// Note: Some Emscripten settings will significantly limit the speed of the generated code.
// Note: Some Emscripten settings may limit the speed of the generated code.
try {
  this['Module'] = Module;
} catch(e) {
  this['Module'] = Module = {};
}
// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;
if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  Module['print'] = function(x) {
    process['stdout'].write(x + '\n');
  };
  Module['printErr'] = function(x) {
    process['stderr'].write(x + '\n');
  };
  var nodeFS = require('fs');
  var nodePath = require('path');
  Module['read'] = function(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };
  Module['readBinary'] = function(filename) { return Module['read'](filename, true) };
  Module['load'] = function(f) {
    globalEval(read(f));
  };
  if (!Module['arguments']) {
    Module['arguments'] = process['argv'].slice(2);
  }
}
if (ENVIRONMENT_IS_SHELL) {
  Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm
  Module['read'] = read;
  Module['readBinary'] = function(f) {
    return read(f, 'binary');
  };
  if (!Module['arguments']) {
    if (typeof scriptArgs != 'undefined') {
      Module['arguments'] = scriptArgs;
    } else if (typeof arguments != 'undefined') {
      Module['arguments'] = arguments;
    }
  }
}
if (ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_WORKER) {
  if (!Module['print']) {
    Module['print'] = function(x) {
      console.log(x);
    };
  }
  if (!Module['printErr']) {
    Module['printErr'] = function(x) {
      console.log(x);
    };
  }
}
if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };
  if (!Module['arguments']) {
    if (typeof arguments != 'undefined') {
      Module['arguments'] = arguments;
    }
  }
}
if (ENVIRONMENT_IS_WORKER) {
  // We can do very little here...
  var TRY_USE_DUMP = false;
  if (!Module['print']) {
    Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }
  Module['load'] = importScripts;
}
if (!ENVIRONMENT_IS_WORKER && !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_SHELL) {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}
function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] == 'undefined' && Module['read']) {
  Module['load'] = function(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
// *** Environment setup code ***
// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];
// Callbacks
if (!Module['preRun']) Module['preRun'] = [];
if (!Module['postRun']) Module['postRun'] = [];
// === Auto-generated preamble library stuff ===
//========================================
// Runtime code shared with compiler
//========================================
var Runtime = {
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  forceAlign: function (target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target/quantum)*quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      var logg = log2(quantum);
      return '((((' +target + ')+' + (quantum-1) + ')>>' + logg + ')<<' + logg + ')';
    }
    return 'Math.ceil((' + target + ')/' + quantum + ')*' + quantum;
  },
  isNumberType: function (type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  },
  isPointerType: function isPointerType(type) {
  return type[type.length-1] == '*';
},
  isStructType: function isStructType(type) {
  if (isPointerType(type)) return false;
  if (/^\[\d+\ x\ (.*)\]/.test(type)) return true; // [15 x ?] blocks. Like structs
  if (/<?{ ?[^}]* ?}>?/.test(type)) return true; // { i32, i8 } etc. - anonymous struct types
  // See comment in isStructPointerType()
  return type[0] == '%';
},
  INT_TYPES: {"i1":0,"i8":0,"i16":0,"i32":0,"i64":0},
  FLOAT_TYPES: {"float":0,"double":0},
  or64: function (x, y) {
    var l = (x | 0) | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  and64: function (x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  xor64: function (x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  getNativeTypeSize: function (type, quantumSize) {
    if (Runtime.QUANTUM_SIZE == 1) return 1;
    var size = {
      '%i1': 1,
      '%i8': 1,
      '%i16': 2,
      '%i32': 4,
      '%i64': 8,
      "%float": 4,
      "%double": 8
    }['%'+type]; // add '%' since float and double confuse Closure compiler as keys, and also spidermonkey as a compiler will remove 's from '_i8' etc
    if (!size) {
      if (type.charAt(type.length-1) == '*') {
        size = Runtime.QUANTUM_SIZE; // A pointer
      } else if (type[0] == 'i') {
        var bits = parseInt(type.substr(1));
        assert(bits % 8 == 0);
        size = bits/8;
      }
    }
    return size;
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  dedup: function dedup(items, ident) {
  var seen = {};
  if (ident) {
    return items.filter(function(item) {
      if (seen[item[ident]]) return false;
      seen[item[ident]] = true;
      return true;
    });
  } else {
    return items.filter(function(item) {
      if (seen[item]) return false;
      seen[item] = true;
      return true;
    });
  }
},
  set: function set() {
  var args = typeof arguments[0] === 'object' ? arguments[0] : arguments;
  var ret = {};
  for (var i = 0; i < args.length; i++) {
    ret[args[i]] = 0;
  }
  return ret;
},
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    type.flatIndexes = type.fields.map(function(field) {
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field); // pack char; char; in structs, also char[X]s.
        alignSize = size;
      } else if (Runtime.isStructType(field)) {
        size = Types.types[field].flatSize;
        alignSize = Types.types[field].alignSize;
      } else if (field[0] == 'b') {
        // bN, large number field, like a [N x i8]
        size = field.substr(1)|0;
        alignSize = 1;
      } else {
        throw 'Unclear type in struct: ' + field + ', in ' + type.name_ + ' :: ' + dump(Types.types[type.name_]);
      }
      alignSize = type.packed ? 1 : Math.min(alignSize, Runtime.QUANTUM_SIZE);
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize); // if necessary, place this on aligned memory
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr-prev);
      }
      prev = curr;
      return curr;
    });
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = (type.flatFactor != 1);
    return type.flatIndexes;
  },
  generateStructInfo: function (struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === 'undefined' ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      if (type.fields.length != struct.length) {
        printErr('Number of named fields must match the type for ' + typeName + ': possibly duplicate struct names. Cannot return structInfo');
        return null;
      }
      alignment = type.flatIndexes;
    } else {
      var type = { fields: struct.map(function(item) { return item[0] }) };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach(function(item, i) {
        if (typeof item === 'string') {
          ret[item] = alignment[i] + offset;
        } else {
          // embedded struct
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      });
    } else {
      struct.forEach(function(item, i) {
        ret[item[1]] = alignment[i];
      });
    }
    return ret;
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  addFunction: function (func, sig) {
    //assert(sig); // TODO: support asm
    var table = FUNCTION_TABLE; // TODO: support asm
    var ret = table.length;
    table.push(func);
    table.push(0);
    return ret;
  },
  removeFunction: function (index) {
    var table = FUNCTION_TABLE; // TODO: support asm
    table[index] = null;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[func]) {
      Runtime.funcWrappers[func] = function() {
        Runtime.dynCall(sig, func, arguments);
      };
    }
    return Runtime.funcWrappers[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xff;
      if (needed) {
        buffer.push(code);
        needed--;
      }
      if (buffer.length == 0) {
        if (code < 128) return String.fromCharCode(code);
        buffer.push(code);
        if (code > 191 && code < 224) {
          needed = 1;
        } else {
          needed = 2;
        }
        return '';
      }
      if (needed > 0) return '';
      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var ret;
      if (c1 > 191 && c1 < 224) {
        ret = String.fromCharCode(((c1 & 31) << 6) | (c2 & 63));
      } else {
        ret = String.fromCharCode(((c1 & 15) << 12) | ((c2 & 63) << 6) | (c3 & 63));
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function(string) {
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = ((((STACKTOP)+3)>>2)<<2); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = ((((STATICTOP)+3)>>2)<<2); if (STATICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 4))*(quantum ? quantum : 4); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+(((low)>>>(0))))+((+(((high)>>>(0))))*(+(4294967296)))) : ((+(((low)>>>(0))))+((+(((high)|(0))))*(+(4294967296))))); return ret; },
  QUANTUM_SIZE: 4,
  __dummy__: 0
}
//========================================
// Runtime essentials
//========================================
var __THREW__ = 0; // Used in checking for thrown exceptions.
var ABORT = false;
var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;
function abort(text) {
  Module.print(text + ':\n' + (new Error).stack);
  ABORT = true;
  throw "Assertion: " + text;
}
function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}
var globalScope = this;
// C calling interface. A convenient way to call C functions (in C files, or
// defined with extern "C").
//
// Note: LLVM optimizations can inline and remove functions, after which you will not be
//       able to call them. Closure can also do so. To avoid that, add your function to
//       the exports using something like
//
//         -s EXPORTED_FUNCTIONS='["_main", "_myfunc"]'
//
// @param ident      The name of the C function (note that C++ functions will be name-mangled - use extern "C")
// @param returnType The return type of the function, one of the JS types 'number', 'string' or 'array' (use 'number' for any C pointer, and
//                   'array' for JavaScript arrays and typed arrays).
// @param argTypes   An array of the types of arguments for the function (if there are no arguments, this can be ommitted). Types are as in returnType,
//                   except that 'array' is not possible (there is no way for us to know the length of the array)
// @param args       An array of the arguments to the function, as native JS values (as in returnType)
//                   Note that string arguments will be stored on the stack (the JS string will become a C string on the stack).
// @return           The return value, as a native JS value (as in returnType)
function ccall(ident, returnType, argTypes, args) {
  return ccallFunc(getCFunc(ident), returnType, argTypes, args);
}
Module["ccall"] = ccall;
// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  try {
    var func = globalScope['Module']['_' + ident]; // closure exported function
    if (!func) func = eval('_' + ident); // explicit lookup
  } catch(e) {
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}
// Internal function that does a C call using a function, not an identifier
function ccallFunc(func, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == 'string') {
      if (value === null || value === undefined || value === 0) return 0; // null string
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length+1);
      writeStringToMemory(value, ret);
      return ret;
    } else if (type == 'array') {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == 'string') {
      return Pointer_stringify(value);
    }
    assert(type != 'array');
    return value;
  }
  var i = 0;
  var cArgs = args ? args.map(function(arg) {
    return toC(arg, argTypes[i++]);
  }) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}
// Returns a native JS wrapper for a C function. This is similar to ccall, but
// returns a function you can call repeatedly in a normal way. For example:
//
//   var my_function = cwrap('my_c_function', 'number', ['number', 'number']);
//   alert(my_function(5, 22));
//   alert(my_function(99, 12));
//
function cwrap(ident, returnType, argTypes) {
  var func = getCFunc(ident);
  return function() {
    return ccallFunc(func, returnType, argTypes, Array.prototype.slice.call(arguments));
  }
}
Module["cwrap"] = cwrap;
// Sets a value in memory in a dynamic way at run-time. Uses the
// type data. This is the same as makeSetValue, except that
// makeSetValue is done at compile-time and generates the needed
// code then, whereas this function picks the right code at
// run-time.
// Note that setValue and getValue only do *aligned* writes and reads!
// Note that ccall uses JS types as for defining types, while setValue and
// getValue need LLVM types ('i8', 'i32') - this is a lower-level operation
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[(ptr)]=value; break;
      case 'i8': HEAP8[(ptr)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,Math.min(Math.floor((value)/(+(4294967296))), (+(4294967295)))>>>0],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': (HEAPF64[(tempDoublePtr)>>3]=value,HEAP32[((ptr)>>2)]=((HEAP32[((tempDoublePtr)>>2)])|0),HEAP32[(((ptr)+(4))>>2)]=((HEAP32[(((tempDoublePtr)+(4))>>2)])|0)); break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;
// Parallel to setValue.
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[(ptr)];
      case 'i8': return HEAP8[(ptr)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return (HEAP32[((tempDoublePtr)>>2)]=HEAP32[((ptr)>>2)],HEAP32[(((tempDoublePtr)+(4))>>2)]=HEAP32[(((ptr)+(4))>>2)],(+(HEAPF64[(tempDoublePtr)>>3])));
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;
var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_NONE = 3; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_NONE'] = ALLOC_NONE;
// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }
  var singleType = typeof types === 'string' ? types : null;
  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }
  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)|0)]=0;
    }
    return ret;
  }
  if (singleType === 'i8') {
    HEAPU8.set(new Uint8Array(slab), ret);
    return ret;
  }
  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];
    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }
    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later
    setValue(ret+i, curr, type);
    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }
  return ret;
}
Module['allocate'] = allocate;
function Pointer_stringify(ptr, /* optional */ length) {
  // Find the length, and check for UTF while doing so
  var hasUtf = false;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))|0)];
    if (t >= 128) hasUtf = true;
    else if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;
  var ret = '';
  if (!hasUtf) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }
  var utf8 = new Runtime.UTF8Processor();
  for (i = 0; i < length; i++) {
    t = HEAPU8[(((ptr)+(i))|0)];
    ret += utf8.processCChar(t);
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;
// Memory management
var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return ((x+4095)>>12)<<12;
}
var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;
var STACK_ROOT, STACKTOP, STACK_MAX;
var STATICTOP;
function enlargeMemory() {
  abort('Cannot enlarge memory arrays in asm.js. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value, or (2) set Module.TOTAL_MEMORY before the program runs.');
}
var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 16777216;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;
// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(!!Int32Array && !!Float64Array && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'Cannot fallback to non-typed array case: Code is too specialized');
var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);
// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');
Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;
STACK_ROOT = STACKTOP = Runtime.alignMemory(1);
STACK_MAX = TOTAL_STACK; // we lose a little stack here, but TOTAL_STACK is nice and round so use that as the max
var tempDoublePtr = Runtime.alignMemory(allocate(12, 'i8', ALLOC_STACK), 8);
assert(tempDoublePtr % 8 == 0);
function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
}
function copyTempDouble(ptr) {
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];
  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];
  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];
  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];
}
STATICTOP = STACK_MAX;
assert(STATICTOP < TOTAL_MEMORY); // Stack must fit in TOTAL_MEMORY; allocations from here on may enlarge TOTAL_MEMORY
var nullString = allocate(intArrayFromString('(null)'), 'i8', ALLOC_STACK);
function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}
var __ATINIT__ = []; // functions called during startup
var __ATMAIN__ = []; // functions called when main() is to be run
var __ATEXIT__ = []; // functions called during shutdown
var runtimeInitialized = false;
function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}
function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}
function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
}
// Tools
// This processes a JS string into a C-line array of numbers, 0-terminated.
// For LLVM-originating strings, see parser.js:parseLLVMString function
function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;
function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;
// Write a Javascript array to somewhere in the heap
function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))|0)]=chr
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;
function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[(((buffer)+(i))|0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;
function unSign(value, bits, ignore, sig) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore, sig) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}
if (!Math.imul) Math.imul = function(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyTracking = {};
var calledInit = false, calledRun = false;
var runDependencyWatcher = null;
function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
    if (runDependencyWatcher === null && typeof setInterval !== 'undefined') {
      // Check for missing dependencies every few seconds
      runDependencyWatcher = setInterval(function() {
        var shown = false;
        for (var dep in runDependencyTracking) {
          if (!shown) {
            shown = true;
            Module.printErr('still waiting on run dependencies:');
          }
          Module.printErr('dependency: ' + dep);
        }
        if (shown) {
          Module.printErr('(end of list)');
        }
      }, 6000);
    }
  } else {
    Module.printErr('warning: run dependency added without ID');
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    Module.printErr('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    } 
    // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
    if (!calledRun && shouldRunNow) run();
  }
}
Module['removeRunDependency'] = removeRunDependency;
Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data
function addPreRun(func) {
  if (!Module['preRun']) Module['preRun'] = [];
  else if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
  Module['preRun'].push(func);
}
var awaitingMemoryInitializer = false;
function loadMemoryInitializer(filename) {
  function applyData(data) {
    HEAPU8.set(data, TOTAL_STACK);
    runPostSets();
  }
  // always do this asynchronously, to keep shell and web as similar as possible
  addPreRun(function() {
    if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
      applyData(Module['readBinary'](filename));
    } else {
      Browser.asyncLoad(filename, function(data) {
        applyData(data);
      }, function(data) {
        throw 'could not load memory initializer ' + filename;
      });
    }
  });
  awaitingMemoryInitializer = false;
}
// === Body ===
assert(STATICTOP == STACK_MAX); assert(STACK_MAX == TOTAL_STACK);
STATICTOP += 84236;
assert(STATICTOP < TOTAL_MEMORY);
var _stdout;
var _stderr;
var _stdout = _stdout=allocate([0,0,0,0], "i8", ALLOC_STATIC);
var _stderr = _stderr=allocate([0,0,0,0], "i8", ALLOC_STATIC);
/* memory initializer */ allocate([4,0,16,0,18,4,0,0,18,4,4,0,14,2,8,0,14,2,10,0,14,2,12,0,14,2,14,0,0,0,0,0,4,0,8,0,18,4,0,0,18,4,4,0,0,0,0,0,4,0,16,0,18,4,0,0,18,4,4,0,18,4,8,0,18,4,12,0,0,0,0,0,4,0,40,0,24,8,0,0,25,4,0,0,18,4,8,0,18,4,12,0,18,4,16,0,25,16,0,0,0,0,0,0,4,0,248,0,18,4,0,0,14,2,4,0,14,2,6,0,25,12,0,0,14,2,8,0,25,2,0,0,14,2,10,0,25,110,0,0,18,4,12,0,18,4,16,0,25,104,0,0,0,0,0,0,4,0,40,0,14,2,0,0,25,34,0,0,14,2,2,0,14,2,4,0,0,0,0,0,4,0,64,0,14,2,0,0,25,58,0,0,18,2,2,0,0,0,0,0,216,49,81,0,44,47,81,0,80,55,81,0,224,0,80,0,0,0,0,0,0,0,0,0,126,1,0,0,4,0,148,0,14,2,0,0,18,4,4,0,24,60,8,0,14,2,68,0,14,2,70,0,14,2,72,0,14,2,74,0,14,2,76,0,14,2,78,0,14,2,80,0,8,1,82,0,8,1,83,0,8,1,84,0,14,2,86,0,8,1,88,0,14,2,90,0,14,2,92,0,8,1,94,0,14,2,96,0,14,2,98,0,8,1,100,0,8,1,101,0,8,1,102,0,8,1,103,0,14,2,104,0,18,4,108,0,18,4,112,0,18,4,116,0,18,4,120,0,8,1,124,0,18,4,128,0,14,2,132,0,14,2,134,0,14,2,136,0,18,2,138,0,24,16,140,0,0,0,0,0,1,2,0,0,40,0,0,0,80,55,81,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,106,3,0,0,152,0,0,0,44,0,0,0,160,0,0,0,110,2,0,0,190,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,1,0,0,136,3,0,0,208,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,3,0,0,196,1,0,0,236,58,81,0,180,55,81,0,8,53,81,0,20,2,80,0,132,50,81,0,16,2,80,0,192,47,81,0,12,2,80,0,0,0,0,0,0,0,0,0,120,3,0,0,2,0,0,0,0,0,0,0,0,0,0,0,118,3,0,0,64,3,0,0,24,3,0,0,198,2,0,0,4,0,5,0,8,1,0,0,8,1,1,0,9,1,2,0,9,1,3,0,8,1,4,0,0,0,0,0,4,0,32,0,16,4,0,0,16,4,4,0,13,2,8,0,13,2,10,0,16,4,12,0,16,4,16,0,16,4,20,0,16,4,24,0,16,4,28,0,0,0,0,0,4,0,54,0,16,4,0,0,16,4,4,0,12,2,8,0,12,2,10,0,12,2,12,0,12,2,14,0,12,2,16,0,24,16,20,0,24,8,36,0,24,6,44,0,9,1,50,0,9,1,51,0,8,1,52,0,8,1,53,0,0,0,0,0,4,0,10,0,13,2,88,0,13,2,90,0,12,2,92,0,12,2,94,0,12,2,96,0,0,0,0,0,4,0,8,0,16,4,80,0,16,4,84,0,0,0,0,0,4,0,78,0,12,2,0,0,13,2,2,0,12,2,4,0,12,2,6,0,13,2,8,0,13,2,10,0,13,2,12,0,13,2,14,0,13,2,16,0,13,2,18,0,13,2,20,0,13,2,22,0,13,2,24,0,13,2,26,0,13,2,28,0,13,2,30,0,8,1,32,0,8,1,33,0,8,1,34,0,8,1,35,0,8,1,36,0,8,1,37,0,8,1,38,0,8,1,39,0,8,1,40,0,8,1,41,0,16,4,44,0,16,4,48,0,16,4,52,0,16,4,56,0,8,1,60,0,8,1,61,0,8,1,62,0,8,1,63,0,12,2,64,0,12,2,66,0,12,2,68,0,13,2,70,0,13,2,72,0,13,2,74,0,12,2,76,0,12,2,78,0,0,0,0,0,4,0,6,0,12,2,0,0,12,4,4,0,12,4,8,0,0,0,0,0,12,2,0,0,12,2,2,0,12,2,4,0,12,2,6,0,12,2,8,0,12,4,12,0,0,0,0,0,4,0,26,0,12,2,6,0,12,2,8,0,12,2,10,0,12,2,12,0,12,2,14,0,12,2,16,0,12,2,18,0,12,2,20,0,12,2,22,0,12,2,24,0,12,2,26,0,12,2,28,0,12,2,30,0,0,0,0,0,4,0,6,0,17,4,0,0,12,2,4,0,0,0,0,0,4,0,36,0,16,4,0,0,13,2,4,0,13,2,6,0,13,2,8,0,12,2,10,0,13,2,12,0,13,2,14,0,13,2,16,0,13,2,18,0,13,2,20,0,13,2,22,0,13,2,24,0,13,2,26,0,13,2,28,0,13,2,30,0,13,2,32,0,12,2,34,0,0,0,0,0,4,0,54,0,16,4,0,0,16,4,4,0,17,4,8,0,17,4,12,0,12,2,16,0,12,2,18,0,17,4,20,0,17,4,24,0,17,4,28,0,17,4,32,0,13,2,36,0,13,2,38,0,13,2,40,0,13,2,42,0,12,2,44,0,12,2,46,0,13,2,48,0,13,2,50,0,13,2,52,0,0,0,0,0,4,0,8,0,12,2,4,0,12,2,6,0,12,2,8,0,12,2,10,0,0,0,0,0,16,4,8,0,17,0,0,0,16,4,0,0,16,4,12,0,0,0,0,0,12,2,40,0,12,2,42,0,8,1,44,0,8,1,45,0,8,1,46,0,9,1,47,0,0,0,0,0,9,1,0,0,9,1,1,0,8,1,2,0,9,1,3,0,9,1,4,0,9,1,5,0,9,1,6,0,9,1,7,0,9,1,8,0,9,1,9,0,9,1,10,0,9,1,11,0,0,0,0,0,1,5,0,0,84,0,0,0,84,62,81,0,0,0,1,0,0,0,2,0,0,0,0,0,184,3,0,0,76,3,0,0,10,3,0,0,56,3,0,0,48,1,0,0,160,0,0,0,18,3,0,0,246,1,0,0,182,0,0,0,122,0,0,0,172,2,0,0,0,0,0,0,112,1,0,0,136,3,0,0,24,1,0,0,242,0,0,0,0,0,0,0,114,2,0,0,170,2,0,0,38,1,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,1,0,0,0,64,0,0,0,1,0,0,0,1,0,0,0,68,0,0,0,0,0,0,0,0,0,0,0,9,0,3,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,0,0,156,7,80,0,152,6,80,0,100,6,80,0,48,6,80,0,252,5,80,0,104,7,80,0,52,7,80,0,0,7,80,0,204,6,80,0,0,0,0,0,24,0,0,0,194,2,0,0,0,0,0,0,170,0,0,0,142,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,210,1,0,0,48,3,0,0,24,0,0,0,194,2,0,0,0,0,0,0,168,3,0,0,14,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,128,3,0,0,194,0,0,0,56,0,0,0,176,1,0,0,0,0,0,0,116,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,246,0,0,0,250,1,0,0,24,0,0,0,194,2,0,0,0,0,0,0,220,2,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,234,0,0,0,102,1,0,0,40,0,0,0,84,2,0,0,22,0,0,0,156,3,0,0,6,3,0,0,30,3,0,0,84,3,0,0,242,1,0,0,104,1,0,0,102,2,0,0,14,0,0,0,70,1,0,0,162,3,0,0,44,0,0,0,134,0,0,0,0,0,0,0,174,1,0,0,230,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,222,2,0,0,168,1,0,0,44,0,0,0,236,2,0,0,0,0,0,0,146,0,0,0,116,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,142,1,0,0,186,0,0,0,24,0,0,0,194,2,0,0,0,0,0,0,66,1,0,0,176,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,64,1,0,0,140,3,0,0,24,0,0,0,194,2,0,0,0,0,0,0,10,2,0,0,180,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,1,0,0,120,1,0,0,88,240,188,5,228,2,0,0,241,59,35,40,196,135,0,0,234,161,68,163,225,1,0,0,88,240,188,5,228,2,0,0,241,59,35,40,196,135,0,0,235,161,68,163,225,1,0,0,212,234,229,17,80,3,0,0,59,202,48,90,99,144,0,0,2,38,164,19,126,0,0,0,252,255,251,255,8,0,0,0,184,72,158,156,162,190,0,0,18,1,2,112,8,0,0,0,252,255,251,255,8,0,0,0,131,4,90,10,57,124,1,0,18,1,2,112,8,0,0,0,68,70,75,97,105,83,104,111,45,83,66,0,0,0,0,0,0,68,70,75,97,105,83,104,117,0,0,0,0,0,0,0,0,0,68,70,75,97,105,45,83,66,0,0,0,0,0,0,0,0,0,72,117,97,84,105,97,110,75,97,105,84,105,63,0,0,0,0,72,117,97,84,105,97,110,83,111,110,103,84,105,63,0,0,0,77,105,110,103,76,105,85,0,0,0,0,0,0,0,0,0,0,80,77,105,110,103,76,105,85,0,0,0,0,0,0,0,0,0,77,105,110,103,76,105,52,51,0,0,0,0,0,0,0,0,0,248,55,81,0,12,9,80,0,156,55,81,0,8,9,80,0,52,55,81,0,248,8,80,0,220,54,81,0,112,54,81,0,0,0,0,0,0,0,0,0,184,0,0,0,100,1,0,0,62,2,0,0,196,2,0,0,146,3,0,0,40,3,0,0,164,3,0,0,104,45,81,0,3,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,43,81,0,3,0,0,0,5,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,42,81,0,3,0,0,0,5,0,0,0,0,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,81,0,3,0,0,0,5,0,0,0,0,0,0,0,12,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,62,81,0,3,0,0,0,5,0,0,0,0,0,0,0,16,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,62,81,0,3,0,0,0,2,0,0,0,0,0,0,0,20,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,61,81,0,3,0,0,0,1,0,0,0,0,0,0,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,61,81,0,3,0,0,0,2,0,0,0,0,0,0,0,26,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,61,81,0,3,0,0,0,2,0,0,0,0,0,0,0,28,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,60,81,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,60,81,0,1,0,0,0,6,0,0,0,0,0,0,0,232,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,60,81,0,1,0,0,0,2,0,0,0,0,0,0,0,44,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,59,81,0,1,0,0,0,2,0,0,0,0,0,0,0,45,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,59,81,0,1,0,0,0,3,0,0,0,0,0,0,0,92,1,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,58,81,0,5,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,58,81,0,5,0,0,0,10,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,58,81,0,5,0,0,0,10,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,57,81,0,5,0,0,0,10,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,57,81,0,5,0,0,0,10,0,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,5,0,0,48,0,0,0,124,56,81,0,0,0,1,0,0,0,2,0,0,0,0,0,18,1,0,0,62,1,0,0,42,3,0,0,48,2,0,0,48,0,0,0,164,0,0,0,78,0,0,0,180,1,0,0,200,1,0,0,60,3,0,0,252,0,0,0,44,0,0,0,112,1,0,0,136,3,0,0,194,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,3,0,0,168,2,0,0,1,5,0,0,40,0,0,0,228,58,81,0,0,0,1,0,0,0,2,0,0,0,0,0,86,3,0,0,64,2,0,0,204,1,0,0,76,1,0,0,48,0,0,0,172,0,0,0,94,3,0,0,188,0,0,0,46,1,0,0,6,1,0,0,130,2,0,0,162,0,0,0,112,1,0,0,136,3,0,0,152,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,0,64,0,65,0,66,0,67,0,68,0,69,0,70,0,71,0,72,0,73,0,74,0,75,0,76,0,77,0,78,0,79,0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,0,88,0,89,0,90,0,91,0,92,0,93,0,94,0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,97,0,98,0,99,0,100,0,101,0,102,0,103,0,104,0,105,0,106,0,107,0,108,0,109,0,110,0,0,0,111,0,112,0,113,0,114,0,0,0,115,0,116,0,117,0,118,0,119,0,120,0,121,0,122,0,0,0,123,0,0,0,124,0,125,0,126,0,127,0,128,0,129,0,130,0,131,0,0,0,132,0,133,0,0,0,134,0,135,0,136,0,137,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,138,0,0,0,139,0,0,0,0,0,0,0,0,0,140,0,141,0,142,0,143,0,0,0,0,0,0,0,0,0,0,0,144,0,0,0,0,0,0,0,145,0,0,0,0,0,146,0,147,0,148,0,149,0,0,0,0,0,0,0,0,0,232,46,81,0,236,14,80,0,172,46,81,0,24,15,80,0,120,46,81,0,80,46,81,0,44,46,81,0,240,14,80,0,20,46,81,0,20,15,80,0,240,45,81,0,0,15,80,0,0,0,0,0,0,0,0,0,200,0,0,0,44,2,0,0,42,0,0,0,216,0,0,0,232,2,0,0,10,0,0,0,144,2,0,0,236,0,0,0,28,0,0,0,106,1,0,0,142,3,0,0,234,2,0,0,76,2,0,0,132,62,81,0,3,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,8,62,81,0,3,0,0,0,5,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,160,61,81,0,3,0,0,0,5,0,0,0,0,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,68,61,81,0,3,0,0,0,5,0,0,0,0,0,0,0,12,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,236,60,81,0,3,0,0,0,5,0,0,0,0,0,0,0,16,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,148,60,81,0,3,0,0,0,2,0,0,0,0,0,0,0,20,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,68,60,81,0,3,0,0,0,1,0,0,0,0,0,0,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,228,59,81,0,3,0,0,0,2,0,0,0,0,0,0,0,26,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,124,59,81,0,3,0,0,0,2,0,0,0,0,0,0,0,28,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,24,59,81,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,156,58,81,0,4,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,68,58,81,0,4,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,224,57,81,0,4,0,0,0,2,0,0,0,0,0,0,0,184,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,144,57,81,0,4,0,0,0,2,0,0,0,0,0,0,0,188,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,64,57,81,0,4,0,0,0,4,0,0,0,0,0,0,0,108,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,236,56,81,0,4,0,0,0,2,0,0,0,0,0,0,0,112,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,172,56,81,0,4,0,0,0,2,0,0,0,0,0,0,0,116,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,100,56,81,0,4,0,0,0,8,0,0,0,0,0,0,0,12,0,0,0,2,0,0,0,14,0,0,0,8,0,0,0,2,0,0,0,20,56,81,0,4,0,0,0,8,0,0,0,0,0,0,0,40,0,0,0,2,0,0,0,10,0,0,0,9,0,0,0,2,0,0,0,200,55,81,0,4,0,0,0,8,0,0,0,0,0,0,0,60,0,0,0,2,0,0,0,14,0,0,0,10,0,0,0,2,0,0,0,100,55,81,0,4,0,0,0,8,0,0,0,0,0,0,0,88,0,0,0,2,0,0,0,10,0,0,0,11,0,0,0,2,0,0,0,12,55,81,0,4,0,0,0,8,0,0,0,0,0,0,0,120,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,152,54,81,0,4,0,0,0,8,0,0,0,0,0,0,0,122,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,76,54,81,0,4,0,0,0,8,0,0,0,0,0,0,0,192,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,12,54,81,0,4,0,0,0,8,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,12,0,0,0,124,0,0,0,2,0,0,0,220,53,81,0,4,0,0,0,8,0,0,0,0,0,0,0,154,0,0,0,2,0,0,0,12,0,0,0,125,0,0,0,2,0,0,0,188,53,81,0,4,0,0,0,3,0,0,0,0,0,0,0,180,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,148,53,81,0,4,0,0,0,1,0,0,0,0,0,0,0,126,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,84,53,81,0,1,0,0,0,6,0,0,0,0,0,0,0,232,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,36,53,81,0,1,0,0,0,2,0,0,0,0,0,0,0,44,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,220,52,81,0,1,0,0,0,2,0,0,0,0,0,0,0,45,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,152,52,81,0,1,0,0,0,3,0,0,0,0,0,0,0,92,1,0,0,4,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,60,52,81,0,5,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,8,52,81,0,7,0,0,0,2,0,0,0,0,0,0,0,24,2,0,0,4,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,224,51,81,0,7,0,0,0,2,0,0,0,0,0,0,0,28,2,0,0,4,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,152,51,81,0,8,0,0,0,8,0,0,0,0,0,0,0,96,1,0,0,4,0,0,0,16,0,0,0,160,1,0,0,1,0,0,0,92,51,81,0,8,0,0,0,10,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,60,51,81,0,8,0,0,0,10,0,0,0,50,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,240,50,81,0,8,0,0,0,10,0,0,0,114,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,252,62,81,0,8,0,0,0,10,0,0,0,186,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,160,50,81,0,8,0,0,0,10,0,0,0,96,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,72,50,81,0,8,0,0,0,10,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,248,49,81,0,8,0,0,0,10,0,0,0,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,152,49,81,0,8,0,0,0,10,0,0,0,158,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,68,49,81,0,8,0,0,0,10,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,24,49,81,0,8,0,0,0,10,0,0,0,184,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,0,230,0,0,0,231,0,232,0,233,0,234,0,235,0,236,0,237,0,238,0,13,0,14,0,15,0,99,0,239,0,240,0,241,0,242,0,243,0,244,0,245,0,246,0,247,0,248,0,27,0,28,0,249,0,250,0,251,0,252,0,0,0,253,0,254,0,255,0,0,1,1,1,0,0,0,0,0,0,2,1,0,0,0,0,3,1,4,1,5,1,6,1,0,0,0,0,7,1,8,1,9,1,0,0,10,1,109,0,110,0,11,1,12,1,13,1,0,0,14,1,15,1,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,37,1,38,1,39,1,40,1,41,1,42,1,43,1,44,1,45,1,46,1,47,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,1,49,1,50,1,0,0,0,0,51,1,52,1,53,1,54,1,55,1,0,0,56,1,0,0,0,0,57,1,0,0,0,0,58,1,59,1,0,0,0,0,60,1,61,1,62,1,0,0,0,0,0,0,158,0,155,0,163,0,63,1,64,1,65,1,66,1,67,1,68,1,69,1,0,0,0,0,70,1,150,0,164,0,169,0,71,1,72,1,73,1,74,1,75,1,76,1,77,1,78,1,79,1,80,1,81,1,82,1,83,1,84,1,85,1,86,1,87,1,88,1,89,1,90,1,91,1,92,1,93,1,94,1,95,1,96,1,97,1,98,1,99,1,100,1,101,1,102,1,103,1,104,1,105,1,106,1,107,1,108,1,109,1,110,1,111,1,112,1,113,1,114,1,115,1,116,1,117,1,118,1,119,1,120,1,121,1,122,1,1,5,0,0,40,0,0,0,188,61,81,0,0,0,1,0,0,0,2,0,0,0,0,0,38,2,0,0,12,1,0,0,216,2,0,0,44,2,0,0,44,0,0,0,180,0,0,0,188,2,0,0,140,0,0,0,86,0,0,0,50,3,0,0,122,2,0,0,56,2,0,0,112,1,0,0,136,3,0,0,40,2,0,0,188,1,0,0,90,1,0,0,32,1,0,0,24,2,0,0,0,0,0,0,158,0,0,0,86,2,0,0,124,0,0,0,24,0,0,0,120,2,0,0,64,0,0,0,172,1,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,34,1,0,0,84,1,0,0,116,1,0,0,124,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,76,1,0,0,84,1,0,0,116,1,0,0,124,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,238,1,0,0,152,0,0,0,54,1,0,0,58,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,24,80,0,128,24,80,0,168,24,80,0,48,24,80,0,90,3,0,0,224,2,0,0,30,2,0,0,206,0,0,0,68,0,0,0,176,0,0,0,104,0,0,0,218,2,0,0,0,0,0,0,0,0,0,0,2,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,6,0,0,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,6,0,0,0,2,0,0,0,6,0,0,0,2,0,0,0,255,255,255,255,1,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,8,63,81,0,156,25,80,0,32,59,81,0,168,25,80,0,212,55,81,0,172,25,80,0,48,53,81,0,180,25,80,0,168,50,81,0,40,2,80,0,0,0,0,0,0,0,0,0,32,0,0,0,254,2,0,0,252,2,0,0,154,3,0,0,244,2,0,0,130,1,0,0,92,0,0,0,126,0,0,0,4,0,8,0,17,4,4,0,17,4,8,0,0,0,0,0,0,0,0,0,20,0,0,0,232,63,81,0,0,0,1,0,0,0,2,0,240,25,80,0,0,0,0,0,0,0,0,0,48,0,0,0,190,1,0,0,134,3,0,0,234,1,0,0,228,0,0,0,48,0,0,0,32,0,0,0,20,1,0,0,160,1,0,0,192,1,0,0,114,1,0,0,224,1,0,0,52,3,0,0,200,2,0,0,8,3,0,0,148,1,0,0,72,2,0,0,60,1,0,0,82,2,0,0,0,3,0,0,98,2,0,0,88,0,0,0,34,0,0,0,204,2,0,0,192,2,0,0,42,2,0,0,158,1,0,0,6,2,0,0,0,2,0,0,118,2,0,0,248,0,0,0,26,1,0,0,150,2,0,0,56,1,0,0,0,1,0,0,68,1,0,0,68,2,0,0,40,1,0,0,110,0,0,0,50,2,0,0,170,1,0,0,2,0,0,0,255,255,255,255,99,105,110,117,0,0,0,0,255,255,255,255,99,105,110,117,1,0,0,0,0,0,0,0,110,109,114,97,3,0,0,0,0,0,0,0,98,109,121,115,3,0,0,0,10,0,0,0,99,105,110,117,3,0,0,0,1,0,0,0,99,105,110,117,3,0,0,0,2,0,0,0,115,105,106,115,3,0,0,0,3,0,0,0,32,32,98,103,3,0,0,0,4,0,0,0,53,103,105,98,3,0,0,0,5,0,0,0,115,110,97,119,3,0,0,0,6,0,0,0,97,104,111,106,4,0,8,0,8,1,0,0,8,1,1,0,9,1,2,0,9,1,3,0,8,1,4,0,9,1,5,0,9,1,6,0,8,1,7,0,0,0,0,0,250,2,0,0,0,0,0,0,46,3,0,0,1,0,0,0,12,0,0,0,2,0,0,0,94,0,0,0,3,0,0,0,154,1,0,0,4,0,0,0,110,1,0,0,5,0,0,0,134,2,0,0,6,0,0,0,82,3,0,0,7,0,0,0,36,3,0,0,8,0,0,0,0,0,0,0,20,0,0,0,92,42,81,0,0,0,1,0,0,0,2,0,232,27,80,0,0,0,0,0,0,0,0,0,100,2,0,0,0,0,0,0,176,0,0,0,220,42,81,0,0,0,1,0,0,0,2,0,204,27,80,0,126,2,0,0,34,2,0,0,0,0,0,0,2,2,0,0,88,2,0,0,58,2,0,0,172,59,81,0,232,27,80,0,0,0,0,0,0,0,0,0,126,3,0,0,218,1,0,0,242,2,0,0,96,0,0,0,142,0,0,0,214,2,0,0,180,12,80,0,188,21,80,0,0,0,0,0,20,0,0,0,64,48,81,0,0,0,2,0,0,0,2,0,44,28,80,0,0,0,0,0,0,0,0,0,0,0,0,0,72,28,80,0,88,28,80,0,224,24,80,0,36,24,80,0,58,1,0,0,208,24,80,0,160,37,81,0,160,3,0,0,30,0,0,0,182,1,0,0,236,1,0,0,92,1,0,0,248,1,0,0,86,1,0,0,94,1,0,0,4,1,0,0,26,0,0,0,66,3,0,0,112,3,0,0,240,0,0,0,244,0,0,0,70,0,0,0,138,1,0,0,12,2,0,0,1,0,0,0,10,0,0,0,100,0,0,0,232,3,0,0,16,39,0,0,160,134,1,0,64,66,15,0,128,150,152,0,0,225,245,5,0,202,154,59,8,61,81,0,244,28,80,0,80,57,81,0,36,54,81,0,0,0,0,0,0,0,0,0,1,0,0,0,114,0,0,0,2,0,0,0,18,2,0,0,3,0,0,0,164,2,0,0,4,0,0,0,214,1,0,0,0,0,0,0,0,0,0,0,138,2,0,0,104,3,0,0,90,2,0,0,4,0,58,0,16,4,0,0,12,4,4,0,12,4,8,0,12,4,12,0,12,4,16,0,12,4,20,0,12,4,24,0,20,4,28,0,20,4,32,0,12,4,36,0,20,4,40,0,20,4,44,0,12,4,48,0,20,4,52,0,20,4,56,0,8,4,60,0,8,4,64,0,8,4,68,0,8,4,72,0,8,4,76,0,20,4,80,0,20,4,84,0,20,4,88,0,12,4,92,0,8,4,96,0,8,4,100,0,12,4,104,0,0,0,0,0,1,1,0,0,40,0,0,0,184,49,81,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,100,3,0,0,184,1,0,0,44,0,0,0,196,0,0,0,230,2,0,0,56,0,0,0,0,0,0,0,0,0,0,0,172,3,0,0,116,2,0,0,112,1,0,0,136,3,0,0,150,3,0,0,248,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,172,0,0,0,48,1,0,0,62,3,0,0,228,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,8,0,18,4,0,0,18,4,4,0,0,0,0,0,4,0,16,0,18,4,0,0,18,4,4,0,18,4,8,0,18,4,12,0,0,0,0,0,144,59,81,0,68,30,80,0,56,59,81,0,168,58,81,0,0,0,0,0,0,0,0,0,230,0,0,0,36,0,0,0,4,0,9,0,17,4,0,0,8,1,4,0,17,4,8,0,0,0,0,0,4,0,9,0,19,4,0,0,8,1,4,0,19,4,8,0,0,0,0,0,4,0,12,0,13,2,0,0,13,2,2,0,13,2,4,0,13,2,6,0,13,2,8,0,13,2,10,0,0,0,0,0,4,0,12,0,15,2,0,0,15,2,2,0,15,2,4,0,15,2,6,0,15,2,8,0,15,2,10,0,0,0,0,0,1,2,0,0,40,0,0,0,32,55,81,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,70,3,0,0,72,1,0,0,44,0,0,0,160,0,0,0,32,3,0,0,186,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,1,0,0,136,3,0,0,174,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,1,0,0,146,2,0,0,4,0,5,0,8,1,0,0,8,1,1,0,8,1,2,0,8,1,3,0,8,1,4,0,0,0,0,0,24,0,0,0,212,1,0,0,150,0,0,0,212,2,0,0,244,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,20,0,8,1,0,0,8,1,1,0,8,1,2,0,8,1,3,0,8,1,4,0,8,1,5,0,8,1,6,0,25,1,0,0,17,4,8,0,17,4,12,0,17,4,16,0,0,0,0,0,4,0,20,0,8,1,0,0,8,1,1,0,8,1,2,0,8,1,3,0,8,1,4,0,8,1,5,0,8,1,6,0,25,1,0,0,19,4,8,0,19,4,12,0,19,4,16,0,0,0,0,0,139,247,225,13,14,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,255,254,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,3,4,5,6,7,8,9,3,5,7,9,11,13,15,17,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,255,128,192,224,240,248,252,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,3,126,0,0,0,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,2,0,0,58,3,0,0,160,0,0,0,162,1,0,0,0,0,0,0,0,0,0,0,4,0,20,0,17,4,0,0,12,2,4,0,12,2,6,0,16,4,8,0,12,2,12,0,12,2,14,0,16,4,16,0,0,0,0,0,89,111,63,0,0,0,45,0,167,144,26,0,71,9,14,0,1,32,7,0,139,147,3,0,56,202,1,0,42,229,0,0,151,114,0,0,76,57,0,0,166,28,0,0,83,14,0,0,41,7,0,0,149,3,0,0,202,1,0,0,229,0,0,0,115,0,0,0,57,0,0,0,29,0,0,0,14,0,0,0,7,0,0,0,4,0,0,0,2,0,0,0,1,0,0,0,108,116,117,111,100,0,0,0,34,3,0,0,196,0,0,0,2,1,0,0,118,1,0,0,46,110,117,108,108,0,110,111,110,109,97,114,107,105,110,103,114,101,116,117,114,110,0,110,111,116,101,113,117,97,108,0,105,110,102,105,110,105,116,121,0,108,101,115,115,101,113,117,97,108,0,103,114,101,97,116,101,114,101,113,117,97,108,0,112,97,114,116,105,97,108,100,105,102,102,0,115,117,109,109,97,116,105,111,110,0,112,114,111,100,117,99,116,0,112,105,0,105,110,116,101,103,114,97,108,0,79,109,101,103,97,0,114,97,100,105,99,97,108,0,97,112,112,114,111,120,101,113,117,97,108,0,68,101,108,116,97,0,110,111,110,98,114,101,97,107,105,110,103,115,112,97,99,101,0,108,111,122,101,110,103,101,0,97,112,112,108,101,0,102,114,97,110,99,0,71,98,114,101,118,101,0,103,98,114,101,118,101,0,73,100,111,116,97,99,99,101,110,116,0,83,99,101,100,105,108,108,97,0,115,99,101,100,105,108,108,97,0,67,97,99,117,116,101,0,99,97,99,117,116,101,0,67,99,97,114,111,110,0,99,99,97,114,111,110,0,100,99,114,111,97,116,0,46,110,111,116,100,101,102,0,115,112,97,99,101,0,101,120,99,108,97,109,0,113,117,111,116,101,100,98,108,0,110,117,109,98,101,114,115,105,103,110,0,100,111,108,108,97,114,0,112,101,114,99,101,110,116,0,97,109,112,101,114,115,97,110,100,0,113,117,111,116,101,114,105,103,104,116,0,112,97,114,101,110,108,101,102,116,0,112,97,114,101,110,114,105,103,104,116,0,97,115,116,101,114,105,115,107,0,112,108,117,115,0,99,111,109,109,97,0,104,121,112,104,101,110,0,112,101,114,105,111,100,0,115,108,97,115,104,0,122,101,114,111,0,111,110,101,0,116,119,111,0,116,104,114,101,101,0,102,111,117,114,0,102,105,118,101,0,115,105,120,0,115,101,118,101,110,0,101,105,103,104,116,0,110,105,110,101,0,99,111,108,111,110,0,115,101,109,105,99,111,108,111,110,0,108,101,115,115,0,101,113,117,97,108,0,103,114,101,97,116,101,114,0,113,117,101,115,116,105,111,110,0,97,116,0,65,0,66,0,67,0,68,0,69,0,70,0,71,0,72,0,73,0,74,0,75,0,76,0,77,0,78,0,79,0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,0,88,0,89,0,90,0,98,114,97,99,107,101,116,108,101,102,116,0,98,97,99,107,115,108,97,115,104,0,98,114,97,99,107,101,116,114,105,103,104,116,0,97,115,99,105,105,99,105,114,99,117,109,0,117,110,100,101,114,115,99,111,114,101,0,113,117,111,116,101,108,101,102,116,0,97,0,98,0,99,0,100,0,101,0,102,0,103,0,104,0,105,0,106,0,107,0,108,0,109,0,110,0,111,0,112,0,113,0,114,0,115,0,116,0,117,0,118,0,119,0,120,0,121,0,122,0,98,114,97,99,101,108,101,102,116,0,98,97,114,0,98,114,97,99,101,114,105,103,104,116,0,97,115,99,105,105,116,105,108,100,101,0,101,120,99,108,97,109,100,111,119,110,0,99,101,110,116,0,115,116,101,114,108,105,110,103,0,102,114,97,99,116,105,111,110,0,121,101,110,0,102,108,111,114,105,110,0,115,101,99,116,105,111,110,0,99,117,114,114,101,110,99,121,0,113,117,111,116,101,115,105,110,103,108,101,0,113,117,111,116,101,100,98,108,108,101,102,116,0,103,117,105,108,108,101,109,111,116,108,101,102,116,0,103,117,105,108,115,105,110,103,108,108,101,102,116,0,103,117,105,108,115,105,110,103,108,114,105,103,104,116,0,102,105,0,102,108,0,101,110,100,97,115,104,0,100,97,103,103,101,114,0,100,97,103,103,101,114,100,98,108,0,112,101,114,105,111,100,99,101,110,116,101,114,101,100,0,112,97,114,97,103,114,97,112,104,0,98,117,108,108,101,116,0,113,117,111,116,101,115,105,110,103,108,98,97,115,101,0,113,117,111,116,101,100,98,108,98,97,115,101,0,113,117,111,116,101,100,98,108,114,105,103,104,116,0,103,117,105,108,108,101,109,111,116,114,105,103,104,116,0,101,108,108,105,112,115,105,115,0,112,101,114,116,104,111,117,115,97,110,100,0,113,117,101,115,116,105,111,110,100,111,119,110,0,103,114,97,118,101,0,97,99,117,116,101,0,99,105,114,99,117,109,102,108,101,120,0,116,105,108,100,101,0,109,97,99,114,111,110,0,98,114,101,118,101,0,100,111,116,97,99,99,101,110,116,0,100,105,101,114,101,115,105,115,0,114,105,110,103,0,99,101,100,105,108,108,97,0,104,117,110,103,97,114,117,109,108,97,117,116,0,111,103,111,110,101,107,0,99,97,114,111,110,0,101,109,100,97,115,104,0,65,69,0,111,114,100,102,101,109,105,110,105,110,101,0,76,115,108,97,115,104,0,79,115,108,97,115,104,0,79,69,0,111,114,100,109,97,115,99,117,108,105,110,101,0,97,101,0,100,111,116,108,101,115,115,105,0,108,115,108,97,115,104,0,111,115,108,97,115,104,0,111,101,0,103,101,114,109,97,110,100,98,108,115,0,111,110,101,115,117,112,101,114,105,111,114,0,108,111,103,105,99,97,108,110,111,116,0,109,117,0,116,114,97,100,101,109,97,114,107,0,69,116,104,0,111,110,101,104,97,108,102,0,112,108,117,115,109,105,110,117,115,0,84,104,111,114,110,0,111,110,101,113,117,97,114,116,101,114,0,100,105,118,105,100,101,0,98,114,111,107,101,110,98,97,114,0,100,101,103,114,101,101,0,116,104,111,114,110,0,116,104,114,101,101,113,117,97,114,116,101,114,115,0,116,119,111,115,117,112,101,114,105,111,114,0,114,101,103,105,115,116,101,114,101,100,0,109,105,110,117,115,0,101,116,104,0,109,117,108,116,105,112,108,121,0,116,104,114,101,101,115,117,112,101,114,105,111,114,0,99,111,112,121,114,105,103,104,116,0,65,97,99,117,116,101,0,65,99,105,114,99,117,109,102,108,101,120,0,65,100,105,101,114,101,115,105,115,0,65,103,114,97,118,101,0,65,114,105,110,103,0,65,116,105,108,100,101,0,67,99,101,100,105,108,108,97,0,69,97,99,117,116,101,0,69,99,105,114,99,117,109,102,108,101,120,0,69,100,105,101,114,101,115,105,115,0,69,103,114,97,118,101,0,73,97,99,117,116,101,0,73,99,105,114,99,117,109,102,108,101,120,0,73,100,105,101,114,101,115,105,115,0,73,103,114,97,118,101,0,78,116,105,108,100,101,0,79,97,99,117,116,101,0,79,99,105,114,99,117,109,102,108,101,120,0,79,100,105,101,114,101,115,105,115,0,79,103,114,97,118,101,0,79,116,105,108,100,101,0,83,99,97,114,111,110,0,85,97,99,117,116,101,0,85,99,105,114,99,117,109,102,108,101,120,0,85,100,105,101,114,101,115,105,115,0,85,103,114,97,118,101,0,89,97,99,117,116,101,0,89,100,105,101,114,101].concat([115,105,115,0,90,99,97,114,111,110,0,97,97,99,117,116,101,0,97,99,105,114,99,117,109,102,108,101,120,0,97,100,105,101,114,101,115,105,115,0,97,103,114,97,118,101,0,97,114,105,110,103,0,97,116,105,108,100,101,0,99,99,101,100,105,108,108,97,0,101,97,99,117,116,101,0,101,99,105,114,99,117,109,102,108,101,120,0,101,100,105,101,114,101,115,105,115,0,101,103,114,97,118,101,0,105,97,99,117,116,101,0,105,99,105,114,99,117,109,102,108,101,120,0,105,100,105,101,114,101,115,105,115,0,105,103,114,97,118,101,0,110,116,105,108,100,101,0,111,97,99,117,116,101,0,111,99,105,114,99,117,109,102,108,101,120,0,111,100,105,101,114,101,115,105,115,0,111,103,114,97,118,101,0,111,116,105,108,100,101,0,115,99,97,114,111,110,0,117,97,99,117,116,101,0,117,99,105,114,99,117,109,102,108,101,120,0,117,100,105,101,114,101,115,105,115,0,117,103,114,97,118,101,0,121,97,99,117,116,101,0,121,100,105,101,114,101,115,105,115,0,122,99,97,114,111,110,0,101,120,99,108,97,109,115,109,97,108,108,0,72,117,110,103,97,114,117,109,108,97,117,116,115,109,97,108,108,0,100,111,108,108,97,114,111,108,100,115,116,121,108,101,0,100,111,108,108,97,114,115,117,112,101,114,105,111,114,0,97,109,112,101,114,115,97,110,100,115,109,97,108,108,0,65,99,117,116,101,115,109,97,108,108,0,112,97,114,101,110,108,101,102,116,115,117,112,101,114,105,111,114,0,112,97,114,101,110,114,105,103,104,116,115,117,112,101,114,105,111,114,0,116,119,111,100,111,116,101,110,108,101,97,100,101,114,0,111,110,101,100,111,116,101,110,108,101,97,100,101,114,0,122,101,114,111,111,108,100,115,116,121,108,101,0,111,110,101,111,108,100,115,116,121,108,101,0,116,119,111,111,108,100,115,116,121,108,101,0,116,104,114,101,101,111,108,100,115,116,121,108,101,0,102,111,117,114,111,108,100,115,116,121,108,101,0,102,105,118,101,111,108,100,115,116,121,108,101,0,115,105,120,111,108,100,115,116,121,108,101,0,115,101,118,101,110,111,108,100,115,116,121,108,101,0,101,105,103,104,116,111,108,100,115,116,121,108,101,0,110,105,110,101,111,108,100,115,116,121,108,101,0,99,111,109,109,97,115,117,112,101,114,105,111,114,0,116,104,114,101,101,113,117,97,114,116,101,114,115,101,109,100,97,115,104,0,112,101,114,105,111,100,115,117,112,101,114,105,111,114,0,113,117,101,115,116,105,111,110,115,109,97,108,108,0,97,115,117,112,101,114,105,111,114,0,98,115,117,112,101,114,105,111,114,0,99,101,110,116,115,117,112,101,114,105,111,114,0,100,115,117,112,101,114,105,111,114,0,101,115,117,112,101,114,105,111,114,0,105,115,117,112,101,114,105,111,114,0,108,115,117,112,101,114,105,111,114,0,109,115,117,112,101,114,105,111,114,0,110,115,117,112,101,114,105,111,114,0,111,115,117,112,101,114,105,111,114,0,114,115,117,112,101,114,105,111,114,0,115,115,117,112,101,114,105,111,114,0,116,115,117,112,101,114,105,111,114,0,102,102,0,102,102,105,0,102,102,108,0,112,97,114,101,110,108,101,102,116,105,110,102,101,114,105,111,114,0,112,97,114,101,110,114,105,103,104,116,105,110,102,101,114,105,111,114,0,67,105,114,99,117,109,102,108,101,120,115,109,97,108,108,0,104,121,112,104,101,110,115,117,112,101,114,105,111,114,0,71,114,97,118,101,115,109,97,108,108,0,65,115,109,97,108,108,0,66,115,109,97,108,108,0,67,115,109,97,108,108,0,68,115,109,97,108,108,0,69,115,109,97,108,108,0,70,115,109,97,108,108,0,71,115,109,97,108,108,0,72,115,109,97,108,108,0,73,115,109,97,108,108,0,74,115,109,97,108,108,0,75,115,109,97,108,108,0,76,115,109,97,108,108,0,77,115,109,97,108,108,0,78,115,109,97,108,108,0,79,115,109,97,108,108,0,80,115,109,97,108,108,0,81,115,109,97,108,108,0,82,115,109,97,108,108,0,83,115,109,97,108,108,0,84,115,109,97,108,108,0,85,115,109,97,108,108,0,86,115,109,97,108,108,0,87,115,109,97,108,108,0,88,115,109,97,108,108,0,89,115,109,97,108,108,0,90,115,109,97,108,108,0,99,111,108,111,110,109,111,110,101,116,97,114,121,0,111,110,101,102,105,116,116,101,100,0,114,117,112,105,97,104,0,84,105,108,100,101,115,109,97,108,108,0,101,120,99,108,97,109,100,111,119,110,115,109,97,108,108,0,99,101,110,116,111,108,100,115,116,121,108,101,0,76,115,108,97,115,104,115,109,97,108,108,0,83,99,97,114,111,110,115,109,97,108,108,0,90,99,97,114,111,110,115,109,97,108,108,0,68,105,101,114,101,115,105,115,115,109,97,108,108,0,66,114,101,118,101,115,109,97,108,108,0,67,97,114,111,110,115,109,97,108,108,0,68,111,116,97,99,99,101,110,116,115,109,97,108,108,0,77,97,99,114,111,110,115,109,97,108,108,0,102,105,103,117,114,101,100,97,115,104,0,104,121,112,104,101,110,105,110,102,101,114,105,111,114,0,79,103,111,110,101,107,115,109,97,108,108,0,82,105,110,103,115,109,97,108,108,0,67,101,100,105,108,108,97,115,109,97,108,108,0,113,117,101,115,116,105,111,110,100,111,119,110,115,109,97,108,108,0,111,110,101,101,105,103,104,116,104,0,116,104,114,101,101,101,105,103,104,116,104,115,0,102,105,118,101,101,105,103,104,116,104,115,0,115,101,118,101,110,101,105,103,104,116,104,115,0,111,110,101,116,104,105,114,100,0,116,119,111,116,104,105,114,100,115,0,122,101,114,111,115,117,112,101,114,105,111,114,0,102,111,117,114,115,117,112,101,114,105,111,114,0,102,105,118,101,115,117,112,101,114,105,111,114,0,115,105,120,115,117,112,101,114,105,111,114,0,115,101,118,101,110,115,117,112,101,114,105,111,114,0,101,105,103,104,116,115,117,112,101,114,105,111,114,0,110,105,110,101,115,117,112,101,114,105,111,114,0,122,101,114,111,105,110,102,101,114,105,111,114,0,111,110,101,105,110,102,101,114,105,111,114,0,116,119,111,105,110,102,101,114,105,111,114,0,116,104,114,101,101,105,110,102,101,114,105,111,114,0,102,111,117,114,105,110,102,101,114,105,111,114,0,102,105,118,101,105,110,102,101,114,105,111,114,0,115,105,120,105,110,102,101,114,105,111,114,0,115,101,118,101,110,105,110,102,101,114,105,111,114,0,101,105,103,104,116,105,110,102,101,114,105,111,114,0,110,105,110,101,105,110,102,101,114,105,111,114,0,99,101,110,116,105,110,102,101,114,105,111,114,0,100,111,108,108,97,114,105,110,102,101,114,105,111,114,0,112,101,114,105,111,100,105,110,102,101,114,105,111,114,0,99,111,109,109,97,105,110,102,101,114,105,111,114,0,65,103,114,97,118,101,115,109,97,108,108,0,65,97,99,117,116,101,115,109,97,108,108,0,65,99,105,114,99,117,109,102,108,101,120,115,109,97,108,108,0,65,116,105,108,100,101,115,109,97,108,108,0,65,100,105,101,114,101,115,105,115,115,109,97,108,108,0,65,114,105,110,103,115,109,97,108,108,0,65,69,115,109,97,108,108,0,67,99,101,100,105,108,108,97,115,109,97,108,108,0,69,103,114,97,118,101,115,109,97,108,108,0,69,97,99,117,116,101,115,109,97,108,108,0,69,99,105,114,99,117,109,102,108,101,120,115,109,97,108,108,0,69,100,105,101,114,101,115,105,115,115,109,97,108,108,0,73,103,114,97,118,101,115,109,97,108,108,0,73,97,99,117,116,101,115,109,97,108,108,0,73,99,105,114,99,117,109,102,108,101,120,115,109,97,108,108,0,73,100,105,101,114,101,115,105,115,115,109,97,108,108,0,69,116,104,115,109,97,108,108,0,78,116,105,108,100,101,115,109,97,108,108,0,79,103,114,97,118,101,115,109,97,108,108,0,79,97,99,117,116,101,115,109,97,108,108,0,79,99,105,114,99,117,109,102,108,101,120,115,109,97,108,108,0,79,116,105,108,100,101,115,109,97,108,108,0,79,100,105,101,114,101,115,105,115,115,109,97,108,108,0,79,69,115,109,97,108,108,0,79,115,108,97,115,104,115,109,97,108,108,0,85,103,114,97,118,101,115,109,97,108,108,0,85,97,99,117,116,101,115,109,97,108,108,0,85,99,105,114,99,117,109,102,108,101,120,115,109,97,108,108,0,85,100,105,101,114,101,115,105,115,115,109,97,108,108,0,89,97,99,117,116,101,115,109,97,108,108,0,84,104,111,114,110,115,109,97,108,108,0,89,100,105,101,114,101,115,105,115,115,109,97,108,108,0,48,48,49,46,48,48,48,0,48,48,49,46,48,48,49,0,48,48,49,46,48,48,50,0,48,48,49,46,48,48,51,0,66,108,97,99,107,0,66,111,108,100,0,66,111,111,107,0,76,105,103,104,116,0,77,101,100,105,117,109,0,82,101,103,117,108,97,114,0,82,111,109,97,110,0,83,101,109,105,98,111,108,100,0,2,0,0,0,72,0,0,0,196,62,81,0,0,0,1,0,0,0,2,0,0,0,0,0,174,0,0,0,0,0,0,0,0,0,0,0,108,116,117,111,82,0,0,0,138,0,0,0,152,2,0,0,148,3,0,0,120,54,80,0,2,0,0,0,72,0,0,0,12,59,81,0,0,0,1,0,0,0,2,0,0,0,0,0,174,0,0,0,0,0,0,0,0,0,0,0,108,116,117,111,178,1,0,0,138,0,0,0,152,2,0,0,148,3,0,0,120,54,80,0,2,0,0,0,72,0,0,0,240,62,81,0,0,0,1,0,0,0,2,0,0,0,0,0,174,0,0,0,0,0,0,0,0,0,0,0,108,116,117,111,182,3,0,0,138,0,0,0,152,2,0,0,148,3,0,0,120,54,80,0,253,0,5,1,11,1,18,1,27,1,38,1,45,1,53,1,63,1,74,1,84,1,95,1,104,1,109,1,115,1,122,1,129,1,135,1,140,1,144,1,148,1,154,1,159,1,164,1,168,1,174,1,180,1,185,1,191,1,201,1,206,1,212,1,220,1,229,1,232,1,234,1,236,1,238,1,240,1,242,1,244,1,246,1,248,1,250,1,252,1,254,1,0,2,2,2,4,2,6,2,8,2,10,2,12,2,14,2,16,2,18,2,20,2,22,2,24,2,26,2,28,2,40,2,50,2,63,2,75,2,86,2,96,2,98,2,100,2,102,2,104,2,106,2,108,2,110,2,112,2,114,2,116,2,118,2,120,2,122,2,124,2,126,2,128,2,130,2,132,2,134,2,136,2,138,2,140,2,142,2,144,2,146,2,148,2,158,2,162,2,173,2,184,2,195,2,200,2,209,2,218,2,222,2,229,2,237,2,246,2,2,3,15,3,29,3,43,3,58,3,61,3,64,3,71,3,78,3,88,3,103,3,113,3,120,3,135,3,148,3,162,3,177,3,186,3,198,3,211,3,217,3,223,3,234,3,240,3,247,3,253,3,7,4,16,4,21,4,29,4,42,4,49,4,55,4,62,4,65,4,77,4,84,4,91,4,94,4,107,4,110,4,119,4,126,4,133,4,136,4,147,4,159,4,170,4,173,4,183,4,187,4,195,4,205,4,211,4,222,4,229,4,239,4,246,4,252,4,10,5,22,5,33,5,39,5,43,5,52,5,66,5,76,5,83,5,95,5,105,5,112,5,118,5,125,5,134,5,141,5,153,5,163,5,170,5,177,5,189,5,199,5,206,5,213,5,220,5,232,5,242,5,249,5,0,6,7,6,14,6,26,6,36,6,43,6,50,6,60,6,67,6,74,6,86,6,96,6,103,6,109,6,116,6,125,6,132,6,144,6,154,6,161,6,168,6,180,6,190,6,197,6,204,6,211,6,223,6,233,6,240,6,247,6,254,6,5,7,17,7,27,7,34,7,41,7,51,7,58,7,70,7,88,7,103,7,118,7,133,7,144,7,162,7,181,7,196,7,211,7,224,7,236,7,248,7,6,8,19,8,32,8,44,8,58,8,72,8,85,8,99,8,119,8,134,8,148,8,158,8,168,8,181,8,191,8,201,8,211,8,221,8,231,8,241,8,251,8,5,9,15,9,25,9,28,9,32,9,36,9,54,9,73,9,89,9,104,9,115,9,122,9,129,9,136,9,143,9,150,9,157,9,164,9,171,9,178,9,185,9,192,9,199,9,206,9,213,9,220,9,227,9,234,9,241,9,248,9,255,9,6,10,13,10,20,10,27,10,34,10,41,10,55,10,65,10,72,10,83,10,99,10,112,10,124,10,136,10,148,10,162,10,173,10,184,10,199,10,211,10,222,10,237,10,249,10,3,11,16,11,34,11,44,11,57,11,69,11,82,11,91,11,101,11,114,11,127,11,140,11,152,11,166,11,180,11,193,11,206,11,218,11,230,11,244,11,1,12,14,12,26,12,40,12,54,12,67,12,80,12,95,12,110,12,124,12,136,12,148,12,165,12,177,12,192,12,203,12,211,12,225,12,237,12,249,12,10,13,25,13,37,13,49,13,66,13,81,13,90,13,102,13,114,13,126,13,143,13,155,13,170,13,178,13,190,13,202,13,214,13,231,13,246,13,2,14,13,14,28,14,36,14,44,14,52,14,60,14,66,14,71,14,76,14,82,14,89,14,97,14,103,14,0,0,2,0,0,0,72,0,0,0,20,63,81,0,0,0,1,0,0,0,2,0,0,0,0,0,88,1,0,0,0,0,0,0,0,0,0,0,108,116,117,111,192,0,0,0,154,0,0,0,36,1,0,0,44,3,0,0,176,33,80,0,2,0,0,0,72,0,0,0,248,41,81,0,0,0,1,0,0,0,2,0,0,0,0,0,88,1,0,0,0,0,0,0,0,0,0,0,108,116,117,111,192,0,0,0,154,0,0,0,36,1,0,0,44,3,0,0,176,33,80,0,253,0,0,0,6,0,5,1,11,1,18,1,27,1,38,1,45,1,53,1,246,2,74,1,84,1,95,1,104,1,109,1,115,1,122,1,129,1,135,1,140,1,144,1,148,1,154,1,159,1,164,1,168,1,174,1,180,1,185,1,191,1,201,1,206,1,212,1,220,1,229,1,232,1,234,1,236,1,238,1,240,1,242,1,244,1,246,1,248,1,250,1,252,1,254,1,0,2,2,2,4,2,6,2,8,2,10,2,12,2,14,2,16,2,18,2,20,2,22,2,24,2,26,2,28,2,40,2,50,2,63,2,75,2,211,3,96,2,98,2,100,2,102,2,104,2,106,2,108,2,110,2,112,2,114,2,116,2,118,2,120,2,122,2,124,2,126,2,128,2,130,2,132,2,134,2,136,2,138,2,140,2,142,2,144,2,146,2,148,2,158,2,162,2,173,2,95,5,112,5,125,5,134,5,206,5,232,5,26,6,67,6,96,6,74,6,86,6,109,6,103,6,116,6,125,6,154,6,132,6,144,6,161,6,190,6,168,6,180,6,197,6,204,6,233,6,211,6,223,6,240,6,254,6,27,7,5,7,17,7,71,3,239,4,195,2,200,2,229,2,113,3,103,3,136,4,22,5,66,5,173,4,217,3,7,4,23,0,62,4,84,4,32,0,195,4,41,0,51,0,218,2,170,4,64,0,76,0,86,0,94,0,97,0,65,4,94,4,106,0,107,4,126,4,198,3,184,2,159,4,112,0,222,2,120,0,132,0,15,3,162,3,177,3,138,0,105,5,118,5,249,5,91,4,133,4,64,3,55,4,2,3,148,3,86,2,63,1,222,4,155,0,41,7,50,6,209,2,237,2,29,3,43,3,58,3,61,3,78,3,88,3,120,3,135,3,186,3,83,5,141,5,76,5,153,5,163,5,170,5,177,5,189,5,199,5,213,5,220,5,163,0,242,5,7,6,14,6,36,6,110,4,223,3,234,3,240,3,247,3,253,3,16,4,21,4,29,4,42,4,49,4,77,4,119,4,0,6,247,6,60,6,51,7,229,4,183,4,39,5,43,6,34,7,205,4,246,4,33,5,43,5,147,4,10,5,52,5,187,4,211,4,252,4,169,0,175,0,182,0,189,0,200,0,209,0,218,0,225,0,232,0,239,0,246,0,108,116,117,111,18,0,0,0,198,1,0,0,0,0,0,0,210,0,0,0,120,0,0,0,148,3,0,0,169,3,0,0,21,34,0,0,173,0,0,0,201,2,0,0,188,3,0,0,25,34,0,0,160,0,0,0,26,2,0,0,27,2,0,0,68,101,108,116,97,0,79,109,101,103,97,0,102,114,97,99,116,105,111,110,0,104,121,112,104,101,110,0,109,97,99,114,111,110,0,109,117,0,112,101,114,105,111,100,99,101,110,116,101,114,101,100,0,115,112,97,99,101,0,84,99,111,109,109,97,97,99,99,101,110,116,0,116,99,111,109,109,97,97,99,99,101,110,116,0,0,0,0,0,0,0,0,6,0,0,0,12,0,0,0,21,0,0,0,28,0,0,0,35,0,0,0,38,0,0,0,53,0,0,0,59,0,0,0,72,0,0,0,40,5,80,0,188,23,80,0,216,35,81,0,76,12,80,0,116,29,80,0,228,11,80,0,124,1,80,0,180,30,80,0,236,36,81,0,204,25,80,0,124,37,81,0,168,27,80,0,56,52,80,0,56,48,80,0,176,48,80,0,116,48,80,0,8,28,80,0,132,27,80,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,1,2,3,4,5,6,7,8,9,255,255,255,255,255,255,255,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,255,255,255,255,255,255,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,255,255,255,255,255,0,52,0,106,2,167,3,63,4,220,6,125,9,143,10,23,11,137,12,199,14,246,15,87,16,233,17,219,18,104,19,88,22,110,23,32,23,71,24,77,27,156,29,73,31,247,32,107,32,222,33,55,34,154,35,218,53,84,59,196,68,6,75,183,83,178,88,135,93,242,101,165,109,185,111,55,117,254,123,73,130,238,138,206,145,31,153,182,156,189,163,249,178,221,193,17,197,99,199,240,204,27,204,155,210,100,65,143,0,65,0,140,0,175,0,193,1,15,1,147,1,233,1,251,2,7,2,40,2,57,2,82,2,91,2,128,2,136,2,154,69,131,0,198,0,150,0,158,0,167,225,227,245,244,101,128,1,252,237,225,227,242,239,110,128,1,226,243,237,225,236,108,128,247,230,225,227,245,244,101,129,0,193,0,185,243,237,225,236,108,128,247,225,226,242,229,246,101,134,1,2,0,213,0,221,0,232,0,243,0,251,1,7,225,227,245,244,101,128,30,174,227,249,242,233,236,236,233,99,128,4,208,228,239,244,226,229,236,239,119,128,30,182,231,242,225,246,101,128,30,176,232,239,239,235,225,226,239,246,101,128,30,178,244,233,236,228,101,128,30,180,99,4,1,25,1,32,1,121,1,137,225,242,239,110,128,1,205,233,242,99,2,1,40,1,45,236,101,128,36,182,245,237,230,236,229,120,134,0,194,1,66,1,74,1,85,1,93,1,105,1,113,225,227,245,244,101,128,30,164,228,239,244,226,229,236,239,119,128,30,172,231,242,225,246,101,128,30,166,232,239,239,235,225,226,239,246,101,128,30,168,243,237,225,236,108,128,247,226,244,233,236,228,101,128,30,170,245,244,101,129,246,201,1,129,243,237,225,236,108,128,247,180,249,242,233,236,236,233,99,128,4,16,100,3,1,155,1,165,1,209,226,236,231,242,225,246,101,128,2,0,233,229,242,229,243,233,115,131,0,196,1,181,1,192,1,201,227,249,242,233,236,236,233,99,128,4,210,237,225,227,242,239,110,128,1,222,243,237,225,236,108,128,247,228,239,116,2,1,216,1,224,226,229,236,239,119,128,30,160,237,225,227,242,239,110,128,1,224,231,242,225,246,101,129,0,192,1,243,243,237,225,236,108,128,247,224,232,239,239,235,225,226,239,246,101,128,30,162,105,2,2,13,2,25,229,227,249,242,233,236,236,233,99,128,4,212,238,246,229,242,244,229,228,226,242,229,246,101,128,2,2,236,240,232,97,129,3,145,2,49,244,239,238,239,115,128,3,134,109,2,2,63,2,71,225,227,242,239,110,128,1,0,239,238,239,243,240,225,227,101,128,255,33,239,231,239,238,229,107,128,1,4,242,233,238,103,131,0,197,2,104,2,112,2,120,225,227,245,244,101,128,1,250,226,229,236,239,119,128,30,0,243,237,225,236,108,128,247,229,243,237,225,236,108,128,247,97,244,233,236,228,101,129,0,195,2,146,243,237,225,236,108,128,247,227,249,226,225,242,237,229,238,233,225,110,128,5,49,66,137,0,66,2,189,2,198,2,223,3,3,3,10,3,22,3,34,3,46,3,54,227,233,242,227,236,101,128,36,183,228,239,116,2,2,206,2,215,225,227,227,229,238,116,128,30,2,226,229,236,239,119,128,30,4,101,3,2,231,2,242,2,254,227,249,242,233,236,236,233,99,128,4,17,238,225,242,237,229,238,233,225,110,128,5,50,244,97,128,3,146,232,239,239,107,128,1,129,236,233,238,229,226,229,236,239,119,128,30,6,237,239,238,239,243,240,225,227,101,128,255,34,242,229,246,229,243,237,225,236,108,128,246,244,243,237,225,236,108,128,247,98,244,239,240,226,225,114,128,1,130,67,137,0,67,3,85,3,127,3,193,3,210,3,224,4,171,4,188,4,200,4,212,97,3,3,93,3,104,3,111,225,242,237,229,238,233,225,110,128,5,62,227,245,244,101,128,1,6,242,239,110,129,246,202,3,119,243,237,225,236,108,128,246,245,99,3,3,135,3,142,3,171,225,242,239,110,128,1,12,229,228,233,236,236,97,130,0,199,3,155,3,163,225,227,245,244,101,128,30,8,243,237,225,236,108,128,247,231,233,242,99,2,3,179,3,184,236,101,128,36,184,245,237,230,236,229,120,128,1,8,228,239,116,129,1,10,3,201,225,227,227,229,238,116,128,1,10,229,228,233,236,236,225,243,237,225,236,108,128,247,184,104,4,3,234,3,246,4,161,4,165,225,225,242,237,229,238,233,225,110,128,5,73,101,6,4,4,4,24,4,35,4,103,4,115,4,136,225,226,235,232,225,243,233,225,238,227,249,242,233,236,236,233,99,128,4,188,227,249,242,233,236,236,233,99,128,4,39,100,2,4,41,4,85,229,243,227,229,238,228,229,114,2,4,54,4,74,225,226,235,232,225,243,233,225,238,227,249,242,233,236,236,233,99,128,4,190,227,249,242,233,236,236,233,99,128,4,182,233,229,242,229,243,233,243,227,249,242,233,236,236,233,99,128,4,244,232,225,242,237,229,238,233,225,110,128,5,67,235,232,225,235,225,243,243,233,225,238,227,249,242,233,236,236,233,99,128,4,203,246,229,242,244,233,227,225,236,243,244,242,239,235,229,227,249,242,233,236,236,233,99,128,4,184,105,128,3,167,239,239,107,128,1,135,233,242,227,245,237,230,236,229,248,243,237,225,236,108,128,246,246,237,239,238,239,243,240,225,227,101,128,255,35,239,225,242,237,229,238,233,225,110,128,5,81,243,237,225,236,108,128,247,99,68,142,0,68,4,252,5,10,5,36,5,96,5,121,5,166,5,173,5,231,5,244,6,0,6,12,6,28,6,48,6,57,90,129,1,241,5,2,227,225,242,239,110,128,1,196,97,2,5,16,5,27,225,242,237,229,238,233,225,110,128,5,52,230,242,233,227,225,110,128,1,137,99,4,5,46,5,53,5,62,5,89,225,242,239,110,128,1,14,229,228,233,236,236,97,128,30,16,233,242,99,2,5,70,5,75,236,101,128,36,185,245,237,230,236,229,248,226,229,236,239,119,128,30,18,242,239,225,116,128,1,16,228,239,116,2,5,104,5,113,225,227,227,229,238,116,128,30,10,226,229,236,239,119,128,30,12,101,3,5,129,5,140,5,150,227,249,242,233,236,236,233,99,128,4,20,233,227,239,240,244,233,99,128,3,238,236,244,97,129,34,6,5,158,231,242,229,229,107,128,3,148,232,239,239,107,128,1,138,105,2,5,179,5,218,229,242,229,243,233,115,131,246,203,5,194,5,202,5,210,193,227,245,244,101,128,246,204,199,242,225,246,101,128,246,205,243,237,225,236,108,128,247,168,231,225,237,237,225,231,242,229,229,107,128,3,220,234,229,227,249,242,233,236,236,233,99,128,4,2,236,233,238,229,226,229,236,239,119,128,30,14,237,239,238,239,243,240,225,227,101,128,255,36,239,244,225,227,227,229,238,244,243,237,225,236,108,128,246,247,115,2,6,34,6,41,236,225,243,104,128,1,16,237,225,236,108,128,247,100,244,239,240,226,225,114,128,1,139,122,131,1,242,6,67,6,75,6,112,227,225,242,239,110,128,1,197,101,2,6,81,6,101,225,226,235,232,225,243,233,225,238,227,249,242,233,236,236,233,99,128,4,224,227,249,242,233,236,236,233,99,128,4,5,232,229,227,249,242,233,236,236,233,99,128,4,15,69,146,0,69,6,165,6,183,6,191,7,89,7,153,7,165,7,183,7,211,8,7,8,36,8,94,8,169,8,189,8,208,8,248,9,44,9,109,9,115,225,227,245,244,101,129,0,201,6,175,243,237,225,236,108,128,247,233,226,242,229,246,101,128,1,20,99,5,6,203,6,210,6,224,6,236,7,79,225,242,239,110,128,1,26,229,228,233,236,236,225,226,242,229,246,101,128,30,28,232,225,242,237,229,238,233,225,110,128,5,53,233,242,99,2,6,244,6,249,236,101,128,36,186,245,237,230,236,229,120,135,0,202,7,16,7,24,7,32,7,43,7,51,7,63,7,71,225,227,245,244,101,128,30,190,226,229,236,239,119,128,30,24,228,239,244,226,229,236,239,119,128,30,198,231,242,225,246,101,128,30,192,232,239,239,235,225,226,239,246,101,128,30,194,243,237,225,236,108,128,247,234,244,233,236,228,101,128,30,196,249,242,233,236,236,233,99,128,4,4,100,3,7,97,7,107,7,127,226,236,231,242,225,246,101,128,2,4,233,229,242,229,243,233,115,129,0,203,7,119,243,237,225,236,108,128,247,235,239,116,130,1,22,7,136,7,145,225,227,227,229,238,116,128,1,22,226,229,236,239,119,128,30,184,230,227,249,242,233,236,236,233,99,128,4,36,231,242,225,246,101,129,0,200,7,175,243,237,225,236,108,128,247,232,104,2,7,189,7,200,225,242,237,229,238,233,225,110,128,5,55,239,239,235,225,226,239,246,101,128,30,186,105,3,7,219,7,230,7,245,231,232,244,242,239,237,225,110,128,33,103,238,246,229,242,244,229,228,226,242,229,246,101,128,2,6,239,244,233,230,233,229,228,227,249,242,233,236,236,233,99,128,4,100,108,2,8,13,8,24,227,249,242,233,236,236,233,99,128,4,27,229,246,229,238,242,239,237,225,110,128,33,106,109,3,8,44,8,72,8,83,225,227,242,239,110,130,1,18,8,56,8,64,225,227,245,244,101,128,30,22,231,242,225,246,101,128,30,20,227,249,242,233,236,236,233,99,128,4,28,239,238,239,243,240,225,227,101,128,255,37,110,4,8,104,8,115,8,135,8,154,227,249,242,233,236,236,233,99,128,4,29,228,229,243,227,229,238,228,229,242,227,249,242,233,236,236,233,99,128,4,162,103,129,1,74,8,141,232,229,227,249,242,233,236,236,233,99,128,4,164,232,239,239,235,227,249,242,233,236,236,233,99,128,4,199,111,2,8,175,8,183,231,239,238,229,107,128,1,24,240,229,110,128,1,144,240,243,233,236,239,110,129,3,149,8,200,244,239,238,239,115,128,3,136,114,2,8,214,8,225,227,249,242,233,236,236,233,99,128,4,32,229,246,229,242,243,229,100,129,1,142,8,237,227,249,242,233,236,236,233,99,128,4,45,115,4,9,2,9,13,9,33,9,37,227,249,242,233,236,236,233,99,128,4,33,228,229,243,227,229,238,228,229,242,227,249,242,233,236,236,233,99,128,4,170,104,128,1,169,237,225,236,108,128,247,101,116,3,9,52,9,78,9,92,97,130,3,151,9,60,9,70,242,237,229,238,233,225,110,128,5,56,244,239,238,239,115,128,3,137,104,129,0,208,9,84,243,237,225,236,108,128,247,240,233,236,228,101,129,30,188,9,101,226,229,236,239,119,128,30,26,245,242,111,128,32,172,250,104,130,1,183,9,124,9,132,227,225,242,239,110,128,1,238,242,229,246,229,242,243,229,100,128,1,184,70,136,0,70,9,163,9,172,9,184,9,212,9,219,9,248,10,4,10,15,227,233,242,227,236,101,128,36,187,228,239,244,225,227,227,229,238,116,128,30,30,101,2,9,190,9,202,232,225,242,237,229,238,233,225,110,128,5,86,233,227,239,240,244,233,99,128,3,228,232,239,239,107,128,1,145,105,2,9,225,9,238,244,225,227,249,242,233,236,236,233,99,128,4,114,246,229,242,239,237,225,110,128,33,100,237,239,238,239,243,240,225,227,101,128,255,38,239,245,242,242,239,237,225,110,128,33,99,243,237,225,236,108,128,247,102,71,140,0,71,10,51,10,61,10,107,10,115,10,176,10,193,10,205,11,39,11,52,11,65,11,90,11,107,194,243,241,245,225,242,101,128,51,135,97,3,10,69,10,76,10,94,227,245,244,101,128,1,244,237,237,97,129,3,147,10,84,225,230,242,233,227,225,110,128,1,148,238,231,233,225,227,239,240,244,233,99,128,3,234,226,242,229,246,101,128,1,30,99,4,10,125,10,132,10,141,10,163,225,242,239,110,128,1,230,229,228,233,236,236,97,128,1,34,233,242,99,2,10,149,10,154,236,101,128,36,188,245,237,230,236,229,120,128,1,28,239,237,237,225,225,227,227,229,238,116,128,1,34,228,239,116,129,1,32,10,184,225,227,227,229,238,116,128,1,32,229,227,249,242,233,236,236,233,99,128,4,19,104,3,10,213,10,226,11,33,225,228,225,242,237,229,238,233,225,110,128,5,66,101,3,10,234,10,255,11,16,237,233,228,228,236,229,232,239,239,235,227,249,242,233,236,236,233,99,128,4,148,243,244,242,239,235,229,227,249,242,233,236,236,233,99,128,4,146,245,240,244,245,242,238,227,249,242,233,236,236,233,99,128,4,144,239,239,107,128,1,147,233,237,225,242,237,229,238,233,225,110,128,5,51,234,229,227,249,242,233,236,236,233,99,128,4,3,109,2,11,71,11,79,225,227,242,239,110,128,30,32,239,238,239,243,240,225,227,101,128,255,39,242,225,246,101,129,246,206,11,99,243,237,225,236,108,128,247,96,115,2,11,113,11,129,237,225,236,108,129,247,103,11,122,232,239,239,107,128,2,155,244,242,239,235,101,128,1,228,72,140,0,72,11,165,11,190,11,198,11,208,12,17,12,40,12,77,12,117,12,129,12,157,12,165,12,189,177,184,53,3,11,175,11,180,11,185,179,51,128,37,207,180,51,128,37,170,181,49,128,37,171,178,178,176,183,51,128,37,161,208,243,241,245,225,242,101,128,51,203,97,3,11,216,11,236,12,0,225,226,235,232,225,243,233,225,238,227,249,242,233,236,236,233,99,128,4,168,228,229,243,227,229,238,228,229,242,227,249,242,233,236,236,233,99,128,4,178,242,228,243,233,231,238,227,249,242,233,236,236,233,99,128,4,42,98,2,12,23,12,28,225,114,128,1,38,242,229,246,229,226,229,236,239,119,128,30,42,99,2,12,46,12,55,229,228,233,236,236,97,128,30,40,233,242,99,2,12,63,12,68,236,101,128,36,189,245,237,230,236,229,120,128,1,36,100,2,12,83,12,93,233,229,242,229,243,233,115,128,30,38,239,116,2,12,100,12,109,225,227,227,229,238,116,128,30,34,226,229,236,239,119,128,30,36,237,239,238,239,243,240,225,227,101,128,255,40,111,2,12,135,12,146,225,242,237,229,238,233,225,110,128,5,64,242,233,227,239,240,244,233,99,128,3,232,243,237,225,236,108,128,247,104,245,238,231,225,242,245,237,236,225,245,116,129,246,207,12,181,243,237,225,236,108,128,246,248,250,243,241,245,225,242,101,128,51,144,73,146,0,73,12,239,12,251,12,255,13,11,13,29,13,37,13,94,13,181,13,214,13,224,13,242,13,254,14,48,14,86,14,99,14,166,14,187,14,205,193,227,249,242,233,236,236,233,99,128,4,47,74,128,1,50,213,227,249,242,233,236,236,233,99,128,4,46,225,227,245,244,101,129,0,205,13,21,243,237,225,236,108,128,247,237,226,242,229,246,101,128,1,44,99,3,13,45,13,52,13,84,225,242,239,110,128,1,207,233,242,99,2,13,60,13,65,236,101,128,36,190,245,237,230,236,229,120,129,0,206,13,76,243,237,225,236,108,128,247,238,249,242,233,236,236,233,99,128,4,6,100,3,13,102,13,112,13,155,226,236,231,242,225,246,101,128,2,8,233,229,242,229,243,233,115,131,0,207,13,128,13,136,13,147,225,227,245,244,101,128,30,46,227,249,242,233,236,236,233,99,128,4,228,243,237,225,236,108,128,247,239,239,116,130,1,48,13,164,13,173,225,227,227,229,238,116,128,1,48,226,229,236,239,119,128,30,202,101,2,13,187,13,203,226,242,229,246,229,227,249,242,233,236,236,233,99,128,4,214,227,249,242,233,236,236,233,99,128,4,21,230,242,225,235,244,245,114,128,33,17,231,242,225,246,101,129,0,204,13,234,243,237,225,236,108,128,247,236,232,239,239,235,225,226,239,246,101,128,30,200,105,3,14,6,14,17,14,32,227,249,242,233,236,236,233,99,128,4,24,238,246,229,242,244,229,228,226,242,229,246,101,128,2,10,243,232,239,242,244,227,249,242,233,236,236,233,99,128,4,25,109,2,14,54,14,75,225,227,242,239,110,129,1,42,14,64,227,249,242,233,236,236,233,99,128,4,226,239,238,239,243,240,225,227,101,128,255,41,238,233,225,242,237,229,238,233,225,110,128,5,59,111,3,14,107,14,118,14,126,227,249,242,233,236,236,233,99,128,4,1,231,239,238,229,107,128,1,46,244,97,131,3,153,14,137,14,147,14,158,225,230,242,233,227,225,110,128,1,150,228,233,229,242,229,243,233,115,128,3,170,244,239,238,239,115,128,3,138,115,2,14,172,14,179,237,225,236,108,128,247,105,244,242,239,235,101,128,1,151,244,233,236,228,101,129,1,40,14,197,226,229,236,239,119,128,30,44,250,232,233,244,243,97,2,14,216,14,227,227,249,242,233,236,236,233,99,128,4,116,228,226,236,231,242,225,246,229,227,249,242,233,236,236,233,99,128,4,118,74,134,0,74,15,6,15,18,15,41,15,53,15,67,15,79,225,225,242,237,229,238,233,225,110,128,5,65,227,233,242,99,2,15,27,15,32,236,101,128,36,191,245,237,230,236,229,120,128,1,52,229,227,249,242,233,236,236,233,99,128,4,8,232,229,232,225,242,237,229,238,233,225,110,128,5,75,237,239,238,239,243,240,225,227,101,128,255,42,243,237,225,236,108,128,247,106,75,140,0,75,15,115,15,125,15,135,16,18,16,65,16,76,16,106,16,143,16,156,16,168,16,180,16,208,194,243,241,245,225,242,101,128,51,133,203,243,241,245,225,242,101,128,51,205,97,7,15,151,15,169,15,191,15,211,15,226,15,232,15,249,226,225,243,232,235,233,242,227,249,242,233,236,236,233,99,128,4,160,99,2,15,175,15,181,245,244,101,128,30,48,249,242,233,236,236,233,99,128,4,26,228,229,243,227,229,238,228,229,242,227,249,242,233,236,236,233,99,128,4,154,232,239,239,235,227,249,242,233,236,236,233,99,128,4,195,240,240,97,128,3,154,243,244,242,239,235,229,227,249,242,233,236,236,233,99,128,4,158,246,229,242,244,233,227,225,236,243,244,242,239,235,229,227,249,242,233,236,236,233,99,128,4,156,99,4,16,28,16,35,16,44,16,52,225,242,239,110,128,1,232,229,228,233,236,236,97,128,1,54,233,242,227,236,101,128,36,192,239,237,237,225,225,227,227,229,238,116,128,1,54,228,239,244,226,229,236,239,119,128,30,50,101,2,16,82,16,94,232,225,242,237,229,238,233,225,110,128,5,84,238,225,242,237,229,238,233,225,110,128,5,63,104,3,16,114,16,126,16,137,225,227,249,242,233,236,236,233,99,128,4,37,229,233,227,239,240,244,233,99,128,3,230,239,239,107,128,1,152,234,229,227,249,242,233,236,236,233,99,128,4,12,236,233,238,229,226,229,236,239,119,128,30,52,237,239,238,239,243,240,225,227,101,128,255,43,239,240,240,97,2,16,189,16,200,227,249,242,233,236,236,233,99,128,4,128,231,242,229,229,107,128,3,222,115,2,16,214,16,226,233,227,249,242,233,236,236,233,99,128,4,110,237,225,236,108,128,247,107,76,138,0,76,17,1,17,5,17,9,17,29,17,95,17,133,17,147,17,165,17,177,17,189,74,128,1,199,76,128,246,191,97,2,17,15,17,22,227,245,244,101,128,1,57,237,226,228,97,128,3,155,99,4,17,39,17,46,17,55,17,82,225,242,239,110,128,1,61,229,228,233,236,236,97,128,1,59,233,242,99,2,17,63,17,68,236,101,128,36,193,245,237,230,236,229,248,226,229,236,239,119,128,30,60,239,237,237,225,225,227,227,229,238,116,128,1,59,228,239,116,130,1,63,17,105,17,114,225,227,227,229,238,116,128,1,63,226,229,236,239,119,129,30,54,17,124,237,225,227,242,239,110,128,30,56,233,247,238,225,242,237,229,238,233,225,110,128,5,60,106,129,1,200,17,153,229,227,249,242,233,236,236,233,99,128,4,9,236,233,238,229,226,229,236,239,119,128,30,58,237,239,238,239,243,240,225,227,101,128,255,44,115,2,17,195,17,212,236,225,243,104,129,1,65,17,204,243,237,225,236,108,128,246,249,237,225,236,108,128,247,108,77,137,0,77,17,241,17,251,18,24,18,33,18,58,18,71,18,83,18,91,18,100,194,243,241,245,225,242,101,128,51,134,225,99,2,18,2,18,18,242,239,110,129,246,208,18,10,243,237,225,236,108,128,247,175,245,244,101,128,30,62,227,233,242,227,236,101,128,36,194,228,239,116,2,18,41,18,50,225,227,227,229,238,116,128,30,64,226,229,236,239,119,128,30,66,229,238,225,242,237,229,238,233,225,110,128,5,68,237,239,238,239,243,240,225,227,101,128,255,45,243,237,225,236,108,128,247,109,244,245,242,238,229,100,128,1,156,117,128,3,156,78,141,0,78,18,134,18,138,18,146,18,212,18,237,18,248,19,3,19,21,19,33,19,45,19,58,19,66,19,84,74,128,1,202,225,227,245,244,101,128,1,67,99,4,18,156,18,163,18,172,18,199,225,242,239,110,128,1,71,229,228,233,236,236,97,128,1,69,233,242,99,2,18,180,18,185,236,101,128,36,195,245,237,230,236,229,248,226,229,236,239,119,128,30,74,239,237,237,225,225,227,227,229,238,116,128,1,69,228,239,116,2,18,220,18,229,225,227,227,229,238,116,128,30,68,226,229,236,239,119,128,30,70,232,239,239,235,236,229,230,116,128,1,157,233,238,229,242,239,237,225,110,128,33,104,106,129,1,203,19,9,229,227,249,242,233,236,236,233,99,128,4,10,236,233,238,229,226,229,236,239,119,128,30,72,237,239,238,239,243,240,225,227,101,128,255,46,239,247,225,242,237,229,238,233,225,110,128,5,70,243,237,225,236,108,128,247,110,244,233,236,228,101,129,0,209,19,76,243,237,225,236,108,128,247,241,117,128,3,157,79,141,0,79,19,118,19,132,19,150,19,203,20,78,20,152,20,187,21,48,21,69,21,213,21,223,21,254,22,53,69,129,1,82,19,124,243,237,225,236,108,128,246,250,225,227,245,244,101,129,0,211,19,142,243,237,225,236,108,128,247,243,98,2,19,156,19,196,225,242,242,229,100,2,19,166,19,177,227,249,242,233,236,236,233,99,128,4,232,228,233,229,242,229,243,233,243,227,249,242,233,236,236,233,99,128,4,234,242,229,246,101,128,1,78,99,4,19,213,19,220,19,235,20,68,225,242,239,110,128,1,209,229,238,244,229,242,229,228,244,233,236,228,101,128,1,159,233,242,99,2,19,243,19,248,236,101,128,36,196,245,237,230,236,229,120,134,0,212,20,13,20,21,20,32,20,40,20,52,20,60,225,227,245,244,101,128,30,208,228,239,244,226,229,236,239,119,128,30,216,231,242,225,246,101,128,30,210,232,239,239,235,225,226,239,246,101,128,30,212,243,237,225,236,108,128,247,244,244,233,236,228,101,128,30,214,249,242,233,236,236,233,99,128,4,30,100,3,20,86,20,109,20,142,226,108,2,20,93,20,101,225,227,245,244,101,128,1,80,231,242,225,246,101,128,2,12,233,229,242,229,243,233,115,130,0,214,20,123,20,134,227,249,242,233,236,236,233,99,128,4,230,243,237,225,236,108,128,247,246,239,244,226,229,236,239,119,128,30,204,103,2,20,158,20,170,239,238,229,235,243,237,225,236,108,128,246,251,242,225,246,101,129,0,210,20,179,243,237,225,236,108,128,247,242,104,4,20,197,20,208,20,212,21,34,225,242,237,229,238,233,225,110,128,5,85,109,128,33,38,111,2,20,218,20,228,239,235,225,226,239,246,101,128,30,206,242,110,133,1,160,20,243,20,251,21,6,21,14,21,26,225,227,245,244,101,128,30,218,228,239,244,226,229,236,239,119,128,30,226,231,242,225,246,101,128,30,220,232,239,239,235,225,226,239,246,101,128,30,222,244,233,236,228,101,128,30,224,245,238,231,225,242,245,237,236,225,245,116,128,1,80,105,129,1,162,21,54,238,246,229,242,244,229,228,226,242,229,246,101,128,2,14,109,4,21,79,21,107,21,184,21,202,225,227,242,239,110,130,1,76,21,91,21,99,225,227,245,244,101,128,30,82,231,242,225,246,101,128,30,80,229,231,97,132,33,38,21,121,21,132,21,140,21,156,227,249,242,233,236,236,233,99,128,4,96,231,242,229,229,107,128,3,169,242,239,245,238,228,227,249,242,233,236,236,233,99,128,4,122,116,2,21,162,21,177,233,244,236,239,227,249,242,233,236,236,233,99,128,4,124,239,238,239,115,128,3,143,233,227,242,239,110,129,3,159,21,194,244,239,238,239,115,128,3,140,239,238,239,243,240,225,227,101,128,255,47,238,229,242,239,237,225,110,128,33,96,111,2,21,229,21,248,231,239,238,229,107,129,1,234,21,239,237,225,227,242,239,110,128,1,236,240,229,110,128,1,134,115,3,22,6,22,33,22,40,236,225,243,104,130,0,216,22,17,22,25,225,227,245,244,101,128,1,254,243,237,225,236,108,128,247,248,237,225,236,108,128,247,111,244,242,239,235,229,225,227,245,244,101,128,1,254,116,2,22,59,22,70,227,249,242,233,236,236,233,99,128,4,126,233,236,228,101,131,0,213,22,83,22,91,22,102,225,227,245,244,101,128,30,76,228,233,229,242,229,243,233,115,128,30,78,243,237,225,236,108,128,247,245,80,136,0,80,22,130,22,138,22,147,22,159,22,211,22,227,22,246,23,2,225,227,245,244,101,128,30,84,227,233,242,227,236,101,128,36,197,228,239,244,225,227,227,229,238,116,128,30,86,101,3,22,167,22,178,22,190,227,249,242,233,236,236,233,99,128,4,31,232,225,242,237,229,238,233,225,110,128,5,74,237,233,228,228,236,229,232,239,239,235,227,249,242,233,236,236,233,99,128,4,166,104,2,22,217,22,221,105,128,3,166,239,239,107,128,1,164,105,129,3,160,22,233,247,242,225,242,237,229,238,233,225,110,128,5,83,237,239,238,239,243,240,225,227,101,128,255,48,115,2,23,8,23,25,105,129,3,168,23,14,227,249,242,233,236,236,233,99,128,4,112,237,225,236,108,128,247,112,81,131,0,81,23,42,23,51,23,63,227,233,242,227,236,101,128,36,198,237,239,238,239,243,240,225,227,101,128,255,49,243,237,225,236,108,128,247,113,82,138,0,82,23,95,23,119,23,166,23,217,23,230,23,240,23,245,24,19,24,31,24,43,97,2,23,101,23,112,225,242,237,229,238,233,225,110,128,5,76,227,245,244,101,128,1,84,99,4,23,129,23,136,23,145,23,153,225,242,239,110,128,1,88,229,228,233,236,236,97,128,1,86,233,242,227,236,101,128,36,199,239,237,237,225,225,227,227,229,238,116,128,1,86,100,2,23,172,23,182,226,236,231,242,225,246,101,128,2,16,239,116,2,23,189,23,198,225,227,227,229,238,116,128,30,88,226,229,236,239,119,129,30,90,23,208,237,225,227,242,239,110,128,30,92,229,232,225,242,237,229,238,233,225,110,128,5,80,230,242,225,235,244,245,114,128,33,28,232,111,128,3,161,233,110,2,23,252,24,5])
.concat([231,243,237,225,236,108,128,246,252,246,229,242,244,229,228,226,242,229,246,101,128,2,18,236,233,238,229,226,229,236,239,119,128,30,94,237,239,238,239,243,240,225,227,101,128,255,50,243,237,225,236,108,129,247,114,24,53,233,238,246,229,242,244,229,100,129,2,129,24,66,243,245,240,229,242,233,239,114,128,2,182,83,139,0,83,24,103,26,17,26,55,26,182,26,221,26,250,27,84,27,105,27,117,27,135,27,143,70,6,24,117,24,209,24,241,25,77,25,119,25,221,48,9,24,137,24,145,24,153,24,161,24,169,24,177,24,185,24,193,24,201,177,176,176,176,48,128,37,12,178,176,176,176,48,128,37,20,179,176,176,176,48,128,37,16,180,176,176,176,48,128,37,24,181,176,176,176,48,128,37,60,182,176,176,176,48,128,37,44,183,176,176,176,48,128,37,52,184,176,176,176,48,128,37,28,185,176,176,176,48,128,37,36,49,3,24,217,24,225,24,233,176,176,176,176,48,128,37,0,177,176,176,176,48,128,37,2,185,176,176,176,48,128,37,97,50,9,25,5,25,13,25,21,25,29,25,37,25,45,25,53,25,61,25,69,176,176,176,176,48,128,37,98,177,176,176,176,48,128,37,86,178,176,176,176,48,128,37,85,179,176,176,176,48,128,37,99,180,176,176,176,48,128,37,81,181,176,176,176,48,128,37,87,182,176,176,176,48,128,37,93,183,176,176,176,48,128,37,92,184,176,176,176,48,128,37,91,51,4,25,87,25,95,25,103,25,111,182,176,176,176,48,128,37,94,183,176,176,176,48,128,37,95,184,176,176,176,48,128,37,90,185,176,176,176,48,128,37,84,52,10,25,141,25,149,25,157,25,165,25,173,25,181,25,189,25,197,25,205,25,213,176,176,176,176,48,128,37,105,177,176,176,176,48,128,37,102,178,176,176,176,48,128,37,96,179,176,176,176,48,128,37,80,180,176,176,176,48,128,37,108,181,176,176,176,48,128,37,103,182,176,176,176,48,128,37,104,183,176,176,176,48,128,37,100,184,176,176,176,48,128,37,101,185,176,176,176,48,128,37,89,53,5,25,233,25,241,25,249,26,1,26,9,176,176,176,176,48,128,37,88,177,176,176,176,48,128,37,82,178,176,176,176,48,128,37,83,179,176,176,176,48,128,37,107,180,176,176,176,48,128,37,106,97,2,26,23,26,44,227,245,244,101,129,1,90,26,32,228,239,244,225,227,227,229,238,116,128,30,100,237,240,233,231,242,229,229,107,128,3,224,99,5,26,67,26,98,26,107,26,147,26,169,225,242,239,110,130,1,96,26,78,26,90,228,239,244,225,227,227,229,238,116,128,30,102,243,237,225,236,108,128,246,253,229,228,233,236,236,97,128,1,94,232,247,97,130,1,143,26,117,26,128,227,249,242,233,236,236,233,99,128,4,216,228,233,229,242,229,243,233,243,227,249,242,233,236,236,233,99,128,4,218,233,242,99,2,26,155,26,160,236,101,128,36,200,245,237,230,236,229,120,128,1,92,239,237,237,225,225,227,227,229,238,116,128,2,24,228,239,116,2,26,190,26,199,225,227,227,229,238,116,128,30,96,226,229,236,239,119,129,30,98,26,209,228,239,244,225,227,227,229,238,116,128,30,104,101,2,26,227,26,239,232,225,242,237,229,238,233,225,110,128,5,77,246,229,238,242,239,237,225,110,128,33,102,104,5,27,6,27,34,27,48,27,59,27,72,97,2,27,12,27,23,225,242,237,229,238,233,225,110,128,5,71,227,249,242,233,236,236,233,99,128,4,40,227,232,225,227,249,242,233,236,236,233,99,128,4,41,229,233,227,239,240,244,233,99,128,3,226,232,225,227,249,242,233,236,236,233,99,128,4,186,233,237,225,227,239,240,244,233,99,128,3,236,105,2,27,90,27,96,231,237,97,128,3,163,248,242,239,237,225,110,128,33,101,237,239,238,239,243,240,225,227,101,128,255,51,239,230,244,243,233,231,238,227,249,242,233,236,236,233,99,128,4,44,243,237,225,236,108,128,247,115,244,233,231,237,225,231,242,229,229,107,128,3,218,84,141,0,84,27,186,27,191,27,197,28,7,28,32,28,96,28,147,28,177,28,189,28,201,28,246,29,6,29,46,225,117,128,3,164,226,225,114,128,1,102,99,4,27,207,27,214,27,223,27,250,225,242,239,110,128,1,100,229,228,233,236,236,97,128,1,98,233,242,99,2,27,231,27,236,236,101,128,36,201,245,237,230,236,229,248,226,229,236,239,119,128,30,112,239,237,237,225,225,227,227,229,238,116,128,1,98,228,239,116,2,28,15,28,24,225,227,227,229,238,116,128,30,106,226,229,236,239,119,128,30,108,101,4,28,42,28,53,28,73,28,82,227,249,242,233,236,236,233,99,128,4,34,228,229,243,227,229,238,228,229,242,227,249,242,233,236,236,233,99,128,4,172,238,242,239,237,225,110,128,33,105,244,243,229,227,249,242,233,236,236,233,99,128,4,180,104,3,28,104,28,110,28,136,229,244,97,128,3,152,111,2,28,116,28,121,239,107,128,1,172,242,110,129,0,222,28,128,243,237,225,236,108,128,247,254,242,229,229,242,239,237,225,110,128,33,98,105,2,28,153,28,164,236,228,229,243,237,225,236,108,128,246,254,247,238,225,242,237,229,238,233,225,110,128,5,79,236,233,238,229,226,229,236,239,119,128,30,110,237,239,238,239,243,240,225,227,101,128,255,52,111,2,28,207,28,218,225,242,237,229,238,233,225,110,128,5,57,238,101,3,28,227,28,234,28,240,230,233,246,101,128,1,188,243,233,120,128,1,132,244,247,111,128,1,167,242,229,244,242,239,230,236,229,248,232,239,239,107,128,1,174,115,3,29,14,29,26,29,39,229,227,249,242,233,236,236,233,99,128,4,38,232,229,227,249,242,233,236,236,233,99,128,4,11,237,225,236,108,128,247,116,119,2,29,52,29,64,229,236,246,229,242,239,237,225,110,128,33,107,239,242,239,237,225,110,128,33,97,85,142,0,85,29,105,29,123,29,131,29,198,30,69,30,87,30,198,30,214,30,226,31,21,31,30,31,142,31,149,31,219,225,227,245,244,101,129,0,218,29,115,243,237,225,236,108,128,247,250,226,242,229,246,101,128,1,108,99,3,29,139,29,146,29,188,225,242,239,110,128,1,211,233,242,99,2,29,154,29,159,236,101,128,36,202,245,237,230,236,229,120,130,0,219,29,172,29,180,226,229,236,239,119,128,30,118,243,237,225,236,108,128,247,251,249,242,233,236,236,233,99,128,4,35,100,3,29,206,29,229,30,59,226,108,2,29,213,29,221,225,227,245,244,101,128,1,112,231,242,225,246,101,128,2,20,233,229,242,229,243,233,115,134,0,220,29,251,30,3,30,11,30,34,30,42,30,51,225,227,245,244,101,128,1,215,226,229,236,239,119,128,30,114,99,2,30,17,30,24,225,242,239,110,128,1,217,249,242,233,236,236,233,99,128,4,240,231,242,225,246,101,128,1,219,237,225,227,242,239,110,128,1,213,243,237,225,236,108,128,247,252,239,244,226,229,236,239,119,128,30,228,231,242,225,246,101,129,0,217,30,79,243,237,225,236,108,128,247,249,104,2,30,93,30,171,111,2,30,99,30,109,239,235,225,226,239,246,101,128,30,230,242,110,133,1,175,30,124,30,132,30,143,30,151,30,163,225,227,245,244,101,128,30,232,228,239,244,226,229,236,239,119,128,30,240,231,242,225,246,101,128,30,234,232,239,239,235,225,226,239,246,101,128,30,236,244,233,236,228,101,128,30,238,245,238,231,225,242,245,237,236,225,245,116,129,1,112,30,187,227,249,242,233,236,236,233,99,128,4,242,233,238,246,229,242,244,229,228,226,242,229,246,101,128,2,22,235,227,249,242,233,236,236,233,99,128,4,120,109,2,30,232,31,10,225,227,242,239,110,130,1,106,30,244,30,255,227,249,242,233,236,236,233,99,128,4,238,228,233,229,242,229,243,233,115,128,30,122,239,238,239,243,240,225,227,101,128,255,53,239,231,239,238,229,107,128,1,114,240,243,233,236,239,110,133,3,165,31,49,31,53,31,90,31,121,31,134,49,128,3,210,97,2,31,59,31,81,227,245,244,229,232,239,239,235,243,249,237,226,239,236,231,242,229,229,107,128,3,211,230,242,233,227,225,110,128,1,177,228,233,229,242,229,243,233,115,129,3,171,31,103,232,239,239,235,243,249,237,226,239,236,231,242,229,229,107,128,3,212,232,239,239,235,243,249,237,226,239,108,128,3,210,244,239,238,239,115,128,3,142,242,233,238,103,128,1,110,115,3,31,157,31,172,31,179,232,239,242,244,227,249,242,233,236,236,233,99,128,4,14,237,225,236,108,128,247,117,244,242,225,233,231,232,116,2,31,191,31,202,227,249,242,233,236,236,233,99,128,4,174,243,244,242,239,235,229,227,249,242,233,236,236,233,99,128,4,176,244,233,236,228,101,130,1,104,31,231,31,239,225,227,245,244,101,128,30,120,226,229,236,239,119,128,30,116,86,136,0,86,32,11,32,20,32,31,32,60,32,67,32,79,32,91,32,99,227,233,242,227,236,101,128,36,203,228,239,244,226,229,236,239,119,128,30,126,101,2,32,37,32,48,227,249,242,233,236,236,233,99,128,4,18,247,225,242,237,229,238,233,225,110,128,5,78,232,239,239,107,128,1,178,237,239,238,239,243,240,225,227,101,128,255,54,239,225,242,237,229,238,233,225,110,128,5,72,243,237,225,236,108,128,247,118,244,233,236,228,101,128,30,124,87,134,0,87,32,123,32,131,32,154,32,194,32,202,32,214,225,227,245,244,101,128,30,130,227,233,242,99,2,32,140,32,145,236,101,128,36,204,245,237,230,236,229,120,128,1,116,100,2,32,160,32,170,233,229,242,229,243,233,115,128,30,132,239,116,2,32,177,32,186,225,227,227,229,238,116,128,30,134,226,229,236,239,119,128,30,136,231,242,225,246,101,128,30,128,237,239,238,239,243,240,225,227,101,128,255,55,243,237,225,236,108,128,247,119,88,134,0,88,32,238,32,247,33,18,33,31,33,35,33,47,227,233,242,227,236,101,128,36,205,100,2,32,253,33,7,233,229,242,229,243,233,115,128,30,140,239,244,225,227,227,229,238,116,128,30,138,229,232,225,242,237,229,238,233,225,110,128,5,61,105,128,3,158,237,239,238,239,243,240,225,227,101,128,255,56,243,237,225,236,108,128,247,120,89,139,0,89,33,81,33,116,33,139,33,189,33,228,33,236,33,253,34,40,34,52,34,60,34,68,97,2,33,87,33,104,227,245,244,101,129,0,221,33,96,243,237,225,236,108,128,247,253,244,227,249,242,233,236,236,233,99,128,4,98,227,233,242,99,2,33,125,33,130,236,101,128,36,206,245,237,230,236,229,120,128,1,118,100,2,33,145,33,165,233,229,242,229,243,233,115,129,1,120,33,157,243,237,225,236,108,128,247,255,239,116,2,33,172,33,181,225,227,227,229,238,116,128,30,142,226,229,236,239,119,128,30,244,229,114,2,33,196,33,208,233,227,249,242,233,236,236,233,99,128,4,43,245,228,233,229,242,229,243,233,243,227,249,242,233,236,236,233,99,128,4,248,231,242,225,246,101,128,30,242,232,239,239,107,129,1,179,33,245,225,226,239,246,101,128,30,246,105,3,34,5,34,16,34,27,225,242,237,229,238,233,225,110,128,5,69,227,249,242,233,236,236,233,99,128,4,7,247,238,225,242,237,229,238,233,225,110,128,5,82,237,239,238,239,243,240,225,227,101,128,255,57,243,237,225,236,108,128,247,121,244,233,236,228,101,128,30,248,245,115,2,34,75,34,113,226,233,103,2,34,83,34,94,227,249,242,233,236,236,233,99,128,4,106,233,239,244,233,230,233,229,228,227,249,242,233,236,236,233,99,128,4,108,236,233,244,244,236,101,2,34,124,34,135,227,249,242,233,236,236,233,99,128,4,102,233,239,244,233,230,233,229,228,227,249,242,233,236,236,233,99,128,4,104,90,136,0,90,34,174,34,198,34,243,35,14,35,81,35,173,35,185,35,197,97,2,34,180,34,191,225,242,237,229,238,233,225,110,128,5,54,227,245,244,101,128,1,121,99,2,34,204,34,221,225,242,239,110,129,1,125,34,213,243,237,225,236,108,128,246,255,233,242,99,2,34,229,34,234,236,101,128,36,207,245,237,230,236,229,120,128,30,144,228,239,116,130,1,123,34,253,35,6,225,227,227,229,238,116,128,1,123,226,229,236,239,119,128,30,146,101,3,35,22,35,33,35,76,227,249,242,233,236,236,233,99,128,4,23,100,2,35,39,35,58,229,243,227,229,238,228,229,242,227,249,242,233,236,236,233,99,128,4,152,233,229,242,229,243,233,243,227,249,242,233,236,236,233,99,128,4,222,244,97,128,3,150,232,101,4,35,92,35,103,35,119,35,130,225,242,237,229,238,233,225,110,128,5,58,226,242,229,246,229,227,249,242,233,236,236,233,99,128,4,193,227,249,242,233,236,236,233,99,128,4,22,100,2,35,136,35,155,229,243,227,229,238,228,229,242,227,249,242,233,236,236,233,99,128,4,150,233,229,242,229,243,233,243,227,249,242,233,236,236,233,99,128,4,220,236,233,238,229,226,229,236,239,119,128,30,148,237,239,238,239,243,240,225,227,101,128,255,58,115,2,35,203,35,210,237,225,236,108,128,247,122,244,242,239,235,101,128,1,181,97,149,0,97,36,8,36,144,37,35,37,211,38,55,38,91,45,10,45,47,45,74,46,43,46,81,47,170,47,242,48,197,48,206,49,79,51,87,52,77,52,124,53,19,53,33,97,7,36,24,36,34,36,41,36,48,36,73,36,89,36,100,226,229,238,231,225,236,105,128,9,134,227,245,244,101,128,0,225,228,229,246,97,128,9,6,231,117,2,36,55,36,64,234,225,242,225,244,105,128,10,134,242,237,245,235,232,105,128,10,6,237,225,244,242,225,231,245,242,237,245,235,232,105,128,10,62,242,245,243,241,245,225,242,101,128,51,3,246,239,247,229,236,243,233,231,110,3,36,116,36,126,36,133,226,229,238,231,225,236,105,128,9,190,228,229,246,97,128,9,62,231,245,234,225,242,225,244,105,128,10,190,98,4,36,154,36,195,36,204,36,214,226,242,229,246,233,225,244,233,239,110,2,36,169,36,184,237,225,242,235,225,242,237,229,238,233,225,110,128,5,95,243,233,231,238,228,229,246,97,128,9,112,229,238,231,225,236,105,128,9,133,239,240,239,237,239,230,111,128,49,26,242,229,246,101,134,1,3,36,233,36,241,36,252,37,7,37,15,37,27,225,227,245,244,101,128,30,175,227,249,242,233,236,236,233,99,128,4,209,228,239,244,226,229,236,239,119,128,30,183,231,242,225,246,101,128,30,177,232,239,239,235,225,226,239,246,101,128,30,179,244,233,236,228,101,128,30,181,99,4,37,45,37,52,37,131,37,201,225,242,239,110,128,1,206,233,242,99,2,37,60,37,65,236,101,128,36,208,245,237,230,236,229,120,133,0,226,37,84,37,92,37,103,37,111,37,123,225,227,245,244,101,128,30,165,228,239,244,226,229,236,239,119,128,30,173,231,242,225,246,101,128,30,167,232,239,239,235,225,226,239,246,101,128,30,169,244,233,236,228,101,128,30,171,245,244,101,133,0,180,37,147,37,158,37,175,37,182,37,191,226,229,236,239,247,227,237,98,128,3,23,99,2,37,164,37,169,237,98,128,3,1,239,237,98,128,3,1,228,229,246,97,128,9,84,236,239,247,237,239,100,128,2,207,244,239,238,229,227,237,98,128,3,65,249,242,233,236,236,233,99,128,4,48,100,5,37,223,37,233,37,247,37,253,38,31,226,236,231,242,225,246,101,128,2,1,228,225,235,231,245,242,237,245,235,232,105,128,10,113,229,246,97,128,9,5,233,229,242,229,243,233,115,130,0,228,38,11,38,22,227,249,242,233,236,236,233,99,128,4,211,237,225,227,242,239,110,128,1,223,239,116,2,38,38,38,46,226,229,236,239,119,128,30,161,237,225,227,242,239,110,128,1,225,101,131,0,230,38,65,38,73,38,82,225,227,245,244,101,128,1,253,235,239,242,229,225,110,128,49,80,237,225,227,242,239,110,128,1,227,230,233,105,6,38,107,38,127,41,64,41,70,41,85,44,185,48,2,38,113,38,120,176,178,176,56,128,32,21,184,185,180,49,128,32,164,177,48,3,38,136,40,160,41,39,48,9,38,156,38,176,38,238,39,44,39,106,39,168,39,230,40,36,40,98,49,3,38,164,38,168,38,172,55,128,4,16,56,128,4,17,57,128,4,18,50,10,38,198,38,202,38,206,38,210,38,214,38,218,38,222,38,226,38,230,38,234,48,128,4,19,49,128,4,20,50,128,4,21,51,128,4,1,52,128,4,22,53,128,4,23,54,128,4,24,55,128,4,25,56,128,4,26,57,128,4,27,51,10,39,4,39,8,39,12,39,16,39,20,39,24,39,28,39,32,39,36,39,40,48,128,4,28,49,128,4,29,50,128,4,30,51,128,4,31,52,128,4,32,53,128,4,33,54,128,4,34,55,128,4,35,56,128,4,36,57,128,4,37,52,10,39,66,39,70,39,74,39,78,39,82,39,86,39,90,39,94,39,98,39,102,48,128,4,38,49,128,4,39,50,128,4,40,51,128,4,41,52,128,4,42,53,128,4,43,54,128,4,44,55,128,4,45,56,128,4,46,57,128,4,47,53,10,39,128,39,132,39,136,39,140,39,144,39,148,39,152,39,156,39,160,39,164,48,128,4,144,49,128,4,2,50,128,4,3,51,128,4,4,52,128,4,5,53,128,4,6,54,128,4,7,55,128,4,8,56,128,4,9,57,128,4,10,54,10,39,190,39,194,39,198,39,202,39,206,39,210,39,214,39,218,39,222,39,226,48,128,4,11,49,128,4,12,50,128,4,14,51,128,246,196,52,128,246,197,53,128,4,48,54,128,4,49,55,128,4,50,56,128,4,51,57,128,4,52,55,10,39,252,40,0,40,4,40,8,40,12,40,16,40,20,40,24,40,28,40,32,48,128,4,53,49,128,4,81,50,128,4,54,51,128,4,55,52,128,4,56,53,128,4,57,54,128,4,58,55,128,4,59,56,128,4,60,57,128,4,61,56,10,40,58,40,62,40,66,40,70,40,74,40,78,40,82,40,86,40,90,40,94,48,128,4,62,49,128,4,63,50,128,4,64,51,128,4,65,52,128,4,66,53,128,4,67,54,128,4,68,55,128,4,69,56,128,4,70,57,128,4,71,57,10,40,120,40,124,40,128,40,132,40,136,40,140,40,144,40,148,40,152,40,156,48,128,4,72,49,128,4,73,50,128,4,74,51,128,4,75,52,128,4,76,53,128,4,77,54,128,4,78,55,128,4,79,56,128,4,145,57,128,4,82,49,4,40,170,40,232,40,237,41,7,48,10,40,192,40,196,40,200,40,204,40,208,40,212,40,216,40,220,40,224,40,228,48,128,4,83,49,128,4,84,50,128,4,85,51,128,4,86,52,128,4,87,53,128,4,88,54,128,4,89,55,128,4,90,56,128,4,91,57,128,4,92,177,48,128,4,94,52,4,40,247,40,251,40,255,41,3,53,128,4,15,54,128,4,98,55,128,4,114,56,128,4,116,57,5,41,19,41,23,41,27,41,31,41,35,50,128,246,198,51,128,4,95,52,128,4,99,53,128,4,115,54,128,4,117,56,2,41,45,41,59,51,2,41,51,41,55,49,128,246,199,50,128,246,200,180,54,128,4,217,178,185,57,128,32,14,179,48,2,41,77,41,81,48,128,32,15,49,128,32,13,181,55,7,41,102,41,172,42,237,43,58,44,15,44,108,44,179,51,2,41,108,41,122,56,2,41,114,41,118,49,128,6,106,56,128,6,12,57,8,41,140,41,144,41,148,41,152,41,156,41,160,41,164,41,168,50,128,6,96,51,128,6,97,52,128,6,98,53,128,6,99,54,128,6,100,55,128,6,101,56,128,6,102,57,128,6,103,52,7,41,188,41,220,42,26,42,88,42,120,42,176,42,232,48,5,41,200,41,204,41,208,41,212,41,216,48,128,6,104,49,128,6,105,51,128,6,27,55,128,6,31,57,128,6,33,49,10,41,242,41,246,41,250,41,254,42,2,42,6,42,10,42,14,42,18,42,22,48,128,6,34,49,128,6,35,50,128,6,36,51,128,6,37,52,128,6,38,53,128,6,39,54,128,6,40,55,128,6,41,56,128,6,42,57,128,6,43,50,10,42,48,42,52,42,56,42,60,42,64,42,68,42,72,42,76,42,80,42,84,48,128,6,44,49,128,6,45,50,128,6,46,51,128,6,47,52,128,6,48,53,128,6,49,54,128,6,50,55,128,6,51,56,128,6,52,57,128,6,53,51,5,42,100,42,104,42,108,42,112,42,116,48,128,6,54,49,128,6,55,50,128,6,56,51,128,6,57,52,128,6,58,52,9,42,140,42,144,42,148,42,152,42,156,42,160,42,164,42,168,42,172,48,128,6,64,49,128,6,65,50,128,6,66,51,128,6,67,52,128,6,68,53,128,6,69,54,128,6,70,56,128,6,72,57,128,6,73,53,9,42,196,42,200,42,204,42,208,42,212,42,216,42,220,42,224,42,228,48,128,6,74,49,128,6,75,50,128,6,76,51,128,6,77,52,128,6,78,53,128,6,79,54,128,6,80,55,128,6,81,56,128,6,82,183,48,128,6,71,53,3,42,245,43,21,43,53,48,5,43,1,43,5,43,9,43,13,43,17,53,128,6,164,54,128,6,126,55,128,6,134,56,128,6,152,57,128,6,175,49,5,43,33,43,37,43,41,43,45,43,49,49,128,6,121,50,128,6,136,51,128,6,145,52,128,6,186,57,128,6,210,179,52,128,6,213,54,7,43,74,43,79,43,84,43,89,43,127,43,189,43,251,179,54,128,32,170,180,53,128,5,190,181,56,128,5,195,54,6,43,103,43,107,43,111,43,115,43,119,43,123,52,128,5,208,53,128,5,209,54,128,5,210,55,128,5,211,56,128,5,212,57,128,5,213,55,10,43,149,43,153,43,157,43,161,43,165,43,169,43,173,43,177,43,181,43,185,48,128,5,214,49,128,5,215,50,128,5,216,51,128,5,217,52,128,5,218,53,128,5,219,54,128,5,220,55,128,5,221,56,128,5,222,57,128,5,223,56,10,43,211,43,215,43,219,43,223,43,227,43,231,43,235,43,239,43,243,43,247,48,128,5,224,49,128,5,225,50,128,5,226,51,128,5,227,52,128,5,228,53,128,5,229,54,128,5,230,55,128,5,231,56,128,5,232,57,128,5,233,57,3,44,3,44,7,44,11,48,128,5,234,52,128,251,42,53,128,251,43,55,4,44,25,44,39,44,59,44,64,48,2,44,31,44,35,48,128,251,75,53,128,251,31,49,3,44,47,44,51,44,55,54,128,5,240,55,128,5,241,56,128,5,242,178,51,128,251,53,57,7,44,80,44,84,44,88,44,92,44,96,44,100,44,104,51,128,5,180,52,128,5,181,53,128,5,182,54,128,5,187,55,128,5,184,56,128,5,183,57,128,5,176,56,3,44,116,44,160,44,165,48,7,44,132,44,136,44,140,44,144,44,148,44,152,44,156,48,128,5,178,49,128,5,177,50,128,5,179,51,128,5,194,52,128,5,193,54,128,5,185,55,128,5,188,179,57,128,5,189,52,2,44,171,44,175,49,128,5,191,50,128,5,192,185,178,57,128,2,188,54,3,44,193,44,252,45,3,49,4,44,203,44,219,44,225,44,246,50,2,44,209,44,214,180,56,128,33,5,184,57,128,33,19,179,181,50,128,33,22,181,55,3,44,234,44,238,44,242,51,128,32,44,52,128,32,45,53,128,32,46,182,182,52,128,32,12,179,177,182,55,128,6,109,180,185,179,55,128,2,189,103,2,45,16,45,23,242,225,246,101,128,0,224,117,2,45,29,45,38,234,225,242,225,244,105,128,10,133,242,237,245,235,232,105,128,10,5,104,2,45,53,45,63,233,242,225,231,225,238,97,128,48,66,239,239,235,225,226,239,246,101,128,30,163,105,7,45,90,45,115,45,122,45,134,45,159,45,175,45,255,98,2,45,96,45,105,229,238,231,225,236,105,128,9,144,239,240,239,237,239,230,111,128,49,30,228,229,246,97,128,9,16,229,227,249,242,233,236,236,233,99,128,4,213,231,117,2,45,141,45,150,234,225,242,225,244,105,128,10,144,242,237,245,235,232,105,128,10,16,237,225,244,242,225,231,245,242,237,245,235,232,105,128,10,72,110,5,45,187,45,196,45,210,45,226,45,241,225,242,225,226,233,99,128,6,57,230,233,238,225,236,225,242,225,226,233,99,128,254,202,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,203,237,229,228,233,225,236,225,242,225,226,233,99,128,254,204,246,229,242,244,229,228,226,242,229,246,101,128,2,3,246,239,247,229,236,243,233,231,110,3,46,15,46,25,46,32,226,229,238,231,225,236,105,128,9,200,228,229,246,97,128,9,72,231,245,234,225,242,225,244,105,128,10,200,107,2,46,49,46,73,225,244,225,235,225,238,97,129,48,162,46,61,232,225,236,230,247,233,228,244,104,128,255,113,239,242,229,225,110,128,49,79,108,3,46,89,47,145,47,154,101,2,46,95,47,140,102,136,5,208,46,115,46,124,46,139,46,153,46,242,47,0,47,111,47,125,225,242,225,226,233,99,128,6,39,228,225,231,229,243,232,232,229,226,242,229,119,128,251,48,230,233,238,225,236,225,242,225,226,233,99,128,254,142,104,2,46,159,46,234,225,237,250,97,2,46,168,46,201,225,226,239,246,101,2,46,178,46,187,225,242,225,226,233,99,128,6,35,230,233,238,225,236,225,242,225,226,233,99,128,254,132,226,229,236,239,119,2,46,211,46,220,225,242,225,226,233,99,128,6,37,230,233,238,225,236,225,242,225,226,233,99,128,254,136,229,226,242,229,119,128,5,208,236,225,237,229,228,232,229,226,242,229,119,128,251,79,237,97,2,47,7,47,43,228,228,225,225,226,239,246,101,2,47,20,47,29,225,242,225,226,233,99,128,6,34,230,233,238,225,236,225,242,225,226,233,99,128,254,130,235,243,245,242,97,4,47,57,47,66,47,80,47,96,225,242,225,226,233,99,128,6,73,230,233,238,225,236,225,242,225,226,233,99,128,254,240,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,243,237,229,228,233,225,236,225,242,225,226,233,99,128,254,244,240,225,244,225,232,232,229,226,242,229,119,128,251,46,241,225,237,225,244,243,232,229,226,242,229,119,128,251,47,240,104,128,33,53,236,229,241,245,225,108,128,34,76,240,232,97,129,3,177,47,162,244,239,238,239,115,128,3,172,109,4,47,180,47,188,47,199,47,233,225,227,242,239,110,128,1,1,239,238,239,243,240,225,227,101,128,255,65,240,229,242,243,225,238,100,130,0,38,47,213,47,225,237,239,238,239,243,240,225,227,101,128,255,6,243,237,225,236,108,128,247,38,243,241,245,225,242,101,128,51,194,110,4,47,252,48,7,48,129,48,139,226,239,240,239,237,239,230,111,128,49,34,103,4,48,17,48,28,48,42,48,121,226,239,240,239,237,239,230,111,128,49,36,235,232,225,238,235,232,245,244,232,225,105,128,14,90,236,101,131,34,32,48,53,48,106,48,113,226,242,225,227,235,229,116,2,48,65,48,85,236,229,230,116,129,48,8,48,74,246,229,242,244,233,227,225,108,128,254,63,242,233,231,232,116,129,48,9,48,95,246,229,242,244,233,227,225,108,128,254,64,236,229,230,116,128,35,41,242,233,231,232,116,128,35,42,243,244,242,239,109,128,33,43,239,244,229,236,229,233,97,128,3,135,117,2,48,145,48,157,228,225,244,244,225,228,229,246,97,128,9,82,243,246,225,242,97,3,48,169,48,179,48,186,226,229,238,231,225,236,105,128,9,130,228,229,246,97,128,9,2,231,245,234,225,242,225,244,105,128,10,130,239,231,239,238,229,107,128,1,5,112,3,48,214,48,238,49,12,97,2,48,220,48,232,225,244,239,243,241,245,225,242,101,128,51,0,242,229,110,128,36,156,239,243,244,242,239,240,232,101,2,48,251,49,6,225,242,237,229,238,233,225,110,128,5,90,237,239,100,128,2,188,112,2,49,18,49,23,236,101,128,248,255,242,111,2,49,30,49,38,225,227,232,229,115,128,34,80,120,2,49,44,49,64,229,241,245,225,108,129,34,72,49,54,239,242,233,237,225,231,101,128,34,82,233,237,225,244,229,236,249,229,241,245,225,108,128,34,69,114,4,49,89,49,116,49,120,49,165,225,229,97,2,49,97,49,107,229,235,239,242,229,225,110,128,49,142,235,239,242,229,225,110,128,49,141,99,128,35,18,105,2,49,126,49,140,231,232,244,232,225,236,230,242,233,238,103,128,30,154,238,103,130,0,229,49,149,49,157,225,227,245,244,101,128,1,251,226,229,236,239,119,128,30,1,242,239,119,8,49,185,49,192,50,65,50,131,50,181,50,236,51,3,51,78,226,239,244,104,128,33,148,100,3,49,200,49,239,50,30,225,243,104,4,49,212,49,219,49,226,49,234,228,239,247,110,128,33,227,236,229,230,116,128,33,224,242,233,231,232,116,128,33,226,245,112,128,33,225,226,108,5,49,252,50,3,50,10,50,17,50,25,226,239,244,104,128,33,212,228,239,247,110,128,33,211,236,229,230,116,128,33,208,242,233,231,232,116,128,33,210,245,112,128,33,209,239,247,110,131,33,147,50,42,50,49,50,57,236,229,230,116,128,33,153,242,233,231,232,116,128,33,152,247,232,233,244,101,128,33,233,104,2,50,71,50,122,229,225,100,4,50,83,50,93,50,103,50,114,228,239,247,238,237,239,100,128,2,197,236,229,230,244,237,239,100,128,2,194,242,233,231,232,244,237,239,100,128,2,195,245,240,237,239,100,128,2,196,239,242,233,250,229,120,128,248,231,236,229,230,116,131,33,144,50,144,50,161,50,173,228,226,108,129,33,208,50,152,243,244,242,239,235,101,128,33,205,239,246,229,242,242,233,231,232,116,128,33,198,247,232,233,244,101,128,33,230,242,233,231,232,116,132,33,146,50,197,50,209,50,217,50,228,228,226,236,243,244,242,239,235,101,128,33,207,232,229,225,246,121,128,39,158,239,246,229,242,236,229,230,116,128,33,196,247,232,233,244,101,128,33,232,244,225,98,2,50,244,50,251,236,229,230,116,128,33,228,242,233,231,232,116,128,33,229,245,112,132,33,145,51,16,51,44,51,62,51,70,100,2,51,22,51,34,110,129,33,149,51,28,226,243,101,128,33,168,239,247,238,226,225,243,101,128,33,168,236,229,230,116,129,33,150,51,53,239,230,228,239,247,110,128,33,197,242,233,231,232,116,128,33,151,247,232,233,244,101,128,33,231,246,229,242,244,229,120,128,248,230,115,5,51,99,51,175,51,220,52,47,52,57,99,2,51,105,51,157,233,105,2,51,112,51,135,227,233,242,227,245,109,129,0,94,51,123,237,239,238,239,243,240,225,227,101,128,255,62,244,233,236,228,101,129,0,126,51,145,237,239,238,239,243,240,225,227,101,128,255,94,242,233,240,116,129,2,81,51,166,244,245,242,238,229,100,128,2,82,237,225,236,108,2,51,184,51,195,232,233,242,225,231,225,238,97,128,48,65,235,225,244,225,235,225,238,97,129,48,161,51,208,232,225,236,230,247,233,228,244,104,128,255,103,244,229,242,233,115,2,51,230,52,43,107,131,0,42,51,240,52,12,52,35,97,2,51,246,52,4,236,244,239,238,229,225,242,225,226,233,99,128,6,109,242,225,226,233,99,128,6,109,109,2,52,18,52,24,225,244,104,128,34,23,239,238,239,243,240,225,227,101,128,255,10,243,237,225,236,108,128,254,97,109,128,32,66,245,240,229,242,233,239,114,128,246,233,249,237,240,244,239,244,233,227,225,236,236,249,229,241,245,225,108,128,34,67,116,132,0,64,52,89,52,96,52,108,52,116,233,236,228,101,128,0,227,237,239,238,239,243,240,225,227,101,128,255,32,243,237,225,236,108,128,254,107,245,242,238,229,100,128,2,80,117,6,52,138,52,163,52,170,52,195,52,215,52,231,98,2,52,144,52,153,229,238,231,225,236,105,128,9,148,239,240,239,237,239,230,111,128,49,32,228,229,246,97,128,9,20,231,117,2,52,177,52,186,234,225,242,225,244,105,128,10,148,242,237,245,235,232,105,128,10,20,236,229,238,231,244,232,237,225,242,235,226,229,238,231,225,236,105,128,9,215,237,225,244,242,225,231,245,242,237,245,235,232,105,128,10,76,246,239,247,229,236,243,233,231,110,3,52,247,53,1,53,8,226,229,238,231,225,236,105,128,9,204,228,229,246,97,128,9,76,231,245,234,225,242,225,244,105,128,10,204,246,225,231,242,225,232,225,228,229,246,97,128,9,61,121,2,53,39,53,51,226,225,242,237,229,238,233,225,110,128,5,97,233,110,130,5,226,53,60,53,75,225,236,244,239,238,229,232,229,226,242,229,119,128,251,32,232,229,226,242,229,119,128,5,226,98,144,0,98,53,120,53,255,54,10,54,19,54,44,55,85,55,147,55,220,57,146,57,158,57,201,57,209,57,219,59,89,59,113,59,122,97,7,53,136,53,146,53,170,53,177,53,202,53,226,53,237,226,229,238,231,225,236,105,128,9,172,227,235,243,236,225,243,104,129,0,92,53,158,237,239,238,239,243,240,225,227,101,128,255,60,228,229,246,97,128,9,44,231,117,2,53,184,53,193,234,225,242,225,244,105,128,10,172,242,237,245,235,232,105,128,10,44,104,2,53,208,53,218,233,242,225,231,225,238,97,128,48,112,244,244,232,225,105,128,14,63,235,225,244,225,235,225,238,97,128,48,208,114,129,0,124,53,243,237,239,238,239,243,240,225,227,101,128,255,92,226,239,240,239,237,239,230,111,128,49,5,227,233,242,227,236,101,128,36,209,228,239,116,2,54,27,54,36,225,227,227,229,238,116,128,30,3,226,229,236,239,119,128,30,5,101,6,54,58,54,79,54,102,54,244,54,255,55,11,225,237,229,228,243,233,248,244,229,229,238,244,232,238,239,244,229,115,128,38,108,99,2,54,85,54,92,225,245,243,101,128,34,53,249,242,233,236,236,233,99,128,4,49,104,5,54,114,54,123,54,137,54,167,54,226,225,242,225,226,233,99,128,6,40,230,233,238,225,236,225,242,225,226,233,99,128,254,144,105,2,54,143,54,158,238,233,244,233,225,236,225,242,225,226,233,99,128,254,145,242,225,231,225,238,97,128,48,121,237,101,2,54,174,54,187,228,233,225,236,225,242,225,226,233,99,128,254,146,229,237,105,2,54,195,54,210,238,233,244,233,225,236,225,242,225,226,233,99,128,252,159,243,239,236,225,244,229,228,225,242,225,226,233,99,128,252,8,238,239,239,238,230,233,238,225,236,225,242,225,226,233,99,128,252,109,235,225,244,225,235,225,238,97,128,48,217,238,225,242,237,229,238,233,225,110,128,5,98,116,132,5,209,55,23,55,43,55,63,55,72,97,129,3,178,55,29,243,249,237,226,239,236,231,242,229,229,107,128,3,208,228,225,231,229,243,104,129,251,49,55,54,232,229,226,242,229,119,128,251,49,232,229,226,242,229,119,128,5,209,242,225,230,229,232,229,226,242,229,119,128,251,76,104,2,55,91,55,141,97,3,55,99,55,109,55,116,226,229,238,231,225,236,105,128,9,173,228,229,246,97,128,9,45,231,117,2,55,123,55,132,234,225,242,225,244,105,128,10,173,242,237,245,235,232,105,128,10,45,239,239,107,128,2,83,105,5,55,159,55,170,55,181,55,195,55,209,232,233,242,225,231,225,238,97,128,48,115,235,225,244,225,235,225,238,97,128,48,211,236,225,226,233,225,236,227,236,233,227,107,128,2,152,238,228,233,231,245,242,237,245,235,232,105,128,10,2,242,245,243,241,245,225,242,101,128,51,49,108,3,55,228,57,129,57,140,97,2,55,234,57,124,227,107,6,55,249,56,2,56,39,56,188,56,243,57,39,227,233,242,227,236,101,128,37,207,100,2,56,8,56,17,233,225,237,239,238,100,128,37,198,239,247,238,240,239,233,238,244,233,238,231,244,242,233,225,238,231,236,101,128,37,188,108,2,56,45,56,148,101,2,56,51,56,87,230,244,240,239,233,238,244,233,238,103,2,56,66,56,76,240,239,233,238,244,229,114,128,37,196,244,242,233,225,238,231,236,101,128,37,192,238,244,233,227,245,236,225,242,226,242,225,227,235,229,116,2,56,107,56,127,236,229,230,116,129,48,16,56,116,246,229,242,244,233,227,225,108,128,254,59,242,233,231,232,116,129,48,17,56,137,246,229,242,244,233,227,225,108,128,254,60,239,247,229,114,2,56,157,56,172,236,229,230,244,244,242,233,225,238,231,236,101,128,37,227,242,233,231,232,244,244,242,233,225,238,231,236,101,128,37,226,114,2,56,194,56,205,229,227,244,225,238,231,236,101,128,37,172,233,231,232,244,240,239,233,238,244,233,238,103,2,56,222,56,232,240,239,233,238,244,229,114,128,37,186,244,242,233,225,238,231,236,101,128,37,182,115,3,56,251,57,25,57,33,109,2,57,1,57,13,225,236,236,243,241,245,225,242,101,128,37,170,233,236,233,238,231,230,225,227,101,128,38,59,241,245,225,242,101,128,37,160,244,225,114,128,38,5,245,240,112,2,57,47,57,85,229,114,2,57,54,57,69,236,229,230,244,244,242,233,225,238,231,236,101,128,37,228,242,233,231,232,244,244,242,233,225,238,231,236,101,128,37,229,239,233,238,244,233,238,103,2,57,97,57,113,243,237,225,236,236,244,242,233,225,238,231,236,101,128,37,180,244,242,233,225,238,231,236,101,128,37,178,238,107,128,36,35,233,238,229,226,229,236,239,119,128,30,7,239,227,107,128,37,136,237,239,238,239,243,240,225,227,101,128,255,66,111,3,57,166,57,179,57,190,226,225,233,237,225,233,244,232,225,105,128,14,26,232,233,242,225,231,225,238,97,128,48,124,235,225,244,225,235,225,238,97,128,48,220,240,225,242,229,110,128,36,157,241,243,241,245,225,242,101,128,51,195,114,4,57,229,58,223,59,40,59,79,225,99,2,57,236,58,130,101,3,57,244,57,249,58,61,229,120,128,248,244,236,229,230,116,133,0,123,58,10,58,15,58,37,58,45,58,50,226,116,128,248,243,109,2,58,21,58,26,233,100,128,248,242,239,238,239,243,240,225,227,101,128,255,91,243,237,225,236,108,128,254,91,244,112,128,248,241,246,229,242,244,233,227,225,108,128,254,55,242,233,231,232,116,133,0,125,58,79,58,84,58,106,58,114,58,119,226,116,128,248,254,109,2,58,90,58,95,233,100,128,248,253,239,238,239,243,240,225,227,101,128,255,93,243,237,225,236,108,128,254,92,244,112,128,248,252,246,229,242,244,233,227,225,108,128,254,56,235,229,116,2,58,138,58,180,236,229,230,116,132,0,91,58,153,58,158,58,163,58,175,226,116,128,248,240,229,120,128,248,239,237,239,238,239,243,240,225,227,101,128,255,59,244,112,128,248,238,242,233,231,232,116,132,0,93,58,196,58,201,58,206,58,218,226,116,128,248,251,229,120,128,248,250,237,239,238,239,243,240,225,227,101,128,255,61,244,112,128,248,249,229,246,101,131,2,216,58,235,58,246,58,252,226,229,236,239,247,227,237,98,128,3,46,227,237,98,128,3,6,233,238,246,229,242,244,229,100,3,59,11,59,22,59,28,226,229,236,239,247,227,237,98,128,3,47,227,237,98,128,3,17,228,239,245,226,236,229,227,237,98,128,3,97,233,228,231,101,2,59,49,59,60,226,229,236,239,247,227,237,98,128,3,42,233,238,246,229,242,244,229,228,226,229,236,239,247,227,237,98,128,3,58,239,235,229,238,226,225,114,128,0,166,115,2,59,95,59,103,244,242,239,235,101,128,1,128,245,240,229,242,233,239,114,128,246,234,244,239,240,226,225,114,128,1,131,117,3,59,130,59,141,59,152,232,233,242,225,231,225,238,97,128,48,118,235,225,244,225,235,225,238,97,128,48,214,236,108,2,59,159,59,189,229,116,130,32,34,59,168,59,178,233,238,246,229,242,243,101,128,37,216,239,240,229,242,225,244,239,114,128,34,25,243,229,249,101,128,37,206,99,143,0,99,59,230,60,179,60,190,60,254,61,29,61,122,63,33,64,17,64,117,64,166,67,158,67,166,67,176,67,188,67,221,97,9,59,250,60,5,60,15,60,22,60,29,60,54,60,64,60,116,60,125,225,242,237,229,238,233,225,110,128,5,110,226,229,238,231,225,236,105,128,9,154,227,245,244,101,128,1,7,228,229,246,97,128,9,26,231,117,2,60,36,60,45,234,225,242,225,244,105,128,10,154,242,237,245,235,232,105,128,10,26,236,243,241,245,225,242,101,128,51,136,238,228,242,225,226,233,238,228,117,4,60,82,60,92,60,98,60,105,226,229,238,231,225,236,105,128,9,129,227,237,98,128,3,16,228,229,246,97,128,9,1,231,245,234,225,242,225,244,105,128,10,129,240,243,236,239,227,107,128,33,234,114,3,60,133,60,139,60,165,229,239,102,128,33,5,239,110,130,2,199,60,148,60,159,226,229,236,239,247,227,237,98,128,3,44,227,237,98,128,3,12,242,233,225,231,229,242,229,244,245,242,110,128,33,181,226,239,240,239,237,239,230,111,128,49,24,99,4,60,200,60,207,60,226,60,248,225,242,239,110,128,1,13,229,228,233,236,236,97,129,0,231,60,218,225,227,245,244,101,128,30,9,233,242,99,2,60,234,60,239,236,101,128,36,210,245,237,230,236,229,120,128,1,9,245,242,108,128,2,85,100,2,61,4,61,20,239,116,129,1,11,61,11,225,227,227,229,238,116,128,1,11,243,241,245,225,242,101,128,51,197,101,2,61,35,61,51,228,233,236,236,97,129,0,184,61,45,227,237,98,128,3,39,238,116,132,0,162,61,64,61,88,61,100,61,111,105,2,61,70,61,78,231,242,225,228,101,128,33,3,238,230,229,242,233,239,114,128,246,223,237,239,238,239,243,240,225,227,101,128,255,224,239,236,228,243,244,249,236,101,128,247,162,243,245,240,229,242,233,239,114,128,246,224,104,5,61,134,61,197,61,208,62,136,62,228,97,4,61,144,61,155,61,165,61,172,225,242,237,229,238,233,225,110,128,5,121,226,229,238,231,225,236,105,128,9,155,228,229,246,97,128,9,27,231,117,2,61,179,61,188,234,225,242,225,244,105,128,10,155,242,237,245,235,232,105,128,10,27,226,239,240,239,237,239,230,111,128,49,20,101,6,61,222,61,242,62,10,62,78,62,90,62,111,225,226,235,232,225,243,233,225,238,227,249,242,233,236,236,233,99,128,4,189,99,2,61,248,62,0,235,237,225,242,107,128,39,19,249,242,233,236,236,233,99,128,4,71,100,2,62,16,62,60,229,243,227,229,238,228,229,114,2,62,29,62,49,225,226,235,232,225,243,233,225,238,227,249,242,233,236,236,233,99,128,4,191,227,249,242,233,236,236,233,99,128,4,183,233,229,242,229,243,233,243,227,249,242,233,236,236,233,99,128,4,245,232,225,242,237,229,238,233,225,110,128,5,115,235,232,225,235,225,243,243,233,225,238,227,249,242,233,236,236,233,99,128,4,204,246,229,242,244,233,227,225,236,243,244,242,239,235,229,227,249,242,233,236,236,233,99,128,4,185,105,129,3,199,62,142,229,245,227,104,4,62,155,62,190,62,205,62,214,97,2,62,161,62,176,227,233,242,227,236,229,235,239,242,229,225,110,128,50,119,240,225,242,229,238,235,239,242,229,225,110,128,50,23,227,233,242,227,236,229,235,239,242,229,225,110,128,50,105,235,239,242,229,225,110,128,49,74,240,225,242,229,238,235,239,242,229,225,110,128,50,9,111,2,62,234,63,28,227,104,3,62,243,63,9,63,19,225,110,2,62,250,63,2,231,244,232,225,105,128,14,10,244,232,225,105,128,14,8,233,238,231,244,232,225,105,128,14,9,239,229,244,232,225,105,128,14,12,239,107,128,1,136,105,2,63,39,63,141,229,245,99,5,63,53,63,88,63,103,63,112,63,126,97,2,63,59,63,74,227,233,242,227,236,229,235,239,242,229,225,110,128,50,118,240,225,242,229,238,235,239,242,229,225,110,128,50,22,227,233,242,227,236,229,235,239,242,229,225,110,128,50,104,235,239,242,229,225,110,128,49,72,240,225,242,229,238,235,239,242,229,225,110,128,50,8,245,240,225,242,229,238,235,239,242,229,225,110,128,50,28,242,99,2,63,148,63,243,236,101,132,37,203,63,161,63,172,63,177,63,201,237,245,236,244,233,240,236,121,128,34,151,239,116,128,34,153,112,2,63,183,63,189,236,245,115,128,34,149,239,243,244,225,236,237,225,242,107,128,48,54,247,233,244,104,2,63,210,63,226,236,229,230,244,232,225,236,230,226,236,225,227,107,128,37,208,242,233,231,232,244,232,225,236,230,226,236,225,227,107,128,37,209,245,237,230,236,229,120,130,2,198])
.concat([64,0,64,11,226,229,236,239,247,227,237,98,128,3,45,227,237,98,128,3,2,108,3,64,25,64,31,64,85,229,225,114,128,35,39,233,227,107,4,64,43,64,54,64,63,64,73,225,236,246,229,239,236,225,114,128,1,194,228,229,238,244,225,108,128,1,192,236,225,244,229,242,225,108,128,1,193,242,229,244,242,239,230,236,229,120,128,1,195,245,98,129,38,99,64,92,243,245,233,116,2,64,101,64,109,226,236,225,227,107,128,38,99,247,232,233,244,101,128,38,103,109,3,64,125,64,139,64,150,227,245,226,229,228,243,241,245,225,242,101,128,51,164,239,238,239,243,240,225,227,101,128,255,67,243,241,245,225,242,229,228,243,241,245,225,242,101,128,51,160,111,8,64,184,64,195,65,26,65,224,66,253,67,28,67,135,67,144,225,242,237,229,238,233,225,110,128,5,129,236,239,110,131,0,58,64,207,64,232,64,251,237,239,110,2,64,215,64,223,229,244,225,242,121,128,32,161,239,243,240,225,227,101,128,255,26,115,2,64,238,64,244,233,231,110,128,32,161,237,225,236,108,128,254,85,244,242,233,225,238,231,245,236,225,114,2,65,10,65,20,232,225,236,230,237,239,100,128,2,209,237,239,100,128,2,208,109,2,65,32,65,217,237,97,134,0,44,65,49,65,113,65,124,65,136,65,166,65,189,97,3,65,57,65,83,65,91,226,239,246,101,2,65,66,65,72,227,237,98,128,3,19,242,233,231,232,244,227,237,98,128,3,21,227,227,229,238,116,128,246,195,114,2,65,97,65,104,225,226,233,99,128,6,12,237,229,238,233,225,110,128,5,93,233,238,230,229,242,233,239,114,128,246,225,237,239,238,239,243,240,225,227,101,128,255,12,242,229,246,229,242,243,229,100,2,65,149,65,160,225,226,239,246,229,227,237,98,128,3,20,237,239,100,128,2,189,115,2,65,172,65,179,237,225,236,108,128,254,80,245,240,229,242,233,239,114,128,246,226,244,245,242,238,229,100,2,65,200,65,211,225,226,239,246,229,227,237,98,128,3,18,237,239,100,128,2,187,240,225,243,115,128,38,60,110,2,65,230,65,239,231,242,245,229,238,116,128,34,69,116,2,65,245,66,3,239,245,242,233,238,244,229,231,242,225,108,128,34,46,242,239,108,142,35,3,66,37,66,43,66,58,66,73,66,117,66,162,66,176,66,181,66,186,66,191,66,197,66,202,66,243,66,248,193,195,75,128,0,6,66,2,66,49,66,54,197,76,128,0,7,83,128,0,8,67,2,66,64,66,69,193,78,128,0,24,82,128,0,13,68,3,66,81,66,107,66,112,67,4,66,91,66,95,66,99,66,103,49,128,0,17,50,128,0,18,51,128,0,19,52,128,0,20,197,76,128,0,127,204,69,128,0,16,69,5,66,129,66,133,66,138,66,143,66,148,77,128,0,25,206,81,128,0,5,207,84,128,0,4,211,67,128,0,27,84,2,66,154,66,158,66,128,0,23,88,128,0,3,70,2,66,168,66,172,70,128,0,12,83,128,0,28,199,83,128,0,29,200,84,128,0,9,204,70,128,0,10,206,193,75,128,0,21,210,83,128,0,30,83,5,66,214,66,218,66,228,66,233,66,238,73,128,0,15,79,129,0,14,66,224,84,128,0,2,212,88,128,0,1,213,66,128,0,26,217,78,128,0,22,213,83,128,0,31,214,84,128,0,11,240,249,242,233,231,232,116,129,0,169,67,9,115,2,67,15,67,21,225,238,115,128,248,233,229,242,233,102,128,246,217,114,2,67,34,67,118,238,229,242,226,242,225,227,235,229,116,2,67,49,67,83,236,229,230,116,130,48,12,67,60,67,72,232,225,236,230,247,233,228,244,104,128,255,98,246,229,242,244,233,227,225,108,128,254,65,242,233,231,232,116,130,48,13,67,95,67,107,232,225,236,230,247,233,228,244,104,128,255,99,246,229,242,244,233,227,225,108,128,254,66,240,239,242,225,244,233,239,238,243,241,245,225,242,101,128,51,127,243,241,245,225,242,101,128,51,199,246,229,242,235,231,243,241,245,225,242,101,128,51,198,240,225,242,229,110,128,36,158,242,245,250,229,233,242,111,128,32,162,243,244,242,229,244,227,232,229,100,128,2,151,245,114,2,67,195,67,213,236,121,2,67,202,67,208,225,238,100,128,34,207,239,114,128,34,206,242,229,238,227,121,128,0,164,249,114,4,67,232,67,240,67,247,67,255,194,242,229,246,101,128,246,209,198,236,229,120,128,246,210,226,242,229,246,101,128,246,212,230,236,229,120,128,246,213,100,146,0,100,68,46,69,184,70,208,71,12,71,188,72,142,72,204,73,133,73,146,73,155,73,181,73,206,73,215,75,26,75,34,75,45,75,65,75,93,97,11,68,70,68,81,68,91,68,163,68,226,68,237,68,248,69,61,69,123,69,129,69,159,225,242,237,229,238,233,225,110,128,5,100,226,229,238,231,225,236,105,128,9,166,100,5,68,103,68,112,68,118,68,132,68,148,225,242,225,226,233,99,128,6,54,229,246,97,128,9,38,230,233,238,225,236,225,242,225,226,233,99,128,254,190,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,191,237,229,228,233,225,236,225,242,225,226,233,99,128,254,192,103,3,68,171,68,188,68,202,229,243,104,129,5,188,68,179,232,229,226,242,229,119,128,5,188,231,229,114,129,32,32,68,196,228,226,108,128,32,33,117,2,68,208,68,217,234,225,242,225,244,105,128,10,166,242,237,245,235,232,105,128,10,38,232,233,242,225,231,225,238,97,128,48,96,235,225,244,225,235,225,238,97,128,48,192,108,3,69,0,69,9,69,47,225,242,225,226,233,99,128,6,47,229,116,130,5,211,69,18,69,38,228,225,231,229,243,104,129,251,51,69,29,232,229,226,242,229,119,128,251,51,232,229,226,242,229,119,128,5,211,230,233,238,225,236,225,242,225,226,233,99,128,254,170,237,237,97,3,69,71,69,80,69,92,225,242,225,226,233,99,128,6,79,236,239,247,225,242,225,226,233,99,128,6,79,244,225,238,97,2,69,101,69,115,236,244,239,238,229,225,242,225,226,233,99,128,6,76,242,225,226,233,99,128,6,76,238,228,97,128,9,100,242,231,97,2,69,137,69,146,232,229,226,242,229,119,128,5,167,236,229,230,244,232,229,226,242,229,119,128,5,167,243,233,225,240,238,229,245,237,225,244,225,227,249,242,233,236,236,233,227,227,237,98,128,4,133,98,3,69,192,70,189,70,199,108,9,69,212,69,220,70,77,70,85,70,101,70,112,70,130,70,144,70,155,199,242,225,246,101,128,246,211,97,2,69,226,70,27,238,231,236,229,226,242,225,227,235,229,116,2,69,242,70,6,236,229,230,116,129,48,10,69,251,246,229,242,244,233,227,225,108,128,254,61,242,233,231,232,116,129,48,11,70,16,246,229,242,244,233,227,225,108,128,254,62,114,2,70,33,70,54,227,232,233,238,246,229,242,244,229,228,226,229,236,239,247,227,237,98,128,3,43,242,239,119,2,70,62,70,69,236,229,230,116,128,33,212,242,233,231,232,116,128,33,210,228,225,238,228,97,128,9,101,231,242,225,246,101,129,246,214,70,95,227,237,98,128,3,15,233,238,244,229,231,242,225,108,128,34,44,236,239,247,236,233,238,101,129,32,23,70,124,227,237,98,128,3,51,239,246,229,242,236,233,238,229,227,237,98,128,3,63,240,242,233,237,229,237,239,100,128,2,186,246,229,242,244,233,227,225,108,2,70,168,70,174,226,225,114,128,32,22,236,233,238,229,225,226,239,246,229,227,237,98,128,3,14,239,240,239,237,239,230,111,128,49,9,243,241,245,225,242,101,128,51,200,99,4,70,218,70,225,70,234,71,5,225,242,239,110,128,1,15,229,228,233,236,236,97,128,30,17,233,242,99,2,70,242,70,247,236,101,128,36,211,245,237,230,236,229,248,226,229,236,239,119,128,30,19,242,239,225,116,128,1,17,100,4,71,22,71,103,71,113,71,164,97,4,71,32,71,42,71,49,71,74,226,229,238,231,225,236,105,128,9,161,228,229,246,97,128,9,33,231,117,2,71,56,71,65,234,225,242,225,244,105,128,10,161,242,237,245,235,232,105,128,10,33,108,2,71,80,71,89,225,242,225,226,233,99,128,6,136,230,233,238,225,236,225,242,225,226,233,99,128,251,137,228,232,225,228,229,246,97,128,9,92,232,97,3,71,122,71,132,71,139,226,229,238,231,225,236,105,128,9,162,228,229,246,97,128,9,34,231,117,2,71,146,71,155,234,225,242,225,244,105,128,10,162,242,237,245,235,232,105,128,10,34,239,116,2,71,171,71,180,225,227,227,229,238,116,128,30,11,226,229,236,239,119,128,30,13,101,8,71,206,72,3,72,10,72,35,72,45,72,56,72,101,72,137,99,2,71,212,71,249,233,237,225,236,243,229,240,225,242,225,244,239,114,2,71,230,71,239,225,242,225,226,233,99,128,6,107,240,229,242,243,233,225,110,128,6,107,249,242,233,236,236,233,99,128,4,52,231,242,229,101,128,0,176,232,105,2,72,17,72,26,232,229,226,242,229,119,128,5,173,242,225,231,225,238,97,128,48,103,233,227,239,240,244,233,99,128,3,239,235,225,244,225,235,225,238,97,128,48,199,108,2,72,62,72,85,229,244,101,2,72,70,72,77,236,229,230,116,128,35,43,242,233,231,232,116,128,35,38,244,97,129,3,180,72,92,244,245,242,238,229,100,128,1,141,238,239,237,233,238,225,244,239,242,237,233,238,245,243,239,238,229,238,245,237,229,242,225,244,239,242,226,229,238,231,225,236,105,128,9,248,250,104,128,2,164,104,2,72,148,72,198,97,3,72,156,72,166,72,173,226,229,238,231,225,236,105,128,9,167,228,229,246,97,128,9,39,231,117,2,72,180,72,189,234,225,242,225,244,105,128,10,167,242,237,245,235,232,105,128,10,39,239,239,107,128,2,87,105,6,72,218,73,11,73,71,73,82,73,93,73,103,97,2,72,224,72,246,236,249,244,233,235,225,244,239,238,239,115,129,3,133,72,240,227,237,98,128,3,68,237,239,238,100,129,38,102,72,255,243,245,233,244,247,232,233,244,101,128,38,98,229,242,229,243,233,115,133,0,168,73,30,73,38,73,49,73,55,73,63,225,227,245,244,101,128,246,215,226,229,236,239,247,227,237,98,128,3,36,227,237,98,128,3,8,231,242,225,246,101,128,246,216,244,239,238,239,115,128,3,133,232,233,242,225,231,225,238,97,128,48,98,235,225,244,225,235,225,238,97,128,48,194,244,244,239,237,225,242,107,128,48,3,246,105,2,73,110,73,121,228,101,129,0,247,73,117,115,128,34,35,243,233,239,238,243,236,225,243,104,128,34,21,234,229,227,249,242,233,236,236,233,99,128,4,82,235,243,232,225,228,101,128,37,147,108,2,73,161,73,172,233,238,229,226,229,236,239,119,128,30,15,243,241,245,225,242,101,128,51,151,109,2,73,187,73,195,225,227,242,239,110,128,1,17,239,238,239,243,240,225,227,101,128,255,68,238,226,236,239,227,107,128,37,132,111,10,73,237,73,249,74,3,74,14,74,25,74,97,74,102,74,113,74,228,74,254,227,232,225,228,225,244,232,225,105,128,14,14,228,229,235,244,232,225,105,128,14,20,232,233,242,225,231,225,238,97,128,48,105,235,225,244,225,235,225,238,97,128,48,201,236,236,225,114,132,0,36,74,40,74,51,74,63,74,74,233,238,230,229,242,233,239,114,128,246,227,237,239,238,239,243,240,225,227,101,128,255,4,239,236,228,243,244,249,236,101,128,247,36,115,2,74,80,74,87,237,225,236,108,128,254,105,245,240,229,242,233,239,114,128,246,228,238,103,128,32,171,242,245,243,241,245,225,242,101,128,51,38,116,6,74,127,74,144,74,166,74,177,74,209,74,216,225,227,227,229,238,116,129,2,217,74,138,227,237,98,128,3,7,226,229,236,239,247,99,2,74,155,74,160,237,98,128,3,35,239,237,98,128,3,35,235,225,244,225,235,225,238,97,128,48,251,236,229,243,115,2,74,186,74,190,105,128,1,49,106,129,246,190,74,196,243,244,242,239,235,229,232,239,239,107,128,2,132,237,225,244,104,128,34,197,244,229,228,227,233,242,227,236,101,128,37,204,245,226,236,229,249,239,228,240,225,244,225,104,129,251,31,74,245,232,229,226,242,229,119,128,251,31,247,238,244,225,227,107,2,75,9,75,20,226,229,236,239,247,227,237,98,128,3,30,237,239,100,128,2,213,240,225,242,229,110,128,36,159,243,245,240,229,242,233,239,114,128,246,235,116,2,75,51,75,57,225,233,108,128,2,86,239,240,226,225,114,128,1,140,117,2,75,71,75,82,232,233,242,225,231,225,238,97,128,48,101,235,225,244,225,235,225,238,97,128,48,197,122,132,1,243,75,105,75,114,75,133,75,170,225,236,244,239,238,101,128,2,163,99,2,75,120,75,127,225,242,239,110,128,1,198,245,242,108,128,2,165,101,2,75,139,75,159,225,226,235,232,225,243,233,225,238,227,249,242,233,236,236,233,99,128,4,225,227,249,242,233,236,236,233,99,128,4,85,232,229,227,249,242,233,236,236,233,99,128,4,95,101,151,0,101,75,233,75,252,76,30,77,4,77,66,77,99,77,111,77,134,77,187,79,43,79,101,79,203,80,63,80,198,81,17,81,48,81,110,81,163,82,98,82,231,82,251,83,39,83,130,97,2,75,239,75,246,227,245,244,101,128,0,233,242,244,104,128,38,65,98,3,76,4,76,13,76,23,229,238,231,225,236,105,128,9,143,239,240,239,237,239,230,111,128,49,28,242,229,246,101,128,1,21,99,5,76,42,76,115,76,129,76,161,76,250,97,2,76,48,76,109,238,228,242,97,3,76,59,76,66,76,77,228,229,246,97,128,9,13,231,245,234,225,242,225,244,105,128,10,141,246,239,247,229,236,243,233,231,110,2,76,91,76,98,228,229,246,97,128,9,69,231,245,234,225,242,225,244,105,128,10,197,242,239,110,128,1,27,229,228,233,236,236,225,226,242,229,246,101,128,30,29,104,2,76,135,76,146,225,242,237,229,238,233,225,110,128,5,101,249,233,247,238,225,242,237,229,238,233,225,110,128,5,135,233,242,99,2,76,169,76,174,236,101,128,36,212,245,237,230,236,229,120,134,0,234,76,195,76,203,76,211,76,222,76,230,76,242,225,227,245,244,101,128,30,191,226,229,236,239,119,128,30,25,228,239,244,226,229,236,239,119,128,30,199,231,242,225,246,101,128,30,193,232,239,239,235,225,226,239,246,101,128,30,195,244,233,236,228,101,128,30,197,249,242,233,236,236,233,99,128,4,84,100,4,77,14,77,24,77,30,77,40,226,236,231,242,225,246,101,128,2,5,229,246,97,128,9,15,233,229,242,229,243,233,115,128,0,235,239,116,130,1,23,77,49,77,58,225,227,227,229,238,116,128,1,23,226,229,236,239,119,128,30,185,101,2,77,72,77,83,231,245,242,237,245,235,232,105,128,10,15,237,225,244,242,225,231,245,242,237,245,235,232,105,128,10,71,230,227,249,242,233,236,236,233,99,128,4,68,103,2,77,117,77,124,242,225,246,101,128,0,232,245,234,225,242,225,244,105,128,10,143,104,4,77,144,77,155,77,166,77,176,225,242,237,229,238,233,225,110,128,5,103,226,239,240,239,237,239,230,111,128,49,29,233,242,225,231,225,238,97,128,48,72,239,239,235,225,226,239,246,101,128,30,187,105,4,77,197,77,208,79,10,79,25,226,239,240,239,237,239,230,111,128,49,31,231,232,116,142,0,56,77,242,77,251,78,5,78,35,78,42,78,80,78,105,78,150,78,184,78,196,78,207,78,240,78,248,79,3,225,242,225,226,233,99,128,6,104,226,229,238,231,225,236,105,128,9,238,227,233,242,227,236,101,129,36,103,78,16,233,238,246,229,242,243,229,243,225,238,243,243,229,242,233,102,128,39,145,228,229,246,97,128,9,110,229,229,110,2,78,50,78,59,227,233,242,227,236,101,128,36,113,112,2,78,65,78,72,225,242,229,110,128,36,133,229,242,233,239,100,128,36,153,231,117,2,78,87,78,96,234,225,242,225,244,105,128,10,238,242,237,245,235,232,105,128,10,110,104,2,78,111,78,137,97,2,78,117,78,128,227,235,225,242,225,226,233,99,128,6,104,238,231,250,232,239,117,128,48,40,238,239,244,229,226,229,225,237,229,100,128,38,107,105,2,78,156,78,174,228,229,239,231,242,225,240,232,233,227,240,225,242,229,110,128,50,39,238,230,229,242,233,239,114,128,32,136,237,239,238,239,243,240,225,227,101,128,255,24,239,236,228,243,244,249,236,101,128,247,56,112,2,78,213,78,220,225,242,229,110,128,36,123,229,114,2,78,227,78,233,233,239,100,128,36,143,243,233,225,110,128,6,248,242,239,237,225,110,128,33,119,243,245,240,229,242,233,239,114,128,32,120,244,232,225,105,128,14,88,238,246,229,242,244,229,228,226,242,229,246,101,128,2,7,239,244,233,230,233,229,228,227,249,242,233,236,236,233,99,128,4,101,107,2,79,49,79,73,225,244,225,235,225,238,97,129,48,168,79,61,232,225,236,230,247,233,228,244,104,128,255,116,111,2,79,79,79,94,238,235,225,242,231,245,242,237,245,235,232,105,128,10,116,242,229,225,110,128,49,84,108,3,79,109,79,120,79,181,227,249,242,233,236,236,233,99,128,4,59,101,2,79,126,79,133,237,229,238,116,128,34,8,246,229,110,3,79,143,79,152,79,173,227,233,242,227,236,101,128,36,106,112,2,79,158,79,165,225,242,229,110,128,36,126,229,242,233,239,100,128,36,146,242,239,237,225,110,128,33,122,236,233,240,243,233,115,129,32,38,79,192,246,229,242,244,233,227,225,108,128,34,238,109,5,79,215,79,243,79,254,80,18,80,29,225,227,242,239,110,130,1,19,79,227,79,235,225,227,245,244,101,128,30,23,231,242,225,246,101,128,30,21,227,249,242,233,236,236,233,99,128,4,60,228,225,243,104,129,32,20,80,7,246,229,242,244,233,227,225,108,128,254,49,239,238,239,243,240,225,227,101,128,255,69,112,2,80,35,80,55,232,225,243,233,243,237,225,242,235,225,242,237,229,238,233,225,110,128,5,91,244,249,243,229,116,128,34,5,110,6,80,77,80,88,80,99,80,143,80,175,80,190,226,239,240,239,237,239,230,111,128,49,35,227,249,242,233,236,236,233,99,128,4,61,100,2,80,105,80,124,225,243,104,129,32,19,80,113,246,229,242,244,233,227,225,108,128,254,50,229,243,227,229,238,228,229,242,227,249,242,233,236,236,233,99,128,4,163,103,130,1,75,80,151,80,162,226,239,240,239,237,239,230,111,128,49,37,232,229,227,249,242,233,236,236,233,99,128,4,165,232,239,239,235,227,249,242,233,236,236,233,99,128,4,200,243,240,225,227,101,128,32,2,111,3,80,206,80,214,80,223,231,239,238,229,107,128,1,25,235,239,242,229,225,110,128,49,83,240,229,110,130,2,91,80,233,80,242,227,236,239,243,229,100,128,2,154,242,229,246,229,242,243,229,100,130,2,92,81,1,81,10,227,236,239,243,229,100,128,2,94,232,239,239,107,128,2,93,112,2,81,23,81,30,225,242,229,110,128,36,160,243,233,236,239,110,129,3,181,81,40,244,239,238,239,115,128,3,173,241,117,2,81,55,81,99,225,108,130,0,61,81,64,81,76,237,239,238,239,243,240,225,227,101,128,255,29,115,2,81,82,81,89,237,225,236,108,128,254,102,245,240,229,242,233,239,114,128,32,124,233,246,225,236,229,238,227,101,128,34,97,114,3,81,118,81,129,81,140,226,239,240,239,237,239,230,111,128,49,38,227,249,242,233,236,236,233,99,128,4,64,229,246,229,242,243,229,100,129,2,88,81,152,227,249,242,233,236,236,233,99,128,4,77,115,6,81,177,81,188,81,208,82,33,82,78,82,88,227,249,242,233,236,236,233,99,128,4,65,228,229,243,227,229,238,228,229,242,227,249,242,233,236,236,233,99,128,4,171,104,132,2,131,81,220,81,227,82,2,82,17,227,245,242,108,128,2,134,239,242,116,2,81,235,81,242,228,229,246,97,128,9,14,246,239,247,229,236,243,233,231,238,228,229,246,97,128,9,70,242,229,246,229,242,243,229,228,236,239,239,112,128,1,170,243,241,245,225,244,242,229,246,229,242,243,229,100,128,2,133,237,225,236,108,2,82,42,82,53,232,233,242,225,231,225,238,97,128,48,71,235,225,244,225,235,225,238,97,129,48,167,82,66,232,225,236,230,247,233,228,244,104,128,255,106,244,233,237,225,244,229,100,128,33,46,245,240,229,242,233,239,114,128,246,236,116,5,82,110,82,136,82,140,82,157,82,223,97,130,3,183,82,118,82,128,242,237,229,238,233,225,110,128,5,104,244,239,238,239,115,128,3,174,104,128,0,240,233,236,228,101,129,30,189,82,149,226,229,236,239,119,128,30,27,238,225,232,244,97,3,82,169,82,201,82,210,230,239,245,235,104,2,82,179,82,188,232,229,226,242,229,119,128,5,145,236,229,230,244,232,229,226,242,229,119,128,5,145,232,229,226,242,229,119,128,5,145,236,229,230,244,232,229,226,242,229,119,128,5,145,245,242,238,229,100,128,1,221,117,2,82,237,82,246,235,239,242,229,225,110,128,49,97,242,111,128,32,172,246,239,247,229,236,243,233,231,110,3,83,11,83,21,83,28,226,229,238,231,225,236,105,128,9,199,228,229,246,97,128,9,71,231,245,234,225,242,225,244,105,128,10,199,120,2,83,45,83,118,227,236,225,109,132,0,33,83,60,83,71,83,98,83,110,225,242,237,229,238,233,225,110,128,5,92,100,2,83,77,83,82,226,108,128,32,60,239,247,110,129,0,161,83,90,243,237,225,236,108,128,247,161,237,239,238,239,243,240,225,227,101,128,255,1,243,237,225,236,108,128,247,33,233,243,244,229,238,244,233,225,108,128,34,3,250,104,131,2,146,83,141,83,160,83,171,99,2,83,147,83,154,225,242,239,110,128,1,239,245,242,108,128,2,147,242,229,246,229,242,243,229,100,128,1,185,244,225,233,108,128,1,186,102,140,0,102,83,206,84,32,84,43,84,52,84,64,84,167,84,183,86,191,86,204,86,230,88,107,88,115,97,4,83,216,83,223,83,234,83,245,228,229,246,97,128,9,94,231,245,242,237,245,235,232,105,128,10,94,232,242,229,238,232,229,233,116,128,33,9,244,232,97,3,83,255,84,8,84,20,225,242,225,226,233,99,128,6,78,236,239,247,225,242,225,226,233,99,128,6,78,244,225,238,225,242,225,226,233,99,128,6,75,226,239,240,239,237,239,230,111,128,49,8,227,233,242,227,236,101,128,36,213,228,239,244,225,227,227,229,238,116,128,30,31,101,3,84,72,84,150,84,160,104,4,84,82,84,105,84,119,84,135,225,114,2,84,89,84,96,225,226,233,99,128,6,65,237,229,238,233,225,110,128,5,134,230,233,238,225,236,225,242,225,226,233,99,128,254,210,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,211,237,229,228,233,225,236,225,242,225,226,233,99,128,254,212,233,227,239,240,244,233,99,128,3,229,237,225,236,101,128,38,64,102,130,251,0,84,175,84,179,105,128,251,3,108,128,251,4,105,136,251,1,84,203,84,243,84,254,85,20,85,142,85,159,85,167,85,180,230,244,229,229,110,2,84,213,84,222,227,233,242,227,236,101,128,36,110,112,2,84,228,84,235,225,242,229,110,128,36,130,229,242,233,239,100,128,36,150,231,245,242,229,228,225,243,104,128,32,18,236,236,229,100,2,85,7,85,13,226,239,120,128,37,160,242,229,227,116,128,37,172,238,225,108,5,85,34,85,73,85,90,85,107,85,123,235,225,102,130,5,218,85,44,85,64,228,225,231,229,243,104,129,251,58,85,55,232,229,226,242,229,119,128,251,58,232,229,226,242,229,119,128,5,218,237,229,109,129,5,221,85,81,232,229,226,242,229,119,128,5,221,238,245,110,129,5,223,85,98,232,229,226,242,229,119,128,5,223,240,101,129,5,227,85,114,232,229,226,242,229,119,128,5,227,244,243,225,228,105,129,5,229,85,133,232,229,226,242,229,119,128,5,229,242,243,244,244,239,238,229,227,232,233,238,229,243,101,128,2,201,243,232,229,249,101,128,37,201,244,225,227,249,242,233,236,236,233,99,128,4,115,246,101,142,0,53,85,213,85,222,85,232,86,6,86,13,86,23,86,48,86,75,86,109,86,121,86,132,86,165,86,173,86,184,225,242,225,226,233,99,128,6,101,226,229,238,231,225,236,105,128,9,235,227,233,242,227,236,101,129,36,100,85,243,233,238,246,229,242,243,229,243,225,238,243,243,229,242,233,102,128,39,142,228,229,246,97,128,9,107,229,233,231,232,244,232,115,128,33,93,231,117,2,86,30,86,39,234,225,242,225,244,105,128,10,235,242,237,245,235,232,105,128,10,107,232,97,2,86,55,86,66,227,235,225,242,225,226,233,99,128,6,101,238,231,250,232,239,117,128,48,37,105,2,86,81,86,99,228,229,239,231,242,225,240,232,233,227,240,225,242,229,110,128,50,36,238,230,229,242,233,239,114,128,32,133,237,239,238,239,243,240,225,227,101,128,255,21,239,236,228,243,244,249,236,101,128,247,53,112,2,86,138,86,145,225,242,229,110,128,36,120,229,114,2,86,152,86,158,233,239,100,128,36,140,243,233,225,110,128,6,245,242,239,237,225,110,128,33,116,243,245,240,229,242,233,239,114,128,32,117,244,232,225,105,128,14,85,108,129,251,2,86,197,239,242,233,110,128,1,146,109,2,86,210,86,221,239,238,239,243,240,225,227,101,128,255,70,243,241,245,225,242,101,128,51,153,111,4,86,240,87,6,87,18,87,25,230,97,2,86,247,86,255,238,244,232,225,105,128,14,31,244,232,225,105,128,14,29,238,231,237,225,238,244,232,225,105,128,14,79,242,225,236,108,128,34,0,245,114,142,0,52,87,58,87,67,87,77,87,107,87,114,87,139,87,166,87,200,87,212,87,231,87,242,88,19,88,27,88,38,225,242,225,226,233,99,128,6,100,226,229,238,231,225,236,105,128,9,234,227,233,242,227,236,101,129,36,99,87,88,233,238,246,229,242,243,229,243,225,238,243,243,229,242,233,102,128,39,141,228,229,246,97,128,9,106,231,117,2,87,121,87,130,234,225,242,225,244,105,128,10,234,242,237,245,235,232,105,128,10,106,232,97,2,87,146,87,157,227,235,225,242,225,226,233,99,128,6,100,238,231,250,232,239,117,128,48,36,105,2,87,172,87,190,228,229,239,231,242,225,240,232,233,227,240,225,242,229,110,128,50,35,238,230,229,242,233,239,114,128,32,132,237,239,238,239,243,240,225,227,101,128,255,20,238,245,237,229,242,225,244,239,242,226,229,238,231,225,236,105,128,9,247,239,236,228,243,244,249,236,101,128,247,52,112,2,87,248,87,255,225,242,229,110,128,36,119,229,114,2,88,6,88,12,233,239,100,128,36,139,243,233,225,110,128,6,244,242,239,237,225,110,128,33,115,243,245,240,229,242,233,239,114,128,32,116,116,2,88,44,88,82,229,229,110,2,88,52,88,61,227,233,242,227,236,101,128,36,109,112,2,88,67,88,74,225,242,229,110,128,36,129,229,242,233,239,100,128,36,149,104,2,88,88,88,93,225,105,128,14,84,244,239,238,229,227,232,233,238,229,243,101,128,2,203,240,225,242,229,110,128,36,161,242,97,2,88,122,88,130,227,244,233,239,110,128,32,68,238,99,128,32,163,103,144,0,103,88,171,89,117,89,140,89,201,89,218,90,139,91,132,91,217,91,230,92,88,92,113,92,141,92,163,93,108,93,130,93,232,97,9,88,191,88,201,88,208,88,215,89,23,89,48,89,59,89,70,89,104,226,229,238,231,225,236,105,128,9,151,227,245,244,101,128,1,245,228,229,246,97,128,9,23,102,4,88,225,88,234,88,248,89,8,225,242,225,226,233,99,128,6,175,230,233,238,225,236,225,242,225,226,233,99,128,251,147,233,238,233,244,233,225,236,225,242,225,226,233,99,128,251,148,237,229,228,233,225,236,225,242,225,226,233,99,128,251,149,231,117,2,89,30,89,39,234,225,242,225,244,105,128,10,151,242,237,245,235,232,105,128,10,23,232,233,242,225,231,225,238,97,128,48,76,235,225,244,225,235,225,238,97,128,48,172,237,237,97,130,3,179,89,80,89,93,236,225,244,233,238,243,237,225,236,108,128,2,99,243,245,240,229,242,233,239,114,128,2,224,238,231,233,225,227,239,240,244,233,99,128,3,235,98,2,89,123,89,133,239,240,239,237,239,230,111,128,49,13,242,229,246,101,128,1,31,99,4,89,150,89,157,89,166,89,188,225,242,239,110,128,1,231,229,228,233,236,236,97,128,1,35,233,242,99,2,89,174,89,179,236,101,128,36,214,245,237,230,236,229,120,128,1,29,239,237,237,225,225,227,227,229,238,116,128,1,35,228,239,116,129,1,33,89,209,225,227,227,229,238,116,128,1,33,101,6,89,232,89,243,89,254,90,9,90,28,90,130,227,249,242,233,236,236,233,99,128,4,51,232,233,242,225,231,225,238,97,128,48,82,235,225,244,225,235,225,238,97,128,48,178,239,237,229,244,242,233,227,225,236,236,249,229,241,245,225,108,128,34,81,114,3,90,36,90,85,90,95,229,243,104,3,90,46,90,61,90,70,225,227,227,229,238,244,232,229,226,242,229,119,128,5,156,232,229,226,242,229,119,128,5,243,237,245,241,228,225,237,232,229,226,242,229,119,128,5,157,237,225,238,228,226,236,115,128,0,223,243,232,225,249,233,109,2,90,106,90,121,225,227,227,229,238,244,232,229,226,242,229,119,128,5,158,232,229,226,242,229,119,128,5,244,244,225,237,225,242,107,128,48,19,104,5,90,151,91,28,91,91,91,116,91,122,97,4,90,161,90,171,90,194,90,219,226,229,238,231,225,236,105,128,9,152,100,2,90,177,90,188,225,242,237,229,238,233,225,110,128,5,114,229,246,97,128,9,24,231,117,2,90,201,90,210,234,225,242,225,244,105,128,10,152,242,237,245,235,232,105,128,10,24,233,110,4,90,230,90,239,90,253,91,13,225,242,225,226,233,99,128,6,58,230,233,238,225,236,225,242,225,226,233,99,128,254,206,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,207,237,229,228,233,225,236,225,242,225,226,233,99,128,254,208,101,3,91,36,91,57,91,74,237,233,228,228,236,229,232,239,239,235,227,249,242,233,236,236,233,99,128,4,149,243,244,242,239,235,229,227,249,242,233,236,236,233,99,128,4,147,245,240,244,245,242,238,227,249,242,233,236,236,233,99,128,4,145,232,97,2,91,98,91,105,228,229,246,97,128,9,90,231,245,242,237,245,235,232,105,128,10,90,239,239,107,128,2,96,250,243,241,245,225,242,101,128,51,147,105,3,91,140,91,151,91,162,232,233,242,225,231,225,238,97,128,48,78,235,225,244,225,235,225,238,97,128,48,174,109,2,91,168,91,179,225,242,237,229,238,233,225,110,128,5,99,229,108,130,5,210,91,188,91,208,228,225,231,229,243,104,129,251,50,91,199,232,229,226,242,229,119,128,251,50,232,229,226,242,229,119,128,5,210,234,229,227,249,242,233,236,236,233,99,128,4,83,236,239,244,244,225,108,2,91,241,92,2,233,238,246,229,242,244,229,228,243,244,242,239,235,101,128,1,190,243,244,239,112,132,2,148,92,17,92,28,92,34,92,66,233,238,246,229,242,244,229,100,128,2,150,237,239,100,128,2,192,242,229,246,229,242,243,229,100,130,2,149,92,49,92,55,237,239,100,128,2,193,243,245,240,229,242,233,239,114,128,2,228,243,244,242,239,235,101,129,2,161,92,77,242,229,246,229,242,243,229,100,128,2,162,109,2,92,94,92,102,225,227,242,239,110,128,30,33,239,238,239,243,240,225,227,101,128,255,71,111,2,92,119,92,130,232,233,242,225,231,225,238,97,128,48,84,235,225,244,225,235,225,238,97,128,48,180,240,97,2,92,148,92,154,242,229,110,128,36,162,243,241,245,225,242,101,128,51,172,114,2,92,169,93,10,97,2,92,175,92,183,228,233,229,238,116,128,34,7,246,101,134,0,96,92,200,92,211,92,228,92,235,92,244,93,0,226,229,236,239,247,227,237,98,128,3,22,99,2,92,217,92,222,237,98,128,3,0,239,237,98,128,3,0,228,229,246,97,128,9,83,236,239,247,237,239,100,128,2,206,237,239,238,239,243,240,225,227,101,128,255,64,244,239,238,229,227,237,98,128,3,64,229,225,244,229,114,132,0,62,93,26,93,45,93,57,93,100,229,241,245,225,108,129,34,101,93,36,239,242,236,229,243,115,128,34,219,237,239,238,239,243,240,225,227,101,128,255,30,111,2,93,63,93,89,114,2,93,69,93,82,229,241,245,233,246,225,236,229,238,116,128,34,115,236,229,243,115,128,34,119,246,229,242,229,241,245,225,108,128,34,103,243,237,225,236,108,128,254,101,115,2,93,114,93,122,227,242,233,240,116,128,2,97,244,242,239,235,101,128,1,229,117,4,93,140,93,151,93,208,93,219,232,233,242,225,231,225,238,97,128,48,80,233,108,2,93,158,93,183,236,229,237,239,116,2,93,168,93,175,236,229,230,116,128,0,171,242,233,231,232,116,128,0,187,243,233,238,231,108,2,93,193,93,200,236,229,230,116,128,32,57,242,233,231,232,116,128,32,58,235,225,244,225,235,225,238,97,128,48,176,242,225,237,245,243,241,245,225,242,101,128,51,24,249,243,241,245,225,242,101,128,51,201,104,144,0,104,94,22,96,164,96,199,96,236,97,20,98,164,98,184,99,149,99,161,99,173,100,241,100,249,101,4,101,13,101,93,101,97,97,13,94,50,94,89,94,99,94,129,94,154,94,232,94,244,95,13,95,28,95,57,95,70,95,128,95,137,97,2,94,56,94,75,226,235,232,225,243,233,225,238,227,249,242,233,236,236,233,99,128,4,169,236,244,239,238,229,225,242,225,226,233,99,128,6,193,226,229,238,231,225,236,105,128,9,185,228,101,2,94,106,94,124,243,227,229,238,228,229,242,227,249,242,233,236,236,233,99,128,4,179,246,97,128,9,57,231,117,2,94,136,94,145,234,225,242,225,244,105,128,10,185,242,237,245,235,232,105,128,10,57,104,4,94,164,94,173,94,187,94,217,225,242,225,226,233,99,128,6,45,230,233,238,225,236,225,242,225,226,233,99,128,254,162,105,2,94,193,94,208,238,233,244,233,225,236,225,242,225,226,233,99,128,254,163,242,225,231,225,238,97,128,48,111,237,229,228,233,225,236,225,242,225,226,233,99,128,254,164,233,244,245,243,241,245,225,242,101,128,51,42,235,225,244,225,235,225,238,97,129,48,207,95,1,232,225,236,230,247,233,228,244,104,128,255,138,236,225,238,244,231,245,242,237,245,235,232,105,128,10,77,237,250,97,2,95,36,95,45,225,242,225,226,233,99,128,6,33,236,239,247,225,242,225,226,233,99,128,6,33,238,231,245,236,230,233,236,236,229,114,128,49,100,114,2,95,76,95,92,228,243,233,231,238,227,249,242,233,236,236,233,99,128,4,74,240,239,239,110,2,95,101,95,114,236,229,230,244,226,225,242,226,245,112,128,33,188,242,233,231,232,244,226,225,242,226,245,112,128,33,192,243,241,245,225,242,101,128,51,202,244,225,102,3,95,147,95,239,96,74,240,225,244,225,104,134,5,178,95,167,95,172,95,186,95,195,95,210,95,226,177,54,128,5,178,50,2,95,178,95,182,51,128,5,178,102,128,5,178,232,229,226,242,229,119,128,5,178,238,225,242,242,239,247,232,229,226,242,229,119,128,5,178,241,245,225,242,244,229,242,232,229,226,242,229,119,128,5,178,247,233,228,229,232,229,226,242,229,119,128,5,178,241,225,237,225,244,115,135,5,179,96,6,96,11,96,16,96,21,96,30,96,45,96,61,177,98,128,5,179,178,56,128,5,179,179,52,128,5,179,232,229,226,242,229,119,128,5,179,238,225,242,242,239,247,232,229,226,242,229,119,128,5,179,241,245,225,242,244,229,242,232,229,226,242,229,119,128,5,179,247,233,228,229,232,229,226,242,229,119,128,5,179,243,229,231,239,108,135,5,177,96,96,96,101,96,106,96,111,96,120,96,135,96,151,177,55,128,5,177,178,52,128,5,177,179,48,128,5,177,232,229,226,242,229,119,128,5,177,238,225,242,242,239,247,232,229,226,242,229,119,128,5,177,241,245,225,242,244,229,242,232,229,226,242,229,119,128,5,177,247,233,228,229,232,229,226,242,229,119,128,5,177,98,3,96,172,96,177,96,187,225,114,128,1,39,239,240,239,237,239,230,111,128,49,15,242,229,246,229,226,229,236,239,119,128,30,43,99,2,96,205,96,214,229,228,233,236,236,97,128,30,41,233,242,99,2,96,222,96,227,236,101,128,36,215,245,237,230,236,229,120,128,1,37,100,2,96,242,96,252,233,229,242,229,243,233,115,128,30,39,239,116,2,97,3,97,12,225,227,227,229,238,116,128,30,35,226,229,236,239,119,128,30,37,101,136,5,212,97,40,97,73,97,93,98,66,98,82,98,127,98,136,98,149,225,242,116,129,38,101,97,48,243,245,233,116,2,97,57,97,65,226,236,225,227,107,128,38,101,247,232,233,244,101,128,38,97,228,225,231,229,243,104,129,251,52,97,84,232,229,226,242,229,119,128,251,52,104,6,97,107,97,135,97,143,97,193,97,239,98,32,97,2,97,113,97,127,236,244,239,238,229,225,242,225,226,233,99,128,6,193,242,225,226,233,99,128,6,71,229,226,242,229,119,128,5,212,230,233,238,225,236,97,2,97,154,97,185,236,116,2,97,161,97,173,239,238,229,225,242,225,226,233,99,128,251,167,244,247,239,225,242,225,226,233,99,128,254,234,242,225,226,233,99,128,254,234,232,225,237,250,225,225,226,239,246,101,2,97,208,97,222,230,233,238,225,236,225,242,225,226,233,99,128,251,165,233,243,239,236,225,244,229,228,225,242,225,226,233,99,128,251,164,105,2,97,245,98,23,238,233,244,233,225,236,97,2,98,1,98,15,236,244,239,238,229,225,242,225,226,233,99,128,251,168,242,225,226,233,99,128,254,235,242,225,231,225,238,97,128,48,120,237,229,228,233,225,236,97,2,98,44,98,58,236,244,239,238,229,225,242,225,226,233,99,128,251,169,242,225,226,233,99,128,254,236,233,243,229,233,229,242,225,243,241,245,225,242,101,128,51,123,107,2,98,88,98,112,225,244,225,235,225,238,97,129,48,216,98,100,232,225,236,230,247,233,228,244,104,128,255,141,245,244,225,225,242,245,243,241,245,225,242,101,128,51,54,238,231,232,239,239,107,128,2,103,242,245,244,245,243,241,245,225,242,101,128,51,57,116,129,5,215,98,155,232,229,226,242,229,119,128,5,215,232,239,239,107,129,2,102,98,173,243,245,240,229,242,233,239,114,128,2,177,105,4,98,194,99,23,99,34,99,59,229,245,104,4,98,206,98,241,99,0,99,9,97,2,98,212,98,227,227,233,242,227,236,229,235,239,242,229,225,110,128,50,123,240,225,242,229,238,235,239,242,229,225,110,128,50,27,227,233,242,227,236,229,235,239,242,229,225,110,128,50,109,235,239,242,229,225,110,128,49,78,240,225,242,229,238,235,239,242,229,225,110,128,50,13,232,233,242,225,231,225,238,97,128,48,114,235,225,244,225,235,225,238,97,129,48,210,99,47,232,225,236,230,247,233,228,244,104,128,255,139,242,233,113,134,5,180,99,77,99,82,99,96,99,105,99,120,99,136,177,52,128,5,180,50,2,99,88,99,92,49,128,5,180,100,128,5,180,232,229,226,242,229,119,128,5,180,238,225,242,242,239,247,232,229,226,242,229,119,128,5,180,241,245,225,242,244,229,242,232,229,226,242,229,119,128,5,180,247,233,228,229,232,229,226,242,229,119,128,5,180,236,233,238,229,226,229,236,239,119,128,30,150,237,239,238,239,243,240,225,227,101,128,255,72,111,9,99,193,99,204,99,228,99,253,100,85,100,98,100,184,100,224,100,235,225,242,237,229,238,233,225,110,128,5,112,232,105,2,99,211,99,219,240,244,232,225,105,128,14,43,242,225,231,225,238,97,128,48,123,235,225,244,225,235,225,238,97,129,48,219,99,241,232,225,236,230,247,233,228,244,104,128,255,142,236,225,109,135,5,185,100,17,100,22,100,27,100,32,100,41,100,56,100,72,177,57,128,5,185,178,54,128,5,185,179,50,128,5,185,232,229,226,242,229,119,128,5,185,238,225,242,242,239,247,232,229,226,242,229,119,128,5,185,241,245,225,242,244,229,242,232,229,226,242,229,119,128,5,185,247,233,228,229,232,229,226,242,229,119,128,5,185,238,239,235,232,245,235,244,232,225,105,128,14,46,111,2,100,104,100,174,107,4,100,114,100,126,100,132,100,154,225,226,239,246,229,227,239,237,98,128,3,9,227,237,98,128,3,9,240,225,236,225,244,225,236,233,250,229,228,226,229,236,239,247,227,237,98,128,3,33,242,229,244,242,239,230,236,229,248,226,229,236,239,247,227,237,98,128,3,34,238,243,241,245,225,242,101,128,51,66,114,2,100,190,100,217,105,2,100,196,100,205,227,239,240,244,233,99,128,3,233,250,239,238,244,225,236,226,225,114,128,32,21,238,227,237,98,128,3,27,244,243,240,242,233,238,231,115,128,38,104,245,243,101,128,35,2,240,225,242,229,110,128,36,163,243,245,240,229,242,233,239,114,128,2,176,244,245,242,238,229,100,128,2,101,117,4,101,23,101,34,101,47,101,72,232,233,242,225,231,225,238,97,128,48,117,233,233,244,239,243,241,245,225,242,101,128,51,51,235,225,244,225,235,225,238,97,129,48,213,101,60,232,225,236,230,247,233,228,244,104,128,255,140,238,231,225,242,245,237,236,225,245,116,129,2,221,101,87,227,237,98,128,3,11,118,128,1,149,249,240,232,229,110,132,0,45,101,113,101,124,101,136,101,159,233,238,230,229,242,233,239,114,128,246,229,237,239,238,239,243,240,225,227,101,128,255,13,115,2,101,142,101,149,237,225,236,108,128,254,99,245,240,229,242,233,239,114,128,246,230,244,247,111,128,32,16,105,149,0,105,101,211,101,234,102,12,102,59,105,197,106,61,106,98,106,125,107,31,107,35,107,73,107,95,107,179,108,88,108,163,108,171,108,184,109,15,109,72,109,100,109,144,225,99,2,101,218,101,224,245,244,101,128,0,237,249,242,233,236,236,233,99,128,4,79,98,3,101,242,101,251,102,5,229,238,231,225,236,105,128,9,135,239,240,239,237,239,230,111,128,49,39,242,229,246,101,128,1,45,99,3,102,20,102,27,102,49,225,242,239,110,128,1,208,233,242,99,2,102,35,102,40,236,101,128,36,216,245,237,230,236,229,120,128,0,238,249,242,233,236,236,233,99,128,4,86,100,4,102,69,102,79,105,154,105,187,226,236,231,242,225,246,101,128,2,9,101,2,102,85,105,149,239,231,242,225,240,104,7,102,106,102,120,102,133,105,62,105,93,105,106,105,118,229,225,242,244,232,227,233,242,227,236,101,128,50,143,230,233,242,229,227,233,242,227,236,101,128,50,139,233,99,14,102,164,102,180,103,23,103,77,103,143,103,172,103,188,103,245,104,38,104,50,104,77,104,144,105,26,105,55,225,236,236,233,225,238,227,229,240,225,242,229,110,128,50,63,99,4,102,190,102,201,102,215,102,222,225,236,236,240,225,242,229,110,128,50,58,229,238,244,242,229,227,233,242,227,236,101,128,50,165,236,239,243,101,128,48,6,111,3,102,230,102,245,103,9,237,237,97,129,48,1,102,238,236,229,230,116,128,255,100,238,231,242,225,244,245,236,225,244,233,239,238,240,225,242,229,110,128,50,55,242,242,229,227,244,227,233,242,227,236,101,128,50,163,101,3,103,31,103,43,103,60,225,242,244,232,240,225,242,229,110,128,50,47,238,244,229,242,240,242,233,243,229,240,225,242,229,110,128,50,61,248,227,229,236,236,229,238,244,227,233,242,227,236,101,128,50,157,102,2,103,83,103,98,229,243,244,233,246,225,236,240,225,242,229,110,128,50,64,105,2,103,104,103,133,238,225,238,227,233,225,108,2,103,116,103,125,227,233,242,227,236,101,128,50,150,240,225,242,229,110,128,50,54,242,229,240,225,242,229,110,128,50,43,104,2,103,149,103,160,225,246,229,240,225,242,229,110,128,50,50,233,231,232,227,233,242,227,236,101,128,50,164,233,244,229,242,225,244,233,239,238,237,225,242,107,128,48,5,108,3,103,196,103,222,103,234,225,226,239,114,2,103,205,103,214,227,233,242,227,236,101,128,50,152,240,225,242,229,110,128,50,56,229,230,244,227,233,242,227,236,101,128,50,167,239,247,227,233,242,227,236,101,128,50,166,109,2,103,251,104,27,101])
.concat([2,104,1,104,16,228,233,227,233,238,229,227,233,242,227,236,101,128,50,169,244,225,236,240,225,242,229,110,128,50,46,239,239,238,240,225,242,229,110,128,50,42,238,225,237,229,240,225,242,229,110,128,50,52,112,2,104,56,104,64,229,242,233,239,100,128,48,2,242,233,238,244,227,233,242,227,236,101,128,50,158,114,2,104,83,104,131,101,3,104,91,104,102,104,117,225,227,232,240,225,242,229,110,128,50,67,240,242,229,243,229,238,244,240,225,242,229,110,128,50,57,243,239,245,242,227,229,240,225,242,229,110,128,50,62,233,231,232,244,227,233,242,227,236,101,128,50,168,115,5,104,156,104,185,104,199,104,224,104,252,101,2,104,162,104,175,227,242,229,244,227,233,242,227,236,101,128,50,153,236,230,240,225,242,229,110,128,50,66,239,227,233,229,244,249,240,225,242,229,110,128,50,51,112,2,104,205,104,211,225,227,101,128,48,0,229,227,233,225,236,240,225,242,229,110,128,50,53,116,2,104,230,104,241,239,227,235,240,225,242,229,110,128,50,49,245,228,249,240,225,242,229,110,128,50,59,117,2,105,2,105,11,238,240,225,242,229,110,128,50,48,240,229,242,246,233,243,229,240,225,242,229,110,128,50,60,119,2,105,32,105,44,225,244,229,242,240,225,242,229,110,128,50,44,239,239,228,240,225,242,229,110,128,50,45,250,229,242,111,128,48,7,109,2,105,68,105,81,229,244,225,236,227,233,242,227,236,101,128,50,142,239,239,238,227,233,242,227,236,101,128,50,138,238,225,237,229,227,233,242,227,236,101,128,50,148,243,245,238,227,233,242,227,236,101,128,50,144,119,2,105,124,105,137,225,244,229,242,227,233,242,227,236,101,128,50,140,239,239,228,227,233,242,227,236,101,128,50,141,246,97,128,9,7,233,229,242,229,243,233,115,130,0,239,105,168,105,176,225,227,245,244,101,128,30,47,227,249,242,233,236,236,233,99,128,4,229,239,244,226,229,236,239,119,128,30,203,101,3,105,205,105,221,105,232,226,242,229,246,229,227,249,242,233,236,236,233,99,128,4,215,227,249,242,233,236,236,233,99,128,4,53,245,238,103,4,105,244,106,23,106,38,106,47,97,2,105,250,106,9,227,233,242,227,236,229,235,239,242,229,225,110,128,50,117,240,225,242,229,238,235,239,242,229,225,110,128,50,21,227,233,242,227,236,229,235,239,242,229,225,110,128,50,103,235,239,242,229,225,110,128,49,71,240,225,242,229,238,235,239,242,229,225,110,128,50,7,103,2,106,67,106,74,242,225,246,101,128,0,236,117,2,106,80,106,89,234,225,242,225,244,105,128,10,135,242,237,245,235,232,105,128,10,7,104,2,106,104,106,114,233,242,225,231,225,238,97,128,48,68,239,239,235,225,226,239,246,101,128,30,201,105,8,106,143,106,153,106,164,106,171,106,196,106,212,106,227,106,243,226,229,238,231,225,236,105,128,9,136,227,249,242,233,236,236,233,99,128,4,56,228,229,246,97,128,9,8,231,117,2,106,178,106,187,234,225,242,225,244,105,128,10,136,242,237,245,235,232,105,128,10,8,237,225,244,242,225,231,245,242,237,245,235,232,105,128,10,64,238,246,229,242,244,229,228,226,242,229,246,101,128,2,11,243,232,239,242,244,227,249,242,233,236,236,233,99,128,4,57,246,239,247,229,236,243,233,231,110,3,107,3,107,13,107,20,226,229,238,231,225,236,105,128,9,192,228,229,246,97,128,9,64,231,245,234,225,242,225,244,105,128,10,192,106,128,1,51,107,2,107,41,107,65,225,244,225,235,225,238,97,129,48,164,107,53,232,225,236,230,247,233,228,244,104,128,255,114,239,242,229,225,110,128,49,99,108,2,107,79,107,84,228,101,128,2,220,245,249,232,229,226,242,229,119,128,5,172,109,2,107,101,107,168,97,3,107,109,107,129,107,154,227,242,239,110,129,1,43,107,118,227,249,242,233,236,236,233,99,128,4,227,231,229,239,242,225,240,240,242,239,248,233,237,225,244,229,236,249,229,241,245,225,108,128,34,83,244,242,225,231,245,242,237,245,235,232,105,128,10,63,239,238,239,243,240,225,227,101,128,255,73,110,5,107,191,107,201,107,210,107,222,108,50,227,242,229,237,229,238,116,128,34,6,230,233,238,233,244,121,128,34,30,233,225,242,237,229,238,233,225,110,128,5,107,116,2,107,228,108,40,101,2,107,234,108,29,231,242,225,108,131,34,43,107,247,108,9,108,14,98,2,107,253,108,5,239,244,244,239,109,128,35,33,116,128,35,33,229,120,128,248,245,116,2,108,20,108,25,239,112,128,35,32,112,128,35,32,242,243,229,227,244,233,239,110,128,34,41,233,243,241,245,225,242,101,128,51,5,118,3,108,58,108,67,108,76,226,245,236,236,229,116,128,37,216,227,233,242,227,236,101,128,37,217,243,237,233,236,229,230,225,227,101,128,38,59,111,3,108,96,108,107,108,115,227,249,242,233,236,236,233,99,128,4,81,231,239,238,229,107,128,1,47,244,97,131,3,185,108,126,108,147,108,155,228,233,229,242,229,243,233,115,129,3,202,108,139,244,239,238,239,115,128,3,144,236,225,244,233,110,128,2,105,244,239,238,239,115,128,3,175,240,225,242,229,110,128,36,164,242,233,231,245,242,237,245,235,232,105,128,10,114,115,4,108,194,108,239,108,253,109,5,237,225,236,108,2,108,203,108,214,232,233,242,225,231,225,238,97,128,48,67,235,225,244,225,235,225,238,97,129,48,163,108,227,232,225,236,230,247,233,228,244,104,128,255,104,243,232,225,242,226,229,238,231,225,236,105,128,9,250,244,242,239,235,101,128,2,104,245,240,229,242,233,239,114,128,246,237,116,2,109,21,109,55,229,242,225,244,233,239,110,2,109,33,109,44,232,233,242,225,231,225,238,97,128,48,157,235,225,244,225,235,225,238,97,128,48,253,233,236,228,101,129,1,41,109,64,226,229,236,239,119,128,30,45,117,2,109,78,109,89,226,239,240,239,237,239,230,111,128,49,41,227,249,242,233,236,236,233,99,128,4,78,246,239,247,229,236,243,233,231,110,3,109,116,109,126,109,133,226,229,238,231,225,236,105,128,9,191,228,229,246,97,128,9,63,231,245,234,225,242,225,244,105,128,10,191,250,232,233,244,243,97,2,109,155,109,166,227,249,242,233,236,236,233,99,128,4,117,228,226,236,231,242,225,246,229,227,249,242,233,236,236,233,99,128,4,119,106,138,0,106,109,209,110,16,110,27,110,77,110,93,110,206,111,19,111,24,111,36,111,44,97,4,109,219,109,230,109,240,109,247,225,242,237,229,238,233,225,110,128,5,113,226,229,238,231,225,236,105,128,9,156,228,229,246,97,128,9,28,231,117,2,109,254,110,7,234,225,242,225,244,105,128,10,156,242,237,245,235,232,105,128,10,28,226,239,240,239,237,239,230,111,128,49,16,99,3,110,35,110,42,110,64,225,242,239,110,128,1,240,233,242,99,2,110,50,110,55,236,101,128,36,217,245,237,230,236,229,120,128,1,53,242,239,243,243,229,228,244,225,233,108,128,2,157,228,239,244,236,229,243,243,243,244,242,239,235,101,128,2,95,101,3,110,101,110,112,110,177,227,249,242,233,236,236,233,99,128,4,88,229,109,4,110,123,110,132,110,146,110,162,225,242,225,226,233,99,128,6,44,230,233,238,225,236,225,242,225,226,233,99,128,254,158,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,159,237,229,228,233,225,236,225,242,225,226,233,99,128,254,160,104,2,110,183,110,192,225,242,225,226,233,99,128,6,152,230,233,238,225,236,225,242,225,226,233,99,128,251,139,104,2,110,212,111,6,97,3,110,220,110,230,110,237,226,229,238,231,225,236,105,128,9,157,228,229,246,97,128,9,29,231,117,2,110,244,110,253,234,225,242,225,244,105,128,10,157,242,237,245,235,232,105,128,10,29,229,232,225,242,237,229,238,233,225,110,128,5,123,233,115,128,48,4,237,239,238,239,243,240,225,227,101,128,255,74,240,225,242,229,110,128,36,165,243,245,240,229,242,233,239,114,128,2,178,107,146,0,107,111,95,113,184,113,195,114,1,114,12,114,102,114,116,115,224,116,164,116,177,116,203,116,252,117,134,117,156,117,169,117,192,117,234,117,244,97,12,111,121,111,153,111,175,111,205,112,63,112,88,112,118,112,143,112,249,113,7,113,130,113,159,98,2,111,127,111,144,225,243,232,235,233,242,227,249,242,233,236,236,233,99,128,4,161,229,238,231,225,236,105,128,9,149,99,2,111,159,111,165,245,244,101,128,30,49,249,242,233,236,236,233,99,128,4,58,228,101,2,111,182,111,200,243,227,229,238,228,229,242,227,249,242,233,236,236,233,99,128,4,155,246,97,128,9,21,102,135,5,219,111,223,111,232,111,252,112,10,112,19,112,35,112,50,225,242,225,226,233,99,128,6,67,228,225,231,229,243,104,129,251,59,111,243,232,229,226,242,229,119,128,251,59,230,233,238,225,236,225,242,225,226,233,99,128,254,218,232,229,226,242,229,119,128,5,219,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,219,237,229,228,233,225,236,225,242,225,226,233,99,128,254,220,242,225,230,229,232,229,226,242,229,119,128,251,77,231,117,2,112,70,112,79,234,225,242,225,244,105,128,10,149,242,237,245,235,232,105,128,10,21,104,2,112,94,112,104,233,242,225,231,225,238,97,128,48,75,239,239,235,227,249,242,233,236,236,233,99,128,4,196,235,225,244,225,235,225,238,97,129,48,171,112,131,232,225,236,230,247,233,228,244,104,128,255,118,112,2,112,149,112,170,240,97,129,3,186,112,156,243,249,237,226,239,236,231,242,229,229,107,128,3,240,249,229,239,245,110,3,112,182,112,196,112,230,237,233,229,245,237,235,239,242,229,225,110,128,49,113,112,2,112,202,112,217,232,233,229,245,240,232,235,239,242,229,225,110,128,49,132,233,229,245,240,235,239,242,229,225,110,128,49,120,243,243,225,238,231,240,233,229,245,240,235,239,242,229,225,110,128,49,121,242,239,242,233,233,243,241,245,225,242,101,128,51,13,115,5,113,19,113,63,113,78,113,86,113,114,232,233,228,225,225,245,244,111,2,113,32,113,41,225,242,225,226,233,99,128,6,64,238,239,243,233,228,229,226,229,225,242,233,238,231,225,242,225,226,233,99,128,6,64,237,225,236,236,235,225,244,225,235,225,238,97,128,48,245,241,245,225,242,101,128,51,132,242,97,2,113,93,113,102,225,242,225,226,233,99,128,6,80,244,225,238,225,242,225,226,233,99,128,6,77,244,242,239,235,229,227,249,242,233,236,236,233,99,128,4,159,244,225,232,233,242,225,240,242,239,236,239,238,231,237,225,242,235,232,225,236,230,247,233,228,244,104,128,255,112,246,229,242,244,233,227,225,236,243,244,242,239,235,229,227,249,242,233,236,236,233,99,128,4,157,226,239,240,239,237,239,230,111,128,49,14,99,4,113,205,113,227,113,236,113,244,97,2,113,211,113,221,236,243,241,245,225,242,101,128,51,137,242,239,110,128,1,233,229,228,233,236,236,97,128,1,55,233,242,227,236,101,128,36,218,239,237,237,225,225,227,227,229,238,116,128,1,55,228,239,244,226,229,236,239,119,128,30,51,101,4,114,22,114,49,114,74,114,86,104,2,114,28,114,39,225,242,237,229,238,233,225,110,128,5,132,233,242,225,231,225,238,97,128,48,81,235,225,244,225,235,225,238,97,129,48,177,114,62,232,225,236,230,247,233,228,244,104,128,255,121,238,225,242,237,229,238,233,225,110,128,5,111,243,237,225,236,236,235,225,244,225,235,225,238,97,128,48,246,231,242,229,229,238,236,225,238,228,233,99,128,1,56,104,6,114,130,115,3,115,14,115,39,115,126,115,214,97,5,114,142,114,152,114,163,114,170,114,195,226,229,238,231,225,236,105,128,9,150,227,249,242,233,236,236,233,99,128,4,69,228,229,246,97,128,9,22,231,117,2,114,177,114,186,234,225,242,225,244,105,128,10,150,242,237,245,235,232,105,128,10,22,104,4,114,205,114,214,114,228,114,244,225,242,225,226,233,99,128,6,46,230,233,238,225,236,225,242,225,226,233,99,128,254,166,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,167,237,229,228,233,225,236,225,242,225,226,233,99,128,254,168,229,233,227,239,240,244,233,99,128,3,231,232,97,2,115,21,115,28,228,229,246,97,128,9,89,231,245,242,237,245,235,232,105,128,10,89,233,229,245,235,104,4,115,53,115,88,115,103,115,112,97,2,115,59,115,74,227,233,242,227,236,229,235,239,242,229,225,110,128,50,120,240,225,242,229,238,235,239,242,229,225,110,128,50,24,227,233,242,227,236,229,235,239,242,229,225,110,128,50,106,235,239,242,229,225,110,128,49,75,240,225,242,229,238,235,239,242,229,225,110,128,50,10,111,4,115,136,115,185,115,195,115,200,235,104,4,115,147,115,156,115,165,115,175,225,233,244,232,225,105,128,14,2,239,238,244,232,225,105,128,14,5,245,225,244,244,232,225,105,128,14,3,247,225,233,244,232,225,105,128,14,4,237,245,244,244,232,225,105,128,14,91,239,107,128,1,153,242,225,235,232,225,238,231,244,232,225,105,128,14,6,250,243,241,245,225,242,101,128,51,145,105,4,115,234,115,245,116,14,116,63,232,233,242,225,231,225,238,97,128,48,77,235,225,244,225,235,225,238,97,129,48,173,116,2,232,225,236,230,247,233,228,244,104,128,255,119,242,111,3,116,23,116,38,116,54,231,245,242,225,237,245,243,241,245,225,242,101,128,51,21,237,229,229,244,239,242,245,243,241,245,225,242,101,128,51,22,243,241,245,225,242,101,128,51,20,249,229,239,107,5,116,78,116,113,116,128,116,137,116,151,97,2,116,84,116,99,227,233,242,227,236,229,235,239,242,229,225,110,128,50,110,240,225,242,229,238,235,239,242,229,225,110,128,50,14,227,233,242,227,236,229,235,239,242,229,225,110,128,50,96,235,239,242,229,225,110,128,49,49,240,225,242,229,238,235,239,242,229,225,110,128,50,0,243,233,239,243,235,239,242,229,225,110,128,49,51,234,229,227,249,242,233,236,236,233,99,128,4,92,108,2,116,183,116,194,233,238,229,226,229,236,239,119,128,30,53,243,241,245,225,242,101,128,51,152,109,3,116,211,116,225,116,236,227,245,226,229,228,243,241,245,225,242,101,128,51,166,239,238,239,243,240,225,227,101,128,255,75,243,241,245,225,242,229,228,243,241,245,225,242,101,128,51,162,111,5,117,8,117,34,117,72,117,84,117,98,104,2,117,14,117,24,233,242,225,231,225,238,97,128,48,83,237,243,241,245,225,242,101,128,51,192,235,97,2,117,41,117,49,233,244,232,225,105,128,14,1,244,225,235,225,238,97,129,48,179,117,60,232,225,236,230,247,233,228,244,104,128,255,122,239,240,239,243,241,245,225,242,101,128,51,30,240,240,225,227,249,242,233,236,236,233,99,128,4,129,114,2,117,104,117,124,229,225,238,243,244,225,238,228,225,242,228,243,249,237,226,239,108,128,50,127,239,238,233,243,227,237,98,128,3,67,240,97,2,117,141,117,147,242,229,110,128,36,166,243,241,245,225,242,101,128,51,170,243,233,227,249,242,233,236,236,233,99,128,4,111,116,2,117,175,117,184,243,241,245,225,242,101,128,51,207,245,242,238,229,100,128,2,158,117,2,117,198,117,209,232,233,242,225,231,225,238,97,128,48,79,235,225,244,225,235,225,238,97,129,48,175,117,222,232,225,236,230,247,233,228,244,104,128,255,120,246,243,241,245,225,242,101,128,51,184,247,243,241,245,225,242,101,128,51,190,108,146,0,108,118,38,120,65,120,94,120,160,120,198,121,94,121,103,121,119,121,143,121,161,122,23,122,64,122,199,122,207,122,240,122,249,123,1,123,63,97,7,118,54,118,64,118,71,118,78,118,103,118,119,120,53,226,229,238,231,225,236,105,128,9,178,227,245,244,101,128,1,58,228,229,246,97,128,9,50,231,117,2,118,85,118,94,234,225,242,225,244,105,128,10,178,242,237,245,235,232,105,128,10,50,235,235,232,225,238,231,249,225,239,244,232,225,105,128,14,69,109,10,118,141,119,80,119,97,119,135,119,149,119,168,119,184,119,204,119,224,119,247,97,2,118,147,119,72,236,229,102,4,118,159,118,173,119,9,119,26,230,233,238,225,236,225,242,225,226,233,99,128,254,252,232,225,237,250,97,2,118,183,118,224,225,226,239,246,101,2,118,193,118,207,230,233,238,225,236,225,242,225,226,233,99,128,254,248,233,243,239,236,225,244,229,228,225,242,225,226,233,99,128,254,247,226,229,236,239,119,2,118,234,118,248,230,233,238,225,236,225,242,225,226,233,99,128,254,250,233,243,239,236,225,244,229,228,225,242,225,226,233,99,128,254,249,233,243,239,236,225,244,229,228,225,242,225,226,233,99,128,254,251,237,225,228,228,225,225,226,239,246,101,2,119,41,119,55,230,233,238,225,236,225,242,225,226,233,99,128,254,246,233,243,239,236,225,244,229,228,225,242,225,226,233,99,128,254,245,242,225,226,233,99,128,6,68,226,228,97,129,3,187,119,88,243,244,242,239,235,101,128,1,155,229,100,130,5,220,119,106,119,126,228,225,231,229,243,104,129,251,60,119,117,232,229,226,242,229,119,128,251,60,232,229,226,242,229,119,128,5,220,230,233,238,225,236,225,242,225,226,233,99,128,254,222,232,225,232,233,238,233,244,233,225,236,225,242,225,226,233,99,128,252,202,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,223,234,229,229,237,233,238,233,244,233,225,236,225,242,225,226,233,99,128,252,201,235,232,225,232,233,238,233,244,233,225,236,225,242,225,226,233,99,128,252,203,236,225,237,232,229,232,233,243,239,236,225,244,229,228,225,242,225,226,233,99,128,253,242,237,101,2,119,254,120,11,228,233,225,236,225,242,225,226,233,99,128,254,224,229,109,2,120,18,120,37,232,225,232,233,238,233,244,233,225,236,225,242,225,226,233,99,128,253,136,233,238,233,244,233,225,236,225,242,225,226,233,99,128,252,204,242,231,229,227,233,242,227,236,101,128,37,239,98,3,120,73,120,78,120,84,225,114,128,1,154,229,236,116,128,2,108,239,240,239,237,239,230,111,128,49,12,99,4,120,104,120,111,120,120,120,147,225,242,239,110,128,1,62,229,228,233,236,236,97,128,1,60,233,242,99,2,120,128,120,133,236,101,128,36,219,245,237,230,236,229,248,226,229,236,239,119,128,30,61,239,237,237,225,225,227,227,229,238,116,128,1,60,228,239,116,130,1,64,120,170,120,179,225,227,227,229,238,116,128,1,64,226,229,236,239,119,129,30,55,120,189,237,225,227,242,239,110,128,30,57,101,3,120,206,120,244,121,89,230,116,2,120,213,120,229,225,238,231,236,229,225,226,239,246,229,227,237,98,128,3,26,244,225,227,235,226,229,236,239,247,227,237,98,128,3,24,243,115,132,0,60,121,1,121,23,121,35,121,81,229,241,245,225,108,129,34,100,121,11,239,242,231,242,229,225,244,229,114,128,34,218,237,239,238,239,243,240,225,227,101,128,255,28,111,2,121,41,121,70,114,2,121,47,121,60,229,241,245,233,246,225,236,229,238,116,128,34,114,231,242,229,225,244,229,114,128,34,118,246,229,242,229,241,245,225,108,128,34,102,243,237,225,236,108,128,254,100,250,104,128,2,110,230,226,236,239,227,107,128,37,140,232,239,239,235,242,229,244,242,239,230,236,229,120,128,2,109,105,2,121,125,121,130,242,97,128,32,164,247,238,225,242,237,229,238,233,225,110,128,5,108,106,129,1,201,121,149,229,227,249,242,233,236,236,233,99,128,4,89,108,132,246,192,121,173,121,197,121,208,121,217,97,2,121,179,121,186,228,229,246,97,128,9,51,231,245,234,225,242,225,244,105,128,10,179,233,238,229,226,229,236,239,119,128,30,59,236,225,228,229,246,97,128,9,52,246,239,227,225,236,233,99,3,121,231,121,241,121,248,226,229,238,231,225,236,105,128,9,225,228,229,246,97,128,9,97,246,239,247,229,236,243,233,231,110,2,122,6,122,16,226,229,238,231,225,236,105,128,9,227,228,229,246,97,128,9,99,109,3,122,31,122,44,122,55,233,228,228,236,229,244,233,236,228,101,128,2,107,239,238,239,243,240,225,227,101,128,255,76,243,241,245,225,242,101,128,51,208,111,6,122,78,122,90,122,132,122,143,122,149,122,191,227,232,245,236,225,244,232,225,105,128,14,44,231,233,227,225,108,3,122,102,122,108,122,127,225,238,100,128,34,39,238,239,116,129,0,172,122,116,242,229,246,229,242,243,229,100,128,35,16,239,114,128,34,40,236,233,238,231,244,232,225,105,128,14,37,238,231,115,128,1,127,247,236,233,238,101,2,122,159,122,182,99,2,122,165,122,177,229,238,244,229,242,236,233,238,101,128,254,78,237,98,128,3,50,228,225,243,232,229,100,128,254,77,250,229,238,231,101,128,37,202,240,225,242,229,110,128,36,167,115,3,122,215,122,222,122,230,236,225,243,104,128,1,66,241,245,225,242,101,128,33,19,245,240,229,242,233,239,114,128,246,238,244,243,232,225,228,101,128,37,145,245,244,232,225,105,128,14,38,246,239,227,225,236,233,99,3,123,15,123,25,123,32,226,229,238,231,225,236,105,128,9,140,228,229,246,97,128,9,12,246,239,247,229,236,243,233,231,110,2,123,46,123,56,226,229,238,231,225,236,105,128,9,226,228,229,246,97,128,9,98,248,243,241,245,225,242,101,128,51,211,109,144,0,109,123,109,125,218,125,243,126,14,126,39,127,92,127,114,128,169,128,199,128,248,129,99,129,121,129,146,129,155,130,182,130,210,97,12,123,135,123,145,123,209,123,216,123,241,124,33,125,125,125,150,125,155,125,169,125,181,125,186,226,229,238,231,225,236,105,128,9,174,99,2,123,151,123,203,242,239,110,132,0,175,123,165,123,176,123,182,123,191,226,229,236,239,247,227,237,98,128,3,49,227,237,98,128,3,4,236,239,247,237,239,100,128,2,205,237,239,238,239,243,240,225,227,101,128,255,227,245,244,101,128,30,63,228,229,246,97,128,9,46,231,117,2,123,223,123,232,234,225,242,225,244,105,128,10,174,242,237,245,235,232,105,128,10,46,104,2,123,247,124,23,225,240,225,235,104,2,124,1,124,10,232,229,226,242,229,119,128,5,164,236,229,230,244,232,229,226,242,229,119,128,5,164,233,242,225,231,225,238,97,128,48,126,105,5,124,45,124,114,124,177,124,207,125,113,227,232,225,244,244,225,247,97,3,124,60,124,91,124,98,236,239,119,2,124,68,124,79,236,229,230,244,244,232,225,105,128,248,149,242,233,231,232,244,244,232,225,105,128,248,148,244,232,225,105,128,14,75,245,240,240,229,242,236,229,230,244,244,232,225,105,128,248,147,229,107,3,124,123,124,154,124,161,236,239,119,2,124,131,124,142,236,229,230,244,244,232,225,105,128,248,140,242,233,231,232,244,244,232,225,105,128,248,139,244,232,225,105,128,14,72,245,240,240,229,242,236,229,230,244,244,232,225,105,128,248,138,232,225,238,225,235,225,116,2,124,189,124,200,236,229,230,244,244,232,225,105,128,248,132,244,232,225,105,128,14,49,116,3,124,215,124,243,125,50,225,233,235,232,117,2,124,225,124,236,236,229,230,244,244,232,225,105,128,248,137,244,232,225,105,128,14,71,232,111,3,124,252,125,27,125,34,236,239,119,2,125,4,125,15,236,229,230,244,244,232,225,105,128,248,143,242,233,231,232,244,244,232,225,105,128,248,142,244,232,225,105,128,14,73,245,240,240,229,242,236,229,230,244,244,232,225,105,128,248,141,242,105,3,125,59,125,90,125,97,236,239,119,2,125,67,125,78,236,229,230,244,244,232,225,105,128,248,146,242,233,231,232,244,244,232,225,105,128,248,145,244,232,225,105,128,14,74,245,240,240,229,242,236,229,230,244,244,232,225,105,128,248,144,249,225,237,239,235,244,232,225,105,128,14,70,235,225,244,225,235,225,238,97,129,48,222,125,138,232,225,236,230,247,233,228,244,104,128,255,143,236,101,128,38,66,238,243,249,239,238,243,241,245,225,242,101,128,51,71,241,225,230,232,229,226,242,229,119,128,5,190,242,115,128,38,66,115,2,125,192,125,210,239,242,225,227,233,242,227,236,229,232,229,226,242,229,119,128,5,175,241,245,225,242,101,128,51,131,98,2,125,224,125,234,239,240,239,237,239,230,111,128,49,7,243,241,245,225,242,101,128,51,212,99,2,125,249,126,1,233,242,227,236,101,128,36,220,245,226,229,228,243,241,245,225,242,101,128,51,165,228,239,116,2,126,22,126,31,225,227,227,229,238,116,128,30,65,226,229,236,239,119,128,30,67,101,7,126,55,126,182,126,193,126,208,126,233,127,14,127,26,101,2,126,61,126,169,109,4,126,71,126,80,126,94,126,110,225,242,225,226,233,99,128,6,69,230,233,238,225,236,225,242,225,226,233,99,128,254,226,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,227,237,101,2,126,117,126,130,228,233,225,236,225,242,225,226,233,99,128,254,228,229,237,105,2,126,138,126,153,238,233,244,233,225,236,225,242,225,226,233,99,128,252,209,243,239,236,225,244,229,228,225,242,225,226,233,99,128,252,72,244,239,242,245,243,241,245,225,242,101,128,51,77,232,233,242,225,231,225,238,97,128,48,129,233,250,233,229,242,225,243,241,245,225,242,101,128,51,126,235,225,244,225,235,225,238,97,129,48,225,126,221,232,225,236,230,247,233,228,244,104,128,255,146,109,130,5,222,126,241,127,5,228,225,231,229,243,104,129,251,62,126,252,232,229,226,242,229,119,128,251,62,232,229,226,242,229,119,128,5,222,238,225,242,237,229,238,233,225,110,128,5,116,242,235,232,97,3,127,37,127,46,127,79,232,229,226,242,229,119,128,5,165,235,229,230,245,236,97,2,127,57,127,66,232,229,226,242,229,119,128,5,166,236,229,230,244,232,229,226,242,229,119,128,5,166,236,229,230,244,232,229,226,242,229,119,128,5,165,104,2,127,98,127,104,239,239,107,128,2,113,250,243,241,245,225,242,101,128,51,146,105,6,127,128,127,165,128,46,128,57,128,82,128,139,228,100,2,127,135,127,160,236,229,228,239,244,235,225,244,225,235,225,238,225,232,225,236,230,247,233,228,244,104,128,255,101,239,116,128,0,183,229,245,109,5,127,179,127,214,127,229,127,238,128,33,97,2,127,185,127,200,227,233,242,227,236,229,235,239,242,229,225,110,128,50,114,240,225,242,229,238,235,239,242,229,225,110,128,50,18,227,233,242,227,236,229,235,239,242,229,225,110,128,50,100,235,239,242,229,225,110,128,49,65,112,2,127,244,128,20,97,2,127,250,128,8,238,243,233,239,243,235,239,242,229,225,110,128,49,112,242,229,238,235,239,242,229,225,110,128,50,4,233,229,245,240,235,239,242,229,225,110,128,49,110,243,233,239,243,235,239,242,229,225,110,128,49,111,232,233,242,225,231,225,238,97,128,48,127,235,225,244,225,235,225,238,97,129,48,223,128,70,232,225,236,230,247,233,228,244,104,128,255,144,238,117,2,128,89,128,134,115,132,34,18,128,101,128,112,128,121,128,127,226,229,236,239,247,227,237,98,128,3,32,227,233,242,227,236,101,128,34,150,237,239,100,128,2,215,240,236,245,115,128,34,19,244,101,128,32,50,242,105,2,128,146,128,160,226,225,225,242,245,243,241,245,225,242,101,128,51,74,243,241,245,225,242,101,128,51,73,108,2,128,175,128,190,239,238,231,236,229,231,244,245,242,238,229,100,128,2,112,243,241,245,225,242,101,128,51,150,109,3,128,207,128,221,128,232,227,245,226,229,228,243,241,245,225,242,101,128,51,163,239,238,239,243,240,225,227,101,128,255,77,243,241,245,225,242,229,228,243,241,245,225,242,101,128,51,159,111,5,129,4,129,30,129,55,129,65,129,74,104,2,129,10,129,20,233,242,225,231,225,238,97,128,48,130,237,243,241,245,225,242,101,128,51,193,235,225,244,225,235,225,238,97,129,48,226,129,43,232,225,236,230,247,233,228,244,104,128,255,147,236,243,241,245,225,242,101,128,51,214,237,225,244,232,225,105,128,14,33,246,229,242,243,243,241,245,225,242,101,129,51,167,129,89,228,243,241,245,225,242,101,128,51,168,240,97,2,129,106,129,112,242,229,110,128,36,168,243,241,245,225,242,101,128,51,171,115,2,129,127,129,136,243,241,245,225,242,101,128,51,179,245,240,229,242,233,239,114,128,246,239,244,245,242,238,229,100,128,2,111,117,141,0,181,129,185,129,189,129,199,129,223,129,233,129,255,130,10,130,35,130,58,130,68,130,98,130,162,130,172,49,128,0,181,225,243,241,245,225,242,101,128,51,130,227,104,2,129,206,129,216,231,242,229,225,244,229,114,128,34,107,236,229,243,115,128,34,106,230,243,241,245,225,242,101,128,51,140,103,2,129,239,129,246,242,229,229,107,128,3,188,243,241,245,225,242,101,128,51,141,232,233,242,225,231,225,238,97,128,48,128,235,225,244,225,235,225,238,97,129,48,224,130,23,232,225,236,230,247,233,228,244,104,128,255,145,108,2,130,41,130,50,243,241,245,225,242,101,128,51,149,244,233,240,236,121,128,0,215,237,243,241,245,225,242,101,128,51,155,238,225,104,2,130,76,130,85,232,229,226,242,229,119,128,5,163,236,229,230,244,232,229,226,242,229,119,128,5,163,115,2,130,104,130,153,233,99,3,130,113,130,130,130,141,225,236,238,239,244,101,129,38,106,130,124,228,226,108,128,38,107,230,236,225,244,243,233,231,110,128,38,109,243,232,225,242,240,243,233,231,110,128,38,111,243,241,245,225,242,101,128,51,178,246,243,241,245,225,242,101,128,51,182,247,243,241,245,225,242,101,128,51,188,118,2,130,188,130,201,237,229,231,225,243,241,245,225,242,101,128,51,185,243,241,245,225,242,101,128,51,183,119,2,130,216,130,229,237,229,231,225,243,241,245,225,242,101,128,51,191,243,241,245,225,242,101,128,51,189,110,150,0,110,131,30,131,164,131,188,131,254,132,23,132,81,132,91,132,158,132,201,134,235,134,253,135,22,135,53,135,79,135,144,137,126,137,134,137,159,137,167,138,135,138,145,138,155,97,8,131,48,131,68,131,75,131,82,131,107,131,118,131,143,131,155,98,2,131,54,131,63,229,238,231,225,236,105,128,9,168,236,97,128,34,7,227,245,244,101,128,1,68,228,229,246,97,128,9,40,231,117,2,131,89,131,98,234,225,242,225,244,105,128,10,168,242,237,245,235,232,105,128,10,40,232,233,242,225,231,225,238,97,128,48,106,235,225,244,225,235,225,238,97,129,48,202,131,131,232,225,236,230,247,233,228,244,104,128,255,133,240,239,243,244,242,239,240,232,101,128,1,73,243,241,245,225,242,101,128,51,129,98,2,131,170,131,180,239,240,239,237,239,230,111,128,49,11,243,240,225,227,101,128,0,160,99,4,131,198,131,205,131,214,131,241,225,242,239,110,128,1,72,229,228,233,236,236,97,128,1,70,233,242,99,2,131,222,131,227,236,101,128,36,221,245,237,230,236,229,248,226,229,236,239,119,128,30,75,239,237,237,225,225,227,227,229,238,116,128,1,70,228,239,116,2,132,6,132,15,225,227,227,229,238,116,128,30,69,226,229,236,239,119,128,30,71,101,3,132,31,132,42,132,67,232,233,242,225,231,225,238,97,128,48,109,235,225,244,225,235,225,238,97,129,48,205,132,55,232,225,236,230,247,233,228,244,104,128,255,136,247,243,232,229,241,229,236,243,233,231,110,128,32,170,230,243,241,245,225,242,101,128,51,139,103,2,132,97,132,147,97,3,132,105,132,115,132,122,226,229,238,231,225,236,105,128,9,153,228,229,246,97,128,9,25,231,117,2,132,129,132,138,234,225,242,225,244,105,128,10,153,242,237,245,235,232,105,128,10,25,239,238,231,245,244,232,225,105,128,14,7,104,2,132,164,132,174,233,242,225,231,225,238,97,128,48,147,239,239,107,2,132,182,132,189,236,229,230,116,128,2,114,242,229,244,242,239,230,236,229,120,128,2,115,105,4,132,211,133,124,133,135,133,193,229,245,110,7,132,229,133,8,133,40,133,54,133,63,133,96,133,109,97,2,132,235,132,250,227,233,242,227,236,229,235,239,242,229,225,110,128,50,111,240,225,242,229,238,235,239,242,229,225,110,128,50,15,227,105,2,133,15,133,27,229,245,227,235,239,242,229,225,110,128,49,53,242,227,236,229,235,239,242,229,225,110,128,50,97,232,233,229,245,232,235,239,242,229,225,110,128,49,54,235,239,242,229,225,110,128,49,52,240,97,2,133,70,133,84,238,243,233,239,243,235,239,242,229,225,110,128,49,104,242,229,238,235,239,242,229,225,110,128,50,1,243,233,239,243,235,239,242,229,225,110,128,49,103,244,233,235,229,245,244,235,239,242,229,225,110,128,49,102,232,233,242,225,231,225,238,97,128,48,107,107,2,133,141,133,165,225,244,225,235,225,238,97,129,48,203,133,153,232,225,236,230,247,233,228,244,104,128,255,134,232,225,232,233,116,2,133,175,133,186,236,229,230,244,244,232,225,105,128,248,153,244,232,225,105,128,14,77,238,101,141,0,57,133,224,133,233,133,243,134,17,134,24,134,49,134,76,134,110,134,122,134,133,134,166,134,174,134,185,225,242,225,226,233,99,128,6,105,226,229,238,231,225,236,105,128,9,239,227,233,242,227,236,101,129,36,104,133,254,233,238,246,229,242,243,229,243,225,238,243,243,229,242,233,102,128,39,146,228,229,246,97,128,9,111,231,117,2,134,31,134,40,234,225,242,225,244,105,128,10,239,242,237,245,235,232,105,128,10,111,232,97,2,134,56,134,67,227,235,225,242,225,226,233,99,128,6,105,238,231,250,232,239,117,128,48,41,105,2,134,82,134,100,228,229,239,231,242,225,240,232,233,227,240,225,242,229,110,128,50,40,238,230,229,242,233,239,114,128,32,137,237,239,238,239,243,240,225,227,101,128,255,25,239,236,228,243,244,249,236,101,128,247,57,112,2,134,139,134,146,225,242,229,110,128,36,124,229,114,2,134,153,134,159,233,239,100,128,36,144,243,233,225,110,128,6,249,242,239,237,225,110,128,33,120,243,245,240,229,242,233,239,114,128,32,121,116,2,134,191,134,229,229,229,110,2,134,199,134,208,227,233,242,227,236,101,128,36,114,112,2,134,214,134,221,225,242,229,110,128,36,134,229,242,233,239,100,128,36,154,232,225,105,128,14,89,106,129,1,204,134,241,229,227,249,242,233,236,236,233,99,128,4,90,235,225,244,225,235,225,238,97,129,48,243,135,10,232,225,236,230,247,233,228,244,104,128,255,157,108,2,135,28,135,42,229,231,242,233,231,232,244,236,239,238,103,128,1,158,233,238,229,226,229,236,239,119,128,30,73,109,2,135,59,135,70,239,238,239,243,240,225,227,101,128,255,78,243,241,245,225,242,101,128,51,154,110,2,135,85,135,135,97,3,135,93,135,103,135,110,226,229,238,231,225,236,105,128,9,163,228,229,246,97,128,9,35,231,117,2,135,117,135,126,234,225,242,225,244,105,128,10,163,242,237,245,235,232,105,128,10,35,238,225,228,229,246,97,128,9,41,111,6,135,158,135,169,135,194,135,235,136,187,137,114,232,233,242,225,231,225,238,97,128,48,110,235,225,244,225,235,225,238,97,129,48,206,135,182,232,225,236,230,247,233,228,244,104,128,255,137,110,3,135,202,135,218,135,227,226,242,229,225,235,233,238,231,243,240,225,227,101,128,0,160,229,238,244,232,225,105,128,14,19,245,244,232,225,105,128,14,25,239,110,7,135,252,136,5,136,19,136,53,136,69,136,110,136,169,225,242,225,226,233,99,128,6,70,230,233,238,225,236,225,242,225,226,233,99,128,254,230,231,232,245,238,238,97,2,136,30,136,39,225,242,225,226,233,99,128,6,186,230,233,238,225,236,225,242,225,226,233,99,128,251,159,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,231,234,229,229,237,105,2,136,79,136,94,238,233,244,233,225,236,225,242,225,226,233,99,128,252,210,243,239,236,225,244,229,228,225,242,225,226,233,99,128,252,75,237,101,2,136,117,136,130,228,233,225,236,225,242,225,226,233,99,128,254,232,229,237,105,2,136,138,136,153,238,233,244,233,225,236,225,242,225,226,233,99,128,252,213,243,239,236,225,244,229,228,225,242,225,226,233,99,128,252,78,238,239,239,238,230,233,238,225,236,225,242,225,226,233,99,128,252,141,116,7,136,203,136,214,136,243,137,22,137,34,137,54,137,80,227,239,238,244,225,233,238,115,128,34,12,101,2,136,220,136,236,236,229,237,229,238,116,129,34,9,136,231,239,102,128,34,9,241,245,225,108,128,34,96,231,242,229,225,244,229,114,129,34,111,136,255,238,239,114,2,137,7,137,15,229,241,245,225,108,128,34,113,236,229,243,115,128,34,121,233,228,229,238,244,233,227,225,108,128,34,98,236,229,243,115,129,34,110,137,43,238,239,242,229,241,245,225,108,128,34,112,112,2,137,60,137,70,225,242,225,236,236,229,108,128,34,38,242,229,227,229,228,229,115,128,34,128,243,117,3,137,89,137,96,137,105,226,243,229,116,128,34,132,227,227,229,229,228,115,128,34,129,240,229,242,243,229,116,128,34,133,247,225,242,237,229,238,233,225,110,128,5,118,240,225,242,229,110,128,36,169,115,2,137,140,137,149,243,241,245,225,242,101,128,51,177,245,240,229,242,233,239,114,128,32,127,244,233,236,228,101,128,0,241,117,132,3,189,137,179,137,190,138,15,138,98,232,233,242,225,231,225,238,97,128,48,108,107,2,137,196,137,220,225,244,225,235,225,238,97,129,48,204,137,208,232,225,236,230,247,233,228,244,104,128,255,135,244,97,3,137,229,137,239,137,246,226,229,238,231,225,236,105,128,9,188,228,229,246,97,128,9,60,231,117,2,137,253,138,6,234,225,242,225,244,105,128,10,188,242,237,245,235,232,105,128,10,60,109,2,138,21,138,55,226,229,242,243,233,231,110,130,0,35,138,35,138,47,237,239,238,239,243,240,225,227,101,128,255,3,243,237,225,236,108,128,254,95,229,114,2,138,62,138,94,225,236,243,233,231,110,2,138,73,138,81,231,242,229,229,107,128,3,116,236,239,247,229,242,231,242,229,229,107,128,3,117,111,128,33,22,110,130,5,224,138,106,138,126,228,225,231,229,243,104,129,251,64,138,117,232,229,226,242,229,119,128,251,64,232,229,226,242,229,119,128,5,224,246,243,241,245,225,242,101,128,51,181,247,243,241,245,225,242,101,128,51,187,249,97,3,138,164,138,174,138,181,226,229,238,231,225,236,105,128,9,158,228,229,246,97,128,9,30,231,117,2,138,188,138,197,234,225,242,225,244,105,128,10,158,242,237,245,235,232,105,128,10,30,111,147,0,111,138,248,139,14,139,92,140,6,140,78,140,93,140,133,141,0,141,21,141,59,141,70,141,248,143,82,143,146,143,179,143,225,144,98,144,145,144,157,97,2,138,254,139,5,227,245,244,101,128,0,243,238,231,244,232,225,105,128,14,45,98,4,139,24,139,66,139,75,139,85,225,242,242,229,100,130,2,117,139,36,139,47,227,249,242,233,236,236,233,99,128,4,233,228,233,229,242,229,243,233,243,227,249,242,233,236,236,233,99,128,4,235,229,238,231,225,236,105,128,9,147,239,240,239,237,239,230,111,128,49,27,242,229,246,101,128,1,79,99,3,139,100,139,173,139,252,97,2,139,106,139,167,238,228,242,97,3,139,117,139,124,139,135,228,229,246,97,128,9,17,231,245,234,225,242,225,244,105,128,10,145,246,239,247,229,236,243,233,231,110,2,139,149,139,156,228,229,246,97,128,9,73,231,245,234,225,242,225,244,105,128,10,201,242,239,110,128,1,210,233,242,99,2,139,181,139,186,236,101,128,36,222,245,237,230,236,229,120,133,0,244,139,205,139,213,139,224,139,232,139,244,225,227,245,244,101,128,30,209,228,239,244,226,229,236,239,119,128,30,217,231,242,225,246,101,128,30,211,232,239,239,235,225,226,239,246,101,128,30,213,244,233,236,228,101,128,30,215,249,242,233,236,236,233,99,128,4,62,100,4,140,16,140,39,140,45,140,68,226,108,2,140,23,140,31,225,227,245,244,101,128,1,81,231,242,225,246,101,128,2,13,229,246,97,128,9,19,233,229,242,229,243,233,115,129,0,246,140,57,227,249,242,233,236,236,233,99,128,4,231,239,244,226,229,236,239,119,128,30,205,101,129,1,83,140,84,235,239,242,229,225,110,128,49,90,103,3,140,101,140,116,140,123,239,238,229,107,129,2,219,140,110,227,237,98,128,3,40,242,225,246,101,128,0,242,245,234,225,242,225,244,105,128,10,147,104,4,140,143,140,154,140,164,140,242,225,242,237,229,238,233,225,110,128,5,133,233,242,225,231,225,238,97,128,48,74,111,2,140,170,140,180,239,235,225,226,239,246,101,128,30,207,242,110,133,1,161,140,195,140,203,140,214,140,222,140,234,225,227,245,244,101,128,30,219,228,239,244,226,229,236,239,119,128,30,227,231,242,225,246,101,128,30,221,232,239,239,235,225,226,239,246,101,128,30,223,244,233,236,228,101,128,30,225,245,238,231,225,242,245,237,236,225,245,116,128,1,81,105,129,1,163,141,6,238,246,229,242,244,229,228,226,242,229,246,101,128,2,15,107,2,141,27,141,51,225,244,225,235,225,238,97,129,48,170,141,39,232,225,236,230,247,233,228,244,104,128,255,117,239,242,229,225,110,128,49,87,236,229,232,229,226,242,229,119,128,5,171,109,6,141,84,141,112,141,119,141,208,141,219,141,237,225,227,242,239,110,130,1,77,141,96,141,104,225,227,245,244,101,128,30,83,231,242,225,246,101,128,30,81,228,229,246,97,128,9,80,229,231,97,133,3,201,141,135,141,139,141,150,141,164,141,180,49,128,3,214,227,249,242,233,236,236,233,99,128,4,97,236,225,244,233,238,227,236,239,243,229,100,128,2,119,242,239,245,238,228,227,249,242,233,236,236,233,99,128,4,123,116,2,141,186,141,201,233,244,236,239,227,249,242,233,236,236,233,99,128,4,125,239,238,239,115,128,3,206,231,245,234,225,242,225,244,105,128,10,208,233,227,242,239,110,129,3,191,141,229,244,239,238,239,115,128,3,204,239,238,239,243,240,225,227,101,128,255,79,238,101,145,0,49,142,31,142,40,142,50,142,80,142,105,142,114,142,123,142,148,142,182,142,216,142,228,142,247,143,2,143,35,143,45,143,53,143,64,225,242,225,226,233,99,128,6,97,226,229,238,231,225,236,105,128,9,231,227,233,242,227,236,101,129,36,96,142,61,233,238,246,229,242,243,229,243,225,238,243,243,229,242,233,102,128,39,138,100,2,142,86,142,92,229,246,97,128,9,103,239,244,229,238,236,229,225,228,229,114,128,32,36,229,233,231,232,244,104,128,33,91,230,233,244,244,229,100,128,246,220,231,117,2,142,130,142,139,234,225,242,225,244,105,128,10,231,242,237,245,235,232,105,128,10,103,232,97,3,142,157,142,168,142,173,227,235,225,242,225,226,233,99,128,6,97,236,102,128,0,189,238,231,250,232,239,117,128,48,33,105,2,142,188,142,206,228,229,239,231,242,225,240,232,233,227,240,225,242,229,110,128,50,32,238,230,229,242,233,239,114,128,32,129,237,239,238,239,243,240,225,227,101,128,255,17,238,245,237,229,242,225,244,239,242,226,229,238,231,225,236,105,128,9,244,239,236,228,243,244,249,236,101,128,247,49,112,2,143,8,143,15,225,242,229,110,128,36,116,229,114,2,143,22,143,28,233,239,100,128,36,136,243,233,225,110,128,6,241,241,245,225,242,244,229,114,128,0,188,242,239,237,225,110,128,33,112,243,245,240,229,242,233,239,114,128,0,185,244,104,2,143,71,143,76,225,105,128,14,81,233,242,100,128,33,83,111,3,143,90,143,124,143,140,103,2,143,96,143,114,239,238,229,107,129,1,235,143,105,237,225,227,242,239,110,128,1,237,245,242,237,245,235,232,105,128,10,19,237,225,244,242,225,231,245,242,237,245,235,232,105,128,10,75,240,229,110,128,2,84,112,3,143,154,143,161,143,172,225,242,229,110,128,36,170,229,238,226,245,236,236,229,116,128,37,230,244,233,239,110,128,35,37,114,2,143,185,143,214,100,2,143,191,143,202,230,229,237,233,238,233,238,101,128,0,170,237,225,243,227,245,236,233,238,101,128,0,186,244,232,239,231,239,238,225,108,128,34,31,115,5,143,237,144,13,144,30,144,75,144,88,232,239,242,116,2,143,246,143,253,228,229,246,97,128,9])
.concat([18,246,239,247,229,236,243,233,231,238,228,229,246,97,128,9,74,236,225,243,104,129,0,248,144,22,225,227,245,244,101,128,1,255,237,225,236,108,2,144,39,144,50,232,233,242,225,231,225,238,97,128,48,73,235,225,244,225,235,225,238,97,129,48,169,144,63,232,225,236,230,247,233,228,244,104,128,255,107,244,242,239,235,229,225,227,245,244,101,128,1,255,245,240,229,242,233,239,114,128,246,240,116,2,144,104,144,115,227,249,242,233,236,236,233,99,128,4,127,233,236,228,101,130,0,245,144,126,144,134,225,227,245,244,101,128,30,77,228,233,229,242,229,243,233,115,128,30,79,245,226,239,240,239,237,239,230,111,128,49,33,118,2,144,163,144,244,229,114,2,144,170,144,236,236,233,238,101,131,32,62,144,183,144,206,144,229,99,2,144,189,144,201,229,238,244,229,242,236,233,238,101,128,254,74,237,98,128,3,5,100,2,144,212,144,220,225,243,232,229,100,128,254,73,226,236,247,225,246,121,128,254,76,247,225,246,121,128,254,75,243,227,239,242,101,128,0,175,239,247,229,236,243,233,231,110,3,145,3,145,13,145,20,226,229,238,231,225,236,105,128,9,203,228,229,246,97,128,9,75,231,245,234,225,242,225,244,105,128,10,203,112,145,0,112,145,69,147,197,147,208,147,217,147,229,149,154,149,164,150,156,151,175,152,9,152,35,152,166,152,174,153,76,153,134,153,162,153,172,97,14,145,99,145,131,145,141,145,148,145,155,145,203,145,214,145,228,145,239,146,30,146,44,147,56,147,95,147,185,97,2,145,105,145,117,237,240,243,243,241,245,225,242,101,128,51,128,243,229,238,244,239,243,241,245,225,242,101,128,51,43,226,229,238,231,225,236,105,128,9,170,227,245,244,101,128,30,85,228,229,246,97,128,9,42,103,2,145,161,145,179,101,2,145,167,145,174,228,239,247,110,128,33,223,245,112,128,33,222,117,2,145,185,145,194,234,225,242,225,244,105,128,10,170,242,237,245,235,232,105,128,10,42,232,233,242,225,231,225,238,97,128,48,113,233,249,225,238,238,239,233,244,232,225,105,128,14,47,235,225,244,225,235,225,238,97,128,48,209,108,2,145,245,146,14,225,244,225,236,233,250,225,244,233,239,238,227,249,242,233,236,236,233,227,227,237,98,128,4,132,239,227,232,235,225,227,249,242,233,236,236,233,99,128,4,192,238,243,233,239,243,235,239,242,229,225,110,128,49,127,114,3,146,52,146,73,147,45,97,2,146,58,146,66,231,242,225,240,104,128,0,182,236,236,229,108,128,34,37,229,110,2,146,80,146,190,236,229,230,116,136,0,40,146,103,146,118,146,123,146,128,146,139,146,151,146,174,146,179,225,236,244,239,238,229,225,242,225,226,233,99,128,253,62,226,116,128,248,237,229,120,128,248,236,233,238,230,229,242,233,239,114,128,32,141,237,239,238,239,243,240,225,227,101,128,255,8,115,2,146,157,146,164,237,225,236,108,128,254,89,245,240,229,242,233,239,114,128,32,125,244,112,128,248,235,246,229,242,244,233,227,225,108,128,254,53,242,233,231,232,116,136,0,41,146,214,146,229,146,234,146,239,146,250,147,6,147,29,147,34,225,236,244,239,238,229,225,242,225,226,233,99,128,253,63,226,116,128,248,248,229,120,128,248,247,233,238,230,229,242,233,239,114,128,32,142,237,239,238,239,243,240,225,227,101,128,255,9,115,2,147,12,147,19,237,225,236,108,128,254,90,245,240,229,242,233,239,114,128,32,126,244,112,128,248,246,246,229,242,244,233,227,225,108,128,254,54,244,233,225,236,228,233,230,102,128,34,2,115,3,147,64,147,75,147,87,229,241,232,229,226,242,229,119,128,5,192,232,244,225,232,229,226,242,229,119,128,5,153,241,245,225,242,101,128,51,169,244,225,104,134,5,183,147,113,147,127,147,132,147,141,147,156,147,172,49,2,147,119,147,123,49,128,5,183,100,128,5,183,178,97,128,5,183,232,229,226,242,229,119,128,5,183,238,225,242,242,239,247,232,229,226,242,229,119,128,5,183,241,245,225,242,244,229,242,232,229,226,242,229,119,128,5,183,247,233,228,229,232,229,226,242,229,119,128,5,183,250,229,242,232,229,226,242,229,119,128,5,161,226,239,240,239,237,239,230,111,128,49,6,227,233,242,227,236,101,128,36,223,228,239,244,225,227,227,229,238,116,128,30,87,101,137,5,228,147,251,148,6,148,26,148,38,148,58,148,160,148,171,148,192,149,147,227,249,242,233,236,236,233,99,128,4,63,228,225,231,229,243,104,129,251,68,148,17,232,229,226,242,229,119,128,251,68,229,250,233,243,241,245,225,242,101,128,51,59,230,233,238,225,236,228,225,231,229,243,232,232,229,226,242,229,119,128,251,67,104,5,148,70,148,93,148,101,148,115,148,145,225,114,2,148,77,148,84,225,226,233,99,128,6,126,237,229,238,233,225,110,128,5,122,229,226,242,229,119,128,5,228,230,233,238,225,236,225,242,225,226,233,99,128,251,87,105,2,148,121,148,136,238,233,244,233,225,236,225,242,225,226,233,99,128,251,88,242,225,231,225,238,97,128,48,122,237,229,228,233,225,236,225,242,225,226,233,99,128,251,89,235,225,244,225,235,225,238,97,128,48,218,237,233,228,228,236,229,232,239,239,235,227,249,242,233,236,236,233,99,128,4,167,114,5,148,204,148,216,149,2,149,123,149,136,225,230,229,232,229,226,242,229,119,128,251,78,227,229,238,116,131,0,37,148,229,148,238,148,250,225,242,225,226,233,99,128,6,106,237,239,238,239,243,240,225,227,101,128,255,5,243,237,225,236,108,128,254,106,105,2,149,8,149,105,239,100,134,0,46,149,25,149,36,149,47,149,59,149,70,149,82,225,242,237,229,238,233,225,110,128,5,137,227,229,238,244,229,242,229,100,128,0,183,232,225,236,230,247,233,228,244,104,128,255,97,233,238,230,229,242,233,239,114,128,246,231,237,239,238,239,243,240,225,227,101,128,255,14,115,2,149,88,149,95,237,225,236,108,128,254,82,245,240,229,242,233,239,114,128,246,232,243,240,239,237,229,238,233,231,242,229,229,235,227,237,98,128,3,66,240,229,238,228,233,227,245,236,225,114,128,34,165,244,232,239,245,243,225,238,100,128,32,48,243,229,244,97,128,32,167,230,243,241,245,225,242,101,128,51,138,104,3,149,172,149,222,150,103,97,3,149,180,149,190,149,197,226,229,238,231,225,236,105,128,9,171,228,229,246,97,128,9,43,231,117,2,149,204,149,213,234,225,242,225,244,105,128,10,171,242,237,245,235,232,105,128,10,43,105,133,3,198,149,236,149,240,150,70,150,78,150,89,49,128,3,213,229,245,240,104,4,149,253,150,32,150,47,150,56,97,2,150,3,150,18,227,233,242,227,236,229,235,239,242,229,225,110,128,50,122,240,225,242,229,238,235,239,242,229,225,110,128,50,26,227,233,242,227,236,229,235,239,242,229,225,110,128,50,108,235,239,242,229,225,110,128,49,77,240,225,242,229,238,235,239,242,229,225,110,128,50,12,236,225,244,233,110,128,2,120,238,244,232,245,244,232,225,105,128,14,58,243,249,237,226,239,236,231,242,229,229,107,128,3,213,111,3,150,111,150,116,150,142,239,107,128,1,165,240,104,2,150,123,150,132,225,238,244,232,225,105,128,14,30,245,238,231,244,232,225,105,128,14,28,243,225,237,240,232,225,239,244,232,225,105,128,14,32,105,133,3,192,150,170,151,126,151,137,151,148,151,162,229,245,112,6,150,186,150,221,150,253,151,25,151,39,151,91,97,2,150,192,150,207,227,233,242,227,236,229,235,239,242,229,225,110,128,50,115,240,225,242,229,238,235,239,242,229,225,110,128,50,19,227,105,2,150,228,150,240,229,245,227,235,239,242,229,225,110,128,49,118,242,227,236,229,235,239,242,229,225,110,128,50,101,107,2,151,3,151,17,233,249,229,239,235,235,239,242,229,225,110,128,49,114,239,242,229,225,110,128,49,66,240,225,242,229,238,235,239,242,229,225,110,128,50,5,243,233,239,115,2,151,48,151,76,107,2,151,54,151,68,233,249,229,239,235,235,239,242,229,225,110,128,49,116,239,242,229,225,110,128,49,68,244,233,235,229,245,244,235,239,242,229,225,110,128,49,117,116,2,151,97,151,112,232,233,229,245,244,232,235,239,242,229,225,110,128,49,119,233,235,229,245,244,235,239,242,229,225,110,128,49,115,232,233,242,225,231,225,238,97,128,48,116,235,225,244,225,235,225,238,97,128,48,212,243,249,237,226,239,236,231,242,229,229,107,128,3,214,247,242,225,242,237,229,238,233,225,110,128,5,131,236,245,115,132,0,43,151,189,151,200,151,209,151,242,226,229,236,239,247,227,237,98,128,3,31,227,233,242,227,236,101,128,34,149,109,2,151,215,151,222,233,238,245,115,128,0,177,111,2,151,228,151,232,100,128,2,214,238,239,243,240,225,227,101,128,255,11,115,2,151,248,151,255,237,225,236,108,128,254,98,245,240,229,242,233,239,114,128,32,122,109,2,152,15,152,26,239,238,239,243,240,225,227,101,128,255,80,243,241,245,225,242,101,128,51,216,111,5,152,47,152,58,152,125,152,136,152,146,232,233,242,225,231,225,238,97,128,48,125,233,238,244,233,238,231,233,238,228,229,120,4,152,78,152,90,152,102,152,115,228,239,247,238,247,232,233,244,101,128,38,31,236,229,230,244,247,232,233,244,101,128,38,28,242,233,231,232,244,247,232,233,244,101,128,38,30,245,240,247,232,233,244,101,128,38,29,235,225,244,225,235,225,238,97,128,48,221,240,236,225,244,232,225,105,128,14,27,243,244,225,236,237,225,242,107,129,48,18,152,159,230,225,227,101,128,48,32,240,225,242,229,110,128,36,171,114,3,152,182,152,208,152,233,101,2,152,188,152,196,227,229,228,229,115,128,34,122,243,227,242,233,240,244,233,239,110,128,33,30,233,237,101,2,152,216,152,222,237,239,100,128,2,185,242,229,246,229,242,243,229,100,128,32,53,111,4,152,243,152,250,153,4,153,17,228,245,227,116,128,34,15,234,229,227,244,233,246,101,128,35,5,236,239,238,231,229,228,235,225,238,97,128,48,252,112,2,153,23,153,60,101,2,153,29,153,36,236,236,239,114,128,35,24,242,243,117,2,153,44,153,51,226,243,229,116,128,34,130,240,229,242,243,229,116,128,34,131,239,242,244,233,239,110,129,34,55,153,71,225,108,128,34,29,115,2,153,82,153,125,105,130,3,200,153,90,153,101,227,249,242,233,236,236,233,99,128,4,113,236,233,240,238,229,245,237,225,244,225,227,249,242,233,236,236,233,227,227,237,98,128,4,134,243,241,245,225,242,101,128,51,176,117,2,153,140,153,151,232,233,242,225,231,225,238,97,128,48,119,235,225,244,225,235,225,238,97,128,48,215,246,243,241,245,225,242,101,128,51,180,247,243,241,245,225,242,101,128,51,186,113,136,0,113,153,202,154,251,155,6,155,15,155,22,155,34,155,72,155,80,97,4,153,212,153,235,154,43,154,234,100,2,153,218,153,224,229,246,97,128,9,88,237,225,232,229,226,242,229,119,128,5,168,102,4,153,245,153,254,154,12,154,28,225,242,225,226,233,99,128,6,66,230,233,238,225,236,225,242,225,226,233,99,128,254,214,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,215,237,229,228,233,225,236,225,242,225,226,233,99,128,254,216,237,225,244,115,136,5,184,154,66,154,86,154,100,154,105,154,110,154,119,154,134,154,221,49,3,154,74,154,78,154,82,48,128,5,184,97,128,5,184,99,128,5,184,50,2,154,92,154,96,55,128,5,184,57,128,5,184,179,51,128,5,184,228,101,128,5,184,232,229,226,242,229,119,128,5,184,238,225,242,242,239,247,232,229,226,242,229,119,128,5,184,113,2,154,140,154,206,225,244,225,110,4,154,153,154,162,154,177,154,193,232,229,226,242,229,119,128,5,184,238,225,242,242,239,247,232,229,226,242,229,119,128,5,184,241,245,225,242,244,229,242,232,229,226,242,229,119,128,5,184,247,233,228,229,232,229,226,242,229,119,128,5,184,245,225,242,244,229,242,232,229,226,242,229,119,128,5,184,247,233,228,229,232,229,226,242,229,119,128,5,184,242,238,229,249,240,225,242,225,232,229,226,242,229,119,128,5,159,226,239,240,239,237,239,230,111,128,49,17,227,233,242,227,236,101,128,36,224,232,239,239,107,128,2,160,237,239,238,239,243,240,225,227,101,128,255,81,239,102,130,5,231,155,43,155,63,228,225,231,229,243,104,129,251,71,155,54,232,229,226,242,229,119,128,251,71,232,229,226,242,229,119,128,5,231,240,225,242,229,110,128,36,172,117,4,155,90,155,102,155,191,156,22,225,242,244,229,242,238,239,244,101,128,38,105,226,245,244,115,135,5,187,155,123,155,128,155,133,155,138,155,147,155,162,155,178,177,56,128,5,187,178,53,128,5,187,179,49,128,5,187,232,229,226,242,229,119,128,5,187,238,225,242,242,239,247,232,229,226,242,229,119,128,5,187,241,245,225,242,244,229,242,232,229,226,242,229,119,128,5,187,247,233,228,229,232,229,226,242,229,119,128,5,187,229,243,244,233,239,110,133,0,63,155,210,155,233,155,250,156,2,156,14,225,114,2,155,217,155,224,225,226,233,99,128,6,31,237,229,238,233,225,110,128,5,94,228,239,247,110,129,0,191,155,242,243,237,225,236,108,128,247,191,231,242,229,229,107,128,3,126,237,239,238,239,243,240,225,227,101,128,255,31,243,237,225,236,108,128,247,63,239,244,101,4,156,34,156,105,156,125,156,154,228,226,108,133,0,34,156,50,156,57,156,64,156,76,156,97,226,225,243,101,128,32,30,236,229,230,116,128,32,28,237,239,238,239,243,240,225,227,101,128,255,2,240,242,233,237,101,129,48,30,156,86,242,229,246,229,242,243,229,100,128,48,29,242,233,231,232,116,128,32,29,236,229,230,116,129,32,24,156,114,242,229,246,229,242,243,229,100,128,32,27,114,2,156,131,156,141,229,246,229,242,243,229,100,128,32,27,233,231,232,116,129,32,25,156,150,110,128,1,73,243,233,238,231,108,2,156,164,156,171,226,225,243,101,128,32,26,101,129,0,39,156,177,237,239,238,239,243,240,225,227,101,128,255,7,114,145,0,114,156,227,157,231,157,242,158,33,158,84,159,101,159,125,159,220,161,254,162,35,162,47,162,101,162,109,163,15,163,26,163,61,163,161,97,11,156,251,157,6,157,16,157,23,157,88,157,104,157,129,157,140,157,165,157,188,157,225,225,242,237,229,238,233,225,110,128,5,124,226,229,238,231,225,236,105,128,9,176,227,245,244,101,128,1,85,100,4,157,33,157,39,157,53,157,79,229,246,97,128,9,48,233,227,225,108,129,34,26,157,48,229,120,128,248,229,239,246,229,242,243,243,241,245,225,242,101,129,51,174,157,69,228,243,241,245,225,242,101,128,51,175,243,241,245,225,242,101,128,51,173,230,101,129,5,191,157,95,232,229,226,242,229,119,128,5,191,231,117,2,157,111,157,120,234,225,242,225,244,105,128,10,176,242,237,245,235,232,105,128,10,48,232,233,242,225,231,225,238,97,128,48,137,235,225,244,225,235,225,238,97,129,48,233,157,153,232,225,236,230,247,233,228,244,104,128,255,151,236,239,247,229,242,228,233,225,231,239,238,225,236,226,229,238,231,225,236,105,128,9,241,109,2,157,194,157,217,233,228,228,236,229,228,233,225,231,239,238,225,236,226,229,238,231,225,236,105,128,9,240,243,232,239,242,110,128,2,100,244,233,111,128,34,54,226,239,240,239,237,239,230,111,128,49,22,99,4,157,252,158,3,158,12,158,20,225,242,239,110,128,1,89,229,228,233,236,236,97,128,1,87,233,242,227,236,101,128,36,225,239,237,237,225,225,227,227,229,238,116,128,1,87,100,2,158,39,158,49,226,236,231,242,225,246,101,128,2,17,239,116,2,158,56,158,65,225,227,227,229,238,116,128,30,89,226,229,236,239,119,129,30,91,158,75,237,225,227,242,239,110,128,30,93,101,6,158,98,158,143,158,178,158,233,159,2,159,35,102,2,158,104,158,117,229,242,229,238,227,229,237,225,242,107,128,32,59,236,229,248,243,117,2,158,127,158,134,226,243,229,116,128,34,134,240,229,242,243,229,116,128,34,135,231,233,243,244,229,114,2,158,154,158,159,229,100,128,0,174,115,2,158,165,158,171,225,238,115,128,248,232,229,242,233,102,128,246,218,104,3,158,186,158,209,158,223,225,114,2,158,193,158,200,225,226,233,99,128,6,49,237,229,238,233,225,110,128,5,128,230,233,238,225,236,225,242,225,226,233,99,128,254,174,233,242,225,231,225,238,97,128,48,140,235,225,244,225,235,225,238,97,129,48,236,158,246,232,225,236,230,247,233,228,244,104,128,255,154,243,104,130,5,232,159,11,159,26,228,225,231,229,243,232,232,229,226,242,229,119,128,251,72,232,229,226,242,229,119,128,5,232,118,3,159,43,159,56,159,88,229,242,243,229,228,244,233,236,228,101,128,34,61,233,97,2,159,63,159,72,232,229,226,242,229,119,128,5,151,237,245,231,242,225,243,232,232,229,226,242,229,119,128,5,151,236,239,231,233,227,225,236,238,239,116,128,35,16,230,233,243,232,232,239,239,107,129,2,126,159,114,242,229,246,229,242,243,229,100,128,2,127,104,2,159,131,159,154,97,2,159,137,159,147,226,229,238,231,225,236,105,128,9,221,228,229,246,97,128,9,93,111,131,3,193,159,164,159,193,159,207,239,107,129,2,125,159,171,244,245,242,238,229,100,129,2,123,159,182,243,245,240,229,242,233,239,114,128,2,181,243,249,237,226,239,236,231,242,229,229,107,128,3,241,244,233,227,232,239,239,235,237,239,100,128,2,222,105,6,159,234,161,22,161,68,161,79,161,104,161,240,229,245,108,9,160,0,160,35,160,50,160,64,160,110,160,124,160,210,160,223,161,2,97,2,160,6,160,21,227,233,242,227,236,229,235,239,242,229,225,110,128,50,113,240,225,242,229,238,235,239,242,229,225,110,128,50,17,227,233,242,227,236,229,235,239,242,229,225,110,128,50,99,232,233,229,245,232,235,239,242,229,225,110,128,49,64,107,2,160,70,160,102,233,249,229,239,107,2,160,80,160,89,235,239,242,229,225,110,128,49,58,243,233,239,243,235,239,242,229,225,110,128,49,105,239,242,229,225,110,128,49,57,237,233,229,245,237,235,239,242,229,225,110,128,49,59,112,3,160,132,160,164,160,179,97,2,160,138,160,152,238,243,233,239,243,235,239,242,229,225,110,128,49,108,242,229,238,235,239,242,229,225,110,128,50,3,232,233,229,245,240,232,235,239,242,229,225,110,128,49,63,233,229,245,112,2,160,188,160,197,235,239,242,229,225,110,128,49,60,243,233,239,243,235,239,242,229,225,110,128,49,107,243,233,239,243,235,239,242,229,225,110,128,49,61,116,2,160,229,160,244,232,233,229,245,244,232,235,239,242,229,225,110,128,49,62,233,235,229,245,244,235,239,242,229,225,110,128,49,106,249,229,239,242,233,238,232,233,229,245,232,235,239,242,229,225,110,128,49,109,231,232,116,2,161,30,161,38,225,238,231,236,101,128,34,31,116,2,161,44,161,58,225,227,235,226,229,236,239,247,227,237,98,128,3,25,242,233,225,238,231,236,101,128,34,191,232,233,242,225,231,225,238,97,128,48,138,235,225,244,225,235,225,238,97,129,48,234,161,92,232,225,236,230,247,233,228,244,104,128,255,152,110,2,161,110,161,226,103,131,2,218,161,120,161,131,161,137,226,229,236,239,247,227,237,98,128,3,37,227,237,98,128,3,10,232,225,236,102,2,161,146,161,192,236,229,230,116,131,2,191,161,159,161,170,161,181,225,242,237,229,238,233,225,110,128,5,89,226,229,236,239,247,227,237,98,128,3,28,227,229,238,244,229,242,229,100,128,2,211,242,233,231,232,116,130,2,190,161,204,161,215,226,229,236,239,247,227,237,98,128,3,57,227,229,238,244,229,242,229,100,128,2,210,246,229,242,244,229,228,226,242,229,246,101,128,2,19,244,244,239,242,245,243,241,245,225,242,101,128,51,81,108,2,162,4,162,15,233,238,229,226,229,236,239,119,128,30,95,239,238,231,236,229,103,129,2,124,162,26,244,245,242,238,229,100,128,2,122,237,239,238,239,243,240,225,227,101,128,255,82,111,3,162,55,162,66,162,91,232,233,242,225,231,225,238,97,128,48,141,235,225,244,225,235,225,238,97,129,48,237,162,79,232,225,236,230,247,233,228,244,104,128,255,155,242,245,225,244,232,225,105,128,14,35,240,225,242,229,110,128,36,173,114,3,162,117,162,153,162,183,97,3,162,125,162,135,162,142,226,229,238,231,225,236,105,128,9,220,228,229,246,97,128,9,49,231,245,242,237,245,235,232,105,128,10,92,229,104,2,162,160,162,169,225,242,225,226,233,99,128,6,145,230,233,238,225,236,225,242,225,226,233,99,128,251,141,246,239,227,225,236,233,99,4,162,199,162,209,162,216,162,227,226,229,238,231,225,236,105,128,9,224,228,229,246,97,128,9,96,231,245,234,225,242,225,244,105,128,10,224,246,239,247,229,236,243,233,231,110,3,162,243,162,253,163,4,226,229,238,231,225,236,105,128,9,196,228,229,246,97,128,9,68,231,245,234,225,242,225,244,105,128,10,196,243,245,240,229,242,233,239,114,128,246,241,116,2,163,32,163,40,226,236,239,227,107,128,37,144,245,242,238,229,100,129,2,121,163,50,243,245,240,229,242,233,239,114,128,2,180,117,4,163,71,163,82,163,107,163,154,232,233,242,225,231,225,238,97,128,48,139,235,225,244,225,235,225,238,97,129,48,235,163,95,232,225,236,230,247,233,228,244,104,128,255,153,112,2,163,113,163,148,229,101,2,163,120,163,134,237,225,242,235,226,229,238,231,225,236,105,128,9,242,243,233,231,238,226,229,238,231,225,236,105,128,9,243,233,225,104,128,246,221,244,232,225,105,128,14,36,246,239,227,225,236,233,99,4,163,177,163,187,163,194,163,205,226,229,238,231,225,236,105,128,9,139,228,229,246,97,128,9,11,231,245,234,225,242,225,244,105,128,10,139,246,239,247,229,236,243,233,231,110,3,163,221,163,231,163,238,226,229,238,231,225,236,105,128,9,195,228,229,246,97,128,9,67,231,245,234,225,242,225,244,105,128,10,195,115,147,0,115,164,35,166,5,166,16,166,142,166,181,169,123,169,134,172,21,174,159,174,205,174,232,175,167,175,234,177,11,177,21,177,207,178,24,178,194,178,204,97,9,164,55,164,65,164,86,164,158,164,183,164,194,164,219,164,251,165,35,226,229,238,231,225,236,105,128,9,184,227,245,244,101,129,1,91,164,74,228,239,244,225,227,227,229,238,116,128,30,101,100,5,164,98,164,107,164,113,164,127,164,143,225,242,225,226,233,99,128,6,53,229,246,97,128,9,56,230,233,238,225,236,225,242,225,226,233,99,128,254,186,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,187,237,229,228,233,225,236,225,242,225,226,233,99,128,254,188,231,117,2,164,165,164,174,234,225,242,225,244,105,128,10,184,242,237,245,235,232,105,128,10,56,232,233,242,225,231,225,238,97,128,48,85,235,225,244,225,235,225,238,97,129,48,181,164,207,232,225,236,230,247,233,228,244,104,128,255,123,236,236,225,236,236,225,232,239,245,225,236,225,249,232,229,247,225,243,225,236,236,225,237,225,242,225,226,233,99,128,253,250,237,229,235,104,130,5,225,165,6,165,26,228,225,231,229,243,104,129,251,65,165,17,232,229,226,242,229,119,128,251,65,232,229,226,242,229,119,128,5,225,242,97,5,165,48,165,122,165,130,165,180,165,188,97,5,165,60,165,68,165,76,165,107,165,115,225,244,232,225,105,128,14,50,229,244,232,225,105,128,14,65,233,237,225,233,109,2,165,86,165,97,225,236,225,233,244,232,225,105,128,14,68,245,225,238,244,232,225,105,128,14,67,237,244,232,225,105,128,14,51,244,232,225,105,128,14,48,229,244,232,225,105,128,14,64,105,3,165,138,165,162,165,173,105,2,165,144,165,155,236,229,230,244,244,232,225,105,128,248,134,244,232,225,105,128,14,53,236,229,230,244,244,232,225,105,128,248,133,244,232,225,105,128,14,52,239,244,232,225,105,128,14,66,117,3,165,196,165,246,165,253,101,3,165,204,165,228,165,239,101,2,165,210,165,221,236,229,230,244,244,232,225,105,128,248,136,244,232,225,105,128,14,55,236,229,230,244,244,232,225,105,128,248,135,244,232,225,105,128,14,54,244,232,225,105,128,14,56,245,244,232,225,105,128,14,57,226,239,240,239,237,239,230,111,128,49,25,99,5,166,28,166,49,166,58,166,107,166,129,225,242,239,110,129,1,97,166,37,228,239,244,225,227,227,229,238,116,128,30,103,229,228,233,236,236,97,128,1,95,232,247,97,131,2,89,166,70,166,81,166,100,227,249,242,233,236,236,233,99,128,4,217,228,233,229,242,229,243,233,243,227,249,242,233,236,236,233,99,128,4,219,232,239,239,107,128,2,90,233,242,99,2,166,115,166,120,236,101,128,36,226,245,237,230,236,229,120,128,1,93,239,237,237,225,225,227,227,229,238,116,128,2,25,228,239,116,2,166,150,166,159,225,227,227,229,238,116,128,30,97,226,229,236,239,119,129,30,99,166,169,228,239,244,225,227,227,229,238,116,128,30,105,101,9,166,201,166,217,166,252,167,61,167,164,167,191,167,216,168,41,168,68,225,231,245,236,236,226,229,236,239,247,227,237,98,128,3,60,99,2,166,223,166,245,239,238,100,129,32,51,166,231,244,239,238,229,227,232,233,238,229,243,101,128,2,202,244,233,239,110,128,0,167,229,110,4,167,7,167,16,167,30,167,46,225,242,225,226,233,99,128,6,51,230,233,238,225,236,225,242,225,226,233,99,128,254,178,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,179,237,229,228,233,225,236,225,242,225,226,233,99,128,254,180,231,239,108,135,5,182,167,81,167,95,167,100,167,109,167,124,167,140,167,151,49,2,167,87,167,91,51,128,5,182,102,128,5,182,178,99,128,5,182,232,229,226,242,229,119,128,5,182,238,225,242,242,239,247,232,229,226,242,229,119,128,5,182,241,245,225,242,244,229,242,232,229,226,242,229,119,128,5,182,244,225,232,229,226,242,229,119,128,5,146,247,233,228,229,232,229,226,242,229,119,128,5,182,104,2,167,170,167,181,225,242,237,229,238,233,225,110,128,5,125,233,242,225,231,225,238,97,128,48,91,235,225,244,225,235,225,238,97,129,48,187,167,204,232,225,236,230,247,233,228,244,104,128,255,126,237,105,2,167,223,168,10,227,239,236,239,110,131,0,59,167,237,167,246,168,2,225,242,225,226,233,99,128,6,27,237,239,238,239,243,240,225,227,101,128,255,27,243,237,225,236,108,128,254,84,246,239,233,227,229,228,237,225,242,235,235,225,238,97,129,48,156,168,29,232,225,236,230,247,233,228,244,104,128,255,159,238,116,2,168,48,168,58,233,243,241,245,225,242,101,128,51,34,239,243,241,245,225,242,101,128,51,35,246,229,110,142,0,55,168,102,168,111,168,121,168,151,168,158,168,168,168,193,168,220,168,254,169,10,169,21,169,54,169,62,169,73,225,242,225,226,233,99,128,6,103,226,229,238,231,225,236,105,128,9,237,227,233,242,227,236,101,129,36,102,168,132,233,238,246,229,242,243,229,243,225,238,243,243,229,242,233,102,128,39,144,228,229,246,97,128,9,109,229,233,231,232,244,232,115,128,33,94,231,117,2,168,175,168,184,234,225,242,225,244,105,128,10,237,242,237,245,235,232,105,128,10,109,232,97,2,168,200,168,211,227,235,225,242,225,226,233,99,128,6,103,238,231,250,232,239,117,128,48,39,105,2,168,226,168,244,228,229,239,231,242,225,240,232,233,227,240,225,242,229,110,128,50,38,238,230,229,242,233,239,114,128,32,135,237,239,238,239,243,240,225,227,101,128,255,23,239,236,228,243,244,249,236,101,128,247,55,112,2,169,27,169,34,225,242,229,110,128,36,122,229,114,2,169,41,169,47,233,239,100,128,36,142,243,233,225,110,128,6,247,242,239,237,225,110,128,33,118,243,245,240,229,242,233,239,114,128,32,119,116,2,169,79,169,117,229,229,110,2,169,87,169,96,227,233,242,227,236,101,128,36,112,112,2,169,102,169,109,225,242,229,110,128,36,132,229,242,233,239,100,128,36,152,232,225,105,128,14,87,230,244,232,249,240,232,229,110,128,0,173,104,7,169,150,170,124,170,135,170,149,171,94,171,107,172,15,97,6,169,164,169,175,169,185,169,196,170,83,170,108,225,242,237,229,238,233,225,110,128,5,119,226,229,238,231,225,236,105,128,9,182,227,249,242,233,236,236,233,99,128,4,72,100,2,169,202,170,42,228,97,4,169,213,169,222,169,253,170,11,225,242,225,226,233,99,128,6,81,228,225,237,237,97,2,169,232,169,241,225,242,225,226,233,99,128,252,97,244,225,238,225,242,225,226,233,99,128,252,94,230,225,244,232,225,225,242,225,226,233,99,128,252,96,235,225,243,242,97,2,170,21,170,30,225,242,225,226,233,99,128,252,98,244,225,238,225,242,225,226,233,99,128,252,95,101,132,37,146,170,54,170,61,170,69,170,78,228,225,242,107,128,37,147,236,233,231,232,116,128,37,145,237,229,228,233,245,109,128,37,146,246,97,128,9,54,231,117,2,170,90,170,99,234,225,242,225,244,105,128,10,182,242,237,245,235,232,105,128,10,54,236,243,232,229,236,229,244,232,229,226,242,229,119,128,5,147,226,239,240,239,237,239,230,111,128,49,21,227,232,225,227,249,242,233,236,236,233,99,128,4,73,101,4,170,159,170,224,170,234,170,251,229,110,4,170,170,170,179,170,193,170,209,225,242,225,226,233,99,128,6,52,230,233,238,225,236,225,242,225,226,233,99,128,254,182,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,183,237,229,228,233,225,236,225,242,225,226,233,99,128,254,184,233,227,239,240,244,233,99,128,3,227,241,229,108,129,32,170,170,242,232,229,226,242,229,119,128,32,170,246,97,134,5,176,171,12,171,27,171,41,171,50,171,65,171,81,49,2,171,18,171,23,177,53,128,5,176,53,128,5,176,50,2,171,33,171,37,50,128,5,176,101,128,5,176,232,229,226,242,229,119,128,5,176,238,225,242,242,239,247,232,229,226,242,229,119,128,5,176,241,245,225,242,244,229,242,232,229,226,242,229,119,128,5,176,247,233,228,229,232,229,226,242,229,119,128,5,176,232,225,227,249,242,233,236,236,233,99,128,4,187,105,2,171,113,171,124,237,225,227,239,240,244,233,99,128,3,237,110,131,5,233,171,134,171,217,171,226,100,2,171,140,171,206,225,231,229,243,104,130,251,73,171,152,171,161,232,229,226,242,229,119,128,251,73,115,2,171,167,171,187,232,233,238,228,239,116,129,251,44,171,178,232,229,226,242,229,119,128,251,44,233,238,228,239,116,129,251,45,171,197,232,229,226,242,229,119,128,251,45,239,244,232,229,226,242,229,119,128,5,193,232,229,226,242,229,119,128,5,233,115,2,171,232,171,252,232,233,238,228,239,116,129,251,42,171,243,232,229,226,242,229,119,128,251,42,233,238,228,239,116,129,251,43,172,6,232,229,226,242,229,119,128,251,43,239,239,107,128,2,130,105,8,172,39,172,83,172,94,172,119,172,149,172,157,172,170,173,85,231,237,97,131,3,195,172,51,172,55,172,63,49,128,3,194,230,233,238,225,108,128,3,194,236,245,238,225,244,229,243,249,237,226,239,236,231,242,229,229,107,128,3,242,232,233,242,225,231,225,238,97,128,48,87,235,225,244,225,235,225,238,97,129,48,183,172,107,232,225,236,230,247,233,228,244,104,128,255,124,236,245,113,2,172,127,172,136,232,229,226,242,229,119,128,5,189,236,229,230,244,232,229,226,242,229,119,128,5,189,237,233,236,225,114,128,34,60,238,228,239,244,232,229,226,242,229,119,128,5,194,239,115,6,172,185,172,220,172,252,173,24,173,38,173,70,97,2,172,191,172,206,227,233,242,227,236,229,235,239,242,229,225,110,128,50,116,240,225,242,229,238,235,239,242,229,225,110,128,50,20,227,105,2,172,227,172,239,229,245,227,235,239,242,229,225,110,128,49,126,242,227,236,229,235,239,242,229,225,110,128,50,102,107,2,173,2,173,16,233,249,229,239,235,235,239,242,229,225,110,128,49,122,239,242,229,225,110,128,49,69,238,233,229,245,238,235,239,242,229,225,110,128,49,123,112,2,173,44,173,57,225,242,229,238,235,239,242,229,225,110,128,50,6,233,229,245,240,235,239,242,229,225,110,128,49,125,244,233,235,229,245,244,235,239,242,229,225,110,128,49,124,120,141,0,54,173,115,173,124,173,134,173,164,173,171,173,196,173,223,174,1,174,13,174,24,174,57,174,65,174,76,225,242,225,226,233,99,128,6,102,226,229,238,231,225,236,105,128,9,236,227,233,242,227,236,101,129,36,101,173,145,233,238,246,229,242,243,229,243,225,238,243,243,229,242,233,102,128,39,143,228,229,246,97,128,9,108,231,117,2,173,178,173,187,234,225,242,225,244,105,128,10,236,242,237,245,235,232,105,128,10,108,232,97,2,173,203,173,214,227,235,225,242,225,226,233,99,128,6,102,238,231,250,232,239,117,128,48,38,105,2,173,229,173,247,228,229,239,231,242,225,240,232,233,227,240,225,242,229,110,128,50,37,238,230,229,242,233,239,114,128,32,134,237,239,238,239,243,240,225,227,101,128,255,22,239,236,228,243,244,249,236,101,128,247,54,112,2,174,30,174,37,225,242,229,110,128,36,121,229,114,2,174,44,174,50,233,239,100,128,36,141,243,233,225,110,128,6,246,242,239,237,225,110,128,33,117,243,245,240,229,242,233,239,114,128,32,118,116,2,174,82,174,153,229,229,110,2,174,90,174,132,99,2,174,96,174,104,233,242,227,236,101,128,36,111,245,242,242,229,238,227,249,228,229,238,239,237,233,238,225,244,239,242,226,229,238,231,225,236,105,128,9,249,112,2,174,138,174,145,225,242,229,110,128,36,131,229,242,233,239,100,128,36,151,232,225,105,128,14,86,108,2,174,165,174,185,225,243,104,129,0,47,174,173,237,239,238,239,243,240,225,227,101,128,255,15,239,238,103,129,1,127,174,193,228,239,244,225,227,227,229,238,116,128,30,155,109,2,174,211,174,221,233,236,229,230,225,227,101,128,38,58,239,238,239,243,240,225,227,101,128,255,83,111,6,174,246,175,40,175,51,175,76,175,121,175,132,102,2,174,252,175,10,240,225,243,245,241,232,229,226,242,229,119,128,5,195,116,2,175,16,175,25,232,249,240,232,229,110,128,0,173,243,233,231,238,227,249,242,233,236,236,233,99,128,4,76,232,233,242,225,231,225,238,97,128,48,93,235,225,244,225,235,225,238,97,129,48,189,175,64,232,225,236,230,247,233,228,244,104,128,255,127,236,233,228,245,115,2,175,86,175,103,236,239,238,231,239,246,229,242,236,225,249,227,237,98,128,3,56,243,232,239,242,244,239,246,229,242,236,225,249,227,237,98,128,3,55,242,245,243,233,244,232,225,105,128,14,41,115,3,175,140,175,150,175,158,225,236,225,244,232,225,105,128,14,40,239,244,232,225,105,128,14,11,245,225,244,232,225,105,128,14,42,240,97,3,175,176,175,196,175,228,227,101,129,0,32,175,183,232,225,227,235,225,242,225,226,233,99,128,0,32,228,101,129,38,96,175,203,243,245,233,116,2,175,212,175,220,226,236,225,227,107,128,38,96,247,232,233,244,101,128,38,100,242,229,110,128,36,174,241,245,225,242,101,11,176,6,176,17,176,31,176,56,176,73,176,99,176,114,176,147,176,174,176,230,176,245,226,229,236,239,247,227,237,98,128,3,59,99,2,176,23,176,27,99,128,51,196,109,128,51,157,228,233,225,231,239,238,225,236,227,242,239,243,243,232,225,244,227,232,230,233,236,108,128,37,169,232,239,242,233,250,239,238,244,225,236,230,233,236,108,128,37,164,107,2,176,79,176,83,103,128,51,143,109,129,51,158,176,89,227,225,240,233,244,225,108,128,51,206,108,2,176,105,176,109,110,128,51,209,239,103,128,51,210,109,4,176,124,176,128,176,133,176,137,103,128,51,142,233,108,128,51,213,109,128,51,156,243,241,245,225,242,229,100,128,51,161,239,242,244,232,239,231,239,238,225,236,227,242,239,243,243,232,225,244,227,232,230,233,236,108,128,37,166,245,240,240,229,114,2,176,184,176,207,236,229,230,244,244,239,236,239,247,229,242,242,233,231,232,244,230,233,236,108,128,37,167,242,233,231,232,244,244,239,236,239,247,229,242,236,229,230,244,230,233,236,108,128,37,168,246,229,242,244,233,227,225,236,230,233,236,108,128,37,165,247,232,233,244,229,247,233,244,232,243,237,225,236,236,226,236,225,227,107,128,37,163,242,243,241,245,225,242,101,128,51,219,115,2,177,27,177,197,97,4,177,37,177,47,177,54,177,65,226,229,238,231,225,236,105,128,9,183,228,229,246,97,128,9,55,231,245,234,225,242,225,244,105,128,10,183,238,103,8,177,84,177,98,177,112,177,126,177,141,177,155,177,169,177,182,227,233,229,245,227,235,239,242,229,225,110,128,49,73,232,233,229,245,232,235,239,242,229,225,110,128,49,133,233,229,245,238,231,235,239,242,229,225,110,128,49,128,235,233,249,229,239,235,235,239,242,229,225,110,128,49,50,238,233,229,245,238,235,239,242,229,225,110,128,49,101,240,233,229,245,240,235,239,242,229,225,110,128,49,67,243,233,239,243,235,239,242,229,225,110,128,49,70,244,233,235,229,245,244,235,239,242,229,225,110,128,49,56,245,240,229,242,233,239,114,128,246,242,116,2,177,213,177,236,229,242,236,233,238,103,129,0,163,177,224,237,239,238,239,243,240,225,227,101,128,255,225,242,239,235,101,2,177,245,178,6,236,239,238,231,239,246,229,242,236,225,249,227,237,98,128,3,54,243,232,239,242,244,239,246,229,242,236,225,249,227,237,98,128,3,53,117,7,178,40,178,72,178,94,178,105,178,146,178,156,178,160,226,243,229,116,130,34,130,178,51,178,62,238,239,244,229,241,245,225,108,128,34,138,239,242,229,241,245,225,108,128,34,134,99,2,178,78,178,86,227,229,229,228,115,128,34,123,232,244,232,225,116,128,34,11,232,233,242,225,231,225,238,97,128,48,89,107,2,178,111,178,135,225,244,225,235,225,238,97,129,48,185,178,123,232,225,236,230,247,233,228,244,104,128,255,125,245,238,225,242,225,226,233,99,128,6,82,237,237,225,244,233,239,110,128,34,17,110,128,38,60,240,229,242,243,229,116,130,34,131,178,173,178,184,238,239,244,229,241,245,225,108,128,34,139,239,242,229,241,245,225,108,128,34,135,246,243,241,245,225,242,101,128,51,220,249,239,245,247,225,229,242,225,243,241,245,225,242,101,128,51,124,116,144,0,116,179,1,180,10,180,31,180,174,180,214,183,6,186,144,187,219,187,231,187,243,189,20,189,45,189,131,190,55,190,239,191,73,97,10,179,23,179,33,179,54,179,61,179,86,179,164,179,181,179,206,179,220,179,224,226,229,238,231,225,236,105,128,9,164,227,107,2,179,40,179,47,228,239,247,110,128,34,164,236,229,230,116,128,34,163,228,229,246,97,128,9,36,231,117,2,179,68,179,77,234,225,242,225,244,105,128,10,164,242,237,245,235,232,105,128,10,36,104,4,179,96,179,105,179,119,179,149,225,242,225,226,233,99,128,6,55,230,233,238,225,236,225,242,225,226,233,99,128,254,194,105,2,179,125,179,140,238,233,244,233,225,236,225,242,225,226,233,99,128,254,195,242,225,231,225,238,97,128,48,95,237,229,228,233,225,236,225,242,225,226,233,99,128,254,196,233,243,249,239,245,229,242,225,243,241,245,225,242,101,128,51,125,235,225,244,225,235,225,238,97,129,48,191,179,194,232,225,236,230,247,233,228,244,104,128,255,128,244,247,229,229,236,225,242,225,226,233,99,128,6,64,117,128,3,196,118,130,5,234,179,232,180,1,228,225,231,229,115,129,251,74,179,242,104,129,251,74,179,248,232,229,226,242,229,119,128,251,74,232,229,226,242,229,119,128,5,234,98,2,180,16,180,21,225,114,128,1,103,239,240,239,237,239,230,111,128,49,10,99,6,180,45,180,52,180,59,180,68,180,134,180,161,225,242,239,110,128,1,101,227,245,242,108,128,2,168,229,228,233,236,236,97,128,1,99,232,229,104,4,180,80,180,89,180,103,180,119,225,242,225,226,233,99,128,6,134,230,233,238,225,236,225,242,225,226,233,99,128,251,123,233,238,233,244,233,225,236,225,242,225,226,233,99,128,251,124,237,229,228,233,225,236,225,242,225,226,233,99,128,251,125,233,242,99,2,180,142,180,147,236,101,128,36,227,245,237,230,236,229,248,226,229,236,239,119,128,30,113,239,237,237,225,225,227,227,229,238,116,128,1,99,100,2,180,180,180,190,233,229,242,229,243,233,115,128,30,151,239,116,2,180,197,180,206,225,227,227,229,238,116,128,30,107,226,229,236,239,119,128,30,109,101,9,180,234,180,245,181,9,182,19,182,44,182,108,182,175,182,180,182,232,227,249,242,233,236,236,233,99,128,4,66,228,229,243,227,229,238,228,229,242,227,249,242,233,236,236,233,99,128,4,173,104,7,181,25,181,34,181,48,181,88,181,118,181,159,182,1,225,242,225,226,233,99,128,6,42,230,233,238,225,236,225,242,225,226,233,99,128,254,150,232,225,232,105,2,181,57,181,72,238,233,244,233,225,236,225,242,225,226,233,99,128,252,162,243,239,236,225,244,229,228,225,242,225,226,233,99,128,252,12,105,2,181,94,181,109,238,233,244,233,225,236,225,242,225,226,233,99,128,254,151,242,225,231,225,238,97,128,48,102,234,229,229,237,105,2,181,128,181,143,238,233,244,233,225,236,225,242,225,226,233,99,128,252,161,243,239,236,225,244,229,228,225,242,225,226,233,99,128,252,11,109,2,181,165,181,199,225,242,226,245,244,97,2,181,176,181,185,225,242,225,226,233,99,128,6,41,230,233,238,225,236,225,242,225,226,233,99,128,254,148,101,2,181,205,181,218,228,233,225,236,225,242,225,226,233,99,128,254,152,229,237,105,2,181,226,181,241,238,233,244,233,225,236,225,242,225,226,233,99,128,252,164,243,239,236,225,244,229,228,225,242,225,226,233,99,128,252,14,238,239,239,238,230,233,238,225,236,225,242,225,226,233,99,128,252,115,235,225,244,225,235,225,238,97,129,48,198,182,32,232,225,236,230,247,233,228,244,104,128,255,131,108,2,182,50,182,69,229,240,232,239,238,101,129,33,33,182,61,226,236,225,227,107,128,38,14,233,243,232,97,2,182,78,182,93,231,229,228,239,236,225,232,229,226,242,229,119,128,5,160,241,229,244,225,238,225,232,229,226,242,229,119,128,5,169,110,4,182,118,182,127,182,146,182,167,227,233,242,227,236,101,128,36,105,233,228,229,239,231,242,225,240,232,233,227,240,225,242,229,110,128,50,41,112,2,182,152,182,159,225,242,229,110,128,36,125,229,242,233,239,100,128,36,145,242,239,237,225,110,128,33,121,243,104,128,2,167,116,131,5,216,182,190,182,210,182,219,228,225,231,229,243,104,129,251,56,182,201,232,229,226,242,229,119,128,251,56,232,229,226,242,229,119,128,5,216,243,229,227,249,242,233,236,236,233,99,128,4,181,246,233,114,2,182,240,182,249,232,229,226,242,229,119,128,5,155,236,229,230,244,232,229,226,242,229,119,128,5,155,104,6,183,20,183,172,184,38,184,170,185,77,186,134,97,5,183,32,183,42,183,49,183,74,183,103,226,229,238,231,225,236,105,128,9,165,228,229,246,97,128,9,37,231,117,2,183,56,183,65,234,225,242,225,244,105,128,10,165,242,237,245,235,232,105,128,10,37,108,2,183,80,183,89,225,242,225,226,233,99,128,6,48,230,233,238,225,236,225,242,225,226,233,99,128,254,172,238,244,232,225,235,232,225,116,3,183,118,183,149,183,156,236,239,119,2,183,126,183,137,236,229,230,244,244,232,225,105,128,248,152,242,233,231,232,244,244,232,225,105,128,248,151,244,232,225,105,128,14,76,245,240,240,229,242,236,229,230,244,244,232,225,105,128,248,150,101,3,183,180,183,244,184,11,104,4,183,190,183,199,183,213,183,229,225,242,225,226,233,99,128,6,43,230,233,238,225,236,225,242,225,226,233,99,128,254,154,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,155,237,229,228,233,225,236,225,242,225,226,233,99,128,254,156,242,101,2,183,251,184,4,229])
.concat([248,233,243,244,115,128,34,3,230,239,242,101,128,34,52,244,97,130,3,184,184,20,184,24,49,128,3,209,243,249,237,226,239,236,231,242,229,229,107,128,3,209,105,2,184,44,184,130,229,245,244,104,4,184,57,184,92,184,107,184,116,97,2,184,63,184,78,227,233,242,227,236,229,235,239,242,229,225,110,128,50,121,240,225,242,229,238,235,239,242,229,225,110,128,50,25,227,233,242,227,236,229,235,239,242,229,225,110,128,50,107,235,239,242,229,225,110,128,49,76,240,225,242,229,238,235,239,242,229,225,110,128,50,11,242,244,229,229,110,2,184,140,184,149,227,233,242,227,236,101,128,36,108,112,2,184,155,184,162,225,242,229,110,128,36,128,229,242,233,239,100,128,36,148,111,6,184,184,184,201,184,206,184,220,184,225,185,22,238,225,238,231,237,239,238,244,232,239,244,232,225,105,128,14,17,239,107,128,1,173,240,232,245,244,232,225,239,244,232,225,105,128,14,18,242,110,128,0,254,244,104,3,184,234,185,2,185,12,97,2,184,240,184,250,232,225,238,244,232,225,105,128,14,23,238,244,232,225,105,128,14,16,239,238,231,244,232,225,105,128,14,24,245,238,231,244,232,225,105,128,14,22,245,243,225,238,100,2,185,32,185,43,227,249,242,233,236,236,233,99,128,4,130,243,243,229,240,225,242,225,244,239,114,2,185,58,185,67,225,242,225,226,233,99,128,6,108,240,229,242,243,233,225,110,128,6,108,242,229,101,144,0,51,185,115,185,124,185,134,185,164,185,171,185,181,185,206,185,233,186,11,186,23,186,42,186,53,186,86,186,108,186,116,186,127,225,242,225,226,233,99,128,6,99,226,229,238,231,225,236,105,128,9,233,227,233,242,227,236,101,129,36,98,185,145,233,238,246,229,242,243,229,243,225,238,243,243,229,242,233,102,128,39,140,228,229,246,97,128,9,105,229,233,231,232,244,232,115,128,33,92,231,117,2,185,188,185,197,234,225,242,225,244,105,128,10,233,242,237,245,235,232,105,128,10,105,232,97,2,185,213,185,224,227,235,225,242,225,226,233,99,128,6,99,238,231,250,232,239,117,128,48,35,105,2,185,239,186,1,228,229,239,231,242,225,240,232,233,227,240,225,242,229,110,128,50,34,238,230,229,242,233,239,114,128,32,131,237,239,238,239,243,240,225,227,101,128,255,19,238,245,237,229,242,225,244,239,242,226,229,238,231,225,236,105,128,9,246,239,236,228,243,244,249,236,101,128,247,51,112,2,186,59,186,66,225,242,229,110,128,36,118,229,114,2,186,73,186,79,233,239,100,128,36,138,243,233,225,110,128,6,243,241,245,225,242,244,229,242,115,129,0,190,186,99,229,237,228,225,243,104,128,246,222,242,239,237,225,110,128,33,114,243,245,240,229,242,233,239,114,128,0,179,244,232,225,105,128,14,83,250,243,241,245,225,242,101,128,51,148,105,7,186,160,186,171,187,30,187,128,187,140,187,189,187,206,232,233,242,225,231,225,238,97,128,48,97,107,2,186,177,186,201,225,244,225,235,225,238,97,129,48,193,186,189,232,225,236,230,247,233,228,244,104,128,255,129,229,245,116,4,186,213,186,248,187,7,187,16,97,2,186,219,186,234,227,233,242,227,236,229,235,239,242,229,225,110,128,50,112,240,225,242,229,238,235,239,242,229,225,110,128,50,16,227,233,242,227,236,229,235,239,242,229,225,110,128,50,98,235,239,242,229,225,110,128,49,55,240,225,242,229,238,235,239,242,229,225,110,128,50,2,236,228,101,133,2,220,187,46,187,57,187,74,187,86,187,114,226,229,236,239,247,227,237,98,128,3,48,99,2,187,63,187,68,237,98,128,3,3,239,237,98,128,3,3,228,239,245,226,236,229,227,237,98,128,3,96,111,2,187,92,187,102,240,229,242,225,244,239,114,128,34,60,246,229,242,236,225,249,227,237,98,128,3,52,246,229,242,244,233,227,225,236,227,237,98,128,3,62,237,229,243,227,233,242,227,236,101,128,34,151,112,2,187,146,187,176,229,232,97,2,187,154,187,163,232,229,226,242,229,119,128,5,150,236,229,230,244,232,229,226,242,229,119,128,5,150,240,233,231,245,242,237,245,235,232,105,128,10,112,244,236,239,227,249,242,233,236,236,233,227,227,237,98,128,4,131,247,238,225,242,237,229,238,233,225,110,128,5,127,236,233,238,229,226,229,236,239,119,128,30,111,237,239,238,239,243,240,225,227,101,128,255,84,111,7,188,3,188,14,188,25,188,50,188,170,188,182,189,10,225,242,237,229,238,233,225,110,128,5,105,232,233,242,225,231,225,238,97,128,48,104,235,225,244,225,235,225,238,97,129,48,200,188,38,232,225,236,230,247,233,228,244,104,128,255,132,110,3,188,58,188,156,188,161,101,4,188,68,188,137,188,144,188,150,226,225,114,4,188,80,188,109,188,119,188,128,229,248,244,242,97,2,188,90,188,100,232,233,231,232,237,239,100,128,2,229,236,239,247,237,239,100,128,2,233,232,233,231,232,237,239,100,128,2,230,236,239,247,237,239,100,128,2,232,237,233,228,237,239,100,128,2,231,230,233,246,101,128,1,189,243,233,120,128,1,133,244,247,111,128,1,168,239,115,128,3,132,243,241,245,225,242,101,128,51,39,240,225,244,225,235,244,232,225,105,128,14,15,242,244,239,233,243,229,243,232,229,236,236,226,242,225,227,235,229,116,2,188,205,188,235,236,229,230,116,130,48,20,188,216,188,224,243,237,225,236,108,128,254,93,246,229,242,244,233,227,225,108,128,254,57,242,233,231,232,116,130,48,21,188,247,188,255,243,237,225,236,108,128,254,94,246,229,242,244,233,227,225,108,128,254,58,244,225,239,244,232,225,105,128,14,21,240,97,2,189,27,189,39,236,225,244,225,236,232,239,239,107,128,1,171,242,229,110,128,36,175,114,3,189,53,189,84,189,99,225,228,229,237,225,242,107,129,33,34,189,65,115,2,189,71,189,77,225,238,115,128,248,234,229,242,233,102,128,246,219,229,244,242,239,230,236,229,248,232,239,239,107,128,2,136,233,225,103,4,189,111,189,116,189,121,189,126,228,110,128,37,188,236,102,128,37,196,242,116,128,37,186,245,112,128,37,178,115,132,2,166,189,143,189,182,190,32,190,45,225,228,105,130,5,230,189,153,189,173,228,225,231,229,243,104,129,251,70,189,164,232,229,226,242,229,119,128,251,70,232,229,226,242,229,119,128,5,230,101,2,189,188,189,199,227,249,242,233,236,236,233,99,128,4,70,242,101,134,5,181,189,216,189,230,189,235,189,244,190,3,190,19,49,2,189,222,189,226,50,128,5,181,101,128,5,181,178,98,128,5,181,232,229,226,242,229,119,128,5,181,238,225,242,242,239,247,232,229,226,242,229,119,128,5,181,241,245,225,242,244,229,242,232,229,226,242,229,119,128,5,181,247,233,228,229,232,229,226,242,229,119,128,5,181,232,229,227,249,242,233,236,236,233,99,128,4,91,245,240,229,242,233,239,114,128,246,243,116,4,190,65,190,115,190,180,190,231,97,3,190,73,190,83,190,90,226,229,238,231,225,236,105,128,9,159,228,229,246,97,128,9,31,231,117,2,190,97,190,106,234,225,242,225,244,105,128,10,159,242,237,245,235,232,105,128,10,31,229,104,4,190,126,190,135,190,149,190,165,225,242,225,226,233,99,128,6,121,230,233,238,225,236,225,242,225,226,233,99,128,251,103,233,238,233,244,233,225,236,225,242,225,226,233,99,128,251,104,237,229,228,233,225,236,225,242,225,226,233,99,128,251,105,232,97,3,190,189,190,199,190,206,226,229,238,231,225,236,105,128,9,160,228,229,246,97,128,9,32,231,117,2,190,213,190,222,234,225,242,225,244,105,128,10,160,242,237,245,235,232,105,128,10,32,245,242,238,229,100,128,2,135,117,3,190,247,191,2,191,27,232,233,242,225,231,225,238,97,128,48,100,235,225,244,225,235,225,238,97,129,48,196,191,15,232,225,236,230,247,233,228,244,104,128,255,130,243,237,225,236,108,2,191,37,191,48,232,233,242,225,231,225,238,97,128,48,99,235,225,244,225,235,225,238,97,129,48,195,191,61,232,225,236,230,247,233,228,244,104,128,255,111,119,2,191,79,191,184,101,2,191,85,191,133,236,246,101,3,191,95,191,104,191,125,227,233,242,227,236,101,128,36,107,112,2,191,110,191,117,225,242,229,110,128,36,127,229,242,233,239,100,128,36,147,242,239,237,225,110,128,33,123,238,244,121,3,191,143,191,152,191,163,227,233,242,227,236,101,128,36,115,232,225,238,231,250,232,239,117,128,83,68,112,2,191,169,191,176,225,242,229,110,128,36,135,229,242,233,239,100,128,36,155,111,142,0,50,191,216,191,225,191,235,192,9,192,61,192,86,192,113,192,147,192,159,192,178,192,189,192,222,192,230,192,254,225,242,225,226,233,99,128,6,98,226,229,238,231,225,236,105,128,9,232,227,233,242,227,236,101,129,36,97,191,246,233,238,246,229,242,243,229,243,225,238,243,243,229,242,233,102,128,39,139,100,2,192,15,192,21,229,246,97,128,9,104,239,116,2,192,28,192,39,229,238,236,229,225,228,229,114,128,32,37,236,229,225,228,229,114,129,32,37,192,50,246,229,242,244,233,227,225,108,128,254,48,231,117,2,192,68,192,77,234,225,242,225,244,105,128,10,232,242,237,245,235,232,105,128,10,104,232,97,2,192,93,192,104,227,235,225,242,225,226,233,99,128,6,98,238,231,250,232,239,117,128,48,34,105,2,192,119,192,137,228,229,239,231,242,225,240,232,233,227,240,225,242,229,110,128,50,33,238,230,229,242,233,239,114,128,32,130,237,239,238,239,243,240,225,227,101,128,255,18,238,245,237,229,242,225,244,239,242,226,229,238,231,225,236,105,128,9,245,239,236,228,243,244,249,236,101,128,247,50,112,2,192,195,192,202,225,242,229,110,128,36,117,229,114,2,192,209,192,215,233,239,100,128,36,137,243,233,225,110,128,6,242,242,239,237,225,110,128,33,113,115,2,192,236,192,244,244,242,239,235,101,128,1,187,245,240,229,242,233,239,114,128,0,178,244,104,2,193,5,193,10,225,105,128,14,82,233,242,228,115,128,33,84,117,145,0,117,193,55,193,63,193,104,193,161,194,43,194,80,194,203,194,219,195,14,195,84,195,165,195,174,196,37,196,61,196,169,196,197,197,55,225,227,245,244,101,128,0,250,98,4,193,73,193,78,193,87,193,97,225,114,128,2,137,229,238,231,225,236,105,128,9,137,239,240,239,237,239,230,111,128,49,40,242,229,246,101,128,1,109,99,3,193,112,193,119,193,151,225,242,239,110,128,1,212,233,242,99,2,193,127,193,132,236,101,128,36,228,245,237,230,236,229,120,129,0,251,193,143,226,229,236,239,119,128,30,119,249,242,233,236,236,233,99,128,4,67,100,5,193,173,193,184,193,207,193,213,194,33,225,244,244,225,228,229,246,97,128,9,81,226,108,2,193,191,193,199,225,227,245,244,101,128,1,113,231,242,225,246,101,128,2,21,229,246,97,128,9,9,233,229,242,229,243,233,115,133,0,252,193,233,193,241,193,249,194,16,194,24,225,227,245,244,101,128,1,216,226,229,236,239,119,128,30,115,99,2,193,255,194,6,225,242,239,110,128,1,218,249,242,233,236,236,233,99,128,4,241,231,242,225,246,101,128,1,220,237,225,227,242,239,110,128,1,214,239,244,226,229,236,239,119,128,30,229,103,2,194,49,194,56,242,225,246,101,128,0,249,117,2,194,62,194,71,234,225,242,225,244,105,128,10,137,242,237,245,235,232,105,128,10,9,104,3,194,88,194,98,194,176,233,242,225,231,225,238,97,128,48,70,111,2,194,104,194,114,239,235,225,226,239,246,101,128,30,231,242,110,133,1,176,194,129,194,137,194,148,194,156,194,168,225,227,245,244,101,128,30,233,228,239,244,226,229,236,239,119,128,30,241,231,242,225,246,101,128,30,235,232,239,239,235,225,226,239,246,101,128,30,237,244,233,236,228,101,128,30,239,245,238,231,225,242,245,237,236,225,245,116,129,1,113,194,192,227,249,242,233,236,236,233,99,128,4,243,233,238,246,229,242,244,229,228,226,242,229,246,101,128,2,23,107,3,194,227,194,251,195,6,225,244,225,235,225,238,97,129,48,166,194,239,232,225,236,230,247,233,228,244,104,128,255,115,227,249,242,233,236,236,233,99,128,4,121,239,242,229,225,110,128,49,92,109,2,195,20,195,73,97,2,195,26,195,59,227,242,239,110,130,1,107,195,37,195,48,227,249,242,233,236,236,233,99,128,4,239,228,233,229,242,229,243,233,115,128,30,123,244,242,225,231,245,242,237,245,235,232,105,128,10,65,239,238,239,243,240,225,227,101,128,255,85,110,2,195,90,195,145,228,229,242,243,227,239,242,101,132,0,95,195,109,195,115,195,127,195,138,228,226,108,128,32,23,237,239,238,239,243,240,225,227,101,128,255,63,246,229,242,244,233,227,225,108,128,254,51,247,225,246,121,128,254,79,105,2,195,151,195,156,239,110,128,34,42,246,229,242,243,225,108,128,34,0,239,231,239,238,229,107,128,1,115,112,5,195,186,195,193,195,201,195,216,196,11,225,242,229,110,128,36,176,226,236,239,227,107,128,37,128,240,229,242,228,239,244,232,229,226,242,229,119,128,5,196,243,233,236,239,110,131,3,197,195,230,195,251,196,3,228,233,229,242,229,243,233,115,129,3,203,195,243,244,239,238,239,115,128,3,176,236,225,244,233,110,128,2,138,244,239,238,239,115,128,3,205,244,225,227,107,2,196,20,196,31,226,229,236,239,247,227,237,98,128,3,29,237,239,100,128,2,212,114,2,196,43,196,55,225,231,245,242,237,245,235,232,105,128,10,115,233,238,103,128,1,111,115,3,196,69,196,84,196,129,232,239,242,244,227,249,242,233,236,236,233,99,128,4,94,237,225,236,108,2,196,93,196,104,232,233,242,225,231,225,238,97,128,48,69,235,225,244,225,235,225,238,97,129,48,165,196,117,232,225,236,230,247,233,228,244,104,128,255,105,244,242,225,233,231,232,116,2,196,141,196,152,227,249,242,233,236,236,233,99,128,4,175,243,244,242,239,235,229,227,249,242,233,236,236,233,99,128,4,177,244,233,236,228,101,130,1,105,196,181,196,189,225,227,245,244,101,128,30,121,226,229,236,239,119,128,30,117,117,5,196,209,196,219,196,226,196,251,197,11,226,229,238,231,225,236,105,128,9,138,228,229,246,97,128,9,10,231,117,2,196,233,196,242,234,225,242,225,244,105,128,10,138,242,237,245,235,232,105,128,10,10,237,225,244,242,225,231,245,242,237,245,235,232,105,128,10,66,246,239,247,229,236,243,233,231,110,3,197,27,197,37,197,44,226,229,238,231,225,236,105,128,9,194,228,229,246,97,128,9,66,231,245,234,225,242,225,244,105,128,10,194,246,239,247,229,236,243,233,231,110,3,197,71,197,81,197,88,226,229,238,231,225,236,105,128,9,193,228,229,246,97,128,9,65,231,245,234,225,242,225,244,105,128,10,193,118,139,0,118,197,125,198,17,198,26,198,37,198,222,198,229,199,71,199,83,199,183,199,191,199,212,97,4,197,135,197,142,197,167,197,178,228,229,246,97,128,9,53,231,117,2,197,149,197,158,234,225,242,225,244,105,128,10,181,242,237,245,235,232,105,128,10,53,235,225,244,225,235,225,238,97,128,48,247,118,132,5,213,197,190,197,217,197,249,198,5,228,225,231,229,243,104,130,251,53,197,203,197,208,182,53,128,251,53,232,229,226,242,229,119,128,251,53,104,2,197,223,197,231,229,226,242,229,119,128,5,213,239,236,225,109,129,251,75,197,240,232,229,226,242,229,119,128,251,75,246,225,246,232,229,226,242,229,119,128,5,240,249,239,228,232,229,226,242,229,119,128,5,241,227,233,242,227,236,101,128,36,229,228,239,244,226,229,236,239,119,128,30,127,101,6,198,51,198,62,198,126,198,137,198,143,198,210,227,249,242,233,236,236,233,99,128,4,50,104,4,198,72,198,81,198,95,198,111,225,242,225,226,233,99,128,6,164,230,233,238,225,236,225,242,225,226,233,99,128,251,107,233,238,233,244,233,225,236,225,242,225,226,233,99,128,251,108,237,229,228,233,225,236,225,242,225,226,233,99,128,251,109,235,225,244,225,235,225,238,97,128,48,249,238,245,115,128,38,64,242,244,233,227,225,108,2,198,154,198,160,226,225,114,128,0,124,236,233,238,101,4,198,173,198,184,198,195,198,204,225,226,239,246,229,227,237,98,128,3,13,226,229,236,239,247,227,237,98,128,3,41,236,239,247,237,239,100,128,2,204,237,239,100,128,2,200,247,225,242,237,229,238,233,225,110,128,5,126,232,239,239,107,128,2,139,105,3,198,237,198,248,199,31,235,225,244,225,235,225,238,97,128,48,248,242,225,237,97,3,199,3,199,13,199,20,226,229,238,231,225,236,105,128,9,205,228,229,246,97,128,9,77,231,245,234,225,242,225,244,105,128,10,205,243,225,242,231,97,3,199,43,199,53,199,60,226,229,238,231,225,236,105,128,9,131,228,229,246,97,128,9,3,231,245,234,225,242,225,244,105,128,10,131,237,239,238,239,243,240,225,227,101,128,255,86,111,3,199,91,199,102,199,172,225,242,237,229,238,233,225,110,128,5,120,233,227,229,100,2,199,111,199,147,233,244,229,242,225,244,233,239,110,2,199,125,199,136,232,233,242,225,231,225,238,97,128,48,158,235,225,244,225,235,225,238,97,128,48,254,237,225,242,235,235,225,238,97,129,48,155,199,160,232,225,236,230,247,233,228,244,104,128,255,158,235,225,244,225,235,225,238,97,128,48,250,240,225,242,229,110,128,36,177,116,2,199,197,199,204,233,236,228,101,128,30,125,245,242,238,229,100,128,2,140,117,2,199,218,199,229,232,233,242,225,231,225,238,97,128,48,148,235,225,244,225,235,225,238,97,128,48,244,119,143,0,119,200,18,200,251,201,5,201,28,201,68,201,135,201,143,203,114,203,155,203,167,203,242,203,250,204,1,204,12,204,21,97,8,200,36,200,43,200,53,200,64,200,102,200,134,200,146,200,182,227,245,244,101,128,30,131,229,235,239,242,229,225,110,128,49,89,232,233,242,225,231,225,238,97,128,48,143,107,2,200,70,200,94,225,244,225,235,225,238,97,129,48,239,200,82,232,225,236,230,247,233,228,244,104,128,255,156,239,242,229,225,110,128,49,88,243,237,225,236,108,2,200,112,200,123,232,233,242,225,231,225,238,97,128,48,142,235,225,244,225,235,225,238,97,128,48,238,244,244,239,243,241,245,225,242,101,128,51,87,118,2,200,152,200,160,229,228,225,243,104,128,48,28,249,245,238,228,229,242,243,227,239,242,229,246,229,242,244,233,227,225,108,128,254,52,119,3,200,190,200,199,200,213,225,242,225,226,233,99,128,6,72,230,233,238,225,236,225,242,225,226,233,99,128,254,238,232,225,237,250,225,225,226,239,246,101,2,200,228,200,237,225,242,225,226,233,99,128,6,36,230,233,238,225,236,225,242,225,226,233,99,128,254,134,226,243,241,245,225,242,101,128,51,221,227,233,242,99,2,201,14,201,19,236,101,128,36,230,245,237,230,236,229,120,128,1,117,100,2,201,34,201,44,233,229,242,229,243,233,115,128,30,133,239,116,2,201,51,201,60,225,227,227,229,238,116,128,30,135,226,229,236,239,119,128,30,137,101,4,201,78,201,89,201,101,201,125,232,233,242,225,231,225,238,97,128,48,145,233,229,242,243,244,242,225,243,115,128,33,24,107,2,201,107,201,117,225,244,225,235,225,238,97,128,48,241,239,242,229,225,110,128,49,94,239,235,239,242,229,225,110,128,49,93,231,242,225,246,101,128,30,129,232,233,244,101,8,201,164,201,173,202,1,202,91,202,175,202,220,203,16,203,72,226,245,236,236,229,116,128,37,230,99,2,201,179,201,199,233,242,227,236,101,129,37,203,201,189,233,238,246,229,242,243,101,128,37,217,239,242,238,229,242,226,242,225,227,235,229,116,2,201,216,201,236,236,229,230,116,129,48,14,201,225,246,229,242,244,233,227,225,108,128,254,67,242,233,231,232,116,129,48,15,201,246,246,229,242,244,233,227,225,108,128,254,68,100,2,202,7,202,48,233,225,237,239,238,100,129,37,199,202,18,227,239,238,244,225,233,238,233,238,231,226,236,225,227,235,243,237,225,236,236,228,233,225,237,239,238,100,128,37,200,239,247,238,240,239,233,238,244,233,238,103,2,202,64,202,80,243,237,225,236,236,244,242,233,225,238,231,236,101,128,37,191,244,242,233,225,238,231,236,101,128,37,189,236,101,2,202,98,202,140,230,244,240,239,233,238,244,233,238,103,2,202,113,202,129,243,237,225,236,236,244,242,233,225,238,231,236,101,128,37,195,244,242,233,225,238,231,236,101,128,37,193,238,244,233,227,245,236,225,242,226,242,225,227,235,229,116,2,202,160,202,167,236,229,230,116,128,48,22,242,233,231,232,116,128,48,23,242,233,231,232,244,240,239,233,238,244,233,238,103,2,202,193,202,209,243,237,225,236,236,244,242,233,225,238,231,236,101,128,37,185,244,242,233,225,238,231,236,101,128,37,183,115,3,202,228,203,2,203,10,109,2,202,234,202,246,225,236,236,243,241,245,225,242,101,128,37,171,233,236,233,238,231,230,225,227,101,128,38,58,241,245,225,242,101,128,37,161,244,225,114,128,38,6,116,2,203,22,203,33,229,236,229,240,232,239,238,101,128,38,15,239,242,244,239,233,243,229,243,232,229,236,236,226,242,225,227,235,229,116,2,203,57,203,64,236,229,230,116,128,48,24,242,233,231,232,116,128,48,25,245,240,240,239,233,238,244,233,238,103,2,203,87,203,103,243,237,225,236,236,244,242,233,225,238,231,236,101,128,37,181,244,242,233,225,238,231,236,101,128,37,179,105,2,203,120,203,131,232,233,242,225,231,225,238,97,128,48,144,107,2,203,137,203,147,225,244,225,235,225,238,97,128,48,240,239,242,229,225,110,128,49,95,237,239,238,239,243,240,225,227,101,128,255,87,111,4,203,177,203,188,203,213,203,231,232,233,242,225,231,225,238,97,128,48,146,235,225,244,225,235,225,238,97,129,48,242,203,201,232,225,236,230,247,233,228,244,104,128,255,102,110,129,32,169,203,219,237,239,238,239,243,240,225,227,101,128,255,230,247,225,229,238,244,232,225,105,128,14,39,240,225,242,229,110,128,36,178,242,233,238,103,128,30,152,243,245,240,229,242,233,239,114,128,2,183,244,245,242,238,229,100,128,2,141,249,238,110,128,1,191,120,137,0,120,204,49,204,60,204,71,204,80,204,107,204,120,204,124,204,136,204,144,225,226,239,246,229,227,237,98,128,3,61,226,239,240,239,237,239,230,111,128,49,18,227,233,242,227,236,101,128,36,231,100,2,204,86,204,96,233,229,242,229,243,233,115,128,30,141,239,244,225,227,227,229,238,116,128,30,139,229,232,225,242,237,229,238,233,225,110,128,5,109,105,128,3,190,237,239,238,239,243,240,225,227,101,128,255,88,240,225,242,229,110,128,36,179,243,245,240,229,242,233,239,114,128,2,227,121,143,0,121,204,189,205,148,205,171,205,211,207,177,207,185,207,202,208,10,208,22,209,19,209,59,209,71,209,82,209,103,210,76,97,11,204,213,204,225,204,235,204,242,204,249,205,3,205,28,205,39,205,77,205,90,205,136,225,228,239,243,241,245,225,242,101,128,51,78,226,229,238,231,225,236,105,128,9,175,227,245,244,101,128,0,253,228,229,246,97,128,9,47,229,235,239,242,229,225,110,128,49,82,231,117,2,205,10,205,19,234,225,242,225,244,105,128,10,175,242,237,245,235,232,105,128,10,47,232,233,242,225,231,225,238,97,128,48,132,107,2,205,45,205,69,225,244,225,235,225,238,97,129,48,228,205,57,232,225,236,230,247,233,228,244,104,128,255,148,239,242,229,225,110,128,49,81,237,225,235,235,225,238,244,232,225,105,128,14,78,243,237,225,236,108,2,205,100,205,111,232,233,242,225,231,225,238,97,128,48,131,235,225,244,225,235,225,238,97,129,48,227,205,124,232,225,236,230,247,233,228,244,104,128,255,108,244,227,249,242,233,236,236,233,99,128,4,99,227,233,242,99,2,205,157,205,162,236,101,128,36,232,245,237,230,236,229,120,128,1,119,100,2,205,177,205,187,233,229,242,229,243,233,115,128,0,255,239,116,2,205,194,205,203,225,227,227,229,238,116,128,30,143,226,229,236,239,119,128,30,245,101,7,205,227,206,235,206,244,207,6,207,38,207,114,207,165,104,8,205,245,205,254,206,32,206,46,206,119,206,135,206,194,206,212,225,242,225,226,233,99,128,6,74,226,225,242,242,229,101,2,206,9,206,18,225,242,225,226,233,99,128,6,210,230,233,238,225,236,225,242,225,226,233,99,128,251,175,230,233,238,225,236,225,242,225,226,233,99,128,254,242,232,225,237,250,225,225,226,239,246,101,4,206,65,206,74,206,88,206,104,225,242,225,226,233,99,128,6,38,230,233,238,225,236,225,242,225,226,233,99,128,254,138,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,139,237,229,228,233,225,236,225,242,225,226,233,99,128,254,140,233,238,233,244,233,225,236,225,242,225,226,233,99,128,254,243,237,101,2,206,142,206,155,228,233,225,236,225,242,225,226,233,99,128,254,244,229,237,105,2,206,163,206,178,238,233,244,233,225,236,225,242,225,226,233,99,128,252,221,243,239,236,225,244,229,228,225,242,225,226,233,99,128,252,88,238,239,239,238,230,233,238,225,236,225,242,225,226,233,99,128,252,148,244,232,242,229,229,228,239,244,243,226,229,236,239,247,225,242,225,226,233,99,128,6,209,235,239,242,229,225,110,128,49,86,110,129,0,165,206,250,237,239,238,239,243,240,225,227,101,128,255,229,111,2,207,12,207,21,235,239,242,229,225,110,128,49,85,242,233,238,232,233,229,245,232,235,239,242,229,225,110,128,49,134,114,3,207,46,207,82,207,94,225,232,226,229,238,249,239,237,111,2,207,60,207,69,232,229,226,242,229,119,128,5,170,236,229,230,244,232,229,226,242,229,119,128,5,170,233,227,249,242,233,236,236,233,99,128,4,75,245,228,233,229,242,229,243,233,243,227,249,242,233,236,236,233,99,128,4,249,243,233,229,245,238,103,3,207,127,207,136,207,152,235,239,242,229,225,110,128,49,129,240,225,238,243,233,239,243,235,239,242,229,225,110,128,49,131,243,233,239,243,235,239,242,229,225,110,128,49,130,244,233,246,232,229,226,242,229,119,128,5,154,231,242,225,246,101,128,30,243,232,239,239,107,129,1,180,207,194,225,226,239,246,101,128,30,247,105,5,207,214,207,225,207,236,207,245,207,253,225,242,237,229,238,233,225,110,128,5,117,227,249,242,233,236,236,233,99,128,4,87,235,239,242,229,225,110,128,49,98,238,249,225,238,103,128,38,47,247,238,225,242,237,229,238,233,225,110,128,5,130,237,239,238,239,243,240,225,227,101,128,255,89,111,7,208,38,208,108,208,119,208,129,208,167,208,213,208,222,100,131,5,217,208,48,208,68,208,77,228,225,231,229,243,104,129,251,57,208,59,232,229,226,242,229,119,128,251,57,232,229,226,242,229,119,128,5,217,249,239,100,2,208,85,208,94,232,229,226,242,229,119,128,5,242,240,225,244,225,232,232,229,226,242,229,119,128,251,31,232,233,242,225,231,225,238,97,128,48,136,233,235,239,242,229,225,110,128,49,137,107,2,208,135,208,159,225,244,225,235,225,238,97,129,48,232,208,147,232,225,236,230,247,233,228,244,104,128,255,150,239,242,229,225,110,128,49,91,243,237,225,236,108,2,208,177,208,188,232,233,242,225,231,225,238,97,128,48,135,235,225,244,225,235,225,238,97,129,48,231,208,201,232,225,236,230,247,233,228,244,104,128,255,110,244,231,242,229,229,107,128,3,243,121,2,208,228,209,9,97,2,208,234,208,244,229,235,239,242,229,225,110,128,49,136,107,2,208,250,209,2,239,242,229,225,110,128,49,135,244,232,225,105,128,14,34,233,238,231,244,232,225,105,128,14,13,112,2,209,25,209,32,225,242,229,110,128,36,180,239,231,229,231,242,225,237,237,229,238,105,129,3,122,209,48,231,242,229,229,235,227,237,98,128,3,69,114,129,1,166,209,65,233,238,103,128,30,153,243,245,240,229,242,233,239,114,128,2,184,116,2,209,88,209,95,233,236,228,101,128,30,249,245,242,238,229,100,128,2,142,117,5,209,115,209,126,209,136,209,174,210,50,232,233,242,225,231,225,238,97,128,48,134,233,235,239,242,229,225,110,128,49,140,107,2,209,142,209,166,225,244,225,235,225,238,97,129,48,230,209,154,232,225,236,230,247,233,228,244,104,128,255,149,239,242,229,225,110,128,49,96,115,3,209,182,209,220,210,5,226,233,103,2,209,190,209,201,227,249,242,233,236,236,233,99,128,4,107,233,239,244,233,230,233,229,228,227,249,242,233,236,236,233,99,128,4,109,236,233,244,244,236,101,2,209,231,209,242,227,249,242,233,236,236,233,99,128,4,103,233,239,244,233,230,233,229,228,227,249,242,233,236,236,233,99,128,4,105,237,225,236,108,2,210,14,210,25,232,233,242,225,231,225,238,97,128,48,133,235,225,244,225,235,225,238,97,129,48,229,210,38,232,225,236,230,247,233,228,244,104,128,255,109,249,101,2,210,57,210,66,235,239,242,229,225,110,128,49,139,239,235,239,242,229,225,110,128,49,138,249,97,2,210,83,210,93,226,229,238,231,225,236,105,128,9,223,228,229,246,97,128,9,95,122,142,0,122,210,132,211,140,211,151,211,194,211,221,213,0,213,108,213,150,213,162,213,174,213,202,213,210,213,226,213,235,97,10,210,154,210,165,210,172,210,179,210,190,211,12,211,42,211,53,211,89,211,101,225,242,237,229,238,233,225,110,128,5,102,227,245,244,101,128,1,122,228,229,246,97,128,9,91,231,245,242,237,245,235,232,105,128,10,91,104,4,210,200,210,209,210,223,210,253,225,242,225,226,233,99,128,6,56,230,233,238,225,236,225,242,225,226,233,99,128,254,198,105,2,210,229,210,244,238,233,244,233,225,236,225,242,225,226,233,99,128,254,199,242,225,231,225,238,97,128,48,86,237,229,228,233,225,236,225,242,225,226,233,99,128,254,200,233,110,2,211,19,211,28,225,242,225,226,233,99,128,6,50,230,233,238,225,236,225,242,225,226,233,99,128,254,176,235,225,244,225,235,225,238,97,128,48,182,241,229,102,2,211,61,211,75,231,225,228,239,236,232,229,226,242,229,119,128,5,149,241,225,244,225,238,232,229,226,242,229,119,128,5,148,242,241,225,232,229,226,242,229,119,128,5,152,249,233,110,130,5,214,211,111,211,131,228,225,231,229,243,104,129,251,54,211,122,232,229,226,242,229,119,128,251,54,232,229,226,242,229,119,128,5,214,226,239,240,239,237,239,230,111,128,49,23,99,3,211,159,211,166,211,188,225,242,239,110,128,1,126,233,242,99,2,211,174,211,179,236,101,128,36,233,245,237,230,236,229,120,128,30,145,245,242,108,128,2,145,228,239,116,130,1,124,211,204,211,213,225,227,227,229,238,116,128,1,124,226,229,236,239,119,128,30,147,101,6,211,235,211,246,212,33,212,44,212,55,212,251,227,249,242,233,236,236,233,99,128,4,55,100,2,211,252,212,15,229,243,227,229,238,228,229,242,227,249,242,233,236,236,233,99,128,4,153,233,229,242,229,243,233,243,227,249,242,233,236,236,233,99,128,4,223,232,233,242,225,231,225,238,97,128,48,92,235,225,244,225,235,225,238,97,128,48,188,242,111,140,0,48,212,84,212,93,212,103,212,110,212,135,212,148,212,159,212,171,212,182,212,192,212,203,212,210,225,242,225,226,233,99,128,6,96,226,229,238,231,225,236,105,128,9,230,228,229,246,97,128,9,102,231,117,2,212,117,212,126,234,225,242,225,244,105,128,10,230,242,237,245,235,232,105,128,10,102,232,225,227,235,225,242,225,226,233,99,128,6,96,233,238,230,229,242,233,239,114,128,32,128,237,239,238,239,243,240,225,227,101,128,255,16,239,236,228,243,244,249,236,101,128,247,48,240,229,242,243,233,225,110,128,6,240,243,245,240,229,242,233,239,114,128,32,112,244,232,225,105,128,14,80,247,233,228,244,104,3,212,222,212,231,212,243,234,239,233,238,229,114,128,254,255,238,239,238,234,239,233,238,229,114,128,32,12,243,240,225,227,101,128,32,11,244,97,128,3,182,104,2,213,6,213,17,226,239,240,239,237,239,230,111,128,49,19,101,4,213,27,213,38,213,54,213,65,225,242,237,229,238,233,225,110,128,5,106,226,242,229,246,229,227,249,242,233,236,236,233,99,128,4,194,227,249,242,233,236,236,233,99,128,4,54,100,2,213,71,213,90,229,243,227,229,238,228,229,242,227,249,242,233,236,236,233,99,128,4,151,233,229,242,229,243,233,243,227,249,242,233,236,236,233,99,128,4,221,105,3,213,116,213,127,213,138,232,233,242,225,231,225,238,97,128,48,88,235,225,244,225,235,225,238,97,128,48,184,238,239,242,232,229,226,242,229,119,128,5,174,236,233,238,229,226,229,236,239,119,128,30,149,237,239,238,239,243,240,225,227,101,128,255,90,111,2,213,180,213,191,232,233,242,225,231,225,238,97,128,48,94,235,225,244,225,235,225,238,97,128,48,190,240,225,242,229,110,128,36,181,242,229,244,242,239,230,236,229,248,232,239,239,107,128,2,144,243,244,242,239,235,101,128,1,182,117,2,213,241,213,252,232,233,242,225,231,225,238,97,128,48,90,235,225,244,225,235,225,238,97,128,48,186,0,24,0,0,0,202,1,0,0,0,0,0,0,186,3,0,0,122,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,47,81,0,120,47,81,0,56,47,81,0,128,14,81,0,208,46,81,0,132,14,81,0,168,46,81,0,148,14,81,0,0,0,0,0,0,0,0,0,154,2,0,0,44,1,0,0,132,2,0,0,0,0,0,0,0,0,0,0,214,0,0,0,52,1,0,0,254,1,0,0,128,45,81,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,43,81,0,0,0,0,0,3,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,42,81,0,0,0,0,0,2,0,0,0,0,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,63,81,0,0,0,0,0,5,0,0,0,0,0,0,0,12,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,62,81,0,0,0,0,0,5,0,0,0,0,0,0,0,16,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,62,81,0,0,0,0,0,2,0,0,0,0,0,0,0,20,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,81,0,0,0,0,0,2,0,0,0,0,0,0,0,72,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,61,81,0,0,0,0,0,2,0,0,0,0,0,0,0,144,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,61,81,0,0,0,0,0,2,0,0,0,0,0,0,0,148,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,60,81,0,0,0,0,0,2,0,0,0,0,0,0,0,152,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,60,81,0,0,0,0,0,2,0,0,0,0,0,0,0,156,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,60,81,0,3,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,59,81,0,3,0,0,0,5,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,59,81,0,3,0,0,0,5,0,0,0,0,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,59,81,0,3,0,0,0,5,0,0,0,0,0,0,0,12,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,58,81,0,3,0,0,0,5,0,0,0,0,0,0,0,16,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,58,81,0,3,0,0,0,2,0,0,0,0,0,0,0,20,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,188,57,81,0,3,0,0,0,1,0,0,0,0,0,0,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,57,81,0,3,0,0,0,2,0,0,0,0,0,0,0,26,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,57,81,0,3,0,0,0,2,0,0,0,0,0,0,0,28,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,56,81,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,56,81,0,1,0,0,0,2,0,0,0,0,0,0,0,212,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,56,81,0,1,0,0,0,2,0,0,0,0,0,0,0,213,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,56,81,0,1,0,0,0,2,0,0,0,0,0,0,0,244,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,55,81,0,1,0,0,0,2,0,0,0,0,0,0,0,248,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,55,81,0,1,0,0,0,2,0,0,0,0,0,0,0,240,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,54,81,0,1,0,0,0,2,0,0,0,0,0,0,0,196,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,54,81,0,1,0,0,0,3,0,0,0,0,0,0,0,200,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,54,81,0,1,0,0,0,3,0,0,0,0,0,0,0,204,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,81,0,4,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,53,81,0,4,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,53,81,0,4,0,0,0,2,0,0,0,0,0,0,0,184,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,53,81,0,4,0,0,0,2,0,0,0,0,0,0,0,188,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,53,81,0,4,0,0,0,4,0,0,0,0,0,0,0,108,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,53,81,0,4,0,0,0,2,0,0,0,0,0,0,0,112,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,52,81,0,4,0,0,0,2,0,0,0,0,0,0,0,116,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,52,81,0,4,0,0,0,8,0,0,0,0,0,0,0,12,0,0,0,2,0,0,0,14,0,0,0,8,0,0,0,0,0,0,0,40,52,81,0,4,0,0,0,8,0,0,0,0,0,0,0,40,0,0,0,2,0,0,0,10,0,0,0,9,0,0,0,0,0,0,0,252,51,81,0,4,0,0,0,8,0,0,0,0,0,0,0,60,0,0,0,2,0,0,0,14,0,0,0,10,0,0,0,0,0,0,0,204,51,81,0,4,0,0,0,8,0,0,0,0,0,0,0,88,0,0,0,2,0,0,0,10,0,0,0,11,0,0,0,0,0,0,0,144,51,81,0,4,0,0,0,8,0,0,0,0,0,0,0,120,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,84,51,81,0,4,0,0,0,8,0,0,0,0,0,0,0,122,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,48,51,81,0,4,0,0,0,8,0,0,0,0,0,0,0,192,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,228,50,81,0,4,0,0,0,8,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,12,0,0,0,124,0,0,0,0,0,0,0,148,50,81,0,4,0,0,0,8,0,0,0,0,0,0,0,154,0,0,0,2,0,0,0,12,0,0,0,125,0,0,0,0,0,0,0,52,50,81,0,4,0,0,0,1,0,0,0,0,0,0,0,126,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,49,81,0,5,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,49,81,0,5,0,0,0,10,0,0,0,132,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,49,81,0,5,0,0,0,10,0,0,0,144,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,49,81,0,5,0,0,0,10,0,0,0,246,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,16,0,16,4,0,0,16,4,4,0,16,4,8,0,16,4,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,0,64,0,65,0,66,0,67,0,68,0,69,0,70,0,71,0,72,0,73,0,74,0,75,0,76,0,77,0,78,0,79,0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,0,88,0,89,0,90,0,91,0,92,0,93,0,94,0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,97,0,98,0,99,0,100,0,101,0,102,0,103,0,104,0,105,0,106,0,107,0,108,0,109,0,110,0,0,0,111,0,112,0,113,0,114,0,0,0,115,0,116,0,117,0,118,0,119,0,120,0,121,0,122,0,0,0,123,0,0,0,124,0,125,0,126,0,127,0,128,0,129,0,130,0,131,0,0,0,132,0,133,0,0,0,134,0,135,0,136,0,137,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,138,0,0,0,139,0,0,0,0,0,0,0,0,0,140,0,141,0,142,0,143,0,0,0,0,0,0,0,0,0,0,0,144,0,0,0,0,0,0,0,145,0,0,0,0,0,146,0,147,0,148,0,149,0,0,0,0,0,0,0,0,0,16,45,81,0,184,43,81,0,116,42,81,0,32,24,81,0,160,63,81,0,28,24,81,0,172,62,81,0])
.concat([48,24,81,0,68,62,81,0,56,24,81,0,212,61,81,0,60,24,81,0,0,0,0,0,0,0,0,0,74,1,0,0,144,0,0,0,0,0,0,0,46,2,0,0,0,0,0,0,74,0,0,0,252,1,0,0,98,3,0,0,98,0,0,0,106,2,0,0,182,2,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,0,64,0,65,0,66,0,67,0,68,0,69,0,70,0,71,0,72,0,73,0,74,0,75,0,76,0,77,0,78,0,79,0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,0,88,0,89,0,90,0,91,0,92,0,93,0,94,0,95,0,96,0,97,0,98,0,99,0,100,0,101,0,102,0,103,0,104,0,105,0,106,0,107,0,108,0,109,0,110,0,111,0,112,0,113,0,114,0,115,0,116,0,117,0,118,0,119,0,120,0,121,0,122,0,123,0,124,0,125,0,126,0,127,0,128,0,129,0,130,0,131,0,132,0,133,0,134,0,135,0,136,0,137,0,138,0,139,0,140,0,141,0,142,0,143,0,144,0,145,0,146,0,147,0,148,0,149,0,150,0,151,0,152,0,153,0,154,0,155,0,156,0,157,0,158,0,159,0,160,0,161,0,162,0,163,0,164,0,165,0,166,0,167,0,168,0,169,0,170,0,171,0,172,0,173,0,174,0,175,0,176,0,177,0,178,0,179,0,180,0,181,0,182,0,183,0,184,0,185,0,186,0,187,0,188,0,189,0,190,0,191,0,192,0,193,0,194,0,195,0,196,0,197,0,198,0,199,0,200,0,201,0,202,0,203,0,204,0,205,0,206,0,207,0,208,0,209,0,210,0,211,0,212,0,213,0,214,0,215,0,216,0,217,0,218,0,219,0,220,0,221,0,222,0,223,0,224,0,225,0,226,0,227,0,228,0,0,0,4,0,4,0,8,1,16,0,8,1,17,0,8,1,18,0,8,1,19,0,0,0,0,0,4,0,0,0,0,16,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,16,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,17,0,0,8,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,2,16,0,0,12,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,3,16,0,0,16,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,16,0,0,20,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,1,17,0,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,17,0,0,28,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,3,17,0,0,32,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,4,17,0,0,36,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,17,0,0,40,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,6,17,0,0,44,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,7,17,0,0,0,0,0,0,0,0,0,0,68,3,0,0,0,0,0,0,0,0,0,0,1,0,0,0,13,16,0,0,76,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,5,16,0,0,0,0,0,0,0,0,0,0,32,2,0,0,0,0,0,0,0,0,0,0,1,0,0,0,8,17,0,0,96,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,15,16,0,0,100,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,16,16,0,0,104,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,17,16,0,0,108,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,18,16,0,0,0,0,0,0,0,0,0,0,136,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,20,17,0,0,120,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,21,17,0,0,124,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,30,17,0,0,0,0,0,0,0,0,0,0,136,2,0,0,0,0,0,0,0,0,0,0,1,0,0,0,31,17,0,0,140,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,32,17,0,0,144,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,33,17,0,0,148,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,34,17,0,0,152,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,35,17,0,0,156,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,36,17,0,0,160,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,37,17,0,0,164,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,38,17,0,0,168,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,6,32,0,0,4,0,0,0,4,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,6,0,0,0,7,32,0,0,60,0,0,0,4,0,0,0,0,0,0,0,10,0,0,0,1,0,0,0,6,0,0,0,8,32,0,0,100,0,0,0,4,0,0,0,0,0,0,0,14,0,0,0,2,0,0,0,6,0,0,0,9,32,0,0,156,0,0,0,4,0,0,0,0,0,0,0,10,0,0,0,3,0,0,0,3,0,0,0,9,33,0,0,196,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,10,33,0,0,200,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,11,33,0,0,204,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,10,32,0,0,208,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,11,32,0,0,212,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,12,33,0,0,220,0,0,0,4,0,0,0,0,0,0,0,13,0,0,0,216,0,0,0,6,0,0,0,13,33,0,0,16,1,0,0,4,0,0,0,0,0,0,0,13,0,0,0,217,0,0,0,5,0,0,0,14,33,0,0,68,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,15,33,0,0,72,1,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,16,33,0,0,76,1,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,17,33,0,0,80,1,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,18,33,0,0,84,1,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,19,33,0,0,88,1,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,19,32,0,0,92,1,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,20,32,0,0,96,1,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,21,32,0,0,100,1,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,0,232,0,235,0,236,0,237,0,238,0,13,0,14,0,15,0,99,0,239,0,240,0,241,0,242,0,243,0,244,0,245,0,246,0,247,0,248,0,27,0,28,0,249,0,250,0,251,0,253,0,254,0,255,0,0,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,109,0,110,0,11,1,12,1,13,1,14,1,16,1,44,1,45,1,46,1,49,1,58,1,59,1,158,0,155,0,163,0,64,1,65,1,66,1,67,1,68,1,69,1,70,1,150,0,164,0,169,0,71,1,72,1,73,1,74,1,75,1,76,1,77,1,78,1,79,1,80,1,81,1,82,1,83,1,84,1,85,1,86,1,87,1,88,1,89,1,90,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,0,230,0,0,0,231,0,232,0,233,0,234,0,235,0,236,0,237,0,238,0,13,0,14,0,15,0,99,0,239,0,240,0,241,0,242,0,243,0,244,0,245,0,246,0,247,0,248,0,27,0,28,0,249,0,250,0,251,0,252,0,0,0,253,0,254,0,255,0,0,1,1,1,0,0,0,0,0,0,2,1,0,0,0,0,3,1,4,1,5,1,6,1,0,0,0,0,7,1,8,1,9,1,0,0,10,1,109,0,110,0,11,1,12,1,13,1,0,0,14,1,15,1,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,37,1,38,1,39,1,40,1,41,1,42,1,43,1,44,1,45,1,46,1,47,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,1,49,1,50,1,0,0,0,0,51,1,52,1,53,1,54,1,55,1,0,0,56,1,0,0,0,0,56,1,0,0,0,0,58,1,59,1,0,0,0,0,60,1,61,1,62,1,0,0,0,0,0,0,158,0,155,0,163,0,63,1,64,1,65,1,66,1,67,1,68,1,69,1,0,0,0,0,70,1,150,0,164,0,169,0,71,1,72,1,73,1,74,1,75,1,76,1,77,1,78,1,79,1,80,1,81,1,82,1,83,1,84,1,85,1,86,1,87,1,88,1,89,1,90,1,91,1,92,1,93,1,94,1,95,1,96,1,97,1,98,1,99,1,100,1,101,1,102,1,103,1,104,1,105,1,106,1,107,1,108,1,109,1,110,1,111,1,112,1,113,1,114,1,115,1,116,1,117,1,118,1,119,1,120,1,121,1,122,1,0,0,1,0,229,0,230,0,231,0,232,0,233,0,234,0,235,0,236,0,237,0,238,0,13,0,14,0,15,0,99,0,239,0,240,0,241,0,242,0,243,0,244,0,245,0,246,0,247,0,248,0,27,0,28,0,249,0,250,0,251,0,252,0,253,0,254,0,255,0,0,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,109,0,110,0,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,37,1,38,1,39,1,40,1,41,1,42,1,43,1,44,1,45,1,46,1,47,1,48,1,49,1,50,1,51,1,52,1,53,1,54,1,55,1,56,1,57,1,58,1,59,1,60,1,61,1,62,1,158,0,155,0,163,0,63,1,64,1,65,1,66,1,67,1,68,1,69,1,70,1,150,0,164,0,169,0,71,1,72,1,73,1,74,1,75,1,76,1,77,1,78,1,79,1,80,1,81,1,82,1,83,1,84,1,85,1,86,1,87,1,88,1,89,1,90,1,91,1,92,1,93,1,94,1,95,1,96,1,97,1,98,1,99,1,100,1,101,1,102,1,103,1,104,1,105,1,106,1,107,1,108,1,109,1,110,1,111,1,112,1,113,1,114,1,115,1,116,1,117,1,118,1,119,1,120,1,121,1,122,1,1,5,0,0,44,0,0,0,248,52,81,0,0,0,1,0,0,0,2,0,0,0,0,0,62,0,0,0,220,1,0,0,22,3,0,0,56,3,0,0,48,0,0,0,172,0,0,0,66,2,0,0,156,1,0,0,220,0,0,0,140,1,0,0,226,0,0,0,132,3,0,0,112,1,0,0,136,3,0,0,174,3,0,0,202,2,0,0,0,0,0,0,184,1,0,0,74,2,0,0,10,1,0,0,24,0,0,0,134,1,0,0,226,1,0,0,166,2,0,0,190,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,24,0,0,0,4,3,0,0,180,0,0,0,128,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,193,193,32,32,32,32,32,32,32,32,32,32,13,7,9,11,128,130,130,130,130,128,128,0,1,2,2,2,1,0,2,1,1,1,2,1,2,1,2,1,4,3,2,2,1,2,4,1,1,0,2,0,0,0,5,4,2,0,192,54,81,0,228,36,81,0,48,63,81,0,28,63,81,0,0,0,0,0,0,0,0,0,208,2,0,0,124,2,0,0,1,2,0,0,40,0,0,0,192,54,81,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,12,3,0,0,168,0,0,0,44,0,0,0,160,0,0,0,178,3,0,0,158,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,1,0,0,136,3,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,3,0,0,50,0,0,0,24,0,0,0,168,0,0,0,156,2,0,0,166,1,0,0,78,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,204,0,0,0,20,55,81,0,0,0,1,0,0,0,2,0,92,41,81,0,238,2,0,0,42,1,0,0,0,0,0,0,84,0,0,0,38,0,0,0,56,3,0,0,236,53,81,0,180,51,81,0,240,48,81,0,92,46,81,0,180,44,81,0,88,43,81,0,12,42,81,0,92,63,81,0,148,62,81,0,56,62,81,0,176,61,81,0,88,61,81,0,248,60,81,0,168,60,81,0,88,60,81,0,0,60,81,0,164,59,81,0,76,59,81,0,172,58,81,0,100,58,81,0,76,58,81,0,240,57,81,0,156,57,81,0,248,56,81,0,196,56,81,0,184,56,81,0,112,56,81,0,32,56,81,0,224,55,81,0,120,55,81,0,176,54,81,0,160,54,81,0,88,54,81,0,24,54,81,0,232,53,81,0,164,53,81,0,160,53,81,0,96,53,81,0,52,53,81,0,232,52,81,0,164,52,81,0,72,52,81,0,12,52,81,0,228,51,81,0,168,51,81,0,104,51,81,0,20,51,81,0,248,50,81,0,208,60,81,0,192,50,81,0,96,50,81,0,8,50,81,0,100,49,81,0,84,49,81,0,40,49,81,0,232,48,81,0,168,48,81,0,120,48,81,0,8,48,81,0,4,48,81,0,168,47,81,0,92,47,81,0,12,47,81,0,184,46,81,0,140,46,81,0,88,46,81,0,60,46,81,0,28,46,81,0,0,46,81,0,216,45,81,0,152,45,81,0,96,45,81,0,48,45,81,0,248,44,81,0,116,40,81,0,192,39,81,0,60,41,81,0,84,40,81,0,0,0,0,0,32,0,0,0,127,0,0,0,160,0,0,0,255,0,0,0,0,1,0,0,127,1,0,0,128,1,0,0,79,2,0,0,80,2,0,0,175,2,0,0,176,2,0,0,255,2,0,0,0,3,0,0,111,3,0,0,112,3,0,0,255,3,0,0,0,4,0,0,255,4,0,0,0,5,0,0,47,5,0,0,0,29,0,0,127,29,0,0,128,29,0,0,191,29,0,0,192,29,0,0,255,29,0,0,0,30,0,0,255,30,0,0,0,31,0,0,255,31,0,0,0,32,0,0,111,32,0,0,112,32,0,0,159,32,0,0,160,32,0,0,207,32,0,0,80,33,0,0,143,33,0,0,96,36,0,0,255,36,0,0,96,44,0,0,127,44,0,0,224,45,0,0,255,45,0,0,64,166,0,0,159,166,0,0,32,167,0,0,255,167,0,0,0,251,0,0,6,251,0,0,0,212,1,0,255,215,1,0,0,0,0,0,0,0,0,0,1,0,0,0,232,38,81,0,64,3,0,0,96,2,0,0,160,2,0,0,0,0,0,0,240,2,0,0,240,1,0,0,99,105,110,117,110,109,114,97,66,79,68,65,49,116,97,108,0,0,0,0,84,72,69,90,79,67,81,83,0,0,0,0,0,72,69,90,76,79,67,85,83,0,0,0,0,0,102,105,106,107,100,98,104,0,0,0,0,0,0,120,122,114,111,101,115,99,0,0,0,0,0,0,120,122,114,111,101,115,99,0,0,0,0,0,0,112,113,103,106,121,0,0,0,0,0,0,0,0,0,0,0,9,0,0,255,13,0,0,0,0,0,0,0,0,0,0,3,0,0,0,68,40,81,0,64,3,0,0,78,2,0,0,132,0,0,0,0,0,0,0,54,3,0,0,148,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,238,0,0,0,4,2,0,0,128,46,0,0,255,46,0,0,0,47,0,0,223,47,0,0,0,48,0,0,63,48,0,0,64,48,0,0,159,48,0,0,160,48,0,0,255,48,0,0,0,49,0,0,47,49,0,0,48,49,0,0,143,49,0,0,160,49,0,0,191,49,0,0,192,49,0,0,239,49,0,0,240,49,0,0,255,49,0,0,0,50,0,0,255,50,0,0,0,51,0,0,255,51,0,0,0,52,0,0,191,77,0,0,192,77,0,0,255,77,0,0,0,78,0,0,255,159,0,0,0,249,0,0,255,250,0,0,48,254,0,0,79,254,0,0,0,255,0,0,239,255,0,0,0,0,2,0,223,166,2,0,0,248,2,0,31,250,2,0,0,0,0,0,0,0,0,0,2,0,0,0,148,40,81,0,64,3,0,0,130,3,0,0,198,0,0,0,0,0,0,0,80,2,0,0,108,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,0,0,0,0,0,0,0,10,11,12,13,14,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,11,12,13,14,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,85,66,83,67,82,73,80,84,95,89,0,114,97,115,116,101,114,49,0,83,85,66,83,67,82,73,80,84,95,88,0,66,108,101,110,100,68,101,115,105,103,110,80,111,115,105,116,105,111,110,115,0,0,0,0,83,85,66,83,67,82,73,80,84,95,83,73,90,69,0,0,83,84,82,73,75,69,79,85,84,95,68,69,83,67,69,78,84,0,0,0,83,84,82,73,75,69,79,85,84,95,65,83,67,69,78,84,0,0,0,0,112,115,110,97,109,101,115,0,82,69,83,79,76,85,84,73,79,78,95,89,0,0,0,0,112,111,115,116,115,99,114,105,112,116,45,105,110,102,111,0,83,77,65,76,76,95,67,65,80,95,83,73,90,69,0,0,67,72,65,82,83,69,84,95,69,78,67,79,68,73,78,71,0,0,0,0,82,69,83,79,76,85,84,73,79,78,0,0,70,117,108,108,78,97,109,101,0,0,0,0,82,69,76,65,84,73,86,69,95,87,69,73,71,72,84,0,67,73,68,70,111,110,116,84,121,112,101,0,112,115,104,105,110,116,101,114,0,0,0,0,99,108,111,115,101,102,105,108,101,0,0,0,79,112,116,105,99,97,108,83,105,122,101,0,82,69,76,65,84,73,86,69,95,83,69,84,87,73,68,84,72,0,0,0,82,65,87,95,88,95,72,69,73,71,72,84,0,0,0,0,37,0,0,0,82,65,87,95,85,78,68,69,82,76,73,78,69,95,84,72,73,67,75,78,69,83,83,0,82,65,87,95,85,78,68,69,82,76,73,78,69,95,80,79,83,73,84,73,79,78,0,0,66,108,101,110,100,68,101,115,105,103,110,77,97,112,0,0,82,65,87,95,83,85,80,69,82,83,67,82,73,80,84,95,89,0,0,0,82,65,87,95,83,85,80,69,82,83,67,82,73,80,84,95,88,0,0,0,82,65,87,95,83,85,80,69,82,83,67,82,73,80,84,95,83,73,90,69,0,0,0,0,82,69,83,79,76,85,84,73,79,78,95,88,0,0,0,0,67,70,70,0,82,65,87,95,83,85,66,83,67,82,73,80,84,95,89,0,67,72,65,82,83,69,84,95,82,69,71,73,83,84,82,89,0,0,0,0,82,65,87,95,83,85,66,83,67,82,73,80,84,95,88,0,78,111,116,105,99,101,0,0,67,73,68,70,111,110,116,86,101,114,115,105,111,110,0,0,82,65,87,95,83,85,66,83,67,82,73,80,84,95,83,73,90,69,0,0,101,101,120,101,99,0,0,0,87,105,100,116,104,0,0,0,112,111,115,116,115,99,114,105,112,116,45,99,109,97,112,115,0,0,0,0,82,65,87,95,83,84,82,73,75,69,79,85,84,95,68,69,83,67,69,78,84,0,0,0,82,65,87,95,83,84,82,73,75,69,79,85,84,95,65,83,67,69,78,84,0,0,0,0,46,65,112,112,108,101,68,111,117,98,108,101,47,0,0,0,82,65,87,95,83,77,65,76,76,95,67,65,80,95,83,73,90,69,0,0,82,65,87,95,81,85,65,68,95,87,73,68,84,72,0,0,82,65,87,95,80,79,73,78,84,83,73,90,69,0,0,0,66,108,101,110,100,65,120,105,115,84,121,112,101,115,0,0,82,65,87,95,80,73,88,69,76,83,73,90,69,0,0,0,112,111,115,116,115,99,114,105,112,116,45,99,109,97,112,115,0,0,0,0,82,65,87,95,80,79,73,78,84,95,83,73,90,69,0,0,88,72,101,105,103,104,116,0,82,65,87,95,80,73,88,69,76,95,83,73,90,69,0,0,120,102,56,54,45,100,114,105,118,101,114,45,110,97,109,101,0,0,0,0,80,73,88,69,76,95,83,73,90,69,0,0,87,101,105,103,104,116,86,101,99,116,111,114,0,0,0,0,82,69,83,79,76,85,84,73,79,78,95,89,0,0,0,0,82,65,87,95,78,79,82,77,95,83,80,65,67,69,0,0,87,101,105,103,104,116,0,0,118,101,114,115,105,111,110,0,82,65,87,95,77,73,78,95,83,80,65,67,69,0,0,0,67,73,68,70,111,110,116,78,97,109,101,0,79,112,116,105,99,97,108,83,105,122,101,0,87,89,0,0,46,110,111,116,100,101,102,0,82,65,87,95,77,65,88,95,83,80,65,67,69,0,0,0,87,101,105,103,104,116,0,0,87,105,100,116,104,0,0,0,67,72,65,82,83,69,84,95,69,78,67,79,68,73,78,71,0,0,0,0,87,88,0,0,82,65,87,95,70,73,71,85,82,69,95,87,73,68,84,72,0,0,0,0,109,117,108,116,105,45,109,97,115,116,101,114,115,0,0,0,87,49,89,0,82,65,87,95,69,78,68,95,83,80,65,67,69,0,0,0,107,101,114,110,105,110,103,0,87,49,88,0,82,65,87,95,68,69,83,67,69,78,84,0,112,111,115,116,115,99,114,105,112,116,45,105,110,102,111,0,87,49,0,0,82,65,87,95,67,65,80,95,72,69,73,71,72,84,0,0,84,121,112,101,32,49,0,0,87,48,89,0,66,0,0,0,82,65,87,95,65,86,71,95,76,79,87,69,82,67,65,83,69,95,87,73,68,84,72,0,120,102,56,54,45,100,114,105,118,101,114,45,110,97,109,101,0,0,0,0,87,48,88,0,82,65,87,95,65,86,71,95,67,65,80,73,84,65,76,95,87,73,68,84,72,0,0,0,67,73,68,0,103,108,121,112,104,45,100,105,99,116,0,0,87,48,0,0,82,65,87,95,65,86,69,82,65,71,69,95,87,73,68,84,72,0,0,0,112,111,115,116,115,99,114,105,112,116,45,105,110,102,111,0,66,108,97,99,107,0,0,0,112,111,115,116,115,99,114,105,112,116,45,102,111,110,116,45,110,97,109,101,0,0,0,0,80,79,73,78,84,95,83,73,90,69,0,0,87,0,0,0,82,69,83,79,76,85,84,73,79,78,95,88,0,0,0,0,82,65,87,95,65,83,67,69,78,84,0,0,87,105,110,100,111,119,115,32,70,78,84,0,112,111,115,116,115,99,114,105,112,116,45,102,111,110,116,45,110,97,109,101,0,0,0,0,37,33,70,111,110,116,84,121,112,101,0,0,86,101,114,115,105,111,110,0,107,110,111,119,110,0,0,0,81,85,65,68,95,87,73,68,84,72,0,0,67,73,68,32,84,121,112,101,32,49,0,0,37,65,68,79,66,101,103,105,110,70,111,110,116,68,105,99,116,0,0,0,37,33,80,83,45,65,100,111,98,101,70,111,110,116,0,0,86,86,101,99,116,111,114,0,66,108,97,99,107,0,0,0,78,79,84,73,67,69,0,0,116,116,45,103,108,121,102,0,120,102,56,54,45,100,114,105,118,101,114,45,110,97,109,101,0,0,0,0,73,83,79,76,97,116,105,110,49,69,110,99,111,100,105,110,103,0,0,0,67,72,65,82,83,69,84,95,82,69,71,73,83,84,82,89,0,0,0,0,86,86,0,0,85,110,100,101,114,108,105,110,101,84,104,105,99,107,110,101,115,115,0,0,78,79,82,77,95,83,80,65,67,69,0,0,40,72,101,120,41,0,0,0,69,120,112,101,114,116,69,110,99,111,100,105,110,103,0,0,112,115,97,117,120,0,0,0,116,121,112,101,52,50,0,0,77,73,78,95,83,80,65,67,69,0,0,0,47,115,102,110,116,115,0,0,83,116,97,110,100,97,114,100,69,110,99,111,100,105,110,103,0,0,0,0,85,110,100,101,114,108,105,110,101,80,111,115,105,116,105,111,110,0,0,0,77,65,88,95,83,80,65,67,69,0,0,0,83,116,97,114,116,68,97,116,97,0,0,0,112,117,116,0,84,114,97,99,107,75,101,114,110,0,0,0,73,84,65,76,73,67,95,65,78,71,76,69,0,0,0,0,37,33,80,83,45,65,100,111,98,101,45,51,46,48,32,82,101,115,111,117,114,99,101,45,67,73,68,70,111,110,116,0,100,117,112,0,83,116,100,86,87,0,0,0,65,120,105,115,84,121,112,101,0,0,0,0,70,85,76,76,95,78,65,77,69,0,0,0,69,120,112,97,110,115,105,111,110,70,97,99,116,111,114,0,66,117,105,108,100,67,104,97,114,65,114,114,97,121,0,0,83,116,100,72,87,0,0,0,70,79,85,78,68,82,89,0,70,111,110,116,77,97,116,114,105,120,0,0,87,101,105,103,104,116,86,101,99,116,111,114,0,0,0,0,83,116,97,114,116,84,114,97,99,107,75,101,114,110,0,0,83,116,97,114,116,75,101,114,110,80,97,105,114,115,49,0,70,79,78,84,78,65,77,69,95,82,69,71,73,83,84,82,89,0,0,0,70,68,65,114,114,97,121,0,66,111,108,100,0,0,0,0,66,108,101,110,100,65,120,105,115,84,121,112,101,115,0,0,65,86,69,82,65,71,69,95,87,73,68,84,72,0,0,0,112,102,114,0,80,73,88,69,76,95,83,73,90,69,0,0,70,73,71,85,82,69,95,87,73,68,84,72,0,0,0,0,120,102,56,54,45,100,114,105,118,101,114,45,110,97,109,101,0,0,0,0,70,111,110,116,66,66,111,120,0,0,0,0,66,108,101,110,100,68,101,115,105,103,110,77,97,112,0,0,83,116,97,114,116,75,101,114,110,80,97,105,114,115,48,0,70,111,110,116,68,105,114,101,99,116,111,114,121,0,0,0,70,65,67,69,95,78,65,77,69,0,0,0,70,111,114,99,101,66,111,108,100,0,0,0,66,108,97,99,107,0,0,0,66,108,101,110,100,68,101,115,105,103,110,80,111,115,105,116,105,111,110,115,0,0,0,0,83,116,97,114,116,75,101,114,110,80,97,105,114,115,0,0,66,111,108,100,0,0,0,0,69,78,68,95,83,80,65,67,69,0,0,0,116,114,117,101,116,121,112,101,45,101,110,103,105,110,101,0,83,116,101,109,83,110,97,112,86,0,0,0,80,114,105,118,97,116,101,0,116,116,45,99,109,97,112,115,0,0,0,0,116,116,45,99,109,97,112,115,0,0,0,0,83,116,97,114,116,75,101,114,110,68,97,116,97,0,0,0,68,69,86,73,67,69,95,70,79,78,84,95,78,65,77,69,0,0,0,0,83,116,101,109,83,110,97,112,72,0,0,0,83,117,98,114,115,0,0,0,83,116,97,114,116,68,105,114,101,99,116,105,111,110,0,0,116,114,117,101,116,121,112,101,0,0,0,0,83,116,97,114,116,67,111,109,112,111,115,105,116,101,115,0,68,69,83,84,73,78,65,84,73,79,78,0,77,105,110,70,101,97,116,117,114,101,0,0,69,110,99,111,100,105,110,103,0,0,0,0,67,79,80,89,82,73,71,72,84,0,0,0,83,116,100,86,87,0,0,0,70,111,110,116,77,97,116,114,105,120,0,0,83,116,97,114,116,67,104,97,114,77,101,116,114,105,99,115,0,0,0,0,67,72,65,82,83,69,84,95,67,79,76,76,69,67,84,73,79,78,83,0,83,116,100,72,87,0,0,0,68,101,115,105,103,110,86,101,99,116,111,114,0,0,0,0,83,116,97,114,116,65,120,105,115,0,0,0,65,120,105,115,76,97,98,101,108,0,0,0,67,65,80,95,72,69,73,71,72,84,0,0,70,97,109,105,108,121,79,116,104,101,114,66,108,117,101,115,0,0,0,0,67,68,86,0,80,67,67,0,65,86,71,95,76,79,87,69,82,67,65,83,69,95,87,73,68,84,72,0,70,97,109,105,108,121,66,108,117,101,115,0,78,68,86,0,78,111,116,105,99,101,0,0,65,86,71,95,67,65,80,73,84,65,76,95,87,73,68,84,72,0,0,0,79,116,104,101,114,66,108,117,101,115,0,0,82,101,103,117,108,97,114,0,70,111,110,116,66,66,111,120,0,0,0,0,78,0,0,0,70,65,77,73,76,89,95,78,65,77,69,0,80,79,73,78,84,95,83,73,90,69,0,0,49,46,50,46,53,0,0,0,95,88,70,82,69,69,56,54,95,71,76,89,80,72,95,82,65,78,71,69,83,0,0,0,73,116,97,108,105,99,0,0,66,108,117,101,86,97,108,117,101,115,0,0,83,116,114,111,107,101,87,105,100,116,104,0,77,101,116,114,105,99,115,83,101,116,115,0,46,110,111,116,100,101,102,0,69,78,68,80,82,79,80,69,82,84,73,69,83,0,0,0,66,108,117,101,70,117,122,122,0,0,0,0,66,111,108,100,0,0,0,0,70,111,110,116,84,121,112,101,0,0,0,0,77,97,112,112,105,110,103,83,99,104,101,109,101,0,0,0,99,102,102,0,82,101,103,117,108,97,114,0,45,0,0,0,109,117,108,116,105,45,109,97,115,116,101,114,115,0,0,0,66,108,117,101,83,104,105,102,116,0,0,0,80,97,105,110,116,84,121,112,101,0,0,0,98,100,102,0,76,0,0,0,68,69,70,65,85,76,84,95,67,72,65,82,0,0,0,0,66,108,117,101,83,99,97,108,101,0,0,0,70,111,110,116,78,97,109,101,0,0,0,0,75,80,89,0,83,101,116,95,67,104,97,114,95,83,105,122,101,32,69,114,114,111,114,33,32,37,100,10,0,0,0,0,66,73,84,77,65,80,0,0,112,97,115,115,119,111,114,100,0,0,0,0,70,111,114,99,101,66,111,108,100,0,0,0,75,80,88,0,75,80,72,0,66,66,88,0,76,97,110,103,117,97,103,101,71,114,111,117,112,0,0,0,69,120,112,97,110,115,105,111,110,70,97,99,116,111,114,0,68,87,73,68,84,72,0,0,108,101,110,73,86,0,0,0,83,116,101,109,83,110,97,112,86,0,0,0,75,80,0,0,65,115,99,101,110,100,101,114,0,0,0,0,83,87,73,68,84,72,0,0,85,110,105,113,117,101,73,68,0,0,0,0,83,116,101,109,83,110,97,112,72,0,0,0,73,116,97,108,105,99,65,110,103,108,101,0,80,70,82,0,69,78,67,79,68,73,78,71,0,0,0,0,116,114,117,101,116,121,112,101,0,0,0,0,83,116,114,111,107,101,87,105,100,116,104,0,77,105,110,70,101,97,116,117,114,101,0,0,73,115,70,105,120,101,100,86,0,0,0,0,83,84,65,82,84,67,72,65,82,0,0,0,84,121,112,101,32,52,50,0,70,111,114,99,101,66,111,108,100,84,104,114,101,115,104,111,108,100,0,0,112,115,104,105,110,116,101,114,0,0,0,0,83,116,100,86,87,0,0,0,73,115,70,105,120,101,100,80,105,116,99,104,0,0,0,0,73,115,67,73,68,70,111,110,116,0,0,0,49,0,0,0,98,100,102,0,65,86,69,82,65,71,69,95,87,73,68,84,72,0,0,0,69,78,68,67,72,65,82,0,120,102,56,54,45,100,114,105,118,101,114,45,110,97,109,101,0,0,0,0,66,111,108,100,0,0,0,0,108,101,110,66,117,105,108,100,67,104,97,114,65,114,114,97,121,0,0,0,83,116,100,72,87,0,0,0,97,117,116,111,102,105,116,116,101,114,0,0,112,99,102,0,82,101,103,117,108,97,114,0,69,78,68,70,79,78,84,0,112,111,115,116,115,99,114,105,112,116,45,105,110,102,111,0,83,117,98,114,67,111,117,110,116,0,0,0,119,105,110,102,111,110,116,115,0,0,0,0,82,101,103,117,108,97,114,0,70,97,109,105,108,121,79,116,104,101,114,66,108,117,101,115,0,0,0,0,73,115,66,97,115,101,70,111,110,116,0,0,112,115,97,117,120,0,0,0,70,79,78,84,95,68,69,83,67,69,78,84,0,0,0,0,112,111,115,116,115,99,114,105,112,116,45,102,111,110,116,45,110,97,109,101,0,0,0,0,84,114,117,101,84,121,112,101,0,0,0,0,83,68,66,121,116,101,115,0,70,97,109,105,108,121,66,108,117,101,115,0,103,108,121,112,104,45,100,105,99,116,0,0,70,117,108,108,78,97,109,101,0,0,0,0,70,79,78,84,95,65,83,67,69,78,84,0,103,108,121,112,104,45,100,105,99,116,0,0,83,117,98,114,77,97,112,79,102,102,115,101,116,0,0,0,79,116,104,101,114,66,108,117,101,115,0,0,70,111,110,116,78,97,109,101,0,0,0,0,78,101,119,95,70,97,99,101,32,69,114,114,111,114,33,32,37,100,10,0,37,104,100,0,37,33,80,83,45,84,114,117,101,84,121,112,101,70,111,110,116,0,0,0,70,111,110,116,84,121,112,101,0,0,0,0,66,108,117,101,86,97,108,117,101,115,0,0,70,111,110,116,66,66,111,120,0,0,0,0,116,121,112,101,52,50,0,0,67,72,65,82,83,0,0,0,73,83,79,76,97,116,105,110,49,69,110,99,111,100,105,110,103,0,0,0,80,97,105,110,116,84,121,112,101,0,0,0,66,108,117,101,70,117,122,122,0,0,0,0,70,97,109,105,108,121,78,97,109,101,0,0,69,115,99,67,104,97,114,0,83,73,90,69,0,0,0,0,69,120,112,101,114,116,69,110,99,111,100,105,110,103,0,0,70,83,84,121,112,101,0,0,66,108,117,101,83,104,105,102,116,0,0,0,69,110,100,84,114,97,99,107,75,101,114,110,0,0,0,0,116,114,117,101,0,0,0,0,70,79,78,84,0,0,0,0,83,116,97,110,100,97,114,100,69,110,99,111,100,105,110,103,0,0,0,0,85,110,100,101,114,108,105,110,101,84,104,105,99,107,110,101,115,115,0,0,66,108,117,101,83,99,97,108,101,0,0,0,114,98,0,0,120,102,56,54,45,100,114,105,118,101,114,45,110,97,109,101,0,0,0,0,70,79,78,84,66,79,85,78,68,73,78,71,66,79,88,0,115,102,110,116,115,0,0,0,85,110,100,101,114,108,105,110,101,80,111,115,105,116,105,111,110,0,0,0,112,97,115,115,119,111,114,100,0,0,0,0,69,110,100,75,101,114,110,80,97,105,114,115,0,0,0,0,32,43,0,0,67,104,97,114,83,116,114,105,110,103,115,0,105,115,70,105,120,101,100,80,105,116,99,104,0,0,0,0,112,111,115,116,115,99,114,105,112,116,45,99,109,97,112,115,0,0,0,0,76,97,110,103,117,97,103,101,71,114,111,117,112,0,0,0,69,110,100,75,101,114,110,68,97,116,97,0,56,56,53,57,0,0,0,0,70,65,77,73,76,89,95,78,65,77,69,0,83,84,65,82,84,80,82,79,80,69,82,84,73,69,83,0,69,110,99,111,100,105,110,103,0,0,0,0,66,111,108,100,32,73,116,97,108,105,99,0,73,116,97,108,105,99,65,110,103,108,101,0,108,101,110,73,86,0,0,0,69,110,100,70,111,110,116,77,101,116,114,105,99,115,0,0,112,115,97,117,120,0,0,0,69,110,100,68,105,114,101,99,116,105,111,110,0,0,0,0,83,84,65,82,84,70,79,78,84,0,0,0,70,111,110,116,77,97,116,114,105,120,0,0,87,101,105,103,104,116,0,0,112,115,97,117,120,0,0,0,85,110,105,113,117,101,73,68,0,0,0,0,80,67,70,0,69,110,100,67,111,109,112,111,115,105,116,101,115,0,0,0,112,111,115,116,115,99,114,105,112,116,45,99,109,97,112,115,0,0,0,0,67,79,77,77,69,78,84,0,70,111,110,116,66,66,111,120,0,0,0,0,116,49,99,105,100,0,0,0,120,102,56,54,45,100,114,105,118,101,114,45,110,97,109,101,0,0,0,0,70,97,109,105,108,121,78,97,109,101,0,0,115,109,111,111,116,104,45,108,99,100,118,0,70,83,84,121,112,101,0,0,112,111,115,116,115,99,114,105,112,116,45,102,111,110,116,45,110,97,109,101,0,0,0,0,120,102,56,54,45,100,114,105,118,101,114,45,110,97,109,101,0,0,0,0,69,110,100,67,104,97,114,77,101,116,114,105,99,115,0,0,82,101,103,117,108,97,114,0,83,116,114,111,107,101,87,105,100,116,104,0,70,117,108,108,78,97,109,101,0,0,0,0,85,110,100,101,114,108,105,110,101,84,104,105,99,107,110,101,115,115,0,0,98,100,102,0,73,110,105,116,32,69,114,114,111,114,33,32,37,100,10,0,69,110,100,65,120,105,115,0,112,111,115,116,115,99,114,105,112,116,45,99,109,97,112,115,0,0,0,0,65,68,68,95,83,84,89,76,69,95,78,65,77,69,0,0,70,111,110,116,84,121,112,101,0,0,0,0,78,111,116,105,99,101,0,0,85,110,100,101,114,108,105,110,101,80,111,115,105,116,105,111,110,0,0,0,82,101,103,117,108,97,114,0,69,110,99,111,100,105,110,103,83,99,104,101,109,101,0,0,65,68,68,95,83,84,89,76,69,95,78,65,77,69,0,0,83,69,84,87,73,68,84,72,95,78,65,77,69,0,0,0,80,97,105,110,116,84,121,112,101,0,0,0,118,101,114,115,105,111,110,0,105,115,70,105,120,101,100,80,105,116,99,104,0,0,0,0,99,105,100,0,68,101,115,99,101,110,100,101,114,0,0,0,83,69,84,87,73,68,84,72,95,78,65,77,69,0,0,0,66,111,108,100,0,0,0,0,70,111,110,116,78,97,109,101,0,0,0,0,67,73,68,67,111,117,110,116,0,0,0,0,73,116,97,108,105,99,65,110,103,108,101,0,116,121,112,101,49,0,0,0,67,104,97,114,97,99,116,101,114,115,0,0,66,111,108,100,0,0,0,0,87,69,73,71,72,84,95,78,65,77,69,0,70,83,84,121,112,101,0,0,83,116,97,114,116,70,111,110,116,77,101,116,114,105,99,115,0,0,0,0,71,68,66,121,116,101,115,0,87,101,105,103,104,116,0,0,99,102,102,0,67,104,97,114,97,99,116,101,114,83,101,116,0,0,0,0,112,102,114,45,109,101,116,114,105,99,115,0,87,69,73,71,72,84,95,78,65,77,69,0,73,116,97,108,105,99,0,0,85,110,100,101,114,108,105,110,101,84,104,105,99,107,110,101,115,115,0,0,70,68,66,121,116,101,115,0,70,97,109,105,108,121,78,97,109,101,0,0,79,84,84,79,0,0,0,0,67,104,97,114,87,105,100,116,104,0,0,0,73,116,97,108,105,99,0,0,79,98,108,105,113,117,101,0,85,110,100,101,114,108,105,110,101,80,111,115,105,116,105,111,110,0,0,0,67,73,68,77,97,112,79,102,102,115,101,116,0,0,0,0,115,102,110,116,0,0,0,0,70,117,108,108,78,97,109,101,0,0,0,0,46,95,0,0,67,97,112,72,101,105,103,104,116,0,0,0,116,121,112,101,49,0,0,0,49,48,54,52,54,0,0,0,79,98,108,105,113,117,101,0,67,73,68,0,83,80,65,67,73,78,71,0,83,76,65,78,84,0,0,0,105,115,70,105,120,101,100,80,105,116,99,104,0,0,0,0,82,101,103,117,108,97,114,0,85,73,68,66,97,115,101,0,78,111,116,105,99,101,0,0,47,46,46,110,97,109,101,100,102,111,114,107,47,114,115,114,99,0,0,0,112,111,115,116,115,99,114,105,112,116,45,99,109,97,112,115,0,0,0,0,67,72,0,0,83,76,65,78,84,0,0,0,116,116,45,99,109,97,112,115,0,0,0,0,49,0,0,0,116,114,117,101,116,121,112,101,0,0,0,0,73,116,97,108,105,99,65,110,103,108,101,0,83,117,112,112,108,101,109,101,110,116,0,0,112,115,104,105,110,116,101,114,0,0,0,0,118,101,114,115,105,111,110,0,47,114,115,114,99,0,0,0,67,67,0,0,67,72,65,82,83,69,84,95,69,78,67,79,68,73,78,71,0,0,0,0,103,108,121,112,104,45,100,105,99,116,0,0,112,115,104,105,110,116,101,114,0,0,0,0,115,109,111,111,116,104,0,0,56,56,53,57,0,0,0,0,87,101,105,103,104,116,0,0,115,102,110,116,0,0,0,0,79,114,100,101,114,105,110,103,0,0,0,0,115,109,111,111,116,104,45,108,99,100,0,0,67,104,97,114,83,116,114,105,110,103,115,0,115,102,110,116,45,116,97,98,108,101,0,0,114,97,115,116,101,114,53,0,66,68,70,0,114,101,115,111,117,114,99,101,46,102,114,107,47,0,0,0,120,102,56,54,45,100,114,105,118,101,114,45,110,97,109,101,0,0,0,0,95,77,85,76,69,95,82,69,76,65,84,73,86,69,95,67,79,77,80,79,83,69,0,0,67,0,0,0,95,77,85,76,69,95,66,65,83,69,76,73,78,69,95,79,70,70,83,69,84,0,0,0,88,95,72,69,73,71,72,84,0,0,0,0,87,69,73,71,72,84,0,0,67,72,65,82,83,69,84,95,82,69,71,73,83,84,82,89,0,0,0,0,112,111,115,116,115,99,114,105,112,116,45,102,111,110,116,45,110,97,109,101,0,0,0,0,85,78,68,69,82,76,73,78,69,95,84,72,73,67,75,78,69,83,83,0,49,48,54,52,54,0,0,0,85,78,68,69,82,76,73,78,69,95,80,79,83,73,84,73,79,78,0,0,115,102,110,116,0,0,0,0,70,97,109,105,108,121,78,97,109,101,0,0,82,101,103,105])
.concat([115,116,114,121,0,0,0,0,83,85,80,69,82,83,67,82,73,80,84,95,89,0,0,0,70,111,110,116,68,105,114,101,99,116,111,114,121,0,0,0,83,108,97,110,116,0,0,0,83,85,80,69,82,83,67,82,73,80,84,95,88,0,0,0,83,85,80,69,82,83,67,82,73,80,84,95,83,73,90,69,0,0,0,0,46,114,101,115,111,117,114,99,101,47,0,0,117,115,97,103,101,58,32,37,115,32,102,111,110,116,32,115,97,109,112,108,101,45,116,101,120,116,32,119,105,100,116,104,32,104,101,105,103,104,116,32,97,110,103,108,101,10,0,0,78,111,110,45,48,115,58,32,37,100,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,59,81,0,1,0,0,0,1,0,0,0,0,0,0,0,196,54,81,0,2,0,0,0,1,0,0,0,0,0,0,0,20,52,81,0,2,0,0,0,1,0,0,0,0,0,0,0,232,51,81,0,2,0,0,0,1,0,0,0,0,0,0,0,192,51,81,0,2,0,0,0,1,0,0,0,0,0,0,0,124,51,81,0,1,0,0,0,1,0,0,0,0,0,0,0,148,42,81,0,1,0,0,0,1,0,0,0,0,0,0,0,204,43,81,0,1,0,0,0,1,0,0,0,0,0,0,0,208,58,81,0,1,0,0,0,1,0,0,0,0,0,0,0,72,51,81,0,1,0,0,0,1,0,0,0,0,0,0,0,56,53,81,0,3,0,0,0,1,0,0,0,0,0,0,0,36,51,81,0,3,0,0,0,1,0,0,0,0,0,0,0,208,50,81,0,1,0,0,0,1,0,0,0,0,0,0,0,120,50,81,0,2,0,0,0,1,0,0,0,0,0,0,0,40,50,81,0,1,0,0,0,1,0,0,0,0,0,0,0,4,58,81,0,1,0,0,0,1,0,0,0,0,0,0,0,200,49,81,0,2,0,0,0,1,0,0,0,0,0,0,0,16,57,81,0,1,0,0,0,1,0,0,0,0,0,0,0,116,49,81,0,1,0,0,0,1,0,0,0,0,0,0,0,236,55,81,0,2,0,0,0,1,0,0,0,0,0,0,0,140,55,81,0,2,0,0,0,1,0,0,0,0,0,0,0,48,49,81,0,1,0,0,0,1,0,0,0,0,0,0,0,252,48,81,0,1,0,0,0,1,0,0,0,0,0,0,0,180,48,81,0,2,0,0,0,1,0,0,0,0,0,0,0,140,48,81,0,2,0,0,0,1,0,0,0,0,0,0,0,80,48,81,0,2,0,0,0,1,0,0,0,0,0,0,0,28,48,81,0,2,0,0,0,1,0,0,0,0,0,0,0,184,47,81,0,1,0,0,0,1,0,0,0,0,0,0,0,188,49,81,0,2,0,0,0,1,0,0,0,0,0,0,0,88,52,81,0,2,0,0,0,1,0,0,0,0,0,0,0,108,47,81,0,2,0,0,0,1,0,0,0,0,0,0,0,32,47,81,0,2,0,0,0,1,0,0,0,0,0,0,0,188,46,81,0,2,0,0,0,1,0,0,0,0,0,0,0,144,46,81,0,2,0,0,0,1,0,0,0,0,0,0,0,96,46,81,0,2,0,0,0,1,0,0,0,0,0,0,0,64,46,81,0,2,0,0,0,1,0,0,0,0,0,0,0,32,46,81,0,2,0,0,0,1,0,0,0,0,0,0,0,4,46,81,0,2,0,0,0,1,0,0,0,0,0,0,0,220,45,81,0,2,0,0,0,1,0,0,0,0,0,0,0,164,45,81,0,2,0,0,0,1,0,0,0,0,0,0,0,112,45,81,0,2,0,0,0,1,0,0,0,0,0,0,0,80,45,81,0,2,0,0,0,1,0,0,0,0,0,0,0,0,45,81,0,2,0,0,0,1,0,0,0,0,0,0,0,232,44,81,0,2,0,0,0,1,0,0,0,0,0,0,0,196,44,81,0,2,0,0,0,1,0,0,0,0,0,0,0,164,44,81,0,2,0,0,0,1,0,0,0,0,0,0,0,148,44,81,0,2,0,0,0,1,0,0,0,0,0,0,0,128,44,81,0,2,0,0,0,1,0,0,0,0,0,0,0,88,44,81,0,2,0,0,0,1,0,0,0,0,0,0,0,64,44,81,0,2,0,0,0,1,0,0,0,0,0,0,0,8,44,81,0,2,0,0,0,1,0,0,0,0,0,0,0,224,43,81,0,2,0,0,0,1,0,0,0,0,0,0,0,188,43,81,0,2,0,0,0,1,0,0,0,0,0,0,0,144,43,81,0,2,0,0,0,1,0,0,0,0,0,0,0,124,43,81,0,2,0,0,0,1,0,0,0,0,0,0,0,104,43,81,0,2,0,0,0,1,0,0,0,0,0,0,0,64,43,81,0,2,0,0,0,1,0,0,0,0,0,0,0,40,43,81,0,2,0,0,0,1,0,0,0,0,0,0,0,20,43,81,0,2,0,0,0,1,0,0,0,0,0,0,0,0,43,81,0,3,0,0,0,1,0,0,0,0,0,0,0,192,42,81,0,3,0,0,0,1,0,0,0,0,0,0,0,168,42,81,0,2,0,0,0,1,0,0,0,0,0,0,0,16,47,81,0,3,0,0,0,1,0,0,0,0,0,0,0,64,45,81,0,3,0,0,0,1,0,0,0,0,0,0,0,32,60,81,0,1,0,0,0,1,0,0,0,0,0,0,0,224,61,81,0,1,0,0,0,1,0,0,0,0,0,0,0,132,42,81,0,2,0,0,0,1,0,0,0,0,0,0,0,216,61,81,0,1,0,0,0,1,0,0,0,0,0,0,0,72,42,81,0,2,0,0,0,1,0,0,0,0,0,0,0,52,42,81,0,2,0,0,0,1,0,0,0,0,0,0,0,36,42,81,0,2,0,0,0,1,0,0,0,0,0,0,0,0,42,81,0,2,0,0,0,1,0,0,0,0,0,0,0,236,41,81,0,2,0,0,0,1,0,0,0,0,0,0,0,64,64,81,0,2,0,0,0,1,0,0,0,0,0,0,0,48,64,81,0,2,0,0,0,1,0,0,0,0,0,0,0,8,64,81,0,2,0,0,0,1,0,0,0,0,0,0,0,212,63,81,0,2,0,0,0,1,0,0,0,0,0,0,0,184,63,81,0,2,0,0,0,1,0,0,0,0,0,0,0,132,63,81,0,3,0,0,0,1,0,0,0,0,0,0,0,188,60,81,0,1,0,0,0,1,0,0,0,0,0,0,0,120,63,81,0,2,0,0,0,1,0,0,0,0,0,0,0,96,63,81,0,2,0,0,0,1,0,0,0,0,0,0,0,68,63,81,0,2,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,4,0,20,0,16,4,0,0,16,4,4,0,16,4,8,0,16,4,12,0,12,2,16,0,12,2,18,0,0,0,0,0,4,0,16,0,17,4,0,0,12,2,4,0,12,2,6,0,12,2,8,0,12,2,10,0,12,2,12,0,12,2,14,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,2,2,0,80,16,16,16,16,16,16,16,16,0,0,16,0,16,16,16,16,18,16,0,34,1,17,16,32,0,16,32,16,16,0,16,16,0,0,0,0,16,16,16,16,16,0,32,32,0,0,32,32,0,0,32,17,32,17,17,17,32,33,33,1,1,0,0,16,33,33,33,33,33,33,17,17,16,0,33,33,17,16,16,16,33,33,33,33,17,17,17,17,17,17,17,17,17,17,17,17,32,16,16,16,16,16,16,16,32,32,0,0,0,0,16,16,0,32,32,0,0,16,32,32,17,16,51,33,33,16,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,1,2,3,4,5,6,7,8,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0])
, "i8", ALLOC_NONE, TOTAL_STACK)
function runPostSets() {
}
if (!awaitingMemoryInitializer) runPostSets();
  var ERRNO_CODES={E2BIG:7,EACCES:13,EADDRINUSE:98,EADDRNOTAVAIL:99,EAFNOSUPPORT:97,EAGAIN:11,EALREADY:114,EBADF:9,EBADMSG:74,EBUSY:16,ECANCELED:125,ECHILD:10,ECONNABORTED:103,ECONNREFUSED:111,ECONNRESET:104,EDEADLK:35,EDESTADDRREQ:89,EDOM:33,EDQUOT:122,EEXIST:17,EFAULT:14,EFBIG:27,EHOSTUNREACH:113,EIDRM:43,EILSEQ:84,EINPROGRESS:115,EINTR:4,EINVAL:22,EIO:5,EISCONN:106,EISDIR:21,ELOOP:40,EMFILE:24,EMLINK:31,EMSGSIZE:90,EMULTIHOP:72,ENAMETOOLONG:36,ENETDOWN:100,ENETRESET:102,ENETUNREACH:101,ENFILE:23,ENOBUFS:105,ENODATA:61,ENODEV:19,ENOENT:2,ENOEXEC:8,ENOLCK:37,ENOLINK:67,ENOMEM:12,ENOMSG:42,ENOPROTOOPT:92,ENOSPC:28,ENOSR:63,ENOSTR:60,ENOSYS:38,ENOTCONN:107,ENOTDIR:20,ENOTEMPTY:39,ENOTRECOVERABLE:131,ENOTSOCK:88,ENOTSUP:95,ENOTTY:25,ENXIO:6,EOVERFLOW:75,EOWNERDEAD:130,EPERM:1,EPIPE:32,EPROTO:71,EPROTONOSUPPORT:93,EPROTOTYPE:91,ERANGE:34,EROFS:30,ESPIPE:29,ESRCH:3,ESTALE:116,ETIME:62,ETIMEDOUT:110,ETXTBSY:26,EWOULDBLOCK:11,EXDEV:18};
  function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      if (!___setErrNo.ret) ___setErrNo.ret = allocate([0], 'i32', ALLOC_STATIC);
      HEAP32[((___setErrNo.ret)>>2)]=value
      return value;
    }
  var _stdin=allocate(1, "i32*", ALLOC_STACK);
  var _stdout=allocate(1, "i32*", ALLOC_STACK);
  var _stderr=allocate(1, "i32*", ALLOC_STACK);
  var __impure_ptr=allocate(1, "i32*", ALLOC_STACK);var FS={currentPath:"/",nextInode:2,streams:[null],ignorePermissions:true,joinPath:function (parts, forceRelative) {
        var ret = parts[0];
        for (var i = 1; i < parts.length; i++) {
          if (ret[ret.length-1] != '/') ret += '/';
          ret += parts[i];
        }
        if (forceRelative && ret[0] == '/') ret = ret.substr(1);
        return ret;
      },absolutePath:function (relative, base) {
        if (typeof relative !== 'string') return null;
        if (base === undefined) base = FS.currentPath;
        if (relative && relative[0] == '/') base = '';
        var full = base + '/' + relative;
        var parts = full.split('/').reverse();
        var absolute = [''];
        while (parts.length) {
          var part = parts.pop();
          if (part == '' || part == '.') {
            // Nothing.
          } else if (part == '..') {
            if (absolute.length > 1) absolute.pop();
          } else {
            absolute.push(part);
          }
        }
        return absolute.length == 1 ? '/' : absolute.join('/');
      },analyzePath:function (path, dontResolveLastLink, linksVisited) {
        var ret = {
          isRoot: false,
          exists: false,
          error: 0,
          name: null,
          path: null,
          object: null,
          parentExists: false,
          parentPath: null,
          parentObject: null
        };
        path = FS.absolutePath(path);
        if (path == '/') {
          ret.isRoot = true;
          ret.exists = ret.parentExists = true;
          ret.name = '/';
          ret.path = ret.parentPath = '/';
          ret.object = ret.parentObject = FS.root;
        } else if (path !== null) {
          linksVisited = linksVisited || 0;
          path = path.slice(1).split('/');
          var current = FS.root;
          var traversed = [''];
          while (path.length) {
            if (path.length == 1 && current.isFolder) {
              ret.parentExists = true;
              ret.parentPath = traversed.length == 1 ? '/' : traversed.join('/');
              ret.parentObject = current;
              ret.name = path[0];
            }
            var target = path.shift();
            if (!current.isFolder) {
              ret.error = ERRNO_CODES.ENOTDIR;
              break;
            } else if (!current.read) {
              ret.error = ERRNO_CODES.EACCES;
              break;
            } else if (!current.contents.hasOwnProperty(target)) {
              ret.error = ERRNO_CODES.ENOENT;
              break;
            }
            current = current.contents[target];
            if (current.link && !(dontResolveLastLink && path.length == 0)) {
              if (linksVisited > 40) { // Usual Linux SYMLOOP_MAX.
                ret.error = ERRNO_CODES.ELOOP;
                break;
              }
              var link = FS.absolutePath(current.link, traversed.join('/'));
              ret = FS.analyzePath([link].concat(path).join('/'),
                                   dontResolveLastLink, linksVisited + 1);
              return ret;
            }
            traversed.push(target);
            if (path.length == 0) {
              ret.exists = true;
              ret.path = traversed.join('/');
              ret.object = current;
            }
          }
        }
        return ret;
      },findObject:function (path, dontResolveLastLink) {
        FS.ensureRoot();
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },createObject:function (parent, name, properties, canRead, canWrite) {
        if (!parent) parent = '/';
        if (typeof parent === 'string') parent = FS.findObject(parent);
        if (!parent) {
          ___setErrNo(ERRNO_CODES.EACCES);
          throw new Error('Parent path must exist.');
        }
        if (!parent.isFolder) {
          ___setErrNo(ERRNO_CODES.ENOTDIR);
          throw new Error('Parent must be a folder.');
        }
        if (!parent.write && !FS.ignorePermissions) {
          ___setErrNo(ERRNO_CODES.EACCES);
          throw new Error('Parent folder must be writeable.');
        }
        if (!name || name == '.' || name == '..') {
          ___setErrNo(ERRNO_CODES.ENOENT);
          throw new Error('Name must not be empty.');
        }
        if (parent.contents.hasOwnProperty(name)) {
          ___setErrNo(ERRNO_CODES.EEXIST);
          throw new Error("Can't overwrite object.");
        }
        parent.contents[name] = {
          read: canRead === undefined ? true : canRead,
          write: canWrite === undefined ? false : canWrite,
          timestamp: Date.now(),
          inodeNumber: FS.nextInode++
        };
        for (var key in properties) {
          if (properties.hasOwnProperty(key)) {
            parent.contents[name][key] = properties[key];
          }
        }
        return parent.contents[name];
      },createFolder:function (parent, name, canRead, canWrite) {
        var properties = {isFolder: true, isDevice: false, contents: {}};
        return FS.createObject(parent, name, properties, canRead, canWrite);
      },createPath:function (parent, path, canRead, canWrite) {
        var current = FS.findObject(parent);
        if (current === null) throw new Error('Invalid parent.');
        path = path.split('/').reverse();
        while (path.length) {
          var part = path.pop();
          if (!part) continue;
          if (!current.contents.hasOwnProperty(part)) {
            FS.createFolder(current, part, canRead, canWrite);
          }
          current = current.contents[part];
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        properties.isFolder = false;
        return FS.createObject(parent, name, properties, canRead, canWrite);
      },createDataFile:function (parent, name, data, canRead, canWrite) {
        if (typeof data === 'string') {
          var dataArray = new Array(data.length);
          for (var i = 0, len = data.length; i < len; ++i) dataArray[i] = data.charCodeAt(i);
          data = dataArray;
        }
        var properties = {
          isDevice: false,
          contents: data.subarray ? data.subarray(0) : data // as an optimization, create a new array wrapper (not buffer) here, to help JS engines understand this object
        };
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
          var LazyUint8Array = function(chunkSize, length) {
            this.length = length;
            this.chunkSize = chunkSize;
            this.chunks = []; // Loaded chunks. Index is the chunk number
          }
          LazyUint8Array.prototype.get = function(idx) {
            if (idx > this.length-1 || idx < 0) {
              return undefined;
            }
            var chunkOffset = idx % chunkSize;
            var chunkNum = Math.floor(idx / chunkSize);
            return this.getter(chunkNum)[chunkOffset];
          }
          LazyUint8Array.prototype.setDataGetter = function(getter) {
            this.getter = getter;
          }
          // Find length
          var xhr = new XMLHttpRequest();
          xhr.open('HEAD', url, false);
          xhr.send(null);
          if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
          var datalength = Number(xhr.getResponseHeader("Content-length"));
          var header;
          var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
          var chunkSize = 1024*1024; // Chunk size in bytes
          if (!hasByteServing) chunkSize = datalength;
          // Function to get a range from the remote URL.
          var doXHR = (function(from, to) {
            if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
            if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
            // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
            var xhr = new XMLHttpRequest();
            xhr.open('GET', url, false);
            if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
            // Some hints to the browser that we want binary data.
            if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
            if (xhr.overrideMimeType) {
              xhr.overrideMimeType('text/plain; charset=x-user-defined');
            }
            xhr.send(null);
            if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
            if (xhr.response !== undefined) {
              return new Uint8Array(xhr.response || []);
            } else {
              return intArrayFromString(xhr.responseText || '', true);
            }
          });
          var lazyArray = new LazyUint8Array(chunkSize, datalength);
          lazyArray.setDataGetter(function(chunkNum) {
            var start = chunkNum * lazyArray.chunkSize;
            var end = (chunkNum+1) * lazyArray.chunkSize - 1; // including this byte
            end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
              lazyArray.chunks[chunkNum] = doXHR(start, end);
            }
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
            return lazyArray.chunks[chunkNum];
          });
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile) {
        Browser.init();
        var fullname = FS.joinPath([parent, name], true);
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },createLink:function (parent, name, target, canRead, canWrite) {
        var properties = {isDevice: false, link: target};
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createDevice:function (parent, name, input, output) {
        if (!(input || output)) {
          throw new Error('A device must have at least one callback defined.');
        }
        var ops = {isDevice: true, input: input, output: output};
        return FS.createFile(parent, name, ops, Boolean(input), Boolean(output));
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },ensureRoot:function () {
        if (FS.root) return;
        // The main file system tree. All the contents are inside this.
        FS.root = {
          read: true,
          write: true,
          isFolder: true,
          isDevice: false,
          timestamp: Date.now(),
          inodeNumber: 1,
          contents: {}
        };
      },init:function (input, output, error) {
        // Make sure we initialize only once.
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
        FS.ensureRoot();
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        input = input || Module['stdin'];
        output = output || Module['stdout'];
        error = error || Module['stderr'];
        // Default handlers.
        var stdinOverridden = true, stdoutOverridden = true, stderrOverridden = true;
        if (!input) {
          stdinOverridden = false;
          input = function() {
            if (!input.cache || !input.cache.length) {
              var result;
              if (typeof window != 'undefined' &&
                  typeof window.prompt == 'function') {
                // Browser.
                result = window.prompt('Input: ');
                if (result === null) result = String.fromCharCode(0); // cancel ==> EOF
              } else if (typeof readline == 'function') {
                // Command line.
                result = readline();
              }
              if (!result) result = '';
              input.cache = intArrayFromString(result + '\n', true);
            }
            return input.cache.shift();
          };
        }
        var utf8 = new Runtime.UTF8Processor();
        function simpleOutput(val) {
          if (val === null || val === 10) {
            output.printer(output.buffer.join(''));
            output.buffer = [];
          } else {
            output.buffer.push(utf8.processCChar(val));
          }
        }
        if (!output) {
          stdoutOverridden = false;
          output = simpleOutput;
        }
        if (!output.printer) output.printer = Module['print'];
        if (!output.buffer) output.buffer = [];
        if (!error) {
          stderrOverridden = false;
          error = simpleOutput;
        }
        if (!error.printer) error.printer = Module['print'];
        if (!error.buffer) error.buffer = [];
        // Create the temporary folder, if not already created
        try {
          FS.createFolder('/', 'tmp', true, true);
        } catch(e) {}
        // Create the I/O devices.
        var devFolder = FS.createFolder('/', 'dev', true, true);
        var stdin = FS.createDevice(devFolder, 'stdin', input);
        var stdout = FS.createDevice(devFolder, 'stdout', null, output);
        var stderr = FS.createDevice(devFolder, 'stderr', null, error);
        FS.createDevice(devFolder, 'tty', input, output);
        // Create default streams.
        FS.streams[1] = {
          path: '/dev/stdin',
          object: stdin,
          position: 0,
          isRead: true,
          isWrite: false,
          isAppend: false,
          isTerminal: !stdinOverridden,
          error: false,
          eof: false,
          ungotten: []
        };
        FS.streams[2] = {
          path: '/dev/stdout',
          object: stdout,
          position: 0,
          isRead: false,
          isWrite: true,
          isAppend: false,
          isTerminal: !stdoutOverridden,
          error: false,
          eof: false,
          ungotten: []
        };
        FS.streams[3] = {
          path: '/dev/stderr',
          object: stderr,
          position: 0,
          isRead: false,
          isWrite: true,
          isAppend: false,
          isTerminal: !stderrOverridden,
          error: false,
          eof: false,
          ungotten: []
        };
        assert(Math.max(_stdin, _stdout, _stderr) < 1024); // make sure these are low, we flatten arrays with these
        HEAP32[((_stdin)>>2)]=1;
        HEAP32[((_stdout)>>2)]=2;
        HEAP32[((_stderr)>>2)]=3;
        // Other system paths
        FS.createPath('/', 'dev/shm/tmp', true, true); // temp files
        // Newlib initialization
        for (var i = FS.streams.length; i < Math.max(_stdin, _stdout, _stderr) + 4; i++) {
          FS.streams[i] = null; // Make sure to keep FS.streams dense
        }
        FS.streams[_stdin] = FS.streams[1];
        FS.streams[_stdout] = FS.streams[2];
        FS.streams[_stderr] = FS.streams[3];
        allocate([ allocate(
          [0, 0, 0, 0, _stdin, 0, 0, 0, _stdout, 0, 0, 0, _stderr, 0, 0, 0],
          'void*', ALLOC_STATIC) ], 'void*', ALLOC_NONE, __impure_ptr);
      },quit:function () {
        if (!FS.init.initialized) return;
        // Flush any partially-printed lines in stdout and stderr. Careful, they may have been closed
        if (FS.streams[2] && FS.streams[2].object.output.buffer.length > 0) FS.streams[2].object.output(10);
        if (FS.streams[3] && FS.streams[3].object.output.buffer.length > 0) FS.streams[3].object.output(10);
      },standardizePath:function (path) {
        if (path.substr(0, 2) == './') path = path.substr(2);
        return path;
      },deleteFile:function (path) {
        path = FS.analyzePath(path);
        if (!path.parentExists || !path.exists) {
          throw 'Invalid path ' + path;
        }
        delete path.parentObject.contents[path.name];
      }};
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.streams[fildes];
      if (!stream || stream.object.isDevice) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isWrite) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (stream.object.isFolder) {
        ___setErrNo(ERRNO_CODES.EISDIR);
        return -1;
      } else if (nbyte < 0 || offset < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        var contents = stream.object.contents;
        while (contents.length < offset) contents.push(0);
        for (var i = 0; i < nbyte; i++) {
          contents[offset + i] = HEAPU8[(((buf)+(i))|0)];
        }
        stream.object.timestamp = Date.now();
        return i;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.streams[fildes];
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isWrite) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (nbyte < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        if (stream.object.isDevice) {
          if (stream.object.output) {
            for (var i = 0; i < nbyte; i++) {
              try {
                stream.object.output(HEAP8[(((buf)+(i))|0)]);
              } catch (e) {
                ___setErrNo(ERRNO_CODES.EIO);
                return -1;
              }
            }
            stream.object.timestamp = Date.now();
            return i;
          } else {
            ___setErrNo(ERRNO_CODES.ENXIO);
            return -1;
          }
        } else {
          var bytesWritten = _pwrite(fildes, buf, nbyte, stream.position);
          if (bytesWritten != -1) stream.position += bytesWritten;
          return bytesWritten;
        }
      }
    }function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)|0)]=chr
      var ret = _write(stream, _fputc.ret, 1);
      if (ret == -1) {
        if (FS.streams[stream]) FS.streams[stream].error = true;
        return -1;
      } else {
        return chr;
      }
    }var _putc=_fputc;
  function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var bytesWritten = _write(stream, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        if (FS.streams[stream]) FS.streams[stream].error = true;
        return 0;
      } else {
        return Math.floor(bytesWritten / size);
      }
    }
  Module["_strlen"] = _strlen;
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = (HEAP32[((tempDoublePtr)>>2)]=HEAP32[(((varargs)+(argIndex))>>2)],HEAP32[(((tempDoublePtr)+(4))>>2)]=HEAP32[(((varargs)+((argIndex)+(4)))>>2)],(+(HEAPF64[(tempDoublePtr)>>3])));
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+4))>>2)]];
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Runtime.getNativeFieldSize(type);
        return ret;
      }
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[(textIndex)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)|0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          }
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)|0)];
            }
          }
          // Handle precision.
          var precisionSet = false;
          if (next == 46) {
            var precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)|0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)|0)];
          } else {
            var precision = 6; // Standard default.
          }
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)|0)];
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = flagAlternative ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
              // Add sign if needed
              if (flagAlwaysSigned) {
                if (currArg < 0) {
                  prefix = '-' + prefix;
                } else {
                  prefix = '+' + prefix;
                }
              }
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
                // Add sign.
                if (flagAlwaysSigned && currArg >= 0) {
                  argText = '+' + argText;
                }
              }
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*') || nullString;
              var argLength = _strlen(arg);
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              for (var i = 0; i < argLength; i++) {
                ret.push(HEAPU8[((arg++)|0)]);
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[(i)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      function ExitStatus() {
        this.name = "ExitStatus";
        this.message = "Program terminated with exit(" + status + ")";
        this.status = status;
        Module.print('Exit Status: ' + status);
      };
      ExitStatus.prototype = new Error();
      ExitStatus.prototype.constructor = ExitStatus;
      exitRuntime();
      ABORT = true;
      throw new ExitStatus();
    }function _exit(status) {
      __exit(status);
    }
  function _isspace(chr) {
      return chr in { 32: 0, 9: 0, 10: 0, 11: 0, 12: 0, 13: 0 };
    }function __parseInt(str, endptr, base, min, max, bits, unsign) {
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      var multiplier = 1;
      if (HEAP8[(str)] == 45) {
        multiplier = -1;
        str++;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            str++;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      // Get digits.
      var chr;
      var ret = 0;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          ret = ret * finalBase + digit;
          str++;
        }
      }
      // Apply sign.
      ret *= multiplier;
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      // Unsign if needed.
      if (unsign) {
        if (Math.abs(ret) > max) {
          ret = max;
          ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          ret = unSign(ret, bits);
        }
      }
      // Validate range.
      if (ret > max || ret < min) {
        ret = ret > max ? max : min;
        ___setErrNo(ERRNO_CODES.ERANGE);
      }
      if (bits == 64) {
        return ((asm.setTempRet0(Math.min(Math.floor((ret)/(+(4294967296))), (+(4294967295)))>>>0),ret>>>0)|0);
      }
      return ret;
    }function _strtol(str, endptr, base) {
      return __parseInt(str, endptr, base, -2147483648, 2147483647, 32);  // LONG_MIN, LONG_MAX.
    }function _atoi(ptr) {
      return _strtol(ptr, null, 10);
    }
  var _cos=Math.cos;
  var _sin=Math.sin;
  Module["_memcpy"] = _memcpy;var _llvm_memcpy_p0i8_p0i8_i32=_memcpy;
  Module["_memmove"] = _memmove;var _llvm_memmove_p0i8_p0i8_i32=_memmove;
  function _strncmp(px, py, n) {
      var i = 0;
      while (i < n) {
        var x = HEAPU8[(((px)+(i))|0)];
        var y = HEAPU8[(((py)+(i))|0)];
        if (x == y && x == 0) return 0;
        if (x == 0) return -1;
        if (y == 0) return 1;
        if (x == y) {
          i ++;
          continue;
        } else {
          return x > y ? 1 : -1;
        }
      }
      return 0;
    }function _strcmp(px, py) {
      return _strncmp(px, py, TOTAL_MEMORY);
    }
  Module["_saveSetjmp"] = _saveSetjmp;
  Module["_testSetjmp"] = _testSetjmp;
  function _longjmp(env, value) {
      Module.print('LOSE, time to throw');
      asm.setThrew(env, value || 1);
      throw 0;
    }
  Module["_memset"] = _memset;var _llvm_memset_p0i8_i32=_memset;
  function _qsort(base, num, size, cmp) {
      if (num == 0 || size == 0) return;
      // forward calls to the JavaScript sort method
      // first, sort the items logically
      var comparator = function(x, y) {
        return Runtime.dynCall('iii', cmp, [x, y]);
      }
      var keys = [];
      for (var i = 0; i < num; i++) keys.push(i);
      keys.sort(function(a, b) {
        return comparator(base+a*size, base+b*size);
      });
      // apply the sort
      var temp = _malloc(num*size);
      _memcpy(temp, base, num*size);
      for (var i = 0; i < num; i++) {
        if (keys[i] == i) continue; // already in place
        _memcpy(base+i*size, temp+keys[i]*size, size);
      }
      _free(temp);
    }
  function _strrchr(ptr, chr) {
      var ptr2 = ptr + _strlen(ptr);
      do {
        if (HEAP8[(ptr2)] == chr) return ptr2;
        ptr2--;
      } while (ptr2 >= ptr);
      return 0;
    }
  Module["_strncpy"] = _strncpy;
  Module["_strcat"] = _strcat;
  Module["_memcmp"] = _memcmp;
  var ___dirent_struct_layout={__size__:1040,d_ino:0,d_name:4,d_off:1028,d_reclen:1032,d_type:1036};function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      // NOTE: This implementation tries to mimic glibc rather than strictly
      // following the POSIX standard.
      var mode = HEAP32[((varargs)>>2)];
      // Simplify flags.
      var accessMode = oflag & 3;
      var isWrite = accessMode != 0;
      var isRead = accessMode != 1;
      var isCreate = Boolean(oflag & 512);
      var isExistCheck = Boolean(oflag & 2048);
      var isTruncate = Boolean(oflag & 1024);
      var isAppend = Boolean(oflag & 8);
      // Verify path.
      var origPath = path;
      path = FS.analyzePath(Pointer_stringify(path));
      if (!path.parentExists) {
        ___setErrNo(path.error);
        return -1;
      }
      var target = path.object || null;
      var finalPath;
      // Verify the file exists, create if needed and allowed.
      if (target) {
        if (isCreate && isExistCheck) {
          ___setErrNo(ERRNO_CODES.EEXIST);
          return -1;
        }
        if ((isWrite || isCreate || isTruncate) && target.isFolder) {
          ___setErrNo(ERRNO_CODES.EISDIR);
          return -1;
        }
        if (isRead && !target.read || isWrite && !target.write) {
          ___setErrNo(ERRNO_CODES.EACCES);
          return -1;
        }
        if (isTruncate && !target.isDevice) {
          target.contents = [];
        } else {
          if (!FS.forceLoadFile(target)) {
            ___setErrNo(ERRNO_CODES.EIO);
            return -1;
          }
        }
        finalPath = path.path;
      } else {
        if (!isCreate) {
          ___setErrNo(ERRNO_CODES.ENOENT);
          return -1;
        }
        if (!path.parentObject.write) {
          ___setErrNo(ERRNO_CODES.EACCES);
          return -1;
        }
        target = FS.createDataFile(path.parentObject, path.name, [],
                                   mode & 0x100, mode & 0x80);  // S_IRUSR, S_IWUSR.
        finalPath = path.parentPath + '/' + path.name;
      }
      // Actually create an open stream.
      var id = FS.streams.length; // Keep dense
      if (target.isFolder) {
        var entryBuffer = 0;
        if (___dirent_struct_layout) {
          entryBuffer = _malloc(___dirent_struct_layout.__size__);
        }
        var contents = [];
        for (var key in target.contents) contents.push(key);
        FS.streams[id] = {
          path: finalPath,
          object: target,
          // An index into contents. Special values: -2 is ".", -1 is "..".
          position: -2,
          isRead: true,
          isWrite: false,
          isAppend: false,
          error: false,
          eof: false,
          ungotten: [],
          // Folder-specific properties:
          // Remember the contents at the time of opening in an array, so we can
          // seek between them relying on a single order.
          contents: contents,
          // Each stream has its own area for readdir() returns.
          currentEntry: entryBuffer
        };
      } else {
        FS.streams[id] = {
          path: finalPath,
          object: target,
          position: 0,
          isRead: isRead,
          isWrite: isWrite,
          isAppend: isAppend,
          error: false,
          eof: false,
          ungotten: []
        };
      }
      return id;
    }function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 1024;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 8;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var ret = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return (ret == -1) ? 0 : ret;
    }
  function _lseek(fildes, offset, whence) {
      // off_t lseek(int fildes, off_t offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/lseek.html
      if (FS.streams[fildes] && !FS.streams[fildes].object.isDevice) {
        var stream = FS.streams[fildes];
        var position = offset;
        if (whence === 1) {  // SEEK_CUR.
          position += stream.position;
        } else if (whence === 2) {  // SEEK_END.
          position += stream.object.contents.length;
        }
        if (position < 0) {
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        } else {
          stream.ungotten = [];
          stream.position = position;
          return position;
        }
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fseek(stream, offset, whence) {
      // int fseek(FILE *stream, long offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fseek.html
      var ret = _lseek(stream, offset, whence);
      if (ret == -1) {
        return -1;
      } else {
        FS.streams[stream].eof = false;
        return 0;
      }
    }
  function _ftell(stream) {
      // long ftell(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftell.html
      if (FS.streams[stream]) {
        stream = FS.streams[stream];
        if (stream.object.isDevice) {
          ___setErrNo(ERRNO_CODES.ESPIPE);
          return -1;
        } else {
          return stream.position;
        }
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }
  function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      if (FS.streams[fildes]) {
        if (FS.streams[fildes].currentEntry) {
          _free(FS.streams[fildes].currentEntry);
        }
        FS.streams[fildes] = null;
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }
  function _fsync(fildes) {
      // int fsync(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fsync.html
      if (FS.streams[fildes]) {
        // We write directly to the file system, so there's nothing to do here.
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      _fsync(stream);
      return _close(stream);
    }
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.streams[fildes];
      if (!stream || stream.object.isDevice) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isRead) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (stream.object.isFolder) {
        ___setErrNo(ERRNO_CODES.EISDIR);
        return -1;
      } else if (nbyte < 0 || offset < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        var bytesRead = 0;
        while (stream.ungotten.length && nbyte > 0) {
          HEAP8[((buf++)|0)]=stream.ungotten.pop()
          nbyte--;
          bytesRead++;
        }
        var contents = stream.object.contents;
        var size = Math.min(contents.length - offset, nbyte);
        if (contents.subarray) { // typed array
          HEAPU8.set(contents.subarray(offset, offset+size), buf);
        } else
        if (contents.slice) { // normal array
          for (var i = 0; i < size; i++) {
            HEAP8[(((buf)+(i))|0)]=contents[offset + i]
          }
        } else {
          for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
            HEAP8[(((buf)+(i))|0)]=contents.get(offset + i)
          }
        }
        bytesRead += size;
        return bytesRead;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.streams[fildes];
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isRead) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (nbyte < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        var bytesRead;
        if (stream.object.isDevice) {
          if (stream.object.input) {
            bytesRead = 0;
            while (stream.ungotten.length && nbyte > 0) {
              HEAP8[((buf++)|0)]=stream.ungotten.pop()
              nbyte--;
              bytesRead++;
            }
            for (var i = 0; i < nbyte; i++) {
              try {
                var result = stream.object.input();
              } catch (e) {
                ___setErrNo(ERRNO_CODES.EIO);
                return -1;
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              HEAP8[(((buf)+(i))|0)]=result
            }
            return bytesRead;
          } else {
            ___setErrNo(ERRNO_CODES.ENXIO);
            return -1;
          }
        } else {
          var ungotSize = stream.ungotten.length;
          bytesRead = _pread(fildes, buf, nbyte, stream.position);
          if (bytesRead != -1) {
            stream.position += (stream.ungotten.length - ungotSize) + bytesRead;
          }
          return bytesRead;
        }
      }
    }function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) return 0;
      var bytesRead = _read(stream, ptr, bytesToRead);
      var streamObj = FS.streams[stream];
      if (bytesRead == -1) {
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        if (bytesRead < bytesToRead) streamObj.eof = true;
        return Math.floor(bytesRead / size);
      }
    }
  function _memchr(ptr, chr, num) {
      chr = unSign(chr);
      for (var i = 0; i < num; i++) {
        if (HEAP8[(ptr)] == chr) return ptr;
        ptr++;
      }
      return 0;
    }
  function _strstr(ptr1, ptr2) {
      var check = 0, start;
      do {
        if (!check) {
          start = ptr1;
          check = ptr2;
        }
        var curr1 = HEAP8[((ptr1++)|0)];
        var curr2 = HEAP8[((check++)|0)];
        if (curr2 == 0) return start;
        if (curr2 != curr1) {
          // rewind to one character after start, to find ez in eeez
          ptr1 = start + 1;
          check = 0;
        }
      } while (curr1);
      return 0;
    }
  var _atol=_atoi;
  function _snprintf(s, n, format, varargs) {
      // int snprintf(char *restrict s, size_t n, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var limit = (n === undefined) ? result.length
                                    : Math.min(result.length, Math.max(n - 1, 0));
      if (s < 0) {
        s = -s;
        var buf = _malloc(limit+1);
        HEAP32[((s)>>2)]=buf;
        s = buf;
      }
      for (var i = 0; i < limit; i++) {
        HEAP8[(((s)+(i))|0)]=result[i];
      }
      if (limit < n || (n === undefined)) HEAP8[(((s)+(i))|0)]=0;
      return result.length;
    }function _sprintf(s, format, varargs) {
      // int sprintf(char *restrict s, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      return _snprintf(s, undefined, format, varargs);
    }
  function _abort() {
      ABORT = true;
      throw 'abort() at ' + (new Error().stack);
    }
  function ___errno_location() {
      return ___setErrNo.ret;
    }var ___errno=___errno_location;
  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 8: return PAGE_SIZE;
        case 54:
        case 56:
        case 21:
        case 61:
        case 63:
        case 22:
        case 67:
        case 23:
        case 24:
        case 25:
        case 26:
        case 27:
        case 69:
        case 28:
        case 101:
        case 70:
        case 71:
        case 29:
        case 30:
        case 199:
        case 75:
        case 76:
        case 32:
        case 43:
        case 44:
        case 80:
        case 46:
        case 47:
        case 45:
        case 48:
        case 49:
        case 42:
        case 82:
        case 33:
        case 7:
        case 108:
        case 109:
        case 107:
        case 112:
        case 119:
        case 121:
          return 200809;
        case 13:
        case 104:
        case 94:
        case 95:
        case 34:
        case 35:
        case 77:
        case 81:
        case 83:
        case 84:
        case 85:
        case 86:
        case 87:
        case 88:
        case 89:
        case 90:
        case 91:
        case 94:
        case 95:
        case 110:
        case 111:
        case 113:
        case 114:
        case 115:
        case 116:
        case 117:
        case 118:
        case 120:
        case 40:
        case 16:
        case 79:
        case 19:
          return -1;
        case 92:
        case 93:
        case 5:
        case 72:
        case 6:
        case 74:
        case 92:
        case 93:
        case 96:
        case 97:
        case 98:
        case 99:
        case 102:
        case 103:
        case 105:
          return 1;
        case 38:
        case 66:
        case 50:
        case 51:
        case 4:
          return 1024;
        case 15:
        case 64:
        case 41:
          return 32;
        case 55:
        case 37:
        case 17:
          return 2147483647;
        case 18:
        case 1:
          return 47839;
        case 59:
        case 57:
          return 99;
        case 68:
        case 58:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 14: return 32768;
        case 73: return 32767;
        case 39: return 16384;
        case 60: return 1000;
        case 106: return 700;
        case 52: return 256;
        case 62: return 255;
        case 2: return 100;
        case 65: return 64;
        case 36: return 20;
        case 100: return 16;
        case 20: return 6;
        case 53: return 4;
        case 10: return 1;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }
  function _time(ptr) {
      var ret = Math.floor(Date.now()/1000);
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret
      }
      return ret;
    }
  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We need to make sure no one else allocates unfreeable memory!
      // We must control this entirely. So we don't even need to do
      // unfreeable allocations - the HEAP is ours, from STATICTOP up.
      // TODO: We could in theory slice off the top of the HEAP when
      //       sbrk gets a negative increment in |bytes|...
      var self = _sbrk;
      if (!self.called) {
        STATICTOP = alignMemoryPage(STATICTOP); // make sure we start out aligned
        self.called = true;
        _sbrk.DYNAMIC_START = STATICTOP;
      }
      var ret = STATICTOP;
      if (bytes != 0) Runtime.staticAlloc(bytes);
      return ret;  // Previous break location.
    }
  function _llvm_uadd_with_overflow_i32(x, y) {
      x = x>>>0;
      y = y>>>0;
      return ((asm.setTempRet0(x+y > 4294967295),(x+y)>>>0)|0);
    }
  var _llvm_memset_p0i8_i64=_memset;
  var Browser={mainLoop:{scheduler:null,shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (Browser.initted) return;
        Browser.initted = true;
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : console.log("warning: cannot create object URLs");
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
        function getMimetype(name) {
          return {
            'jpg': 'image/jpeg',
            'jpeg': 'image/jpeg',
            'png': 'image/png',
            'bmp': 'image/bmp',
            'ogg': 'audio/ogg',
            'wav': 'audio/wav',
            'mp3': 'audio/mpeg'
          }[name.substr(name.lastIndexOf('.')+1)];
        }
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = [];
        var imagePlugin = {};
        imagePlugin['canHandle'] = function(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/.exec(name);
        };
        imagePlugin['handle'] = function(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: getMimetype(name) });
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
        var audioPlugin = {};
        audioPlugin['canHandle'] = function(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            setTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
        // Canvas event setup
        var canvas = Module['canvas'];
        canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                    canvas['mozRequestPointerLock'] ||
                                    canvas['webkitRequestPointerLock'];
        canvas.exitPointerLock = document['exitPointerLock'] ||
                                 document['mozExitPointerLock'] ||
                                 document['webkitExitPointerLock'];
        canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas;
        }
        document.addEventListener('pointerlockchange', pointerLockChange, false);
        document.addEventListener('mozpointerlockchange', pointerLockChange, false);
        document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
        if (Module['elementPointerLock']) {
          canvas.addEventListener("click", function(ev) {
            if (!Browser.pointerLock && canvas.requestPointerLock) {
              canvas.requestPointerLock();
              ev.preventDefault();
            }
          }, false);
        }
      },createContext:function (canvas, useWebGL, setInModule) {
        var ctx;
        try {
          if (useWebGL) {
            ctx = canvas.getContext('experimental-webgl', {
              alpha: false
            });
          } else {
            ctx = canvas.getContext('2d');
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas - ' + e);
          return null;
        }
        if (useWebGL) {
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
          // Warn on context loss
          canvas.addEventListener('webglcontextlost', function(event) {
            alert('WebGL context lost. You will need to reload the page.');
          }, false);
        }
        if (setInModule) {
          Module.ctx = ctx;
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas) {
        this.lockPointer = lockPointer;
        this.resizeCanvas = resizeCanvas;
        if (typeof this.lockPointer === 'undefined') this.lockPointer = true;
        if (typeof this.resizeCanvas === 'undefined') this.resizeCanvas = false;
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement']) === canvas) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'];
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else if (Browser.resizeCanvas){
            Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
        }
        if (!this.fullScreenHandlersInstalled) {
          this.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
        }
        canvas.requestFullScreen = canvas['requestFullScreen'] ||
                                   canvas['mozRequestFullScreen'] ||
                                   (canvas['webkitRequestFullScreen'] ? function() { canvas['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvas.requestFullScreen(); 
      },requestAnimationFrame:function (func) {
        if (!window.requestAnimationFrame) {
          window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                         window['mozRequestAnimationFrame'] ||
                                         window['webkitRequestAnimationFrame'] ||
                                         window['msRequestAnimationFrame'] ||
                                         window['oRequestAnimationFrame'] ||
                                         window['setTimeout'];
        }
        window.requestAnimationFrame(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        canvas.width = width;
        canvas.height = height;
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        var canvas = Module['canvas'];
        this.windowedWidth = canvas.width;
        this.windowedHeight = canvas.height;
        canvas.width = screen.width;
        canvas.height = screen.height;
        var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        var canvas = Module['canvas'];
        canvas.width = this.windowedWidth;
        canvas.height = this.windowedHeight;
        var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        Browser.updateResizeListeners();
      }};
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___setErrNo(0);
Module["requestFullScreen"] = function(lockPointer, resizeCanvas) { Browser.requestFullScreen(lockPointer, resizeCanvas) };
  Module["requestAnimationFrame"] = function(func) { Browser.requestAnimationFrame(func) };
  Module["pauseMainLoop"] = function() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function() { Browser.mainLoop.resume() };
var Math_min = Math.min;
function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module.dynCall_iiii(index,a1,a2,a3);
  } catch(e) {
    asm.setThrew(1, 0);
  }
}
function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module.dynCall_viiiii(index,a1,a2,a3,a4,a5);
  } catch(e) {
    asm.setThrew(1, 0);
  }
}
function invoke_vi(index,a1) {
  try {
    Module.dynCall_vi(index,a1);
  } catch(e) {
    asm.setThrew(1, 0);
  }
}
function invoke_vii(index,a1,a2) {
  try {
    Module.dynCall_vii(index,a1,a2);
  } catch(e) {
    asm.setThrew(1, 0);
  }
}
function invoke_iiiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    return Module.dynCall_iiiiiii(index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    asm.setThrew(1, 0);
  }
}
function invoke_ii(index,a1) {
  try {
    return Module.dynCall_ii(index,a1);
  } catch(e) {
    asm.setThrew(1, 0);
  }
}
function invoke_iiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    return Module.dynCall_iiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    asm.setThrew(1, 0);
  }
}
function invoke_viii(index,a1,a2,a3) {
  try {
    Module.dynCall_viii(index,a1,a2,a3);
  } catch(e) {
    asm.setThrew(1, 0);
  }
}
function invoke_v(index) {
  try {
    Module.dynCall_v(index);
  } catch(e) {
    asm.setThrew(1, 0);
  }
}
function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module.dynCall_iiiii(index,a1,a2,a3,a4);
  } catch(e) {
    asm.setThrew(1, 0);
  }
}
function invoke_iiiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module.dynCall_iiiiiiii(index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    asm.setThrew(1, 0);
  }
}
function invoke_viiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module.dynCall_viiiiii(index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    asm.setThrew(1, 0);
  }
}
function invoke_iii(index,a1,a2) {
  try {
    return Module.dynCall_iii(index,a1,a2);
  } catch(e) {
    asm.setThrew(1, 0);
  }
}
function invoke_iiiiii(index,a1,a2,a3,a4,a5) {
  try {
    return Module.dynCall_iiiiii(index,a1,a2,a3,a4,a5);
  } catch(e) {
    asm.setThrew(1, 0);
  }
}
function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module.dynCall_viiii(index,a1,a2,a3,a4);
  } catch(e) {
    asm.setThrew(1, 0);
  }
}
function asmPrintInt(x, y) {
  Module.print('int ' + x);// + ' ' + new Error().stack);
}
function asmPrintFloat(x, y) {
  Module.print('float ' + x + ',' + y);// + ' ' + new Error().stack);
}
// EMSCRIPTEN_START_ASM
var asm = (function(global, env, buffer) {
  'use asm';
  var HEAP8 = new global.Int8Array(buffer);
  var HEAP16 = new global.Int16Array(buffer);
  var HEAP32 = new global.Int32Array(buffer);
  var HEAPU8 = new global.Uint8Array(buffer);
  var HEAPU16 = new global.Uint16Array(buffer);
  var HEAPU32 = new global.Uint32Array(buffer);
  var HEAPF32 = new global.Float32Array(buffer);
  var HEAPF64 = new global.Float64Array(buffer);
  var STACKTOP=env.STACKTOP|0;
  var STACK_MAX=env.STACK_MAX|0;
  var tempDoublePtr=env.tempDoublePtr|0;
  var ABORT=env.ABORT|0;
  var _stderr=env._stderr|0;
  var _stdout=env._stdout|0;
  var NaN=+env.NaN;
  var Infinity=+env.Infinity;
  var __THREW__ = 0;
  var threwValue = 0;
  var setjmpId = 0;
  var undef = 0;
  var tempInt = 0, tempBigInt = 0, tempBigIntP = 0, tempBigIntS = 0, tempBigIntR = 0.0, tempBigIntI = 0, tempBigIntD = 0, tempValue = 0, tempDouble = 0.0;
  var tempRet0 = 0;
  var tempRet1 = 0;
  var tempRet2 = 0;
  var tempRet3 = 0;
  var tempRet4 = 0;
  var tempRet5 = 0;
  var tempRet6 = 0;
  var tempRet7 = 0;
  var tempRet8 = 0;
  var tempRet9 = 0;
  var Math_floor=global.Math.floor;
  var Math_abs=global.Math.abs;
  var Math_sqrt=global.Math.sqrt;
  var Math_pow=global.Math.pow;
  var Math_cos=global.Math.cos;
  var Math_sin=global.Math.sin;
  var Math_tan=global.Math.tan;
  var Math_acos=global.Math.acos;
  var Math_asin=global.Math.asin;
  var Math_atan=global.Math.atan;
  var Math_atan2=global.Math.atan2;
  var Math_exp=global.Math.exp;
  var Math_log=global.Math.log;
  var Math_ceil=global.Math.ceil;
  var Math_imul=global.Math.imul;
  var abort=env.abort;
  var assert=env.assert;
  var asmPrintInt=env.asmPrintInt;
  var asmPrintFloat=env.asmPrintFloat;
  var copyTempDouble=env.copyTempDouble;
  var copyTempFloat=env.copyTempFloat;
  var Math_min=env.min;
  var invoke_iiii=env.invoke_iiii;
  var invoke_viiiii=env.invoke_viiiii;
  var invoke_vi=env.invoke_vi;
  var invoke_vii=env.invoke_vii;
  var invoke_iiiiiii=env.invoke_iiiiiii;
  var invoke_ii=env.invoke_ii;
  var invoke_iiiiiiiiii=env.invoke_iiiiiiiiii;
  var invoke_viii=env.invoke_viii;
  var invoke_v=env.invoke_v;
  var invoke_iiiii=env.invoke_iiiii;
  var invoke_iiiiiiii=env.invoke_iiiiiiii;
  var invoke_viiiiii=env.invoke_viiiiii;
  var invoke_iii=env.invoke_iii;
  var invoke_iiiiii=env.invoke_iiiiii;
  var invoke_viiii=env.invoke_viiii;
  var _strncmp=env._strncmp;
  var _lseek=env._lseek;
  var _pread=env._pread;
  var _snprintf=env._snprintf;
  var _fclose=env._fclose;
  var _abort=env._abort;
  var _fprintf=env._fprintf;
  var _printf=env._printf;
  var _close=env._close;
  var _fopen=env._fopen;
  var __reallyNegative=env.__reallyNegative;
  var _strtol=env._strtol;
  var _fputc=env._fputc;
  var _sysconf=env._sysconf;
  var _open=env._open;
  var ___setErrNo=env.___setErrNo;
  var _fwrite=env._fwrite;
  var _fseek=env._fseek;
  var _qsort=env._qsort;
  var _write=env._write;
  var _ftell=env._ftell;
  var _exit=env._exit;
  var _sprintf=env._sprintf;
  var _strrchr=env._strrchr;
  var _sin=env._sin;
  var _fread=env._fread;
  var _longjmp=env._longjmp;
  var _read=env._read;
  var _llvm_uadd_with_overflow_i32=env._llvm_uadd_with_overflow_i32;
  var __formatString=env.__formatString;
  var _atoi=env._atoi;
  var _cos=env._cos;
  var _pwrite=env._pwrite;
  var _strstr=env._strstr;
  var _sbrk=env._sbrk;
  var _fsync=env._fsync;
  var ___errno_location=env.___errno_location;
  var _isspace=env._isspace;
  var __parseInt=env.__parseInt;
  var _time=env._time;
  var __exit=env.__exit;
  var _strcmp=env._strcmp;
  var _memchr=env._memchr;
// EMSCRIPTEN_START_FUNCS
function stackAlloc(size) {
  size = size | 0;
  var ret = 0;
  ret = STACKTOP;
  STACKTOP = STACKTOP + size | 0;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  return ret | 0;
}
function stackSave() {
  return STACKTOP | 0;
}
function stackRestore(top) {
  top = top | 0;
  STACKTOP = top;
}
function setThrew(threw, value) {
  threw = threw | 0;
  value = value | 0;
  if ((__THREW__ | 0) == 0) {
    __THREW__ = threw;
    threwValue = value;
  }
}
function setTempRet0(value) {
  value = value | 0;
  tempRet0 = value;
}
function setTempRet1(value) {
  value = value | 0;
  tempRet1 = value;
}
function setTempRet2(value) {
  value = value | 0;
  tempRet2 = value;
}
function setTempRet3(value) {
  value = value | 0;
  tempRet3 = value;
}
function setTempRet4(value) {
  value = value | 0;
  tempRet4 = value;
}
function setTempRet5(value) {
  value = value | 0;
  tempRet5 = value;
}
function setTempRet6(value) {
  value = value | 0;
  tempRet6 = value;
}
function setTempRet7(value) {
  value = value | 0;
  tempRet7 = value;
}
function setTempRet8(value) {
  value = value | 0;
  tempRet8 = value;
}
function setTempRet9(value) {
  value = value | 0;
  tempRet9 = value;
}
function _FT_RoundFix($a) {
  $a = $a | 0;
  var $1 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($a | 0) > -1;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = $a + 32768 | 0;
    $4 = $3 & -65536;
    $10 = $4;
    label = 4;
    break;
   case 3:
    $6 = 32768 - $a | 0;
    $7 = $6 & -65536;
    $8 = -$7 | 0;
    $10 = $8;
    label = 4;
    break;
   case 4:
    return $10 | 0;
  }
  return 0;
}
function _ft_div64by32($hi, $lo, $y) {
  $hi = $hi | 0;
  $lo = $lo | 0;
  $y = $y | 0;
  var $1 = 0, $_013 = 0, $r_0 = 0, $q_0 = 0, $i_0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $r_1 = 0, $q_1 = 0, $11 = 0, $12 = 0, $13 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hi >>> 0 < $y >>> 0;
    if ($1) {
      $i_0 = 32;
      $q_0 = 0;
      $r_0 = $hi;
      $_013 = $lo;
      label = 2;
      break;
    } else {
      $_0 = 2147483647;
      label = 5;
      break;
    }
   case 2:
    $2 = $r_0 << 1;
    $3 = $q_0 << 1;
    $4 = $_013 >>> 31;
    $5 = $2 | $4;
    $6 = $5 >>> 0 < $y >>> 0;
    if ($6) {
      $q_1 = $3;
      $r_1 = $5;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $8 = $5 - $y | 0;
    $9 = $3 | 1;
    $q_1 = $9;
    $r_1 = $8;
    label = 4;
    break;
   case 4:
    $11 = $_013 << 1;
    $12 = $i_0 - 1 | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      $_0 = $q_1;
      label = 5;
      break;
    } else {
      $i_0 = $12;
      $q_0 = $q_1;
      $r_0 = $r_1;
      $_013 = $11;
      label = 2;
      break;
    }
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function __Z11draw_bitmapP10FT_Bitmap_ii($bitmap, $x, $y) {
  $bitmap = $bitmap | 0;
  $x = $x | 0;
  $y = $y | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i_022 = 0, $p_021 = 0, $j_020 = 0, $q_019 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $or_cond18 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $bitmap + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + $x | 0;
    $4 = $bitmap | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 + $y | 0;
    $7 = ($2 | 0) > 0;
    if ($7) {
      label = 2;
      break;
    } else {
      label = 9;
      break;
    }
   case 2:
    $8 = ($5 | 0) > 0;
    $9 = $bitmap + 12 | 0;
    $p_021 = 0;
    $i_022 = $x;
    label = 3;
    break;
   case 3:
    if ($8) {
      $q_019 = 0;
      $j_020 = $y;
      label = 4;
      break;
    } else {
      label = 8;
      break;
    }
   case 4:
    $10 = $j_020 | $i_022;
    $11 = ($10 | 0) < 0;
    if ($11) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $13 = HEAP32[1331693] | 0;
    $14 = ($i_022 | 0) < ($13 | 0);
    $15 = HEAP32[1331775] | 0;
    $16 = ($j_020 | 0) < ($15 | 0);
    $or_cond18 = $14 & $16;
    if ($or_cond18) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $18 = HEAP32[$1 >> 2] | 0;
    $19 = Math_imul($18, $q_019);
    $20 = $19 + $p_021 | 0;
    $21 = HEAP32[$9 >> 2] | 0;
    $22 = $21 + $20 | 0;
    $23 = HEAP8[$22] | 0;
    $24 = Math_imul($13, $j_020);
    $25 = $24 + $i_022 | 0;
    $26 = HEAP32[1312828] | 0;
    $27 = $26 + $25 | 0;
    $28 = HEAP8[$27] | 0;
    $29 = $28 | $23;
    HEAP8[$27] = $29;
    label = 7;
    break;
   case 7:
    $31 = $j_020 + 1 | 0;
    $32 = $q_019 + 1 | 0;
    $33 = ($31 | 0) < ($6 | 0);
    if ($33) {
      $q_019 = $32;
      $j_020 = $31;
      label = 4;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $34 = $i_022 + 1 | 0;
    $35 = $p_021 + 1 | 0;
    $36 = ($34 | 0) < ($3 | 0);
    if ($36) {
      $p_021 = $35;
      $i_022 = $34;
      label = 3;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    return;
  }
}
function __Z10show_imagev() {
  var $1 = 0, $2 = 0, $count_014 = 0, $i_012 = 0, $3 = 0, $4 = 0, $5 = 0, $count_111 = 0, $j_010 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $count_1_ = 0, $15 = 0, $16 = 0, $phitmp = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $count_1_lcssa = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $count_0_lcssa = 0, $29 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[1331775] | 0;
    $2 = ($1 | 0) > 0;
    if ($2) {
      $i_012 = 0;
      $count_014 = 0;
      label = 2;
      break;
    } else {
      $count_0_lcssa = 0;
      label = 7;
      break;
    }
   case 2:
    $3 = HEAP32[1331693] | 0;
    $4 = ($3 | 0) > 0;
    if ($4) {
      $j_010 = 0;
      $count_111 = $count_014;
      $5 = $3;
      label = 3;
      break;
    } else {
      $count_1_lcssa = $count_014;
      label = 6;
      break;
    }
   case 3:
    $6 = Math_imul($5, $i_012);
    $7 = $6 + $j_010 | 0;
    $8 = HEAP32[1312828] | 0;
    $9 = $8 + $7 | 0;
    $10 = HEAP8[$9] | 0;
    $11 = $10 << 24 >> 24 == 0;
    $12 = $11 & 1;
    $13 = $12 ^ 1;
    $count_1_ = $13 + $count_111 | 0;
    if ($11) {
      $18 = 32;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $15 = $10 << 24 >> 24 >> 7;
    $16 = $15 + 43 & 255;
    $phitmp = $16 << 24 >> 24;
    $18 = $phitmp;
    label = 5;
    break;
   case 5:
    $19 = HEAP32[_stdout >> 2] | 0;
    $20 = _fputc($18 | 0, $19 | 0) | 0;
    $21 = $j_010 + 1 | 0;
    $22 = HEAP32[1331693] | 0;
    $23 = ($21 | 0) < ($22 | 0);
    if ($23) {
      $j_010 = $21;
      $count_111 = $count_1_;
      $5 = $22;
      label = 3;
      break;
    } else {
      $count_1_lcssa = $count_1_;
      label = 6;
      break;
    }
   case 6:
    $24 = HEAP32[_stdout >> 2] | 0;
    $25 = _fputc(10, $24 | 0) | 0;
    $26 = $i_012 + 1 | 0;
    $27 = HEAP32[1331775] | 0;
    $28 = ($26 | 0) < ($27 | 0);
    if ($28) {
      $i_012 = $26;
      $count_014 = $count_1_lcssa;
      label = 2;
      break;
    } else {
      $count_0_lcssa = $count_1_lcssa;
      label = 7;
      break;
    }
   case 7:
    $29 = _printf(5324944, (tempInt = STACKTOP, STACKTOP = STACKTOP + 4 | 0, HEAP32[tempInt >> 2] = $count_0_lcssa, tempInt) | 0) | 0;
    STACKTOP = __stackBase__;
    return;
  }
}
function _FT_Get_Advance($face, $gindex, $flags, $padvance) {
  $face = $face | 0;
  $gindex = $gindex | 0;
  $flags = $flags | 0;
  $padvance = $padvance | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $or_cond = 0, $20 = 0, $22 = 0, $24 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($face | 0) == 0;
    if ($1) {
      $_0 = 35;
      label = 8;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 16 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 >>> 0 > $gindex >>> 0;
    if ($5) {
      label = 3;
      break;
    } else {
      $_0 = 16;
      label = 8;
      break;
    }
   case 3:
    $7 = $face + 96 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 + 20 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10 + 92 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 7;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $15 = $flags & 3;
    $16 = ($15 | 0) != 0;
    $17 = $flags & 983040;
    $18 = ($17 | 0) == 65536;
    $or_cond = $16 | $18;
    if ($or_cond) {
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    $20 = FUNCTION_TABLE_iiiiii[$12 & 1023]($face, $gindex, 1, $flags, $padvance) | 0;
    if (($20 | 0) == 0) {
      label = 6;
      break;
    } else if (($20 | 0) == 7) {
      label = 7;
      break;
    } else {
      $_0 = $20;
      label = 8;
      break;
    }
   case 6:
    $22 = __ft_face_scale_advances($face, $padvance, 1, $flags) | 0;
    $_0 = $22;
    label = 8;
    break;
   case 7:
    $24 = _FT_Get_Advances($face, $gindex, 1, $flags, $padvance) | 0;
    $_0 = $24;
    label = 8;
    break;
   case 8:
    return $_0 | 0;
  }
  return 0;
}
function __ft_face_scale_advances($face, $advances, $count, $flags) {
  $face = $face | 0;
  $advances = $advances | 0;
  $count = $count | 0;
  $flags = $flags | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $scale_0_in = 0, $scale_0 = 0, $12 = 0, $nn_011 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $exitcond = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $flags & 1;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 5;
      break;
    }
   case 2:
    $4 = $face + 88 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      $_0 = 36;
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $8 = $flags & 16;
    $9 = ($8 | 0) == 0;
    $10 = $5 + 20 | 0;
    $11 = $5 + 16 | 0;
    $scale_0_in = $9 ? $11 : $10;
    $scale_0 = HEAP32[$scale_0_in >> 2] | 0;
    $12 = ($count | 0) == 0;
    if ($12) {
      $_0 = 0;
      label = 5;
      break;
    } else {
      $nn_011 = 0;
      label = 4;
      break;
    }
   case 4:
    $13 = $advances + ($nn_011 << 2) | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = _FT_MulDiv($14, $scale_0, 64) | 0;
    HEAP32[$13 >> 2] = $15;
    $16 = $nn_011 + 1 | 0;
    $exitcond = ($16 | 0) == ($count | 0);
    if ($exitcond) {
      $_0 = 0;
      label = 5;
      break;
    } else {
      $nn_011 = $16;
      label = 4;
      break;
    }
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function _FT_Get_Advances($face, $start, $count, $flags, $padvances) {
  $face = $face | 0;
  $start = $start | 0;
  $count = $count | 0;
  $flags = $flags | 0;
  $padvances = $padvances | 0;
  var $1 = 0, $3 = 0, $4 = 0, $uadd$0 = 0, $uadd$1 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $or_cond = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $or_cond42 = 0, $26 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $nn_043 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $_in = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $_040 = 0, $48 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($face | 0) == 0;
    if ($1) {
      $_0 = 35;
      label = 14;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 16 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $uadd$0 = _llvm_uadd_with_overflow_i32($start | 0, $count | 0) | 0;
    $uadd$1 = tempRet0;
    $5 = $4 >>> 0 > $start >>> 0;
    if ($5) {
      label = 3;
      break;
    } else {
      $_0 = 16;
      label = 14;
      break;
    }
   case 3:
    $7 = $uadd$0;
    $8 = $uadd$1;
    $9 = $7 >>> 0 > $4 >>> 0;
    $or_cond = $8 | $9;
    if ($or_cond) {
      $_0 = 16;
      label = 14;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $11 = ($count | 0) == 0;
    if ($11) {
      $_0 = 0;
      label = 14;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $13 = $face + 96 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 + 20 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $16 + 92 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $21 = $flags & 3;
    $22 = ($21 | 0) != 0;
    $23 = $flags & 983040;
    $24 = ($23 | 0) == 65536;
    $or_cond42 = $22 | $24;
    if ($or_cond42) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $26 = FUNCTION_TABLE_iiiiii[$18 & 1023]($face, $start, $count, $flags, $padvances) | 0;
    if (($26 | 0) == 7) {
      label = 8;
      break;
    } else if (($26 | 0) == 0) {
      $_040 = $flags;
      label = 13;
      break;
    } else {
      $_0 = $26;
      label = 14;
      break;
    }
   case 8:
    $28 = $flags & 536870912;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 9;
      break;
    } else {
      $_0 = 7;
      label = 14;
      break;
    }
   case 9:
    $31 = $flags | 256;
    $32 = ($count | 0) == 0;
    if ($32) {
      $_040 = $31;
      label = 13;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $33 = $flags & 16;
    $34 = ($33 | 0) == 0;
    $35 = $face + 84 | 0;
    $nn_043 = 0;
    label = 11;
    break;
   case 11:
    $37 = $nn_043 + $start | 0;
    $38 = _FT_Load_Glyph($face, $37, $31) | 0;
    $39 = ($38 | 0) == 0;
    if ($39) {
      label = 12;
      break;
    } else {
      $_0 = $38;
      label = 14;
      break;
    }
   case 12:
    $41 = HEAP32[$35 >> 2] | 0;
    $42 = $41 + 68 | 0;
    $43 = $41 + 64 | 0;
    $_in = $34 ? $43 : $42;
    $44 = HEAP32[$_in >> 2] | 0;
    $45 = $padvances + ($nn_043 << 2) | 0;
    HEAP32[$45 >> 2] = $44;
    $46 = $nn_043 + 1 | 0;
    $47 = $46 >>> 0 < $count >>> 0;
    if ($47) {
      $nn_043 = $46;
      label = 11;
      break;
    } else {
      $_040 = $31;
      label = 13;
      break;
    }
   case 13:
    $48 = __ft_face_scale_advances($face, $padvances, $count, $_040) | 0;
    $_0 = $48;
    label = 14;
    break;
   case 14:
    return $_0 | 0;
  }
  return 0;
}
function _FT_Load_Glyph($face, $glyph_index, $load_flags) {
  $face = $face | 0;
  $glyph_index = $glyph_index | 0;
  $load_flags = $load_flags | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $load_flags_ = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $_1 = 0, $26 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $71 = 0, $72 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $82 = 0, $83 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $94 = 0, $95 = 0, $96 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $119 = 0, $120 = 0, $121 = 0, $123 = 0, $124 = 0, $125 = 0, $127 = 0, $128 = 0, $_1_tr = 0, $130 = 0, $error_0 = 0, $132 = 0, $133 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $145 = 0, $146 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $165 = 0, $166 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $174 = 0, $175 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $185 = 0, $186 = 0, $187 = 0, $189 = 0, $190 = 0, $192 = 0, $194 = 0, $195 = 0, $197 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $error_1 = 0, $203 = 0, $204 = 0, $error_2 = 0, $206 = 0, $208 = 0, $209 = 0, $211 = 0, $212 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $or_cond106 = 0, $mode2_0 = 0, $219 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($face | 0) == 0;
    if ($1) {
      $_0 = 35;
      label = 48;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 88 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $_0 = 35;
      label = 48;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $face + 84 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      $_0 = 35;
      label = 48;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    _ft_glyphslot_clear($8);
    $11 = $face + 96 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + 4 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 + 168 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $load_flags & 1024;
    $18 = ($17 | 0) == 0;
    $19 = $load_flags | 2049;
    $load_flags_ = $18 ? $load_flags : $19;
    $20 = $load_flags_ & 1;
    $21 = ($20 | 0) == 0;
    if ($21) {
      $_1 = $load_flags_;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $23 = $load_flags_ & -15;
    $24 = $23 | 10;
    $_1 = $24;
    label = 6;
    break;
   case 6:
    $26 = ($16 | 0) == 0;
    if ($26) {
      label = 23;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $28 = $_1 & 32770;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 8;
      break;
    } else {
      label = 23;
      break;
    }
   case 8:
    $31 = $12 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $32 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $34 & 768;
    $36 = ($35 | 0) == 256;
    if ($36) {
      label = 9;
      break;
    } else {
      label = 23;
      break;
    }
   case 9:
    $38 = $face + 8 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = $39 & 8192;
    $41 = ($40 | 0) == 0;
    if ($41) {
      label = 10;
      break;
    } else {
      label = 23;
      break;
    }
   case 10:
    $43 = $face + 128 | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    $45 = $44 + 12 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = ($46 | 0) == 0;
    if ($47) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $49 = $44 + 4 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = ($50 | 0) == 0;
    if ($51) {
      label = 12;
      break;
    } else {
      label = 14;
      break;
    }
   case 12:
    $53 = HEAP32[$43 >> 2] | 0;
    $54 = $53 + 4 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = ($55 | 0) == 0;
    if ($56) {
      label = 13;
      break;
    } else {
      label = 23;
      break;
    }
   case 13:
    $58 = $53 + 12 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = ($59 | 0) == 0;
    if ($60) {
      label = 23;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $62 = $_1 & 32;
    $63 = ($62 | 0) == 0;
    if ($63) {
      label = 15;
      break;
    } else {
      label = 18;
      break;
    }
   case 15:
    $65 = HEAP32[$31 >> 2] | 0;
    $66 = $65 | 0;
    $67 = HEAP32[$66 >> 2] | 0;
    $68 = $67 & 1024;
    $69 = ($68 | 0) == 0;
    if ($69) {
      label = 18;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $71 = $_1 & 983040;
    $72 = ($71 | 0) == 65536;
    if ($72) {
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $74 = HEAP32[$43 >> 2] | 0;
    $75 = $74 + 56 | 0;
    $76 = HEAP8[$75] | 0;
    $77 = $76 << 24 >> 24 == 0;
    if ($77) {
      label = 23;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $78 = HEAP32[$38 >> 2] | 0;
    $79 = $78 & 2;
    $80 = ($79 | 0) == 0;
    if ($80) {
      label = 22;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $82 = $_1 & 8;
    $83 = ($82 | 0) == 0;
    if ($83) {
      label = 20;
      break;
    } else {
      label = 22;
      break;
    }
   case 20:
    $85 = $12 + 20 | 0;
    $86 = HEAP32[$85 >> 2] | 0;
    $87 = $86 + 80 | 0;
    $88 = HEAP32[$87 >> 2] | 0;
    $89 = HEAP32[$3 >> 2] | 0;
    $90 = $_1 | 16384;
    $91 = FUNCTION_TABLE_iiiii[$88 & 1023]($8, $89, $glyph_index, $90) | 0;
    $92 = ($91 | 0) == 0;
    if ($92) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    $94 = $8 + 72 | 0;
    $95 = HEAP32[$94 >> 2] | 0;
    $96 = ($95 | 0) == 1651078259;
    if ($96) {
      $error_0 = 0;
      label = 28;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $98 = HEAP32[$43 >> 2] | 0;
    $99 = $98 + 28 | 0;
    $100 = HEAP32[$99 >> 2] | 0;
    HEAP32[$99 >> 2] = 0;
    $101 = $16 | 0;
    $102 = HEAP32[$101 >> 2] | 0;
    $103 = $102 + 20 | 0;
    $104 = HEAP32[$103 >> 2] | 0;
    $105 = $104 + 12 | 0;
    $106 = $105;
    $107 = HEAP32[$106 >> 2] | 0;
    $108 = $16;
    $109 = HEAP32[$3 >> 2] | 0;
    $110 = FUNCTION_TABLE_iiiiii[$107 & 1023]($108, $8, $109, $glyph_index, $_1) | 0;
    HEAP32[$99 >> 2] = $100;
    $error_0 = $110;
    label = 28;
    break;
   case 23:
    $111 = $12 + 20 | 0;
    $112 = HEAP32[$111 >> 2] | 0;
    $113 = $112 + 80 | 0;
    $114 = HEAP32[$113 >> 2] | 0;
    $115 = HEAP32[$3 >> 2] | 0;
    $116 = FUNCTION_TABLE_iiiii[$114 & 1023]($8, $115, $glyph_index, $_1) | 0;
    $117 = ($116 | 0) == 0;
    if ($117) {
      label = 24;
      break;
    } else {
      $_0 = $116;
      label = 48;
      break;
    }
   case 24:
    $119 = $8 + 72 | 0;
    $120 = HEAP32[$119 >> 2] | 0;
    $121 = ($120 | 0) == 1869968492;
    if ($121) {
      label = 25;
      break;
    } else {
      $error_0 = 0;
      label = 28;
      break;
    }
   case 25:
    $123 = $8 + 108 | 0;
    $124 = _FT_Outline_Check($123) | 0;
    $125 = ($124 | 0) == 0;
    if ($125) {
      label = 26;
      break;
    } else {
      $_0 = $124;
      label = 48;
      break;
    }
   case 26:
    $127 = $_1 & 2;
    $128 = ($127 | 0) == 0;
    if ($128) {
      label = 27;
      break;
    } else {
      $error_0 = 0;
      label = 28;
      break;
    }
   case 27:
    $_1_tr = $_1 & 255;
    $130 = $_1_tr & 16;
    _ft_glyphslot_grid_fit_metrics($8, $130);
    $error_0 = $124;
    label = 28;
    break;
   case 28:
    $132 = $_1 & 16;
    $133 = ($132 | 0) == 0;
    if ($133) {
      label = 30;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    $135 = $8 + 64 | 0;
    HEAP32[$135 >> 2] = 0;
    $136 = $8 + 52 | 0;
    $137 = HEAP32[$136 >> 2] | 0;
    $138 = $8 + 68 | 0;
    HEAP32[$138 >> 2] = $137;
    label = 31;
    break;
   case 30:
    $140 = $8 + 40 | 0;
    $141 = HEAP32[$140 >> 2] | 0;
    $142 = $8 + 64 | 0;
    HEAP32[$142 >> 2] = $141;
    $143 = $8 + 68 | 0;
    HEAP32[$143 >> 2] = 0;
    label = 31;
    break;
   case 31:
    $145 = $_1 & 8192;
    $146 = ($145 | 0) == 0;
    if ($146) {
      label = 32;
      break;
    } else {
      label = 34;
      break;
    }
   case 32:
    $148 = $face + 8 | 0;
    $149 = HEAP32[$148 >> 2] | 0;
    $150 = $149 & 1;
    $151 = ($150 | 0) == 0;
    if ($151) {
      label = 34;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    $153 = HEAP32[$3 >> 2] | 0;
    $154 = $8 + 56 | 0;
    $155 = HEAP32[$154 >> 2] | 0;
    $156 = $153 + 16 | 0;
    $157 = HEAP32[$156 >> 2] | 0;
    $158 = _FT_MulDiv($155, $157, 64) | 0;
    HEAP32[$154 >> 2] = $158;
    $159 = $8 + 60 | 0;
    $160 = HEAP32[$159 >> 2] | 0;
    $161 = $153 + 20 | 0;
    $162 = HEAP32[$161 >> 2] | 0;
    $163 = _FT_MulDiv($160, $162, 64) | 0;
    HEAP32[$159 >> 2] = $163;
    label = 34;
    break;
   case 34:
    $165 = $_1 & 2048;
    $166 = ($165 | 0) == 0;
    if ($166) {
      label = 35;
      break;
    } else {
      $error_2 = $error_0;
      label = 44;
      break;
    }
   case 35:
    $168 = $face + 128 | 0;
    $169 = HEAP32[$168 >> 2] | 0;
    $170 = $169 + 28 | 0;
    $171 = HEAP32[$170 >> 2] | 0;
    $172 = ($171 | 0) == 0;
    if ($172) {
      $error_2 = $error_0;
      label = 44;
      break;
    } else {
      label = 36;
      break;
    }
   case 36:
    $174 = _ft_lookup_glyph_renderer($8) | 0;
    $175 = ($174 | 0) == 0;
    if ($175) {
      label = 38;
      break;
    } else {
      label = 37;
      break;
    }
   case 37:
    $177 = $174 + 20 | 0;
    $178 = HEAP32[$177 >> 2] | 0;
    $179 = $178 + 44 | 0;
    $180 = HEAP32[$179 >> 2] | 0;
    $181 = $169 + 4 | 0;
    $182 = $169 + 20 | 0;
    $183 = FUNCTION_TABLE_iiiii[$180 & 1023]($174, $8, $181, $182) | 0;
    $error_1 = $183;
    label = 43;
    break;
   case 38:
    $185 = $8 + 72 | 0;
    $186 = HEAP32[$185 >> 2] | 0;
    $187 = ($186 | 0) == 1869968492;
    if ($187) {
      label = 39;
      break;
    } else {
      $error_1 = $error_0;
      label = 43;
      break;
    }
   case 39:
    $189 = $169 + 4 | 0;
    $190 = ($189 | 0) == 0;
    if ($190) {
      label = 41;
      break;
    } else {
      label = 40;
      break;
    }
   case 40:
    $192 = $8 + 108 | 0;
    _FT_Outline_Transform($192, $189);
    label = 41;
    break;
   case 41:
    $194 = $169 + 20 | 0;
    $195 = ($194 | 0) == 0;
    if ($195) {
      $error_1 = $error_0;
      label = 43;
      break;
    } else {
      label = 42;
      break;
    }
   case 42:
    $197 = $8 + 108 | 0;
    $198 = $194 | 0;
    $199 = HEAP32[$198 >> 2] | 0;
    $200 = $169 + 24 | 0;
    $201 = HEAP32[$200 >> 2] | 0;
    _FT_Outline_Translate($197, $199, $201);
    $error_1 = $error_0;
    label = 43;
    break;
   case 43:
    $203 = $8 + 64 | 0;
    $204 = $169 + 4 | 0;
    _FT_Vector_Transform($203, $204);
    $error_2 = $error_1;
    label = 44;
    break;
   case 44:
    $206 = ($error_2 | 0) == 0;
    if ($206) {
      label = 45;
      break;
    } else {
      $_0 = $error_2;
      label = 48;
      break;
    }
   case 45:
    $208 = $8 + 72 | 0;
    $209 = HEAP32[$208 >> 2] | 0;
    if (($209 | 0) == 1651078259 | ($209 | 0) == 1668246896) {
      $_0 = 0;
      label = 48;
      break;
    } else {
      label = 46;
      break;
    }
   case 46:
    $211 = $_1 & 4;
    $212 = ($211 | 0) == 0;
    if ($212) {
      $_0 = $error_2;
      label = 48;
      break;
    } else {
      label = 47;
      break;
    }
   case 47:
    $214 = $_1 >>> 16;
    $215 = $214 & 15;
    $216 = ($215 | 0) != 0;
    $217 = $_1 & 4096;
    $218 = ($217 | 0) == 0;
    $or_cond106 = $216 | $218;
    $mode2_0 = $or_cond106 ? $215 : 2;
    $219 = _FT_Render_Glyph($8, $mode2_0) | 0;
    $_0 = $219;
    label = 48;
    break;
   case 48:
    return $_0 | 0;
  }
  return 0;
}
function _FT_MulDiv($a, $b, $c) {
  $a = $a | 0;
  $b = $b | 0;
  $c = $c | 0;
  var $temp = 0, $temp2 = 0, $1 = 0, $2 = 0, $or_cond = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $or_cond32 = 0, $_off = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $_0 = 0, $36 = 0, $37 = 0, $38 = 0, $_031 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $temp = __stackBase__ | 0;
    $temp2 = __stackBase__ + 8 | 0;
    $1 = ($a | 0) == 0;
    $2 = ($b | 0) == ($c | 0);
    $or_cond = $1 | $2;
    if ($or_cond) {
      $_031 = $a;
      label = 8;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = ($a | 0) < 0;
    $5 = -$a | 0;
    $6 = $4 ? $5 : $a;
    $7 = $b ^ $a;
    $8 = ($b | 0) < 0;
    $9 = -$b | 0;
    $10 = $8 ? $9 : $b;
    $11 = $7 ^ $c;
    $12 = ($c | 0) < 0;
    $13 = -$c | 0;
    $14 = $12 ? $13 : $c;
    $15 = ($6 | 0) < 46341;
    $16 = ($10 | 0) < 46341;
    $or_cond32 = $15 & $16;
    if ($or_cond32) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $_off = $14 - 1 | 0;
    $18 = $_off >>> 0 < 176095;
    if ($18) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $20 = Math_imul($10, $6);
    $21 = $14 >> 1;
    $22 = $21 + $20 | 0;
    $23 = ($22 | 0) / ($14 | 0) & -1;
    $_0 = $23;
    label = 7;
    break;
   case 5:
    $25 = ($14 | 0) > 0;
    if ($25) {
      label = 6;
      break;
    } else {
      $_0 = 2147483647;
      label = 7;
      break;
    }
   case 6:
    _ft_multo64($6, $10, $temp);
    $27 = $temp2 + 4 | 0;
    HEAP32[$27 >> 2] = 0;
    $28 = $14 >> 1;
    $29 = $temp2 | 0;
    HEAP32[$29 >> 2] = $28;
    _FT_Add64($temp, $temp2, $temp);
    $30 = $temp + 4 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $temp | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = _ft_div64by32($31, $33, $14) | 0;
    $_0 = $34;
    label = 7;
    break;
   case 7:
    $36 = ($11 | 0) < 0;
    $37 = -$_0 | 0;
    $38 = $36 ? $37 : $_0;
    $_031 = $38;
    label = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return $_031 | 0;
  }
  return 0;
}
function _ft_multo64($x, $y, $z) {
  $x = $x | 0;
  $y = $y | 0;
  $z = $z | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $uadd$0 = 0, $9 = 0, $12 = 0, $uadd21$0 = 0;
  $1 = $x & 65535;
  $2 = $x >>> 16;
  $3 = $y & 65535;
  $4 = $y >>> 16;
  $5 = Math_imul($3, $1);
  $6 = Math_imul($4, $1);
  $7 = Math_imul($3, $2);
  $8 = Math_imul($4, $2);
  $uadd$0 = _llvm_uadd_with_overflow_i32($6 | 0, $7 | 0) | 0;
  $9 = $uadd$0;
  $12 = (tempRet0 & 1) << 16;
  $uadd21$0 = _llvm_uadd_with_overflow_i32($5 | 0, $9 << 16 | 0) | 0;
  HEAP32[$z >> 2] = $uadd21$0;
  HEAP32[$z + 4 >> 2] = ((($9 >>> 16) + $8 | 0) + $12 | 0) + (tempRet0 & 1) | 0;
  return;
}
function _FT_Add64($x, $y, $z) {
  $x = $x | 0;
  $y = $y | 0;
  $z = $z | 0;
  var $uadd$0 = 0, $13 = 0;
  $uadd$0 = _llvm_uadd_with_overflow_i32(HEAP32[$x >> 2] | 0, HEAP32[$y >> 2] | 0) | 0;
  $13 = ((HEAP32[$y + 4 >> 2] | 0) + (HEAP32[$x + 4 >> 2] | 0) | 0) + (tempRet0 & 1) | 0;
  HEAP32[$z >> 2] = $uadd$0;
  HEAP32[$z + 4 >> 2] = $13;
  return;
}
function _main($argc, $argv) {
  $argc = $argc | 0;
  $argv = $argv | 0;
  var $library = 0, $face = 0, $matrix = 0, $pen = 0, $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $x_032 = 0, $30 = 0, $31 = 0, $y_029 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0.0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $n_028 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $103 = 0, $exitcond = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 32 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $library = __stackBase__ | 0;
    $face = __stackBase__ + 4 | 0;
    $matrix = __stackBase__ + 8 | 0;
    $pen = __stackBase__ + 24 | 0;
    $1 = ($argc | 0) == 6;
    if ($1) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = HEAP32[_stderr >> 2] | 0;
    $4 = HEAP32[$argv >> 2] | 0;
    $5 = _fprintf($3 | 0, 5324896, (tempInt = STACKTOP, STACKTOP = STACKTOP + 4 | 0, HEAP32[tempInt >> 2] = $4, tempInt) | 0) | 0;
    _exit(1);
    return 0;
   case 3:
    $7 = $argv + 4 | 0;
    $8 = $argv + 8 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = _strlen($9 | 0) | 0;
    $11 = $argv + 12 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = _atoi($12 | 0) | 0;
    HEAP32[1331693] = $13;
    $14 = $argv + 16 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = _atoi($15 | 0) | 0;
    HEAP32[1331775] = $16;
    $17 = $argv + 20 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = _atoi($18 | 0) | 0;
    $20 = +($19 | 0);
    $21 = $20 / 360.0;
    $22 = $21;
    $23 = $22 * 3.14159;
    $24 = $23 * 2.0;
    $25 = HEAP32[1331693] | 0;
    $26 = Math_imul($25, $16);
    $27 = _malloc($26) | 0;
    HEAP32[1312828] = $27;
    $28 = HEAP32[1331693] | 0;
    $29 = ($28 | 0) > 0;
    if ($29) {
      $x_032 = 0;
      label = 4;
      break;
    } else {
      label = 7;
      break;
    }
   case 4:
    $30 = HEAP32[1331775] | 0;
    $31 = ($30 | 0) > 0;
    if ($31) {
      $y_029 = 0;
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $32 = HEAP32[1331693] | 0;
    $33 = Math_imul($32, $y_029);
    $34 = $33 + $x_032 | 0;
    $35 = HEAP32[1312828] | 0;
    $36 = $35 + $34 | 0;
    HEAP8[$36] = 0;
    $37 = $y_029 + 1 | 0;
    $38 = HEAP32[1331775] | 0;
    $39 = ($37 | 0) < ($38 | 0);
    if ($39) {
      $y_029 = $37;
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $40 = $x_032 + 1 | 0;
    $41 = HEAP32[1331693] | 0;
    $42 = ($40 | 0) < ($41 | 0);
    if ($42) {
      $x_032 = $40;
      label = 4;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $43 = _FT_Init_FreeType($library) | 0;
    $44 = ($43 | 0) == 0;
    if ($44) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $46 = _printf(5323668, (tempInt = STACKTOP, STACKTOP = STACKTOP + 4 | 0, HEAP32[tempInt >> 2] = $43, tempInt) | 0) | 0;
    label = 9;
    break;
   case 9:
    $48 = HEAP32[$library >> 2] | 0;
    $49 = HEAP32[$7 >> 2] | 0;
    $50 = _FT_New_Face($48, $49, 0, $face) | 0;
    $51 = ($50 | 0) == 0;
    if ($51) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $53 = _printf(5322796, (tempInt = STACKTOP, STACKTOP = STACKTOP + 4 | 0, HEAP32[tempInt >> 2] = $50, tempInt) | 0) | 0;
    label = 11;
    break;
   case 11:
    $55 = HEAP32[$face >> 2] | 0;
    $56 = _FT_Set_Char_Size($55, 3200, 0, 100, 0) | 0;
    $57 = ($56 | 0) == 0;
    if ($57) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $59 = _printf(5322084, (tempInt = STACKTOP, STACKTOP = STACKTOP + 4 | 0, HEAP32[tempInt >> 2] = $56, tempInt) | 0) | 0;
    label = 13;
    break;
   case 13:
    $61 = HEAP32[$face >> 2] | 0;
    $62 = $61 + 84 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = +Math_cos(+$24);
    $65 = $64 * 65536.0;
    $66 = ~~$65;
    $67 = $matrix | 0;
    HEAP32[$67 >> 2] = $66;
    $68 = +Math_sin(+$24);
    $69 = $68 * -65536.0;
    $70 = ~~$69;
    $71 = $matrix + 4 | 0;
    HEAP32[$71 >> 2] = $70;
    $72 = $68 * 65536.0;
    $73 = ~~$72;
    $74 = $matrix + 8 | 0;
    HEAP32[$74 >> 2] = $73;
    $75 = $matrix + 12 | 0;
    HEAP32[$75 >> 2] = $66;
    $76 = $pen | 0;
    HEAP32[$76 >> 2] = 1e3;
    $77 = $pen + 4 | 0;
    HEAP32[$77 >> 2] = 0;
    $78 = ($10 | 0) > 0;
    if ($78) {
      label = 14;
      break;
    } else {
      label = 18;
      break;
    }
   case 14:
    $79 = $63 + 76 | 0;
    $80 = $63 + 100 | 0;
    $81 = $63 + 104 | 0;
    $82 = $63 + 64 | 0;
    $83 = $63 + 68 | 0;
    $n_028 = 0;
    label = 15;
    break;
   case 15:
    $85 = HEAP32[$face >> 2] | 0;
    _FT_Set_Transform($85, $matrix, $pen);
    $86 = HEAP32[$face >> 2] | 0;
    $87 = $9 + $n_028 | 0;
    $88 = HEAP8[$87] | 0;
    $89 = $88 << 24 >> 24;
    $90 = _FT_Load_Char($86, $89, 4) | 0;
    $91 = ($90 | 0) == 0;
    if ($91) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    $93 = HEAP32[$80 >> 2] | 0;
    $94 = HEAP32[$81 >> 2] | 0;
    $95 = $16 - $94 | 0;
    __Z11draw_bitmapP10FT_Bitmap_ii($79, $93, $95);
    $96 = HEAP32[$82 >> 2] | 0;
    $97 = HEAP32[$76 >> 2] | 0;
    $98 = $97 + $96 | 0;
    HEAP32[$76 >> 2] = $98;
    $99 = HEAP32[$83 >> 2] | 0;
    $100 = HEAP32[$77 >> 2] | 0;
    $101 = $100 + $99 | 0;
    HEAP32[$77 >> 2] = $101;
    label = 17;
    break;
   case 17:
    $103 = $n_028 + 1 | 0;
    $exitcond = ($103 | 0) == ($10 | 0);
    if ($exitcond) {
      label = 18;
      break;
    } else {
      $n_028 = $103;
      label = 15;
      break;
    }
   case 18:
    __Z10show_imagev();
    $104 = HEAP32[$face >> 2] | 0;
    $105 = _FT_Done_Face($104) | 0;
    $106 = HEAP32[$library >> 2] | 0;
    $107 = _FT_Done_FreeType($106) | 0;
    STACKTOP = __stackBase__;
    return 0;
  }
  return 0;
}
function _FT_MulFix($a, $b) {
  $a = $a | 0;
  $b = $b | 0;
  var $1 = 0, $2 = 0, $or_cond = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $or_cond22 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $ua_0 = 0, $30 = 0, $31 = 0, $32 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($a | 0) == 0;
    $2 = ($b | 0) == 65536;
    $or_cond = $1 | $2;
    if ($or_cond) {
      $_0 = $a;
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = ($a | 0) < 0;
    $5 = -$a | 0;
    $6 = $4 ? $5 : $a;
    $7 = $b ^ $a;
    $8 = ($b | 0) < 0;
    $9 = -$b | 0;
    $10 = $8 ? $9 : $b;
    $11 = $6 >>> 0 < 2049;
    $12 = $10 >>> 0 < 1048577;
    $or_cond22 = $11 & $12;
    if ($or_cond22) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $14 = Math_imul($10, $6);
    $15 = $14 + 32768 | 0;
    $16 = $15 >>> 16;
    $ua_0 = $16;
    label = 5;
    break;
   case 4:
    $18 = $6 & 65535;
    $19 = $6 >>> 16;
    $20 = Math_imul($19, $10);
    $21 = $10 >>> 16;
    $22 = Math_imul($21, $18);
    $23 = $22 + $20 | 0;
    $24 = $10 & 65535;
    $25 = Math_imul($24, $18);
    $26 = $25 + 32768 | 0;
    $27 = $26 >>> 16;
    $28 = $23 + $27 | 0;
    $ua_0 = $28;
    label = 5;
    break;
   case 5:
    $30 = ($7 | 0) < 0;
    $31 = -$ua_0 | 0;
    $32 = $30 ? $31 : $ua_0;
    $_0 = $32;
    label = 6;
    break;
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _FT_SqrtFixed($x) {
  $x = $x | 0;
  var $1 = 0, $rem_hi_0 = 0, $rem_lo_0 = 0, $root_0 = 0, $count_0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $rem_hi_1 = 0, $root_1 = 0, $14 = 0, $15 = 0, $root_2 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($x | 0) > 0;
    if ($1) {
      $count_0 = 24;
      $root_0 = 0;
      $rem_lo_0 = $x;
      $rem_hi_0 = 0;
      label = 2;
      break;
    } else {
      $root_2 = 0;
      label = 5;
      break;
    }
   case 2:
    $2 = $rem_hi_0 << 2;
    $3 = $rem_lo_0 >>> 30;
    $4 = $3 | $2;
    $5 = $rem_lo_0 << 2;
    $6 = $root_0 << 1;
    $7 = $root_0 << 2;
    $8 = $7 | 1;
    $9 = $4 >>> 0 < $8 >>> 0;
    if ($9) {
      $root_1 = $6;
      $rem_hi_1 = $4;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = $4 - $8 | 0;
    $12 = $6 | 1;
    $root_1 = $12;
    $rem_hi_1 = $11;
    label = 4;
    break;
   case 4:
    $14 = $count_0 - 1 | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      $root_2 = $root_1;
      label = 5;
      break;
    } else {
      $count_0 = $14;
      $root_0 = $root_1;
      $rem_lo_0 = $5;
      $rem_hi_0 = $rem_hi_1;
      label = 2;
      break;
    }
   case 5:
    return $root_2 | 0;
  }
  return 0;
}
function _ft_corner_is_flat($in_x, $in_y, $out_x, $out_y) {
  $in_x = $in_x | 0;
  $in_y = $in_y | 0;
  $out_x = $out_x | 0;
  $out_y = $out_y | 0;
  var $9 = 0, $12 = 0, $15 = 0;
  $9 = $out_x + $in_x | 0;
  $12 = $out_y + $in_y | 0;
  $15 = (($12 | 0) < 0 ? -$12 | 0 : $12) + (($9 | 0) < 0 ? -$9 | 0 : $9) | 0;
  return (((((($in_y | 0) < 0 ? -$in_y | 0 : $in_y) + (($in_x | 0) < 0 ? -$in_x | 0 : $in_x) | 0) + (($out_x | 0) < 0 ? -$out_x | 0 : $out_x) | 0) + (($out_y | 0) < 0 ? -$out_y | 0 : $out_y) | 0) - $15 | 0) < ($15 >> 4 | 0) & 1 | 0;
}
function _FT_GlyphLoader_Adjust_Points($loader) {
  $loader = $loader | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $loader + 24 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $loader + 22 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 << 16 >> 16;
    $6 = $2 + ($5 << 3) | 0;
    $7 = $loader + 60 | 0;
    HEAP32[$7 >> 2] = $6;
    $8 = $loader + 28 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = HEAP16[$3 >> 1] | 0;
    $11 = $10 << 16 >> 16;
    $12 = $9 + $11 | 0;
    $13 = $loader + 64 | 0;
    HEAP32[$13 >> 2] = $12;
    $14 = $loader + 32 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $loader + 20 | 0;
    $17 = HEAP16[$16 >> 1] | 0;
    $18 = $17 << 16 >> 16;
    $19 = $15 + ($18 << 1) | 0;
    $20 = $loader + 68 | 0;
    HEAP32[$20 >> 2] = $19;
    $21 = $loader + 16 | 0;
    $22 = HEAP8[$21] | 0;
    $23 = $22 << 24 >> 24 == 0;
    if ($23) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $25 = $loader + 40 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = HEAP16[$3 >> 1] | 0;
    $28 = $27 << 16 >> 16;
    $29 = $26 + ($28 << 3) | 0;
    $30 = $loader + 76 | 0;
    HEAP32[$30 >> 2] = $29;
    $31 = $loader + 44 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = HEAP16[$3 >> 1] | 0;
    $34 = $33 << 16 >> 16;
    $35 = $32 + ($34 << 3) | 0;
    $36 = $loader + 80 | 0;
    HEAP32[$36 >> 2] = $35;
    label = 3;
    break;
   case 3:
    return;
  }
}
function _FT_GlyphLoader_Adjust_Subglyphs($loader) {
  $loader = $loader | 0;
  HEAP32[$loader + 88 >> 2] = (HEAP32[$loader + 52 >> 2] | 0) + (HEAP32[$loader + 48 >> 2] << 5) | 0;
  return;
}
function _ft_validator_init($valid, $base, $limit, $level) {
  $valid = $valid | 0;
  $base = $base | 0;
  $limit = $limit | 0;
  $level = $level | 0;
  HEAP32[$valid >> 2] = $base;
  HEAP32[$valid + 4 >> 2] = $limit;
  HEAP32[$valid + 8 >> 2] = $level;
  HEAP32[$valid + 12 >> 2] = 0;
  return;
}
function _FT_MulDiv_No_Round($a, $b, $c) {
  $a = $a | 0;
  $b = $b | 0;
  $c = $c | 0;
  var $temp = 0, $1 = 0, $2 = 0, $or_cond = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $or_cond28 = 0, $17 = 0, $or_cond29 = 0, $19 = 0, $20 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $_0 = 0, $29 = 0, $30 = 0, $31 = 0, $_027 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $temp = __stackBase__ | 0;
    $1 = ($a | 0) == 0;
    $2 = ($b | 0) == ($c | 0);
    $or_cond = $1 | $2;
    if ($or_cond) {
      $_027 = $a;
      label = 7;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = ($a | 0) < 0;
    $5 = -$a | 0;
    $6 = $4 ? $5 : $a;
    $7 = $b ^ $a;
    $8 = ($b | 0) < 0;
    $9 = -$b | 0;
    $10 = $8 ? $9 : $b;
    $11 = $7 ^ $c;
    $12 = ($c | 0) < 0;
    $13 = -$c | 0;
    $14 = $12 ? $13 : $c;
    $15 = ($6 | 0) < 46341;
    $16 = ($10 | 0) < 46341;
    $or_cond28 = $15 & $16;
    $17 = ($14 | 0) > 0;
    $or_cond29 = $or_cond28 & $17;
    if ($or_cond29) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $19 = Math_imul($10, $6);
    $20 = ($19 | 0) / ($14 | 0) & -1;
    $_0 = $20;
    label = 6;
    break;
   case 4:
    if ($17) {
      label = 5;
      break;
    } else {
      $_0 = 2147483647;
      label = 6;
      break;
    }
   case 5:
    _ft_multo64($6, $10, $temp);
    $23 = $temp + 4 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $temp | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = _ft_div64by32($24, $26, $14) | 0;
    $_0 = $27;
    label = 6;
    break;
   case 6:
    $29 = ($11 | 0) < 0;
    $30 = -$_0 | 0;
    $31 = $29 ? $30 : $_0;
    $_027 = $31;
    label = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return $_027 | 0;
  }
  return 0;
}
function _FT_DivFix($a, $b) {
  $a = $a | 0;
  $b = $b | 0;
  var $temp = 0, $temp2 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $q_0 = 0, $28 = 0, $29 = 0, $30 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $temp = __stackBase__ | 0;
    $temp2 = __stackBase__ + 8 | 0;
    $1 = ($a | 0) < 0;
    $2 = -$a | 0;
    $3 = $1 ? $2 : $a;
    $4 = $b ^ $a;
    $5 = ($b | 0) < 0;
    $6 = -$b | 0;
    $7 = $5 ? $6 : $b;
    $8 = ($7 | 0) == 0;
    if ($8) {
      $q_0 = 2147483647;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = $3 >> 16;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $13 = $3 << 16;
    $14 = $7 >> 1;
    $15 = $14 + $13 | 0;
    $16 = ($15 >>> 0) / ($7 >>> 0) >>> 0;
    $q_0 = $16;
    label = 5;
    break;
   case 4:
    $18 = $temp + 4 | 0;
    HEAP32[$18 >> 2] = $10;
    $19 = $3 << 16;
    $20 = $temp | 0;
    HEAP32[$20 >> 2] = $19;
    $21 = $temp2 + 4 | 0;
    HEAP32[$21 >> 2] = 0;
    $22 = $7 >> 1;
    $23 = $temp2 | 0;
    HEAP32[$23 >> 2] = $22;
    _FT_Add64($temp, $temp2, $temp);
    $24 = HEAP32[$18 >> 2] | 0;
    $25 = HEAP32[$20 >> 2] | 0;
    $26 = _ft_div64by32($24, $25, $7) | 0;
    $q_0 = $26;
    label = 5;
    break;
   case 5:
    $28 = ($4 | 0) < 0;
    $29 = -$q_0 | 0;
    $30 = $28 ? $29 : $q_0;
    STACKTOP = __stackBase__;
    return $30 | 0;
  }
  return 0;
}
function _FT_Matrix_Invert($matrix) {
  $matrix = $matrix | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($matrix | 0) == 0;
    if ($1) {
      $_0 = 6;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $matrix | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $matrix + 12 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = _FT_MulFix($4, $6) | 0;
    $8 = $matrix + 4 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $matrix + 8 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = _FT_MulFix($9, $11) | 0;
    $13 = $7 - $12 | 0;
    $14 = ($7 | 0) == ($12 | 0);
    if ($14) {
      $_0 = 6;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $16 = _FT_DivFix($9, $13) | 0;
    $17 = -$16 | 0;
    HEAP32[$8 >> 2] = $17;
    $18 = HEAP32[$10 >> 2] | 0;
    $19 = _FT_DivFix($18, $13) | 0;
    $20 = -$19 | 0;
    HEAP32[$10 >> 2] = $20;
    $21 = HEAP32[$3 >> 2] | 0;
    $22 = HEAP32[$5 >> 2] | 0;
    $23 = _FT_DivFix($22, $13) | 0;
    HEAP32[$3 >> 2] = $23;
    $24 = _FT_DivFix($21, $13) | 0;
    HEAP32[$5 >> 2] = $24;
    $_0 = 0;
    label = 4;
    break;
   case 4:
    return $_0 | 0;
  }
  return 0;
}
function _FT_Matrix_Multiply_Scaled($a, $b, $scaling) {
  $a = $a | 0;
  $b = $b | 0;
  $scaling = $scaling | 0;
  var $1 = 0, $2 = 0, $3 = 0, $or_cond = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $scaling << 16;
    $2 = ($a | 0) == 0;
    $3 = ($b | 0) == 0;
    $or_cond = $2 | $3;
    if ($or_cond) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $a | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $b | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = _FT_MulDiv($6, $8, $1) | 0;
    $10 = $a + 4 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $b + 8 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = _FT_MulDiv($11, $13, $1) | 0;
    $15 = $14 + $9 | 0;
    $16 = HEAP32[$5 >> 2] | 0;
    $17 = $b + 4 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = _FT_MulDiv($16, $18, $1) | 0;
    $20 = HEAP32[$10 >> 2] | 0;
    $21 = $b + 12 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = _FT_MulDiv($20, $22, $1) | 0;
    $24 = $23 + $19 | 0;
    $25 = $a + 8 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = HEAP32[$7 >> 2] | 0;
    $28 = _FT_MulDiv($26, $27, $1) | 0;
    $29 = $a + 12 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = HEAP32[$12 >> 2] | 0;
    $32 = _FT_MulDiv($30, $31, $1) | 0;
    $33 = $32 + $28 | 0;
    $34 = HEAP32[$25 >> 2] | 0;
    $35 = HEAP32[$17 >> 2] | 0;
    $36 = _FT_MulDiv($34, $35, $1) | 0;
    $37 = HEAP32[$29 >> 2] | 0;
    $38 = HEAP32[$21 >> 2] | 0;
    $39 = _FT_MulDiv($37, $38, $1) | 0;
    $40 = $39 + $36 | 0;
    HEAP32[$7 >> 2] = $15;
    HEAP32[$17 >> 2] = $24;
    HEAP32[$12 >> 2] = $33;
    HEAP32[$21 >> 2] = $40;
    label = 3;
    break;
   case 3:
    return;
  }
}
function _FT_Vector_Transform_Scaled($vector, $matrix, $scaling) {
  $vector = $vector | 0;
  $matrix = $matrix | 0;
  $scaling = $scaling | 0;
  var $1 = 0, $2 = 0, $3 = 0, $or_cond = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $scaling << 16;
    $2 = ($vector | 0) == 0;
    $3 = ($matrix | 0) == 0;
    $or_cond = $2 | $3;
    if ($or_cond) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $vector | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $matrix | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = _FT_MulDiv($6, $8, $1) | 0;
    $10 = $vector + 4 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $matrix + 4 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = _FT_MulDiv($11, $13, $1) | 0;
    $15 = $14 + $9 | 0;
    $16 = HEAP32[$5 >> 2] | 0;
    $17 = $matrix + 8 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = _FT_MulDiv($16, $18, $1) | 0;
    $20 = HEAP32[$10 >> 2] | 0;
    $21 = $matrix + 12 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = _FT_MulDiv($20, $22, $1) | 0;
    $24 = $23 + $19 | 0;
    HEAP32[$5 >> 2] = $15;
    HEAP32[$10 >> 2] = $24;
    label = 3;
    break;
   case 3:
    return;
  }
}
function _ft_corner_orientation($in_x, $in_y, $out_x, $out_y) {
  $in_x = $in_x | 0;
  $in_y = $in_y | 0;
  $out_x = $out_x | 0;
  $out_y = $out_y | 0;
  var $z1 = 0, $z2 = 0, $1 = 0, $3 = 0, $4 = 0, $out_y_ = 0, $6 = 0, $8 = 0, $9 = 0, $_out_x = 0, $11 = 0, $13 = 0, $14 = 0, $in_y_ = 0, $16 = 0, $18 = 0, $19 = 0, $_in_x = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $_ = 0, $result_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $z1 = __stackBase__ | 0;
    $z2 = __stackBase__ + 8 | 0;
    $1 = ($in_y | 0) == 0;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = ($in_x | 0) > -1;
    $4 = -$out_y | 0;
    $out_y_ = $3 ? $out_y : $4;
    STACKTOP = __stackBase__;
    return $out_y_ | 0;
   case 3:
    $6 = ($in_x | 0) == 0;
    if ($6) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $8 = ($in_y | 0) > -1;
    $9 = -$out_x | 0;
    $_out_x = $8 ? $9 : $out_x;
    $result_0 = $_out_x;
    label = 13;
    break;
   case 5:
    $11 = ($out_y | 0) == 0;
    if ($11) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $13 = ($out_x | 0) > -1;
    $14 = -$in_y | 0;
    $in_y_ = $13 ? $in_y : $14;
    $result_0 = $in_y_;
    label = 13;
    break;
   case 7:
    $16 = ($out_x | 0) == 0;
    if ($16) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $18 = ($out_y | 0) > -1;
    $19 = -$in_x | 0;
    $_in_x = $18 ? $19 : $in_x;
    $result_0 = $_in_x;
    label = 13;
    break;
   case 9:
    _ft_multo64($in_x, $out_y, $z1);
    _ft_multo64($in_y, $out_x, $z2);
    $21 = $z1 + 4 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $z2 + 4 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $22 >>> 0 > $24 >>> 0;
    if ($25) {
      $result_0 = 1;
      label = 13;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $27 = $22 >>> 0 < $24 >>> 0;
    if ($27) {
      $result_0 = -1;
      label = 13;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $29 = $z1 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $z2 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $30 >>> 0 > $32 >>> 0;
    if ($33) {
      $result_0 = 1;
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $35 = $30 >>> 0 < $32 >>> 0;
    $_ = $35 << 31 >> 31;
    $result_0 = $_;
    label = 13;
    break;
   case 13:
    STACKTOP = __stackBase__;
    return $result_0 | 0;
  }
  return 0;
}
function _FT_GlyphLoader_New($memory, $aloader) {
  $memory = $memory | 0;
  $aloader = $aloader | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = _ft_mem_alloc($memory, 96, $error) | 0;
    $2 = HEAP32[$error >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $5 = $1;
    $6 = $1;
    HEAP32[$6 >> 2] = $memory;
    HEAP32[$aloader >> 2] = $5;
    label = 3;
    break;
   case 3:
    $8 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $8 | 0;
  }
  return 0;
}
function _ft_mem_alloc($memory, $size, $p_error) {
  $memory = $memory | 0;
  $size = $size | 0;
  $p_error = $p_error | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $or_cond = 0, $7 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = _ft_mem_qalloc($memory, $size, $error) | 0;
    $2 = HEAP32[$error >> 2] | 0;
    $3 = ($2 | 0) == 0;
    $4 = ($size | 0) > 0;
    $or_cond = $3 & $4;
    if ($or_cond) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    _memset($1 | 0, 0, $size | 0);
    label = 3;
    break;
   case 3:
    $7 = HEAP32[$error >> 2] | 0;
    HEAP32[$p_error >> 2] = $7;
    STACKTOP = __stackBase__;
    return $1 | 0;
  }
  return 0;
}
function _FT_GlyphLoader_Rewind($loader) {
  $loader = $loader | 0;
  var $1 = 0;
  $1 = $loader + 20 | 0;
  HEAP16[$loader + 22 >> 1] = 0;
  HEAP16[$1 >> 1] = 0;
  HEAP32[$loader + 48 >> 2] = 0;
  _memcpy($loader + 56 | 0, $1 | 0, 36);
  return;
}
function _FT_GlyphLoader_Reset($loader) {
  $loader = $loader | 0;
  var $2 = 0, $3 = 0, $6 = 0, $8 = 0, $11 = 0, $14 = 0;
  $2 = HEAP32[$loader >> 2] | 0;
  $3 = $loader + 24 | 0;
  _ft_mem_free($2, HEAP32[$3 >> 2] | 0);
  HEAP32[$3 >> 2] = 0;
  $6 = $loader + 28 | 0;
  _ft_mem_free($2, HEAP32[$6 >> 2] | 0);
  HEAP32[$6 >> 2] = 0;
  $8 = $loader + 32 | 0;
  _ft_mem_free($2, HEAP32[$8 >> 2] | 0);
  HEAP32[$8 >> 2] = 0;
  $11 = $loader + 40 | 0;
  _ft_mem_free($2, HEAP32[$11 >> 2] | 0);
  HEAP32[$11 >> 2] = 0;
  $14 = $loader + 52 | 0;
  _ft_mem_free($2, HEAP32[$14 >> 2] | 0);
  HEAP32[$14 >> 2] = 0;
  HEAP32[$loader + 44 >> 2] = 0;
  HEAP32[$loader + 4 >> 2] = 0;
  HEAP32[$loader + 8 >> 2] = 0;
  HEAP32[$loader + 12 >> 2] = 0;
  _FT_GlyphLoader_Rewind($loader);
  return;
}
function _ft_mem_free($memory, $P) {
  $memory = $memory | 0;
  $P = $P | 0;
  var $1 = 0, $3 = 0, $4 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($P | 0) == 0;
    if ($1) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $memory + 8 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    FUNCTION_TABLE_vii[$4 & 1023]($memory, $P);
    label = 3;
    break;
   case 3:
    return;
  }
}
function _FT_GlyphLoader_Done($loader) {
  $loader = $loader | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($loader | 0) == 0;
    if ($1) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $loader | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    _FT_GlyphLoader_Reset($loader);
    $5 = $loader;
    _ft_mem_free($4, $5);
    label = 3;
    break;
   case 3:
    return;
  }
}
function _FT_GlyphLoader_CreateExtra($loader) {
  $loader = $loader | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $loader | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $loader + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 << 1;
    $6 = _ft_mem_realloc($2, 8, 0, $5, 0, $error) | 0;
    $7 = $6;
    $8 = $loader + 40 | 0;
    HEAP32[$8 >> 2] = $7;
    $9 = HEAP32[$error >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $12 = $loader + 16 | 0;
    HEAP8[$12] = 1;
    $13 = HEAP32[$8 >> 2] | 0;
    $14 = HEAP32[$3 >> 2] | 0;
    $15 = $13 + ($14 << 3) | 0;
    $16 = $loader + 44 | 0;
    HEAP32[$16 >> 2] = $15;
    _FT_GlyphLoader_Adjust_Points($loader);
    label = 3;
    break;
   case 3:
    $18 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $18 | 0;
  }
  return 0;
}
function _ft_mem_realloc($memory, $item_size, $cur_count, $new_count, $block, $p_error) {
  $memory = $memory | 0;
  $item_size = $item_size | 0;
  $cur_count = $cur_count | 0;
  $new_count = $new_count | 0;
  $block = $block | 0;
  $p_error = $p_error | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $or_cond = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = _ft_mem_qrealloc($memory, $item_size, $cur_count, $new_count, $block, $error) | 0;
    $2 = HEAP32[$error >> 2] | 0;
    $3 = ($2 | 0) == 0;
    $4 = ($new_count | 0) > ($cur_count | 0);
    $or_cond = $3 & $4;
    if ($or_cond) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $6 = Math_imul($cur_count, $item_size);
    $7 = $1 + $6 | 0;
    $8 = $new_count - $cur_count | 0;
    $9 = Math_imul($8, $item_size);
    _memset($7 | 0, 0, $9 | 0);
    label = 3;
    break;
   case 3:
    $11 = HEAP32[$error >> 2] | 0;
    HEAP32[$p_error >> 2] = $11;
    STACKTOP = __stackBase__;
    return $1 | 0;
  }
  return 0;
}
function _FT_GlyphLoader_CheckPoints($loader, $n_points, $n_contours) {
  $loader = $loader | 0;
  $n_points = $n_points | 0;
  $n_contours = $n_contours | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $adjust_0 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $71 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $81 = 0, $84 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $loader | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $3 = $loader + 22 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 << 16 >> 16;
    $6 = $loader + 58 | 0;
    $7 = HEAP16[$6 >> 1] | 0;
    $8 = $7 << 16 >> 16;
    $9 = $5 + $n_points | 0;
    $10 = $9 + $8 | 0;
    $11 = $loader + 4 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $10 >>> 0 > $12 >>> 0;
    if ($13) {
      label = 2;
      break;
    } else {
      $adjust_0 = 0;
      label = 9;
      break;
    }
   case 2:
    $15 = $10 + 7 | 0;
    $16 = $15 & -8;
    $17 = $16 >>> 0 > 32767;
    if ($17) {
      $_0 = 10;
      label = 16;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $19 = $loader + 24 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $20;
    $22 = _ft_mem_realloc($2, 8, $12, $16, $21, $error) | 0;
    $23 = $22;
    HEAP32[$19 >> 2] = $23;
    $24 = HEAP32[$error >> 2] | 0;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 4;
      break;
    } else {
      label = 15;
      break;
    }
   case 4:
    $27 = $loader + 28 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = _ft_mem_realloc($2, 1, $12, $16, $28, $error) | 0;
    HEAP32[$27 >> 2] = $29;
    $30 = HEAP32[$error >> 2] | 0;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 5;
      break;
    } else {
      label = 15;
      break;
    }
   case 5:
    $33 = $loader + 16 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 << 24 >> 24 == 0;
    if ($35) {
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $37 = $12 << 1;
    $38 = $16 << 1;
    $39 = $loader + 40 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $40;
    $42 = _ft_mem_realloc($2, 8, $37, $38, $41, $error) | 0;
    $43 = $42;
    HEAP32[$39 >> 2] = $43;
    $44 = HEAP32[$error >> 2] | 0;
    $45 = ($44 | 0) == 0;
    if ($45) {
      label = 7;
      break;
    } else {
      label = 15;
      break;
    }
   case 7:
    $47 = $43 + ($16 << 3) | 0;
    $48 = $47;
    $49 = $43 + ($12 << 3) | 0;
    $50 = $49;
    $51 = $12 << 3;
    _memmove($48 | 0, $50 | 0, $51 | 0);
    $52 = HEAP32[$39 >> 2] | 0;
    $53 = $52 + ($16 << 3) | 0;
    $54 = $loader + 44 | 0;
    HEAP32[$54 >> 2] = $53;
    label = 8;
    break;
   case 8:
    HEAP32[$11 >> 2] = $16;
    $adjust_0 = 1;
    label = 9;
    break;
   case 9:
    $57 = $loader + 8 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = $loader + 20 | 0;
    $60 = HEAP16[$59 >> 1] | 0;
    $61 = $60 << 16 >> 16;
    $62 = $loader + 56 | 0;
    $63 = HEAP16[$62 >> 1] | 0;
    $64 = $63 << 16 >> 16;
    $65 = $61 + $n_contours | 0;
    $66 = $65 + $64 | 0;
    $67 = $66 >>> 0 > $58 >>> 0;
    if ($67) {
      label = 10;
      break;
    } else {
      label = 13;
      break;
    }
   case 10:
    $69 = $66 + 3 | 0;
    $70 = $69 & -4;
    $71 = $70 >>> 0 > 32767;
    if ($71) {
      $_0 = 10;
      label = 16;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $73 = $loader + 32 | 0;
    $74 = HEAP32[$73 >> 2] | 0;
    $75 = $74;
    $76 = _ft_mem_realloc($2, 2, $58, $70, $75, $error) | 0;
    $77 = $76;
    HEAP32[$73 >> 2] = $77;
    $78 = HEAP32[$error >> 2] | 0;
    $79 = ($78 | 0) == 0;
    if ($79) {
      label = 12;
      break;
    } else {
      label = 15;
      break;
    }
   case 12:
    HEAP32[$57 >> 2] = $70;
    label = 14;
    break;
   case 13:
    $81 = $adjust_0 << 24 >> 24 == 0;
    if ($81) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    _FT_GlyphLoader_Adjust_Points($loader);
    label = 15;
    break;
   case 15:
    $84 = HEAP32[$error >> 2] | 0;
    $_0 = $84;
    label = 16;
    break;
   case 16:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_GlyphLoader_CheckSubGlyphs($loader, $n_subs) {
  $loader = $loader | 0;
  $n_subs = $n_subs | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $24 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $loader | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $3 = $loader + 48 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $loader + 84 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $4 + $n_subs | 0;
    $8 = $7 + $6 | 0;
    $9 = $loader + 12 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $8 >>> 0 > $10 >>> 0;
    if ($11) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $13 = $8 + 1 | 0;
    $14 = $13 & -2;
    $15 = $loader + 52 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $16;
    $18 = _ft_mem_realloc($2, 32, $10, $14, $17, $error) | 0;
    $19 = $18;
    HEAP32[$15 >> 2] = $19;
    $20 = HEAP32[$error >> 2] | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    HEAP32[$9 >> 2] = $14;
    _FT_GlyphLoader_Adjust_Subglyphs($loader);
    label = 4;
    break;
   case 4:
    $24 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $24 | 0;
  }
  return 0;
}
function _FT_GlyphLoader_Prepare($loader) {
  $loader = $loader | 0;
  HEAP16[$loader + 58 >> 1] = 0;
  HEAP16[$loader + 56 >> 1] = 0;
  HEAP32[$loader + 84 >> 2] = 0;
  _FT_GlyphLoader_Adjust_Points($loader);
  _FT_GlyphLoader_Adjust_Subglyphs($loader);
  return;
}
function _FT_GlyphLoader_Add($loader) {
  $loader = $loader | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $n_017 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($loader | 0) == 0;
    if ($1) {
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $loader + 56 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 << 16 >> 16;
    $6 = $loader + 22 | 0;
    $7 = HEAP16[$6 >> 1] | 0;
    $8 = $loader + 58 | 0;
    $9 = HEAP16[$8 >> 1] | 0;
    $10 = $9 + $7 & 65535;
    HEAP16[$6 >> 1] = $10;
    $11 = $loader + 20 | 0;
    $12 = HEAP16[$11 >> 1] | 0;
    $13 = HEAP16[$3 >> 1] | 0;
    $14 = $13 + $12 & 65535;
    HEAP16[$11 >> 1] = $14;
    $15 = $loader + 84 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $loader + 48 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $18 + $16 | 0;
    HEAP32[$17 >> 2] = $19;
    $20 = $4 << 16 >> 16 == 0;
    if ($20) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $21 = $loader + 68 | 0;
    $n_017 = 0;
    label = 4;
    break;
   case 4:
    $23 = HEAP32[$21 >> 2] | 0;
    $24 = $23 + ($n_017 << 1) | 0;
    $25 = HEAP16[$24 >> 1] | 0;
    $26 = $25 + $7 & 65535;
    HEAP16[$24 >> 1] = $26;
    $27 = $n_017 + 1 | 0;
    $28 = $27 >>> 0 < $5 >>> 0;
    if ($28) {
      $n_017 = $27;
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    _FT_GlyphLoader_Prepare($loader);
    label = 6;
    break;
   case 6:
    return;
  }
}
function _FT_GlyphLoader_CopyPoints($target, $source) {
  $target = $target | 0;
  $source = $source | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $source + 22 | 0;
    $2 = HEAP16[$1 >> 1] | 0;
    $3 = $2 << 16 >> 16;
    $4 = $source + 20 | 0;
    $5 = HEAP16[$4 >> 1] | 0;
    $6 = $5 << 16 >> 16;
    $7 = _FT_GlyphLoader_CheckPoints($target, $3, $6) | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $10 = $target + 24 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11;
    $13 = $source + 24 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14;
    $16 = $3 << 3;
    _memcpy($12 | 0, $15 | 0, $16 | 0);
    $17 = $target + 28 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $source + 28 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    _memcpy($18 | 0, $20 | 0, $3 | 0);
    $21 = $target + 32 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22;
    $24 = $source + 32 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $25;
    $27 = $6 << 1;
    _memcpy($23 | 0, $26 | 0, $27 | 0);
    $28 = $target + 16 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $29 << 24 >> 24 == 0;
    if ($30) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $32 = $source + 16 | 0;
    $33 = HEAP8[$32] | 0;
    $34 = $33 << 24 >> 24 == 0;
    if ($34) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $36 = $target + 40 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $37;
    $39 = $source + 40 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $40;
    _memcpy($38 | 0, $41 | 0, $16 | 0);
    $42 = $target + 44 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $43;
    $45 = $source + 44 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $46;
    _memcpy($44 | 0, $47 | 0, $16 | 0);
    label = 5;
    break;
   case 5:
    $49 = $target + 22 | 0;
    HEAP16[$49 >> 1] = $2;
    $50 = $target + 20 | 0;
    HEAP16[$50 >> 1] = $5;
    _FT_GlyphLoader_Adjust_Points($target);
    label = 6;
    break;
   case 6:
    return $7 | 0;
  }
  return 0;
}
function _ft_service_list_lookup($service_descriptors, $service_id) {
  $service_descriptors = $service_descriptors | 0;
  $service_id = $service_id | 0;
  var $1 = 0, $2 = 0, $or_cond = 0, $desc_0 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($service_descriptors | 0) == 0;
    $2 = ($service_id | 0) == 0;
    $or_cond = $1 | $2;
    if ($or_cond) {
      $result_0 = 0;
      label = 5;
      break;
    } else {
      $desc_0 = $service_descriptors;
      label = 2;
      break;
    }
   case 2:
    $3 = $desc_0 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $result_0 = 0;
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = _strcmp($4 | 0, $service_id | 0) | 0;
    $8 = ($7 | 0) == 0;
    $9 = $desc_0 + 8 | 0;
    if ($8) {
      label = 4;
      break;
    } else {
      $desc_0 = $9;
      label = 2;
      break;
    }
   case 4:
    $11 = $desc_0 + 4 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $result_0 = $12;
    label = 5;
    break;
   case 5:
    return $result_0 | 0;
  }
  return 0;
}
function _ft_validator_error($valid, $error) {
  $valid = $valid | 0;
  $error = $error | 0;
  HEAP32[$valid + 12 >> 2] = $error;
  _longjmp($valid + 16 | 0, 1);
}
function _FT_Stream_OpenMemory($stream, $base, $size) {
  $stream = $stream | 0;
  $base = $base | 0;
  $size = $size | 0;
  HEAP32[$stream >> 2] = $base;
  HEAP32[$stream + 4 >> 2] = $size;
  HEAP32[$stream + 8 >> 2] = 0;
  HEAP32[$stream + 32 >> 2] = 0;
  HEAP32[$stream + 20 >> 2] = 0;
  HEAP32[$stream + 24 >> 2] = 0;
  return;
}
function _FT_Outline_Check($outline) {
  $outline = $outline | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $or_cond15 = 0, $14 = 0, $end0_0 = 0, $n_0 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $or_cond16 = 0, $24 = 0, $26 = 0, $27 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($outline | 0) == 0;
    if ($1) {
      label = 8;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $outline + 2 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 << 16 >> 16;
    $6 = $outline | 0;
    $7 = HEAP16[$6 >> 1] | 0;
    $8 = $7 << 16 >> 16;
    $9 = $7 | $4;
    $10 = $9 << 16 >> 16 == 0;
    if ($10) {
      $_0 = 0;
      label = 9;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = $4 << 16 >> 16 < 1;
    $13 = $7 << 16 >> 16 < 1;
    $or_cond15 = $12 | $13;
    if ($or_cond15) {
      label = 8;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $14 = $outline + 12 | 0;
    $n_0 = 0;
    $end0_0 = -1;
    label = 5;
    break;
   case 5:
    $16 = ($n_0 | 0) < ($8 | 0);
    if ($16) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $18 = HEAP32[$14 >> 2] | 0;
    $19 = $18 + ($n_0 << 1) | 0;
    $20 = HEAP16[$19 >> 1] | 0;
    $21 = $20 << 16 >> 16;
    $22 = ($21 | 0) > ($end0_0 | 0);
    $23 = $20 << 16 >> 16 < $4 << 16 >> 16;
    $or_cond16 = $22 & $23;
    $24 = $n_0 + 1 | 0;
    if ($or_cond16) {
      $n_0 = $24;
      $end0_0 = $21;
      label = 5;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $26 = $5 - 1 | 0;
    $27 = ($end0_0 | 0) == ($26 | 0);
    if ($27) {
      $_0 = 0;
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $_0 = 6;
    label = 9;
    break;
   case 9:
    return $_0 | 0;
  }
  return 0;
}
function _ft_glyphslot_grid_fit_metrics($slot, $vertical) {
  $slot = $slot | 0;
  $vertical = $vertical | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $slot + 24 | 0;
    $2 = $vertical << 24 >> 24 == 0;
    if ($2) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $slot + 32 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 & -64;
    HEAP32[$4 >> 2] = $6;
    $7 = $slot + 36 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 + 63 | 0;
    $10 = $9 & -64;
    HEAP32[$7 >> 2] = $10;
    $11 = $slot + 44 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $1 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $12 + 63 | 0;
    $16 = $15 + $14 | 0;
    $17 = $16 & -64;
    $18 = $slot + 48 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $slot + 28 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $19 + 63 | 0;
    $23 = $22 + $21 | 0;
    $24 = $23 & -64;
    $25 = $12 & -64;
    HEAP32[$11 >> 2] = $25;
    $26 = HEAP32[$18 >> 2] | 0;
    $27 = $26 & -64;
    HEAP32[$18 >> 2] = $27;
    $28 = HEAP32[$11 >> 2] | 0;
    $29 = $17 - $28 | 0;
    HEAP32[$13 >> 2] = $29;
    $30 = HEAP32[$18 >> 2] | 0;
    $31 = $24 - $30 | 0;
    HEAP32[$20 >> 2] = $31;
    label = 4;
    break;
   case 3:
    $33 = $slot + 44 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $34 & -64;
    HEAP32[$33 >> 2] = $35;
    $36 = $slot + 48 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $37 & -64;
    HEAP32[$36 >> 2] = $38;
    $39 = $slot + 32 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $1 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = $40 + 63 | 0;
    $44 = $43 + $42 | 0;
    $45 = $44 & -64;
    $46 = $slot + 36 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $slot + 28 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = $47 - $49 | 0;
    $51 = $50 & -64;
    $52 = $40 & -64;
    HEAP32[$39 >> 2] = $52;
    $53 = HEAP32[$46 >> 2] | 0;
    $54 = $53 + 63 | 0;
    $55 = $54 & -64;
    HEAP32[$46 >> 2] = $55;
    $56 = HEAP32[$39 >> 2] | 0;
    $57 = $45 - $56 | 0;
    HEAP32[$41 >> 2] = $57;
    $58 = HEAP32[$46 >> 2] | 0;
    $59 = $58 - $51 | 0;
    HEAP32[$48 >> 2] = $59;
    label = 4;
    break;
   case 4:
    $61 = $slot + 40 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = $62 + 32 | 0;
    $64 = $63 & -64;
    HEAP32[$61 >> 2] = $64;
    $65 = $slot + 52 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = $66 + 32 | 0;
    $68 = $67 & -64;
    HEAP32[$65 >> 2] = $68;
    return;
  }
}
function _FT_Outline_Translate($outline, $xOffset, $yOffset) {
  $outline = $outline | 0;
  $xOffset = $xOffset | 0;
  $yOffset = $yOffset | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vec_09 = 0, $n_08 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($outline | 0) == 0;
    if ($1) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $outline + 2 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 << 16 >> 16 > 0;
    if ($5) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $6 = $outline + 4 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $n_08 = 0;
    $vec_09 = $7;
    label = 4;
    break;
   case 4:
    $9 = $vec_09 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10 + $xOffset | 0;
    HEAP32[$9 >> 2] = $11;
    $12 = $vec_09 + 4 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 + $yOffset | 0;
    HEAP32[$12 >> 2] = $14;
    $15 = $vec_09 + 8 | 0;
    $16 = $n_08 + 1 & 65535;
    $17 = $16 & 65535;
    $18 = HEAP16[$3 >> 1] | 0;
    $19 = $18 << 16 >> 16;
    $20 = ($17 | 0) < ($19 | 0);
    if ($20) {
      $n_08 = $16;
      $vec_09 = $15;
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    return;
  }
}
function _FT_Stream_New($library, $args, $astream) {
  $library = $library | 0;
  $args = $args | 0;
  $astream = $astream | 0;
  var $error = 0, $1 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $stream_0_ph = 0, $_pr = 0, $43 = 0, $stream_024 = 0, $45 = 0, $47 = 0, $stream_1 = 0, $50 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$astream >> 2] = 0;
    $1 = ($library | 0) == 0;
    if ($1) {
      $_0 = 33;
      label = 17;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = ($args | 0) == 0;
    if ($3) {
      $_0 = 6;
      label = 17;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $5 = $library | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = _ft_mem_alloc($6, 40, $error) | 0;
    $8 = $7;
    $9 = HEAP32[$error >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 16;
      break;
    }
   case 4:
    $12 = $7 + 28 | 0;
    $13 = $12;
    HEAP32[$13 >> 2] = $6;
    $14 = $args | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15 & 1;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $19 = $args + 4 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $args + 8 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    _FT_Stream_OpenMemory($8, $20, $22);
    $stream_0_ph = $8;
    label = 12;
    break;
   case 6:
    $24 = $15 & 4;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $27 = $args + 12 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = _FT_Stream_Open($8, $28) | 0;
    HEAP32[$error >> 2] = $29;
    $30 = HEAP32[$27 >> 2] | 0;
    $31 = $7 + 16 | 0;
    $32 = $31;
    HEAP32[$32 >> 2] = $30;
    $stream_0_ph = $8;
    label = 12;
    break;
   case 8:
    $34 = $15 & 2;
    $35 = ($34 | 0) == 0;
    if ($35) {
      label = 11;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $37 = $args + 16 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = ($38 | 0) == 0;
    if ($39) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    _ft_mem_free($6, $7);
    $41 = HEAP32[$37 >> 2] | 0;
    $stream_0_ph = $41;
    label = 12;
    break;
   case 11:
    HEAP32[$error >> 2] = 6;
    $stream_024 = $8;
    label = 13;
    break;
   case 12:
    $_pr = HEAP32[$error >> 2] | 0;
    $43 = ($_pr | 0) == 0;
    if ($43) {
      label = 14;
      break;
    } else {
      $stream_024 = $stream_0_ph;
      label = 13;
      break;
    }
   case 13:
    $45 = $stream_024;
    _ft_mem_free($6, $45);
    $stream_1 = 0;
    label = 15;
    break;
   case 14:
    $47 = $stream_0_ph + 28 | 0;
    HEAP32[$47 >> 2] = $6;
    $stream_1 = $stream_0_ph;
    label = 15;
    break;
   case 15:
    HEAP32[$astream >> 2] = $stream_1;
    label = 16;
    break;
   case 16:
    $50 = HEAP32[$error >> 2] | 0;
    $_0 = $50;
    label = 17;
    break;
   case 17:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_Stream_Free($stream, $external) {
  $stream = $stream | 0;
  $external = $external | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($stream | 0) == 0;
    if ($1) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $stream + 28 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    _FT_Stream_Close($stream);
    $5 = ($external | 0) == 0;
    if ($5) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $7 = $stream;
    _ft_mem_free($4, $7);
    label = 4;
    break;
   case 4:
    return;
  }
}
function _FT_Stream_Close($stream) {
  $stream = $stream | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($stream | 0) == 0;
    if ($1) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $stream + 24 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    FUNCTION_TABLE_vi[$4 & 1023]($stream);
    label = 4;
    break;
   case 4:
    return;
  }
}
function _ft_glyphslot_free_bitmap($slot) {
  $slot = $slot | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $slot + 156 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 + 4 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 & 1;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $10 = $slot + 4 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 + 100 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $slot + 88 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    _ft_mem_free($13, $15);
    HEAP32[$14 >> 2] = 0;
    $16 = HEAP32[$1 >> 2] | 0;
    $17 = $16 + 4 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $18 & -2;
    HEAP32[$17 >> 2] = $19;
    label = 5;
    break;
   case 4:
    $21 = $slot + 88 | 0;
    HEAP32[$21 >> 2] = 0;
    label = 5;
    break;
   case 5:
    return;
  }
}
function _ft_glyphslot_set_bitmap($slot, $buffer) {
  $slot = $slot | 0;
  $buffer = $buffer | 0;
  _ft_glyphslot_free_bitmap($slot);
  HEAP32[$slot + 88 >> 2] = $buffer;
  return;
}
function _ft_glyphslot_alloc_bitmap($slot, $size) {
  $slot = $slot | 0;
  $size = $size | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $slot + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 100 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $slot + 156 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + 4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 & 1;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $12 = $slot + 88 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    _ft_mem_free($4, $13);
    HEAP32[$12 >> 2] = 0;
    label = 4;
    break;
   case 3:
    $15 = $8 | 1;
    HEAP32[$7 >> 2] = $15;
    label = 4;
    break;
   case 4:
    $17 = _ft_mem_alloc($4, $size, $error) | 0;
    $18 = $slot + 88 | 0;
    HEAP32[$18 >> 2] = $17;
    $19 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $19 | 0;
  }
  return 0;
}
function _FT_New_GlyphSlot($face, $aslot) {
  $face = $face | 0;
  $aslot = $aslot | 0;
  var $error = 0, $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $31 = 0, $34 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = ($face | 0) == 0;
    if ($1) {
      $_0 = 6;
      label = 11;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 96 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $_0 = 6;
      label = 11;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $4 + 20 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $4 + 8 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $8 + 44 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = _ft_mem_alloc($10, $12, $error) | 0;
    $14 = $13;
    $15 = HEAP32[$error >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 4;
      break;
    } else {
      label = 8;
      break;
    }
   case 4:
    $18 = $13 + 4 | 0;
    $19 = $18;
    HEAP32[$19 >> 2] = $face;
    $20 = _ft_glyphslot_init($14) | 0;
    HEAP32[$error >> 2] = $20;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    _ft_glyphslot_done($14);
    _ft_mem_free($10, $13);
    label = 10;
    break;
   case 6:
    $24 = $face + 84 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $13 + 8 | 0;
    $27 = $26;
    HEAP32[$27 >> 2] = $25;
    HEAP32[$24 >> 2] = $14;
    $28 = ($aslot | 0) == 0;
    if ($28) {
      label = 10;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    HEAP32[$aslot >> 2] = $14;
    label = 10;
    break;
   case 8:
    $31 = ($aslot | 0) == 0;
    if ($31) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    HEAP32[$aslot >> 2] = 0;
    label = 10;
    break;
   case 10:
    $34 = HEAP32[$error >> 2] | 0;
    $_0 = $34;
    label = 11;
    break;
   case 11:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _ft_glyphslot_init($slot) {
  $slot = $slot | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $_pr = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $37 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $slot + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 96 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 20 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $4 + 8 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $9 = $4 + 4 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $slot | 0;
    HEAP32[$11 >> 2] = $10;
    $12 = _ft_mem_alloc($8, 40, $error) | 0;
    $13 = HEAP32[$error >> 2] | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 2;
      break;
    } else {
      label = 8;
      break;
    }
   case 2:
    $16 = $12;
    $17 = $slot + 156 | 0;
    HEAP32[$17 >> 2] = $16;
    $18 = $4 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $19 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $21 & 512;
    $23 = ($22 | 0) == 0;
    if ($23) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $25 = $12;
    $26 = _FT_GlyphLoader_New($8, $25) | 0;
    HEAP32[$error >> 2] = $26;
    $28 = $26;
    label = 5;
    break;
   case 4:
    $_pr = HEAP32[$error >> 2] | 0;
    $28 = $_pr;
    label = 5;
    break;
   case 5:
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 6;
      break;
    } else {
      label = 8;
      break;
    }
   case 6:
    $31 = $6 + 64 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = ($32 | 0) == 0;
    if ($33) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $35 = FUNCTION_TABLE_ii[$32 & 1023]($slot) | 0;
    HEAP32[$error >> 2] = $35;
    label = 8;
    break;
   case 8:
    $37 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $37 | 0;
  }
  return 0;
}
function _ft_glyphslot_done($slot) {
  $slot = $slot | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $slot + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 96 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 20 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $4 + 8 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $6 + 68 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    FUNCTION_TABLE_vi[$10 & 1023]($slot);
    label = 3;
    break;
   case 3:
    _ft_glyphslot_free_bitmap($slot);
    $14 = $slot + 156 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 7;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $18 = $4 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $19 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $21 & 512;
    $23 = ($22 | 0) == 0;
    if ($23) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $25 = $15 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    _FT_GlyphLoader_Done($26);
    $27 = HEAP32[$14 >> 2] | 0;
    $28 = $27 | 0;
    HEAP32[$28 >> 2] = 0;
    label = 6;
    break;
   case 6:
    $30 = HEAP32[$14 >> 2] | 0;
    $31 = $30;
    _ft_mem_free($8, $31);
    HEAP32[$14 >> 2] = 0;
    label = 7;
    break;
   case 7:
    return;
  }
}
function _FT_Done_GlyphSlot($slot) {
  $slot = $slot | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $prev_0 = 0, $cur_0_in = 0, $cur_0 = 0, $11 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($slot | 0) == 0;
    if ($1) {
      label = 9;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $slot + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 96 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + 8 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $4 + 84 | 0;
    $cur_0_in = $9;
    $prev_0 = 0;
    label = 3;
    break;
   case 3:
    $cur_0 = HEAP32[$cur_0_in >> 2] | 0;
    $11 = ($cur_0 | 0) == 0;
    if ($11) {
      label = 9;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $13 = ($cur_0 | 0) == ($slot | 0);
    $14 = $cur_0 + 8 | 0;
    if ($13) {
      label = 5;
      break;
    } else {
      $cur_0_in = $14;
      $prev_0 = $cur_0;
      label = 3;
      break;
    }
   case 5:
    $16 = ($prev_0 | 0) == 0;
    $17 = $cur_0 + 8 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    if ($16) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $20 = HEAP32[$3 >> 2] | 0;
    $21 = $20 + 84 | 0;
    HEAP32[$21 >> 2] = $18;
    label = 8;
    break;
   case 7:
    $23 = $prev_0 + 8 | 0;
    HEAP32[$23 >> 2] = $18;
    label = 8;
    break;
   case 8:
    _ft_glyphslot_done($slot);
    $25 = $slot;
    _ft_mem_free($8, $25);
    label = 9;
    break;
   case 9:
    return;
  }
}
function _FT_Set_Transform($face, $matrix, $delta) {
  $face = $face | 0;
  $matrix = $matrix | 0;
  $delta = $delta | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $_0 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $ld$0$0 = 0, $43$0 = 0, $ld$1$1 = 0, $43$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $_022 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $53 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($face | 0) == 0;
    if ($1) {
      label = 14;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 128 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 28 | 0;
    HEAP32[$5 >> 2] = 0;
    $6 = ($matrix | 0) == 0;
    $7 = $4 + 4 | 0;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $9 = $7 | 0;
    HEAP32[$9 >> 2] = 65536;
    $10 = $4 + 8 | 0;
    HEAP32[$10 >> 2] = 0;
    $11 = $4 + 12 | 0;
    HEAP32[$11 >> 2] = 0;
    $12 = $4 + 16 | 0;
    HEAP32[$12 >> 2] = 65536;
    $_0 = $7;
    label = 5;
    break;
   case 4:
    $14 = $7;
    $15 = $matrix;
    _memcpy($14 | 0, $15 | 0, 16);
    $_0 = $matrix;
    label = 5;
    break;
   case 5:
    $17 = $_0 + 4 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $_0 + 8 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $20 | $18;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 6;
      break;
    } else {
      label = 8;
      break;
    }
   case 6:
    $24 = $_0 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = ($25 | 0) == 65536;
    if ($26) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $28 = $_0 + 12 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = ($29 | 0) == 65536;
    if ($30) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $32 = HEAP32[$5 >> 2] | 0;
    $33 = $32 | 1;
    HEAP32[$5 >> 2] = $33;
    label = 9;
    break;
   case 9:
    $35 = ($delta | 0) == 0;
    $36 = $4 + 20 | 0;
    if ($35) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $38 = $36 | 0;
    HEAP32[$38 >> 2] = 0;
    $39 = $4 + 24 | 0;
    HEAP32[$39 >> 2] = 0;
    $_022 = $36;
    label = 12;
    break;
   case 11:
    $41 = $delta;
    $42 = $36;
    $ld$0$0 = $41 | 0;
    $43$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $41 + 4 | 0;
    $43$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $42 | 0;
    HEAP32[$st$2$0 >> 2] = $43$0;
    $st$3$1 = $42 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $43$1;
    $_022 = $delta;
    label = 12;
    break;
   case 12:
    $45 = $_022 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $_022 + 4 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $48 | $46;
    $50 = ($49 | 0) == 0;
    if ($50) {
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $52 = HEAP32[$5 >> 2] | 0;
    $53 = $52 | 2;
    HEAP32[$5 >> 2] = $53;
    label = 14;
    break;
   case 14:
    return;
  }
}
function _ft_glyphslot_clear($slot) {
  $slot = $slot | 0;
  _ft_glyphslot_free_bitmap($slot);
  HEAP8[$slot + 94 | 0] = 0;
  _memset($slot + 24 | 0, 0, 40);
  _memset($slot + 72 | 0, 0, 16);
  _memset($slot + 100 | 0, 0, 56);
  return;
}
function _ft_lookup_glyph_renderer($slot) {
  $slot = $slot | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $slot + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 96 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 4 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + 164 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $11 = $8 + 24 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $slot + 72 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($12 | 0) == ($14 | 0);
    if ($15) {
      $result_0 = $8;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $17 = $slot + 72 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = _FT_Lookup_Renderer($6, $18, 0) | 0;
    $result_0 = $19;
    label = 4;
    break;
   case 4:
    return $result_0 | 0;
  }
  return 0;
}
function _FT_Outline_Transform($outline, $matrix) {
  $outline = $outline | 0;
  $matrix = $matrix | 0;
  var $1 = 0, $2 = 0, $or_cond = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $vec_08 = 0, $11 = 0, $12 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($outline | 0) == 0;
    $2 = ($matrix | 0) == 0;
    $or_cond = $1 | $2;
    if ($or_cond) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $outline + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $outline + 2 | 0;
    $7 = HEAP16[$6 >> 1] | 0;
    $8 = $7 << 16 >> 16;
    $9 = $5 + ($8 << 3) | 0;
    $10 = $7 << 16 >> 16 > 0;
    if ($10) {
      $vec_08 = $5;
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    _FT_Vector_Transform($vec_08, $matrix);
    $11 = $vec_08 + 8 | 0;
    $12 = $11 >>> 0 < $9 >>> 0;
    if ($12) {
      $vec_08 = $11;
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    return;
  }
}
function _FT_Vector_Transform($vector, $matrix) {
  $vector = $vector | 0;
  $matrix = $matrix | 0;
  var $1 = 0, $2 = 0, $or_cond = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($vector | 0) == 0;
    $2 = ($matrix | 0) == 0;
    $or_cond = $1 | $2;
    if ($or_cond) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $vector | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $matrix | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = _FT_MulFix($5, $7) | 0;
    $9 = $vector + 4 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $matrix + 4 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = _FT_MulFix($10, $12) | 0;
    $14 = $13 + $8 | 0;
    $15 = $matrix + 8 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = _FT_MulFix($5, $16) | 0;
    $18 = $matrix + 12 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = _FT_MulFix($10, $19) | 0;
    $21 = $20 + $17 | 0;
    HEAP32[$4 >> 2] = $14;
    HEAP32[$9 >> 2] = $21;
    label = 3;
    break;
   case 3:
    return;
  }
}
function _FT_Render_Glyph($slot, $render_mode) {
  $slot = $slot | 0;
  $render_mode = $render_mode | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($slot | 0) == 0;
    if ($1) {
      $_0 = 6;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $slot + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $_0 = 6;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $4 + 96 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 + 4 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = _FT_Render_Glyph_Internal($10, $slot, $render_mode) | 0;
    $_0 = $11;
    label = 4;
    break;
   case 4:
    return $_0 | 0;
  }
  return 0;
}
function _FT_Load_Char($face, $char_code, $load_flags) {
  $face = $face | 0;
  $char_code = $char_code | 0;
  $load_flags = $load_flags | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $glyph_index_0 = 0, $9 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($face | 0) == 0;
    if ($1) {
      $_0 = 35;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 92 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $glyph_index_0 = $char_code;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = _FT_Get_Char_Index($face, $char_code) | 0;
    $glyph_index_0 = $7;
    label = 4;
    break;
   case 4:
    $9 = _FT_Load_Glyph($face, $glyph_index_0, $load_flags) | 0;
    $_0 = $9;
    label = 5;
    break;
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function _FT_Get_Char_Index($face, $charcode) {
  $face = $face | 0;
  $charcode = $charcode | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($face | 0) == 0;
    if ($1) {
      $result_0 = 0;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 92 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $result_0 = 0;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $4;
    $8 = $4 + 12 | 0;
    $9 = $8;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10 + 12 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = FUNCTION_TABLE_iii[$12 & 1023]($7, $charcode) | 0;
    $result_0 = $13;
    label = 4;
    break;
   case 4:
    return $result_0 | 0;
  }
  return 0;
}
function _FT_New_Face($library, $pathname, $face_index, $aface) {
  $library = $library | 0;
  $pathname = $pathname | 0;
  $face_index = $face_index | 0;
  $aface = $aface | 0;
  var $args = 0, $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 32 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $args = __stackBase__ | 0;
    $1 = ($pathname | 0) == 0;
    if ($1) {
      $_0 = 6;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $args | 0;
    HEAP32[$3 >> 2] = 4;
    $4 = $args + 12 | 0;
    HEAP32[$4 >> 2] = $pathname;
    $5 = $args + 16 | 0;
    HEAP32[$5 >> 2] = 0;
    $6 = _FT_Open_Face($library, $args, $face_index, $aface) | 0;
    $_0 = $6;
    label = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_List_Add($list, $node) {
  $list = $list | 0;
  $node = $node | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $9 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $list + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $node + 4 | 0;
    HEAP32[$3 >> 2] = 0;
    $4 = $node | 0;
    HEAP32[$4 >> 2] = $2;
    $5 = ($2 | 0) == 0;
    if ($5) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $2 + 4 | 0;
    HEAP32[$7 >> 2] = $node;
    label = 4;
    break;
   case 3:
    $9 = $list | 0;
    HEAP32[$9 >> 2] = $node;
    label = 4;
    break;
   case 4:
    HEAP32[$1 >> 2] = $node;
    return;
  }
}
function _FT_List_Find($list, $data) {
  $list = $list | 0;
  $data = $data | 0;
  var $1 = 0, $cur_0_in = 0, $cur_0 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $list | 0;
    $cur_0_in = $1;
    label = 2;
    break;
   case 2:
    $cur_0 = HEAP32[$cur_0_in >> 2] | 0;
    $3 = ($cur_0 | 0) == 0;
    if ($3) {
      $_0 = 0;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $5 = $cur_0 + 8 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == ($data | 0);
    $8 = $cur_0 + 4 | 0;
    if ($7) {
      $_0 = $cur_0;
      label = 4;
      break;
    } else {
      $cur_0_in = $8;
      label = 2;
      break;
    }
   case 4:
    return $_0 | 0;
  }
  return 0;
}
function _FT_List_Remove($list, $node) {
  $list = $list | 0;
  $node = $node | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $9 = 0, $11 = 0, $13 = 0, $15 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $node | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $node + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) == 0;
    if ($5) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $2 + 4 | 0;
    HEAP32[$7 >> 2] = $4;
    label = 4;
    break;
   case 3:
    $9 = $list | 0;
    HEAP32[$9 >> 2] = $4;
    label = 4;
    break;
   case 4:
    $11 = ($4 | 0) == 0;
    if ($11) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $13 = $4 | 0;
    HEAP32[$13 >> 2] = $2;
    label = 7;
    break;
   case 6:
    $15 = $list + 4 | 0;
    HEAP32[$15 >> 2] = $2;
    label = 7;
    break;
   case 7:
    return;
  }
}
function _FT_Open_Face($library, $args, $face_index, $aface) {
  $library = $library | 0;
  $args = $args | 0;
  $face_index = $face_index | 0;
  $aface = $aface | 0;
  var $error = 0, $stream = 0, $face = 0, $size = 0, $1 = 0, $_not = 0, $2 = 0, $or_cond = 0, $3 = 0, $or_cond62 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $num_params_0 = 0, $params_0 = 0, $44 = 0, $45 = 0, $46 = 0, $49 = 0, $50 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $cur_066 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $73 = 0, $74 = 0, $num_params1_0 = 0, $params2_0 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $93 = 0, $95 = 0, $96 = 0, $97 = 0, $99 = 0, $100 = 0, $101 = 0, $103 = 0, $104 = 0, $105 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $112 = 0, $113 = 0, $114 = 0, $116 = 0, $117 = 0, $118 = 0, $120 = 0, $121 = 0, $124 = 0, $125 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $132 = 0, $133 = 0, $134 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $146 = 0, $147 = 0, $148 = 0, $150 = 0, $151 = 0, $152 = 0, $154 = 0, $155 = 0, $156 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $164 = 0, $165 = 0, $166 = 0, $168 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $176 = 0, $177 = 0, $178 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $192 = 0, $i_063 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $199 = 0, $201 = 0, $202 = 0, $203 = 0, $205 = 0, $sext = 0, $206 = 0, $208 = 0, $209 = 0, $210 = 0, $212 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $230 = 0, $232 = 0, $233 = 0, $235 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $stream = __stackBase__ + 4 | 0;
    $face = __stackBase__ + 8 | 0;
    $size = __stackBase__ + 12 | 0;
    HEAP32[$stream >> 2] = 0;
    HEAP32[$face >> 2] = 0;
    $1 = ($aface | 0) != 0;
    $_not = $1 ^ 1;
    $2 = ($face_index | 0) > -1;
    $or_cond = $2 & $_not;
    $3 = ($args | 0) == 0;
    $or_cond62 = $or_cond | $3;
    if ($or_cond62) {
      $_0 = 6;
      label = 59;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $args | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 & 2;
    $8 = ($7 | 0) == 0;
    if ($8) {
      $14 = 0;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $10 = $args + 16 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($11 | 0) != 0;
    $14 = $12;
    label = 4;
    break;
   case 4:
    $15 = _FT_Stream_New($library, $args, $stream) | 0;
    HEAP32[$error >> 2] = $15;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 5;
      break;
    } else {
      label = 26;
      break;
    }
   case 5:
    $18 = $library | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = HEAP32[$5 >> 2] | 0;
    $21 = $20 & 8;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 13;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $24 = $args + 20 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 13;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $28 = $25;
    $29 = $25 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $30 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $32 & 1;
    $34 = ($33 | 0) == 0;
    if ($34) {
      label = 11;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $36 = $20 & 16;
    $37 = ($36 | 0) == 0;
    if ($37) {
      $params_0 = 0;
      $num_params_0 = 0;
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $39 = $args + 24 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $args + 28 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $params_0 = $42;
    $num_params_0 = $40;
    label = 10;
    break;
   case 10:
    $44 = HEAP32[$stream >> 2] | 0;
    $45 = _open_face($28, $44, $face_index, $num_params_0, $params_0, $face) | 0;
    HEAP32[$error >> 2] = $45;
    $46 = ($45 | 0) == 0;
    if ($46) {
      label = 32;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    HEAP32[$error >> 2] = 32;
    label = 12;
    break;
   case 12:
    $49 = HEAP32[$stream >> 2] | 0;
    $50 = $14 & 1;
    _FT_Stream_Free($49, $50);
    label = 57;
    break;
   case 13:
    $52 = $library + 24 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $library + 28 + ($53 << 2) | 0;
    $55 = ($53 | 0) > 0;
    if ($55) {
      label = 14;
      break;
    } else {
      label = 26;
      break;
    }
   case 14:
    $56 = $library + 28 | 0;
    $57 = $args + 24 | 0;
    $58 = $args + 28 | 0;
    $cur_066 = $56;
    label = 15;
    break;
   case 15:
    $60 = HEAP32[$cur_066 >> 2] | 0;
    $61 = $60 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = $62 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = $64 & 1;
    $66 = ($65 | 0) == 0;
    if ($66) {
      label = 25;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $68 = $60;
    $69 = HEAP32[$5 >> 2] | 0;
    $70 = $69 & 16;
    $71 = ($70 | 0) == 0;
    if ($71) {
      $params2_0 = 0;
      $num_params1_0 = 0;
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $73 = HEAP32[$57 >> 2] | 0;
    $74 = HEAP32[$58 >> 2] | 0;
    $params2_0 = $74;
    $num_params1_0 = $73;
    label = 18;
    break;
   case 18:
    $76 = HEAP32[$stream >> 2] | 0;
    $77 = _open_face($68, $76, $face_index, $num_params1_0, $params2_0, $face) | 0;
    HEAP32[$error >> 2] = $77;
    $78 = ($77 | 0) == 0;
    if ($78) {
      label = 32;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $80 = HEAP32[$cur_066 >> 2] | 0;
    $81 = $80 | 0;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = $82 + 8 | 0;
    $84 = HEAP32[$83 >> 2] | 0;
    $85 = _strcmp($84 | 0, 5321480) | 0;
    $86 = ($85 | 0) == 0;
    if ($86) {
      label = 20;
      break;
    } else {
      label = 24;
      break;
    }
   case 20:
    $88 = $77 & 255;
    $89 = ($88 | 0) == 142;
    if ($89) {
      label = 21;
      break;
    } else {
      label = 24;
      break;
    }
   case 21:
    $91 = HEAP32[$stream >> 2] | 0;
    $92 = _FT_Stream_Seek($91, 0) | 0;
    $93 = ($92 | 0) == 0;
    if ($93) {
      label = 22;
      break;
    } else {
      label = 26;
      break;
    }
   case 22:
    $95 = HEAP32[$stream >> 2] | 0;
    $96 = _open_face_PS_from_sfnt_stream($library, $95, $face_index, $aface) | 0;
    HEAP32[$error >> 2] = $96;
    $97 = ($96 | 0) == 0;
    if ($97) {
      label = 23;
      break;
    } else {
      label = 24;
      break;
    }
   case 23:
    $99 = HEAP32[$stream >> 2] | 0;
    $100 = $14 & 1;
    _FT_Stream_Free($99, $100);
    $101 = HEAP32[$error >> 2] | 0;
    $_0 = $101;
    label = 59;
    break;
   case 24:
    $103 = HEAP32[$error >> 2] | 0;
    $104 = $103 & 255;
    $105 = ($104 | 0) == 2;
    if ($105) {
      label = 25;
      break;
    } else {
      label = 26;
      break;
    }
   case 25:
    $107 = $cur_066 + 4 | 0;
    $108 = $107 >>> 0 < $54 >>> 0;
    if ($108) {
      $cur_066 = $107;
      label = 15;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $109 = HEAP32[$error >> 2] | 0;
    $110 = $109 & 255;
    if (($110 | 0) == 81 | ($110 | 0) == 2 | ($110 | 0) == 85) {
      label = 27;
      break;
    } else {
      label = 31;
      break;
    }
   case 27:
    $112 = HEAP32[$stream >> 2] | 0;
    $113 = _load_mac_face($library, $112, $face_index, $aface, $args) | 0;
    HEAP32[$error >> 2] = $113;
    $114 = ($113 | 0) == 0;
    if ($114) {
      label = 28;
      break;
    } else {
      label = 29;
      break;
    }
   case 28:
    $116 = HEAP32[$stream >> 2] | 0;
    $117 = $14 & 1;
    _FT_Stream_Free($116, $117);
    $118 = HEAP32[$error >> 2] | 0;
    $_0 = $118;
    label = 59;
    break;
   case 29:
    $120 = $113 & 255;
    $121 = ($120 | 0) == 2;
    if ($121) {
      label = 30;
      break;
    } else {
      label = 31;
      break;
    }
   case 30:
    HEAP32[$error >> 2] = 2;
    label = 31;
    break;
   case 31:
    $124 = HEAP32[$stream >> 2] | 0;
    $125 = $14 & 1;
    _FT_Stream_Free($124, $125);
    label = 57;
    break;
   case 32:
    if ($14) {
      label = 33;
      break;
    } else {
      label = 34;
      break;
    }
   case 33:
    $127 = HEAP32[$face >> 2] | 0;
    $128 = $127 + 8 | 0;
    $129 = HEAP32[$128 >> 2] | 0;
    $130 = $129 | 1024;
    HEAP32[$128 >> 2] = $130;
    label = 34;
    break;
   case 34:
    $132 = _ft_mem_alloc($19, 12, $error) | 0;
    $133 = HEAP32[$error >> 2] | 0;
    $134 = ($133 | 0) == 0;
    if ($134) {
      label = 35;
      break;
    } else {
      label = 57;
      break;
    }
   case 35:
    $136 = $132;
    $137 = HEAP32[$face >> 2] | 0;
    $138 = $137;
    $139 = $132 + 8 | 0;
    $140 = $139;
    HEAP32[$140 >> 2] = $138;
    $141 = HEAP32[$face >> 2] | 0;
    $142 = $141 + 96 | 0;
    $143 = HEAP32[$142 >> 2] | 0;
    $144 = $143 + 24 | 0;
    _FT_List_Add($144, $136);
    if ($2) {
      label = 36;
      break;
    } else {
      label = 39;
      break;
    }
   case 36:
    $146 = HEAP32[$face >> 2] | 0;
    $147 = _FT_New_GlyphSlot($146, 0) | 0;
    HEAP32[$error >> 2] = $147;
    $148 = ($147 | 0) == 0;
    if ($148) {
      label = 37;
      break;
    } else {
      label = 57;
      break;
    }
   case 37:
    $150 = HEAP32[$face >> 2] | 0;
    $151 = _FT_New_Size($150, $size) | 0;
    HEAP32[$error >> 2] = $151;
    $152 = ($151 | 0) == 0;
    if ($152) {
      label = 38;
      break;
    } else {
      label = 57;
      break;
    }
   case 38:
    $154 = HEAP32[$size >> 2] | 0;
    $155 = HEAP32[$face >> 2] | 0;
    $156 = $155 + 88 | 0;
    HEAP32[$156 >> 2] = $154;
    label = 39;
    break;
   case 39:
    $158 = HEAP32[$face >> 2] | 0;
    $159 = $158 + 8 | 0;
    $160 = HEAP32[$159 >> 2] | 0;
    $161 = $160 & 1;
    $162 = ($161 | 0) == 0;
    if ($162) {
      label = 44;
      break;
    } else {
      label = 40;
      break;
    }
   case 40:
    $164 = $158 + 74 | 0;
    $165 = HEAP16[$164 >> 1] | 0;
    $166 = $165 << 16 >> 16 < 0;
    if ($166) {
      label = 41;
      break;
    } else {
      label = 42;
      break;
    }
   case 41:
    $168 = -$165 & 65535;
    HEAP16[$164 >> 1] = $168;
    label = 42;
    break;
   case 42:
    $170 = HEAP32[$face >> 2] | 0;
    $171 = $170 + 8 | 0;
    $172 = HEAP32[$171 >> 2] | 0;
    $173 = $172 & 32;
    $174 = ($173 | 0) == 0;
    if ($174) {
      label = 43;
      break;
    } else {
      label = 44;
      break;
    }
   case 43:
    $176 = $170 + 74 | 0;
    $177 = HEAP16[$176 >> 1] | 0;
    $178 = $170 + 78 | 0;
    HEAP16[$178 >> 1] = $177;
    label = 44;
    break;
   case 44:
    $180 = HEAP32[$face >> 2] | 0;
    $181 = $180 + 8 | 0;
    $182 = HEAP32[$181 >> 2] | 0;
    $183 = $182 & 2;
    $184 = ($183 | 0) == 0;
    if ($184) {
      label = 54;
      break;
    } else {
      label = 45;
      break;
    }
   case 45:
    $185 = HEAP32[$face >> 2] | 0;
    $186 = $185 + 28 | 0;
    $187 = HEAP32[$186 >> 2] | 0;
    $188 = ($187 | 0) > 0;
    if ($188) {
      label = 46;
      break;
    } else {
      label = 54;
      break;
    }
   case 46:
    $189 = HEAP32[$face >> 2] | 0;
    $190 = $189 + 28 | 0;
    $i_063 = 0;
    $192 = $185;
    label = 47;
    break;
   case 47:
    $193 = $192 + 32 | 0;
    $194 = HEAP32[$193 >> 2] | 0;
    $195 = $194 + ($i_063 << 4) | 0;
    $196 = HEAP16[$195 >> 1] | 0;
    $197 = $196 << 16 >> 16 < 0;
    if ($197) {
      label = 48;
      break;
    } else {
      label = 49;
      break;
    }
   case 48:
    $199 = -$196 & 65535;
    HEAP16[$195 >> 1] = $199;
    label = 49;
    break;
   case 49:
    $201 = $194 + ($i_063 << 4) + 8 | 0;
    $202 = HEAP32[$201 >> 2] | 0;
    $203 = ($202 | 0) < 0;
    if ($203) {
      label = 50;
      break;
    } else {
      label = 51;
      break;
    }
   case 50:
    $205 = -$202 | 0;
    $sext = $205 << 16;
    $206 = $sext >> 16;
    HEAP32[$201 >> 2] = $206;
    label = 51;
    break;
   case 51:
    $208 = $194 + ($i_063 << 4) + 12 | 0;
    $209 = HEAP32[$208 >> 2] | 0;
    $210 = ($209 | 0) < 0;
    if ($210) {
      label = 52;
      break;
    } else {
      label = 53;
      break;
    }
   case 52:
    $212 = -$209 | 0;
    HEAP32[$208 >> 2] = $212;
    label = 53;
    break;
   case 53:
    $214 = $i_063 + 1 | 0;
    $215 = HEAP32[$190 >> 2] | 0;
    $216 = ($214 | 0) < ($215 | 0);
    if ($216) {
      $i_063 = $214;
      $192 = $189;
      label = 47;
      break;
    } else {
      label = 54;
      break;
    }
   case 54:
    $217 = HEAP32[$face >> 2] | 0;
    $218 = $217 + 128 | 0;
    $219 = HEAP32[$218 >> 2] | 0;
    $220 = $219 + 4 | 0;
    HEAP32[$220 >> 2] = 65536;
    $221 = $219 + 8 | 0;
    HEAP32[$221 >> 2] = 0;
    $222 = $219 + 12 | 0;
    HEAP32[$222 >> 2] = 0;
    $223 = $219 + 16 | 0;
    HEAP32[$223 >> 2] = 65536;
    $224 = $219 + 20 | 0;
    HEAP32[$224 >> 2] = 0;
    $225 = $219 + 24 | 0;
    HEAP32[$225 >> 2] = 0;
    $226 = $219 + 60 | 0;
    HEAP32[$226 >> 2] = 1;
    $227 = HEAP32[$face >> 2] | 0;
    if ($1) {
      label = 55;
      break;
    } else {
      label = 56;
      break;
    }
   case 55:
    HEAP32[$aface >> 2] = $227;
    label = 58;
    break;
   case 56:
    $230 = _FT_Done_Face($227) | 0;
    label = 58;
    break;
   case 57:
    $232 = HEAP32[$face >> 2] | 0;
    $233 = _FT_Done_Face($232) | 0;
    label = 58;
    break;
   case 58:
    $235 = HEAP32[$error >> 2] | 0;
    $_0 = $235;
    label = 59;
    break;
   case 59:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _open_face($driver, $stream, $face_index, $num_params, $params, $aface) {
  $driver = $driver | 0;
  $stream = $stream | 0;
  $face_index = $face_index | 0;
  $num_params = $num_params | 0;
  $params = $params | 0;
  $aface = $aface | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $i_044 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $_pr = 0, $49 = 0, $50 = 0, $52 = 0, $_pr42 = 0, $56 = 0, $internal_043 = 0, $57 = 0, $58 = 0, $59 = 0, $62 = 0, $64 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $driver + 20 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $driver + 8 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + 36 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = _ft_mem_alloc($4, $6, $error) | 0;
    $8 = $7;
    $9 = HEAP32[$error >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 2;
      break;
    } else {
      $internal_043 = 0;
      label = 16;
      break;
    }
   case 2:
    $12 = _ft_mem_alloc($4, 64, $error) | 0;
    $13 = $12;
    $14 = HEAP32[$error >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 3;
      break;
    } else {
      $internal_043 = $13;
      label = 16;
      break;
    }
   case 3:
    $17 = $7 + 128 | 0;
    $18 = $17;
    HEAP32[$18 >> 2] = $13;
    $19 = $7 + 96 | 0;
    $20 = $19;
    HEAP32[$20 >> 2] = $driver;
    $21 = $7 + 100 | 0;
    $22 = $21;
    HEAP32[$22 >> 2] = $4;
    $23 = $7 + 104 | 0;
    $24 = $23;
    HEAP32[$24 >> 2] = $stream;
    $25 = HEAP32[$18 >> 2] | 0;
    $26 = $25 + 52 | 0;
    HEAP32[$26 >> 2] = 0;
    $27 = ($num_params | 0) > 0;
    if ($27) {
      $i_044 = 0;
      label = 4;
      break;
    } else {
      label = 8;
      break;
    }
   case 4:
    $28 = HEAP32[$18 >> 2] | 0;
    $29 = $28 + 52 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 5;
      break;
    } else {
      label = 8;
      break;
    }
   case 5:
    $33 = $params + ($i_044 << 3) | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = ($34 | 0) == 1768842098;
    if ($35) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $37 = $params + ($i_044 << 3) + 4 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $38;
    HEAP32[$29 >> 2] = $39;
    label = 7;
    break;
   case 7:
    $41 = $i_044 + 1 | 0;
    $42 = ($41 | 0) < ($num_params | 0);
    if ($42) {
      $i_044 = $41;
      label = 4;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $43 = $2 + 48 | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    $45 = ($44 | 0) == 0;
    if ($45) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $47 = FUNCTION_TABLE_iiiiii[$44 & 1023]($stream, $8, $face_index, $num_params, $params) | 0;
    HEAP32[$error >> 2] = $47;
    $49 = $47;
    label = 11;
    break;
   case 10:
    $_pr = HEAP32[$error >> 2] | 0;
    $49 = $_pr;
    label = 11;
    break;
   case 11:
    $50 = ($49 | 0) == 0;
    if ($50) {
      label = 12;
      break;
    } else {
      label = 15;
      break;
    }
   case 12:
    $52 = _find_unicode_charmap($8) | 0;
    if (($52 | 0) == 38 | ($52 | 0) == 0) {
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    HEAP32[$error >> 2] = $52;
    $internal_043 = $13;
    label = 16;
    break;
   case 14:
    HEAP32[$aface >> 2] = $8;
    label = 15;
    break;
   case 15:
    $_pr42 = HEAP32[$error >> 2] | 0;
    $56 = ($_pr42 | 0) == 0;
    if ($56) {
      label = 19;
      break;
    } else {
      $internal_043 = $13;
      label = 16;
      break;
    }
   case 16:
    _destroy_charmaps($8, $4);
    $57 = $2 + 52 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = ($58 | 0) == 0;
    if ($59) {
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    FUNCTION_TABLE_vi[$58 & 1023]($8);
    label = 18;
    break;
   case 18:
    $62 = $internal_043;
    _ft_mem_free($4, $62);
    _ft_mem_free($4, $7);
    HEAP32[$aface >> 2] = 0;
    label = 19;
    break;
   case 19:
    $64 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $64 | 0;
  }
  return 0;
}
function _FT_Stream_Seek($stream, $pos) {
  $stream = $stream | 0;
  $pos = $pos | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $_ = 0, $8 = 0, $9 = 0, $10 = 0, $_9 = 0, $error_0 = 0, $12 = 0, $14 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $stream + 20 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = FUNCTION_TABLE_iiiii[$2 & 1023]($stream, $pos, 0, 0) | 0;
    $6 = ($5 | 0) == 0;
    $_ = $6 ? 0 : 85;
    $error_0 = $_;
    label = 4;
    break;
   case 3:
    $8 = $stream + 4 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 >>> 0 < $pos >>> 0;
    $_9 = $10 ? 85 : 0;
    $error_0 = $_9;
    label = 4;
    break;
   case 4:
    $12 = ($error_0 | 0) == 0;
    if ($12) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $14 = $stream + 8 | 0;
    HEAP32[$14 >> 2] = $pos;
    label = 6;
    break;
   case 6:
    return $error_0 | 0;
  }
  return 0;
}
function _open_face_PS_from_sfnt_stream($library, $stream, $face_index, $aface) {
  $library = $library | 0;
  $stream = $stream | 0;
  $face_index = $face_index | 0;
  $aface = $aface | 0;
  var $error = 0, $offset = 0, $length = 0, $is_sfnt_cid = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $_pr = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $35 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $offset = __stackBase__ + 4 | 0;
    $length = __stackBase__ + 8 | 0;
    $is_sfnt_cid = __stackBase__ + 12 | 0;
    $1 = $library | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _FT_Stream_Pos($stream) | 0;
    $4 = _ft_lookup_PS_in_sfnt_stream($stream, $face_index, $offset, $length, $is_sfnt_cid) | 0;
    HEAP32[$error >> 2] = $4;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $29 = $4;
      label = 7;
      break;
    }
   case 2:
    $7 = HEAP32[$offset >> 2] | 0;
    $8 = $7 + $3 | 0;
    $9 = _FT_Stream_Seek($stream, $8) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 3:
    $12 = HEAP32[$length >> 2] | 0;
    $13 = _ft_mem_alloc($2, $12, $error) | 0;
    $14 = HEAP32[$error >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 4;
      break;
    } else {
      $29 = $14;
      label = 7;
      break;
    }
   case 4:
    $17 = HEAP32[$length >> 2] | 0;
    $18 = _FT_Stream_Read($stream, $13, $17) | 0;
    HEAP32[$error >> 2] = $18;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 5;
      break;
    } else {
      $29 = $18;
      label = 7;
      break;
    }
   case 5:
    $21 = HEAP32[$length >> 2] | 0;
    $22 = ($face_index | 0) < 0;
    $23 = $22 ? $face_index : 0;
    $24 = HEAP8[$is_sfnt_cid] | 0;
    $25 = $24 << 24 >> 24 != 0;
    $26 = $25 ? 5323860 : 5323936;
    $27 = _open_face_from_buffer($library, $13, $21, $23, $26, $aface) | 0;
    HEAP32[$error >> 2] = $27;
    $29 = $27;
    label = 7;
    break;
   case 6:
    $_pr = HEAP32[$error >> 2] | 0;
    $29 = $_pr;
    label = 7;
    break;
   case 7:
    $30 = ($29 | 0) == 2;
    if ($30) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $32 = _FT_Stream_Seek($stream, $3) | 0;
    $33 = ($32 | 0) == 0;
    if ($33) {
      label = 9;
      break;
    } else {
      $_0 = $32;
      label = 10;
      break;
    }
   case 9:
    $35 = HEAP32[$error >> 2] | 0;
    $_0 = $35;
    label = 10;
    break;
   case 10:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _load_mac_face($library, $stream, $face_index, $aface, $args) {
  $library = $library | 0;
  $stream = $stream | 0;
  $face_index = $face_index | 0;
  $aface = $aface | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $error_0 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $error_1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _IsMacBinary($library, $stream, $face_index, $aface) | 0;
    $2 = $1 & 255;
    $3 = ($2 | 0) == 2;
    if ($3) {
      label = 2;
      break;
    } else {
      $error_0 = $1;
      label = 3;
      break;
    }
   case 2:
    $5 = _IsMacResource($library, $stream, 0, $face_index, $aface) | 0;
    $error_0 = $5;
    label = 3;
    break;
   case 3:
    $7 = $error_0 & 255;
    if (($7 | 0) == 2 | ($7 | 0) == 85) {
      label = 4;
      break;
    } else {
      $error_1 = $error_0;
      label = 6;
      break;
    }
   case 4:
    $9 = $args | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10 & 4;
    $12 = ($11 | 0) == 0;
    if ($12) {
      $error_1 = $error_0;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $14 = _load_face_in_embedded_rfork($library, $stream, $face_index, $aface, $args) | 0;
    $error_1 = $14;
    label = 6;
    break;
   case 6:
    return $error_1 | 0;
  }
  return 0;
}
function _FT_New_Size($face, $asize) {
  $face = $face | 0;
  $asize = $asize | 0;
  var $error = 0, $1 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $_pr = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $_pr23 = 0, $42 = 0, $node_024 = 0, $43 = 0, $45 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = ($face | 0) == 0;
    if ($1) {
      $_0 = 35;
      label = 14;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = ($asize | 0) == 0;
    if ($3) {
      $_0 = 36;
      label = 14;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $5 = $face + 96 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      $_0 = 34;
      label = 14;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    HEAP32[$asize >> 2] = 0;
    $9 = HEAP32[$5 >> 2] | 0;
    $10 = $9 + 20 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $face + 100 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $11 + 40 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = _ft_mem_alloc($13, $15, $error) | 0;
    $17 = $16;
    $18 = HEAP32[$error >> 2] | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 5;
      break;
    } else {
      $node_024 = 0;
      label = 12;
      break;
    }
   case 5:
    $21 = _ft_mem_alloc($13, 12, $error) | 0;
    $22 = $21;
    $23 = HEAP32[$error >> 2] | 0;
    $24 = ($23 | 0) == 0;
    if ($24) {
      label = 6;
      break;
    } else {
      $node_024 = $22;
      label = 12;
      break;
    }
   case 6:
    $26 = $16;
    HEAP32[$26 >> 2] = $face;
    $27 = $16 + 40 | 0;
    $28 = $27;
    HEAP32[$28 >> 2] = 0;
    $29 = $11 + 56 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $33 = FUNCTION_TABLE_ii[$30 & 1023]($17) | 0;
    HEAP32[$error >> 2] = $33;
    $35 = $33;
    label = 9;
    break;
   case 8:
    $_pr = HEAP32[$error >> 2] | 0;
    $35 = $_pr;
    label = 9;
    break;
   case 9:
    $36 = ($35 | 0) == 0;
    if ($36) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    HEAP32[$asize >> 2] = $17;
    $38 = $21 + 8 | 0;
    $39 = $38;
    HEAP32[$39 >> 2] = $16;
    $40 = $face + 108 | 0;
    _FT_List_Add($40, $22);
    label = 11;
    break;
   case 11:
    $_pr23 = HEAP32[$error >> 2] | 0;
    $42 = ($_pr23 | 0) == 0;
    if ($42) {
      label = 13;
      break;
    } else {
      $node_024 = $22;
      label = 12;
      break;
    }
   case 12:
    $43 = $node_024;
    _ft_mem_free($13, $43);
    _ft_mem_free($13, $16);
    label = 13;
    break;
   case 13:
    $45 = HEAP32[$error >> 2] | 0;
    $_0 = $45;
    label = 14;
    break;
   case 14:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_Done_Face($face) {
  $face = $face | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($face | 0) == 0;
    if ($1) {
      $error_0 = 35;
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 96 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $error_0 = 35;
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $face + 128 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 + 60 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10 - 1 | 0;
    HEAP32[$9 >> 2] = $11;
    $12 = HEAP32[$7 >> 2] | 0;
    $13 = $12 + 60 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 4;
      break;
    } else {
      $error_0 = 0;
      label = 6;
      break;
    }
   case 4:
    $17 = HEAP32[$3 >> 2] | 0;
    $18 = $17 + 8 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $17 + 24 | 0;
    $21 = $face;
    $22 = _FT_List_Find($20, $21) | 0;
    $23 = ($22 | 0) == 0;
    if ($23) {
      $error_0 = 35;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    _FT_List_Remove($20, $22);
    $25 = $22;
    _ft_mem_free($19, $25);
    _destroy_face($19, $face, $17);
    $error_0 = 0;
    label = 6;
    break;
   case 6:
    return $error_0 | 0;
  }
  return 0;
}
function _destroy_face($memory, $face, $driver) {
  $memory = $memory | 0;
  $face = $face | 0;
  $driver = $driver | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $_lobit = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $40 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $driver + 20 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 120 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $face + 116 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    FUNCTION_TABLE_vi[$4 & 1023]($8);
    label = 3;
    break;
   case 3:
    $9 = $face + 84 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 5;
      break;
    } else {
      $12 = $10;
      label = 4;
      break;
    }
   case 4:
    _FT_Done_GlyphSlot($12);
    $13 = HEAP32[$9 >> 2] | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 5;
      break;
    } else {
      $12 = $13;
      label = 4;
      break;
    }
   case 5:
    $15 = $face + 108 | 0;
    $16 = $driver;
    _FT_List_Finalize($15, 106, $memory, $16);
    $17 = $face + 88 | 0;
    HEAP32[$17 >> 2] = 0;
    $18 = $face + 48 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $22 = $face;
    FUNCTION_TABLE_vi[$19 & 1023]($22);
    label = 7;
    break;
   case 7:
    _destroy_charmaps($face, $memory);
    $24 = $2 + 52 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    FUNCTION_TABLE_vi[$25 & 1023]($face);
    label = 9;
    break;
   case 9:
    $29 = $face + 104 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $face + 8 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $32 >>> 10;
    $_lobit = $33 & 1;
    _FT_Stream_Free($30, $_lobit);
    HEAP32[$29 >> 2] = 0;
    $34 = $face + 128 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = ($35 | 0) == 0;
    if ($36) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $38 = $35;
    _ft_mem_free($memory, $38);
    HEAP32[$34 >> 2] = 0;
    label = 11;
    break;
   case 11:
    $40 = $face;
    _ft_mem_free($memory, $40);
    return;
  }
}
function _FT_Match_Size($face, $req, $ignore_width, $size_index) {
  $face = $face | 0;
  $req = $req | 0;
  $ignore_width = $ignore_width | 0;
  $size_index = $size_index | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $_pr = 0, $38 = 0, $39 = 0, $40 = 0, $_ = 0, $w_0 = 0, $h_0 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $i_027 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $or_cond = 0, $63 = 0, $66 = 0, $67 = 0, $68 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 & 2;
    $4 = ($3 | 0) == 0;
    if ($4) {
      $_0 = 35;
      label = 18;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $req | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 3;
      break;
    } else {
      $_0 = 7;
      label = 18;
      break;
    }
   case 3:
    $10 = $req + 12 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($11 | 0) == 0;
    $13 = $req + 4 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    if ($12) {
      $20 = $14;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $16 = Math_imul($14, $11);
    $17 = $16 + 36 | 0;
    $18 = ($17 | 0) / 72 & -1;
    $20 = $18;
    label = 5;
    break;
   case 5:
    $21 = $req + 16 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = ($22 | 0) == 0;
    $24 = $req + 8 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    if ($23) {
      $31 = $25;
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $27 = Math_imul($25, $22);
    $28 = $27 + 36 | 0;
    $29 = ($28 | 0) / 72 & -1;
    $31 = $29;
    label = 7;
    break;
   case 7:
    $32 = HEAP32[$13 >> 2] | 0;
    $33 = ($32 | 0) == 0;
    if ($33) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $35 = HEAP32[$24 >> 2] | 0;
    $36 = ($35 | 0) == 0;
    if ($36) {
      $h_0 = $20;
      $w_0 = $20;
      label = 11;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $_pr = HEAP32[$13 >> 2] | 0;
    $38 = ($_pr | 0) == 0;
    if ($38) {
      label = 10;
      break;
    } else {
      $h_0 = $31;
      $w_0 = $20;
      label = 11;
      break;
    }
   case 10:
    $39 = HEAP32[$24 >> 2] | 0;
    $40 = ($39 | 0) == 0;
    $_ = $40 ? $20 : $31;
    $h_0 = $31;
    $w_0 = $_;
    label = 11;
    break;
   case 11:
    $42 = $w_0 + 32 | 0;
    $43 = $h_0 + 32 | 0;
    $44 = $face + 28 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = ($45 | 0) > 0;
    if ($46) {
      label = 12;
      break;
    } else {
      $_0 = 23;
      label = 18;
      break;
    }
   case 12:
    $47 = $face + 32 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $ignore_width << 24 >> 24 == 0;
    $i_027 = 0;
    label = 13;
    break;
   case 13:
    $51 = $48 + ($i_027 << 4) + 12 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = $52 + 32 | 0;
    $54 = $53 ^ $43;
    $55 = $54 >>> 0 > 63;
    if ($55) {
      label = 17;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $57 = $48 + ($i_027 << 4) + 8 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = $58 + 32 | 0;
    $60 = $59 ^ $42;
    $61 = $60 >>> 0 > 63;
    $or_cond = $61 & $49;
    if ($or_cond) {
      label = 17;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $63 = ($size_index | 0) == 0;
    if ($63) {
      $_0 = 0;
      label = 18;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    HEAP32[$size_index >> 2] = $i_027;
    $_0 = 0;
    label = 18;
    break;
   case 17:
    $66 = $i_027 + 1 | 0;
    $67 = HEAP32[$44 >> 2] | 0;
    $68 = ($66 | 0) < ($67 | 0);
    if ($68) {
      $i_027 = $66;
      label = 13;
      break;
    } else {
      $_0 = 23;
      label = 18;
      break;
    }
   case 18:
    return $_0 | 0;
  }
  return 0;
}
function _ft_synthesize_vertical_metrics($metrics, $advance) {
  $metrics = $metrics | 0;
  $advance = $advance | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $_ = 0, $9 = 0, $10 = 0, $_17 = 0, $height_0 = 0, $12 = 0, $14 = 0, $15 = 0, $_0 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $metrics + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $metrics + 12 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) < 0;
    if ($5) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $7 = ($2 | 0) < ($4 | 0);
    $_ = $7 ? $4 : $2;
    $height_0 = $_;
    label = 4;
    break;
   case 3:
    $9 = ($4 | 0) > 0;
    $10 = $9 ? $4 : 0;
    $_17 = $2 - $10 | 0;
    $height_0 = $_17;
    label = 4;
    break;
   case 4:
    $12 = ($advance | 0) == 0;
    if ($12) {
      label = 5;
      break;
    } else {
      $_0 = $advance;
      label = 6;
      break;
    }
   case 5:
    $14 = $height_0 * 12 & -1;
    $15 = ($14 | 0) / 10 & -1;
    $_0 = $15;
    label = 6;
    break;
   case 6:
    $17 = $metrics + 8 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $metrics + 16 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = ($20 | 0) / 2 & -1;
    $22 = $18 - $21 | 0;
    $23 = $metrics + 20 | 0;
    HEAP32[$23 >> 2] = $22;
    $24 = $_0 - $height_0 | 0;
    $25 = ($24 | 0) / 2 & -1;
    $26 = $metrics + 24 | 0;
    HEAP32[$26 >> 2] = $25;
    $27 = $metrics + 28 | 0;
    HEAP32[$27 >> 2] = $_0;
    return;
  }
}
function _find_unicode_charmap($face) {
  $face = $face | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $_sum = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $_sum27 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 40 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      $_0 = 38;
      label = 18;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $face + 36 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $_sum = $6 - 1 | 0;
    $7 = ($_sum | 0) < 0;
    if ($7) {
      label = 12;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $8 = $2 + ($_sum << 2) | 0;
    $9 = $2;
    $11 = $8;
    label = 4;
    break;
   case 4:
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + 4 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($14 | 0) == 1970170211;
    if ($15) {
      label = 5;
      break;
    } else {
      label = 10;
      break;
    }
   case 5:
    $17 = $12 + 8 | 0;
    $18 = HEAP16[$17 >> 1] | 0;
    $19 = $18 << 16 >> 16 == 3;
    if ($19) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $21 = $12 + 10 | 0;
    $22 = HEAP16[$21 >> 1] | 0;
    $23 = $22 << 16 >> 16 == 10;
    if ($23) {
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $25 = HEAP32[$11 >> 2] | 0;
    $26 = $25 + 8 | 0;
    $27 = HEAP16[$26 >> 1] | 0;
    $28 = $27 << 16 >> 16 == 0;
    if ($28) {
      label = 8;
      break;
    } else {
      label = 10;
      break;
    }
   case 8:
    $30 = $25 + 10 | 0;
    $31 = HEAP16[$30 >> 1] | 0;
    $32 = $31 << 16 >> 16 == 4;
    if ($32) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $34 = $11;
    $35 = $34 - $9 | 0;
    $36 = ($35 | 0) > 60;
    if ($36) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $37 = $11 - 4 | 0;
    $38 = $37 >>> 0 < $2 >>> 0;
    if ($38) {
      label = 12;
      break;
    } else {
      $11 = $37;
      label = 4;
      break;
    }
   case 11:
    $40 = HEAP32[$11 >> 2] | 0;
    $41 = $face + 92 | 0;
    HEAP32[$41 >> 2] = $40;
    $_0 = 0;
    label = 18;
    break;
   case 12:
    $42 = HEAP32[$5 >> 2] | 0;
    $_sum27 = $42 - 1 | 0;
    $43 = ($_sum27 | 0) < 0;
    if ($43) {
      $_0 = 38;
      label = 18;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $44 = $2 + ($_sum27 << 2) | 0;
    $45 = $2;
    $47 = $44;
    label = 14;
    break;
   case 14:
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $48 + 4 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = ($50 | 0) == 1970170211;
    if ($51) {
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 15:
    $53 = $47;
    $54 = $53 - $45 | 0;
    $55 = ($54 | 0) > 60;
    if ($55) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    $56 = $47 - 4 | 0;
    $57 = $56 >>> 0 < $2 >>> 0;
    if ($57) {
      $_0 = 38;
      label = 18;
      break;
    } else {
      $47 = $56;
      label = 14;
      break;
    }
   case 17:
    $59 = $face + 92 | 0;
    HEAP32[$59 >> 2] = $48;
    $_0 = 0;
    label = 18;
    break;
   case 18:
    return $_0 | 0;
  }
  return 0;
}
function _FT_Done_Size($size) {
  $size = $size | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($size | 0) == 0;
    if ($1) {
      $_0 = 36;
      label = 9;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $size | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $_0 = 35;
      label = 9;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $4 + 96 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      $_0 = 34;
      label = 9;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $11 = $8 + 8 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $4 + 108 | 0;
    $14 = $size;
    $15 = _FT_List_Find($13, $14) | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      $_0 = 36;
      label = 9;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    _FT_List_Remove($13, $15);
    $18 = $15;
    _ft_mem_free($12, $18);
    $19 = $4 + 88 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = ($20 | 0) == ($size | 0);
    if ($21) {
      label = 6;
      break;
    } else {
      label = 8;
      break;
    }
   case 6:
    HEAP32[$19 >> 2] = 0;
    $23 = $13 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $27 = $24 + 8 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $28;
    HEAP32[$19 >> 2] = $29;
    label = 8;
    break;
   case 8:
    _destroy_size($12, $size, $8);
    $_0 = 0;
    label = 9;
    break;
   case 9:
    return $_0 | 0;
  }
  return 0;
}
function _destroy_size($memory, $size, $driver) {
  $memory = $memory | 0;
  $size = $size | 0;
  $driver = $driver | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $size;
    FUNCTION_TABLE_vi[$2 & 1023]($5);
    label = 3;
    break;
   case 3:
    $7 = $driver + 20 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 + 60 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    FUNCTION_TABLE_vi[$10 & 1023]($size);
    label = 5;
    break;
   case 5:
    $14 = $size + 40 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15;
    _ft_mem_free($memory, $16);
    HEAP32[$14 >> 2] = 0;
    $17 = $size;
    _ft_mem_free($memory, $17);
    return;
  }
}
function _FT_Select_Metrics($face, $strike_index) {
  $face = $face | 0;
  $strike_index = $strike_index | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 88 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 12 | 0;
    $4 = $face + 32 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 + ($strike_index << 4) + 8 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 + 32 | 0;
    $9 = $8 >>> 6;
    $10 = $9 & 65535;
    $11 = $3 | 0;
    HEAP16[$11 >> 1] = $10;
    $12 = $5 + ($strike_index << 4) + 12 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 + 32 | 0;
    $15 = $14 >>> 6;
    $16 = $15 & 65535;
    $17 = $2 + 14 | 0;
    HEAP16[$17 >> 1] = $16;
    $18 = $face + 8 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $19 & 1;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $23 = HEAP32[$6 >> 2] | 0;
    $24 = $face + 68 | 0;
    $25 = HEAP16[$24 >> 1] | 0;
    $26 = $25 & 65535;
    $27 = _FT_DivFix($23, $26) | 0;
    $28 = $2 + 16 | 0;
    HEAP32[$28 >> 2] = $27;
    $29 = HEAP32[$12 >> 2] | 0;
    $30 = HEAP16[$24 >> 1] | 0;
    $31 = $30 & 65535;
    $32 = _FT_DivFix($29, $31) | 0;
    $33 = $2 + 20 | 0;
    HEAP32[$33 >> 2] = $32;
    _ft_recompute_scaled_metrics($face, $3);
    label = 4;
    break;
   case 3:
    $35 = $2 + 16 | 0;
    HEAP32[$35 >> 2] = 65536;
    $36 = $2 + 20 | 0;
    HEAP32[$36 >> 2] = 65536;
    $37 = HEAP32[$12 >> 2] | 0;
    $38 = $2 + 24 | 0;
    HEAP32[$38 >> 2] = $37;
    $39 = $2 + 28 | 0;
    HEAP32[$39 >> 2] = 0;
    $40 = $5 + ($strike_index << 4) | 0;
    $41 = HEAP16[$40 >> 1] | 0;
    $42 = $41 << 16 >> 16;
    $43 = $42 << 6;
    $44 = $2 + 32 | 0;
    HEAP32[$44 >> 2] = $43;
    $45 = HEAP32[$6 >> 2] | 0;
    $46 = $2 + 36 | 0;
    HEAP32[$46 >> 2] = $45;
    label = 4;
    break;
   case 4:
    return;
  }
}
function _ft_recompute_scaled_metrics($face, $metrics) {
  $face = $face | 0;
  $metrics = $metrics | 0;
  var $4 = 0;
  $4 = $metrics + 8 | 0;
  HEAP32[$metrics + 12 >> 2] = (_FT_MulFix(HEAP16[$face + 70 >> 1] << 16 >> 16, HEAP32[$4 >> 2] | 0) | 0) + 63 & -64;
  HEAP32[$metrics + 16 >> 2] = _FT_MulFix(HEAP16[$face + 72 >> 1] << 16 >> 16, HEAP32[$4 >> 2] | 0) & -64;
  HEAP32[$metrics + 20 >> 2] = (_FT_MulFix(HEAP16[$face + 74 >> 1] << 16 >> 16, HEAP32[$4 >> 2] | 0) | 0) + 32 & -64;
  HEAP32[$metrics + 24 >> 2] = (_FT_MulFix(HEAP16[$face + 76 >> 1] << 16 >> 16, HEAP32[$metrics + 4 >> 2] | 0) | 0) + 32 & -64;
  return;
}
function _FT_Request_Metrics($face, $req) {
  $face = $face | 0;
  $req = $req | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $56 = 0, $w_0 = 0, $h_0 = 0, $59 = 0, $60 = 0, $_w_0 = 0, $61 = 0, $62 = 0, $h_1 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $71 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $82 = 0, $84 = 0, $85 = 0, $86 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $98 = 0, $99 = 0, $103 = 0, $104 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $scaled_w_0_ph = 0, $scaled_h_0_ph = 0, $_pr = 0, $111 = 0, $scaled_w_0 = 0, $scaled_h_0 = 0, $112 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $scaled_w_1 = 0, $scaled_h_1 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $133 = 0, $134 = 0, $135 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 88 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 12 | 0;
    $4 = $face + 8 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 & 1;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 27;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = $req | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    if (($10 | 0) == 0) {
      label = 3;
      break;
    } else if (($10 | 0) == 1) {
      label = 4;
      break;
    } else if (($10 | 0) == 2) {
      label = 5;
      break;
    } else if (($10 | 0) == 3) {
      label = 6;
      break;
    } else if (($10 | 0) == 4) {
      label = 7;
      break;
    } else {
      $h_0 = 0;
      $w_0 = 0;
      label = 11;
      break;
    }
   case 3:
    $12 = $face + 68 | 0;
    $13 = HEAP16[$12 >> 1] | 0;
    $14 = $13 & 65535;
    $h_0 = $14;
    $w_0 = $14;
    label = 11;
    break;
   case 4:
    $16 = $face + 70 | 0;
    $17 = HEAP16[$16 >> 1] | 0;
    $18 = $17 << 16 >> 16;
    $19 = $face + 72 | 0;
    $20 = HEAP16[$19 >> 1] | 0;
    $21 = $20 << 16 >> 16;
    $22 = $18 - $21 | 0;
    $h_0 = $22;
    $w_0 = $22;
    label = 11;
    break;
   case 5:
    $24 = $face + 60 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $face + 52 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $25 - $27 | 0;
    $29 = $face + 64 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $face + 56 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $30 - $32 | 0;
    $h_0 = $33;
    $w_0 = $28;
    label = 11;
    break;
   case 6:
    $35 = $face + 76 | 0;
    $36 = HEAP16[$35 >> 1] | 0;
    $37 = $36 << 16 >> 16;
    $38 = $face + 70 | 0;
    $39 = HEAP16[$38 >> 1] | 0;
    $40 = $39 << 16 >> 16;
    $41 = $face + 72 | 0;
    $42 = HEAP16[$41 >> 1] | 0;
    $43 = $42 << 16 >> 16;
    $44 = $40 - $43 | 0;
    $h_0 = $44;
    $w_0 = $37;
    label = 11;
    break;
   case 7:
    $46 = $req + 4 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $2 + 16 | 0;
    HEAP32[$48 >> 2] = $47;
    $49 = $req + 8 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $2 + 20 | 0;
    HEAP32[$51 >> 2] = $50;
    $52 = HEAP32[$48 >> 2] | 0;
    $53 = ($52 | 0) == 0;
    if ($53) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    HEAP32[$48 >> 2] = $50;
    $scaled_h_0_ph = 0;
    $scaled_w_0_ph = 0;
    label = 23;
    break;
   case 9:
    $56 = ($50 | 0) == 0;
    if ($56) {
      label = 10;
      break;
    } else {
      $scaled_h_0_ph = 0;
      $scaled_w_0_ph = 0;
      label = 23;
      break;
    }
   case 10:
    HEAP32[$51 >> 2] = $52;
    $scaled_h_0_ph = 0;
    $scaled_w_0_ph = 0;
    label = 23;
    break;
   case 11:
    $59 = ($w_0 | 0) < 0;
    $60 = -$w_0 | 0;
    $_w_0 = $59 ? $60 : $w_0;
    $61 = ($h_0 | 0) < 0;
    $62 = -$h_0 | 0;
    $h_1 = $61 ? $62 : $h_0;
    $63 = $req + 12 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = ($64 | 0) == 0;
    $66 = $req + 4 | 0;
    $67 = HEAP32[$66 >> 2] | 0;
    if ($65) {
      $73 = $67;
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $69 = Math_imul($67, $64);
    $70 = $69 + 36 | 0;
    $71 = ($70 | 0) / 72 & -1;
    $73 = $71;
    label = 13;
    break;
   case 13:
    $74 = $req + 16 | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    $76 = ($75 | 0) == 0;
    $77 = $req + 8 | 0;
    $78 = HEAP32[$77 >> 2] | 0;
    if ($76) {
      $84 = $78;
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $80 = Math_imul($78, $75);
    $81 = $80 + 36 | 0;
    $82 = ($81 | 0) / 72 & -1;
    $84 = $82;
    label = 15;
    break;
   case 15:
    $85 = HEAP32[$66 >> 2] | 0;
    $86 = ($85 | 0) == 0;
    if ($86) {
      label = 22;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $88 = _FT_DivFix($73, $_w_0) | 0;
    $89 = $2 + 16 | 0;
    HEAP32[$89 >> 2] = $88;
    $90 = HEAP32[$77 >> 2] | 0;
    $91 = ($90 | 0) == 0;
    if ($91) {
      label = 21;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $93 = _FT_DivFix($84, $h_1) | 0;
    $94 = $2 + 20 | 0;
    HEAP32[$94 >> 2] = $93;
    $95 = HEAP32[$9 >> 2] | 0;
    $96 = ($95 | 0) == 3;
    if ($96) {
      label = 18;
      break;
    } else {
      $scaled_h_0 = $84;
      $scaled_w_0 = $73;
      $111 = $95;
      label = 24;
      break;
    }
   case 18:
    $98 = HEAP32[$89 >> 2] | 0;
    $99 = ($93 | 0) > ($98 | 0);
    if ($99) {
      label = 19;
      break;
    } else {
      label = 20;
      break;
    }
   case 19:
    HEAP32[$94 >> 2] = $98;
    $scaled_h_0_ph = $84;
    $scaled_w_0_ph = $73;
    label = 23;
    break;
   case 20:
    HEAP32[$89 >> 2] = $93;
    $scaled_h_0_ph = $84;
    $scaled_w_0_ph = $73;
    label = 23;
    break;
   case 21:
    $103 = $2 + 20 | 0;
    HEAP32[$103 >> 2] = $88;
    $104 = _FT_MulDiv($73, $h_1, $_w_0) | 0;
    $scaled_h_0_ph = $104;
    $scaled_w_0_ph = $73;
    label = 23;
    break;
   case 22:
    $106 = _FT_DivFix($84, $h_1) | 0;
    $107 = $2 + 20 | 0;
    HEAP32[$107 >> 2] = $106;
    $108 = $2 + 16 | 0;
    HEAP32[$108 >> 2] = $106;
    $109 = _FT_MulDiv($84, $_w_0, $h_1) | 0;
    $scaled_h_0_ph = $84;
    $scaled_w_0_ph = $109;
    label = 23;
    break;
   case 23:
    $_pr = HEAP32[$9 >> 2] | 0;
    $scaled_h_0 = $scaled_h_0_ph;
    $scaled_w_0 = $scaled_w_0_ph;
    $111 = $_pr;
    label = 24;
    break;
   case 24:
    $112 = ($111 | 0) == 0;
    if ($112) {
      $scaled_h_1 = $scaled_h_0;
      $scaled_w_1 = $scaled_w_0;
      label = 26;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $114 = $face + 68 | 0;
    $115 = HEAP16[$114 >> 1] | 0;
    $116 = $115 & 65535;
    $117 = $2 + 16 | 0;
    $118 = HEAP32[$117 >> 2] | 0;
    $119 = _FT_MulFix($116, $118) | 0;
    $120 = $2 + 20 | 0;
    $121 = HEAP32[$120 >> 2] | 0;
    $122 = _FT_MulFix($116, $121) | 0;
    $scaled_h_1 = $122;
    $scaled_w_1 = $119;
    label = 26;
    break;
   case 26:
    $124 = $scaled_w_1 + 32 | 0;
    $125 = $124 >>> 6;
    $126 = $125 & 65535;
    $127 = $3 | 0;
    HEAP16[$127 >> 1] = $126;
    $128 = $scaled_h_1 + 32 | 0;
    $129 = $128 >>> 6;
    $130 = $129 & 65535;
    $131 = $2 + 14 | 0;
    HEAP16[$131 >> 1] = $130;
    _ft_recompute_scaled_metrics($face, $3);
    label = 28;
    break;
   case 27:
    $133 = $3;
    _memset($133 | 0, 0, 28);
    $134 = $2 + 16 | 0;
    HEAP32[$134 >> 2] = 65536;
    $135 = $2 + 20 | 0;
    HEAP32[$135 >> 2] = 65536;
    label = 28;
    break;
   case 28:
    return;
  }
}
function _FT_Select_Size($face, $strike_index) {
  $face = $face | 0;
  $strike_index = $strike_index | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($face | 0) == 0;
    if ($1) {
      $_0 = 35;
      label = 8;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 8 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 & 2;
    $6 = ($5 | 0) == 0;
    if ($6) {
      $_0 = 35;
      label = 8;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $8 = ($strike_index | 0) < 0;
    if ($8) {
      $_0 = 6;
      label = 8;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $10 = $face + 28 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($11 | 0) > ($strike_index | 0);
    if ($12) {
      label = 5;
      break;
    } else {
      $_0 = 6;
      label = 8;
      break;
    }
   case 5:
    $14 = $face + 96 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15 + 20 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $17 + 100 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $22 = $face + 88 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = FUNCTION_TABLE_iii[$19 & 1023]($23, $strike_index) | 0;
    $_0 = $24;
    label = 8;
    break;
   case 7:
    _FT_Select_Metrics($face, $strike_index);
    $_0 = 0;
    label = 8;
    break;
   case 8:
    return $_0 | 0;
  }
  return 0;
}
function _FT_Request_Size($face, $req) {
  $face = $face | 0;
  $req = $req | 0;
  var $strike_index = 0, $1 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $strike_index = __stackBase__ | 0;
    $1 = ($face | 0) == 0;
    if ($1) {
      $_0 = 35;
      label = 12;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = ($req | 0) == 0;
    if ($3) {
      $_0 = 6;
      label = 12;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $5 = $req + 4 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) < 0;
    if ($7) {
      $_0 = 6;
      label = 12;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $9 = $req + 8 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($10 | 0) < 0;
    if ($11) {
      $_0 = 6;
      label = 12;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $13 = $req | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 >>> 0 > 4;
    if ($15) {
      $_0 = 6;
      label = 12;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $17 = $face + 96 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $18 + 20 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $20 + 96 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = ($22 | 0) == 0;
    if ($23) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $25 = $face + 88 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = FUNCTION_TABLE_iii[$22 & 1023]($26, $req) | 0;
    $_0 = $27;
    label = 12;
    break;
   case 8:
    $29 = $face + 8 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $30 & 3;
    $32 = ($31 | 0) == 2;
    if ($32) {
      label = 9;
      break;
    } else {
      label = 11;
      break;
    }
   case 9:
    $34 = _FT_Match_Size($face, $req, 0, $strike_index) | 0;
    $35 = ($34 | 0) == 0;
    if ($35) {
      label = 10;
      break;
    } else {
      $_0 = $34;
      label = 12;
      break;
    }
   case 10:
    $37 = HEAP32[$strike_index >> 2] | 0;
    $38 = _FT_Select_Size($face, $37) | 0;
    $_0 = $38;
    label = 12;
    break;
   case 11:
    _FT_Request_Metrics($face, $req);
    $_0 = 0;
    label = 12;
    break;
   case 12:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_Set_Char_Size($face, $char_width, $char_height, $horz_resolution, $vert_resolution) {
  $face = $face | 0;
  $char_width = $char_width | 0;
  $char_height = $char_height | 0;
  $horz_resolution = $horz_resolution | 0;
  $vert_resolution = $vert_resolution | 0;
  var $req = 0, $1 = 0, $3 = 0, $char_width_char_height = 0, $_018 = 0, $_016 = 0, $5 = 0, $7 = 0, $horz_resolution_vert_resolution = 0, $_014 = 0, $_0 = 0, $9 = 0, $__018 = 0, $10 = 0, $_117 = 0, $11 = 0, $__014 = 0, $__0 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 20 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $req = __stackBase__ | 0;
    $1 = ($char_width | 0) == 0;
    if ($1) {
      $_016 = $char_height;
      $_018 = $char_height;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = ($char_height | 0) == 0;
    $char_width_char_height = $3 ? $char_width : $char_height;
    $_016 = $char_width_char_height;
    $_018 = $char_width;
    label = 3;
    break;
   case 3:
    $5 = ($horz_resolution | 0) == 0;
    if ($5) {
      $_0 = $vert_resolution;
      $_014 = $vert_resolution;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $7 = ($vert_resolution | 0) == 0;
    $horz_resolution_vert_resolution = $7 ? $horz_resolution : $vert_resolution;
    $_0 = $horz_resolution_vert_resolution;
    $_014 = $horz_resolution;
    label = 5;
    break;
   case 5:
    $9 = ($_018 | 0) < 64;
    $__018 = $9 ? 64 : $_018;
    $10 = ($_016 | 0) < 64;
    $_117 = $10 ? 64 : $_016;
    $11 = ($_014 | 0) == 0;
    $__014 = $11 ? 72 : $_014;
    $__0 = $11 ? 72 : $_0;
    $12 = $req | 0;
    HEAP32[$12 >> 2] = 0;
    $13 = $req + 4 | 0;
    HEAP32[$13 >> 2] = $__018;
    $14 = $req + 8 | 0;
    HEAP32[$14 >> 2] = $_117;
    $15 = $req + 12 | 0;
    HEAP32[$15 >> 2] = $__014;
    $16 = $req + 16 | 0;
    HEAP32[$16 >> 2] = $__0;
    $17 = _FT_Request_Size($face, $req) | 0;
    STACKTOP = __stackBase__;
    return $17 | 0;
  }
  return 0;
}
function _FT_Select_Charmap($face, $encoding) {
  $face = $face | 0;
  $encoding = $encoding | 0;
  var $1 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $cur_015 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $28 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($face | 0) == 0;
    if ($1) {
      $_0 = 35;
      label = 10;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    if (($encoding | 0) == 1970170211) {
      label = 3;
      break;
    } else if (($encoding | 0) == 0) {
      $_0 = 6;
      label = 10;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $4 = _find_unicode_charmap($face) | 0;
    $_0 = $4;
    label = 10;
    break;
   case 4:
    $6 = $face + 40 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      $_0 = 38;
      label = 10;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $10 = $face + 36 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $7 + ($11 << 2) | 0;
    $13 = ($11 | 0) > 0;
    if ($13) {
      $cur_015 = $7;
      label = 6;
      break;
    } else {
      $_0 = 6;
      label = 10;
      break;
    }
   case 6:
    $14 = HEAP32[$cur_015 >> 2] | 0;
    $15 = $14 + 4 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($16 | 0) == ($encoding | 0);
    if ($17) {
      label = 7;
      break;
    } else {
      label = 9;
      break;
    }
   case 7:
    $19 = HEAP32[$6 >> 2] | 0;
    $20 = $cur_015;
    $21 = $19;
    $22 = $20 - $21 | 0;
    $23 = ($22 | 0) > 60;
    if ($23) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $25 = $face + 92 | 0;
    HEAP32[$25 >> 2] = $14;
    $_0 = 0;
    label = 10;
    break;
   case 9:
    $27 = $cur_015 + 4 | 0;
    $28 = $27 >>> 0 < $12 >>> 0;
    if ($28) {
      $cur_015 = $27;
      label = 6;
      break;
    } else {
      $_0 = 6;
      label = 10;
      break;
    }
   case 10:
    return $_0 | 0;
  }
  return 0;
}
function _FT_Set_Charmap($face, $charmap) {
  $face = $face | 0;
  $charmap = $charmap | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $cur_014 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0, $26 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($face | 0) == 0;
    if ($1) {
      $_0 = 35;
      label = 9;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 40 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $_0 = 38;
      label = 9;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = _FT_Get_CMap_Format($charmap) | 0;
    $8 = ($7 | 0) == 14;
    if ($8) {
      $_0 = 6;
      label = 9;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $10 = $face + 36 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $4 + ($11 << 2) | 0;
    $13 = ($11 | 0) > 0;
    if ($13) {
      $cur_014 = $4;
      label = 5;
      break;
    } else {
      $_0 = 6;
      label = 9;
      break;
    }
   case 5:
    $14 = HEAP32[$cur_014 >> 2] | 0;
    $15 = ($14 | 0) == ($charmap | 0);
    if ($15) {
      label = 6;
      break;
    } else {
      label = 8;
      break;
    }
   case 6:
    $17 = HEAP32[$3 >> 2] | 0;
    $18 = $cur_014;
    $19 = $17;
    $20 = $18 - $19 | 0;
    $21 = ($20 | 0) > 60;
    if ($21) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $23 = $face + 92 | 0;
    HEAP32[$23 >> 2] = $14;
    $_0 = 0;
    label = 9;
    break;
   case 8:
    $25 = $cur_014 + 4 | 0;
    $26 = $25 >>> 0 < $12 >>> 0;
    if ($26) {
      $cur_014 = $25;
      label = 5;
      break;
    } else {
      $_0 = 6;
      label = 9;
      break;
    }
   case 9:
    return $_0 | 0;
  }
  return 0;
}
function _FT_Activate_Size($size) {
  $size = $size | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($size | 0) == 0;
    if ($1) {
      $_0 = 6;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $size | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $_0 = 6;
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $4 + 96 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      $_0 = 6;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $11 = $4 + 88 | 0;
    HEAP32[$11 >> 2] = $size;
    $_0 = 0;
    label = 5;
    break;
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function _FT_Lookup_Renderer($library, $format, $node) {
  $library = $library | 0;
  $format = $format | 0;
  $node = $node | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $cur_0 = 0, $cur_1_ph = 0, $13 = 0, $cur_114 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $24 = 0, $25 = 0, $26 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($library | 0) == 0;
    if ($1) {
      $result_0 = 0;
      label = 11;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $library + 156 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($node | 0) != 0;
    if ($5) {
      label = 3;
      break;
    } else {
      $cur_1_ph = $4;
      label = 6;
      break;
    }
   case 3:
    $7 = HEAP32[$node >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      $cur_0 = $4;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $10 = $7 + 4 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $cur_0 = $11;
    label = 5;
    break;
   case 5:
    HEAP32[$node >> 2] = 0;
    $cur_1_ph = $cur_0;
    label = 6;
    break;
   case 6:
    $13 = ($cur_1_ph | 0) == 0;
    if ($13) {
      $result_0 = 0;
      label = 11;
      break;
    } else {
      $cur_114 = $cur_1_ph;
      label = 7;
      break;
    }
   case 7:
    $14 = $cur_114 + 8 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15;
    $17 = $15 + 24 | 0;
    $18 = $17;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = ($19 | 0) == ($format | 0);
    if ($20) {
      label = 8;
      break;
    } else {
      label = 10;
      break;
    }
   case 8:
    if ($5) {
      label = 9;
      break;
    } else {
      $result_0 = $16;
      label = 11;
      break;
    }
   case 9:
    HEAP32[$node >> 2] = $cur_114;
    $result_0 = $16;
    label = 11;
    break;
   case 10:
    $24 = $cur_114 + 4 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      $result_0 = 0;
      label = 11;
      break;
    } else {
      $cur_114 = $25;
      label = 7;
      break;
    }
   case 11:
    return $result_0 | 0;
  }
  return 0;
}
function _FT_List_Up($list, $node) {
  $list = $list | 0;
  $node = $node | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $node | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $node + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) == 0;
    if ($5) {
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $2 + 4 | 0;
    HEAP32[$7 >> 2] = $4;
    $8 = ($4 | 0) == 0;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $10 = $4 | 0;
    HEAP32[$10 >> 2] = $2;
    label = 5;
    break;
   case 4:
    $12 = $list + 4 | 0;
    HEAP32[$12 >> 2] = $2;
    label = 5;
    break;
   case 5:
    HEAP32[$1 >> 2] = 0;
    $14 = $list | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    HEAP32[$3 >> 2] = $15;
    $16 = HEAP32[$14 >> 2] | 0;
    $17 = $16 | 0;
    HEAP32[$17 >> 2] = $node;
    HEAP32[$14 >> 2] = $node;
    label = 6;
    break;
   case 6:
    return;
  }
}
function _FT_Get_CMap_Format($charmap) {
  $charmap = $charmap | 0;
  var $cmap_info = 0, $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $cmap_info = __stackBase__ | 0;
    $1 = ($charmap | 0) == 0;
    if ($1) {
      $_0 = -1;
      label = 7;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $charmap | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $_0 = -1;
      label = 7;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $4 + 96 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10 + 32 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      $_0 = -1;
      label = 7;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $15 = $8 | 0;
    $16 = FUNCTION_TABLE_iii[$12 & 1023]($15, 5321396) | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      $_0 = -1;
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $19 = $16;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = FUNCTION_TABLE_iii[$20 & 1023]($charmap, $cmap_info) | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 6;
      break;
    } else {
      $_0 = -1;
      label = 7;
      break;
    }
   case 6:
    $24 = $cmap_info + 4 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $_0 = $25;
    label = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _ft_cmap_done_internal($cmap) {
  $cmap = $cmap | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $13 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 12 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $cmap | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 100 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $2 + 8 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $11 = $8;
    FUNCTION_TABLE_vi[$11 & 1023]($cmap);
    label = 3;
    break;
   case 3:
    $13 = $cmap;
    _ft_mem_free($6, $13);
    return;
  }
}
function _FT_CMap_New($clazz, $init_data, $charmap, $acmap) {
  $clazz = $clazz | 0;
  $init_data = $init_data | 0;
  $charmap = $charmap | 0;
  $acmap = $acmap | 0;
  var $error = 0, $1 = 0, $2 = 0, $or_cond = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $cmap_0 = 0, $44 = 0, $47 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = ($clazz | 0) == 0;
    $2 = ($charmap | 0) == 0;
    $or_cond = $1 | $2;
    if ($or_cond) {
      $_0 = 6;
      label = 12;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $charmap | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      $_0 = 6;
      label = 12;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $8 = $5 + 100 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $clazz | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = _ft_mem_alloc($9, $11, $error) | 0;
    $13 = $12;
    $14 = HEAP32[$error >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 4;
      break;
    } else {
      $cmap_0 = $13;
      label = 8;
      break;
    }
   case 4:
    $17 = $charmap;
    _memcpy($12 | 0, $17 | 0, 12);
    $18 = $12 + 12 | 0;
    $19 = $18;
    HEAP32[$19 >> 2] = $clazz;
    $20 = $clazz + 4 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $24 = FUNCTION_TABLE_iii[$21 & 1023]($13, $init_data) | 0;
    HEAP32[$error >> 2] = $24;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 6;
      break;
    } else {
      label = 11;
      break;
    }
   case 6:
    $27 = $5 + 36 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $28 + 1 | 0;
    $30 = $5 + 40 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $31;
    $33 = _ft_mem_realloc($9, 4, $28, $29, $32, $error) | 0;
    $34 = $33;
    HEAP32[$30 >> 2] = $34;
    $35 = HEAP32[$error >> 2] | 0;
    $36 = ($35 | 0) == 0;
    if ($36) {
      label = 7;
      break;
    } else {
      label = 11;
      break;
    }
   case 7:
    $38 = $12;
    $39 = HEAP32[$27 >> 2] | 0;
    $40 = $39 + 1 | 0;
    HEAP32[$27 >> 2] = $40;
    $41 = HEAP32[$30 >> 2] | 0;
    $42 = $41 + ($39 << 2) | 0;
    HEAP32[$42 >> 2] = $38;
    $cmap_0 = $13;
    label = 8;
    break;
   case 8:
    $44 = ($acmap | 0) == 0;
    if ($44) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    HEAP32[$acmap >> 2] = $cmap_0;
    label = 10;
    break;
   case 10:
    $47 = HEAP32[$error >> 2] | 0;
    $_0 = $47;
    label = 12;
    break;
   case 11:
    _ft_cmap_done_internal($13);
    $cmap_0 = 0;
    label = 8;
    break;
   case 12:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_Get_Next_Char($face, $charcode, $agindex) {
  $face = $face | 0;
  $charcode = $charcode | 0;
  $agindex = $agindex | 0;
  var $code = 0, $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $gindex_0 = 0, $result_0 = 0, $27 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $code = __stackBase__ | 0;
    $1 = ($face | 0) == 0;
    if ($1) {
      $result_0 = 0;
      $gindex_0 = 0;
      label = 7;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 92 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $result_0 = 0;
      $gindex_0 = 0;
      label = 7;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $face + 16 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      $result_0 = 0;
      $gindex_0 = 0;
      label = 7;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    HEAP32[$code >> 2] = $charcode;
    $11 = HEAP32[$3 >> 2] | 0;
    $12 = $11;
    $13 = $11 + 12 | 0;
    $14 = $13;
    label = 5;
    break;
   case 5:
    $16 = HEAP32[$14 >> 2] | 0;
    $17 = $16 + 16 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = FUNCTION_TABLE_iii[$18 & 1023]($12, $code) | 0;
    $20 = HEAP32[$7 >> 2] | 0;
    $21 = $19 >>> 0 < $20 >>> 0;
    if ($21) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 6:
    $23 = ($19 | 0) == 0;
    $24 = HEAP32[$code >> 2] | 0;
    $25 = $23 ? 0 : $24;
    $result_0 = $25;
    $gindex_0 = $19;
    label = 7;
    break;
   case 7:
    $27 = ($agindex | 0) == 0;
    if ($27) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    HEAP32[$agindex >> 2] = $gindex_0;
    label = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return $result_0 | 0;
  }
  return 0;
}
function _FT_Set_Renderer($library, $renderer, $num_params, $parameters) {
  $library = $library | 0;
  $renderer = $renderer | 0;
  $num_params = $num_params | 0;
  $parameters = $parameters | 0;
  var $1 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $_018 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($library | 0) == 0;
    if ($1) {
      $_0 = 33;
      label = 10;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = ($renderer | 0) == 0;
    if ($3) {
      $_0 = 6;
      label = 10;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $5 = $library + 156 | 0;
    $6 = $renderer;
    $7 = _FT_List_Find($5, $6) | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      $_0 = 6;
      label = 10;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    _FT_List_Up($5, $7);
    $10 = $renderer + 24 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($11 | 0) == 1869968492;
    if ($12) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $14 = $library + 164 | 0;
    HEAP32[$14 >> 2] = $renderer;
    label = 6;
    break;
   case 6:
    $16 = ($num_params | 0) == 0;
    if ($16) {
      $_0 = 0;
      label = 10;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $18 = $renderer + 20 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $19 + 52 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $parameters | 0;
    $23 = $parameters + 4 | 0;
    $_018 = $num_params;
    label = 8;
    break;
   case 8:
    $25 = ($_018 | 0) == 0;
    if ($25) {
      $_0 = 0;
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $27 = HEAP32[$22 >> 2] | 0;
    $28 = HEAP32[$23 >> 2] | 0;
    $29 = FUNCTION_TABLE_iiii[$21 & 1023]($renderer, $27, $28) | 0;
    $30 = ($29 | 0) == 0;
    $31 = $_018 - 1 | 0;
    if ($30) {
      $_018 = $31;
      label = 8;
      break;
    } else {
      $_0 = $29;
      label = 10;
      break;
    }
   case 10:
    return $_0 | 0;
  }
  return 0;
}
function _FT_Render_Glyph_Internal($library, $slot, $render_mode) {
  $library = $library | 0;
  $slot = $slot | 0;
  $render_mode = $render_mode | 0;
  var $node = 0, $1 = 0, $2 = 0, $cond = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $renderer_1_ph = 0, $13 = 0, $update_027 = 0, $renderer_126 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $or_cond = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $brmerge = 0, $28 = 0, $error_2 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $node = __stackBase__ | 0;
    $1 = $slot + 72 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $cond = ($2 | 0) == 1651078259;
    if ($cond) {
      $error_2 = 0;
      label = 10;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    HEAP32[$node >> 2] = 0;
    $4 = HEAP32[$1 >> 2] | 0;
    $5 = ($4 | 0) == 1869968492;
    if ($5) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $7 = $library + 164 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $library + 156 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    HEAP32[$node >> 2] = $10;
    $renderer_1_ph = $8;
    label = 5;
    break;
   case 4:
    $12 = _FT_Lookup_Renderer($library, $4, $node) | 0;
    $renderer_1_ph = $12;
    label = 5;
    break;
   case 5:
    $13 = ($renderer_1_ph | 0) == 0;
    if ($13) {
      $error_2 = 7;
      label = 10;
      break;
    } else {
      $renderer_126 = $renderer_1_ph;
      $update_027 = 0;
      label = 6;
      break;
    }
   case 6:
    $14 = $renderer_126 + 68 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = FUNCTION_TABLE_iiiii[$15 & 1023]($renderer_126, $slot, $render_mode, 0) | 0;
    $17 = ($16 | 0) != 0;
    $18 = $16 & 255;
    $19 = ($18 | 0) == 19;
    $or_cond = $17 & $19;
    if ($or_cond) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $21 = HEAP32[$1 >> 2] | 0;
    $22 = _FT_Lookup_Renderer($library, $21, $node) | 0;
    $23 = ($22 | 0) == 0;
    if ($23) {
      $error_2 = $16;
      label = 10;
      break;
    } else {
      $renderer_126 = $22;
      $update_027 = 1;
      label = 6;
      break;
    }
   case 8:
    $25 = ($16 | 0) != 0;
    $26 = ($update_027 | 0) == 0;
    $brmerge = $25 | $26;
    if ($brmerge) {
      $error_2 = $16;
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $28 = _FT_Set_Renderer($library, $renderer_126, 0, 0) | 0;
    $error_2 = $16;
    label = 10;
    break;
   case 10:
    STACKTOP = __stackBase__;
    return $error_2 | 0;
  }
  return 0;
}
function _FT_Add_Module($library, $clazz) {
  $library = $library | 0;
  $clazz = $clazz | 0;
  var $error = 0, $1 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $nn_0 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $64 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $86 = 0, $87 = 0, $88 = 0, $90 = 0, $91 = 0, $93 = 0, $94 = 0, $95 = 0, $97 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $105 = 0, $106 = 0, $107 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = ($library | 0) == 0;
    if ($1) {
      $_0 = 33;
      label = 30;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = ($clazz | 0) == 0;
    if ($3) {
      $_0 = 6;
      label = 30;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $5 = $clazz + 16 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) > 131076;
    if ($7) {
      $_0 = 4;
      label = 30;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $8 = $library + 24 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $clazz + 8 | 0;
    $nn_0 = 0;
    label = 5;
    break;
   case 5:
    $12 = $nn_0 >>> 0 < $9 >>> 0;
    if ($12) {
      label = 6;
      break;
    } else {
      label = 9;
      break;
    }
   case 6:
    $14 = $library + 28 + ($nn_0 << 2) | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $17 + 8 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = HEAP32[$10 >> 2] | 0;
    $21 = _strcmp($19 | 0, $20 | 0) | 0;
    $22 = ($21 | 0) == 0;
    $23 = $nn_0 + 1 | 0;
    if ($22) {
      label = 7;
      break;
    } else {
      $nn_0 = $23;
      label = 5;
      break;
    }
   case 7:
    $25 = $clazz + 12 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $17 + 12 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = ($26 | 0) > ($28 | 0);
    if ($29) {
      label = 8;
      break;
    } else {
      $_0 = 5;
      label = 30;
      break;
    }
   case 8:
    $31 = _FT_Remove_Module($library, $15) | 0;
    label = 9;
    break;
   case 9:
    $32 = $library | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $34 = HEAP32[$8 >> 2] | 0;
    $35 = $34 >>> 0 > 31;
    if ($35) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    HEAP32[$error >> 2] = 48;
    label = 22;
    break;
   case 11:
    $38 = $clazz + 4 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = _ft_mem_alloc($33, $39, $error) | 0;
    $41 = $40;
    $42 = HEAP32[$error >> 2] | 0;
    $43 = ($42 | 0) == 0;
    if ($43) {
      label = 12;
      break;
    } else {
      label = 22;
      break;
    }
   case 12:
    $45 = $40 + 4 | 0;
    $46 = $45;
    HEAP32[$46 >> 2] = $library;
    $47 = $40 + 8 | 0;
    $48 = $47;
    HEAP32[$48 >> 2] = $33;
    $49 = $40;
    HEAP32[$49 >> 2] = $clazz;
    $50 = $clazz | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = $51 & 2;
    $53 = ($52 | 0) == 0;
    if ($53) {
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $55 = _ft_add_renderer($41) | 0;
    HEAP32[$error >> 2] = $55;
    $56 = ($55 | 0) == 0;
    if ($56) {
      label = 14;
      break;
    } else {
      label = 23;
      break;
    }
   case 14:
    $58 = HEAP32[$49 >> 2] | 0;
    $59 = $58 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = $60 & 4;
    $62 = ($61 | 0) == 0;
    if ($62) {
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $64 = $library + 168 | 0;
    HEAP32[$64 >> 2] = $41;
    label = 16;
    break;
   case 16:
    $66 = HEAP32[$49 >> 2] | 0;
    $67 = $66 | 0;
    $68 = HEAP32[$67 >> 2] | 0;
    $69 = $68 & 1;
    $70 = ($69 | 0) == 0;
    if ($70) {
      label = 19;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $72 = $66;
    $73 = $40 + 20 | 0;
    $74 = $73;
    HEAP32[$74 >> 2] = $72;
    $75 = HEAP32[$49 >> 2] | 0;
    $76 = $75 | 0;
    $77 = HEAP32[$76 >> 2] | 0;
    $78 = $77 & 512;
    $79 = ($78 | 0) == 0;
    if ($79) {
      label = 18;
      break;
    } else {
      label = 19;
      break;
    }
   case 18:
    $81 = $40 + 36 | 0;
    $82 = $81;
    $83 = _FT_GlyphLoader_New($33, $82) | 0;
    HEAP32[$error >> 2] = $83;
    $84 = ($83 | 0) == 0;
    if ($84) {
      label = 19;
      break;
    } else {
      label = 23;
      break;
    }
   case 19:
    $86 = $clazz + 24 | 0;
    $87 = HEAP32[$86 >> 2] | 0;
    $88 = ($87 | 0) == 0;
    if ($88) {
      label = 21;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $90 = FUNCTION_TABLE_ii[$87 & 1023]($41) | 0;
    HEAP32[$error >> 2] = $90;
    $91 = ($90 | 0) == 0;
    if ($91) {
      label = 21;
      break;
    } else {
      label = 23;
      break;
    }
   case 21:
    $93 = HEAP32[$8 >> 2] | 0;
    $94 = $93 + 1 | 0;
    HEAP32[$8 >> 2] = $94;
    $95 = $library + 28 + ($93 << 2) | 0;
    HEAP32[$95 >> 2] = $41;
    label = 22;
    break;
   case 22:
    $97 = HEAP32[$error >> 2] | 0;
    $_0 = $97;
    label = 30;
    break;
   case 23:
    $99 = HEAP32[$49 >> 2] | 0;
    $100 = $99 | 0;
    $101 = HEAP32[$100 >> 2] | 0;
    $102 = $101 & 513;
    $103 = ($102 | 0) == 1;
    if ($103) {
      label = 24;
      break;
    } else {
      label = 25;
      break;
    }
   case 24:
    $105 = $40 + 36 | 0;
    $106 = $105;
    $107 = HEAP32[$106 >> 2] | 0;
    _FT_GlyphLoader_Done($107);
    label = 25;
    break;
   case 25:
    $109 = HEAP32[$49 >> 2] | 0;
    $110 = $109 | 0;
    $111 = HEAP32[$110 >> 2] | 0;
    $112 = $111 & 2;
    $113 = ($112 | 0) == 0;
    if ($113) {
      label = 29;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $115 = $40 + 20 | 0;
    $116 = $115;
    $117 = HEAP32[$116 >> 2] | 0;
    $118 = $117 + 36 | 0;
    $119 = HEAP32[$118 >> 2] | 0;
    $120 = ($119 | 0) == 1869968492;
    if ($120) {
      label = 27;
      break;
    } else {
      label = 29;
      break;
    }
   case 27:
    $122 = $40 + 60 | 0;
    $123 = $122;
    $124 = HEAP32[$123 >> 2] | 0;
    $125 = ($124 | 0) == 0;
    if ($125) {
      label = 29;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $127 = $117 + 56 | 0;
    $128 = HEAP32[$127 >> 2] | 0;
    $129 = $128 + 20 | 0;
    $130 = HEAP32[$129 >> 2] | 0;
    FUNCTION_TABLE_vi[$130 & 1023]($124);
    label = 29;
    break;
   case 29:
    _ft_mem_free($33, $40);
    label = 22;
    break;
   case 30:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_Remove_Module($library, $module) {
  $library = $library | 0;
  $module = $module | 0;
  var $1 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $cur_0 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $_sum = 0, $18 = 0, $19 = 0, $cur_118 = 0, $20 = 0, $21 = 0, $22 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($library | 0) == 0;
    if ($1) {
      $_0 = 33;
      label = 9;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = ($module | 0) == 0;
    if ($3) {
      $_0 = 34;
      label = 9;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $5 = $library + 28 | 0;
    $6 = $library + 24 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $library + 28 + ($7 << 2) | 0;
    $cur_0 = $5;
    label = 4;
    break;
   case 4:
    $10 = $cur_0 >>> 0 < $8 >>> 0;
    if ($10) {
      label = 5;
      break;
    } else {
      $_0 = 34;
      label = 9;
      break;
    }
   case 5:
    $12 = HEAP32[$cur_0 >> 2] | 0;
    $13 = ($12 | 0) == ($module | 0);
    $14 = $cur_0 + 4 | 0;
    if ($13) {
      label = 6;
      break;
    } else {
      $cur_0 = $14;
      label = 4;
      break;
    }
   case 6:
    $16 = HEAP32[$6 >> 2] | 0;
    $17 = $16 - 1 | 0;
    HEAP32[$6 >> 2] = $17;
    $_sum = $7 - 1 | 0;
    $18 = $library + 28 + ($_sum << 2) | 0;
    $19 = $cur_0 >>> 0 < $18 >>> 0;
    if ($19) {
      $cur_118 = $cur_0;
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $20 = $cur_118 + 4 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    HEAP32[$cur_118 >> 2] = $21;
    $22 = $20 >>> 0 < $18 >>> 0;
    if ($22) {
      $cur_118 = $20;
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    HEAP32[$18 >> 2] = 0;
    _Destroy_Module($module);
    $_0 = 0;
    label = 9;
    break;
   case 9:
    return $_0 | 0;
  }
  return 0;
}
function _ft_add_renderer($module) {
  $module = $module | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $_c = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $_c20 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $_c21 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $_pr = 0, $46 = 0, $48 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $module + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = _ft_mem_alloc($4, 12, $error) | 0;
    $6 = $5;
    $7 = HEAP32[$error >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 8;
      break;
    }
   case 2:
    $10 = $module | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $module + 20 | 0;
    HEAP32[$12 >> 2] = $11;
    $13 = $11 + 36 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $module + 24 | 0;
    $_c = $14;
    HEAP32[$15 >> 2] = $_c;
    $16 = HEAP32[$13 >> 2] | 0;
    $17 = ($16 | 0) == 1869968492;
    if ($17) {
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 3:
    $19 = $11 + 56 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $20 + 4 | 0;
    $22 = $21;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = ($23 | 0) == 0;
    if ($24) {
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $26 = $4;
    $27 = $module + 60 | 0;
    $28 = $27;
    $29 = FUNCTION_TABLE_iii[$23 & 1023]($26, $28) | 0;
    HEAP32[$error >> 2] = $29;
    $30 = ($29 | 0) == 0;
    if ($30) {
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    $32 = HEAP32[$19 >> 2] | 0;
    $33 = $32 + 16 | 0;
    $34 = $33;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $module + 64 | 0;
    $_c20 = $35;
    HEAP32[$36 >> 2] = $_c20;
    $37 = $11 + 40 | 0;
    $38 = $37;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = $module + 68 | 0;
    $_c21 = $39;
    HEAP32[$40 >> 2] = $_c21;
    label = 6;
    break;
   case 6:
    $42 = $module;
    $43 = $5 + 8 | 0;
    $44 = $43;
    HEAP32[$44 >> 2] = $42;
    $45 = $2 + 156 | 0;
    _FT_List_Add($45, $6);
    _ft_set_current_renderer($2);
    $_pr = HEAP32[$error >> 2] | 0;
    $46 = ($_pr | 0) == 0;
    if ($46) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    _ft_mem_free($4, $5);
    label = 8;
    break;
   case 8:
    $48 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $48 | 0;
  }
  return 0;
}
function _FT_Get_Module($library, $module_name) {
  $library = $library | 0;
  $module_name = $module_name | 0;
  var $1 = 0, $2 = 0, $or_cond = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $cur_0 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($library | 0) == 0;
    $2 = ($module_name | 0) == 0;
    $or_cond = $1 | $2;
    if ($or_cond) {
      $_0 = 0;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $library + 28 | 0;
    $5 = $library + 24 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $library + 28 + ($6 << 2) | 0;
    $cur_0 = $4;
    label = 3;
    break;
   case 3:
    $9 = $cur_0 >>> 0 < $7 >>> 0;
    if ($9) {
      label = 4;
      break;
    } else {
      $_0 = 0;
      label = 5;
      break;
    }
   case 4:
    $11 = HEAP32[$cur_0 >> 2] | 0;
    $12 = $11 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 + 8 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = _strcmp($15 | 0, $module_name | 0) | 0;
    $17 = ($16 | 0) == 0;
    $18 = $cur_0 + 4 | 0;
    if ($17) {
      $_0 = $11;
      label = 5;
      break;
    } else {
      $cur_0 = $18;
      label = 3;
      break;
    }
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function _FT_Get_Module_Interface($library, $mod_name) {
  $library = $library | 0;
  $mod_name = $mod_name | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _FT_Get_Module($library, $mod_name) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      $9 = 0;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $1 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 + 20 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $9 = $7;
    label = 3;
    break;
   case 3:
    return $9 | 0;
  }
  return 0;
}
function _ft_module_get_service($module, $service_id) {
  $module = $module | 0;
  $service_id = $service_id | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $cur_018 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $result_3 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($module | 0) == 0;
    if ($1) {
      $result_3 = 0;
      label = 10;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $module | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 32 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = FUNCTION_TABLE_iii[$6 & 1023]($module, $service_id) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      $result_3 = $9;
      label = 10;
      break;
    }
   case 4:
    $11 = $module + 4 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + 24 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $12 + 28 + ($14 << 2) | 0;
    $16 = ($14 | 0) > 0;
    if ($16) {
      label = 5;
      break;
    } else {
      $result_3 = 0;
      label = 10;
      break;
    }
   case 5:
    $17 = $12 + 28 | 0;
    $cur_018 = $17;
    label = 6;
    break;
   case 6:
    $19 = HEAP32[$cur_018 >> 2] | 0;
    $20 = ($19 | 0) == ($module | 0);
    if ($20) {
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $22 = $19 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $23 + 32 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $28 = FUNCTION_TABLE_iii[$25 & 1023]($19, $service_id) | 0;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 9;
      break;
    } else {
      $result_3 = $28;
      label = 10;
      break;
    }
   case 9:
    $31 = $cur_018 + 4 | 0;
    $32 = $31 >>> 0 < $15 >>> 0;
    if ($32) {
      $cur_018 = $31;
      label = 6;
      break;
    } else {
      $result_3 = 0;
      label = 10;
      break;
    }
   case 10:
    return $result_3 | 0;
  }
  return 0;
}
function _Destroy_Module($module) {
  $module = $module | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $40 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $module + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $module | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $module + 4 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $module + 16 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $11 = $module;
    FUNCTION_TABLE_vi[$8 & 1023]($11);
    label = 3;
    break;
   case 3:
    $13 = ($6 | 0) == 0;
    if ($13) {
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $15 = $6 + 168 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($16 | 0) == ($module | 0);
    if ($17) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    HEAP32[$15 >> 2] = 0;
    label = 6;
    break;
   case 6:
    $20 = HEAP32[$3 >> 2] | 0;
    $21 = $20 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22 & 2;
    $24 = ($23 | 0) == 0;
    if ($24) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    _ft_remove_renderer($module);
    label = 8;
    break;
   case 8:
    $27 = HEAP32[$3 >> 2] | 0;
    $28 = $27 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $29 & 1;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $33 = $module;
    _Destroy_Driver($33);
    label = 10;
    break;
   case 10:
    $35 = $4 + 28 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = ($36 | 0) == 0;
    if ($37) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    FUNCTION_TABLE_vi[$36 & 1023]($module);
    label = 12;
    break;
   case 12:
    $40 = $module;
    _ft_mem_free($2, $40);
    return;
  }
}
function _FT_Outline_Get_CBox($outline, $acbox) {
  $outline = $outline | 0;
  $acbox = $acbox | 0;
  var $1 = 0, $2 = 0, $or_cond = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $vec_026 = 0, $vec_032 = 0, $xMin_031 = 0, $yMin_030 = 0, $xMax_029 = 0, $_pn28 = 0, $yMax_027 = 0, $18 = 0, $19 = 0, $20 = 0, $_xMin_0 = 0, $21 = 0, $xMax_1 = 0, $22 = 0, $23 = 0, $24 = 0, $_yMin_0 = 0, $25 = 0, $yMax_1 = 0, $vec_0 = 0, $26 = 0, $yMax_2 = 0, $xMax_2 = 0, $yMin_2 = 0, $xMin_2 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($outline | 0) == 0;
    $2 = ($acbox | 0) == 0;
    $or_cond = $1 | $2;
    if ($or_cond) {
      label = 7;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $outline + 2 | 0;
    $5 = HEAP16[$4 >> 1] | 0;
    $6 = $5 << 16 >> 16 == 0;
    if ($6) {
      $xMin_2 = 0;
      $yMin_2 = 0;
      $xMax_2 = 0;
      $yMax_2 = 0;
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $8 = $5 << 16 >> 16;
    $9 = $outline + 4 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10 + ($8 << 3) | 0;
    $12 = $10 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $10 + 4 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $5 << 16 >> 16 > 1;
    if ($16) {
      label = 4;
      break;
    } else {
      $xMin_2 = $13;
      $yMin_2 = $15;
      $xMax_2 = $13;
      $yMax_2 = $15;
      label = 6;
      break;
    }
   case 4:
    $vec_026 = $10 + 8 | 0;
    $yMax_027 = $15;
    $_pn28 = $10;
    $xMax_029 = $13;
    $yMin_030 = $15;
    $xMin_031 = $13;
    $vec_032 = $vec_026;
    label = 5;
    break;
   case 5:
    $18 = $vec_032 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = ($19 | 0) < ($xMin_031 | 0);
    $_xMin_0 = $20 ? $19 : $xMin_031;
    $21 = ($19 | 0) > ($xMax_029 | 0);
    $xMax_1 = $21 ? $19 : $xMax_029;
    $22 = $_pn28 + 12 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = ($23 | 0) < ($yMin_030 | 0);
    $_yMin_0 = $24 ? $23 : $yMin_030;
    $25 = ($23 | 0) > ($yMax_027 | 0);
    $yMax_1 = $25 ? $23 : $yMax_027;
    $vec_0 = $vec_032 + 8 | 0;
    $26 = $vec_0 >>> 0 < $11 >>> 0;
    if ($26) {
      $yMax_027 = $yMax_1;
      $_pn28 = $vec_032;
      $xMax_029 = $xMax_1;
      $yMin_030 = $_yMin_0;
      $xMin_031 = $_xMin_0;
      $vec_032 = $vec_0;
      label = 5;
      break;
    } else {
      $xMin_2 = $_xMin_0;
      $yMin_2 = $_yMin_0;
      $xMax_2 = $xMax_1;
      $yMax_2 = $yMax_1;
      label = 6;
      break;
    }
   case 6:
    $27 = $acbox | 0;
    HEAP32[$27 >> 2] = $xMin_2;
    $28 = $acbox + 8 | 0;
    HEAP32[$28 >> 2] = $xMax_2;
    $29 = $acbox + 4 | 0;
    HEAP32[$29 >> 2] = $yMin_2;
    $30 = $acbox + 12 | 0;
    HEAP32[$30 >> 2] = $yMax_2;
    label = 7;
    break;
   case 7:
    return;
  }
}
function _FT_New_Library($memory, $alibrary) {
  $memory = $memory | 0;
  $alibrary = $alibrary | 0;
  var $error = 0, $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = ($memory | 0) == 0;
    if ($1) {
      $_0 = 6;
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = _ft_mem_alloc($memory, 200, $error) | 0;
    $4 = $3;
    $5 = HEAP32[$error >> 2] | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      $_0 = $5;
      label = 6;
      break;
    }
   case 3:
    $8 = $3;
    HEAP32[$8 >> 2] = $memory;
    $9 = $3 + 176 | 0;
    $10 = $9;
    HEAP32[$10 >> 2] = 16384;
    $11 = _ft_mem_alloc($memory, 16384, $error) | 0;
    $12 = $3 + 172 | 0;
    $13 = $12;
    HEAP32[$13 >> 2] = $11;
    $14 = HEAP32[$error >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $17 = $3 + 12 | 0;
    $18 = $17;
    HEAP32[$18 >> 2] = 2;
    $19 = $3 + 16 | 0;
    $20 = $19;
    HEAP32[$20 >> 2] = 4;
    $21 = $3 + 20 | 0;
    $22 = $21;
    HEAP32[$22 >> 2] = 4;
    $23 = $3 + 196 | 0;
    $24 = $23;
    HEAP32[$24 >> 2] = 1;
    HEAP32[$alibrary >> 2] = $4;
    $_0 = 0;
    label = 6;
    break;
   case 5:
    _ft_mem_free($memory, $3);
    $26 = HEAP32[$error >> 2] | 0;
    $_0 = $26;
    label = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_Done_Library($library) {
  $library = $library | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $n_031 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $_0 = 0, $n_031_1 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($library | 0) == 0;
    if ($1) {
      $_0 = 33;
      label = 14;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $library + 196 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 - 1 | 0;
    HEAP32[$3 >> 2] = $5;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      $_0 = 0;
      label = 14;
      break;
    }
   case 3:
    $8 = $library | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $library + 8 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $14 = $library;
    FUNCTION_TABLE_vi[$11 & 1023]($14);
    label = 5;
    break;
   case 5:
    $15 = $library + 24 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 19;
      break;
    } else {
      $n_031 = 0;
      label = 6;
      break;
    }
   case 6:
    $19 = $library + 28 + ($n_031 << 2) | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $20 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22 + 8 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = _strcmp($24 | 0, 5320776) | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 7;
      break;
    } else {
      label = 10;
      break;
    }
   case 7:
    $28 = HEAP32[$21 >> 2] | 0;
    $29 = $28 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $30 & 1;
    $32 = ($31 | 0) == 0;
    if ($32) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $34 = $20 + 24 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = ($35 | 0) == 0;
    if ($36) {
      label = 10;
      break;
    } else {
      $37 = $35;
      label = 9;
      break;
    }
   case 9:
    $38 = $37 + 8 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = $39;
    $41 = _FT_Done_Face($40) | 0;
    $42 = HEAP32[$34 >> 2] | 0;
    $43 = ($42 | 0) == 0;
    if ($43) {
      label = 10;
      break;
    } else {
      $37 = $42;
      label = 9;
      break;
    }
   case 10:
    $44 = $n_031 + 1 | 0;
    $45 = HEAP32[$15 >> 2] | 0;
    $46 = $44 >>> 0 < $45 >>> 0;
    if ($46) {
      $n_031 = $44;
      label = 6;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $47 = ($45 | 0) == 0;
    if ($47) {
      label = 19;
      break;
    } else {
      $n_031_1 = 0;
      label = 15;
      break;
    }
   case 12:
    $49 = $48 - 1 | 0;
    $50 = $library + 28 + ($49 << 2) | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = _FT_Remove_Module($library, $51) | 0;
    $53 = HEAP32[$83 >> 2] | 0;
    $54 = ($53 | 0) == 0;
    if ($54) {
      label = 13;
      break;
    } else {
      $48 = $53;
      label = 12;
      break;
    }
   case 13:
    $55 = $library + 172 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    _ft_mem_free($9, $56);
    HEAP32[$55 >> 2] = 0;
    $57 = $library + 176 | 0;
    HEAP32[$57 >> 2] = 0;
    $58 = $library;
    _ft_mem_free($9, $58);
    $_0 = 0;
    label = 14;
    break;
   case 14:
    return $_0 | 0;
   case 15:
    $61 = $library + 28 + ($n_031_1 << 2) | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = $62 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = $64 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = $66 & 1;
    $68 = ($67 | 0) == 0;
    if ($68) {
      label = 18;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $70 = $62 + 24 | 0;
    $71 = HEAP32[$70 >> 2] | 0;
    $72 = ($71 | 0) == 0;
    if ($72) {
      label = 18;
      break;
    } else {
      $73 = $71;
      label = 17;
      break;
    }
   case 17:
    $74 = $73 + 8 | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    $76 = $75;
    $77 = _FT_Done_Face($76) | 0;
    $78 = HEAP32[$70 >> 2] | 0;
    $79 = ($78 | 0) == 0;
    if ($79) {
      label = 18;
      break;
    } else {
      $73 = $78;
      label = 17;
      break;
    }
   case 18:
    $80 = $n_031_1 + 1 | 0;
    $81 = HEAP32[$15 >> 2] | 0;
    $82 = $80 >>> 0 < $81 >>> 0;
    if ($82) {
      $n_031_1 = $80;
      label = 15;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $83 = $library + 24 | 0;
    $84 = HEAP32[$83 >> 2] | 0;
    $85 = ($84 | 0) == 0;
    if ($85) {
      label = 13;
      break;
    } else {
      $48 = $84;
      label = 12;
      break;
    }
  }
  return 0;
}
function _ft_stub_set_char_sizes($size, $width, $height, $horz_res, $vert_res) {
  $size = $size | 0;
  $width = $width | 0;
  $height = $height | 0;
  $horz_res = $horz_res | 0;
  $vert_res = $vert_res | 0;
  var $req = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $vert_res_horz_res = 0, $15 = 0, $_013 = 0, $16 = 0, $_vert_res_horz_res = 0, $__013 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 20 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $req = __stackBase__ | 0;
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 96 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 20 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + 96 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      $_0 = 0;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $11 = $req | 0;
    HEAP32[$11 >> 2] = 0;
    $12 = $req + 4 | 0;
    HEAP32[$12 >> 2] = $width;
    $13 = $req + 8 | 0;
    HEAP32[$13 >> 2] = $height;
    $14 = ($horz_res | 0) == 0;
    $vert_res_horz_res = $14 ? $vert_res : $horz_res;
    $15 = ($vert_res | 0) == 0;
    $_013 = $15 ? $vert_res_horz_res : $vert_res;
    $16 = ($vert_res_horz_res | 0) == 0;
    $_vert_res_horz_res = $16 ? 72 : $vert_res_horz_res;
    $__013 = $16 ? 72 : $_013;
    $17 = $req + 12 | 0;
    HEAP32[$17 >> 2] = $_vert_res_horz_res;
    $18 = $req + 16 | 0;
    HEAP32[$18 >> 2] = $__013;
    $19 = HEAP32[$5 >> 2] | 0;
    $20 = $19 + 96 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = FUNCTION_TABLE_iii[$21 & 1023]($size, $req) | 0;
    $_0 = $22;
    label = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _ft_stub_set_pixel_sizes($size, $width, $height) {
  $size = $size | 0;
  $width = $width | 0;
  $height = $height | 0;
  var $req = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 20 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $req = __stackBase__ | 0;
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 96 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 20 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + 96 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      $_0 = 0;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $11 = $req | 0;
    HEAP32[$11 >> 2] = 0;
    $12 = $width << 6;
    $13 = $req + 4 | 0;
    HEAP32[$13 >> 2] = $12;
    $14 = $height << 6;
    $15 = $req + 8 | 0;
    HEAP32[$15 >> 2] = $14;
    $16 = $req + 12 | 0;
    HEAP32[$16 >> 2] = 0;
    $17 = $req + 16 | 0;
    HEAP32[$17 >> 2] = 0;
    $18 = HEAP32[$5 >> 2] | 0;
    $19 = $18 + 96 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = FUNCTION_TABLE_iii[$20 & 1023]($size, $req) | 0;
    $_0 = $21;
    label = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_Outline_Decompose($outline, $func_interface, $user) {
  $outline = $outline | 0;
  $func_interface = $func_interface | 0;
  $user = $user | 0;
  var $v_control = 0, $v_start = 0, $vec = 0, $vec1 = 0, $v_middle = 0, $vec12 = 0, $vec2 = 0, $vec3 = 0, $1 = 0, $2 = 0, $or_cond = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $first_0134 = 0, $n_0133 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $ld$0$0 = 0, $52$0 = 0, $ld$1$1 = 0, $52$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $v_last_sroa_0_0__idx82 = 0, $v_last_sroa_0_0_copyload83 = 0, $v_last_sroa_1_4__idx88 = 0, $v_last_sroa_1_4_copyload89 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $ld$4$0 = 0, $64$0 = 0, $ld$5$1 = 0, $64$1 = 0, $st$6$0 = 0, $st$7$1 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $_sum119 = 0, $77 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $limit_0 = 0, $_sum = 0, $86 = 0, $_sum_pn = 0, $limit_1 = 0, $tags_0 = 0, $point_0 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $tags_1128 = 0, $point_1127 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $tags_2123 = 0, $point_2122 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $133 = 0, $134 = 0, $135 = 0, $point_1_be = 0, $tags_1_be = 0, $136 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $ld$8$0 = 0, $150$0 = 0, $ld$9$1 = 0, $150$1 = 0, $st$10$0 = 0, $st$11$1 = 0, $151 = 0, $152 = 0, $153 = 0, $155 = 0, $156 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $error_0 = 0, $200 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 64 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $v_control = __stackBase__ | 0;
    $v_start = __stackBase__ + 8 | 0;
    $vec = __stackBase__ + 16 | 0;
    $vec1 = __stackBase__ + 24 | 0;
    $v_middle = __stackBase__ + 32 | 0;
    $vec12 = __stackBase__ + 40 | 0;
    $vec2 = __stackBase__ + 48 | 0;
    $vec3 = __stackBase__ + 56 | 0;
    $1 = ($outline | 0) == 0;
    $2 = ($func_interface | 0) == 0;
    $or_cond = $1 | $2;
    if ($or_cond) {
      $_0 = 6;
      label = 29;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $func_interface + 16 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $func_interface + 20 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $outline | 0;
    $9 = HEAP16[$8 >> 1] | 0;
    $10 = $9 << 16 >> 16 > 0;
    if ($10) {
      label = 3;
      break;
    } else {
      $_0 = 0;
      label = 29;
      break;
    }
   case 3:
    $11 = $outline + 12 | 0;
    $12 = $outline + 4 | 0;
    $13 = $v_start;
    $14 = $v_start | 0;
    $15 = $v_start + 4 | 0;
    $16 = $v_control;
    $17 = $outline + 8 | 0;
    $18 = $func_interface | 0;
    $19 = $func_interface + 4 | 0;
    $20 = $vec12 | 0;
    $21 = $vec12 + 4 | 0;
    $22 = $vec2 | 0;
    $23 = $vec2 + 4 | 0;
    $24 = $vec3 | 0;
    $25 = $vec3 + 4 | 0;
    $26 = $func_interface + 12 | 0;
    $27 = $vec | 0;
    $28 = $vec + 4 | 0;
    $29 = $func_interface + 4 | 0;
    $30 = $v_control | 0;
    $31 = $v_control + 4 | 0;
    $32 = $vec1 | 0;
    $33 = $vec1 + 4 | 0;
    $34 = $v_middle | 0;
    $35 = $v_middle + 4 | 0;
    $36 = $func_interface + 8 | 0;
    $37 = $vec1;
    $38 = $func_interface + 8 | 0;
    $39 = $func_interface + 12 | 0;
    $40 = $func_interface + 8 | 0;
    $n_0133 = 0;
    $first_0134 = 0;
    label = 4;
    break;
   case 4:
    $42 = HEAP32[$11 >> 2] | 0;
    $43 = $42 + ($n_0133 << 1) | 0;
    $44 = HEAP16[$43 >> 1] | 0;
    $45 = $44 << 16 >> 16;
    $46 = $44 << 16 >> 16 < 0;
    if ($46) {
      $_0 = 20;
      label = 29;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $48 = HEAP32[$12 >> 2] | 0;
    $49 = $48 + ($45 << 3) | 0;
    $50 = $48 + ($first_0134 << 3) | 0;
    $51 = $50;
    $ld$0$0 = $51 | 0;
    $52$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $51 + 4 | 0;
    $52$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $13 | 0;
    HEAP32[$st$2$0 >> 2] = $52$0;
    $st$3$1 = $13 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $52$1;
    $53 = HEAP32[$14 >> 2] | 0;
    $54 = $53 << $5;
    $55 = $54 - $7 | 0;
    HEAP32[$14 >> 2] = $55;
    $56 = HEAP32[$15 >> 2] | 0;
    $57 = $56 << $5;
    $58 = $57 - $7 | 0;
    HEAP32[$15 >> 2] = $58;
    $59 = HEAP32[$12 >> 2] | 0;
    $v_last_sroa_0_0__idx82 = $59 + ($45 << 3) | 0;
    $v_last_sroa_0_0_copyload83 = HEAP32[$v_last_sroa_0_0__idx82 >> 2] | 0;
    $v_last_sroa_1_4__idx88 = $59 + ($45 << 3) + 4 | 0;
    $v_last_sroa_1_4_copyload89 = HEAP32[$v_last_sroa_1_4__idx88 >> 2] | 0;
    $60 = $v_last_sroa_0_0_copyload83 << $5;
    $61 = $60 - $7 | 0;
    $62 = $v_last_sroa_1_4_copyload89 << $5;
    $63 = $62 - $7 | 0;
    $ld$4$0 = $13 | 0;
    $64$0 = HEAP32[$ld$4$0 >> 2] | 0;
    $ld$5$1 = $13 + 4 | 0;
    $64$1 = HEAP32[$ld$5$1 >> 2] | 0;
    $st$6$0 = $16 | 0;
    HEAP32[$st$6$0 >> 2] = $64$0;
    $st$7$1 = $16 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $64$1;
    $65 = HEAP32[$12 >> 2] | 0;
    $66 = HEAP32[$17 >> 2] | 0;
    $67 = $66 + $first_0134 | 0;
    $68 = HEAP8[$67] | 0;
    $69 = $68 & 255;
    $70 = $69 & 3;
    if (($70 | 0) == 0) {
      label = 6;
      break;
    } else if (($70 | 0) == 2) {
      $_0 = 20;
      label = 29;
      break;
    } else {
      $tags_0 = $67;
      $limit_1 = $49;
      $_sum_pn = $first_0134;
      label = 10;
      break;
    }
   case 6:
    $72 = $66 + $45 | 0;
    $73 = HEAP8[$72] | 0;
    $74 = $73 & 3;
    $75 = $74 << 24 >> 24 == 1;
    if ($75) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    HEAP32[$14 >> 2] = $61;
    HEAP32[$15 >> 2] = $63;
    $_sum119 = $45 - 1 | 0;
    $77 = $48 + ($_sum119 << 3) | 0;
    $limit_0 = $77;
    label = 9;
    break;
   case 8:
    $79 = HEAP32[$14 >> 2] | 0;
    $80 = $79 + $61 | 0;
    $81 = ($80 | 0) / 2 & -1;
    HEAP32[$14 >> 2] = $81;
    $82 = HEAP32[$15 >> 2] | 0;
    $83 = $82 + $63 | 0;
    $84 = ($83 | 0) / 2 & -1;
    HEAP32[$15 >> 2] = $84;
    $limit_0 = $49;
    label = 9;
    break;
   case 9:
    $_sum = $first_0134 - 1 | 0;
    $86 = $66 + $_sum | 0;
    $tags_0 = $86;
    $limit_1 = $limit_0;
    $_sum_pn = $_sum;
    label = 10;
    break;
   case 10:
    $point_0 = $65 + ($_sum_pn << 3) | 0;
    $88 = HEAP32[$18 >> 2] | 0;
    $89 = FUNCTION_TABLE_iii[$88 & 1023]($v_start, $user) | 0;
    $90 = ($89 | 0) == 0;
    if ($90) {
      label = 11;
      break;
    } else {
      $_0 = $89;
      label = 29;
      break;
    }
   case 11:
    $91 = $point_0 >>> 0 < $limit_1 >>> 0;
    if ($91) {
      $point_1127 = $point_0;
      $tags_1128 = $tags_0;
      label = 12;
      break;
    } else {
      label = 26;
      break;
    }
   case 12:
    $92 = $point_1127 + 8 | 0;
    $93 = $tags_1128 + 1 | 0;
    $94 = HEAP8[$93] | 0;
    $95 = $94 & 255;
    $96 = $95 & 3;
    if (($96 | 0) == 1) {
      label = 13;
      break;
    } else if (($96 | 0) == 0) {
      label = 14;
      break;
    } else {
      label = 21;
      break;
    }
   case 13:
    $98 = $92 | 0;
    $99 = HEAP32[$98 >> 2] | 0;
    $100 = $99 << $5;
    $101 = $100 - $7 | 0;
    HEAP32[$27 >> 2] = $101;
    $102 = $point_1127 + 12 | 0;
    $103 = HEAP32[$102 >> 2] | 0;
    $104 = $103 << $5;
    $105 = $104 - $7 | 0;
    HEAP32[$28 >> 2] = $105;
    $106 = HEAP32[$29 >> 2] | 0;
    $107 = FUNCTION_TABLE_iii[$106 & 1023]($vec, $user) | 0;
    $108 = ($107 | 0) == 0;
    if ($108) {
      $tags_1_be = $93;
      $point_1_be = $92;
      label = 17;
      break;
    } else {
      $_0 = $107;
      label = 29;
      break;
    }
   case 14:
    $110 = $92 | 0;
    $111 = HEAP32[$110 >> 2] | 0;
    $112 = $111 << $5;
    $113 = $112 - $7 | 0;
    HEAP32[$30 >> 2] = $113;
    $114 = $point_1127 + 12 | 0;
    $115 = HEAP32[$114 >> 2] | 0;
    $116 = $115 << $5;
    $117 = $116 - $7 | 0;
    HEAP32[$31 >> 2] = $117;
    $118 = $92 >>> 0 < $limit_1 >>> 0;
    if ($118) {
      $point_2122 = $92;
      $tags_2123 = $93;
      label = 15;
      break;
    } else {
      label = 20;
      break;
    }
   case 15:
    $119 = $point_2122 + 8 | 0;
    $120 = $tags_2123 + 1 | 0;
    $121 = HEAP8[$120] | 0;
    $122 = $121 & 255;
    $123 = $122 & 3;
    $124 = $119 | 0;
    $125 = HEAP32[$124 >> 2] | 0;
    $126 = $125 << $5;
    $127 = $126 - $7 | 0;
    HEAP32[$32 >> 2] = $127;
    $128 = $point_2122 + 12 | 0;
    $129 = HEAP32[$128 >> 2] | 0;
    $130 = $129 << $5;
    $131 = $130 - $7 | 0;
    HEAP32[$33 >> 2] = $131;
    if (($123 | 0) == 1) {
      label = 16;
      break;
    } else if (($123 | 0) == 0) {
      label = 18;
      break;
    } else {
      $_0 = 20;
      label = 29;
      break;
    }
   case 16:
    $133 = HEAP32[$38 >> 2] | 0;
    $134 = FUNCTION_TABLE_iiii[$133 & 1023]($v_control, $vec1, $user) | 0;
    $135 = ($134 | 0) == 0;
    if ($135) {
      $tags_1_be = $120;
      $point_1_be = $119;
      label = 17;
      break;
    } else {
      $_0 = $134;
      label = 29;
      break;
    }
   case 17:
    $136 = $point_1_be >>> 0 < $limit_1 >>> 0;
    if ($136) {
      $point_1127 = $point_1_be;
      $tags_1128 = $tags_1_be;
      label = 12;
      break;
    } else {
      label = 26;
      break;
    }
   case 18:
    $138 = HEAP32[$30 >> 2] | 0;
    $139 = HEAP32[$32 >> 2] | 0;
    $140 = $139 + $138 | 0;
    $141 = ($140 | 0) / 2 & -1;
    HEAP32[$34 >> 2] = $141;
    $142 = HEAP32[$31 >> 2] | 0;
    $143 = HEAP32[$33 >> 2] | 0;
    $144 = $143 + $142 | 0;
    $145 = ($144 | 0) / 2 & -1;
    HEAP32[$35 >> 2] = $145;
    $146 = HEAP32[$36 >> 2] | 0;
    $147 = FUNCTION_TABLE_iiii[$146 & 1023]($v_control, $v_middle, $user) | 0;
    $148 = ($147 | 0) == 0;
    if ($148) {
      label = 19;
      break;
    } else {
      $_0 = $147;
      label = 29;
      break;
    }
   case 19:
    $ld$8$0 = $37 | 0;
    $150$0 = HEAP32[$ld$8$0 >> 2] | 0;
    $ld$9$1 = $37 + 4 | 0;
    $150$1 = HEAP32[$ld$9$1 >> 2] | 0;
    $st$10$0 = $16 | 0;
    HEAP32[$st$10$0 >> 2] = $150$0;
    $st$11$1 = $16 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $150$1;
    $151 = $119 >>> 0 < $limit_1 >>> 0;
    if ($151) {
      $point_2122 = $119;
      $tags_2123 = $120;
      label = 15;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $152 = HEAP32[$40 >> 2] | 0;
    $153 = FUNCTION_TABLE_iiii[$152 & 1023]($v_control, $v_start, $user) | 0;
    $error_0 = $153;
    label = 27;
    break;
   case 21:
    $155 = $point_1127 + 16 | 0;
    $156 = $155 >>> 0 > $limit_1 >>> 0;
    if ($156) {
      $_0 = 20;
      label = 29;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $158 = $tags_1128 + 2 | 0;
    $159 = HEAP8[$158] | 0;
    $160 = $159 & 3;
    $161 = $160 << 24 >> 24 == 2;
    if ($161) {
      label = 23;
      break;
    } else {
      $_0 = 20;
      label = 29;
      break;
    }
   case 23:
    $163 = $point_1127 + 24 | 0;
    $164 = $point_1127 + 8 | 0;
    $165 = HEAP32[$164 >> 2] | 0;
    $166 = $165 << $5;
    $167 = $166 - $7 | 0;
    HEAP32[$20 >> 2] = $167;
    $168 = $point_1127 + 12 | 0;
    $169 = HEAP32[$168 >> 2] | 0;
    $170 = $169 << $5;
    $171 = $170 - $7 | 0;
    HEAP32[$21 >> 2] = $171;
    $172 = $point_1127 + 16 | 0;
    $173 = HEAP32[$172 >> 2] | 0;
    $174 = $173 << $5;
    $175 = $174 - $7 | 0;
    HEAP32[$22 >> 2] = $175;
    $176 = $point_1127 + 20 | 0;
    $177 = HEAP32[$176 >> 2] | 0;
    $178 = $177 << $5;
    $179 = $178 - $7 | 0;
    HEAP32[$23 >> 2] = $179;
    $180 = $163 >>> 0 > $limit_1 >>> 0;
    if ($180) {
      label = 25;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $182 = $tags_1128 + 3 | 0;
    $183 = $163 | 0;
    $184 = HEAP32[$183 >> 2] | 0;
    $185 = $184 << $5;
    $186 = $185 - $7 | 0;
    HEAP32[$24 >> 2] = $186;
    $187 = $point_1127 + 28 | 0;
    $188 = HEAP32[$187 >> 2] | 0;
    $189 = $188 << $5;
    $190 = $189 - $7 | 0;
    HEAP32[$25 >> 2] = $190;
    $191 = HEAP32[$26 >> 2] | 0;
    $192 = FUNCTION_TABLE_iiiii[$191 & 1023]($vec12, $vec2, $vec3, $user) | 0;
    $193 = ($192 | 0) == 0;
    if ($193) {
      $tags_1_be = $182;
      $point_1_be = $163;
      label = 17;
      break;
    } else {
      $_0 = $192;
      label = 29;
      break;
    }
   case 25:
    $195 = HEAP32[$39 >> 2] | 0;
    $196 = FUNCTION_TABLE_iiiii[$195 & 1023]($vec12, $vec2, $v_start, $user) | 0;
    $error_0 = $196;
    label = 27;
    break;
   case 26:
    $197 = HEAP32[$19 >> 2] | 0;
    $198 = FUNCTION_TABLE_iii[$197 & 1023]($v_start, $user) | 0;
    $error_0 = $198;
    label = 27;
    break;
   case 27:
    $200 = ($error_0 | 0) == 0;
    if ($200) {
      label = 28;
      break;
    } else {
      $_0 = $error_0;
      label = 29;
      break;
    }
   case 28:
    $202 = $45 + 1 | 0;
    $203 = $n_0133 + 1 | 0;
    $204 = HEAP16[$8 >> 1] | 0;
    $205 = $204 << 16 >> 16;
    $206 = ($203 | 0) < ($205 | 0);
    if ($206) {
      $n_0133 = $203;
      $first_0134 = $202;
      label = 4;
      break;
    } else {
      $_0 = 0;
      label = 29;
      break;
    }
   case 29:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_Outline_Get_Orientation($outline) {
  $outline = $outline | 0;
  var $ray_y = 0, $result = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $xmin_0112 = 0, $first_0111 = 0, $contour_0110 = 0, $xmin_last_0109 = 0, $xmin_first_0108 = 0, $xmin_ymax_0107 = 0, $xmin_ymin_0106 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $contour_ymax_099 = 0, $contour_ymin_098 = 0, $contour_xmax_097 = 0, $contour_xmin_096 = 0, $point_095 = 0, $25 = 0, $26 = 0, $27 = 0, $_contour_xmin_0 = 0, $28 = 0, $contour_xmax_1 = 0, $29 = 0, $30 = 0, $31 = 0, $_contour_ymin_0 = 0, $32 = 0, $contour_ymax_1 = 0, $33 = 0, $34 = 0, $contour_ymax_0_lcssa = 0, $contour_ymin_0_lcssa = 0, $contour_xmax_0_lcssa = 0, $contour_xmin_0_lcssa = 0, $35 = 0, $36 = 0, $or_cond = 0, $37 = 0, $or_cond77 = 0, $xmin_ymin_0_contour_ymin_0 = 0, $xmin_ymax_0_contour_ymax_0 = 0, $xmin_first_0_first_0 = 0, $xmin_last_0_ = 0, $xmin_0_contour_xmin_0 = 0, $xmin_ymin_1 = 0, $xmin_ymax_1 = 0, $xmin_first_1 = 0, $xmin_last_1 = 0, $xmin_1 = 0, $39 = 0, $_sum = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $i_092 = 0, $56 = 0, $right2_088 = 0, $right1_087 = 0, $left2_086 = 0, $left1_085 = 0, $right_x_084 = 0, $left_x_083 = 0, $point_182 = 0, $prev_081 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $or_cond78 = 0, $73 = 0, $74 = 0, $or_cond80 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $_left_x_0 = 0, $prev_0_left1_0 = 0, $point_1_left2_0 = 0, $90 = 0, $_right_x_0 = 0, $prev_0_right1_0 = 0, $point_1_right2_0 = 0, $left_x_2 = 0, $right_x_1 = 0, $left1_2 = 0, $left2_2 = 0, $right1_1 = 0, $right2_1 = 0, $92 = 0, $prev_0_be = 0, $point_1_be = 0, $left_x_0_be = 0, $right_x_0_be = 0, $left1_0_be = 0, $left2_0_be = 0, $right1_0_be = 0, $right2_0_be = 0, $93 = 0, $94 = 0, $95 = 0, $or_cond79 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $109 = 0, $111 = 0, $112 = 0, $113 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $121 = 0, $123 = 0, $124 = 0, $exitcond = 0, $126 = 0, $127 = 0, $128 = 0, $130 = 0, $131 = 0, $132 = 0, $134 = 0, $135 = 0, $136 = 0, $138 = 0, $140 = 0, $141 = 0, $142 = 0, $144 = 0, $145 = 0, $146 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 24 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $ray_y = __stackBase__ | 0;
    $result = __stackBase__ + 12 | 0;
    $1 = $result;
    _memcpy($1 | 0, 5327104, 12);
    $2 = ($outline | 0) == 0;
    if ($2) {
      $_0 = 0;
      label = 38;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $outline + 2 | 0;
    $5 = HEAP16[$4 >> 1] | 0;
    $6 = $5 << 16 >> 16 < 1;
    if ($6) {
      $_0 = 0;
      label = 38;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $8 = $outline | 0;
    $9 = HEAP16[$8 >> 1] | 0;
    $10 = $9 << 16 >> 16 > 0;
    if ($10) {
      label = 4;
      break;
    } else {
      $_0 = 0;
      label = 38;
      break;
    }
   case 4:
    $11 = $outline + 12 | 0;
    $12 = $outline + 4 | 0;
    $13 = HEAP32[$11 >> 2] | 0;
    $14 = HEAP32[$12 >> 2] | 0;
    $15 = HEAP16[$8 >> 1] | 0;
    $16 = $15 << 16 >> 16;
    $17 = $13 + ($16 << 1) | 0;
    $xmin_ymin_0106 = 32768;
    $xmin_ymax_0107 = -32768;
    $xmin_first_0108 = 0;
    $xmin_last_0109 = 0;
    $contour_0110 = $13;
    $first_0111 = $14;
    $xmin_0112 = 32768;
    label = 5;
    break;
   case 5:
    $19 = HEAP16[$contour_0110 >> 1] | 0;
    $20 = $19 << 16 >> 16;
    $21 = $14 + ($20 << 3) | 0;
    $22 = $first_0111 + 16 | 0;
    $23 = $21 >>> 0 < $22 >>> 0;
    if ($23) {
      $xmin_1 = $xmin_0112;
      $xmin_last_1 = $xmin_last_0109;
      $xmin_first_1 = $xmin_first_0108;
      $xmin_ymax_1 = $xmin_ymax_0107;
      $xmin_ymin_1 = $xmin_ymin_0106;
      label = 9;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $24 = $first_0111 >>> 0 > $21 >>> 0;
    if ($24) {
      $contour_xmin_0_lcssa = 32768;
      $contour_xmax_0_lcssa = -32768;
      $contour_ymin_0_lcssa = 32768;
      $contour_ymax_0_lcssa = -32768;
      label = 8;
      break;
    } else {
      $point_095 = $first_0111;
      $contour_xmin_096 = 32768;
      $contour_xmax_097 = -32768;
      $contour_ymin_098 = 32768;
      $contour_ymax_099 = -32768;
      label = 7;
      break;
    }
   case 7:
    $25 = $point_095 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = ($26 | 0) < ($contour_xmin_096 | 0);
    $_contour_xmin_0 = $27 ? $26 : $contour_xmin_096;
    $28 = ($26 | 0) > ($contour_xmax_097 | 0);
    $contour_xmax_1 = $28 ? $26 : $contour_xmax_097;
    $29 = $point_095 + 4 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = ($30 | 0) < ($contour_ymin_098 | 0);
    $_contour_ymin_0 = $31 ? $30 : $contour_ymin_098;
    $32 = ($30 | 0) > ($contour_ymax_099 | 0);
    $contour_ymax_1 = $32 ? $30 : $contour_ymax_099;
    $33 = $point_095 + 8 | 0;
    $34 = $33 >>> 0 > $21 >>> 0;
    if ($34) {
      $contour_xmin_0_lcssa = $_contour_xmin_0;
      $contour_xmax_0_lcssa = $contour_xmax_1;
      $contour_ymin_0_lcssa = $_contour_ymin_0;
      $contour_ymax_0_lcssa = $contour_ymax_1;
      label = 8;
      break;
    } else {
      $point_095 = $33;
      $contour_xmin_096 = $_contour_xmin_0;
      $contour_xmax_097 = $contour_xmax_1;
      $contour_ymin_098 = $_contour_ymin_0;
      $contour_ymax_099 = $contour_ymax_1;
      label = 7;
      break;
    }
   case 8:
    $35 = ($contour_xmin_0_lcssa | 0) >= ($xmin_0112 | 0);
    $36 = ($contour_xmin_0_lcssa | 0) == ($contour_xmax_0_lcssa | 0);
    $or_cond = $35 | $36;
    $37 = ($contour_ymin_0_lcssa | 0) == ($contour_ymax_0_lcssa | 0);
    $or_cond77 = $or_cond | $37;
    $xmin_ymin_0_contour_ymin_0 = $or_cond77 ? $xmin_ymin_0106 : $contour_ymin_0_lcssa;
    $xmin_ymax_0_contour_ymax_0 = $or_cond77 ? $xmin_ymax_0107 : $contour_ymax_0_lcssa;
    $xmin_first_0_first_0 = $or_cond77 ? $xmin_first_0108 : $first_0111;
    $xmin_last_0_ = $or_cond77 ? $xmin_last_0109 : $21;
    $xmin_0_contour_xmin_0 = $or_cond77 ? $xmin_0112 : $contour_xmin_0_lcssa;
    $xmin_1 = $xmin_0_contour_xmin_0;
    $xmin_last_1 = $xmin_last_0_;
    $xmin_first_1 = $xmin_first_0_first_0;
    $xmin_ymax_1 = $xmin_ymax_0_contour_ymax_0;
    $xmin_ymin_1 = $xmin_ymin_0_contour_ymin_0;
    label = 9;
    break;
   case 9:
    $39 = $contour_0110 + 2 | 0;
    $_sum = $20 + 1 | 0;
    $40 = $14 + ($_sum << 3) | 0;
    $41 = $39 >>> 0 < $17 >>> 0;
    if ($41) {
      $xmin_ymin_0106 = $xmin_ymin_1;
      $xmin_ymax_0107 = $xmin_ymax_1;
      $xmin_first_0108 = $xmin_first_1;
      $xmin_last_0109 = $xmin_last_1;
      $contour_0110 = $39;
      $first_0111 = $40;
      $xmin_0112 = $xmin_1;
      label = 5;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $42 = ($xmin_1 | 0) == 32768;
    if ($42) {
      $_0 = 0;
      label = 38;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $44 = $xmin_ymin_1 * 3 & -1;
    $45 = $44 + $xmin_ymax_1 | 0;
    $46 = $45 >> 2;
    $47 = $ray_y | 0;
    HEAP32[$47 >> 2] = $46;
    $48 = $xmin_ymax_1 + $xmin_ymin_1 | 0;
    $49 = $48 >> 1;
    $50 = $ray_y + 4 | 0;
    HEAP32[$50 >> 2] = $49;
    $51 = $xmin_ymax_1 * 3 & -1;
    $52 = $51 + $xmin_ymin_1 | 0;
    $53 = $52 >> 2;
    $54 = $ray_y + 8 | 0;
    HEAP32[$54 >> 2] = $53;
    $55 = $xmin_first_1 >>> 0 > $xmin_last_1 >>> 0;
    $i_092 = 0;
    label = 12;
    break;
   case 12:
    if ($55) {
      label = 30;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $56 = $ray_y + ($i_092 << 2) | 0;
    $prev_081 = $xmin_last_1;
    $point_182 = $xmin_first_1;
    $left_x_083 = 32768;
    $right_x_084 = -32768;
    $left1_085 = 0;
    $left2_086 = 0;
    $right1_087 = 0;
    $right2_088 = 0;
    label = 14;
    break;
   case 14:
    $58 = $point_182 + 4 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = HEAP32[$56 >> 2] | 0;
    $61 = ($59 | 0) == ($60 | 0);
    if ($61) {
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $63 = $prev_081 + 4 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = ($64 | 0) == ($60 | 0);
    if ($65) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    $67 = HEAP32[$56 >> 2] | 0;
    $68 = $67 + 1 | 0;
    HEAP32[$56 >> 2] = $68;
    $right2_0_be = 0;
    $right1_0_be = 0;
    $left2_0_be = 0;
    $left1_0_be = 0;
    $right_x_0_be = -32768;
    $left_x_0_be = 32768;
    $point_1_be = $xmin_first_1;
    $prev_0_be = $xmin_last_1;
    label = 21;
    break;
   case 17:
    $70 = ($59 | 0) < ($60 | 0);
    $71 = ($64 | 0) < ($60 | 0);
    $or_cond78 = $70 & $71;
    if ($or_cond78) {
      $right2_1 = $right2_088;
      $right1_1 = $right1_087;
      $left2_2 = $left2_086;
      $left1_2 = $left1_085;
      $right_x_1 = $right_x_084;
      $left_x_2 = $left_x_083;
      label = 20;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $73 = ($59 | 0) > ($60 | 0);
    $74 = ($64 | 0) > ($60 | 0);
    $or_cond80 = $73 & $74;
    if ($or_cond80) {
      $right2_1 = $right2_088;
      $right1_1 = $right1_087;
      $left2_2 = $left2_086;
      $left1_2 = $left1_085;
      $right_x_1 = $right_x_084;
      $left_x_2 = $left_x_083;
      label = 20;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $76 = $point_182 | 0;
    $77 = HEAP32[$76 >> 2] | 0;
    $78 = $prev_081 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = $77 - $79 | 0;
    $81 = HEAP32[$56 >> 2] | 0;
    $82 = HEAP32[$63 >> 2] | 0;
    $83 = $81 - $82 | 0;
    $84 = HEAP32[$58 >> 2] | 0;
    $85 = $84 - $82 | 0;
    $86 = _FT_MulDiv($80, $83, $85) | 0;
    $87 = HEAP32[$78 >> 2] | 0;
    $88 = $87 + $86 | 0;
    $89 = ($88 | 0) < ($left_x_083 | 0);
    $_left_x_0 = $89 ? $88 : $left_x_083;
    $prev_0_left1_0 = $89 ? $prev_081 : $left1_085;
    $point_1_left2_0 = $89 ? $point_182 : $left2_086;
    $90 = ($88 | 0) > ($right_x_084 | 0);
    $_right_x_0 = $90 ? $88 : $right_x_084;
    $prev_0_right1_0 = $90 ? $prev_081 : $right1_087;
    $point_1_right2_0 = $90 ? $point_182 : $right2_088;
    $right2_1 = $point_1_right2_0;
    $right1_1 = $prev_0_right1_0;
    $left2_2 = $point_1_left2_0;
    $left1_2 = $prev_0_left1_0;
    $right_x_1 = $_right_x_0;
    $left_x_2 = $_left_x_0;
    label = 20;
    break;
   case 20:
    $92 = $point_182 + 8 | 0;
    $right2_0_be = $right2_1;
    $right1_0_be = $right1_1;
    $left2_0_be = $left2_2;
    $left1_0_be = $left1_2;
    $right_x_0_be = $right_x_1;
    $left_x_0_be = $left_x_2;
    $point_1_be = $92;
    $prev_0_be = $point_182;
    label = 21;
    break;
   case 21:
    $93 = $point_1_be >>> 0 > $xmin_last_1 >>> 0;
    if ($93) {
      label = 22;
      break;
    } else {
      $prev_081 = $prev_0_be;
      $point_182 = $point_1_be;
      $left_x_083 = $left_x_0_be;
      $right_x_084 = $right_x_0_be;
      $left1_085 = $left1_0_be;
      $left2_086 = $left2_0_be;
      $right1_087 = $right1_0_be;
      $right2_088 = $right2_0_be;
      label = 14;
      break;
    }
   case 22:
    $94 = ($left1_0_be | 0) == 0;
    $95 = ($right1_0_be | 0) == 0;
    $or_cond79 = $94 | $95;
    if ($or_cond79) {
      label = 30;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $97 = $left1_0_be + 4 | 0;
    $98 = HEAP32[$97 >> 2] | 0;
    $99 = $left2_0_be + 4 | 0;
    $100 = HEAP32[$99 >> 2] | 0;
    $101 = ($98 | 0) < ($100 | 0);
    if ($101) {
      label = 24;
      break;
    } else {
      label = 26;
      break;
    }
   case 24:
    $103 = $right1_0_be + 4 | 0;
    $104 = HEAP32[$103 >> 2] | 0;
    $105 = $right2_0_be + 4 | 0;
    $106 = HEAP32[$105 >> 2] | 0;
    $107 = ($104 | 0) > ($106 | 0);
    if ($107) {
      label = 25;
      break;
    } else {
      label = 26;
      break;
    }
   case 25:
    $109 = $result + ($i_092 << 2) | 0;
    HEAP32[$109 >> 2] = 0;
    label = 30;
    break;
   case 26:
    $111 = HEAP32[$97 >> 2] | 0;
    $112 = HEAP32[$99 >> 2] | 0;
    $113 = ($111 | 0) > ($112 | 0);
    if ($113) {
      label = 27;
      break;
    } else {
      label = 29;
      break;
    }
   case 27:
    $115 = $right1_0_be + 4 | 0;
    $116 = HEAP32[$115 >> 2] | 0;
    $117 = $right2_0_be + 4 | 0;
    $118 = HEAP32[$117 >> 2] | 0;
    $119 = ($116 | 0) < ($118 | 0);
    if ($119) {
      label = 28;
      break;
    } else {
      label = 29;
      break;
    }
   case 28:
    $121 = $result + ($i_092 << 2) | 0;
    HEAP32[$121 >> 2] = 1;
    label = 30;
    break;
   case 29:
    $123 = $result + ($i_092 << 2) | 0;
    HEAP32[$123 >> 2] = 2;
    label = 30;
    break;
   case 30:
    $124 = $i_092 + 1 | 0;
    $exitcond = ($124 | 0) == 3;
    if ($exitcond) {
      label = 31;
      break;
    } else {
      $i_092 = $124;
      label = 12;
      break;
    }
   case 31:
    $126 = $result | 0;
    $127 = HEAP32[$126 >> 2] | 0;
    $128 = ($127 | 0) == 2;
    if ($128) {
      label = 35;
      break;
    } else {
      label = 32;
      break;
    }
   case 32:
    $130 = $result + 4 | 0;
    $131 = HEAP32[$130 >> 2] | 0;
    $132 = ($127 | 0) == ($131 | 0);
    if ($132) {
      label = 34;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    $134 = $result + 8 | 0;
    $135 = HEAP32[$134 >> 2] | 0;
    $136 = ($127 | 0) == ($135 | 0);
    if ($136) {
      label = 34;
      break;
    } else {
      label = 35;
      break;
    }
   case 34:
    $138 = HEAP32[$126 >> 2] | 0;
    $_0 = $138;
    label = 38;
    break;
   case 35:
    $140 = $result + 4 | 0;
    $141 = HEAP32[$140 >> 2] | 0;
    $142 = ($141 | 0) == 2;
    if ($142) {
      label = 37;
      break;
    } else {
      label = 36;
      break;
    }
   case 36:
    $144 = $result + 8 | 0;
    $145 = HEAP32[$144 >> 2] | 0;
    $146 = ($141 | 0) == ($145 | 0);
    if ($146) {
      $_0 = $141;
      label = 38;
      break;
    } else {
      label = 37;
      break;
    }
   case 37:
    $_0 = 0;
    label = 38;
    break;
   case 38:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _ft_raccess_sort_ref_by_id($a, $b) {
  $a = $a | 0;
  $b = $b | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $_ = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $a | 0;
    $2 = HEAP16[$1 >> 1] | 0;
    $3 = $b | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = ($2 & 65535) < ($4 & 65535);
    if ($5) {
      $_0 = -1;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = ($2 & 65535) > ($4 & 65535);
    $_ = $7 & 1;
    $_0 = $_;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _FT_Stream_Pos($stream) {
  $stream = $stream | 0;
  return HEAP32[$stream + 8 >> 2] | 0;
}
function _FT_Stream_GetChar($stream) {
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $stream + 32 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $stream + 36 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 >>> 0 < $4 >>> 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $result_0 = 0;
      label = 3;
      break;
    }
   case 2:
    $7 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $7;
    $8 = HEAP8[$2] | 0;
    $result_0 = $8;
    label = 3;
    break;
   case 3:
    return $result_0 | 0;
  }
  return 0;
}
function _FT_Stream_GetShort($stream) {
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $p_0 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $stream + 32 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 1 | 0;
    $4 = $stream + 36 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $3 >>> 0 < $5 >>> 0;
    if ($6) {
      label = 2;
      break;
    } else {
      $result_0 = 0;
      $p_0 = $2;
      label = 3;
      break;
    }
   case 2:
    $8 = $2 + 2 | 0;
    $9 = HEAP8[$2] | 0;
    $10 = $9 & 255;
    $11 = $10 << 8;
    $12 = HEAP8[$3] | 0;
    $13 = $12 & 255;
    $14 = $11 | $13;
    $result_0 = $14;
    $p_0 = $8;
    label = 3;
    break;
   case 3:
    HEAP32[$1 >> 2] = $p_0;
    return $result_0 | 0;
  }
  return 0;
}
function _FT_Stream_GetShortLE($stream) {
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $p_0 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $stream + 32 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 1 | 0;
    $4 = $stream + 36 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $3 >>> 0 < $5 >>> 0;
    if ($6) {
      label = 2;
      break;
    } else {
      $result_0 = 0;
      $p_0 = $2;
      label = 3;
      break;
    }
   case 2:
    $8 = $2 + 2 | 0;
    $9 = HEAP8[$3] | 0;
    $10 = $9 & 255;
    $11 = $10 << 8;
    $12 = HEAP8[$2] | 0;
    $13 = $12 & 255;
    $14 = $11 | $13;
    $result_0 = $14;
    $p_0 = $8;
    label = 3;
    break;
   case 3:
    HEAP32[$1 >> 2] = $p_0;
    return $result_0 | 0;
  }
  return 0;
}
function _FT_Stream_GetLong($stream) {
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $p_0 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $stream + 32 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 3 | 0;
    $4 = $stream + 36 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $3 >>> 0 < $5 >>> 0;
    if ($6) {
      label = 2;
      break;
    } else {
      $result_0 = 0;
      $p_0 = $2;
      label = 3;
      break;
    }
   case 2:
    $8 = $2 + 4 | 0;
    $9 = HEAP8[$2] | 0;
    $10 = $9 & 255;
    $11 = $10 << 24;
    $12 = $2 + 1 | 0;
    $13 = HEAP8[$12] | 0;
    $14 = $13 & 255;
    $15 = $14 << 16;
    $16 = $15 | $11;
    $17 = $2 + 2 | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $18 & 255;
    $20 = $19 << 8;
    $21 = $16 | $20;
    $22 = HEAP8[$3] | 0;
    $23 = $22 & 255;
    $24 = $21 | $23;
    $result_0 = $24;
    $p_0 = $8;
    label = 3;
    break;
   case 3:
    HEAP32[$1 >> 2] = $p_0;
    return $result_0 | 0;
  }
  return 0;
}
function _FT_Stream_GetLongLE($stream) {
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $p_0 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $stream + 32 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 3 | 0;
    $4 = $stream + 36 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $3 >>> 0 < $5 >>> 0;
    if ($6) {
      label = 2;
      break;
    } else {
      $result_0 = 0;
      $p_0 = $2;
      label = 3;
      break;
    }
   case 2:
    $8 = $2 + 4 | 0;
    $9 = HEAP8[$3] | 0;
    $10 = $9 & 255;
    $11 = $10 << 24;
    $12 = $2 + 2 | 0;
    $13 = HEAP8[$12] | 0;
    $14 = $13 & 255;
    $15 = $14 << 16;
    $16 = $15 | $11;
    $17 = $2 + 1 | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $18 & 255;
    $20 = $19 << 8;
    $21 = $16 | $20;
    $22 = HEAP8[$2] | 0;
    $23 = $22 & 255;
    $24 = $21 | $23;
    $result_0 = $24;
    $p_0 = $8;
    label = 3;
    break;
   case 3:
    HEAP32[$1 >> 2] = $p_0;
    return $result_0 | 0;
  }
  return 0;
}
function _FT_Raccess_Get_HeaderInfo($library, $stream, $rfork_offset, $map_offset, $rdata_pos) {
  $library = $library | 0;
  $stream = $stream | 0;
  $rfork_offset = $rfork_offset | 0;
  $map_offset = $map_offset | 0;
  $rdata_pos = $rdata_pos | 0;
  var $error = 0, $head = 0, $head2 = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $or_cond = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $i_029 = 0, $allmatch_028 = 0, $allzeros_027 = 0, $77 = 0, $78 = 0, $79 = 0, $allzeros_0_ = 0, $80 = 0, $81 = 0, $82 = 0, $allmatch_1 = 0, $83 = 0, $exitcond = 0, $85 = 0, $86 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 36 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $head = __stackBase__ + 4 | 0;
    $head2 = __stackBase__ + 20 | 0;
    $1 = _FT_Stream_Seek($stream, $rfork_offset) | 0;
    HEAP32[$error >> 2] = $1;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $_0 = $1;
      label = 11;
      break;
    }
   case 2:
    $4 = $head | 0;
    $5 = _FT_Stream_Read($stream, $4, 16) | 0;
    HEAP32[$error >> 2] = $5;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      $_0 = $5;
      label = 11;
      break;
    }
   case 3:
    $8 = HEAP8[$4] | 0;
    $9 = $8 & 255;
    $10 = $9 << 24;
    $11 = $head + 1 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $12 & 255;
    $14 = $13 << 16;
    $15 = $14 | $10;
    $16 = $head + 2 | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 & 255;
    $19 = $18 << 8;
    $20 = $15 | $19;
    $21 = $head + 3 | 0;
    $22 = HEAP8[$21] | 0;
    $23 = $22 & 255;
    $24 = $20 | $23;
    $25 = $24 + $rfork_offset | 0;
    HEAP32[$rdata_pos >> 2] = $25;
    $26 = $head + 4 | 0;
    $27 = HEAP8[$26] | 0;
    $28 = $27 & 255;
    $29 = $28 << 24;
    $30 = $head + 5 | 0;
    $31 = HEAP8[$30] | 0;
    $32 = $31 & 255;
    $33 = $32 << 16;
    $34 = $33 | $29;
    $35 = $head + 6 | 0;
    $36 = HEAP8[$35] | 0;
    $37 = $36 & 255;
    $38 = $37 << 8;
    $39 = $34 | $38;
    $40 = $head + 7 | 0;
    $41 = HEAP8[$40] | 0;
    $42 = $41 & 255;
    $43 = $39 | $42;
    $44 = $43 + $rfork_offset | 0;
    $45 = $head + 8 | 0;
    $46 = HEAP8[$45] | 0;
    $47 = $46 & 255;
    $48 = $47 << 24;
    $49 = $head + 9 | 0;
    $50 = HEAP8[$49] | 0;
    $51 = $50 & 255;
    $52 = $51 << 16;
    $53 = $52 | $48;
    $54 = $head + 10 | 0;
    $55 = HEAP8[$54] | 0;
    $56 = $55 & 255;
    $57 = $56 << 8;
    $58 = $53 | $57;
    $59 = $head + 11 | 0;
    $60 = HEAP8[$59] | 0;
    $61 = $60 & 255;
    $62 = $58 | $61;
    $63 = $62 + $25 | 0;
    $64 = ($63 | 0) != ($44 | 0);
    $65 = ($43 | 0) == 0;
    $or_cond = $64 | $65;
    if ($or_cond) {
      $_0 = 2;
      label = 11;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $67 = _FT_Stream_Seek($stream, $44) | 0;
    HEAP32[$error >> 2] = $67;
    $68 = ($67 | 0) == 0;
    if ($68) {
      label = 5;
      break;
    } else {
      $_0 = $67;
      label = 11;
      break;
    }
   case 5:
    $70 = $head + 15 | 0;
    $71 = HEAP8[$70] | 0;
    $72 = $71 + 1 & 255;
    $73 = $head2 + 15 | 0;
    HEAP8[$73] = $72;
    $74 = $head2 | 0;
    $75 = _FT_Stream_Read($stream, $74, 16) | 0;
    HEAP32[$error >> 2] = $75;
    $76 = ($75 | 0) == 0;
    if ($76) {
      $allzeros_027 = 1;
      $allmatch_028 = 1;
      $i_029 = 0;
      label = 6;
      break;
    } else {
      $_0 = $75;
      label = 11;
      break;
    }
   case 6:
    $77 = $head2 + $i_029 | 0;
    $78 = HEAP8[$77] | 0;
    $79 = $78 << 24 >> 24 == 0;
    $allzeros_0_ = $79 ? $allzeros_027 : 0;
    $80 = $head + $i_029 | 0;
    $81 = HEAP8[$80] | 0;
    $82 = $78 << 24 >> 24 == $81 << 24 >> 24;
    $allmatch_1 = $82 ? $allmatch_028 : 0;
    $83 = $i_029 + 1 | 0;
    $exitcond = ($83 | 0) == 16;
    if ($exitcond) {
      label = 7;
      break;
    } else {
      $allzeros_027 = $allzeros_0_;
      $allmatch_028 = $allmatch_1;
      $i_029 = $83;
      label = 6;
      break;
    }
   case 7:
    $85 = $allmatch_1 | $allzeros_0_;
    $86 = ($85 | 0) == 0;
    if ($86) {
      $_0 = 2;
      label = 11;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $88 = _FT_Stream_Skip($stream, 8) | 0;
    HEAP32[$error >> 2] = $88;
    $89 = _FT_Stream_ReadShort($stream, $error) | 0;
    $90 = HEAP32[$error >> 2] | 0;
    $91 = ($90 | 0) == 0;
    if ($91) {
      label = 9;
      break;
    } else {
      $_0 = $90;
      label = 11;
      break;
    }
   case 9:
    $93 = $89 & 65535;
    $94 = $93 + $44 | 0;
    $95 = _FT_Stream_Seek($stream, $94) | 0;
    HEAP32[$error >> 2] = $95;
    $96 = ($95 | 0) == 0;
    if ($96) {
      label = 10;
      break;
    } else {
      $_0 = $95;
      label = 11;
      break;
    }
   case 10:
    HEAP32[$map_offset >> 2] = $94;
    $_0 = 0;
    label = 11;
    break;
   case 11:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_Stream_Read($stream, $buffer, $count) {
  $stream = $stream | 0;
  $buffer = $buffer | 0;
  $count = $count | 0;
  return _FT_Stream_ReadAt($stream, HEAP32[$stream + 8 >> 2] | 0, $buffer, $count) | 0;
}
function _FT_Stream_Skip($stream, $distance) {
  $stream = $stream | 0;
  $distance = $distance | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($distance | 0) < 0;
    if ($1) {
      $_0 = 85;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $stream + 8 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + $distance | 0;
    $6 = _FT_Stream_Seek($stream, $5) | 0;
    $_0 = $6;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _FT_Stream_ReadShort($stream, $error) {
  $stream = $stream | 0;
  $error = $error | 0;
  var $reads = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $p_014 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $result_0 = 0, $28 = 0, $29 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $reads = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $stream + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 1 | 0;
    $4 = $stream + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $3 >>> 0 < $5 >>> 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 7;
      break;
    }
   case 2:
    $8 = $stream + 20 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = $reads | 0;
    $13 = FUNCTION_TABLE_iiiii[$9 & 1023]($stream, $2, $12, 2) | 0;
    $14 = ($13 | 0) == 2;
    if ($14) {
      $p_014 = $12;
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 4:
    $16 = $stream | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $17 + $2 | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      $result_0 = 0;
      label = 6;
      break;
    } else {
      $p_014 = $18;
      label = 5;
      break;
    }
   case 5:
    $20 = HEAP8[$p_014] | 0;
    $21 = $20 & 255;
    $22 = $21 << 8;
    $23 = $p_014 + 1 | 0;
    $24 = HEAP8[$23] | 0;
    $25 = $24 & 255;
    $26 = $22 | $25;
    $result_0 = $26;
    label = 6;
    break;
   case 6:
    $28 = HEAP32[$1 >> 2] | 0;
    $29 = $28 + 2 | 0;
    HEAP32[$1 >> 2] = $29;
    $_0 = $result_0;
    label = 8;
    break;
   case 7:
    HEAP32[$error >> 2] = 85;
    $_0 = 0;
    label = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_Raccess_Get_DataOffsets($library, $stream, $map_offset, $rdata_pos, $tag, $offsets, $count) {
  $library = $library | 0;
  $stream = $stream | 0;
  $map_offset = $map_offset | 0;
  $rdata_pos = $rdata_pos | 0;
  $tag = $tag | 0;
  $offsets = $offsets | 0;
  $count = $count | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $i_0 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $j_043 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $_lcssa = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $j_140 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $library | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _FT_Stream_Seek($stream, $map_offset) | 0;
    HEAP32[$error >> 2] = $3;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 2;
      break;
    } else {
      $_0 = $3;
      label = 23;
      break;
    }
   case 2:
    $6 = _FT_Stream_ReadShort($stream, $error) | 0;
    $7 = HEAP32[$error >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 3;
      break;
    } else {
      $_0 = $7;
      label = 23;
      break;
    }
   case 3:
    $10 = $6 & 65535;
    $11 = $10 + 1 | 0;
    $i_0 = 0;
    label = 4;
    break;
   case 4:
    $13 = ($i_0 | 0) < ($11 | 0);
    if ($13) {
      label = 5;
      break;
    } else {
      $_0 = 1;
      label = 23;
      break;
    }
   case 5:
    $15 = _FT_Stream_ReadLong($stream, $error) | 0;
    $16 = HEAP32[$error >> 2] | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 6;
      break;
    } else {
      label = 8;
      break;
    }
   case 6:
    $19 = _FT_Stream_ReadShort($stream, $error) | 0;
    $20 = $19 & 65535;
    $21 = HEAP32[$error >> 2] | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $24 = _FT_Stream_ReadShort($stream, $error) | 0;
    $25 = HEAP32[$error >> 2] | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $28 = HEAP32[$error >> 2] | 0;
    $_0 = $28;
    label = 23;
    break;
   case 9:
    $30 = ($15 | 0) == ($tag | 0);
    $31 = $i_0 + 1 | 0;
    if ($30) {
      label = 10;
      break;
    } else {
      $i_0 = $31;
      label = 4;
      break;
    }
   case 10:
    $33 = $24 & 65535;
    $34 = $20 + 1 | 0;
    HEAP32[$count >> 2] = $34;
    $35 = $33 + $map_offset | 0;
    $36 = _FT_Stream_Seek($stream, $35) | 0;
    HEAP32[$error >> 2] = $36;
    $37 = ($36 | 0) == 0;
    if ($37) {
      label = 11;
      break;
    } else {
      $_0 = $36;
      label = 23;
      break;
    }
   case 11:
    $39 = HEAP32[$count >> 2] | 0;
    $40 = _ft_mem_realloc($2, 8, 0, $39, 0, $error) | 0;
    $41 = $40;
    $42 = HEAP32[$error >> 2] | 0;
    $43 = ($42 | 0) == 0;
    if ($43) {
      label = 12;
      break;
    } else {
      $_0 = $42;
      label = 23;
      break;
    }
   case 12:
    $44 = HEAP32[$count >> 2] | 0;
    $45 = ($44 | 0) > 0;
    if ($45) {
      $j_043 = 0;
      label = 13;
      break;
    } else {
      $_lcssa = $44;
      label = 18;
      break;
    }
   case 13:
    $46 = _FT_Stream_ReadShort($stream, $error) | 0;
    $47 = $41 + ($j_043 << 3) | 0;
    HEAP16[$47 >> 1] = $46;
    $48 = HEAP32[$error >> 2] | 0;
    $49 = ($48 | 0) == 0;
    if ($49) {
      label = 14;
      break;
    } else {
      label = 22;
      break;
    }
   case 14:
    $51 = _FT_Stream_Skip($stream, 2) | 0;
    HEAP32[$error >> 2] = $51;
    $52 = ($51 | 0) == 0;
    if ($52) {
      label = 15;
      break;
    } else {
      label = 22;
      break;
    }
   case 15:
    $54 = _FT_Stream_ReadLong($stream, $error) | 0;
    $55 = HEAP32[$error >> 2] | 0;
    $56 = ($55 | 0) == 0;
    if ($56) {
      label = 16;
      break;
    } else {
      label = 22;
      break;
    }
   case 16:
    $58 = _FT_Stream_Skip($stream, 4) | 0;
    HEAP32[$error >> 2] = $58;
    $59 = ($58 | 0) == 0;
    if ($59) {
      label = 17;
      break;
    } else {
      label = 22;
      break;
    }
   case 17:
    $61 = $54 & 16777215;
    $62 = $41 + ($j_043 << 3) + 4 | 0;
    HEAP32[$62 >> 2] = $61;
    $63 = $j_043 + 1 | 0;
    $64 = HEAP32[$count >> 2] | 0;
    $65 = ($63 | 0) < ($64 | 0);
    if ($65) {
      $j_043 = $63;
      label = 13;
      break;
    } else {
      $_lcssa = $64;
      label = 18;
      break;
    }
   case 18:
    _qsort($40 | 0, $_lcssa | 0, 8, 478);
    $66 = HEAP32[$count >> 2] | 0;
    $67 = _ft_mem_realloc($2, 4, 0, $66, 0, $error) | 0;
    $68 = $67;
    $69 = HEAP32[$error >> 2] | 0;
    $70 = ($69 | 0) == 0;
    if ($70) {
      label = 19;
      break;
    } else {
      label = 22;
      break;
    }
   case 19:
    $71 = HEAP32[$count >> 2] | 0;
    $72 = ($71 | 0) > 0;
    if ($72) {
      $j_140 = 0;
      label = 20;
      break;
    } else {
      label = 21;
      break;
    }
   case 20:
    $73 = $41 + ($j_140 << 3) + 4 | 0;
    $74 = HEAP32[$73 >> 2] | 0;
    $75 = $74 + $rdata_pos | 0;
    $76 = $68 + ($j_140 << 2) | 0;
    HEAP32[$76 >> 2] = $75;
    $77 = $j_140 + 1 | 0;
    $78 = HEAP32[$count >> 2] | 0;
    $79 = ($77 | 0) < ($78 | 0);
    if ($79) {
      $j_140 = $77;
      label = 20;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    HEAP32[$offsets >> 2] = $68;
    HEAP32[$error >> 2] = 0;
    label = 22;
    break;
   case 22:
    _ft_mem_free($2, $40);
    $80 = HEAP32[$error >> 2] | 0;
    $_0 = $80;
    label = 23;
    break;
   case 23:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_Stream_ReadLong($stream, $error) {
  $stream = $stream | 0;
  $error = $error | 0;
  var $reads = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $p_016 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $result_0 = 0, $38 = 0, $39 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $reads = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $stream + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 3 | 0;
    $4 = $stream + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $3 >>> 0 < $5 >>> 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 7;
      break;
    }
   case 2:
    $8 = $stream + 20 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = $reads | 0;
    $13 = FUNCTION_TABLE_iiiii[$9 & 1023]($stream, $2, $12, 4) | 0;
    $14 = ($13 | 0) == 4;
    if ($14) {
      $p_016 = $12;
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 4:
    $16 = $stream | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $17 + $2 | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      $result_0 = 0;
      label = 6;
      break;
    } else {
      $p_016 = $18;
      label = 5;
      break;
    }
   case 5:
    $20 = HEAP8[$p_016] | 0;
    $21 = $20 & 255;
    $22 = $21 << 24;
    $23 = $p_016 + 1 | 0;
    $24 = HEAP8[$23] | 0;
    $25 = $24 & 255;
    $26 = $25 << 16;
    $27 = $26 | $22;
    $28 = $p_016 + 2 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $29 & 255;
    $31 = $30 << 8;
    $32 = $27 | $31;
    $33 = $p_016 + 3 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $32 | $35;
    $result_0 = $36;
    label = 6;
    break;
   case 6:
    $38 = HEAP32[$1 >> 2] | 0;
    $39 = $38 + 4 | 0;
    HEAP32[$1 >> 2] = $39;
    $_0 = $result_0;
    label = 8;
    break;
   case 7:
    HEAP32[$error >> 2] = 85;
    $_0 = 0;
    label = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_Raccess_Guess($library, $stream, $base_name, $new_names, $offsets, $errors) {
  $library = $library | 0;
  $stream = $stream | 0;
  $base_name = $base_name | 0;
  $new_names = $new_names | 0;
  $offsets = $offsets | 0;
  $errors = $errors | 0;
  var $1 = 0, $i_021 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $exitcond = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($stream | 0) == 0;
    $i_021 = 0;
    label = 2;
    break;
   case 2:
    $3 = $new_names + ($i_021 << 2) | 0;
    HEAP32[$3 >> 2] = 0;
    if ($1) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $5 = _FT_Stream_Seek($stream, 0) | 0;
    $6 = $errors + ($i_021 << 2) | 0;
    HEAP32[$6 >> 2] = $5;
    label = 5;
    break;
   case 4:
    $8 = $errors + ($i_021 << 2) | 0;
    HEAP32[$8 >> 2] = 0;
    label = 5;
    break;
   case 5:
    $10 = $errors + ($i_021 << 2) | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $14 = 5249852 + ($i_021 << 3) | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $offsets + ($i_021 << 2) | 0;
    $17 = FUNCTION_TABLE_iiiiii[$15 & 1023]($library, $stream, $base_name, $3, $16) | 0;
    HEAP32[$10 >> 2] = $17;
    label = 7;
    break;
   case 7:
    $19 = $i_021 + 1 | 0;
    $exitcond = ($19 | 0) == 9;
    if ($exitcond) {
      label = 8;
      break;
    } else {
      $i_021 = $19;
      label = 2;
      break;
    }
   case 8:
    return;
  }
}
function _FT_Stream_ReadAt($stream, $pos, $buffer, $count) {
  $stream = $stream | 0;
  $pos = $pos | 0;
  $buffer = $buffer | 0;
  $count = $count | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $11 = 0, $12 = 0, $count_ = 0, $13 = 0, $14 = 0, $15 = 0, $read_bytes_1 = 0, $17 = 0, $18 = 0, $19 = 0, $_ = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $stream + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 >>> 0 > $pos >>> 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $_0 = 85;
      label = 6;
      break;
    }
   case 2:
    $5 = $stream + 20 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = FUNCTION_TABLE_iiiii[$6 & 1023]($stream, $pos, $buffer, $count) | 0;
    $read_bytes_1 = $9;
    label = 5;
    break;
   case 4:
    $11 = $2 - $pos | 0;
    $12 = $11 >>> 0 > $count >>> 0;
    $count_ = $12 ? $count : $11;
    $13 = $stream | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 + $pos | 0;
    _memcpy($buffer | 0, $15 | 0, $count_ | 0);
    $read_bytes_1 = $count_;
    label = 5;
    break;
   case 5:
    $17 = $read_bytes_1 + $pos | 0;
    $18 = $stream + 8 | 0;
    HEAP32[$18 >> 2] = $17;
    $19 = $read_bytes_1 >>> 0 < $count >>> 0;
    $_ = $19 ? 85 : 0;
    $_0 = $_;
    label = 6;
    break;
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _FT_Stream_TryRead($stream, $buffer, $count) {
  $stream = $stream | 0;
  $buffer = $buffer | 0;
  $count = $count | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $13 = 0, $14 = 0, $count_ = 0, $15 = 0, $16 = 0, $17 = 0, $read_bytes_1 = 0, $19 = 0, $20 = 0, $read_bytes_2 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $stream + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $stream + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 >>> 0 < $4 >>> 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $read_bytes_2 = 0;
      label = 6;
      break;
    }
   case 2:
    $7 = $stream + 20 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = FUNCTION_TABLE_iiiii[$8 & 1023]($stream, $2, $buffer, $count) | 0;
    $read_bytes_1 = $11;
    label = 5;
    break;
   case 4:
    $13 = $4 - $2 | 0;
    $14 = $13 >>> 0 > $count >>> 0;
    $count_ = $14 ? $count : $13;
    $15 = $stream | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $16 + $2 | 0;
    _memcpy($buffer | 0, $17 | 0, $count_ | 0);
    $read_bytes_1 = $count_;
    label = 5;
    break;
   case 5:
    $19 = HEAP32[$1 >> 2] | 0;
    $20 = $19 + $read_bytes_1 | 0;
    HEAP32[$1 >> 2] = $20;
    $read_bytes_2 = $read_bytes_1;
    label = 6;
    break;
   case 6:
    return $read_bytes_2 | 0;
  }
  return 0;
}
function _FT_Stream_ExtractFrame($stream, $count, $pbytes) {
  $stream = $stream | 0;
  $count = $count | 0;
  $pbytes = $pbytes | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _FT_Stream_EnterFrame($stream, $count) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $4 = $stream + 32 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    HEAP32[$pbytes >> 2] = $5;
    HEAP32[$4 >> 2] = 0;
    $6 = $stream + 36 | 0;
    HEAP32[$6 >> 2] = 0;
    label = 3;
    break;
   case 3:
    return $1 | 0;
  }
  return 0;
}
function _FT_Stream_EnterFrame($stream, $count) {
  $stream = $stream | 0;
  $count = $count | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $or_cond = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $_sum = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $stream + 20 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 8;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $stream + 28 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $stream + 4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 >>> 0 < $count >>> 0;
    if ($9) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    HEAP32[$error >> 2] = 85;
    label = 11;
    break;
   case 4:
    $12 = _ft_mem_qalloc($6, $count, $error) | 0;
    $13 = $stream | 0;
    HEAP32[$13 >> 2] = $12;
    $14 = HEAP32[$error >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 5;
      break;
    } else {
      label = 11;
      break;
    }
   case 5:
    $17 = HEAP32[$1 >> 2] | 0;
    $18 = $stream + 8 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = FUNCTION_TABLE_iiiii[$17 & 1023]($stream, $19, $12, $count) | 0;
    $21 = $20 >>> 0 < $count >>> 0;
    if ($21) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $23 = HEAP32[$13 >> 2] | 0;
    _ft_mem_free($6, $23);
    HEAP32[$13 >> 2] = 0;
    HEAP32[$error >> 2] = 85;
    label = 7;
    break;
   case 7:
    $25 = HEAP32[$13 >> 2] | 0;
    $26 = $stream + 32 | 0;
    HEAP32[$26 >> 2] = $25;
    $27 = $25 + $count | 0;
    $28 = $stream + 36 | 0;
    HEAP32[$28 >> 2] = $27;
    $29 = HEAP32[$18 >> 2] | 0;
    $30 = $29 + $20 | 0;
    HEAP32[$18 >> 2] = $30;
    label = 11;
    break;
   case 8:
    $32 = $stream + 8 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $stream + 4 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $33 >>> 0 >= $35 >>> 0;
    $37 = $35 - $33 | 0;
    $38 = $37 >>> 0 < $count >>> 0;
    $or_cond = $36 | $38;
    if ($or_cond) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    HEAP32[$error >> 2] = 85;
    label = 11;
    break;
   case 10:
    $41 = $stream | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = $42 + $33 | 0;
    $44 = $stream + 32 | 0;
    HEAP32[$44 >> 2] = $43;
    $_sum = $33 + $count | 0;
    $45 = $42 + $_sum | 0;
    $46 = $stream + 36 | 0;
    HEAP32[$46 >> 2] = $45;
    $47 = HEAP32[$32 >> 2] | 0;
    $48 = $47 + $count | 0;
    HEAP32[$32 >> 2] = $48;
    label = 11;
    break;
   case 11:
    $50 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $50 | 0;
  }
  return 0;
}
function _FT_Stream_ReleaseFrame($stream, $pbytes) {
  $stream = $stream | 0;
  $pbytes = $pbytes | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($stream | 0) == 0;
    if ($1) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $stream + 20 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $stream + 28 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = HEAP32[$pbytes >> 2] | 0;
    _ft_mem_free($8, $9);
    HEAP32[$pbytes >> 2] = 0;
    label = 4;
    break;
   case 4:
    HEAP32[$pbytes >> 2] = 0;
    return;
  }
}
function _ft_mem_qalloc($memory, $size, $p_error) {
  $memory = $memory | 0;
  $size = $size | 0;
  $p_error = $p_error | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_ = 0, $8 = 0, $9 = 0, $error_0 = 0, $block_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($size | 0) > 0;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = $memory + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = FUNCTION_TABLE_iii[$4 & 1023]($memory, $size) | 0;
    $6 = ($5 | 0) == 0;
    $_ = $6 ? 64 : 0;
    $block_0 = $5;
    $error_0 = $_;
    label = 4;
    break;
   case 3:
    $8 = $size >> 31;
    $9 = $8 & 6;
    $block_0 = 0;
    $error_0 = $9;
    label = 4;
    break;
   case 4:
    HEAP32[$p_error >> 2] = $error_0;
    return $block_0 | 0;
  }
  return 0;
}
function _FT_Stream_ExitFrame($stream) {
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $stream + 20 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $stream + 28 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $stream | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    _ft_mem_free($6, $8);
    HEAP32[$7 >> 2] = 0;
    label = 3;
    break;
   case 3:
    $10 = $stream + 32 | 0;
    HEAP32[$10 >> 2] = 0;
    $11 = $stream + 36 | 0;
    HEAP32[$11 >> 2] = 0;
    return;
  }
}
function _FT_Stream_ReadChar($stream, $error) {
  $stream = $stream | 0;
  $error = $error | 0;
  var $result = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $result = __stackBase__ | 0;
    HEAP8[$result] = 0;
    HEAP32[$error >> 2] = 0;
    $1 = $stream + 20 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    $4 = $stream + 8 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = FUNCTION_TABLE_iiiii[$2 & 1023]($stream, $5, $result, 1) | 0;
    $8 = ($7 | 0) == 1;
    if ($8) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 3:
    $10 = $stream + 4 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $5 >>> 0 < $11 >>> 0;
    if ($12) {
      label = 4;
      break;
    } else {
      label = 6;
      break;
    }
   case 4:
    $14 = $stream | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15 + $5 | 0;
    $17 = HEAP8[$16] | 0;
    HEAP8[$result] = $17;
    label = 5;
    break;
   case 5:
    $19 = HEAP32[$4 >> 2] | 0;
    $20 = $19 + 1 | 0;
    HEAP32[$4 >> 2] = $20;
    $21 = HEAP8[$result] | 0;
    $_0 = $21;
    label = 7;
    break;
   case 6:
    HEAP32[$error >> 2] = 85;
    $_0 = 0;
    label = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_Stream_ReadShortLE($stream, $error) {
  $stream = $stream | 0;
  $error = $error | 0;
  var $reads = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $p_014 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $result_0 = 0, $28 = 0, $29 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $reads = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $stream + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 1 | 0;
    $4 = $stream + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $3 >>> 0 < $5 >>> 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 7;
      break;
    }
   case 2:
    $8 = $stream + 20 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = $reads | 0;
    $13 = FUNCTION_TABLE_iiiii[$9 & 1023]($stream, $2, $12, 2) | 0;
    $14 = ($13 | 0) == 2;
    if ($14) {
      $p_014 = $12;
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 4:
    $16 = $stream | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $17 + $2 | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      $result_0 = 0;
      label = 6;
      break;
    } else {
      $p_014 = $18;
      label = 5;
      break;
    }
   case 5:
    $20 = $p_014 + 1 | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $21 & 255;
    $23 = $22 << 8;
    $24 = HEAP8[$p_014] | 0;
    $25 = $24 & 255;
    $26 = $23 | $25;
    $result_0 = $26;
    label = 6;
    break;
   case 6:
    $28 = HEAP32[$1 >> 2] | 0;
    $29 = $28 + 2 | 0;
    HEAP32[$1 >> 2] = $29;
    $_0 = $result_0;
    label = 8;
    break;
   case 7:
    HEAP32[$error >> 2] = 85;
    $_0 = 0;
    label = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _ft_trig_downscale($val) {
  $val = $val | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $9 = 0, $11 = 0, $14 = 0, $16 = 0, $hi_0 = 0;
  $1 = ($val | 0) > -1;
  $3 = $1 ? $val : -$val | 0;
  $4 = $3 >>> 16;
  $5 = $3 & 65535;
  $9 = ($5 * 17797 & -1) + ($4 * 47593 & -1) | 0;
  $11 = ($5 * 47593 & -1) >>> 16;
  $14 = $9 + $11 | 0;
  $16 = ($14 >>> 16) + ($4 * 17797 & -1) | 0;
  $hi_0 = $14 >>> 0 < ($9 >>> 0 >= $11 >>> 0 ? $9 : $11) >>> 0 ? $16 + 65536 | 0 : $16;
  return ($1 ? $hi_0 : -$hi_0 | 0) | 0;
}
function _ft_highpow2($value) {
  $value = $value | 0;
  var $_0 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $_0 = $value;
    label = 2;
    break;
   case 2:
    $2 = $_0 - 1 | 0;
    $3 = $2 & $_0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 3;
      break;
    } else {
      $_0 = $3;
      label = 2;
      break;
    }
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _ft_trig_prenorm($vec) {
  $vec = $vec | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $z_0 = 0, $shift_0 = 0, $14 = 0, $16 = 0, $17 = 0, $z_1 = 0, $shift_1 = 0, $19 = 0, $21 = 0, $22 = 0, $z_2 = 0, $shift_2 = 0, $24 = 0, $26 = 0, $27 = 0, $z_3 = 0, $shift_3 = 0, $29 = 0, $30 = 0, $shift_4 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $shift_5 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $vec | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $vec + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) > -1;
    $6 = -$2 | 0;
    $7 = $5 ? $2 : $6;
    $8 = ($4 | 0) > -1;
    $9 = -$4 | 0;
    $10 = $8 ? $4 : $9;
    $11 = $10 | $7;
    $12 = ($11 | 0) > 65535;
    $13 = $11 >> 16;
    $z_0 = $12 ? $13 : $11;
    $shift_0 = $12 ? 16 : 0;
    $14 = ($z_0 | 0) > 255;
    if ($14) {
      label = 2;
      break;
    } else {
      $shift_1 = $shift_0;
      $z_1 = $z_0;
      label = 3;
      break;
    }
   case 2:
    $16 = $z_0 >> 8;
    $17 = $shift_0 | 8;
    $shift_1 = $17;
    $z_1 = $16;
    label = 3;
    break;
   case 3:
    $19 = ($z_1 | 0) > 15;
    if ($19) {
      label = 4;
      break;
    } else {
      $shift_2 = $shift_1;
      $z_2 = $z_1;
      label = 5;
      break;
    }
   case 4:
    $21 = $z_1 >> 4;
    $22 = $shift_1 + 4 | 0;
    $shift_2 = $22;
    $z_2 = $21;
    label = 5;
    break;
   case 5:
    $24 = ($z_2 | 0) > 3;
    if ($24) {
      label = 6;
      break;
    } else {
      $shift_3 = $shift_2;
      $z_3 = $z_2;
      label = 7;
      break;
    }
   case 6:
    $26 = $z_2 >> 2;
    $27 = $shift_2 + 2 | 0;
    $shift_3 = $27;
    $z_3 = $26;
    label = 7;
    break;
   case 7:
    $29 = ($z_3 | 0) > 1;
    $30 = $29 & 1;
    $shift_4 = $30 + $shift_3 | 0;
    $31 = ($shift_4 | 0) < 28;
    if ($31) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $33 = 27 - $shift_4 | 0;
    $34 = $2 << $33;
    HEAP32[$1 >> 2] = $34;
    $35 = $4 << $33;
    HEAP32[$3 >> 2] = $35;
    $shift_5 = $33;
    label = 10;
    break;
   case 9:
    $37 = $shift_4 - 27 | 0;
    $38 = $2 >> $37;
    HEAP32[$1 >> 2] = $38;
    $39 = $4 >> $37;
    HEAP32[$3 >> 2] = $39;
    $40 = 27 - $shift_4 | 0;
    $shift_5 = $40;
    label = 10;
    break;
   case 10:
    return $shift_5 | 0;
  }
  return 0;
}
function _ft_trig_pseudo_polarize($vec) {
  $vec = $vec | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $theta_0 = 0, $x_0 = 0, $y_0 = 0, $10 = 0, $11 = 0, $theta_1 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $theta_3 = 0, $i_0 = 0, $x_2 = 0, $y_2 = 0, $arctanptr_1 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $theta_4 = 0, $x_3 = 0, $y_3 = 0, $arctanptr_2 = 0, $39 = 0, $exitcond = 0, $41 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $theta_5 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $vec | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $vec + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) < 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $y_0 = $4;
      $x_0 = $2;
      $theta_0 = 0;
      label = 3;
      break;
    }
   case 2:
    $7 = -$2 | 0;
    $8 = -$4 | 0;
    $y_0 = $8;
    $x_0 = $7;
    $theta_0 = 11796480;
    label = 3;
    break;
   case 3:
    $10 = ($y_0 | 0) > 0;
    $11 = -$theta_0 | 0;
    $theta_1 = $10 ? $11 : $theta_0;
    $12 = ($y_0 | 0) < 0;
    $13 = $x_0 << 1;
    if ($12) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $15 = $y_0 + $13 | 0;
    $16 = $y_0 << 1;
    $17 = $x_0 - $16 | 0;
    $18 = $theta_1 - 4157273 | 0;
    $arctanptr_1 = 5251412;
    $y_2 = $15;
    $x_2 = $17;
    $i_0 = 0;
    $theta_3 = $18;
    label = 6;
    break;
   case 5:
    $20 = $y_0 - $13 | 0;
    $21 = $y_0 << 1;
    $22 = $21 + $x_0 | 0;
    $23 = $theta_1 + 4157273 | 0;
    $arctanptr_1 = 5251412;
    $y_2 = $20;
    $x_2 = $22;
    $i_0 = 0;
    $theta_3 = $23;
    label = 6;
    break;
   case 6:
    $24 = ($y_2 | 0) < 0;
    $25 = $x_2 >> $i_0;
    if ($24) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $27 = $y_2 + $25 | 0;
    $28 = $y_2 >> $i_0;
    $29 = $x_2 - $28 | 0;
    $30 = HEAP32[$arctanptr_1 >> 2] | 0;
    $31 = $theta_3 - $30 | 0;
    $y_3 = $27;
    $x_3 = $29;
    $theta_4 = $31;
    label = 9;
    break;
   case 8:
    $33 = $y_2 - $25 | 0;
    $34 = $y_2 >> $i_0;
    $35 = $34 + $x_2 | 0;
    $36 = HEAP32[$arctanptr_1 >> 2] | 0;
    $37 = $36 + $theta_3 | 0;
    $y_3 = $33;
    $x_3 = $35;
    $theta_4 = $37;
    label = 9;
    break;
   case 9:
    $arctanptr_2 = $arctanptr_1 + 4 | 0;
    $39 = $i_0 + 1 | 0;
    $exitcond = ($39 | 0) == 23;
    if ($exitcond) {
      label = 10;
      break;
    } else {
      $arctanptr_1 = $arctanptr_2;
      $y_2 = $y_3;
      $x_2 = $x_3;
      $i_0 = $39;
      $theta_3 = $theta_4;
      label = 6;
      break;
    }
   case 10:
    $41 = ($theta_4 | 0) > -1;
    if ($41) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $43 = $theta_4 + 16 | 0;
    $44 = $43 & -32;
    $theta_5 = $44;
    label = 13;
    break;
   case 12:
    $46 = 16 - $theta_4 | 0;
    $47 = $46 & -32;
    $48 = -$47 | 0;
    $theta_5 = $48;
    label = 13;
    break;
   case 13:
    HEAP32[$1 >> 2] = $x_3;
    HEAP32[$3 >> 2] = $theta_5;
    return;
  }
}
function _ft_mem_strcpyn($dst, $src, $size) {
  $dst = $dst | 0;
  $src = $src | 0;
  $size = $size | 0;
  var $1 = 0, $_011 = 0, $_0710 = 0, $_089 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_07_lcssa = 0, $_08_lcssa = 0, $9 = 0, $10 = 0, $11 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size >>> 0 > 1;
    if ($1) {
      $_089 = $dst;
      $_0710 = $src;
      $_011 = $size;
      label = 2;
      break;
    } else {
      $_08_lcssa = $dst;
      $_07_lcssa = $src;
      label = 4;
      break;
    }
   case 2:
    $2 = HEAP8[$_0710] | 0;
    $3 = $2 << 24 >> 24 == 0;
    if ($3) {
      $_08_lcssa = $_089;
      $_07_lcssa = $_0710;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $5 = $_0710 + 1 | 0;
    $6 = $_089 + 1 | 0;
    HEAP8[$_089] = $2;
    $7 = $_011 - 1 | 0;
    $8 = $7 >>> 0 > 1;
    if ($8) {
      $_089 = $6;
      $_0710 = $5;
      $_011 = $7;
      label = 2;
      break;
    } else {
      $_08_lcssa = $6;
      $_07_lcssa = $5;
      label = 4;
      break;
    }
   case 4:
    HEAP8[$_08_lcssa] = 0;
    $9 = HEAP8[$_07_lcssa] | 0;
    $10 = $9 << 24 >> 24 != 0;
    $11 = $10 & 1;
    return $11 | 0;
  }
  return 0;
}
function _FT_Stream_ReadOffset($stream, $error) {
  $stream = $stream | 0;
  $error = $error | 0;
  var $reads = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $p_015 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $result_0 = 0, $33 = 0, $34 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $reads = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $stream + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 2 | 0;
    $4 = $stream + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $3 >>> 0 < $5 >>> 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 7;
      break;
    }
   case 2:
    $8 = $stream + 20 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = $reads | 0;
    $13 = FUNCTION_TABLE_iiiii[$9 & 1023]($stream, $2, $12, 3) | 0;
    $14 = ($13 | 0) == 3;
    if ($14) {
      $p_015 = $12;
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 4:
    $16 = $stream | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $17 + $2 | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      $result_0 = 0;
      label = 6;
      break;
    } else {
      $p_015 = $18;
      label = 5;
      break;
    }
   case 5:
    $20 = HEAP8[$p_015] | 0;
    $21 = $20 << 24 >> 24;
    $22 = $21 << 16;
    $23 = $p_015 + 1 | 0;
    $24 = HEAP8[$23] | 0;
    $25 = $24 & 255;
    $26 = $25 << 8;
    $27 = $26 | $22;
    $28 = $p_015 + 2 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $29 & 255;
    $31 = $27 | $30;
    $result_0 = $31;
    label = 6;
    break;
   case 6:
    $33 = HEAP32[$1 >> 2] | 0;
    $34 = $33 + 3 | 0;
    HEAP32[$1 >> 2] = $34;
    $_0 = $result_0;
    label = 8;
    break;
   case 7:
    HEAP32[$error >> 2] = 85;
    $_0 = 0;
    label = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_Stream_ReadLongLE($stream, $error) {
  $stream = $stream | 0;
  $error = $error | 0;
  var $reads = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $p_016 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $result_0 = 0, $38 = 0, $39 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $reads = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $stream + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 3 | 0;
    $4 = $stream + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $3 >>> 0 < $5 >>> 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 7;
      break;
    }
   case 2:
    $8 = $stream + 20 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = $reads | 0;
    $13 = FUNCTION_TABLE_iiiii[$9 & 1023]($stream, $2, $12, 4) | 0;
    $14 = ($13 | 0) == 4;
    if ($14) {
      $p_016 = $12;
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 4:
    $16 = $stream | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $17 + $2 | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      $result_0 = 0;
      label = 6;
      break;
    } else {
      $p_016 = $18;
      label = 5;
      break;
    }
   case 5:
    $20 = $p_016 + 3 | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $21 & 255;
    $23 = $22 << 24;
    $24 = $p_016 + 2 | 0;
    $25 = HEAP8[$24] | 0;
    $26 = $25 & 255;
    $27 = $26 << 16;
    $28 = $27 | $23;
    $29 = $p_016 + 1 | 0;
    $30 = HEAP8[$29] | 0;
    $31 = $30 & 255;
    $32 = $31 << 8;
    $33 = $28 | $32;
    $34 = HEAP8[$p_016] | 0;
    $35 = $34 & 255;
    $36 = $33 | $35;
    $result_0 = $36;
    label = 6;
    break;
   case 6:
    $38 = HEAP32[$1 >> 2] | 0;
    $39 = $38 + 4 | 0;
    HEAP32[$1 >> 2] = $39;
    $_0 = $result_0;
    label = 8;
    break;
   case 7:
    HEAP32[$error >> 2] = 85;
    $_0 = 0;
    label = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_Stream_ReadFields($stream, $fields, $structure) {
  $stream = $stream | 0;
  $fields = $fields | 0;
  $structure = $structure | 0;
  var $1 = 0, $2 = 0, $or_cond = 0, $4 = 0, $5 = 0, $_062_ph = 0, $frame_accessed_0_ph = 0, $cursor_0_ph = 0, $_062 = 0, $cursor_0 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $cursor_1 = 0, $value_0 = 0, $sign_shift_0 = 0, $123 = 0, $124 = 0, $125 = 0, $127 = 0, $128 = 0, $value_1 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $138 = 0, $140 = 0, $141 = 0, $143 = 0, $145 = 0, $cursor_0_be = 0, $_062_be = 0, $error_1 = 0, $146 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($fields | 0) == 0;
    $2 = ($stream | 0) == 0;
    $or_cond = $1 | $2;
    if ($or_cond) {
      $_0 = 6;
      label = 28;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $stream + 32 | 0;
    $5 = $stream + 36 | 0;
    $frame_accessed_0_ph = 0;
    $_062_ph = $fields;
    label = 3;
    break;
   case 3:
    $cursor_0_ph = HEAP32[$4 >> 2] | 0;
    $cursor_0 = $cursor_0_ph;
    $_062 = $_062_ph;
    label = 4;
    break;
   case 4:
    $7 = $_062 | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 & 255;
    if (($9 | 0) == 4) {
      label = 5;
      break;
    } else if (($9 | 0) == 24 | ($9 | 0) == 25) {
      label = 7;
      break;
    } else if (($9 | 0) == 8 | ($9 | 0) == 9) {
      label = 10;
      break;
    } else if (($9 | 0) == 13 | ($9 | 0) == 12) {
      label = 11;
      break;
    } else if (($9 | 0) == 15 | ($9 | 0) == 14) {
      label = 12;
      break;
    } else if (($9 | 0) == 17 | ($9 | 0) == 16) {
      label = 13;
      break;
    } else if (($9 | 0) == 19 | ($9 | 0) == 18) {
      label = 14;
      break;
    } else if (($9 | 0) == 21 | ($9 | 0) == 20) {
      label = 15;
      break;
    } else if (($9 | 0) == 23 | ($9 | 0) == 22) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 5:
    $11 = $_062 + 2 | 0;
    $12 = HEAP16[$11 >> 1] | 0;
    $13 = $12 & 65535;
    $14 = _FT_Stream_EnterFrame($stream, $13) | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 6;
      break;
    } else {
      $error_1 = $14;
      label = 26;
      break;
    }
   case 6:
    $17 = $_062 + 4 | 0;
    $frame_accessed_0_ph = 1;
    $_062_ph = $17;
    label = 3;
    break;
   case 7:
    $19 = $_062 + 1 | 0;
    $20 = HEAP8[$19] | 0;
    $21 = $20 & 255;
    $22 = $cursor_0 + $21 | 0;
    $23 = HEAP32[$5 >> 2] | 0;
    $24 = $22 >>> 0 > $23 >>> 0;
    if ($24) {
      $error_1 = 85;
      label = 26;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $26 = HEAP8[$7] | 0;
    $27 = $26 << 24 >> 24 == 24;
    if ($27) {
      label = 9;
      break;
    } else {
      $cursor_0_be = $22;
      label = 25;
      break;
    }
   case 9:
    $29 = $_062 + 2 | 0;
    $30 = HEAP16[$29 >> 1] | 0;
    $31 = $30 & 65535;
    $32 = $structure + $31 | 0;
    _memcpy($32 | 0, $cursor_0 | 0, $21 | 0);
    $cursor_0_be = $22;
    label = 25;
    break;
   case 10:
    $34 = $cursor_0 + 1 | 0;
    $35 = HEAP8[$cursor_0] | 0;
    $36 = $35 & 255;
    $sign_shift_0 = 24;
    $value_0 = $36;
    $cursor_1 = $34;
    label = 18;
    break;
   case 11:
    $38 = $cursor_0 + 2 | 0;
    $39 = HEAP8[$cursor_0] | 0;
    $40 = $39 & 255;
    $41 = $40 << 8;
    $42 = $cursor_0 + 1 | 0;
    $43 = HEAP8[$42] | 0;
    $44 = $43 & 255;
    $45 = $41 | $44;
    $sign_shift_0 = 16;
    $value_0 = $45;
    $cursor_1 = $38;
    label = 18;
    break;
   case 12:
    $47 = $cursor_0 + 2 | 0;
    $48 = $cursor_0 + 1 | 0;
    $49 = HEAP8[$48] | 0;
    $50 = $49 & 255;
    $51 = $50 << 8;
    $52 = HEAP8[$cursor_0] | 0;
    $53 = $52 & 255;
    $54 = $51 | $53;
    $sign_shift_0 = 16;
    $value_0 = $54;
    $cursor_1 = $47;
    label = 18;
    break;
   case 13:
    $56 = $cursor_0 + 4 | 0;
    $57 = HEAP8[$cursor_0] | 0;
    $58 = $57 & 255;
    $59 = $58 << 24;
    $60 = $cursor_0 + 1 | 0;
    $61 = HEAP8[$60] | 0;
    $62 = $61 & 255;
    $63 = $62 << 16;
    $64 = $63 | $59;
    $65 = $cursor_0 + 2 | 0;
    $66 = HEAP8[$65] | 0;
    $67 = $66 & 255;
    $68 = $67 << 8;
    $69 = $64 | $68;
    $70 = $cursor_0 + 3 | 0;
    $71 = HEAP8[$70] | 0;
    $72 = $71 & 255;
    $73 = $69 | $72;
    $sign_shift_0 = 0;
    $value_0 = $73;
    $cursor_1 = $56;
    label = 18;
    break;
   case 14:
    $75 = $cursor_0 + 4 | 0;
    $76 = $cursor_0 + 3 | 0;
    $77 = HEAP8[$76] | 0;
    $78 = $77 & 255;
    $79 = $78 << 24;
    $80 = $cursor_0 + 2 | 0;
    $81 = HEAP8[$80] | 0;
    $82 = $81 & 255;
    $83 = $82 << 16;
    $84 = $83 | $79;
    $85 = $cursor_0 + 1 | 0;
    $86 = HEAP8[$85] | 0;
    $87 = $86 & 255;
    $88 = $87 << 8;
    $89 = $84 | $88;
    $90 = HEAP8[$cursor_0] | 0;
    $91 = $90 & 255;
    $92 = $89 | $91;
    $sign_shift_0 = 0;
    $value_0 = $92;
    $cursor_1 = $75;
    label = 18;
    break;
   case 15:
    $94 = $cursor_0 + 3 | 0;
    $95 = HEAP8[$cursor_0] | 0;
    $96 = $95 & 255;
    $97 = $96 << 16;
    $98 = $cursor_0 + 1 | 0;
    $99 = HEAP8[$98] | 0;
    $100 = $99 & 255;
    $101 = $100 << 8;
    $102 = $101 | $97;
    $103 = $cursor_0 + 2 | 0;
    $104 = HEAP8[$103] | 0;
    $105 = $104 & 255;
    $106 = $102 | $105;
    $sign_shift_0 = 8;
    $value_0 = $106;
    $cursor_1 = $94;
    label = 18;
    break;
   case 16:
    $108 = $cursor_0 + 3 | 0;
    $109 = $cursor_0 + 2 | 0;
    $110 = HEAP8[$109] | 0;
    $111 = $110 & 255;
    $112 = $111 << 16;
    $113 = $cursor_0 + 1 | 0;
    $114 = HEAP8[$113] | 0;
    $115 = $114 & 255;
    $116 = $115 << 8;
    $117 = $116 | $112;
    $118 = HEAP8[$cursor_0] | 0;
    $119 = $118 & 255;
    $120 = $117 | $119;
    $sign_shift_0 = 8;
    $value_0 = $120;
    $cursor_1 = $108;
    label = 18;
    break;
   case 17:
    HEAP32[$4 >> 2] = $cursor_0;
    $error_1 = 0;
    label = 26;
    break;
   case 18:
    $123 = HEAP8[$7] | 0;
    $124 = $123 & 1;
    $125 = $124 << 24 >> 24 == 0;
    if ($125) {
      $value_1 = $value_0;
      label = 20;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $127 = $value_0 << $sign_shift_0;
    $128 = $127 >> $sign_shift_0;
    $value_1 = $128;
    label = 20;
    break;
   case 20:
    $130 = $_062 + 2 | 0;
    $131 = HEAP16[$130 >> 1] | 0;
    $132 = $131 & 65535;
    $133 = $structure + $132 | 0;
    $134 = $_062 + 1 | 0;
    $135 = HEAP8[$134] | 0;
    $136 = $135 & 255;
    if (($136 | 0) == 1) {
      label = 21;
      break;
    } else if (($136 | 0) == 2) {
      label = 22;
      break;
    } else if (($136 | 0) == 4) {
      label = 23;
      break;
    } else {
      label = 24;
      break;
    }
   case 21:
    $138 = $value_1 & 255;
    HEAP8[$133] = $138;
    $cursor_0_be = $cursor_1;
    label = 25;
    break;
   case 22:
    $140 = $value_1 & 65535;
    $141 = $133;
    HEAP16[$141 >> 1] = $140;
    $cursor_0_be = $cursor_1;
    label = 25;
    break;
   case 23:
    $143 = $133;
    HEAP32[$143 >> 2] = $value_1;
    $cursor_0_be = $cursor_1;
    label = 25;
    break;
   case 24:
    $145 = $133;
    HEAP32[$145 >> 2] = $value_1;
    $cursor_0_be = $cursor_1;
    label = 25;
    break;
   case 25:
    $_062_be = $_062 + 4 | 0;
    $cursor_0 = $cursor_0_be;
    $_062 = $_062_be;
    label = 4;
    break;
   case 26:
    $146 = $frame_accessed_0_ph << 24 >> 24 == 0;
    if ($146) {
      $_0 = $error_1;
      label = 28;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    _FT_Stream_ExitFrame($stream);
    $_0 = $error_1;
    label = 28;
    break;
   case 28:
    return $_0 | 0;
  }
  return 0;
}
function _FT_Vector_Length($vec) {
  $vec = $vec | 0;
  var $v = 0, $1 = 0, $2 = 0, $ld$0$0 = 0, $3$0 = 0, $ld$1$1 = 0, $3$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $v = __stackBase__ | 0;
    $1 = $vec;
    $2 = $v;
    $ld$0$0 = $1 | 0;
    $3$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $1 + 4 | 0;
    $3$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $2 | 0;
    HEAP32[$st$2$0 >> 2] = $3$0;
    $st$3$1 = $2 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $3$1;
    $4 = $v | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($5 | 0) == 0;
    $7 = $v + 4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $10 = ($8 | 0) > -1;
    $11 = -$8 | 0;
    $12 = $10 ? $8 : $11;
    $_0 = $12;
    label = 8;
    break;
   case 3:
    $14 = ($8 | 0) == 0;
    if ($14) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $16 = ($5 | 0) > -1;
    $17 = -$5 | 0;
    $18 = $16 ? $5 : $17;
    $_0 = $18;
    label = 8;
    break;
   case 5:
    $20 = _ft_trig_prenorm($v) | 0;
    _ft_trig_pseudo_polarize($v);
    $21 = HEAP32[$4 >> 2] | 0;
    $22 = _ft_trig_downscale($21) | 0;
    HEAP32[$4 >> 2] = $22;
    $23 = ($20 | 0) > 0;
    if ($23) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $25 = $20 - 1 | 0;
    $26 = 1 << $25;
    $27 = $22 + $26 | 0;
    $28 = $27 >> $20;
    $_0 = $28;
    label = 8;
    break;
   case 7:
    $30 = -$20 | 0;
    $31 = $22 << $30;
    $_0 = $31;
    label = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _ft_mem_qrealloc($memory, $item_size, $cur_count, $new_count, $block, $p_error) {
  $memory = $memory | 0;
  $item_size = $item_size | 0;
  $cur_count = $cur_count | 0;
  $new_count = $new_count | 0;
  $block = $block | 0;
  $p_error = $p_error | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $6 = 0, $7 = 0, $or_cond24 = 0, $10 = 0, $11 = 0, $14 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $_0 = 0, $27 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $cur_count | $item_size;
    $2 = $1 | $new_count;
    $3 = ($2 | 0) < 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    HEAP32[$error >> 2] = 6;
    $_0 = $block;
    label = 11;
    break;
   case 3:
    $6 = ($new_count | 0) == 0;
    $7 = ($item_size | 0) == 0;
    $or_cond24 = $6 | $7;
    if ($or_cond24) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    _ft_mem_free($memory, $block);
    $_0 = 0;
    label = 11;
    break;
   case 5:
    $10 = 2147483647 / ($item_size | 0) & -1;
    $11 = ($10 | 0) < ($new_count | 0);
    if ($11) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    HEAP32[$error >> 2] = 10;
    $_0 = $block;
    label = 11;
    break;
   case 7:
    $14 = ($cur_count | 0) == 0;
    if ($14) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $16 = Math_imul($new_count, $item_size);
    $17 = _ft_mem_alloc($memory, $16, $error) | 0;
    $_0 = $17;
    label = 11;
    break;
   case 9:
    $19 = Math_imul($cur_count, $item_size);
    $20 = Math_imul($new_count, $item_size);
    $21 = $memory + 12 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = FUNCTION_TABLE_iiiii[$22 & 1023]($memory, $19, $20, $block) | 0;
    $24 = ($23 | 0) == 0;
    if ($24) {
      label = 10;
      break;
    } else {
      $_0 = $23;
      label = 11;
      break;
    }
   case 10:
    HEAP32[$error >> 2] = 64;
    $_0 = $block;
    label = 11;
    break;
   case 11:
    $27 = HEAP32[$error >> 2] | 0;
    HEAP32[$p_error >> 2] = $27;
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _ft_mem_dup($memory, $address, $size, $p_error) {
  $memory = $memory | 0;
  $address = $address | 0;
  $size = $size | 0;
  $p_error = $p_error | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $or_cond = 0, $7 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = _ft_mem_qalloc($memory, $size, $error) | 0;
    $2 = HEAP32[$error >> 2] | 0;
    $3 = ($2 | 0) != 0;
    $4 = ($address | 0) == 0;
    $or_cond = $3 | $4;
    if ($or_cond) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    _memcpy($1 | 0, $address | 0, $size | 0);
    label = 3;
    break;
   case 3:
    $7 = HEAP32[$error >> 2] | 0;
    HEAP32[$p_error >> 2] = $7;
    STACKTOP = __stackBase__;
    return $1 | 0;
  }
  return 0;
}
function _ft_mem_strdup($memory, $str, $p_error) {
  $memory = $memory | 0;
  $str = $str | 0;
  $p_error = $p_error | 0;
  var $1 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($str | 0) == 0;
    if ($1) {
      $6 = 0;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = _strlen($str | 0) | 0;
    $4 = $3 + 1 | 0;
    $6 = $4;
    label = 3;
    break;
   case 3:
    $7 = _ft_mem_dup($memory, $str, $6, $p_error) | 0;
    return $7 | 0;
  }
  return 0;
}
function _FT_List_Finalize($list, $destroy, $memory, $user) {
  $list = $list | 0;
  $destroy = $destroy | 0;
  $memory = $memory | 0;
  $user = $user | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $cur_011 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $list | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = ($destroy | 0) == 0;
    $cur_011 = $2;
    label = 3;
    break;
   case 3:
    $6 = $cur_011 + 4 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    if ($4) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $9 = $cur_011 + 8 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    FUNCTION_TABLE_viii[$destroy & 1023]($memory, $10, $user);
    label = 5;
    break;
   case 5:
    $12 = $cur_011;
    _ft_mem_free($memory, $12);
    $13 = ($7 | 0) == 0;
    if ($13) {
      label = 6;
      break;
    } else {
      $cur_011 = $7;
      label = 3;
      break;
    }
   case 6:
    HEAP32[$1 >> 2] = 0;
    $14 = $list + 4 | 0;
    HEAP32[$14 >> 2] = 0;
    return;
  }
}
function _raccess_guess_apple_double($library, $stream, $base_file_name, $result_file_name, $result_offset) {
  $library = $library | 0;
  $stream = $stream | 0;
  $base_file_name = $base_file_name | 0;
  $result_file_name = $result_file_name | 0;
  $result_offset = $result_offset | 0;
  var $1 = 0, $3 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    HEAP32[$result_file_name >> 2] = 0;
    $1 = ($stream | 0) == 0;
    if ($1) {
      $_0 = 81;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = _raccess_guess_apple_generic($stream, 333319, $result_offset) | 0;
    $_0 = $3;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _raccess_guess_apple_single($library, $stream, $base_file_name, $result_file_name, $result_offset) {
  $library = $library | 0;
  $stream = $stream | 0;
  $base_file_name = $base_file_name | 0;
  $result_file_name = $result_file_name | 0;
  $result_offset = $result_offset | 0;
  var $1 = 0, $3 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    HEAP32[$result_file_name >> 2] = 0;
    $1 = ($stream | 0) == 0;
    if ($1) {
      $_0 = 81;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = _raccess_guess_apple_generic($stream, 333312, $result_offset) | 0;
    $_0 = $3;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _raccess_guess_darwin_ufs_export($library, $stream, $base_file_name, $result_file_name, $result_offset) {
  $library = $library | 0;
  $stream = $stream | 0;
  $base_file_name = $base_file_name | 0;
  $result_file_name = $result_file_name | 0;
  $result_offset = $result_offset | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $library | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _raccess_make_file_name($2, $base_file_name, 5324204) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      $_0 = 64;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = _raccess_guess_linux_double_from_file_name($library, $3, $result_offset) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    HEAP32[$result_file_name >> 2] = $3;
    $_0 = 0;
    label = 5;
    break;
   case 4:
    _ft_mem_free($2, $3);
    $_0 = $6;
    label = 5;
    break;
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function _raccess_guess_darwin_newvfs($library, $stream, $base_file_name, $result_file_name, $result_offset) {
  $library = $library | 0;
  $stream = $stream | 0;
  $base_file_name = $base_file_name | 0;
  $result_file_name = $result_file_name | 0;
  $result_offset = $result_offset | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = _strlen($base_file_name | 0) | 0;
    $2 = $library | 0;
    $3 = $1 + 18 | 0;
    $4 = HEAP32[$2 >> 2] | 0;
    $5 = _ft_mem_alloc($4, $3, $error) | 0;
    $6 = HEAP32[$error >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 2;
      break;
    } else {
      $_0 = $6;
      label = 3;
      break;
    }
   case 2:
    _memcpy($5 | 0, $base_file_name | 0, $1 | 0);
    $9 = $5 + $1 | 0;
    _memcpy($9 | 0, 5324304, 18);
    HEAP32[$result_file_name >> 2] = $5;
    HEAP32[$result_offset >> 2] = 0;
    $_0 = 0;
    label = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _raccess_guess_darwin_hfsplus($library, $stream, $base_file_name, $result_file_name, $result_offset) {
  $library = $library | 0;
  $stream = $stream | 0;
  $base_file_name = $base_file_name | 0;
  $result_file_name = $result_file_name | 0;
  $result_offset = $result_offset | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = _strlen($base_file_name | 0) | 0;
    $2 = $library | 0;
    $3 = $1 + 6 | 0;
    $4 = HEAP32[$2 >> 2] | 0;
    $5 = _ft_mem_alloc($4, $3, $error) | 0;
    $6 = HEAP32[$error >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 2;
      break;
    } else {
      $_0 = $6;
      label = 3;
      break;
    }
   case 2:
    _memcpy($5 | 0, $base_file_name | 0, $1 | 0);
    $9 = $5 + $1 | 0;
    _memcpy($9 | 0, 5324428, 6);
    HEAP32[$result_file_name >> 2] = $5;
    HEAP32[$result_offset >> 2] = 0;
    $_0 = 0;
    label = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _raccess_guess_vfat($library, $stream, $base_file_name, $result_file_name, $result_offset) {
  $library = $library | 0;
  $stream = $stream | 0;
  $base_file_name = $base_file_name | 0;
  $result_file_name = $result_file_name | 0;
  $result_offset = $result_offset | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $library | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _raccess_make_file_name($2, $base_file_name, 5324576) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      $_0 = 64;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    HEAP32[$result_file_name >> 2] = $3;
    HEAP32[$result_offset >> 2] = 0;
    $_0 = 0;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _raccess_guess_linux_cap($library, $stream, $base_file_name, $result_file_name, $result_offset) {
  $library = $library | 0;
  $stream = $stream | 0;
  $base_file_name = $base_file_name | 0;
  $result_file_name = $result_file_name | 0;
  $result_offset = $result_offset | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $library | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _raccess_make_file_name($2, $base_file_name, 5324884) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      $_0 = 64;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    HEAP32[$result_file_name >> 2] = $3;
    HEAP32[$result_offset >> 2] = 0;
    $_0 = 0;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _raccess_guess_linux_double($library, $stream, $base_file_name, $result_file_name, $result_offset) {
  $library = $library | 0;
  $stream = $stream | 0;
  $base_file_name = $base_file_name | 0;
  $result_file_name = $result_file_name | 0;
  $result_offset = $result_offset | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $library | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _raccess_make_file_name($2, $base_file_name, 5319460) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      $_0 = 64;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = _raccess_guess_linux_double_from_file_name($library, $3, $result_offset) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    HEAP32[$result_file_name >> 2] = $3;
    $_0 = 0;
    label = 5;
    break;
   case 4:
    _ft_mem_free($2, $3);
    $_0 = $6;
    label = 5;
    break;
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function _raccess_guess_linux_netatalk($library, $stream, $base_file_name, $result_file_name, $result_offset) {
  $library = $library | 0;
  $stream = $stream | 0;
  $base_file_name = $base_file_name | 0;
  $result_file_name = $result_file_name | 0;
  $result_offset = $result_offset | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $library | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _raccess_make_file_name($2, $base_file_name, 5319792) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      $_0 = 64;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = _raccess_guess_linux_double_from_file_name($library, $3, $result_offset) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    HEAP32[$result_file_name >> 2] = $3;
    $_0 = 0;
    label = 5;
    break;
   case 4:
    _ft_mem_free($2, $3);
    $_0 = $6;
    label = 5;
    break;
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function _raccess_get_rule_type_from_rule_index($rule_index) {
  $rule_index = $rule_index | 0;
  var $1 = 0, $3 = 0, $4 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $rule_index >>> 0 > 8;
    if ($1) {
      $_0 = -2;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = 5249856 + ($rule_index << 3) | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $_0 = $4;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _raccess_make_file_name($memory, $original_name, $insertion) {
  $memory = $memory | 0;
  $original_name = $original_name | 0;
  $insertion = $insertion | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $slash_0 = 0, $21 = 0, $22 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = _strlen($original_name | 0) | 0;
    $2 = _strlen($insertion | 0) | 0;
    $3 = $1 + 1 | 0;
    $4 = $3 + $2 | 0;
    $5 = _ft_mem_alloc($memory, $4, $error) | 0;
    $6 = HEAP32[$error >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 6;
      break;
    }
   case 2:
    $9 = _strrchr($original_name | 0, 47) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = $9;
    $13 = $original_name;
    $14 = $12 - $13 | 0;
    $15 = $14 + 1 | 0;
    $16 = _strncpy($5 | 0, $original_name | 0, $15 | 0) | 0;
    $17 = $5 + $15 | 0;
    HEAP8[$17] = 0;
    $18 = $9 + 1 | 0;
    $slash_0 = $18;
    label = 5;
    break;
   case 4:
    HEAP8[$5] = 0;
    $slash_0 = $original_name;
    label = 5;
    break;
   case 5:
    $21 = _strcat($5 | 0, $insertion | 0) | 0;
    $22 = _strcat($5 | 0, $slash_0 | 0) | 0;
    $_0 = $5;
    label = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _raccess_guess_linux_double_from_file_name($library, $file_name, $result_offset) {
  $library = $library | 0;
  $file_name = $file_name | 0;
  $result_offset = $result_offset | 0;
  var $args2 = 0, $stream2 = 0, $nouse = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 40 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $args2 = __stackBase__ | 0;
    $stream2 = __stackBase__ + 32 | 0;
    $nouse = __stackBase__ + 36 | 0;
    HEAP32[$nouse >> 2] = 0;
    $1 = $args2 | 0;
    HEAP32[$1 >> 2] = 4;
    $2 = $args2 + 12 | 0;
    HEAP32[$2 >> 2] = $file_name;
    $3 = _FT_Stream_New($library, $args2, $stream2) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 2;
      break;
    } else {
      $_0 = $3;
      label = 3;
      break;
    }
   case 2:
    $6 = HEAP32[$stream2 >> 2] | 0;
    $7 = _raccess_guess_apple_double($library, $6, $file_name, $nouse, $result_offset) | 0;
    $8 = HEAP32[$stream2 >> 2] | 0;
    _FT_Stream_Free($8, 0);
    $_0 = $7;
    label = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _raccess_guess_apple_generic($stream, $magic, $result_offset) {
  $stream = $stream | 0;
  $magic = $magic | 0;
  $result_offset = $result_offset | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $i_01 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = _FT_Stream_ReadLong($stream, $error) | 0;
    $2 = HEAP32[$error >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $_0 = $2;
      label = 14;
      break;
    }
   case 2:
    $5 = ($1 | 0) == ($magic | 0);
    if ($5) {
      label = 3;
      break;
    } else {
      $_0 = 2;
      label = 14;
      break;
    }
   case 3:
    $7 = _FT_Stream_ReadLong($stream, $error) | 0;
    $8 = HEAP32[$error >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 4;
      break;
    } else {
      $_0 = $8;
      label = 14;
      break;
    }
   case 4:
    $11 = _FT_Stream_Skip($stream, 16) | 0;
    HEAP32[$error >> 2] = $11;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 5;
      break;
    } else {
      $_0 = $11;
      label = 14;
      break;
    }
   case 5:
    $14 = _FT_Stream_ReadShort($stream, $error) | 0;
    $15 = HEAP32[$error >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 6;
      break;
    } else {
      $_0 = $15;
      label = 14;
      break;
    }
   case 6:
    $18 = $14 & 65535;
    $19 = $14 << 16 >> 16 == 0;
    if ($19) {
      $_0 = 2;
      label = 14;
      break;
    } else {
      $i_01 = 0;
      label = 7;
      break;
    }
   case 7:
    $20 = _FT_Stream_ReadLong($stream, $error) | 0;
    $21 = HEAP32[$error >> 2] | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 8;
      break;
    } else {
      $_0 = $21;
      label = 14;
      break;
    }
   case 8:
    $24 = ($20 | 0) == 2;
    if ($24) {
      label = 9;
      break;
    } else {
      label = 12;
      break;
    }
   case 9:
    $26 = _FT_Stream_ReadLong($stream, $error) | 0;
    $27 = HEAP32[$error >> 2] | 0;
    $28 = ($27 | 0) == 0;
    if ($28) {
      label = 10;
      break;
    } else {
      label = 13;
      break;
    }
   case 10:
    $30 = _FT_Stream_ReadLong($stream, $error) | 0;
    $31 = HEAP32[$error >> 2] | 0;
    $32 = ($31 | 0) == 0;
    if ($32) {
      label = 11;
      break;
    } else {
      label = 13;
      break;
    }
   case 11:
    HEAP32[$result_offset >> 2] = $26;
    $_0 = 0;
    label = 14;
    break;
   case 12:
    $35 = _FT_Stream_Skip($stream, 8) | 0;
    HEAP32[$error >> 2] = $35;
    $36 = ($35 | 0) == 0;
    if ($36) {
      label = 13;
      break;
    } else {
      $_0 = $35;
      label = 14;
      break;
    }
   case 13:
    $38 = $i_01 + 1 | 0;
    $39 = ($38 | 0) < ($18 | 0);
    if ($39) {
      $i_01 = $38;
      label = 7;
      break;
    } else {
      $_0 = 2;
      label = 14;
      break;
    }
   case 14:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _ft_remove_renderer($module) {
  $module = $module | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $module + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + 156 | 0;
    $6 = $module;
    $7 = _FT_List_Find($5, $6) | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = $module + 20 | 0;
    $11 = $10;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + 36 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($14 | 0) == 1869968492;
    if ($15) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $17 = $module + 60 | 0;
    $18 = $17;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $22 = $12 + 56 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $23 + 20 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    FUNCTION_TABLE_vi[$25 & 1023]($19);
    label = 5;
    break;
   case 5:
    _FT_List_Remove($5, $7);
    $27 = $7;
    _ft_mem_free($4, $27);
    _ft_set_current_renderer($2);
    label = 6;
    break;
   case 6:
    return;
  }
}
function _Destroy_Driver($driver) {
  $driver = $driver | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $driver + 24 | 0;
    $2 = $driver + 8 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $driver;
    _FT_List_Finalize($1, 842, $3, $4);
    $5 = $driver | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 & 512;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $12 = $driver + 36 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    _FT_GlyphLoader_Done($13);
    label = 3;
    break;
   case 3:
    return;
  }
}
function _ft_set_current_renderer($library) {
  $library = $library | 0;
  HEAP32[$library + 164 >> 2] = _FT_Lookup_Renderer($library, 1869968492, 0) | 0;
  return;
}
function _destroy_charmaps($face, $memory) {
  $face = $face | 0;
  $memory = $memory | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $n_013 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $_lcssa12 = 0, $17 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($face | 0) == 0;
    if ($1) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $2 = $face + 36 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = ($3 | 0) > 0;
    $5 = $face + 40 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    if ($4) {
      $n_013 = 0;
      $7 = $6;
      label = 3;
      break;
    } else {
      $_lcssa12 = $6;
      label = 4;
      break;
    }
   case 3:
    $8 = $7 + ($n_013 << 2) | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9;
    _ft_cmap_done_internal($10);
    $11 = HEAP32[$5 >> 2] | 0;
    $12 = $11 + ($n_013 << 2) | 0;
    HEAP32[$12 >> 2] = 0;
    $13 = $n_013 + 1 | 0;
    $14 = HEAP32[$2 >> 2] | 0;
    $15 = ($13 | 0) < ($14 | 0);
    $16 = HEAP32[$5 >> 2] | 0;
    if ($15) {
      $n_013 = $13;
      $7 = $16;
      label = 3;
      break;
    } else {
      $_lcssa12 = $16;
      label = 4;
      break;
    }
   case 4:
    $17 = $_lcssa12;
    _ft_mem_free($memory, $17);
    HEAP32[$5 >> 2] = 0;
    HEAP32[$2 >> 2] = 0;
    label = 5;
    break;
   case 5:
    return;
  }
}
function _IsMacBinary($library, $stream, $face_index, $aface) {
  $library = $library | 0;
  $stream = $stream | 0;
  $face_index = $face_index | 0;
  $aface = $aface | 0;
  var $header = 0, $1 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $or_cond = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 128 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $header = __stackBase__ | 0;
    $1 = ($stream | 0) == 0;
    if ($1) {
      $_0 = 85;
      label = 11;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = _FT_Stream_Seek($stream, 0) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 3;
      break;
    } else {
      $_0 = $3;
      label = 11;
      break;
    }
   case 3:
    $6 = $header | 0;
    $7 = _FT_Stream_Read($stream, $6, 128) | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 4;
      break;
    } else {
      $_0 = $7;
      label = 11;
      break;
    }
   case 4:
    $10 = HEAP8[$6] | 0;
    $11 = $10 << 24 >> 24 == 0;
    if ($11) {
      label = 5;
      break;
    } else {
      $_0 = 2;
      label = 11;
      break;
    }
   case 5:
    $13 = $header + 74 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 << 24 >> 24 == 0;
    if ($15) {
      label = 6;
      break;
    } else {
      $_0 = 2;
      label = 11;
      break;
    }
   case 6:
    $17 = $header + 82 | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $18 << 24 >> 24 == 0;
    if ($19) {
      label = 7;
      break;
    } else {
      $_0 = 2;
      label = 11;
      break;
    }
   case 7:
    $21 = $header + 1 | 0;
    $22 = HEAP8[$21] | 0;
    $23 = $22 & 255;
    $24 = $22 << 24 >> 24 == 0;
    $25 = ($22 & 255) > 33;
    $or_cond = $24 | $25;
    if ($or_cond) {
      $_0 = 2;
      label = 11;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $27 = $header + 63 | 0;
    $28 = HEAP8[$27] | 0;
    $29 = $28 << 24 >> 24 == 0;
    if ($29) {
      label = 9;
      break;
    } else {
      $_0 = 2;
      label = 11;
      break;
    }
   case 9:
    $31 = $23 + 2 | 0;
    $32 = $header + $31 | 0;
    $33 = HEAP8[$32] | 0;
    $34 = $33 << 24 >> 24 == 0;
    if ($34) {
      label = 10;
      break;
    } else {
      $_0 = 2;
      label = 11;
      break;
    }
   case 10:
    $36 = $header + 83 | 0;
    $37 = HEAP8[$36] | 0;
    $38 = $37 & 255;
    $39 = $38 << 24;
    $40 = $header + 84 | 0;
    $41 = HEAP8[$40] | 0;
    $42 = $41 & 255;
    $43 = $42 << 16;
    $44 = $43 | $39;
    $45 = $header + 85 | 0;
    $46 = HEAP8[$45] | 0;
    $47 = $46 & 255;
    $48 = $47 << 8;
    $49 = $44 | $48;
    $50 = $header + 86 | 0;
    $51 = HEAP8[$50] | 0;
    $52 = $51 & 255;
    $53 = $49 | $52;
    $54 = $53 + 255 | 0;
    $55 = $54 & -128;
    $56 = _IsMacResource($library, $stream, $55, $face_index, $aface) | 0;
    $_0 = $56;
    label = 11;
    break;
   case 11:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _IsMacResource($library, $stream, $resource_offset, $face_index, $aface) {
  $library = $library | 0;
  $stream = $stream | 0;
  $resource_offset = $resource_offset | 0;
  $face_index = $face_index | 0;
  $aface = $aface | 0;
  var $map_offset = 0, $rdara_pos = 0, $data_offsets = 0, $count = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $map_offset = __stackBase__ | 0;
    $rdara_pos = __stackBase__ + 4 | 0;
    $data_offsets = __stackBase__ + 8 | 0;
    $count = __stackBase__ + 12 | 0;
    $1 = $library | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _FT_Raccess_Get_HeaderInfo(0, $stream, $resource_offset, $map_offset, $rdara_pos) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 2;
      break;
    } else {
      $_0 = $3;
      label = 8;
      break;
    }
   case 2:
    $6 = HEAP32[$map_offset >> 2] | 0;
    $7 = HEAP32[$rdara_pos >> 2] | 0;
    $8 = _FT_Raccess_Get_DataOffsets($library, $stream, $6, $7, 1347375956, $data_offsets, $count) | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $11 = HEAP32[$data_offsets >> 2] | 0;
    $12 = HEAP32[$count >> 2] | 0;
    $13 = _Mac_Read_POST_Resource($library, $stream, $11, $12, $face_index, $aface) | 0;
    $14 = HEAP32[$data_offsets >> 2] | 0;
    $15 = $14;
    _ft_mem_free($2, $15);
    HEAP32[$data_offsets >> 2] = 0;
    $16 = ($13 | 0) == 0;
    if ($16) {
      label = 4;
      break;
    } else {
      $_0 = $13;
      label = 8;
      break;
    }
   case 4:
    $18 = HEAP32[$aface >> 2] | 0;
    $19 = $18 | 0;
    HEAP32[$19 >> 2] = 1;
    $_0 = 0;
    label = 8;
    break;
   case 5:
    $21 = HEAP32[$map_offset >> 2] | 0;
    $22 = HEAP32[$rdara_pos >> 2] | 0;
    $23 = _FT_Raccess_Get_DataOffsets($library, $stream, $21, $22, 1936092788, $data_offsets, $count) | 0;
    $24 = ($23 | 0) == 0;
    if ($24) {
      label = 6;
      break;
    } else {
      $_0 = $23;
      label = 8;
      break;
    }
   case 6:
    $26 = HEAP32[$count >> 2] | 0;
    $27 = ($face_index | 0) % ($26 | 0);
    $28 = HEAP32[$data_offsets >> 2] | 0;
    $29 = _Mac_Read_sfnt_Resource($library, $stream, $28, $26, $27, $aface) | 0;
    $30 = HEAP32[$data_offsets >> 2] | 0;
    $31 = $30;
    _ft_mem_free($2, $31);
    HEAP32[$data_offsets >> 2] = 0;
    $32 = ($29 | 0) == 0;
    if ($32) {
      label = 7;
      break;
    } else {
      $_0 = $29;
      label = 8;
      break;
    }
   case 7:
    $34 = HEAP32[$count >> 2] | 0;
    $35 = HEAP32[$aface >> 2] | 0;
    $36 = $35 | 0;
    HEAP32[$36 >> 2] = $34;
    $_0 = 0;
    label = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _load_face_in_embedded_rfork($library, $stream, $face_index, $aface, $args) {
  $library = $library | 0;
  $stream = $stream | 0;
  $face_index = $face_index | 0;
  $aface = $aface | 0;
  $args = $args | 0;
  var $file_names = 0, $offsets = 0, $errors = 0, $args2 = 0, $stream2 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vfs_rfork_has_no_font_031 = 0, $error_030 = 0, $i_028 = 0, $11 = 0, $12 = 0, $_not = 0, $13 = 0, $or_cond = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $or_cond26 = 0, $vfs_rfork_has_no_font_1 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $vfs_rfork_has_no_font_1_ = 0, $error_1 = 0, $vfs_rfork_has_no_font_2 = 0, $39 = 0, $40 = 0, $error_2 = 0, $42 = 0, $43 = 0, $44 = 0, $47 = 0, $48 = 0, $49 = 0, $52 = 0, $53 = 0, $54 = 0, $57 = 0, $58 = 0, $59 = 0, $62 = 0, $63 = 0, $64 = 0, $67 = 0, $68 = 0, $69 = 0, $72 = 0, $73 = 0, $74 = 0, $77 = 0, $78 = 0, $79 = 0, $82 = 0, $83 = 0, $84 = 0, $87 = 0, $error_2_ = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 144 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $file_names = __stackBase__ | 0;
    $offsets = __stackBase__ + 36 | 0;
    $errors = __stackBase__ + 72 | 0;
    $args2 = __stackBase__ + 108 | 0;
    $stream2 = __stackBase__ + 140 | 0;
    $1 = $library | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$stream2 >> 2] = 0;
    $3 = $args + 12 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $file_names | 0;
    $6 = $offsets | 0;
    $7 = $errors | 0;
    _FT_Raccess_Guess($library, $stream, $4, $5, $6, $7);
    $8 = $args2 | 0;
    $9 = $args2 + 12 | 0;
    $i_028 = 0;
    $error_030 = 2;
    $vfs_rfork_has_no_font_031 = 0;
    label = 2;
    break;
   case 2:
    $11 = _raccess_rule_by_darwin_vfs($i_028) | 0;
    $12 = $11 << 24 >> 24 != 0;
    $_not = $12 ^ 1;
    $13 = $vfs_rfork_has_no_font_031 << 24 >> 24 == 0;
    $or_cond = $13 | $_not;
    if ($or_cond) {
      label = 3;
      break;
    } else {
      $vfs_rfork_has_no_font_2 = $vfs_rfork_has_no_font_031;
      $error_1 = $error_030;
      label = 9;
      break;
    }
   case 3:
    $15 = $errors + ($i_028 << 2) | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 4;
      break;
    } else {
      $vfs_rfork_has_no_font_2 = $vfs_rfork_has_no_font_031;
      $error_1 = $error_030;
      label = 9;
      break;
    }
   case 4:
    HEAP32[$8 >> 2] = 4;
    $19 = $file_names + ($i_028 << 2) | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 5;
      break;
    } else {
      $25 = $20;
      label = 6;
      break;
    }
   case 5:
    $23 = HEAP32[$3 >> 2] | 0;
    $25 = $23;
    label = 6;
    break;
   case 6:
    HEAP32[$9 >> 2] = $25;
    $26 = _FT_Stream_New($library, $args2, $stream2) | 0;
    $27 = ($26 | 0) == 81;
    $or_cond26 = $12 & $27;
    $vfs_rfork_has_no_font_1 = $or_cond26 ? 1 : $vfs_rfork_has_no_font_031;
    $28 = ($26 | 0) == 0;
    if ($28) {
      label = 7;
      break;
    } else {
      $vfs_rfork_has_no_font_2 = $vfs_rfork_has_no_font_1;
      $error_1 = $26;
      label = 9;
      break;
    }
   case 7:
    $30 = HEAP32[$stream2 >> 2] | 0;
    $31 = $offsets + ($i_028 << 2) | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = _IsMacResource($library, $30, $32, $face_index, $aface) | 0;
    $34 = HEAP32[$stream2 >> 2] | 0;
    _FT_Stream_Free($34, 0);
    $35 = ($33 | 0) == 0;
    if ($35) {
      $error_2 = 0;
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $37 = $11 << 24 >> 24 == 0;
    $vfs_rfork_has_no_font_1_ = $37 ? $vfs_rfork_has_no_font_1 : 1;
    $vfs_rfork_has_no_font_2 = $vfs_rfork_has_no_font_1_;
    $error_1 = $33;
    label = 9;
    break;
   case 9:
    $39 = $i_028 + 1 | 0;
    $40 = ($39 | 0) < 9;
    if ($40) {
      $i_028 = $39;
      $error_030 = $error_1;
      $vfs_rfork_has_no_font_031 = $vfs_rfork_has_no_font_2;
      label = 2;
      break;
    } else {
      $error_2 = $error_1;
      label = 10;
      break;
    }
   case 10:
    $42 = $file_names | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = ($43 | 0) == 0;
    if ($44) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    _ft_mem_free($2, $43);
    HEAP32[$42 >> 2] = 0;
    label = 12;
    break;
   case 12:
    $47 = $file_names + 4 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = ($48 | 0) == 0;
    if ($49) {
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    _ft_mem_free($2, $48);
    HEAP32[$47 >> 2] = 0;
    label = 14;
    break;
   case 14:
    $52 = $file_names + 8 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = ($53 | 0) == 0;
    if ($54) {
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    _ft_mem_free($2, $53);
    HEAP32[$52 >> 2] = 0;
    label = 16;
    break;
   case 16:
    $57 = $file_names + 12 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = ($58 | 0) == 0;
    if ($59) {
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    _ft_mem_free($2, $58);
    HEAP32[$57 >> 2] = 0;
    label = 18;
    break;
   case 18:
    $62 = $file_names + 16 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = ($63 | 0) == 0;
    if ($64) {
      label = 20;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    _ft_mem_free($2, $63);
    HEAP32[$62 >> 2] = 0;
    label = 20;
    break;
   case 20:
    $67 = $file_names + 20 | 0;
    $68 = HEAP32[$67 >> 2] | 0;
    $69 = ($68 | 0) == 0;
    if ($69) {
      label = 22;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    _ft_mem_free($2, $68);
    HEAP32[$67 >> 2] = 0;
    label = 22;
    break;
   case 22:
    $72 = $file_names + 24 | 0;
    $73 = HEAP32[$72 >> 2] | 0;
    $74 = ($73 | 0) == 0;
    if ($74) {
      label = 24;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    _ft_mem_free($2, $73);
    HEAP32[$72 >> 2] = 0;
    label = 24;
    break;
   case 24:
    $77 = $file_names + 28 | 0;
    $78 = HEAP32[$77 >> 2] | 0;
    $79 = ($78 | 0) == 0;
    if ($79) {
      label = 26;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    _ft_mem_free($2, $78);
    HEAP32[$77 >> 2] = 0;
    label = 26;
    break;
   case 26:
    $82 = $file_names + 32 | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = ($83 | 0) == 0;
    if ($84) {
      label = 28;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    _ft_mem_free($2, $83);
    HEAP32[$82 >> 2] = 0;
    label = 28;
    break;
   case 28:
    $87 = ($error_2 | 0) == 0;
    $error_2_ = $87 ? 0 : 2;
    STACKTOP = __stackBase__;
    return $error_2_ | 0;
  }
  return 0;
}
function _raccess_rule_by_darwin_vfs($rule_index) {
  $rule_index = $rule_index | 0;
  return ((_raccess_get_rule_type_from_rule_index($rule_index) | 0) - 3 | 0) >>> 0 < 2 & 1 | 0;
}
function _Mac_Read_POST_Resource($library, $stream, $offsets, $resource_cnt, $face_index, $aface) {
  $library = $library | 0;
  $stream = $stream | 0;
  $offsets = $offsets | 0;
  $resource_cnt = $resource_cnt | 0;
  $face_index = $face_index | 0;
  $aface = $aface | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $_face_index = 0, $4 = 0, $5 = 0, $pfb_len_0115 = 0, $i_0114 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $pfb_len_0_lcssa = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $pfb_lenpos_0108 = 0, $pfb_pos_0107 = 0, $len_0106 = 0, $type_0105 = 0, $i_1104 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $rlen_0 = 0, $47 = 0, $49 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $type_1 = 0, $len_1 = 0, $pfb_pos_1 = 0, $pfb_lenpos_1 = 0, $85 = 0, $87 = 0, $88 = 0, $90 = 0, $91 = 0, $92 = 0, $type_2 = 0, $len_2 = 0, $pfb_pos_2 = 0, $pfb_lenpos_2 = 0, $94 = 0, $95 = 0, $pfb_lenpos_0_lcssa = 0, $pfb_pos_0_lcssa = 0, $len_0_lcssa = 0, $96 = 0, $97 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 1;
    $1 = $library | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($face_index | 0) == -1;
    $_face_index = $3 ? 0 : $face_index;
    $4 = ($_face_index | 0) == 0;
    if ($4) {
      label = 2;
      break;
    } else {
      $_0 = 1;
      label = 27;
      break;
    }
   case 2:
    $5 = ($resource_cnt | 0) > 0;
    if ($5) {
      $i_0114 = 0;
      $pfb_len_0115 = 0;
      label = 3;
      break;
    } else {
      $pfb_len_0_lcssa = 0;
      label = 6;
      break;
    }
   case 3:
    $6 = $offsets + ($i_0114 << 2) | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = _FT_Stream_Seek($stream, $7) | 0;
    HEAP32[$error >> 2] = $8;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 4;
      break;
    } else {
      label = 26;
      break;
    }
   case 4:
    $11 = _FT_Stream_ReadLong($stream, $error) | 0;
    $12 = HEAP32[$error >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 5;
      break;
    } else {
      label = 26;
      break;
    }
   case 5:
    $15 = $pfb_len_0115 + 6 | 0;
    $16 = $15 + $11 | 0;
    $17 = $i_0114 + 1 | 0;
    $18 = ($17 | 0) < ($resource_cnt | 0);
    if ($18) {
      $i_0114 = $17;
      $pfb_len_0115 = $16;
      label = 3;
      break;
    } else {
      $pfb_len_0_lcssa = $16;
      label = 6;
      break;
    }
   case 6:
    $19 = $pfb_len_0_lcssa + 2 | 0;
    $20 = _ft_mem_alloc($2, $19, $error) | 0;
    $21 = HEAP32[$error >> 2] | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 7;
      break;
    } else {
      label = 26;
      break;
    }
   case 7:
    HEAP8[$20] = -128;
    $24 = $20 + 1 | 0;
    HEAP8[$24] = 1;
    $25 = $20 + 2 | 0;
    $26 = ($resource_cnt | 0) > 0;
    $27 = $25;
    tempBigInt = 0;
    HEAP8[$27] = tempBigInt & 255;
    tempBigInt = tempBigInt >> 8;
    HEAP8[$27 + 1 | 0] = tempBigInt & 255;
    tempBigInt = tempBigInt >> 8;
    HEAP8[$27 + 2 | 0] = tempBigInt & 255;
    tempBigInt = tempBigInt >> 8;
    HEAP8[$27 + 3 | 0] = tempBigInt & 255;
    if ($26) {
      $i_1104 = 0;
      $type_0105 = 1;
      $len_0106 = 0;
      $pfb_pos_0107 = 6;
      $pfb_lenpos_0108 = 2;
      label = 8;
      break;
    } else {
      $len_0_lcssa = 0;
      $pfb_pos_0_lcssa = 6;
      $pfb_lenpos_0_lcssa = 2;
      label = 22;
      break;
    }
   case 8:
    $28 = $offsets + ($i_1104 << 2) | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = _FT_Stream_Seek($stream, $29) | 0;
    HEAP32[$error >> 2] = $30;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 9;
      break;
    } else {
      label = 25;
      break;
    }
   case 9:
    $33 = _FT_Stream_ReadLong($stream, $error) | 0;
    $34 = HEAP32[$error >> 2] | 0;
    $35 = ($34 | 0) == 0;
    if ($35) {
      label = 10;
      break;
    } else {
      label = 26;
      break;
    }
   case 10:
    $37 = _FT_Stream_ReadShort($stream, $error) | 0;
    $38 = HEAP32[$error >> 2] | 0;
    $39 = ($38 | 0) == 0;
    if ($39) {
      label = 11;
      break;
    } else {
      label = 26;
      break;
    }
   case 11:
    $41 = $37 & 65535;
    $42 = $41 >>> 8;
    $43 = ($42 | 0) == 0;
    if ($43) {
      $pfb_lenpos_2 = $pfb_lenpos_0108;
      $pfb_pos_2 = $pfb_pos_0107;
      $len_2 = $len_0106;
      $type_2 = $type_0105;
      label = 21;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $45 = ($33 | 0) > 2;
    $46 = $33 - 2 | 0;
    $rlen_0 = $45 ? $46 : 0;
    $47 = ($42 | 0) == ($type_0105 | 0);
    if ($47) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    $49 = $rlen_0 + $len_0106 | 0;
    $pfb_lenpos_1 = $pfb_lenpos_0108;
    $pfb_pos_1 = $pfb_pos_0107;
    $len_1 = $49;
    $type_1 = $type_0105;
    label = 18;
    break;
   case 14:
    $51 = $pfb_lenpos_0108 + 3 | 0;
    $52 = ($51 | 0) > ($19 | 0);
    if ($52) {
      label = 25;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $54 = $len_0106 & 255;
    $55 = $20 + $pfb_lenpos_0108 | 0;
    HEAP8[$55] = $54;
    $56 = $len_0106 >>> 8;
    $57 = $56 & 255;
    $58 = $pfb_lenpos_0108 + 1 | 0;
    $59 = $20 + $58 | 0;
    HEAP8[$59] = $57;
    $60 = $len_0106 >>> 16;
    $61 = $60 & 255;
    $62 = $pfb_lenpos_0108 + 2 | 0;
    $63 = $20 + $62 | 0;
    HEAP8[$63] = $61;
    $64 = $len_0106 >>> 24;
    $65 = $64 & 255;
    $66 = $20 + $51 | 0;
    HEAP8[$66] = $65;
    $67 = ($42 | 0) == 5;
    if ($67) {
      $len_0_lcssa = $len_0106;
      $pfb_pos_0_lcssa = $pfb_pos_0107;
      $pfb_lenpos_0_lcssa = $pfb_lenpos_0108;
      label = 22;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $69 = $pfb_pos_0107 + 6 | 0;
    $70 = ($69 | 0) > ($19 | 0);
    if ($70) {
      label = 25;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $72 = $pfb_pos_0107 + 1 | 0;
    $73 = $20 + $pfb_pos_0107 | 0;
    HEAP8[$73] = -128;
    $74 = $42 & 255;
    $75 = $pfb_pos_0107 + 2 | 0;
    $76 = $20 + $72 | 0;
    HEAP8[$76] = $74;
    $77 = $pfb_pos_0107 + 3 | 0;
    $78 = $20 + $75 | 0;
    HEAP8[$78] = 0;
    $79 = $pfb_pos_0107 + 4 | 0;
    $80 = $20 + $77 | 0;
    HEAP8[$80] = 0;
    $81 = $pfb_pos_0107 + 5 | 0;
    $82 = $20 + $79 | 0;
    HEAP8[$82] = 0;
    $83 = $20 + $81 | 0;
    HEAP8[$83] = 0;
    $pfb_lenpos_1 = $75;
    $pfb_pos_1 = $69;
    $len_1 = $rlen_0;
    $type_1 = $42;
    label = 18;
    break;
   case 18:
    HEAP32[$error >> 2] = 1;
    $85 = ($pfb_pos_1 | 0) > ($pfb_len_0_lcssa | 0);
    if ($85) {
      label = 25;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $87 = $pfb_pos_1 + $rlen_0 | 0;
    $88 = ($87 | 0) > ($pfb_len_0_lcssa | 0);
    if ($88) {
      label = 25;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $90 = $20 + $pfb_pos_1 | 0;
    $91 = _FT_Stream_Read($stream, $90, $rlen_0) | 0;
    HEAP32[$error >> 2] = $91;
    $92 = ($91 | 0) == 0;
    if ($92) {
      $pfb_lenpos_2 = $pfb_lenpos_1;
      $pfb_pos_2 = $87;
      $len_2 = $len_1;
      $type_2 = $type_1;
      label = 21;
      break;
    } else {
      label = 25;
      break;
    }
   case 21:
    $94 = $i_1104 + 1 | 0;
    $95 = ($94 | 0) < ($resource_cnt | 0);
    if ($95) {
      $i_1104 = $94;
      $type_0105 = $type_2;
      $len_0106 = $len_2;
      $pfb_pos_0107 = $pfb_pos_2;
      $pfb_lenpos_0108 = $pfb_lenpos_2;
      label = 8;
      break;
    } else {
      $len_0_lcssa = $len_2;
      $pfb_pos_0_lcssa = $pfb_pos_2;
      $pfb_lenpos_0_lcssa = $pfb_lenpos_2;
      label = 22;
      break;
    }
   case 22:
    $96 = $pfb_pos_0_lcssa + 2 | 0;
    $97 = ($96 | 0) > ($19 | 0);
    if ($97) {
      label = 25;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $99 = $pfb_pos_0_lcssa + 1 | 0;
    $100 = $20 + $pfb_pos_0_lcssa | 0;
    HEAP8[$100] = -128;
    $101 = $20 + $99 | 0;
    HEAP8[$101] = 3;
    $102 = $pfb_lenpos_0_lcssa + 3 | 0;
    $103 = ($102 | 0) > ($19 | 0);
    if ($103) {
      label = 25;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $105 = $len_0_lcssa & 255;
    $106 = $20 + $pfb_lenpos_0_lcssa | 0;
    HEAP8[$106] = $105;
    $107 = $len_0_lcssa >>> 8;
    $108 = $107 & 255;
    $109 = $pfb_lenpos_0_lcssa + 1 | 0;
    $110 = $20 + $109 | 0;
    HEAP8[$110] = $108;
    $111 = $len_0_lcssa >>> 16;
    $112 = $111 & 255;
    $113 = $pfb_lenpos_0_lcssa + 2 | 0;
    $114 = $20 + $113 | 0;
    HEAP8[$114] = $112;
    $115 = $len_0_lcssa >>> 24;
    $116 = $115 & 255;
    $117 = $20 + $102 | 0;
    HEAP8[$117] = $116;
    $118 = _open_face_from_buffer($library, $20, $96, $_face_index, 5323936, $aface) | 0;
    $_0 = $118;
    label = 27;
    break;
   case 25:
    _ft_mem_free($2, $20);
    label = 26;
    break;
   case 26:
    $119 = HEAP32[$error >> 2] | 0;
    $_0 = $119;
    label = 27;
    break;
   case 27:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _Mac_Read_sfnt_Resource($library, $stream, $offsets, $resource_cnt, $face_index, $aface) {
  $library = $library | 0;
  $stream = $stream | 0;
  $offsets = $offsets | 0;
  $resource_cnt = $resource_cnt | 0;
  $face_index = $face_index | 0;
  $aface = $aface | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $_face_index = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $31 = 0, $33 = 0, $34 = 0, $phitmp = 0, $36 = 0, $37 = 0, $39 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $library | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($face_index | 0) == -1;
    $_face_index = $3 ? 0 : $face_index;
    $4 = ($_face_index | 0) < ($resource_cnt | 0);
    if ($4) {
      label = 2;
      break;
    } else {
      $_0 = 1;
      label = 13;
      break;
    }
   case 2:
    $6 = $offsets + ($_face_index << 2) | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = _FT_Stream_Seek($stream, $7) | 0;
    HEAP32[$error >> 2] = $8;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 3;
      break;
    } else {
      label = 12;
      break;
    }
   case 3:
    $11 = _FT_Stream_ReadLong($stream, $error) | 0;
    $12 = HEAP32[$error >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 4;
      break;
    } else {
      label = 12;
      break;
    }
   case 4:
    $15 = ($11 | 0) == -1;
    if ($15) {
      $_0 = 1;
      label = 13;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = _open_face_PS_from_sfnt_stream($library, $stream, $_face_index, $aface) | 0;
    HEAP32[$error >> 2] = $17;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 12;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $20 = $7 + 4 | 0;
    $21 = _FT_Stream_Seek($stream, $20) | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 7;
      break;
    } else {
      label = 12;
      break;
    }
   case 7:
    $24 = _ft_mem_alloc($2, $11, $error) | 0;
    $25 = HEAP32[$error >> 2] | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 8;
      break;
    } else {
      $_0 = $25;
      label = 13;
      break;
    }
   case 8:
    $28 = _FT_Stream_Read($stream, $24, $11) | 0;
    HEAP32[$error >> 2] = $28;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 9;
      break;
    } else {
      label = 12;
      break;
    }
   case 9:
    $31 = ($11 | 0) > 4;
    if ($31) {
      label = 10;
      break;
    } else {
      $36 = 5321480;
      label = 11;
      break;
    }
   case 10:
    $33 = _memcmp($24 | 0, 5324112, 4) | 0;
    $34 = ($33 | 0) != 0;
    $phitmp = $34 ? 5321480 : 5324020;
    $36 = $phitmp;
    label = 11;
    break;
   case 11:
    $37 = _open_face_from_buffer($library, $24, $11, 0, $36, $aface) | 0;
    HEAP32[$error >> 2] = $37;
    label = 12;
    break;
   case 12:
    $39 = HEAP32[$error >> 2] | 0;
    $_0 = $39;
    label = 13;
    break;
   case 13:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _open_face_from_buffer($library, $base, $size, $face_index, $driver_name, $aface) {
  $library = $library | 0;
  $base = $base | 0;
  $size = $size | 0;
  $face_index = $face_index | 0;
  $driver_name = $driver_name | 0;
  $aface = $aface | 0;
  var $args = 0, $stream = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 36 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $args = __stackBase__ | 0;
    $stream = __stackBase__ + 32 | 0;
    HEAP32[$stream >> 2] = 0;
    $1 = $library | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _new_memory_stream($library, $base, $size, $stream) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    _ft_mem_free($2, $base);
    $_0 = $3;
    label = 8;
    break;
   case 3:
    $7 = $args | 0;
    HEAP32[$7 >> 2] = 2;
    $8 = HEAP32[$stream >> 2] | 0;
    $9 = $args + 16 | 0;
    HEAP32[$9 >> 2] = $8;
    $10 = ($driver_name | 0) == 0;
    if ($10) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $12 = HEAP32[$7 >> 2] | 0;
    $13 = $12 | 8;
    HEAP32[$7 >> 2] = $13;
    $14 = _FT_Get_Module($library, $driver_name) | 0;
    $15 = $args + 20 | 0;
    HEAP32[$15 >> 2] = $14;
    label = 5;
    break;
   case 5:
    $17 = _FT_Open_Face($library, $args, $face_index, $aface) | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $20 = HEAP32[$aface >> 2] | 0;
    $21 = $20 + 8 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22 & -1025;
    HEAP32[$21 >> 2] = $23;
    $_0 = 0;
    label = 8;
    break;
   case 7:
    $25 = HEAP32[$stream >> 2] | 0;
    _FT_Stream_Close($25);
    $26 = HEAP32[$stream >> 2] | 0;
    $27 = $26;
    _ft_mem_free($2, $27);
    HEAP32[$stream >> 2] = 0;
    $_0 = $17;
    label = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _pcf_cmap_init($pcfcmap, $init_data) {
  $pcfcmap = $pcfcmap | 0;
  $init_data = $init_data | 0;
  var $2 = 0;
  $2 = HEAP32[$pcfcmap >> 2] | 0;
  HEAP32[$pcfcmap + 16 >> 2] = HEAP32[$2 + 296 >> 2] | 0;
  HEAP32[$pcfcmap + 20 >> 2] = HEAP32[$2 + 300 >> 2] | 0;
  return 0;
}
function _pcf_cmap_done($pcfcmap) {
  $pcfcmap = $pcfcmap | 0;
  HEAP32[$pcfcmap + 20 >> 2] = 0;
  HEAP32[$pcfcmap + 16 >> 2] = 0;
  return;
}
function _pcf_cmap_char_index($pcfcmap, $charcode) {
  $pcfcmap = $pcfcmap | 0;
  $charcode = $charcode | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $min_011 = 0, $max_010 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $_max_0 = 0, $min_0_ = 0, $21 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $pcfcmap + 20 | 0;
    $2 = $1;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $pcfcmap + 16 | 0;
    $5 = $4;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      $result_0 = 0;
      label = 5;
      break;
    } else {
      $max_010 = $6;
      $min_011 = 0;
      label = 2;
      break;
    }
   case 2:
    $8 = $min_011 + $max_010 | 0;
    $9 = $8 >>> 1;
    $10 = $3 + ($9 << 3) | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($11 | 0) == ($charcode | 0);
    if ($12) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $14 = $3 + ($9 << 3) + 4 | 0;
    $15 = HEAP16[$14 >> 1] | 0;
    $16 = $15 & 65535;
    $17 = $16 + 1 | 0;
    $result_0 = $17;
    label = 5;
    break;
   case 4:
    $19 = $11 >>> 0 > $charcode >>> 0;
    $20 = $9 + 1 | 0;
    $_max_0 = $19 ? $9 : $max_010;
    $min_0_ = $19 ? $min_011 : $20;
    $21 = $min_0_ >>> 0 < $_max_0 >>> 0;
    if ($21) {
      $max_010 = $_max_0;
      $min_011 = $min_0_;
      label = 2;
      break;
    } else {
      $result_0 = 0;
      label = 5;
      break;
    }
   case 5:
    return $result_0 | 0;
  }
  return 0;
}
function _pcf_cmap_char_next($pcfcmap, $acharcode) {
  $pcfcmap = $pcfcmap | 0;
  $acharcode = $acharcode | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $min_022 = 0, $max_021 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $_max_0 = 0, $min_0_ = 0, $23 = 0, $min_0_lcssa = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $charcode_0 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $pcfcmap + 20 | 0;
    $2 = $1;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = HEAP32[$acharcode >> 2] | 0;
    $5 = $4 + 1 | 0;
    $6 = $pcfcmap + 16 | 0;
    $7 = $6;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      $min_0_lcssa = 0;
      label = 5;
      break;
    } else {
      $max_021 = $8;
      $min_022 = 0;
      label = 2;
      break;
    }
   case 2:
    $10 = $min_022 + $max_021 | 0;
    $11 = $10 >>> 1;
    $12 = $3 + ($11 << 3) | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = ($5 | 0) == ($13 | 0);
    if ($14) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $16 = $3 + ($11 << 3) + 4 | 0;
    $17 = HEAP16[$16 >> 1] | 0;
    $18 = $17 & 65535;
    $19 = $18 + 1 | 0;
    $result_0 = $19;
    $charcode_0 = $5;
    label = 7;
    break;
   case 4:
    $21 = $5 >>> 0 < $13 >>> 0;
    $22 = $11 + 1 | 0;
    $_max_0 = $21 ? $11 : $max_021;
    $min_0_ = $21 ? $min_022 : $22;
    $23 = $min_0_ >>> 0 < $_max_0 >>> 0;
    if ($23) {
      $max_021 = $_max_0;
      $min_022 = $min_0_;
      label = 2;
      break;
    } else {
      $min_0_lcssa = $min_0_;
      label = 5;
      break;
    }
   case 5:
    $24 = HEAP32[$7 >> 2] | 0;
    $25 = $min_0_lcssa >>> 0 < $24 >>> 0;
    if ($25) {
      label = 6;
      break;
    } else {
      $result_0 = 0;
      $charcode_0 = 0;
      label = 7;
      break;
    }
   case 6:
    $27 = $3 + ($min_0_lcssa << 3) | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $3 + ($min_0_lcssa << 3) + 4 | 0;
    $30 = HEAP16[$29 >> 1] | 0;
    $31 = $30 & 65535;
    $32 = $31 + 1 | 0;
    $result_0 = $32;
    $charcode_0 = $28;
    label = 7;
    break;
   case 7:
    HEAP32[$acharcode >> 2] = $charcode_0;
    return $result_0 | 0;
  }
  return 0;
}
function _new_memory_stream($library, $base, $size, $astream) {
  $library = $library | 0;
  $base = $base | 0;
  $size = $size | 0;
  $astream = $astream | 0;
  var $error = 0, $1 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $15 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = ($library | 0) == 0;
    if ($1) {
      $_0 = 33;
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = ($base | 0) == 0;
    if ($3) {
      $_0 = 6;
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    HEAP32[$astream >> 2] = 0;
    $5 = $library | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = _ft_mem_alloc($6, 40, $error) | 0;
    $8 = $7;
    $9 = HEAP32[$error >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    _FT_Stream_OpenMemory($8, $base, $size);
    $12 = $7 + 24 | 0;
    $13 = $12;
    HEAP32[$13 >> 2] = 864;
    HEAP32[$astream >> 2] = $8;
    label = 5;
    break;
   case 5:
    $15 = HEAP32[$error >> 2] | 0;
    $_0 = $15;
    label = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _memory_stream_close($stream) {
  $stream = $stream | 0;
  var $3 = 0;
  $3 = $stream | 0;
  _ft_mem_free(HEAP32[$stream + 28 >> 2] | 0, HEAP32[$3 >> 2] | 0);
  HEAP32[$stream + 4 >> 2] = 0;
  HEAP32[$3 >> 2] = 0;
  HEAP32[$stream + 24 >> 2] = 0;
  return;
}
function _ft_lookup_PS_in_sfnt_stream($stream, $face_index, $offset, $length, $is_sfnt_cid) {
  $stream = $stream | 0;
  $face_index = $face_index | 0;
  $offset = $offset | 0;
  $length = $length | 0;
  $is_sfnt_cid = $is_sfnt_cid | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $pstable_index_0 = 0, $i_0 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $pstable_index_1 = 0, $51 = 0, $or_cond = 0, $52 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$offset >> 2] = 0;
    HEAP32[$length >> 2] = 0;
    HEAP8[$is_sfnt_cid] = 0;
    $1 = _FT_Stream_ReadLong($stream, $error) | 0;
    $2 = HEAP32[$error >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $_0 = $2;
      label = 16;
      break;
    }
   case 2:
    $5 = ($1 | 0) == 1954115633;
    if ($5) {
      label = 3;
      break;
    } else {
      $_0 = 2;
      label = 16;
      break;
    }
   case 3:
    $7 = _FT_Stream_ReadShort($stream, $error) | 0;
    $8 = HEAP32[$error >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 4;
      break;
    } else {
      $_0 = $8;
      label = 16;
      break;
    }
   case 4:
    $11 = _FT_Stream_Skip($stream, 6) | 0;
    HEAP32[$error >> 2] = $11;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 5;
      break;
    } else {
      $_0 = $11;
      label = 16;
      break;
    }
   case 5:
    HEAP8[$is_sfnt_cid] = 0;
    $14 = $7 & 65535;
    $15 = ($face_index | 0) > -1;
    $16 = ($face_index | 0) < 0;
    $17 = ($face_index | 0) < 0;
    $i_0 = 0;
    $pstable_index_0 = -1;
    label = 6;
    break;
   case 6:
    $19 = ($i_0 | 0) < ($14 | 0);
    if ($19) {
      label = 7;
      break;
    } else {
      $_0 = 142;
      label = 16;
      break;
    }
   case 7:
    $21 = _FT_Stream_ReadLong($stream, $error) | 0;
    $22 = HEAP32[$error >> 2] | 0;
    $23 = ($22 | 0) == 0;
    if ($23) {
      label = 8;
      break;
    } else {
      label = 11;
      break;
    }
   case 8:
    $25 = _FT_Stream_Skip($stream, 4) | 0;
    HEAP32[$error >> 2] = $25;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 9;
      break;
    } else {
      label = 11;
      break;
    }
   case 9:
    $28 = _FT_Stream_ReadLong($stream, $error) | 0;
    HEAP32[$offset >> 2] = $28;
    $29 = HEAP32[$error >> 2] | 0;
    $30 = ($29 | 0) == 0;
    if ($30) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $32 = _FT_Stream_ReadLong($stream, $error) | 0;
    HEAP32[$length >> 2] = $32;
    $33 = HEAP32[$error >> 2] | 0;
    $34 = ($33 | 0) == 0;
    if ($34) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $36 = HEAP32[$error >> 2] | 0;
    $_0 = $36;
    label = 16;
    break;
   case 12:
    if (($21 | 0) == 1128875040) {
      label = 13;
      break;
    } else if (($21 | 0) == 1415139377) {
      label = 14;
      break;
    } else {
      $pstable_index_1 = $pstable_index_0;
      label = 15;
      break;
    }
   case 13:
    $39 = $pstable_index_0 + 1 | 0;
    $40 = HEAP32[$offset >> 2] | 0;
    $41 = $40 + 22 | 0;
    HEAP32[$offset >> 2] = $41;
    $42 = HEAP32[$length >> 2] | 0;
    $43 = $42 - 22 | 0;
    HEAP32[$length >> 2] = $43;
    HEAP8[$is_sfnt_cid] = 1;
    if ($16) {
      $_0 = 0;
      label = 16;
      break;
    } else {
      $pstable_index_1 = $39;
      label = 15;
      break;
    }
   case 14:
    $45 = $pstable_index_0 + 1 | 0;
    $46 = HEAP32[$offset >> 2] | 0;
    $47 = $46 + 24 | 0;
    HEAP32[$offset >> 2] = $47;
    $48 = HEAP32[$length >> 2] | 0;
    $49 = $48 - 24 | 0;
    HEAP32[$length >> 2] = $49;
    HEAP8[$is_sfnt_cid] = 0;
    if ($17) {
      $_0 = 0;
      label = 16;
      break;
    } else {
      $pstable_index_1 = $45;
      label = 15;
      break;
    }
   case 15:
    $51 = ($pstable_index_1 | 0) == ($face_index | 0);
    $or_cond = $15 & $51;
    $52 = $i_0 + 1 | 0;
    if ($or_cond) {
      $_0 = 0;
      label = 16;
      break;
    } else {
      $i_0 = $52;
      $pstable_index_0 = $pstable_index_1;
      label = 6;
      break;
    }
   case 16:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _FT_Add_Default_Modules($library) {
  $library = $library | 0;
  var $1 = 0, $cur_03 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0;
  label = 2;
  while (1) switch (label | 0) {
   case 2:
    $cur_03 = 5257016;
    $1 = 5244200;
    label = 1;
    break;
   case 1:
    $2 = _FT_Add_Module($library, $1) | 0;
    $3 = $cur_03 + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 3;
      break;
    } else {
      $cur_03 = $3;
      $1 = $4;
      label = 1;
      break;
    }
   case 3:
    return;
  }
}
function _FT_Init_FreeType($alibrary) {
  $alibrary = $alibrary | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $8 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _FT_New_Memory() | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      $_0 = 7;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = _FT_New_Library($1, $alibrary) | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    _FT_Done_Memory($1);
    $_0 = $4;
    label = 5;
    break;
   case 4:
    $8 = HEAP32[$alibrary >> 2] | 0;
    _FT_Add_Default_Modules($8);
    $_0 = 0;
    label = 5;
    break;
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function _FT_Done_FreeType($library) {
  $library = $library | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($library | 0) == 0;
    if ($1) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $library | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = _FT_Done_Library($library) | 0;
    _FT_Done_Memory($4);
    label = 3;
    break;
   case 3:
    return 0;
  }
  return 0;
}
function _FT_Stream_Open($stream, $filepathname) {
  $stream = $stream | 0;
  $filepathname = $filepathname | 0;
  var $1 = 0, $3 = 0, $4 = 0, $filepathname_c = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, $_c = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($stream | 0) == 0;
    if ($1) {
      $_0 = 40;
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $stream + 12 | 0;
    HEAP32[$3 >> 2] = 0;
    $4 = $stream + 16 | 0;
    $filepathname_c = $filepathname;
    HEAP32[$4 >> 2] = $filepathname_c;
    $5 = $stream | 0;
    HEAP32[$5 >> 2] = 0;
    $6 = $stream + 8 | 0;
    HEAP32[$6 >> 2] = 0;
    $7 = $stream + 20 | 0;
    HEAP32[$7 >> 2] = 0;
    $8 = $stream + 24 | 0;
    HEAP32[$8 >> 2] = 0;
    $9 = _fopen($filepathname | 0, 5323084) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      $_0 = 1;
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = _fseek($9 | 0, 0, 2) | 0;
    $13 = _ftell($9 | 0) | 0;
    $14 = $stream + 4 | 0;
    HEAP32[$14 >> 2] = $13;
    $15 = ($13 | 0) == 0;
    if ($15) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $17 = _fclose($9 | 0) | 0;
    $_0 = 81;
    label = 6;
    break;
   case 5:
    $19 = _fseek($9 | 0, 0, 0) | 0;
    $_c = $9;
    HEAP32[$3 >> 2] = $_c;
    HEAP32[$7 >> 2] = 72;
    HEAP32[$8 >> 2] = 912;
    $_0 = 0;
    label = 6;
    break;
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _ft_ansi_stream_io($stream, $offset, $buffer, $count) {
  $stream = $stream | 0;
  $offset = $offset | 0;
  $buffer = $buffer | 0;
  $count = $count | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $17 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($count | 0) == 0;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = $stream + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 >>> 0 < $offset >>> 0;
    if ($5) {
      $_0 = 1;
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $stream + 12 | 0;
    $8 = $7;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9;
    $11 = $stream + 8 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($12 | 0) == ($offset | 0);
    if ($13) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $15 = _fseek($10 | 0, $offset | 0, 0) | 0;
    label = 5;
    break;
   case 5:
    $17 = _fread($buffer | 0, 1, $count | 0, $10 | 0) | 0;
    $_0 = $17;
    label = 6;
    break;
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _ft_ansi_stream_close($stream) {
  $stream = $stream | 0;
  var $1 = 0;
  $1 = $stream + 12 | 0;
  _fclose(HEAP32[$1 >> 2] | 0);
  HEAP32[$1 >> 2] = 0;
  HEAP32[$stream + 4 >> 2] = 0;
  HEAP32[$stream >> 2] = 0;
  return;
}
function _FT_New_Memory() {
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _malloc(16) | 0;
    $2 = $1;
    $3 = ($1 | 0) == 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $1;
    HEAP32[$5 >> 2] = 0;
    $6 = $1 + 4 | 0;
    $7 = $6;
    HEAP32[$7 >> 2] = 354;
    $8 = $1 + 12 | 0;
    $9 = $8;
    HEAP32[$9 >> 2] = 8;
    $10 = $1 + 8 | 0;
    $11 = $10;
    HEAP32[$11 >> 2] = 616;
    label = 3;
    break;
   case 3:
    return $2 | 0;
  }
  return 0;
}
function _ft_alloc($memory, $size) {
  $memory = $memory | 0;
  $size = $size | 0;
  return _malloc($size) | 0;
}
function _ft_realloc($memory, $cur_size, $new_size, $block) {
  $memory = $memory | 0;
  $cur_size = $cur_size | 0;
  $new_size = $new_size | 0;
  $block = $block | 0;
  return _realloc($block, $new_size) | 0;
}
function _ft_free($memory, $block) {
  $memory = $memory | 0;
  $block = $block | 0;
  _free($block);
  return;
}
function _FT_Done_Memory($memory) {
  $memory = $memory | 0;
  _free($memory);
  return;
}
function _pcf_driver_requester($module, $name) {
  $module = $module | 0;
  $name = $name | 0;
  return _ft_service_list_lookup(5250604, $name) | 0;
}
function _PCF_Face_Init($stream, $pcfface, $face_index, $num_params, $params) {
  $stream = $stream | 0;
  $pcfface = $pcfface | 0;
  $face_index = $face_index | 0;
  $num_params = $num_params | 0;
  $params = $params | 0;
  var $charmap = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $or_cond = 0, $17 = 0, $stream_c = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $31 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $$etemp$0$0 = 0, $$etemp$0$1 = 0, $st$1$0 = 0, $st$2$1 = 0, $53 = 0, $54 = 0, $55 = 0, $$etemp$3$0 = 0, $$etemp$3$1 = 0, $st$4$0 = 0, $st$5$1 = 0, $56 = 0, $57 = 0, $59 = 0, $error_1 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $charmap = __stackBase__ | 0;
    $1 = $pcfface;
    $2 = _pcf_load_font($stream, $1) | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    _PCF_Face_Done($pcfface);
    $5 = $pcfface + 132 | 0;
    $6 = $5;
    $7 = _FT_Stream_OpenGzip($6, $stream) | 0;
    $8 = $7 & 255;
    $9 = ($8 | 0) == 7;
    if ($9) {
      label = 18;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = ($7 | 0) == 0;
    if ($11) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $13 = _FT_Stream_OpenLZW($6, $stream) | 0;
    $14 = $13 & 255;
    $15 = ($14 | 0) != 7;
    $16 = ($13 | 0) == 0;
    $or_cond = $15 & $16;
    if ($or_cond) {
      label = 5;
      break;
    } else {
      label = 18;
      break;
    }
   case 5:
    $17 = $pcfface + 172 | 0;
    $stream_c = $stream;
    HEAP32[$17 >> 2] = $stream_c;
    $18 = $pcfface + 104 | 0;
    HEAP32[$18 >> 2] = $6;
    $19 = _pcf_load_font($6, $1) | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 6;
      break;
    } else {
      label = 18;
      break;
    }
   case 6:
    $22 = $pcfface + 180 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $23;
    $25 = $pcfface + 176 | 0;
    $26 = ($23 | 0) == 0;
    if ($26) {
      label = 14;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $28 = HEAP32[$25 >> 2] | 0;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 14;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $31 = HEAP8[$24] | 0;
    if (($31 << 24 >> 24 | 0) == 105 | ($31 << 24 >> 24 | 0) == 73) {
      label = 9;
      break;
    } else {
      label = 14;
      break;
    }
   case 9:
    $33 = $24 + 1 | 0;
    $34 = HEAP8[$33] | 0;
    if (($34 << 24 >> 24 | 0) == 115 | ($34 << 24 >> 24 | 0) == 83) {
      label = 10;
      break;
    } else {
      label = 14;
      break;
    }
   case 10:
    $36 = $24 + 2 | 0;
    $37 = HEAP8[$36] | 0;
    if (($37 << 24 >> 24 | 0) == 111 | ($37 << 24 >> 24 | 0) == 79) {
      label = 11;
      break;
    } else {
      label = 14;
      break;
    }
   case 11:
    $39 = $24 + 3 | 0;
    $40 = _strcmp($39 | 0, 5324228) | 0;
    $41 = ($40 | 0) == 0;
    if ($41) {
      label = 15;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $43 = _strcmp($39 | 0, 5323260) | 0;
    $44 = ($43 | 0) == 0;
    if ($44) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    $46 = HEAP32[$25 >> 2] | 0;
    $47 = _strcmp($46 | 0, 5322428) | 0;
    $48 = ($47 | 0) == 0;
    if ($48) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $49 = $charmap | 0;
    HEAP32[$49 >> 2] = $pcfface;
    $50 = $charmap + 4 | 0;
    $51 = $50;
    $$etemp$0$0 = 0;
    $$etemp$0$1 = 0;
    $st$1$0 = $51 | 0;
    HEAP32[$st$1$0 >> 2] = $$etemp$0$0;
    $st$2$1 = $51 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $$etemp$0$1;
    label = 16;
    break;
   case 15:
    $53 = $charmap | 0;
    HEAP32[$53 >> 2] = $pcfface;
    $54 = $charmap + 4 | 0;
    $55 = $54;
    $$etemp$3$0 = 0;
    $$etemp$3$1 = 0;
    $st$4$0 = $55 | 0;
    HEAP32[$st$4$0 >> 2] = $$etemp$3$0;
    $st$5$1 = $55 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $$etemp$3$1;
    $56 = $charmap + 10 | 0;
    $57 = $charmap + 8 | 0;
    HEAP32[$54 >> 2] = 1970170211;
    HEAP16[$57 >> 1] = 3;
    HEAP16[$56 >> 1] = 1;
    label = 16;
    break;
   case 16:
    $59 = _FT_CMap_New(5250872, 0, $charmap, 0) | 0;
    $error_1 = $59;
    label = 17;
    break;
   case 17:
    STACKTOP = __stackBase__;
    return $error_1 | 0;
   case 18:
    _PCF_Face_Done($pcfface);
    $error_1 = 2;
    label = 17;
    break;
  }
  return 0;
}
function _PCF_Face_Done($pcfface) {
  $pcfface = $pcfface | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $i_045 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($pcfface | 0) == 0;
    if ($1) {
      label = 10;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $pcfface + 100 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $pcfface + 300 | 0;
    $6 = $5;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7;
    _ft_mem_free($4, $8);
    HEAP32[$5 >> 2] = 0;
    $9 = $pcfface + 292 | 0;
    $10 = $9;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11;
    _ft_mem_free($4, $12);
    HEAP32[$9 >> 2] = 0;
    $13 = $pcfface + 284 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 8;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $16 = $pcfface + 280 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($17 | 0) > 0;
    if ($18) {
      $i_045 = 0;
      label = 4;
      break;
    } else {
      label = 8;
      break;
    }
   case 4:
    $19 = HEAP32[$13 >> 2] | 0;
    $20 = $19;
    $21 = $20 + ($i_045 * 12 & -1) | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $24 = $21 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    _ft_mem_free($4, $25);
    HEAP32[$24 >> 2] = 0;
    $26 = $20 + ($i_045 * 12 & -1) + 4 | 0;
    $27 = HEAP8[$26] | 0;
    $28 = $27 << 24 >> 24 == 0;
    if ($28) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $30 = $20 + ($i_045 * 12 & -1) + 8 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    _ft_mem_free($4, $31);
    HEAP32[$30 >> 2] = 0;
    label = 7;
    break;
   case 7:
    $33 = $i_045 + 1 | 0;
    $34 = HEAP32[$16 >> 2] | 0;
    $35 = ($33 | 0) < ($34 | 0);
    if ($35) {
      $i_045 = $33;
      label = 4;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $36 = HEAP32[$13 >> 2] | 0;
    _ft_mem_free($4, $36);
    HEAP32[$13 >> 2] = 0;
    $37 = $pcfface + 192 | 0;
    $38 = $37;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = $39;
    _ft_mem_free($4, $40);
    HEAP32[$37 >> 2] = 0;
    $41 = $pcfface + 20 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    _ft_mem_free($4, $42);
    HEAP32[$41 >> 2] = 0;
    $43 = $pcfface + 24 | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    _ft_mem_free($4, $44);
    HEAP32[$43 >> 2] = 0;
    $45 = $pcfface + 32 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $46;
    _ft_mem_free($4, $47);
    HEAP32[$45 >> 2] = 0;
    $48 = $pcfface + 176 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    _ft_mem_free($4, $49);
    HEAP32[$48 >> 2] = 0;
    $50 = $pcfface + 180 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = $51;
    _ft_mem_free($4, $52);
    HEAP32[$50 >> 2] = 0;
    $53 = $pcfface + 104 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = $pcfface + 132 | 0;
    $56 = $55;
    $57 = ($54 | 0) == ($56 | 0);
    if ($57) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    _FT_Stream_Close($56);
    $59 = $pcfface + 172 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = $60;
    HEAP32[$53 >> 2] = $61;
    label = 10;
    break;
   case 10:
    return;
  }
}
function _PCF_Glyph_Load($slot, $size, $glyph_index, $load_flags) {
  $slot = $slot | 0;
  $size = $size | 0;
  $glyph_index = $glyph_index | 0;
  $load_flags = $load_flags | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $glyph_index_ = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $_lobit = 0, $81 = 0, $83 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $92 = 0, $93 = 0, $94 = 0, $96 = 0, $98 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      $_0 = 6;
      label = 18;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 + 16 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 >>> 0 > $glyph_index >>> 0;
    if ($7) {
      label = 3;
      break;
    } else {
      $_0 = 6;
      label = 18;
      break;
    }
   case 3:
    $9 = $2 + 104 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($glyph_index | 0) == 0;
    $12 = $glyph_index - 1 | 0;
    $glyph_index_ = $11 ? 0 : $12;
    $13 = $2 + 292 | 0;
    $14 = $13;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15 + ($glyph_index_ << 4) + 6 | 0;
    $17 = HEAP16[$16 >> 1] | 0;
    $18 = $17 << 16 >> 16;
    $19 = $15 + ($glyph_index_ << 4) + 8 | 0;
    $20 = HEAP16[$19 >> 1] | 0;
    $21 = $20 << 16 >> 16;
    $22 = $21 + $18 | 0;
    $23 = $slot + 76 | 0;
    HEAP32[$23 >> 2] = $22;
    $24 = $15 + ($glyph_index_ << 4) + 2 | 0;
    $25 = HEAP16[$24 >> 1] | 0;
    $26 = $25 << 16 >> 16;
    $27 = $15 + ($glyph_index_ << 4) | 0;
    $28 = HEAP16[$27 >> 1] | 0;
    $29 = $28 << 16 >> 16;
    $30 = $26 - $29 | 0;
    $31 = $slot + 80 | 0;
    HEAP32[$31 >> 2] = $30;
    $32 = $slot + 92 | 0;
    HEAP16[$32 >> 1] = 1;
    $33 = $slot + 94 | 0;
    HEAP8[$33] = 1;
    $34 = $2 + 308 | 0;
    $35 = $34;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $36 & 3;
    $38 = 1 << $37;
    if (($38 | 0) == 1) {
      label = 4;
      break;
    } else if (($38 | 0) == 2) {
      label = 5;
      break;
    } else if (($38 | 0) == 4) {
      label = 6;
      break;
    } else if (($38 | 0) == 8) {
      label = 7;
      break;
    } else {
      $_0 = 3;
      label = 18;
      break;
    }
   case 4:
    $40 = HEAP32[$31 >> 2] | 0;
    $41 = $40 + 7 | 0;
    $42 = $41 >> 3;
    $43 = $slot + 84 | 0;
    HEAP32[$43 >> 2] = $42;
    label = 8;
    break;
   case 5:
    $45 = HEAP32[$31 >> 2] | 0;
    $46 = $45 + 15 | 0;
    $47 = $46 >> 4;
    $48 = $47 << 1;
    $49 = $slot + 84 | 0;
    HEAP32[$49 >> 2] = $48;
    label = 8;
    break;
   case 6:
    $51 = HEAP32[$31 >> 2] | 0;
    $52 = $51 + 31 | 0;
    $53 = $52 >> 5;
    $54 = $53 << 2;
    $55 = $slot + 84 | 0;
    HEAP32[$55 >> 2] = $54;
    label = 8;
    break;
   case 7:
    $57 = HEAP32[$31 >> 2] | 0;
    $58 = $57 + 63 | 0;
    $59 = $58 >> 6;
    $60 = $59 << 3;
    $61 = $slot + 84 | 0;
    HEAP32[$61 >> 2] = $60;
    label = 8;
    break;
   case 8:
    $63 = $slot + 84 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = HEAP32[$23 >> 2] | 0;
    $66 = Math_imul($65, $64);
    $67 = _ft_glyphslot_alloc_bitmap($slot, $66) | 0;
    $68 = ($67 | 0) == 0;
    if ($68) {
      label = 9;
      break;
    } else {
      $_0 = $67;
      label = 18;
      break;
    }
   case 9:
    $70 = $15 + ($glyph_index_ << 4) + 12 | 0;
    $71 = HEAP32[$70 >> 2] | 0;
    $72 = _FT_Stream_Seek($10, $71) | 0;
    $73 = ($72 | 0) == 0;
    if ($73) {
      label = 10;
      break;
    } else {
      $_0 = $72;
      label = 18;
      break;
    }
   case 10:
    $75 = $slot + 88 | 0;
    $76 = HEAP32[$75 >> 2] | 0;
    $77 = _FT_Stream_Read($10, $76, $66) | 0;
    $78 = ($77 | 0) == 0;
    if ($78) {
      label = 11;
      break;
    } else {
      $_0 = $77;
      label = 18;
      break;
    }
   case 11:
    $80 = HEAP32[$35 >> 2] | 0;
    $_lobit = $80 & 8;
    $81 = ($_lobit | 0) == 0;
    if ($81) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $83 = HEAP32[$75 >> 2] | 0;
    _BitOrderInvert($83, $66);
    label = 13;
    break;
   case 13:
    $85 = HEAP32[$35 >> 2] | 0;
    $86 = $85 >>> 2;
    $87 = $85 >>> 3;
    $88 = $86 ^ $87;
    $89 = $88 & 1;
    $90 = ($89 | 0) == 0;
    if ($90) {
      label = 17;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $92 = $85 >>> 4;
    $93 = $92 & 3;
    $94 = 1 << $93;
    if (($94 | 0) == 2) {
      label = 15;
      break;
    } else if (($94 | 0) == 4) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 15:
    $96 = HEAP32[$75 >> 2] | 0;
    _TwoByteSwap($96, $66);
    label = 17;
    break;
   case 16:
    $98 = HEAP32[$75 >> 2] | 0;
    _FourByteSwap($98, $66);
    label = 17;
    break;
   case 17:
    $100 = $slot + 72 | 0;
    HEAP32[$100 >> 2] = 1651078259;
    $101 = HEAP16[$27 >> 1] | 0;
    $102 = $101 << 16 >> 16;
    $103 = $slot + 100 | 0;
    HEAP32[$103 >> 2] = $102;
    $104 = HEAP16[$16 >> 1] | 0;
    $105 = $104 << 16 >> 16;
    $106 = $slot + 104 | 0;
    HEAP32[$106 >> 2] = $105;
    $107 = $15 + ($glyph_index_ << 4) + 4 | 0;
    $108 = HEAP16[$107 >> 1] | 0;
    $109 = $108 << 16 >> 16;
    $110 = $109 << 6;
    $111 = $slot + 24 | 0;
    $112 = $slot + 40 | 0;
    HEAP32[$112 >> 2] = $110;
    $113 = HEAP16[$27 >> 1] | 0;
    $114 = $113 << 16 >> 16;
    $115 = $114 << 6;
    $116 = $slot + 32 | 0;
    HEAP32[$116 >> 2] = $115;
    $117 = HEAP16[$16 >> 1] | 0;
    $118 = $117 << 16 >> 16;
    $119 = $118 << 6;
    $120 = $slot + 36 | 0;
    HEAP32[$120 >> 2] = $119;
    $121 = HEAP16[$24 >> 1] | 0;
    $122 = $121 << 16 >> 16;
    $123 = HEAP16[$27 >> 1] | 0;
    $124 = $123 << 16 >> 16;
    $125 = $122 - $124 | 0;
    $126 = $125 << 6;
    $127 = $111 | 0;
    HEAP32[$127 >> 2] = $126;
    $128 = HEAP32[$23 >> 2] | 0;
    $129 = $128 << 6;
    $130 = $slot + 28 | 0;
    HEAP32[$130 >> 2] = $129;
    $131 = $2 + 196 | 0;
    $132 = $131 + 8 | 0;
    $133 = HEAP32[$132 >> 2] | 0;
    $134 = $131 + 12 | 0;
    $135 = HEAP32[$134 >> 2] | 0;
    $136 = $135 + $133 | 0;
    $137 = $136 << 6;
    _ft_synthesize_vertical_metrics($111, $137);
    $_0 = $77;
    label = 18;
    break;
   case 18:
    return $_0 | 0;
  }
  return 0;
}
function _PCF_Size_Request($size, $req) {
  $size = $size | 0;
  $req = $req | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $_sink13 = 0, $33 = 0, $_ = 0, $35 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 32 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $req + 16 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == 0;
    $8 = $req + 8 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    if ($7) {
      $15 = $9;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $11 = Math_imul($9, $6);
    $12 = $11 + 36 | 0;
    $13 = ($12 | 0) / 72 & -1;
    $15 = $13;
    label = 3;
    break;
   case 3:
    $16 = $15 + 32 | 0;
    $17 = $16 >> 6;
    $18 = $req | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    if (($19 | 0) == 0) {
      label = 4;
      break;
    } else if (($19 | 0) == 1) {
      label = 5;
      break;
    } else {
      $_0 = 7;
      label = 8;
      break;
    }
   case 4:
    $21 = $4 + 12 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22 + 32 | 0;
    $24 = $23 >> 6;
    $_sink13 = $24;
    label = 6;
    break;
   case 5:
    $26 = $2 + 196 | 0;
    $27 = $26 + 8 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $26 + 12 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $30 + $28 | 0;
    $_sink13 = $31;
    label = 6;
    break;
   case 6:
    $33 = ($17 | 0) == ($_sink13 | 0);
    $_ = $33 ? 0 : 23;
    if ($33) {
      label = 7;
      break;
    } else {
      $_0 = $_;
      label = 8;
      break;
    }
   case 7:
    $35 = _PCF_Size_Select($size, 0) | 0;
    $_0 = 0;
    label = 8;
    break;
   case 8:
    return $_0 | 0;
  }
  return 0;
}
function _PCF_Size_Select($size, $strike_index) {
  $size = $size | 0;
  $strike_index = $strike_index | 0;
  var $2 = 0, $3 = 0;
  $2 = HEAP32[$size >> 2] | 0;
  $3 = $2 + 196 | 0;
  _FT_Select_Metrics($2, $strike_index);
  HEAP32[$size + 24 >> 2] = HEAP32[$3 + 8 >> 2] << 6;
  HEAP32[$size + 28 >> 2] = -(HEAP32[$3 + 12 >> 2] | 0) << 6;
  HEAP32[$size + 36 >> 2] = HEAP16[$3 + 40 >> 1] << 16 >> 16 << 6;
  return 0;
}
function _BitOrderInvert($buf, $nbytes) {
  $buf = $buf | 0;
  $nbytes = $nbytes | 0;
  var $1 = 0, $_013 = 0, $_01112 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($nbytes | 0) == 0;
    if ($1) {
      label = 3;
      break;
    } else {
      $_01112 = $nbytes;
      $_013 = $buf;
      label = 2;
      break;
    }
   case 2:
    $2 = HEAP8[$_013] | 0;
    $3 = $2 & 255;
    $4 = $3 >>> 1;
    $5 = $4 & 85;
    $6 = $3 << 1;
    $7 = $6 & 170;
    $8 = $5 | $7;
    $9 = $8 >>> 2;
    $10 = $9 & 51;
    $11 = $8 << 2;
    $12 = $11 & 204;
    $13 = $10 | $12;
    $14 = $13 >>> 4;
    $15 = $13 << 4;
    $16 = $14 | $15;
    $17 = $16 & 255;
    HEAP8[$_013] = $17;
    $18 = $_01112 - 1 | 0;
    $19 = $_013 + 1 | 0;
    $20 = ($18 | 0) == 0;
    if ($20) {
      label = 3;
      break;
    } else {
      $_01112 = $18;
      $_013 = $19;
      label = 2;
      break;
    }
   case 3:
    return;
  }
}
function _TwoByteSwap($buf, $nbytes) {
  $buf = $buf | 0;
  $nbytes = $nbytes | 0;
  var $1 = 0, $_09 = 0, $_078 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $nbytes >>> 0 > 1;
    if ($1) {
      $_078 = $nbytes;
      $_09 = $buf;
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $2 = HEAP8[$_09] | 0;
    $3 = $_09 + 1 | 0;
    $4 = HEAP8[$3] | 0;
    HEAP8[$_09] = $4;
    HEAP8[$3] = $2;
    $5 = $_078 - 2 | 0;
    $6 = $_09 + 2 | 0;
    $7 = $5 >>> 0 > 1;
    if ($7) {
      $_078 = $5;
      $_09 = $6;
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    return;
  }
}
function _FourByteSwap($buf, $nbytes) {
  $buf = $buf | 0;
  $nbytes = $nbytes | 0;
  var $1 = 0, $_014 = 0, $_01213 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $nbytes >>> 0 > 3;
    if ($1) {
      $_01213 = $nbytes;
      $_014 = $buf;
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $2 = HEAP8[$_014] | 0;
    $3 = $_014 + 3 | 0;
    $4 = HEAP8[$3] | 0;
    HEAP8[$_014] = $4;
    HEAP8[$3] = $2;
    $5 = $_014 + 1 | 0;
    $6 = HEAP8[$5] | 0;
    $7 = $_014 + 2 | 0;
    $8 = HEAP8[$7] | 0;
    HEAP8[$5] = $8;
    HEAP8[$7] = $6;
    $9 = $_01213 - 4 | 0;
    $10 = $_014 + 4 | 0;
    $11 = $9 >>> 0 > 3;
    if ($11) {
      $_01213 = $9;
      $_014 = $10;
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    return;
  }
}
function _pcf_has_table_type($tables, $ntables) {
  $tables = $tables | 0;
  $ntables = $ntables | 0;
  var $i_0 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $i_0 = 0;
    label = 2;
    break;
   case 2:
    $2 = $i_0 >>> 0 < $ntables >>> 0;
    if ($2) {
      label = 3;
      break;
    } else {
      $_0 = 0;
      label = 4;
      break;
    }
   case 3:
    $4 = $tables + ($i_0 << 4) | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($5 | 0) == 256;
    $7 = $i_0 + 1 | 0;
    if ($6) {
      $_0 = 1;
      label = 4;
      break;
    } else {
      $i_0 = $7;
      label = 2;
      break;
    }
   case 4:
    return $_0 | 0;
  }
  return 0;
}
function _pcf_load_font($stream, $face) {
  $stream = $stream | 0;
  $face = $face | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $sext85 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $95 = 0, $96 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $107 = 0, $108 = 0, $110 = 0, $111 = 0, $112 = 0, $sext81 = 0, $113 = 0, $114 = 0, $115 = 0, $117 = 0, $118 = 0, $120 = 0, $121 = 0, $122 = 0, $sext = 0, $phitmp = 0, $resolution_x_0 = 0, $124 = 0, $125 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $resolution_y_0 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $142 = 0, $143 = 0, $144 = 0, $146 = 0, $147 = 0, $or_cond = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $159 = 0, $160 = 0, $161 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $or_cond82 = 0, $168 = 0, $169 = 0, $170 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $_pr = 0, $184 = 0, $186 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _pcf_read_TOC($stream, $face) | 0;
    HEAP32[$error >> 2] = $3;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 41;
      break;
    }
   case 2:
    $6 = _pcf_get_properties($stream, $face) | 0;
    HEAP32[$error >> 2] = $6;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 41;
      break;
    }
   case 3:
    $9 = $face + 192 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $face + 188 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = _pcf_has_table_type($10, $12) | 0;
    $14 = $13 << 24 >> 24 != 0;
    if ($14) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $16 = _pcf_get_accel($stream, $face, 2) | 0;
    HEAP32[$error >> 2] = $16;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 5;
      break;
    } else {
      label = 41;
      break;
    }
   case 5:
    $19 = _pcf_get_metrics($stream, $face) | 0;
    HEAP32[$error >> 2] = $19;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 6;
      break;
    } else {
      label = 41;
      break;
    }
   case 6:
    $22 = _pcf_get_bitmaps($stream, $face) | 0;
    HEAP32[$error >> 2] = $22;
    $23 = ($22 | 0) == 0;
    if ($23) {
      label = 7;
      break;
    } else {
      label = 41;
      break;
    }
   case 7:
    $25 = _pcf_get_encodings($stream, $face) | 0;
    HEAP32[$error >> 2] = $25;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 8;
      break;
    } else {
      label = 41;
      break;
    }
   case 8:
    if ($14) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $29 = _pcf_get_accel($stream, $face, 256) | 0;
    HEAP32[$error >> 2] = $29;
    $30 = ($29 | 0) == 0;
    if ($30) {
      label = 10;
      break;
    } else {
      label = 41;
      break;
    }
   case 10:
    $32 = $face | 0;
    HEAP32[$32 >> 2] = 1;
    $33 = $face + 4 | 0;
    HEAP32[$33 >> 2] = 0;
    $34 = $face + 8 | 0;
    HEAP32[$34 >> 2] = 146;
    $35 = $face + 199 | 0;
    $36 = HEAP8[$35] | 0;
    $37 = $36 << 24 >> 24 == 0;
    if ($37) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    HEAP32[$34 >> 2] = 150;
    label = 12;
    break;
   case 12:
    $40 = _pcf_interpret_style($face) | 0;
    HEAP32[$error >> 2] = $40;
    $41 = ($40 | 0) == 0;
    if ($41) {
      label = 13;
      break;
    } else {
      label = 41;
      break;
    }
   case 13:
    $43 = _pcf_find_property($face, 5321804) | 0;
    $44 = ($43 | 0) == 0;
    if ($44) {
      label = 16;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $46 = $43 + 4 | 0;
    $47 = HEAP8[$46] | 0;
    $48 = $47 << 24 >> 24 == 0;
    if ($48) {
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $50 = $43 + 8 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = _ft_mem_strdup($2, $51, $error) | 0;
    $53 = $face + 20 | 0;
    HEAP32[$53 >> 2] = $52;
    $54 = HEAP32[$error >> 2] | 0;
    $55 = ($54 | 0) == 0;
    if ($55) {
      label = 17;
      break;
    } else {
      label = 41;
      break;
    }
   case 16:
    $57 = $face + 20 | 0;
    HEAP32[$57 >> 2] = 0;
    label = 17;
    break;
   case 17:
    $59 = $face + 288 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = $60 + 1 | 0;
    $62 = $face + 16 | 0;
    HEAP32[$62 >> 2] = $61;
    $63 = $face + 28 | 0;
    HEAP32[$63 >> 2] = 1;
    $64 = _ft_mem_realloc($2, 16, 0, 1, 0, $error) | 0;
    $65 = $64;
    $66 = $face + 32 | 0;
    HEAP32[$66 >> 2] = $65;
    $67 = HEAP32[$error >> 2] | 0;
    $68 = ($67 | 0) == 0;
    if ($68) {
      label = 18;
      break;
    } else {
      label = 41;
      break;
    }
   case 18:
    _memset($64 | 0, 0, 16);
    $70 = $face + 204 | 0;
    $71 = HEAP32[$70 >> 2] | 0;
    $72 = $face + 208 | 0;
    $73 = HEAP32[$72 >> 2] | 0;
    $74 = $73 + $71 | 0;
    $75 = $74 & 65535;
    $76 = $64;
    HEAP16[$76 >> 1] = $75;
    $77 = _pcf_find_property($face, 5321128) | 0;
    $78 = ($77 | 0) == 0;
    if ($78) {
      label = 20;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $80 = $77 + 8 | 0;
    $81 = $80;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = $82 + 5 | 0;
    $84 = ($83 | 0) / 10 & -1;
    $85 = $84 & 65535;
    $86 = $64 + 2 | 0;
    $87 = $86;
    HEAP16[$87 >> 1] = $85;
    label = 21;
    break;
   case 20:
    $sext85 = $74 << 16;
    $89 = $sext85 >> 15;
    $90 = ($89 | 0) / 3 & -1;
    $91 = $90 & 65535;
    $92 = $64 + 2 | 0;
    $93 = $92;
    HEAP16[$93 >> 1] = $91;
    label = 21;
    break;
   case 21:
    $95 = _pcf_find_property($face, 5320448) | 0;
    $96 = ($95 | 0) == 0;
    if ($96) {
      label = 23;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $98 = $95 + 8 | 0;
    $99 = $98;
    $100 = HEAP32[$99 >> 2] | 0;
    $101 = $100 * 460800 & -1;
    $102 = $101 + 36135 | 0;
    $103 = ($102 | 0) / 72270 & -1;
    $104 = $64 + 4 | 0;
    $105 = $104;
    HEAP32[$105 >> 2] = $103;
    label = 23;
    break;
   case 23:
    $107 = _pcf_find_property($face, 5319972) | 0;
    $108 = ($107 | 0) == 0;
    if ($108) {
      label = 25;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $110 = $107 + 8 | 0;
    $111 = $110;
    $112 = HEAP32[$111 >> 2] | 0;
    $sext81 = $112 << 16;
    $113 = $sext81 >> 10;
    $114 = $64 + 12 | 0;
    $115 = $114;
    HEAP32[$115 >> 2] = $113;
    label = 25;
    break;
   case 25:
    $117 = _pcf_find_property($face, 5319592) | 0;
    $118 = ($117 | 0) == 0;
    if ($118) {
      $resolution_x_0 = 0;
      label = 27;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $120 = $117 + 8 | 0;
    $121 = $120;
    $122 = HEAP32[$121 >> 2] | 0;
    $sext = $122 << 16;
    $phitmp = $sext >> 16;
    $resolution_x_0 = $phitmp;
    label = 27;
    break;
   case 27:
    $124 = _pcf_find_property($face, 5319268) | 0;
    $125 = ($124 | 0) == 0;
    if ($125) {
      $resolution_y_0 = 0;
      label = 29;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $127 = $124 + 8 | 0;
    $128 = $127;
    $129 = HEAP32[$128 >> 2] | 0;
    $130 = $129 & 65535;
    $resolution_y_0 = $130;
    label = 29;
    break;
   case 29:
    $132 = $64 + 12 | 0;
    $133 = $132;
    $134 = HEAP32[$133 >> 2] | 0;
    $135 = ($134 | 0) == 0;
    if ($135) {
      label = 30;
      break;
    } else {
      label = 32;
      break;
    }
   case 30:
    $137 = $64 + 4 | 0;
    $138 = $137;
    $139 = HEAP32[$138 >> 2] | 0;
    HEAP32[$133 >> 2] = $139;
    $140 = $resolution_y_0 << 16 >> 16 == 0;
    if ($140) {
      label = 34;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    $142 = $resolution_y_0 << 16 >> 16;
    $143 = Math_imul($139, $142);
    $144 = ($143 | 0) / 72 & -1;
    HEAP32[$133 >> 2] = $144;
    label = 32;
    break;
   case 32:
    $146 = ($resolution_x_0 | 0) == 0;
    $147 = $resolution_y_0 << 16 >> 16 == 0;
    $or_cond = $146 | $147;
    if ($or_cond) {
      label = 34;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    $149 = $resolution_y_0 << 16 >> 16;
    $150 = HEAP32[$133 >> 2] | 0;
    $151 = Math_imul($150, $resolution_x_0);
    $152 = ($151 | 0) / ($149 | 0) & -1;
    $153 = $64 + 8 | 0;
    $154 = $153;
    HEAP32[$154 >> 2] = $152;
    label = 35;
    break;
   case 34:
    $155 = HEAP32[$133 >> 2] | 0;
    $156 = $64 + 8 | 0;
    $157 = $156;
    HEAP32[$157 >> 2] = $155;
    label = 35;
    break;
   case 35:
    $159 = _pcf_find_property($face, 5324684) | 0;
    $160 = _pcf_find_property($face, 5324440) | 0;
    $161 = ($159 | 0) == 0;
    if ($161) {
      label = 40;
      break;
    } else {
      label = 36;
      break;
    }
   case 36:
    $163 = $159 + 4 | 0;
    $164 = HEAP8[$163] | 0;
    $165 = $164 << 24 >> 24 == 0;
    $166 = ($160 | 0) == 0;
    $or_cond82 = $165 | $166;
    if ($or_cond82) {
      label = 40;
      break;
    } else {
      label = 37;
      break;
    }
   case 37:
    $168 = $160 + 4 | 0;
    $169 = HEAP8[$168] | 0;
    $170 = $169 << 24 >> 24 == 0;
    if ($170) {
      label = 40;
      break;
    } else {
      label = 38;
      break;
    }
   case 38:
    $172 = $160 + 8 | 0;
    $173 = HEAP32[$172 >> 2] | 0;
    $174 = _ft_mem_strdup($2, $173, $error) | 0;
    $175 = $face + 176 | 0;
    HEAP32[$175 >> 2] = $174;
    $176 = HEAP32[$error >> 2] | 0;
    $177 = ($176 | 0) == 0;
    if ($177) {
      label = 39;
      break;
    } else {
      label = 41;
      break;
    }
   case 39:
    $179 = $159 + 8 | 0;
    $180 = HEAP32[$179 >> 2] | 0;
    $181 = _ft_mem_strdup($2, $180, $error) | 0;
    $182 = $face + 180 | 0;
    HEAP32[$182 >> 2] = $181;
    label = 40;
    break;
   case 40:
    $_pr = HEAP32[$error >> 2] | 0;
    $184 = ($_pr | 0) == 0;
    if ($184) {
      label = 42;
      break;
    } else {
      label = 41;
      break;
    }
   case 41:
    HEAP32[$error >> 2] = 3;
    label = 42;
    break;
   case 42:
    $186 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $186 | 0;
  }
  return 0;
}
function _pcf_read_TOC($stream, $face) {
  $stream = $stream | 0;
  $face = $face | 0;
  var $error = 0, $tmp = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $or_cond = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $n_051 = 0, $tables_050 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $n_1 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $i_0 = 0, $have_change_0 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $have_change_1 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $66 = 0, $68 = 0, $69 = 0, $71 = 0, $72 = 0, $73 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 20 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $tmp = __stackBase__ + 4 | 0;
    $1 = $face + 184 | 0;
    $2 = $face + 100 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = _FT_Stream_Seek($stream, 0) | 0;
    HEAP32[$error >> 2] = $4;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $_0 = 1;
      label = 19;
      break;
    }
   case 2:
    $7 = $1;
    $8 = _FT_Stream_ReadFields($stream, 5250564, $7) | 0;
    HEAP32[$error >> 2] = $8;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 3;
      break;
    } else {
      $_0 = 1;
      label = 19;
      break;
    }
   case 3:
    $11 = $1 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($12 | 0) == 1885562369;
    if ($13) {
      label = 4;
      break;
    } else {
      $_0 = 3;
      label = 19;
      break;
    }
   case 4:
    $15 = $face + 188 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $16 >>> 0 > 134217727;
    $18 = ($16 | 0) == 0;
    $or_cond = $17 | $18;
    if ($or_cond) {
      $_0 = 3;
      label = 19;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $20 = _ft_mem_realloc($3, 16, 0, $16, 0, $error) | 0;
    $21 = $20;
    $22 = $face + 192 | 0;
    HEAP32[$22 >> 2] = $21;
    $23 = HEAP32[$error >> 2] | 0;
    $24 = ($23 | 0) == 0;
    if ($24) {
      label = 6;
      break;
    } else {
      $_0 = 64;
      label = 19;
      break;
    }
   case 6:
    $25 = HEAP32[$15 >> 2] | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 9;
      break;
    } else {
      $tables_050 = $21;
      $n_051 = 0;
      label = 7;
      break;
    }
   case 7:
    $27 = $tables_050;
    $28 = _FT_Stream_ReadFields($stream, 5250580, $27) | 0;
    HEAP32[$error >> 2] = $28;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 8;
      break;
    } else {
      label = 18;
      break;
    }
   case 8:
    $31 = $tables_050 + 16 | 0;
    $32 = $n_051 + 1 | 0;
    $33 = HEAP32[$15 >> 2] | 0;
    $34 = $32 >>> 0 < $33 >>> 0;
    if ($34) {
      $tables_050 = $31;
      $n_051 = $32;
      label = 7;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $35 = HEAP32[$22 >> 2] | 0;
    $36 = $tmp;
    $n_1 = 0;
    label = 10;
    break;
   case 10:
    $38 = HEAP32[$15 >> 2] | 0;
    $39 = $38 - 1 | 0;
    $40 = $n_1 >>> 0 < $39 >>> 0;
    if ($40) {
      label = 11;
      break;
    } else {
      $_0 = 0;
      label = 19;
      break;
    }
   case 11:
    $41 = $n_1 ^ -1;
    $have_change_0 = 0;
    $i_0 = 0;
    label = 12;
    break;
   case 12:
    $43 = HEAP32[$15 >> 2] | 0;
    $44 = $43 + $41 | 0;
    $45 = $i_0 >>> 0 < $44 >>> 0;
    if ($45) {
      label = 13;
      break;
    } else {
      label = 17;
      break;
    }
   case 13:
    $47 = $35 + ($i_0 << 4) + 12 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $i_0 + 1 | 0;
    $50 = $35 + ($49 << 4) + 12 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = $48 >>> 0 > $51 >>> 0;
    if ($52) {
      label = 14;
      break;
    } else {
      $have_change_1 = $have_change_0;
      label = 15;
      break;
    }
   case 14:
    $54 = $35 + ($49 << 4) | 0;
    $55 = $35 + ($i_0 << 4) | 0;
    $56 = $55;
    _memcpy($36 | 0, $56 | 0, 16);
    $57 = $54;
    _memcpy($56 | 0, $57 | 0, 16);
    _memcpy($57 | 0, $36 | 0, 16);
    $have_change_1 = 1;
    label = 15;
    break;
   case 15:
    $59 = $35 + ($i_0 << 4) + 8 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = HEAP32[$50 >> 2] | 0;
    $62 = $60 >>> 0 > $61 >>> 0;
    if ($62) {
      $_0 = 9;
      label = 19;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $64 = HEAP32[$47 >> 2] | 0;
    $65 = $61 - $60 | 0;
    $66 = $64 >>> 0 > $65 >>> 0;
    if ($66) {
      $_0 = 9;
      label = 19;
      break;
    } else {
      $have_change_0 = $have_change_1;
      $i_0 = $49;
      label = 12;
      break;
    }
   case 17:
    $68 = ($have_change_0 | 0) == 0;
    $69 = $n_1 + 1 | 0;
    if ($68) {
      $_0 = 0;
      label = 19;
      break;
    } else {
      $n_1 = $69;
      label = 10;
      break;
    }
   case 18:
    $71 = HEAP32[$22 >> 2] | 0;
    $72 = $71;
    _ft_mem_free($3, $72);
    HEAP32[$22 >> 2] = 0;
    $73 = HEAP32[$error >> 2] | 0;
    $_0 = $73;
    label = 19;
    break;
   case 19:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _pcf_get_properties($stream, $face) {
  $stream = $stream | 0;
  $face = $face | 0;
  var $format = 0, $size = 0, $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $or_cond = 0, $15 = 0, $16 = 0, $18 = 0, $20 = 0, $nprops_0 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $i_064 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $64 = 0, $string_size_0 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $75 = 0, $76 = 0, $77 = 0, $79 = 0, $80 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $87 = 0, $88 = 0, $i_162 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $or_cond60 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $109 = 0, $110 = 0, $or_cond61 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $119 = 0, $_c = 0, $121 = 0, $122 = 0, $strings_0 = 0, $props_0 = 0, $123 = 0, $124 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $format = __stackBase__ | 0;
    $size = __stackBase__ + 4 | 0;
    $error = __stackBase__ + 8 | 0;
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 192 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $face + 188 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = _pcf_seek_to_table_type($stream, $4, $6, 1, $format, $size) | 0;
    HEAP32[$error >> 2] = $7;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 2;
      break;
    } else {
      $props_0 = 0;
      $strings_0 = 0;
      label = 39;
      break;
    }
   case 2:
    $10 = _FT_Stream_ReadLongLE($stream, $error) | 0;
    HEAP32[$format >> 2] = $10;
    $11 = HEAP32[$error >> 2] | 0;
    $12 = ($11 | 0) == 0;
    $13 = $10 >>> 0 < 256;
    $or_cond = $12 & $13;
    if ($or_cond) {
      label = 3;
      break;
    } else {
      $props_0 = 0;
      $strings_0 = 0;
      label = 39;
      break;
    }
   case 3:
    $15 = $10 & 4;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $18 = _FT_Stream_ReadLong($stream, $error) | 0;
    $nprops_0 = $18;
    label = 6;
    break;
   case 5:
    $20 = _FT_Stream_ReadLongLE($stream, $error) | 0;
    $nprops_0 = $20;
    label = 6;
    break;
   case 6:
    $22 = HEAP32[$error >> 2] | 0;
    $23 = ($22 | 0) == 0;
    if ($23) {
      label = 7;
      break;
    } else {
      $props_0 = 0;
      $strings_0 = 0;
      label = 39;
      break;
    }
   case 7:
    $25 = HEAP32[$size >> 2] | 0;
    $26 = ($25 >>> 0) / 9 >>> 0;
    $27 = $nprops_0 >>> 0 > $26 >>> 0;
    if ($27) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    HEAP32[$error >> 2] = 8;
    $props_0 = 0;
    $strings_0 = 0;
    label = 39;
    break;
   case 9:
    $30 = $face + 280 | 0;
    HEAP32[$30 >> 2] = $nprops_0;
    $31 = _ft_mem_realloc($2, 12, 0, $nprops_0, 0, $error) | 0;
    $32 = $31;
    $33 = HEAP32[$error >> 2] | 0;
    $34 = ($33 | 0) == 0;
    if ($34) {
      label = 10;
      break;
    } else {
      $props_0 = $32;
      $strings_0 = 0;
      label = 39;
      break;
    }
   case 10:
    $35 = ($nprops_0 | 0) == 0;
    if ($35) {
      label = 19;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $36 = HEAP32[$format >> 2] | 0;
    $37 = $36 & 4;
    $38 = ($37 | 0) == 0;
    $i_064 = 0;
    label = 12;
    break;
   case 12:
    $40 = $32 + ($i_064 * 12 & -1) | 0;
    $41 = $40;
    if ($38) {
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $43 = _FT_Stream_ReadFields($stream, 5250636, $41) | 0;
    HEAP32[$error >> 2] = $43;
    $44 = ($43 | 0) == 0;
    if ($44) {
      label = 15;
      break;
    } else {
      $props_0 = $32;
      $strings_0 = 0;
      label = 39;
      break;
    }
   case 14:
    $46 = _FT_Stream_ReadFields($stream, 5250656, $41) | 0;
    HEAP32[$error >> 2] = $46;
    $47 = ($46 | 0) == 0;
    if ($47) {
      label = 15;
      break;
    } else {
      $props_0 = $32;
      $strings_0 = 0;
      label = 39;
      break;
    }
   case 15:
    $49 = $i_064 + 1 | 0;
    $50 = $49 >>> 0 < $nprops_0 >>> 0;
    if ($50) {
      $i_064 = $49;
      label = 12;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $51 = $nprops_0 & 3;
    $52 = ($51 | 0) == 0;
    if ($52) {
      label = 19;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $54 = 4 - $51 | 0;
    $55 = _FT_Stream_Skip($stream, $54) | 0;
    HEAP32[$error >> 2] = $55;
    $56 = ($55 | 0) == 0;
    if ($56) {
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    HEAP32[$error >> 2] = 83;
    $props_0 = $32;
    $strings_0 = 0;
    label = 39;
    break;
   case 19:
    $58 = HEAP32[$format >> 2] | 0;
    $59 = $58 & 4;
    $60 = ($59 | 0) == 0;
    if ($60) {
      label = 21;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $62 = _FT_Stream_ReadLong($stream, $error) | 0;
    $string_size_0 = $62;
    label = 22;
    break;
   case 21:
    $64 = _FT_Stream_ReadLongLE($stream, $error) | 0;
    $string_size_0 = $64;
    label = 22;
    break;
   case 22:
    $66 = HEAP32[$error >> 2] | 0;
    $67 = ($66 | 0) == 0;
    if ($67) {
      label = 23;
      break;
    } else {
      $props_0 = $32;
      $strings_0 = 0;
      label = 39;
      break;
    }
   case 23:
    $69 = HEAP32[$size >> 2] | 0;
    $70 = $nprops_0 * -9 & -1;
    $71 = $69 + $70 | 0;
    $72 = $string_size_0 >>> 0 > $71 >>> 0;
    if ($72) {
      label = 24;
      break;
    } else {
      label = 25;
      break;
    }
   case 24:
    HEAP32[$error >> 2] = 8;
    $props_0 = $32;
    $strings_0 = 0;
    label = 39;
    break;
   case 25:
    $75 = _ft_mem_realloc($2, 1, 0, $string_size_0, 0, $error) | 0;
    $76 = HEAP32[$error >> 2] | 0;
    $77 = ($76 | 0) == 0;
    if ($77) {
      label = 26;
      break;
    } else {
      $props_0 = $32;
      $strings_0 = $75;
      label = 39;
      break;
    }
   case 26:
    $79 = _FT_Stream_Read($stream, $75, $string_size_0) | 0;
    HEAP32[$error >> 2] = $79;
    $80 = ($79 | 0) == 0;
    if ($80) {
      label = 27;
      break;
    } else {
      $props_0 = $32;
      $strings_0 = $75;
      label = 39;
      break;
    }
   case 27:
    $82 = _ft_mem_realloc($2, 12, 0, $nprops_0, 0, $error) | 0;
    $83 = $82;
    $84 = HEAP32[$error >> 2] | 0;
    $85 = ($84 | 0) == 0;
    if ($85) {
      label = 28;
      break;
    } else {
      $props_0 = $32;
      $strings_0 = $75;
      label = 39;
      break;
    }
   case 28:
    $87 = $face + 284 | 0;
    HEAP32[$87 >> 2] = $83;
    $88 = ($nprops_0 | 0) == 0;
    if ($88) {
      label = 38;
      break;
    } else {
      $i_162 = 0;
      label = 29;
      break;
    }
   case 29:
    $89 = $32 + ($i_162 * 12 & -1) | 0;
    $90 = HEAP32[$89 >> 2] | 0;
    $91 = ($90 | 0) < 0;
    $92 = $90 >>> 0 > $string_size_0 >>> 0;
    $or_cond60 = $91 | $92;
    if ($or_cond60) {
      label = 30;
      break;
    } else {
      label = 31;
      break;
    }
   case 30:
    HEAP32[$error >> 2] = 9;
    $props_0 = $32;
    $strings_0 = $75;
    label = 39;
    break;
   case 31:
    $95 = $75 + $90 | 0;
    $96 = _ft_mem_strdup($2, $95, $error) | 0;
    $97 = $83 + ($i_162 * 12 & -1) | 0;
    HEAP32[$97 >> 2] = $96;
    $98 = HEAP32[$error >> 2] | 0;
    $99 = ($98 | 0) == 0;
    if ($99) {
      label = 32;
      break;
    } else {
      $props_0 = $32;
      $strings_0 = $75;
      label = 39;
      break;
    }
   case 32:
    $101 = $32 + ($i_162 * 12 & -1) + 4 | 0;
    $102 = HEAP8[$101] | 0;
    $103 = $83 + ($i_162 * 12 & -1) + 4 | 0;
    HEAP8[$103] = $102;
    $104 = HEAP8[$101] | 0;
    $105 = $104 << 24 >> 24 == 0;
    $106 = $32 + ($i_162 * 12 & -1) + 8 | 0;
    $107 = HEAP32[$106 >> 2] | 0;
    if ($105) {
      label = 36;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    $109 = ($107 | 0) < 0;
    $110 = $107 >>> 0 > $string_size_0 >>> 0;
    $or_cond61 = $109 | $110;
    if ($or_cond61) {
      label = 34;
      break;
    } else {
      label = 35;
      break;
    }
   case 34:
    HEAP32[$error >> 2] = 9;
    $props_0 = $32;
    $strings_0 = $75;
    label = 39;
    break;
   case 35:
    $113 = $75 + $107 | 0;
    $114 = _ft_mem_strdup($2, $113, $error) | 0;
    $115 = $83 + ($i_162 * 12 & -1) + 8 | 0;
    HEAP32[$115 >> 2] = $114;
    $116 = HEAP32[$error >> 2] | 0;
    $117 = ($116 | 0) == 0;
    if ($117) {
      label = 37;
      break;
    } else {
      $props_0 = $32;
      $strings_0 = $75;
      label = 39;
      break;
    }
   case 36:
    $119 = $83 + ($i_162 * 12 & -1) + 8 | 0;
    $_c = $107;
    HEAP32[$119 >> 2] = $_c;
    label = 37;
    break;
   case 37:
    $121 = $i_162 + 1 | 0;
    $122 = $121 >>> 0 < $nprops_0 >>> 0;
    if ($122) {
      $i_162 = $121;
      label = 29;
      break;
    } else {
      label = 38;
      break;
    }
   case 38:
    HEAP32[$error >> 2] = 0;
    $props_0 = $32;
    $strings_0 = $75;
    label = 39;
    break;
   case 39:
    $123 = $props_0;
    _ft_mem_free($2, $123);
    _ft_mem_free($2, $strings_0);
    $124 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $124 | 0;
  }
  return 0;
}
function _pcf_get_accel($stream, $face, $type) {
  $stream = $stream | 0;
  $face = $face | 0;
  $type = $type | 0;
  var $format = 0, $size = 0, $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $format = __stackBase__ | 0;
    $size = __stackBase__ + 4 | 0;
    $error = __stackBase__ + 8 | 0;
    $1 = $face + 192 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 188 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = _pcf_seek_to_table_type($stream, $2, $4, $type, $format, $size) | 0;
    HEAP32[$error >> 2] = $5;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 13;
      break;
    }
   case 2:
    $8 = _FT_Stream_ReadLongLE($stream, $error) | 0;
    HEAP32[$format >> 2] = $8;
    $9 = HEAP32[$error >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 3;
      break;
    } else {
      label = 13;
      break;
    }
   case 3:
    $12 = $8 & -256;
    if (($12 | 0) == 0 | ($12 | 0) == 256) {
      label = 4;
      break;
    } else {
      label = 13;
      break;
    }
   case 4:
    $14 = HEAP32[$format >> 2] | 0;
    $15 = $14 & 4;
    $16 = ($15 | 0) == 0;
    $17 = $face + 196 | 0;
    if ($16) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $19 = _FT_Stream_ReadFields($stream, 5250912, $17) | 0;
    HEAP32[$error >> 2] = $19;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 7;
      break;
    } else {
      label = 13;
      break;
    }
   case 6:
    $22 = _FT_Stream_ReadFields($stream, 5250964, $17) | 0;
    HEAP32[$error >> 2] = $22;
    $23 = ($22 | 0) == 0;
    if ($23) {
      label = 7;
      break;
    } else {
      label = 13;
      break;
    }
   case 7:
    $25 = HEAP32[$format >> 2] | 0;
    $26 = $25 & 255;
    $27 = $face + 216 | 0;
    $28 = _pcf_get_metric($stream, $26, $27) | 0;
    HEAP32[$error >> 2] = $28;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 8;
      break;
    } else {
      label = 13;
      break;
    }
   case 8:
    $31 = HEAP32[$format >> 2] | 0;
    $32 = $31 & 255;
    $33 = $face + 232 | 0;
    $34 = _pcf_get_metric($stream, $32, $33) | 0;
    HEAP32[$error >> 2] = $34;
    $35 = ($34 | 0) == 0;
    if ($35) {
      label = 9;
      break;
    } else {
      label = 13;
      break;
    }
   case 9:
    $37 = HEAP32[$format >> 2] | 0;
    $38 = $37 & -256;
    $39 = ($38 | 0) == 256;
    if ($39) {
      label = 10;
      break;
    } else {
      label = 12;
      break;
    }
   case 10:
    $41 = $37 & 255;
    $42 = $face + 248 | 0;
    $43 = _pcf_get_metric($stream, $41, $42) | 0;
    HEAP32[$error >> 2] = $43;
    $44 = ($43 | 0) == 0;
    if ($44) {
      label = 11;
      break;
    } else {
      label = 13;
      break;
    }
   case 11:
    $46 = HEAP32[$format >> 2] | 0;
    $47 = $46 & 255;
    $48 = $face + 264 | 0;
    $49 = _pcf_get_metric($stream, $47, $48) | 0;
    HEAP32[$error >> 2] = $49;
    label = 13;
    break;
   case 12:
    $51 = $face + 248 | 0;
    $52 = $51;
    $53 = $27;
    _memcpy($52 | 0, $53 | 0, 16);
    $54 = $face + 264 | 0;
    $55 = $54;
    $56 = $33;
    _memcpy($55 | 0, $56 | 0, 16);
    label = 13;
    break;
   case 13:
    $58 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $58 | 0;
  }
  return 0;
}
function _pcf_get_metrics($stream, $face) {
  $stream = $stream | 0;
  $face = $face | 0;
  var $error = 0, $format = 0, $size = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $22 = 0, $24 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $nmetrics_0 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $i_0 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $_pr = 0, $65 = 0, $66 = 0, $67 = 0, $69 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $format = __stackBase__ + 4 | 0;
    $size = __stackBase__ + 8 | 0;
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 192 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $face + 188 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = _pcf_seek_to_table_type($stream, $4, $6, 4, $format, $size) | 0;
    HEAP32[$error >> 2] = $7;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 2;
      break;
    } else {
      $_0 = $7;
      label = 23;
      break;
    }
   case 2:
    $10 = _FT_Stream_ReadLongLE($stream, $error) | 0;
    HEAP32[$format >> 2] = $10;
    $11 = HEAP32[$error >> 2] | 0;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 3;
      break;
    } else {
      label = 22;
      break;
    }
   case 3:
    $14 = $10 & -256;
    if (($14 | 0) == 0 | ($14 | 0) == 256) {
      label = 4;
      break;
    } else {
      $_0 = 3;
      label = 23;
      break;
    }
   case 4:
    $16 = HEAP32[$format >> 2] | 0;
    $17 = $16 >>> 0 < 256;
    $18 = $16 & 4;
    $19 = ($18 | 0) != 0;
    if ($17) {
      label = 5;
      break;
    } else {
      label = 8;
      break;
    }
   case 5:
    if ($19) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $22 = _FT_Stream_ReadLong($stream, $error) | 0;
    $nmetrics_0 = $22;
    label = 11;
    break;
   case 7:
    $24 = _FT_Stream_ReadLongLE($stream, $error) | 0;
    $nmetrics_0 = $24;
    label = 11;
    break;
   case 8:
    if ($19) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $27 = _FT_Stream_ReadShort($stream, $error) | 0;
    $28 = $27 & 65535;
    $nmetrics_0 = $28;
    label = 11;
    break;
   case 10:
    $30 = _FT_Stream_ReadShortLE($stream, $error) | 0;
    $31 = $30 & 65535;
    $nmetrics_0 = $31;
    label = 11;
    break;
   case 11:
    $33 = HEAP32[$error >> 2] | 0;
    $34 = ($33 | 0) == 0;
    if ($34) {
      label = 12;
      break;
    } else {
      $_0 = 3;
      label = 23;
      break;
    }
   case 12:
    $36 = $face + 288 | 0;
    HEAP32[$36 >> 2] = $nmetrics_0;
    $37 = ($nmetrics_0 | 0) == 0;
    if ($37) {
      $_0 = 8;
      label = 23;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $39 = HEAP32[$format >> 2] | 0;
    $40 = $39 >>> 0 < 256;
    $41 = HEAP32[$size >> 2] | 0;
    if ($40) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $43 = ($41 >>> 0) / 12 >>> 0;
    $44 = $nmetrics_0 >>> 0 > $43 >>> 0;
    if ($44) {
      $_0 = 8;
      label = 23;
      break;
    } else {
      label = 16;
      break;
    }
   case 15:
    $46 = ($41 >>> 0) / 5 >>> 0;
    $47 = $nmetrics_0 >>> 0 > $46 >>> 0;
    if ($47) {
      $_0 = 8;
      label = 23;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $49 = _ft_mem_realloc($2, 16, 0, $nmetrics_0, 0, $error) | 0;
    $50 = $49;
    $51 = $face + 292 | 0;
    HEAP32[$51 >> 2] = $50;
    $52 = HEAP32[$error >> 2] | 0;
    $53 = ($52 | 0) == 0;
    if ($53) {
      label = 17;
      break;
    } else {
      $_0 = 64;
      label = 23;
      break;
    }
   case 17:
    $54 = HEAP32[$format >> 2] | 0;
    $i_0 = 0;
    label = 18;
    break;
   case 18:
    $56 = $i_0 >>> 0 < $nmetrics_0 >>> 0;
    if ($56) {
      label = 19;
      break;
    } else {
      label = 20;
      break;
    }
   case 19:
    $58 = $50 + ($i_0 << 4) | 0;
    $59 = _pcf_get_metric($stream, $54, $58) | 0;
    HEAP32[$error >> 2] = $59;
    $60 = $50 + ($i_0 << 4) + 12 | 0;
    HEAP32[$60 >> 2] = 0;
    $61 = HEAP32[$error >> 2] | 0;
    $62 = ($61 | 0) == 0;
    $63 = $i_0 + 1 | 0;
    if ($62) {
      $i_0 = $63;
      label = 18;
      break;
    } else {
      label = 21;
      break;
    }
   case 20:
    $_pr = HEAP32[$error >> 2] | 0;
    $65 = ($_pr | 0) == 0;
    if ($65) {
      label = 22;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $66 = HEAP32[$51 >> 2] | 0;
    $67 = $66;
    _ft_mem_free($2, $67);
    HEAP32[$51 >> 2] = 0;
    label = 22;
    break;
   case 22:
    $69 = HEAP32[$error >> 2] | 0;
    $_0 = $69;
    label = 23;
    break;
   case 23:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _pcf_get_bitmaps($stream, $face) {
  $stream = $stream | 0;
  $face = $face | 0;
  var $error = 0, $format = 0, $size = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, $nbitmaps_0 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $or_cond = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $i_041 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $45 = 0, $exitcond44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $i_1 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $59 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $i_238 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $or_cond45 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $77 = 0, $exitcond = 0, $78 = 0, $79 = 0, $80 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $format = __stackBase__ + 4 | 0;
    $size = __stackBase__ + 8 | 0;
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 192 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $face + 188 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = _pcf_seek_to_table_type($stream, $4, $6, 8, $format, $size) | 0;
    HEAP32[$error >> 2] = $7;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 2;
      break;
    } else {
      $_0 = $7;
      label = 29;
      break;
    }
   case 2:
    $10 = _FT_Stream_EnterFrame($stream, 8) | 0;
    HEAP32[$error >> 2] = $10;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 3;
      break;
    } else {
      $_0 = $10;
      label = 29;
      break;
    }
   case 3:
    $13 = _FT_Stream_GetLongLE($stream) | 0;
    HEAP32[$format >> 2] = $13;
    $14 = $13 & 4;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $17 = _FT_Stream_GetLong($stream) | 0;
    $nbitmaps_0 = $17;
    label = 6;
    break;
   case 5:
    $19 = _FT_Stream_GetLongLE($stream) | 0;
    $nbitmaps_0 = $19;
    label = 6;
    break;
   case 6:
    _FT_Stream_ExitFrame($stream);
    $21 = HEAP32[$format >> 2] | 0;
    $22 = $21 >>> 0 < 256;
    if ($22) {
      label = 7;
      break;
    } else {
      $_0 = 3;
      label = 29;
      break;
    }
   case 7:
    $24 = $face + 288 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = ($25 | 0) > -1;
    $27 = ($nbitmaps_0 | 0) == ($25 | 0);
    $or_cond = $26 & $27;
    if ($or_cond) {
      label = 8;
      break;
    } else {
      $_0 = 3;
      label = 29;
      break;
    }
   case 8:
    $29 = _ft_mem_realloc($2, 4, 0, $nbitmaps_0, 0, $error) | 0;
    $30 = $29;
    $31 = HEAP32[$error >> 2] | 0;
    $32 = ($31 | 0) == 0;
    if ($32) {
      label = 9;
      break;
    } else {
      $_0 = $31;
      label = 29;
      break;
    }
   case 9:
    $33 = ($nbitmaps_0 | 0) == 0;
    if ($33) {
      label = 15;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $34 = HEAP32[$format >> 2] | 0;
    $35 = $34 & 4;
    $36 = ($35 | 0) == 0;
    $i_041 = 0;
    label = 11;
    break;
   case 11:
    if ($36) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $39 = _FT_Stream_ReadLong($stream, $error) | 0;
    $40 = $30 + ($i_041 << 2) | 0;
    HEAP32[$40 >> 2] = $39;
    label = 14;
    break;
   case 13:
    $42 = _FT_Stream_ReadLongLE($stream, $error) | 0;
    $43 = $30 + ($i_041 << 2) | 0;
    HEAP32[$43 >> 2] = $42;
    label = 14;
    break;
   case 14:
    $45 = $i_041 + 1 | 0;
    $exitcond44 = ($45 | 0) == ($nbitmaps_0 | 0);
    if ($exitcond44) {
      label = 15;
      break;
    } else {
      $i_041 = $45;
      label = 11;
      break;
    }
   case 15:
    $46 = HEAP32[$error >> 2] | 0;
    $47 = ($46 | 0) == 0;
    if ($47) {
      label = 16;
      break;
    } else {
      label = 28;
      break;
    }
   case 16:
    $48 = HEAP32[$format >> 2] | 0;
    $49 = $48 & 4;
    $50 = ($49 | 0) == 0;
    $i_1 = 0;
    label = 17;
    break;
   case 17:
    $52 = $i_1 >>> 0 < 4;
    if ($52) {
      label = 20;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $53 = ($nbitmaps_0 | 0) == 0;
    if ($53) {
      label = 27;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $54 = HEAP32[$size >> 2] | 0;
    $55 = $stream + 8 | 0;
    $56 = $face + 292 | 0;
    $i_238 = 0;
    label = 24;
    break;
   case 20:
    if ($50) {
      label = 22;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $59 = _FT_Stream_ReadLong($stream, $error) | 0;
    label = 23;
    break;
   case 22:
    $61 = _FT_Stream_ReadLongLE($stream, $error) | 0;
    label = 23;
    break;
   case 23:
    $63 = HEAP32[$error >> 2] | 0;
    $64 = ($63 | 0) == 0;
    $65 = $i_1 + 1 | 0;
    if ($64) {
      $i_1 = $65;
      label = 17;
      break;
    } else {
      label = 28;
      break;
    }
   case 24:
    $67 = $30 + ($i_238 << 2) | 0;
    $68 = HEAP32[$67 >> 2] | 0;
    $69 = ($68 | 0) < 0;
    $70 = $68 >>> 0 > $54 >>> 0;
    $or_cond45 = $69 | $70;
    if ($or_cond45) {
      label = 26;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $72 = HEAP32[$55 >> 2] | 0;
    $73 = $72 + $68 | 0;
    $74 = HEAP32[$56 >> 2] | 0;
    $75 = $74 + ($i_238 << 4) + 12 | 0;
    HEAP32[$75 >> 2] = $73;
    label = 26;
    break;
   case 26:
    $77 = $i_238 + 1 | 0;
    $exitcond = ($77 | 0) == ($nbitmaps_0 | 0);
    if ($exitcond) {
      label = 27;
      break;
    } else {
      $i_238 = $77;
      label = 24;
      break;
    }
   case 27:
    $78 = HEAP32[$format >> 2] | 0;
    $79 = $face + 308 | 0;
    HEAP32[$79 >> 2] = $78;
    label = 28;
    break;
   case 28:
    _ft_mem_free($2, $29);
    $80 = HEAP32[$error >> 2] | 0;
    $_0 = $80;
    label = 29;
    break;
   case 29:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _pcf_get_encodings($stream, $face) {
  $stream = $stream | 0;
  $face = $face | 0;
  var $error = 0, $format = 0, $size = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $firstCol_0_in = 0, $lastCol_0_in = 0, $firstRow_0_in = 0, $lastRow_0_in = 0, $firstRow_0 = 0, $firstCol_0 = 0, $31 = 0, $32 = 0, $lastRow_0 = 0, $lastCol_0 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $j_062 = 0, $i_061 = 0, $62 = 0, $64 = 0, $encodingOffset_0_in = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $j_1 = 0, $78 = 0, $exitcond65 = 0, $j_0_lcssa = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $i_159 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $exitcond = 0, $91 = 0, $92 = 0, $93 = 0, $encoding_0 = 0, $95 = 0, $96 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $format = __stackBase__ + 4 | 0;
    $size = __stackBase__ + 8 | 0;
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 192 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $face + 188 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = _pcf_seek_to_table_type($stream, $4, $6, 32, $format, $size) | 0;
    HEAP32[$error >> 2] = $7;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 2;
      break;
    } else {
      $_0 = $7;
      label = 22;
      break;
    }
   case 2:
    $10 = _FT_Stream_EnterFrame($stream, 14) | 0;
    HEAP32[$error >> 2] = $10;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 3;
      break;
    } else {
      $_0 = $10;
      label = 22;
      break;
    }
   case 3:
    $13 = _FT_Stream_GetLongLE($stream) | 0;
    HEAP32[$format >> 2] = $13;
    $14 = $13 & 4;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $17 = _FT_Stream_GetShort($stream) | 0;
    $18 = _FT_Stream_GetShort($stream) | 0;
    $19 = _FT_Stream_GetShort($stream) | 0;
    $20 = _FT_Stream_GetShort($stream) | 0;
    $21 = _FT_Stream_GetShort($stream) | 0;
    $22 = $face + 304 | 0;
    HEAP16[$22 >> 1] = $21;
    $lastRow_0_in = $20;
    $firstRow_0_in = $19;
    $lastCol_0_in = $18;
    $firstCol_0_in = $17;
    label = 6;
    break;
   case 5:
    $24 = _FT_Stream_GetShortLE($stream) | 0;
    $25 = _FT_Stream_GetShortLE($stream) | 0;
    $26 = _FT_Stream_GetShortLE($stream) | 0;
    $27 = _FT_Stream_GetShortLE($stream) | 0;
    $28 = _FT_Stream_GetShortLE($stream) | 0;
    $29 = $face + 304 | 0;
    HEAP16[$29 >> 1] = $28;
    $lastRow_0_in = $27;
    $firstRow_0_in = $26;
    $lastCol_0_in = $25;
    $firstCol_0_in = $24;
    label = 6;
    break;
   case 6:
    $firstRow_0 = $firstRow_0_in << 16 >> 16;
    $firstCol_0 = $firstCol_0_in << 16 >> 16;
    _FT_Stream_ExitFrame($stream);
    $31 = HEAP32[$format >> 2] | 0;
    $32 = $31 >>> 0 < 256;
    if ($32) {
      label = 7;
      break;
    } else {
      $_0 = 3;
      label = 22;
      break;
    }
   case 7:
    $lastRow_0 = $lastRow_0_in << 16 >> 16;
    $lastCol_0 = $lastCol_0_in << 16 >> 16;
    $34 = $lastCol_0 - $firstCol_0 | 0;
    $35 = $34 + 1 | 0;
    $36 = 1 - $firstRow_0 | 0;
    $37 = $36 + $lastRow_0 | 0;
    $38 = Math_imul($37, $35);
    $39 = _ft_mem_realloc($2, 8, 0, $38, 0, $error) | 0;
    $40 = $39;
    $41 = HEAP32[$error >> 2] | 0;
    $42 = ($41 | 0) == 0;
    if ($42) {
      label = 8;
      break;
    } else {
      $_0 = 64;
      label = 22;
      break;
    }
   case 8:
    $44 = $38 << 1;
    $45 = _FT_Stream_EnterFrame($stream, $44) | 0;
    HEAP32[$error >> 2] = $45;
    $46 = ($45 | 0) == 0;
    if ($46) {
      label = 9;
      break;
    } else {
      $encoding_0 = 0;
      label = 21;
      break;
    }
   case 9:
    $47 = ($38 | 0) > 0;
    if ($47) {
      label = 10;
      break;
    } else {
      $j_0_lcssa = 0;
      label = 17;
      break;
    }
   case 10:
    $48 = HEAP32[$format >> 2] | 0;
    $49 = $48 & 4;
    $50 = ($49 | 0) == 0;
    $51 = $lastRow_0_in << 16 >> 16;
    $52 = $51 + 1 | 0;
    $53 = $firstRow_0_in << 16 >> 16;
    $54 = $52 - $53 | 0;
    $55 = $lastCol_0_in << 16 >> 16;
    $56 = $55 + 1 | 0;
    $57 = $firstCol_0_in << 16 >> 16;
    $58 = $56 - $57 | 0;
    $59 = Math_imul($54, $58);
    $i_061 = 0;
    $j_062 = 0;
    label = 11;
    break;
   case 11:
    if ($50) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $62 = _FT_Stream_GetShort($stream) | 0;
    $encodingOffset_0_in = $62;
    label = 14;
    break;
   case 13:
    $64 = _FT_Stream_GetShortLE($stream) | 0;
    $encodingOffset_0_in = $64;
    label = 14;
    break;
   case 14:
    $66 = $encodingOffset_0_in << 16 >> 16 == -1;
    if ($66) {
      $j_1 = $j_062;
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $68 = ($i_061 | 0) / ($35 | 0) & -1;
    $69 = $68 + $firstRow_0 | 0;
    $70 = $69 << 8;
    $71 = ($i_061 | 0) % ($35 | 0);
    $72 = $71 + $firstCol_0 | 0;
    $73 = $72 + $70 | 0;
    $74 = $40 + ($j_062 << 3) | 0;
    HEAP32[$74 >> 2] = $73;
    $75 = $40 + ($j_062 << 3) + 4 | 0;
    HEAP16[$75 >> 1] = $encodingOffset_0_in;
    $76 = $j_062 + 1 | 0;
    $j_1 = $76;
    label = 16;
    break;
   case 16:
    $78 = $i_061 + 1 | 0;
    $exitcond65 = ($78 | 0) == ($59 | 0);
    if ($exitcond65) {
      $j_0_lcssa = $j_1;
      label = 17;
      break;
    } else {
      $i_061 = $78;
      $j_062 = $j_1;
      label = 11;
      break;
    }
   case 17:
    _FT_Stream_ExitFrame($stream);
    $79 = _ft_mem_realloc($2, 8, 0, $j_0_lcssa, 0, $error) | 0;
    $80 = $79;
    $81 = HEAP32[$error >> 2] | 0;
    $82 = ($81 | 0) == 0;
    if ($82) {
      label = 18;
      break;
    } else {
      $encoding_0 = $80;
      label = 21;
      break;
    }
   case 18:
    $83 = ($j_0_lcssa | 0) > 0;
    if ($83) {
      $i_159 = 0;
      label = 19;
      break;
    } else {
      label = 20;
      break;
    }
   case 19:
    $84 = $40 + ($i_159 << 3) | 0;
    $85 = HEAP32[$84 >> 2] | 0;
    $86 = $80 + ($i_159 << 3) | 0;
    HEAP32[$86 >> 2] = $85;
    $87 = $40 + ($i_159 << 3) + 4 | 0;
    $88 = HEAP16[$87 >> 1] | 0;
    $89 = $80 + ($i_159 << 3) + 4 | 0;
    HEAP16[$89 >> 1] = $88;
    $90 = $i_159 + 1 | 0;
    $exitcond = ($90 | 0) == ($j_0_lcssa | 0);
    if ($exitcond) {
      label = 20;
      break;
    } else {
      $i_159 = $90;
      label = 19;
      break;
    }
   case 20:
    $91 = $face + 296 | 0;
    HEAP32[$91 >> 2] = $j_0_lcssa;
    $92 = $face + 300 | 0;
    HEAP32[$92 >> 2] = $80;
    _ft_mem_free($2, $39);
    $93 = HEAP32[$error >> 2] | 0;
    $_0 = $93;
    label = 22;
    break;
   case 21:
    $95 = $encoding_0;
    _ft_mem_free($2, $95);
    _ft_mem_free($2, $39);
    $96 = HEAP32[$error >> 2] | 0;
    $_0 = $96;
    label = 22;
    break;
   case 22:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _pcf_interpret_style($pcf) {
  $pcf = $pcf | 0;
  var $error = 0, $strings = 0, $lengths = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $phitmp = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $72 = 0, $73 = 0, $len_1 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $len_2 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $93 = 0, $94 = 0, $96 = 0, $s_1 = 0, $97 = 0, $mm_063 = 0, $98 = 0, $99 = 0, $100 = 0, $103 = 0, $exitcond = 0, $104 = 0, $s_2 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $_0 = 0, $113 = 0, $114 = 0, $116 = 0, $s_1_1 = 0, $118 = 0, $s_2_1 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $126 = 0, $127 = 0, $129 = 0, $s_1_2 = 0, $131 = 0, $s_2_2 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $139 = 0, $140 = 0, $142 = 0, $s_1_3 = 0, $143 = 0, $mm_063_3 = 0, $144 = 0, $145 = 0, $146 = 0, $149 = 0, $exitcond_3 = 0, $150 = 0, $s_2_3 = 0, $152 = 0, $154 = 0, $155 = 0, $156 = 0, $len_1_1 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $163 = 0, $164 = 0, $165 = 0, $len_1_2 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $172 = 0, $173 = 0, $174 = 0, $len_1_3 = 0, $176 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 36 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $strings = __stackBase__ + 4 | 0;
    $lengths = __stackBase__ + 20 | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $pcf + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $strings;
    _memset($3 | 0, 0, 16);
    $4 = $pcf + 12 | 0;
    HEAP32[$4 >> 2] = 0;
    $5 = _pcf_find_property($pcf, 5324348) | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 7;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $5 + 4 | 0;
    $9 = HEAP8[$8] | 0;
    $10 = $9 << 24 >> 24 == 0;
    if ($10) {
      label = 7;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = $5 + 8 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = HEAP8[$13] | 0;
    if (($14 << 24 >> 24 | 0) == 79 | ($14 << 24 >> 24 | 0) == 111 | ($14 << 24 >> 24 | 0) == 73 | ($14 << 24 >> 24 | 0) == 105) {
      label = 4;
      break;
    } else {
      label = 7;
      break;
    }
   case 4:
    $16 = HEAP32[$4 >> 2] | 0;
    $17 = $16 | 1;
    HEAP32[$4 >> 2] = $17;
    $18 = HEAP32[$12 >> 2] | 0;
    $19 = HEAP8[$18] | 0;
    $20 = $19 << 24 >> 24 == 79;
    if ($20) {
      $24 = 5324236;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $22 = $19 << 24 >> 24 == 111;
    $phitmp = $22 ? 5324236 : 5324132;
    $24 = $phitmp;
    label = 6;
    break;
   case 6:
    $25 = $strings + 8 | 0;
    HEAP32[$25 >> 2] = $24;
    label = 7;
    break;
   case 7:
    $27 = _pcf_find_property($pcf, 5324052) | 0;
    $28 = ($27 | 0) == 0;
    if ($28) {
      label = 11;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $30 = $27 + 4 | 0;
    $31 = HEAP8[$30] | 0;
    $32 = $31 << 24 >> 24 == 0;
    if ($32) {
      label = 11;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $34 = $27 + 8 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = HEAP8[$35] | 0;
    if (($36 << 24 >> 24 | 0) == 66 | ($36 << 24 >> 24 | 0) == 98) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $38 = HEAP32[$4 >> 2] | 0;
    $39 = $38 | 2;
    HEAP32[$4 >> 2] = $39;
    $40 = $strings + 4 | 0;
    HEAP32[$40 >> 2] = 5323956;
    label = 11;
    break;
   case 11:
    $42 = _pcf_find_property($pcf, 5323876) | 0;
    $43 = ($42 | 0) == 0;
    if ($43) {
      label = 15;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $45 = $42 + 4 | 0;
    $46 = HEAP8[$45] | 0;
    $47 = $46 << 24 >> 24 == 0;
    if ($47) {
      label = 15;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $49 = $42 + 8 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = HEAP8[$50] | 0;
    if (($51 << 24 >> 24 | 0) == 0 | ($51 << 24 >> 24 | 0) == 78 | ($51 << 24 >> 24 | 0) == 110) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $53 = $strings + 12 | 0;
    HEAP32[$53 >> 2] = $50;
    label = 15;
    break;
   case 15:
    $55 = _pcf_find_property($pcf, 5323792) | 0;
    $56 = ($55 | 0) == 0;
    if ($56) {
      label = 19;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $58 = $55 + 4 | 0;
    $59 = HEAP8[$58] | 0;
    $60 = $59 << 24 >> 24 == 0;
    if ($60) {
      label = 19;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $62 = $55 + 8 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = HEAP8[$63] | 0;
    if (($64 << 24 >> 24 | 0) == 0 | ($64 << 24 >> 24 | 0) == 78 | ($64 << 24 >> 24 | 0) == 110) {
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $66 = $strings | 0;
    HEAP32[$66 >> 2] = $63;
    label = 19;
    break;
   case 19:
    $67 = $lengths | 0;
    HEAP32[$67 >> 2] = 0;
    $68 = $strings | 0;
    $69 = HEAP32[$68 >> 2] | 0;
    $70 = ($69 | 0) == 0;
    if ($70) {
      $len_1 = 0;
      label = 21;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $72 = _strlen($69 | 0) | 0;
    HEAP32[$67 >> 2] = $72;
    $73 = $72 + 1 | 0;
    $len_1 = $73;
    label = 21;
    break;
   case 21:
    $75 = $lengths + 4 | 0;
    HEAP32[$75 >> 2] = 0;
    $76 = $strings + 4 | 0;
    $77 = HEAP32[$76 >> 2] | 0;
    $78 = ($77 | 0) == 0;
    if ($78) {
      $len_1_1 = $len_1;
      label = 51;
      break;
    } else {
      label = 50;
      break;
    }
   case 22:
    $80 = $strings | 0;
    HEAP32[$80 >> 2] = 5323768;
    $81 = $lengths | 0;
    HEAP32[$81 >> 2] = 7;
    $len_2 = 8;
    label = 23;
    break;
   case 23:
    $83 = _ft_mem_alloc($2, $len_2, $error) | 0;
    $84 = $pcf + 24 | 0;
    HEAP32[$84 >> 2] = $83;
    $85 = HEAP32[$error >> 2] | 0;
    $86 = ($85 | 0) == 0;
    if ($86) {
      label = 24;
      break;
    } else {
      $_0 = $85;
      label = 33;
      break;
    }
   case 24:
    $87 = $strings | 0;
    $88 = HEAP32[$87 >> 2] | 0;
    $89 = $lengths | 0;
    $90 = HEAP32[$89 >> 2] | 0;
    $91 = ($88 | 0) == 0;
    if ($91) {
      $s_2 = $83;
      label = 32;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $93 = HEAP32[$84 >> 2] | 0;
    $94 = ($83 | 0) == ($93 | 0);
    if ($94) {
      $s_1 = $83;
      label = 27;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $96 = $83 + 1 | 0;
    HEAP8[$83] = 32;
    $s_1 = $96;
    label = 27;
    break;
   case 27:
    _memcpy($s_1 | 0, $88 | 0, $90 | 0);
    $97 = ($90 | 0) == 0;
    if ($97) {
      label = 31;
      break;
    } else {
      $mm_063 = 0;
      label = 28;
      break;
    }
   case 28:
    $98 = $s_1 + $mm_063 | 0;
    $99 = HEAP8[$98] | 0;
    $100 = $99 << 24 >> 24 == 32;
    if ($100) {
      label = 29;
      break;
    } else {
      label = 30;
      break;
    }
   case 29:
    HEAP8[$98] = 45;
    label = 30;
    break;
   case 30:
    $103 = $mm_063 + 1 | 0;
    $exitcond = ($103 | 0) == ($90 | 0);
    if ($exitcond) {
      label = 31;
      break;
    } else {
      $mm_063 = $103;
      label = 28;
      break;
    }
   case 31:
    $104 = $s_1 + $90 | 0;
    $s_2 = $104;
    label = 32;
    break;
   case 32:
    $106 = $strings + 4 | 0;
    $107 = HEAP32[$106 >> 2] | 0;
    $108 = $lengths + 4 | 0;
    $109 = HEAP32[$108 >> 2] | 0;
    $110 = ($107 | 0) == 0;
    if ($110) {
      $s_2_1 = $s_2;
      label = 37;
      break;
    } else {
      label = 34;
      break;
    }
   case 33:
    STACKTOP = __stackBase__;
    return $_0 | 0;
   case 34:
    $113 = HEAP32[$84 >> 2] | 0;
    $114 = ($s_2 | 0) == ($113 | 0);
    if ($114) {
      $s_1_1 = $s_2;
      label = 36;
      break;
    } else {
      label = 35;
      break;
    }
   case 35:
    $116 = $s_2 + 1 | 0;
    HEAP8[$s_2] = 32;
    $s_1_1 = $116;
    label = 36;
    break;
   case 36:
    _memcpy($s_1_1 | 0, $107 | 0, $109 | 0);
    $118 = $s_1_1 + $109 | 0;
    $s_2_1 = $118;
    label = 37;
    break;
   case 37:
    $120 = $strings + 8 | 0;
    $121 = HEAP32[$120 >> 2] | 0;
    $122 = $lengths + 8 | 0;
    $123 = HEAP32[$122 >> 2] | 0;
    $124 = ($121 | 0) == 0;
    if ($124) {
      $s_2_2 = $s_2_1;
      label = 41;
      break;
    } else {
      label = 38;
      break;
    }
   case 38:
    $126 = HEAP32[$84 >> 2] | 0;
    $127 = ($s_2_1 | 0) == ($126 | 0);
    if ($127) {
      $s_1_2 = $s_2_1;
      label = 40;
      break;
    } else {
      label = 39;
      break;
    }
   case 39:
    $129 = $s_2_1 + 1 | 0;
    HEAP8[$s_2_1] = 32;
    $s_1_2 = $129;
    label = 40;
    break;
   case 40:
    _memcpy($s_1_2 | 0, $121 | 0, $123 | 0);
    $131 = $s_1_2 + $123 | 0;
    $s_2_2 = $131;
    label = 41;
    break;
   case 41:
    $133 = $strings + 12 | 0;
    $134 = HEAP32[$133 >> 2] | 0;
    $135 = $lengths + 12 | 0;
    $136 = HEAP32[$135 >> 2] | 0;
    $137 = ($134 | 0) == 0;
    if ($137) {
      $s_2_3 = $s_2_2;
      label = 49;
      break;
    } else {
      label = 42;
      break;
    }
   case 42:
    $139 = HEAP32[$84 >> 2] | 0;
    $140 = ($s_2_2 | 0) == ($139 | 0);
    if ($140) {
      $s_1_3 = $s_2_2;
      label = 44;
      break;
    } else {
      label = 43;
      break;
    }
   case 43:
    $142 = $s_2_2 + 1 | 0;
    HEAP8[$s_2_2] = 32;
    $s_1_3 = $142;
    label = 44;
    break;
   case 44:
    _memcpy($s_1_3 | 0, $134 | 0, $136 | 0);
    $143 = ($136 | 0) == 0;
    if ($143) {
      label = 48;
      break;
    } else {
      $mm_063_3 = 0;
      label = 45;
      break;
    }
   case 45:
    $144 = $s_1_3 + $mm_063_3 | 0;
    $145 = HEAP8[$144] | 0;
    $146 = $145 << 24 >> 24 == 32;
    if ($146) {
      label = 46;
      break;
    } else {
      label = 47;
      break;
    }
   case 46:
    HEAP8[$144] = 45;
    label = 47;
    break;
   case 47:
    $149 = $mm_063_3 + 1 | 0;
    $exitcond_3 = ($149 | 0) == ($136 | 0);
    if ($exitcond_3) {
      label = 48;
      break;
    } else {
      $mm_063_3 = $149;
      label = 45;
      break;
    }
   case 48:
    $150 = $s_1_3 + $136 | 0;
    $s_2_3 = $150;
    label = 49;
    break;
   case 49:
    HEAP8[$s_2_3] = 0;
    $152 = HEAP32[$error >> 2] | 0;
    $_0 = $152;
    label = 33;
    break;
   case 50:
    $154 = _strlen($77 | 0) | 0;
    HEAP32[$75 >> 2] = $154;
    $155 = $len_1 + 1 | 0;
    $156 = $155 + $154 | 0;
    $len_1_1 = $156;
    label = 51;
    break;
   case 51:
    $158 = $lengths + 8 | 0;
    HEAP32[$158 >> 2] = 0;
    $159 = $strings + 8 | 0;
    $160 = HEAP32[$159 >> 2] | 0;
    $161 = ($160 | 0) == 0;
    if ($161) {
      $len_1_2 = $len_1_1;
      label = 53;
      break;
    } else {
      label = 52;
      break;
    }
   case 52:
    $163 = _strlen($160 | 0) | 0;
    HEAP32[$158 >> 2] = $163;
    $164 = $len_1_1 + 1 | 0;
    $165 = $164 + $163 | 0;
    $len_1_2 = $165;
    label = 53;
    break;
   case 53:
    $167 = $lengths + 12 | 0;
    HEAP32[$167 >> 2] = 0;
    $168 = $strings + 12 | 0;
    $169 = HEAP32[$168 >> 2] | 0;
    $170 = ($169 | 0) == 0;
    if ($170) {
      $len_1_3 = $len_1_2;
      label = 55;
      break;
    } else {
      label = 54;
      break;
    }
   case 54:
    $172 = _strlen($169 | 0) | 0;
    HEAP32[$167 >> 2] = $172;
    $173 = $len_1_2 + 1 | 0;
    $174 = $173 + $172 | 0;
    $len_1_3 = $174;
    label = 55;
    break;
   case 55:
    $176 = ($len_1_3 | 0) == 0;
    if ($176) {
      label = 22;
      break;
    } else {
      $len_2 = $len_1_3;
      label = 23;
      break;
    }
  }
  return 0;
}
function _pcf_find_property($face, $prop) {
  $face = $face | 0;
  $prop = $prop | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $i_010 = 0, $found_09 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $_found_0 = 0, $12 = 0, $13 = 0, $14 = 0, $or_cond = 0, $16 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 284 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 280 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) > 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 6;
      break;
    }
   case 2:
    $6 = HEAP32[$3 >> 2] | 0;
    $found_09 = 0;
    $i_010 = 0;
    label = 3;
    break;
   case 3:
    $8 = $2 + ($i_010 * 12 & -1) | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = _strcmp($9 | 0, $prop | 0) | 0;
    $11 = ($10 | 0) == 0;
    $_found_0 = $11 ? 1 : $found_09;
    $12 = $i_010 + 1 | 0;
    $13 = ($12 | 0) < ($6 | 0);
    $14 = $_found_0 << 24 >> 24 == 0;
    $or_cond = $13 & $14;
    if ($or_cond) {
      $found_09 = $_found_0;
      $i_010 = $12;
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    if ($14) {
      $_0 = 0;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $16 = $2 + ($i_010 * 12 & -1) | 0;
    $_0 = $16;
    label = 6;
    break;
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _pcf_seek_to_table_type($stream, $tables, $ntables, $type, $aformat, $asize) {
  $stream = $stream | 0;
  $tables = $tables | 0;
  $ntables = $ntables | 0;
  $type = $type | 0;
  $aformat = $aformat | 0;
  $asize = $asize | 0;
  var $i_0 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $error_0 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $i_0 = 0;
    label = 2;
    break;
   case 2:
    $2 = $i_0 >>> 0 < $ntables >>> 0;
    if ($2) {
      label = 3;
      break;
    } else {
      $error_0 = 3;
      label = 7;
      break;
    }
   case 3:
    $4 = $tables + ($i_0 << 4) | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($5 | 0) == ($type | 0);
    $7 = $i_0 + 1 | 0;
    if ($6) {
      label = 4;
      break;
    } else {
      $i_0 = $7;
      label = 2;
      break;
    }
   case 4:
    $9 = $stream + 8 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $tables + ($i_0 << 4) + 12 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $10 >>> 0 > $12 >>> 0;
    if ($13) {
      $error_0 = 83;
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $15 = $12 - $10 | 0;
    $16 = _FT_Stream_Skip($stream, $15) | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 6;
      break;
    } else {
      $error_0 = 83;
      label = 7;
      break;
    }
   case 6:
    $19 = $tables + ($i_0 << 4) + 8 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    HEAP32[$asize >> 2] = $20;
    $21 = $tables + ($i_0 << 4) + 4 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    HEAP32[$aformat >> 2] = $22;
    $_0 = 0;
    label = 8;
    break;
   case 7:
    HEAP32[$asize >> 2] = 0;
    $_0 = $error_0;
    label = 8;
    break;
   case 8:
    return $_0 | 0;
  }
  return 0;
}
function _pcf_get_metric($stream, $format, $metric) {
  $stream = $stream | 0;
  $format = $format | 0;
  $metric = $metric | 0;
  var $compr = 0, $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $compr = __stackBase__ | 0;
    $1 = $format >>> 0 < 256;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = $format & 4;
    $4 = ($3 | 0) != 0;
    $5 = $4 ? 5250676 : 5250708;
    $6 = $metric;
    $7 = _FT_Stream_ReadFields($stream, $5, $6) | 0;
    $error_0 = $7;
    label = 5;
    break;
   case 3:
    $9 = $compr | 0;
    $10 = _FT_Stream_ReadFields($stream, 5250844, $9) | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 4;
      break;
    } else {
      $error_0 = $10;
      label = 5;
      break;
    }
   case 4:
    $13 = HEAP8[$9] | 0;
    $14 = $13 & 255;
    $15 = $14 - 128 & 65535;
    $16 = $metric | 0;
    HEAP16[$16 >> 1] = $15;
    $17 = $compr + 1 | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $18 & 255;
    $20 = $19 - 128 & 65535;
    $21 = $metric + 2 | 0;
    HEAP16[$21 >> 1] = $20;
    $22 = $compr + 2 | 0;
    $23 = HEAP8[$22] | 0;
    $24 = $23 & 255;
    $25 = $24 - 128 & 65535;
    $26 = $metric + 4 | 0;
    HEAP16[$26 >> 1] = $25;
    $27 = $compr + 3 | 0;
    $28 = HEAP8[$27] | 0;
    $29 = $28 & 255;
    $30 = $29 - 128 & 65535;
    $31 = $metric + 6 | 0;
    HEAP16[$31 >> 1] = $30;
    $32 = $compr + 4 | 0;
    $33 = HEAP8[$32] | 0;
    $34 = $33 & 255;
    $35 = $34 - 128 & 65535;
    $36 = $metric + 8 | 0;
    HEAP16[$36 >> 1] = $35;
    $37 = $metric + 10 | 0;
    HEAP16[$37 >> 1] = 0;
    $error_0 = 0;
    label = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _pcf_get_charset_id($face, $acharset_encoding, $acharset_registry) {
  $face = $face | 0;
  $acharset_encoding = $acharset_encoding | 0;
  $acharset_registry = $acharset_registry | 0;
  HEAP32[$acharset_encoding >> 2] = HEAP32[$face + 176 >> 2] | 0;
  HEAP32[$acharset_registry >> 2] = HEAP32[$face + 180 >> 2] | 0;
  return 0;
}
function _pfr_cmap_init($cmap) {
  $cmap = $cmap | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $n_0 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 288 | 0;
    $4 = $3 + 120 | 0;
    $5 = $4;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $cmap + 16 | 0;
    HEAP32[$7 >> 2] = $6;
    $8 = $3 + 128 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9;
    $11 = $cmap + 20 | 0;
    HEAP32[$11 >> 2] = $10;
    $12 = HEAP32[$7 >> 2] | 0;
    $n_0 = 1;
    label = 2;
    break;
   case 2:
    $14 = $n_0 >>> 0 < $12 >>> 0;
    if ($14) {
      label = 3;
      break;
    } else {
      $error_0 = 0;
      label = 4;
      break;
    }
   case 3:
    $16 = $n_0 - 1 | 0;
    $17 = HEAP32[$11 >> 2] | 0;
    $18 = $17 + ($16 << 4) | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $17 + ($n_0 << 4) | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $19 >>> 0 < $21 >>> 0;
    $23 = $n_0 + 1 | 0;
    if ($22) {
      $n_0 = $23;
      label = 2;
      break;
    } else {
      $error_0 = 8;
      label = 4;
      break;
    }
   case 4:
    return $error_0 | 0;
  }
  return 0;
}
function _pfr_cmap_done($cmap) {
  $cmap = $cmap | 0;
  HEAP32[$cmap + 20 >> 2] = 0;
  HEAP32[$cmap + 16 >> 2] = 0;
  return;
}
function _pfr_cmap_char_index($cmap, $char_code) {
  $cmap = $cmap | 0;
  $char_code = $char_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $min_012 = 0, $max_011 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $16 = 0, $17 = 0, $max_0_ = 0, $_min_0 = 0, $18 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      $_0 = 0;
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $cmap + 20 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $max_011 = $2;
    $min_012 = 0;
    label = 3;
    break;
   case 3:
    $7 = $max_011 - $min_012 | 0;
    $8 = $7 >>> 1;
    $9 = $8 + $min_012 | 0;
    $10 = $5 + ($9 << 4) | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($11 | 0) == ($char_code | 0);
    if ($12) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $14 = $9 + 1 | 0;
    $_0 = $14;
    label = 6;
    break;
   case 5:
    $16 = $11 >>> 0 < $char_code >>> 0;
    $17 = $9 + 1 | 0;
    $max_0_ = $16 ? $max_011 : $9;
    $_min_0 = $16 ? $17 : $min_012;
    $18 = $_min_0 >>> 0 < $max_0_ >>> 0;
    if ($18) {
      $max_011 = $max_0_;
      $min_012 = $_min_0;
      label = 3;
      break;
    } else {
      $_0 = 0;
      label = 6;
      break;
    }
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _pfr_cmap_char_next($cmap, $pchar_code) {
  $cmap = $cmap | 0;
  $pchar_code = $pchar_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $char_code_0_in = 0, $char_code_0 = 0, $7 = 0, $max_025 = 0, $min_024 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $18 = 0, $20 = 0, $21 = 0, $_min_0 = 0, $max_0_ = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $or_cond = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $char_code_1 = 0, $result_1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$pchar_code >> 2] | 0;
    $2 = $cmap + 16 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = ($3 | 0) == 0;
    $5 = $cmap + 20 | 0;
    $char_code_0_in = $1;
    label = 2;
    break;
   case 2:
    $char_code_0 = $char_code_0_in + 1 | 0;
    if ($4) {
      $result_1 = 0;
      $char_code_1 = 0;
      label = 10;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = HEAP32[$5 >> 2] | 0;
    $min_024 = 0;
    $max_025 = $3;
    label = 4;
    break;
   case 4:
    $9 = $max_025 - $min_024 | 0;
    $10 = $9 >>> 1;
    $11 = $10 + $min_024 | 0;
    $12 = $7 + ($11 << 4) | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = ($13 | 0) == ($char_code_0 | 0);
    if ($14) {
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    $16 = ($11 | 0) == 0;
    if ($16) {
      $char_code_0_in = $char_code_0;
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $18 = $11 + 1 | 0;
    $result_1 = $18;
    $char_code_1 = $char_code_0;
    label = 10;
    break;
   case 7:
    $20 = $13 >>> 0 < $char_code_0 >>> 0;
    $21 = $11 + 1 | 0;
    $_min_0 = $20 ? $21 : $min_024;
    $max_0_ = $20 ? $max_025 : $11;
    $22 = $_min_0 >>> 0 < $max_0_ >>> 0;
    if ($22) {
      $min_024 = $_min_0;
      $max_025 = $max_0_;
      label = 4;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $23 = HEAP32[$2 >> 2] | 0;
    $24 = $_min_0 >>> 0 >= $23 >>> 0;
    $25 = ($_min_0 | 0) == 0;
    $or_cond = $24 | $25;
    if ($or_cond) {
      $result_1 = 0;
      $char_code_1 = 0;
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $27 = $cmap + 20 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $_min_0 + 1 | 0;
    $30 = $28 + ($_min_0 << 4) | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $result_1 = $29;
    $char_code_1 = $31;
    label = 10;
    break;
   case 10:
    HEAP32[$pchar_code >> 2] = $char_code_1;
    return $result_1 | 0;
  }
  return 0;
}
function _pfr_get_advance($pfrface, $gindex, $anadvance) {
  $pfrface = $pfrface | 0;
  $gindex = $gindex | 0;
  $anadvance = $anadvance | 0;
  var $1 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    HEAP32[$anadvance >> 2] = 0;
    $1 = ($gindex | 0) == 0;
    if ($1) {
      $error_0 = 6;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $gindex - 1 | 0;
    $4 = ($pfrface | 0) == 0;
    if ($4) {
      $error_0 = 6;
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $6 = $pfrface + 288 | 0;
    $7 = $6 + 120 | 0;
    $8 = $7;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $3 >>> 0 < $9 >>> 0;
    if ($10) {
      label = 4;
      break;
    } else {
      $error_0 = 6;
      label = 5;
      break;
    }
   case 4:
    $12 = $6 + 128 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13;
    $15 = $14 + ($3 << 4) + 4 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    HEAP32[$anadvance >> 2] = $16;
    $error_0 = 0;
    label = 5;
    break;
   case 5:
    return $error_0 | 0;
  }
  return 0;
}
function _pcf_get_bdf_property($face, $prop_name, $aproperty) {
  $face = $face | 0;
  $prop_name = $prop_name | 0;
  $aproperty = $aproperty | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $_c = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _pcf_find_property($face, $prop_name) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      $_0 = 6;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $1 + 4 | 0;
    $5 = HEAP8[$4] | 0;
    $6 = $5 << 24 >> 24 == 0;
    if ($6) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $8 = $aproperty | 0;
    HEAP32[$8 >> 2] = 1;
    $9 = $1 + 8 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $aproperty + 4 | 0;
    HEAP32[$11 >> 2] = $10;
    $_0 = 0;
    label = 5;
    break;
   case 4:
    $13 = $1 + 8 | 0;
    $14 = $13;
    $15 = $aproperty | 0;
    HEAP32[$15 >> 2] = 2;
    $16 = HEAP32[$14 >> 2] | 0;
    $17 = $aproperty + 4 | 0;
    $_c = $16;
    HEAP32[$17 >> 2] = $_c;
    $_0 = 0;
    label = 5;
    break;
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function _pfr_get_metrics($pfrface, $anoutline_resolution, $ametrics_resolution, $ametrics_x_scale, $ametrics_y_scale) {
  $pfrface = $pfrface | 0;
  $anoutline_resolution = $anoutline_resolution | 0;
  $ametrics_resolution = $ametrics_resolution | 0;
  $ametrics_x_scale = $ametrics_x_scale | 0;
  $ametrics_y_scale = $ametrics_y_scale | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $y_scale_0 = 0, $x_scale_0 = 0, $33 = 0, $36 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $pfrface + 288 | 0;
    $2 = $pfrface + 88 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = ($anoutline_resolution | 0) == 0;
    if ($4) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $1 + 12 | 0;
    $7 = $6;
    $8 = HEAP32[$7 >> 2] | 0;
    HEAP32[$anoutline_resolution >> 2] = $8;
    label = 3;
    break;
   case 3:
    $10 = ($ametrics_resolution | 0) == 0;
    if ($10) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $12 = $1 + 16 | 0;
    $13 = $12;
    $14 = HEAP32[$13 >> 2] | 0;
    HEAP32[$ametrics_resolution >> 2] = $14;
    label = 5;
    break;
   case 5:
    $16 = ($3 | 0) == 0;
    if ($16) {
      $x_scale_0 = 65536;
      $y_scale_0 = 65536;
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $18 = $3 + 12 | 0;
    $19 = HEAP16[$18 >> 1] | 0;
    $20 = $19 & 65535;
    $21 = $20 << 6;
    $22 = $1 + 16 | 0;
    $23 = $22;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = _FT_DivFix($21, $24) | 0;
    $26 = $3 + 14 | 0;
    $27 = HEAP16[$26 >> 1] | 0;
    $28 = $27 & 65535;
    $29 = $28 << 6;
    $30 = HEAP32[$23 >> 2] | 0;
    $31 = _FT_DivFix($29, $30) | 0;
    $x_scale_0 = $25;
    $y_scale_0 = $31;
    label = 7;
    break;
   case 7:
    $33 = ($ametrics_x_scale | 0) == 0;
    if ($33) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    HEAP32[$ametrics_x_scale >> 2] = $x_scale_0;
    label = 9;
    break;
   case 9:
    $36 = ($ametrics_y_scale | 0) == 0;
    if ($36) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    HEAP32[$ametrics_y_scale >> 2] = $y_scale_0;
    label = 11;
    break;
   case 11:
    return 0;
  }
  return 0;
}
function _pfr_face_get_kerning($pfrface, $glyph1, $glyph2, $kerning) {
  $pfrface = $pfrface | 0;
  $glyph1 = $glyph1 | 0;
  $glyph2 = $glyph2 | 0;
  $kerning = $kerning | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $glyph1_ = 0, $6 = 0, $7 = 0, $_079 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $or_cond = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $item_0101 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $_sum90 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $_sum92 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $_sum93 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $_sum94 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $_sum87 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $_sum89 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $_sum90_pn = 0, $cpair_0 = 0, $p_0 = 0, $102 = 0, $104 = 0, $106 = 0, $p_0_sum_pn_v = 0, $p_0_sum_pn = 0, $p_1 = 0, $base_0_ph = 0, $107 = 0, $108 = 0, $base_098 = 0, $probe_097 = 0, $110 = 0, $111 = 0, $_sum82 = 0, $113 = 0, $114 = 0, $115 = 0, $_sum84 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $_sum85 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $_sum86 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $_sum = 0, $131 = 0, $132 = 0, $133 = 0, $_sum81 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $_sum82_pn = 0, $cpair_1 = 0, $139 = 0, $141 = 0, $_base_0 = 0, $142 = 0, $base_0_lcssa = 0, $143 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $p_3 = 0, $cpair_2 = 0, $173 = 0, $p_2 = 0, $p_4 = 0, $175 = 0, $176 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $186 = 0, $value_0 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $pfrface + 288 | 0;
    $2 = $kerning | 0;
    HEAP32[$2 >> 2] = 0;
    $3 = $kerning + 4 | 0;
    HEAP32[$3 >> 2] = 0;
    $4 = ($glyph1 | 0) == 0;
    $5 = $glyph1 - 1 | 0;
    $glyph1_ = $4 ? 0 : $5;
    $6 = ($glyph2 | 0) == 0;
    $7 = $glyph2 - 1 | 0;
    $_079 = $6 ? 0 : $7;
    $8 = $1 + 120 | 0;
    $9 = $8;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $glyph1_ >>> 0 > $10 >>> 0;
    $12 = $_079 >>> 0 > $10 >>> 0;
    $or_cond = $11 | $12;
    if ($or_cond) {
      $error_0 = 0;
      label = 33;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $14 = $1 + 128 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15;
    $17 = $16 + ($glyph1_ << 4) | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $16 + ($_079 << 4) | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $18 << 16;
    $22 = $20 & 65535;
    $23 = $22 | $21;
    $24 = $1 + 136 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $pfrface + 104 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = ($25 | 0) == 0;
    if ($28) {
      $error_0 = 0;
      label = 33;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $29 = $25;
    $item_0101 = $29;
    label = 4;
    break;
   case 4:
    $31 = $item_0101 + 16 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $23 >>> 0 < $32 >>> 0;
    if ($33) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $35 = $item_0101 + 20 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $23 >>> 0 > $36 >>> 0;
    if ($37) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $39 = $item_0101 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = ($40 | 0) == 0;
    if ($41) {
      $error_0 = 0;
      label = 33;
      break;
    } else {
      $item_0101 = $40;
      label = 4;
      break;
    }
   case 7:
    $43 = $item_0101 + 12 | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    $45 = _FT_Stream_Seek($27, $44) | 0;
    $46 = ($45 | 0) == 0;
    if ($46) {
      label = 8;
      break;
    } else {
      $error_0 = $45;
      label = 33;
      break;
    }
   case 8:
    $48 = $item_0101 + 4 | 0;
    $49 = HEAP8[$48] | 0;
    $50 = $49 & 255;
    $51 = $item_0101 + 8 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = Math_imul($50, $52);
    $54 = _FT_Stream_EnterFrame($27, $53) | 0;
    $55 = ($54 | 0) == 0;
    if ($55) {
      label = 9;
      break;
    } else {
      $error_0 = $54;
      label = 33;
      break;
    }
   case 9:
    $57 = HEAP8[$48] | 0;
    $58 = $57 & 255;
    $59 = HEAP32[$51 >> 2] | 0;
    $60 = _ft_highpow2($58) | 0;
    $61 = Math_imul($60, $59);
    $62 = $27 + 32 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = $item_0101 + 5 | 0;
    $65 = HEAP8[$64] | 0;
    $66 = $65 & 1;
    $67 = $65 & 2;
    $68 = ($58 | 0) == ($60 | 0);
    if ($68) {
      $base_0_ph = $63;
      label = 16;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $70 = $58 - $60 | 0;
    $71 = Math_imul($70, $59);
    $72 = $66 << 24 >> 24 == 0;
    if ($72) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $_sum90 = $71 + 4 | 0;
    $74 = $63 + $71 | 0;
    $75 = HEAP8[$74] | 0;
    $76 = $75 & 255;
    $77 = $76 << 24;
    $_sum92 = $71 + 1 | 0;
    $78 = $63 + $_sum92 | 0;
    $79 = HEAP8[$78] | 0;
    $80 = $79 & 255;
    $81 = $80 << 16;
    $82 = $81 | $77;
    $_sum93 = $71 + 2 | 0;
    $83 = $63 + $_sum93 | 0;
    $84 = HEAP8[$83] | 0;
    $85 = $84 & 255;
    $86 = $85 << 8;
    $87 = $82 | $86;
    $_sum94 = $71 + 3 | 0;
    $88 = $63 + $_sum94 | 0;
    $89 = HEAP8[$88] | 0;
    $90 = $89 & 255;
    $91 = $87 | $90;
    $cpair_0 = $91;
    $_sum90_pn = $_sum90;
    label = 13;
    break;
   case 12:
    $_sum87 = $71 + 2 | 0;
    $93 = $63 + $71 | 0;
    $94 = HEAP8[$93] | 0;
    $95 = $94 & 255;
    $96 = $95 << 16;
    $_sum89 = $71 + 1 | 0;
    $97 = $63 + $_sum89 | 0;
    $98 = HEAP8[$97] | 0;
    $99 = $98 & 255;
    $100 = $96 | $99;
    $cpair_0 = $100;
    $_sum90_pn = $_sum87;
    label = 13;
    break;
   case 13:
    $p_0 = $63 + $_sum90_pn | 0;
    $102 = ($cpair_0 | 0) == ($23 | 0);
    if ($102) {
      $p_4 = $p_0;
      label = 28;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $104 = $cpair_0 >>> 0 < $23 >>> 0;
    if ($104) {
      label = 15;
      break;
    } else {
      $base_0_ph = $63;
      label = 16;
      break;
    }
   case 15:
    $106 = $67 << 24 >> 24 == 0;
    $p_0_sum_pn_v = $106 ? 1 : 2;
    $p_0_sum_pn = $_sum90_pn + $p_0_sum_pn_v | 0;
    $p_1 = $63 + $p_0_sum_pn | 0;
    $base_0_ph = $p_1;
    label = 16;
    break;
   case 16:
    $107 = $61 >>> 0 > $59 >>> 0;
    if ($107) {
      label = 17;
      break;
    } else {
      $base_0_lcssa = $base_0_ph;
      label = 23;
      break;
    }
   case 17:
    $108 = $66 << 24 >> 24 == 0;
    $probe_097 = $61;
    $base_098 = $base_0_ph;
    label = 18;
    break;
   case 18:
    $110 = $probe_097 >>> 1;
    $111 = $base_098 + $110 | 0;
    if ($108) {
      label = 20;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $_sum82 = $110 + 4 | 0;
    $113 = HEAP8[$111] | 0;
    $114 = $113 & 255;
    $115 = $114 << 24;
    $_sum84 = $110 + 1 | 0;
    $116 = $base_098 + $_sum84 | 0;
    $117 = HEAP8[$116] | 0;
    $118 = $117 & 255;
    $119 = $118 << 16;
    $120 = $119 | $115;
    $_sum85 = $110 + 2 | 0;
    $121 = $base_098 + $_sum85 | 0;
    $122 = HEAP8[$121] | 0;
    $123 = $122 & 255;
    $124 = $123 << 8;
    $125 = $120 | $124;
    $_sum86 = $110 + 3 | 0;
    $126 = $base_098 + $_sum86 | 0;
    $127 = HEAP8[$126] | 0;
    $128 = $127 & 255;
    $129 = $125 | $128;
    $cpair_1 = $129;
    $_sum82_pn = $_sum82;
    label = 21;
    break;
   case 20:
    $_sum = $110 + 2 | 0;
    $131 = HEAP8[$111] | 0;
    $132 = $131 & 255;
    $133 = $132 << 16;
    $_sum81 = $110 + 1 | 0;
    $134 = $base_098 + $_sum81 | 0;
    $135 = HEAP8[$134] | 0;
    $136 = $135 & 255;
    $137 = $133 | $136;
    $cpair_1 = $137;
    $_sum82_pn = $_sum;
    label = 21;
    break;
   case 21:
    $139 = ($cpair_1 | 0) == ($23 | 0);
    if ($139) {
      label = 27;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $141 = $cpair_1 >>> 0 < $23 >>> 0;
    $_base_0 = $141 ? $111 : $base_098;
    $142 = $110 >>> 0 > $59 >>> 0;
    if ($142) {
      $probe_097 = $110;
      $base_098 = $_base_0;
      label = 18;
      break;
    } else {
      $base_0_lcssa = $_base_0;
      label = 23;
      break;
    }
   case 23:
    $143 = $66 << 24 >> 24 == 0;
    if ($143) {
      label = 25;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $145 = $base_0_lcssa + 4 | 0;
    $146 = HEAP8[$base_0_lcssa] | 0;
    $147 = $146 & 255;
    $148 = $147 << 24;
    $149 = $base_0_lcssa + 1 | 0;
    $150 = HEAP8[$149] | 0;
    $151 = $150 & 255;
    $152 = $151 << 16;
    $153 = $152 | $148;
    $154 = $base_0_lcssa + 2 | 0;
    $155 = HEAP8[$154] | 0;
    $156 = $155 & 255;
    $157 = $156 << 8;
    $158 = $153 | $157;
    $159 = $base_0_lcssa + 3 | 0;
    $160 = HEAP8[$159] | 0;
    $161 = $160 & 255;
    $162 = $158 | $161;
    $cpair_2 = $162;
    $p_3 = $145;
    label = 26;
    break;
   case 25:
    $164 = $base_0_lcssa + 2 | 0;
    $165 = HEAP8[$base_0_lcssa] | 0;
    $166 = $165 & 255;
    $167 = $166 << 16;
    $168 = $base_0_lcssa + 1 | 0;
    $169 = HEAP8[$168] | 0;
    $170 = $169 & 255;
    $171 = $167 | $170;
    $cpair_2 = $171;
    $p_3 = $164;
    label = 26;
    break;
   case 26:
    $173 = ($cpair_2 | 0) == ($23 | 0);
    if ($173) {
      $p_4 = $p_3;
      label = 28;
      break;
    } else {
      label = 32;
      break;
    }
   case 27:
    $p_2 = $base_098 + $_sum82_pn | 0;
    $p_4 = $p_2;
    label = 28;
    break;
   case 28:
    $175 = $67 << 24 >> 24 == 0;
    $176 = HEAP8[$p_4] | 0;
    if ($175) {
      label = 30;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    $178 = $176 & 255;
    $179 = $178 << 8;
    $180 = $p_4 + 1 | 0;
    $181 = HEAP8[$180] | 0;
    $182 = $181 & 255;
    $183 = $182 | $179;
    $184 = $183 << 16 >> 16;
    $value_0 = $184;
    label = 31;
    break;
   case 30:
    $186 = $176 & 255;
    $value_0 = $186;
    label = 31;
    break;
   case 31:
    $188 = $item_0101 + 6 | 0;
    $189 = HEAP16[$188 >> 1] | 0;
    $190 = $189 << 16 >> 16;
    $191 = $190 + $value_0 | 0;
    HEAP32[$2 >> 2] = $191;
    label = 32;
    break;
   case 32:
    _FT_Stream_ExitFrame($27);
    $error_0 = $54;
    label = 33;
    break;
   case 33:
    return $error_0 | 0;
  }
  return 0;
}
function _pfr_get_service($module, $service_id) {
  $module = $module | 0;
  $service_id = $service_id | 0;
  return _ft_service_list_lookup(5250228, $service_id) | 0;
}
function _pfr_face_init($stream, $pfrface, $face_index, $num_params, $params) {
  $stream = $stream | 0;
  $pfrface = $pfrface | 0;
  $face_index = $face_index | 0;
  $num_params = $num_params | 0;
  $params = $params | 0;
  var $error = 0, $num_faces = 0, $charmap = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $nn_0 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $storemerge = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $93 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $100 = 0, $101 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $108 = 0, $109 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $sext = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $149 = 0, $151 = 0, $152 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $strike_0109 = 0, $size_0108 = 0, $n_0107 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $exitcond = 0, $187 = 0, $188 = 0, $189 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $197 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $gchar_0106 = 0, $count1_0105 = 0, $max_0104 = 0, $203 = 0, $204 = 0, $205 = 0, $_max_0 = 0, $206 = 0, $207 = 0, $208 = 0, $phitmp = 0, $max_0_lcssa = 0, $210 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $div = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $229 = 0, $230 = 0, $232 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 20 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $num_faces = __stackBase__ + 4 | 0;
    $charmap = __stackBase__ + 8 | 0;
    $1 = $pfrface + 132 | 0;
    $2 = $1;
    $3 = _pfr_header_load($2, $stream) | 0;
    HEAP32[$error >> 2] = $3;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 41;
      break;
    }
   case 2:
    $6 = _pfr_header_check($2) | 0;
    $7 = $6 << 24 >> 24 == 0;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    HEAP32[$error >> 2] = 2;
    label = 41;
    break;
   case 4:
    $10 = $pfrface + 152 | 0;
    $11 = $10;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = _pfr_log_font_count($stream, $12, $num_faces) | 0;
    HEAP32[$error >> 2] = $13;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 5;
      break;
    } else {
      label = 41;
      break;
    }
   case 5:
    $16 = HEAP32[$num_faces >> 2] | 0;
    $17 = $pfrface | 0;
    HEAP32[$17 >> 2] = $16;
    $18 = ($face_index | 0) < 0;
    if ($18) {
      label = 41;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $20 = ($16 | 0) > ($face_index | 0);
    if ($20) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    HEAP32[$error >> 2] = 6;
    label = 41;
    break;
   case 8:
    $23 = $pfrface + 240 | 0;
    $24 = $23;
    $25 = HEAP32[$11 >> 2] | 0;
    $26 = $pfrface + 204 | 0;
    $27 = $26;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = ($28 | 0) != 0;
    $30 = $29 & 1;
    $31 = _pfr_log_font_load($24, $stream, $face_index, $25, $30) | 0;
    HEAP32[$error >> 2] = $31;
    $32 = ($31 | 0) == 0;
    if ($32) {
      label = 9;
      break;
    } else {
      label = 41;
      break;
    }
   case 9:
    $34 = $pfrface + 288 | 0;
    $35 = $34;
    $36 = $23 + 44 | 0;
    $37 = $36;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $23 + 40 | 0;
    $40 = $39;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = _pfr_phy_font_load($35, $stream, $38, $41) | 0;
    HEAP32[$error >> 2] = $42;
    $43 = ($42 | 0) == 0;
    if ($43) {
      label = 10;
      break;
    } else {
      label = 41;
      break;
    }
   case 10:
    $45 = $pfrface + 4 | 0;
    HEAP32[$45 >> 2] = $face_index;
    $46 = $34 + 120 | 0;
    $47 = $46;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $48 + 1 | 0;
    $50 = $pfrface + 16 | 0;
    HEAP32[$50 >> 2] = $49;
    $51 = $pfrface + 8 | 0;
    HEAP32[$51 >> 2] = 1;
    $52 = $34 + 128 | 0;
    $53 = HEAP32[$47 >> 2] | 0;
    $nn_0 = 0;
    label = 11;
    break;
   case 11:
    $55 = $nn_0 >>> 0 < $53 >>> 0;
    if ($55) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $57 = HEAP32[$52 >> 2] | 0;
    $58 = $57;
    $59 = $58 + ($nn_0 << 4) + 12 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = ($60 | 0) == 0;
    $62 = $nn_0 + 1 | 0;
    if ($61) {
      $nn_0 = $62;
      label = 11;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $64 = HEAP32[$47 >> 2] | 0;
    $65 = ($nn_0 | 0) == ($64 | 0);
    if ($65) {
      label = 14;
      break;
    } else {
      label = 17;
      break;
    }
   case 14:
    $67 = $34 + 92 | 0;
    $68 = $67;
    $69 = HEAP32[$68 >> 2] | 0;
    $70 = ($69 | 0) == 0;
    if ($70) {
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    HEAP32[$51 >> 2] = 0;
    label = 17;
    break;
   case 16:
    HEAP32[$error >> 2] = 3;
    label = 41;
    break;
   case 17:
    $74 = $34 + 36 | 0;
    $75 = $74;
    $76 = HEAP32[$75 >> 2] | 0;
    $77 = $76 & 4;
    $78 = ($77 | 0) == 0;
    if ($78) {
      label = 18;
      break;
    } else {
      label = 19;
      break;
    }
   case 18:
    $80 = HEAP32[$51 >> 2] | 0;
    $81 = $80 | 4;
    HEAP32[$51 >> 2] = $81;
    label = 19;
    break;
   case 19:
    $83 = HEAP32[$75 >> 2] | 0;
    $84 = HEAP32[$51 >> 2] | 0;
    $85 = $83 << 4;
    $86 = $85 & 16;
    $87 = $86 + 16 | 0;
    $storemerge = $87 | $84;
    HEAP32[$51 >> 2] = $storemerge;
    $88 = $34 + 92 | 0;
    $89 = $88;
    $90 = HEAP32[$89 >> 2] | 0;
    $91 = ($90 | 0) == 0;
    if ($91) {
      label = 21;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $93 = $storemerge | 2;
    HEAP32[$51 >> 2] = $93;
    label = 21;
    break;
   case 21:
    $95 = $34 + 132 | 0;
    $96 = $95;
    $97 = HEAP32[$96 >> 2] | 0;
    $98 = ($97 | 0) == 0;
    if ($98) {
      label = 23;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $100 = HEAP32[$51 >> 2] | 0;
    $101 = $100 | 64;
    HEAP32[$51 >> 2] = $101;
    label = 23;
    break;
   case 23:
    $103 = $34 + 84 | 0;
    $104 = HEAP32[$103 >> 2] | 0;
    $105 = $pfrface + 20 | 0;
    HEAP32[$105 >> 2] = $104;
    $106 = ($104 | 0) == 0;
    if ($106) {
      label = 24;
      break;
    } else {
      label = 25;
      break;
    }
   case 24:
    $108 = $34 + 80 | 0;
    $109 = HEAP32[$108 >> 2] | 0;
    HEAP32[$105 >> 2] = $109;
    label = 25;
    break;
   case 25:
    $111 = $34 + 88 | 0;
    $112 = HEAP32[$111 >> 2] | 0;
    $113 = $pfrface + 24 | 0;
    HEAP32[$113 >> 2] = $112;
    $114 = $pfrface + 28 | 0;
    HEAP32[$114 >> 2] = 0;
    $115 = $pfrface + 32 | 0;
    HEAP32[$115 >> 2] = 0;
    $116 = $pfrface + 52 | 0;
    $117 = $34 + 20 | 0;
    $118 = $116;
    $119 = $117;
    _memcpy($118 | 0, $119 | 0, 16);
    $120 = $34 + 12 | 0;
    $121 = $120;
    $122 = HEAP32[$121 >> 2] | 0;
    $123 = $122 & 65535;
    $124 = $pfrface + 68 | 0;
    HEAP16[$124 >> 1] = $123;
    $125 = $34 + 32 | 0;
    $126 = $125;
    $127 = HEAP32[$126 >> 2] | 0;
    $128 = $127 & 65535;
    $129 = $pfrface + 70 | 0;
    HEAP16[$129 >> 1] = $128;
    $130 = $34 + 24 | 0;
    $131 = $130;
    $132 = HEAP32[$131 >> 2] | 0;
    $133 = $132 & 65535;
    $134 = $pfrface + 72 | 0;
    HEAP16[$134 >> 1] = $133;
    $135 = HEAP16[$124 >> 1] | 0;
    $136 = $135 & 65535;
    $137 = $136 * 12 & -1;
    $138 = ($137 >>> 0) / 10 >>> 0;
    $139 = $138 & 65535;
    $140 = $pfrface + 74 | 0;
    HEAP16[$140 >> 1] = $139;
    $sext = $138 << 16;
    $141 = $sext >> 16;
    $142 = HEAP16[$129 >> 1] | 0;
    $143 = $142 << 16 >> 16;
    $144 = HEAP16[$134 >> 1] | 0;
    $145 = $144 << 16 >> 16;
    $146 = $143 - $145 | 0;
    $147 = ($141 | 0) < ($146 | 0);
    if ($147) {
      label = 26;
      break;
    } else {
      label = 27;
      break;
    }
   case 26:
    $149 = $146 & 65535;
    HEAP16[$140 >> 1] = $149;
    label = 27;
    break;
   case 27:
    $151 = HEAP32[$89 >> 2] | 0;
    $152 = ($151 | 0) == 0;
    if ($152) {
      label = 32;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $154 = $pfrface + 104 | 0;
    $155 = HEAP32[$154 >> 2] | 0;
    $156 = $155 + 28 | 0;
    $157 = HEAP32[$156 >> 2] | 0;
    $158 = _ft_mem_realloc($157, 16, 0, $151, 0, $error) | 0;
    $159 = $158;
    HEAP32[$115 >> 2] = $159;
    $160 = HEAP32[$error >> 2] | 0;
    $161 = ($160 | 0) == 0;
    if ($161) {
      label = 29;
      break;
    } else {
      label = 41;
      break;
    }
   case 29:
    $162 = $34 + 100 | 0;
    $163 = HEAP32[$162 >> 2] | 0;
    $164 = $163;
    $n_0107 = 0;
    $size_0108 = $159;
    $strike_0109 = $164;
    label = 30;
    break;
   case 30:
    $166 = $strike_0109 + 4 | 0;
    $167 = HEAP32[$166 >> 2] | 0;
    $168 = $167 & 65535;
    $169 = $size_0108 | 0;
    HEAP16[$169 >> 1] = $168;
    $170 = $strike_0109 | 0;
    $171 = HEAP32[$170 >> 2] | 0;
    $172 = $171 & 65535;
    $173 = $size_0108 + 2 | 0;
    HEAP16[$173 >> 1] = $172;
    $174 = HEAP32[$166 >> 2] | 0;
    $175 = $174 << 6;
    $176 = $size_0108 + 4 | 0;
    HEAP32[$176 >> 2] = $175;
    $177 = HEAP32[$170 >> 2] | 0;
    $178 = $177 << 6;
    $179 = $size_0108 + 8 | 0;
    HEAP32[$179 >> 2] = $178;
    $180 = HEAP32[$166 >> 2] | 0;
    $181 = $180 << 6;
    $182 = $size_0108 + 12 | 0;
    HEAP32[$182 >> 2] = $181;
    $183 = $n_0107 + 1 | 0;
    $184 = $size_0108 + 16 | 0;
    $185 = $strike_0109 + 36 | 0;
    $exitcond = ($183 | 0) == ($151 | 0);
    if ($exitcond) {
      label = 31;
      break;
    } else {
      $n_0107 = $183;
      $size_0108 = $184;
      $strike_0109 = $185;
      label = 30;
      break;
    }
   case 31:
    HEAP32[$114 >> 2] = $151;
    label = 32;
    break;
   case 32:
    $187 = HEAP32[$75 >> 2] | 0;
    $188 = $187 & 4;
    $189 = ($188 | 0) == 0;
    if ($189) {
      label = 33;
      break;
    } else {
      label = 34;
      break;
    }
   case 33:
    $191 = $34 + 40 | 0;
    $192 = $191;
    $193 = HEAP32[$192 >> 2] | 0;
    $194 = $193 & 65535;
    $195 = $pfrface + 76 | 0;
    HEAP16[$195 >> 1] = $194;
    label = 39;
    break;
   case 34:
    $197 = HEAP32[$47 >> 2] | 0;
    $198 = ($197 | 0) == 0;
    if ($198) {
      $max_0_lcssa = 0;
      label = 38;
      break;
    } else {
      label = 35;
      break;
    }
   case 35:
    $199 = $34 + 128 | 0;
    $200 = HEAP32[$199 >> 2] | 0;
    $201 = $200;
    $max_0104 = 0;
    $count1_0105 = $197;
    $gchar_0106 = $201;
    label = 36;
    break;
   case 36:
    $203 = $gchar_0106 + 4 | 0;
    $204 = HEAP32[$203 >> 2] | 0;
    $205 = ($max_0104 | 0) < ($204 | 0);
    $_max_0 = $205 ? $204 : $max_0104;
    $206 = $count1_0105 - 1 | 0;
    $207 = $gchar_0106 + 16 | 0;
    $208 = ($206 | 0) == 0;
    if ($208) {
      label = 37;
      break;
    } else {
      $max_0104 = $_max_0;
      $count1_0105 = $206;
      $gchar_0106 = $207;
      label = 36;
      break;
    }
   case 37:
    $phitmp = $_max_0 & 65535;
    $max_0_lcssa = $phitmp;
    label = 38;
    break;
   case 38:
    $210 = $pfrface + 76 | 0;
    HEAP16[$210 >> 1] = $max_0_lcssa;
    label = 39;
    break;
   case 39:
    $212 = HEAP16[$140 >> 1] | 0;
    $213 = $pfrface + 78 | 0;
    HEAP16[$213 >> 1] = $212;
    $214 = HEAP16[$124 >> 1] | 0;
    $215 = $214 & 65535;
    $216 = ($215 | 0) / -10 & -1;
    $217 = $216 & 65535;
    $218 = $pfrface + 80 | 0;
    HEAP16[$218 >> 1] = $217;
    $219 = HEAP16[$124 >> 1] | 0;
    $div = ($219 & 65535) / 30 >>> 0;
    $220 = $pfrface + 82 | 0;
    HEAP16[$220 >> 1] = $div;
    $221 = $charmap | 0;
    HEAP32[$221 >> 2] = $pfrface;
    $222 = $charmap + 8 | 0;
    HEAP16[$222 >> 1] = 3;
    $223 = $charmap + 10 | 0;
    HEAP16[$223 >> 1] = 1;
    $224 = $charmap + 4 | 0;
    HEAP32[$224 >> 2] = 1970170211;
    $225 = _FT_CMap_New(5250524, 0, $charmap, 0) | 0;
    HEAP32[$error >> 2] = $225;
    $226 = HEAP32[$96 >> 2] | 0;
    $227 = ($226 | 0) == 0;
    if ($227) {
      label = 41;
      break;
    } else {
      label = 40;
      break;
    }
   case 40:
    $229 = HEAP32[$51 >> 2] | 0;
    $230 = $229 | 64;
    HEAP32[$51 >> 2] = $230;
    label = 41;
    break;
   case 41:
    $232 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $232 | 0;
  }
  return 0;
}
function _pfr_face_done($pfrface) {
  $pfrface = $pfrface | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($pfrface | 0) == 0;
    if ($1) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $pfrface + 96 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 8 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $pfrface + 20 | 0;
    HEAP32[$7 >> 2] = 0;
    $8 = $pfrface + 24 | 0;
    HEAP32[$8 >> 2] = 0;
    $9 = $pfrface + 288 | 0;
    $10 = $9;
    $11 = $pfrface + 100 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    _pfr_phy_font_done($10, $12);
    $13 = $pfrface + 32 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14;
    _ft_mem_free($6, $15);
    HEAP32[$13 >> 2] = 0;
    label = 3;
    break;
   case 3:
    return;
  }
}
function _pfr_slot_init($pfrslot) {
  $pfrslot = $pfrslot | 0;
  _pfr_glyph_init($pfrslot + 160 | 0, HEAP32[HEAP32[$pfrslot + 156 >> 2] >> 2] | 0);
  return 0;
}
function _pfr_slot_done($pfrslot) {
  $pfrslot = $pfrslot | 0;
  _pfr_glyph_done($pfrslot + 160 | 0);
  return;
}
function _pfr_slot_load($pfrslot, $pfrsize, $gindex, $load_flags) {
  $pfrslot = $pfrslot | 0;
  $pfrsize = $pfrsize | 0;
  $gindex = $gindex | 0;
  $load_flags = $load_flags | 0;
  var $cbox = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $gindex_ = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $75 = 0, $advance_0 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $vec_067 = 0, $n_066 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $cbox = __stackBase__ | 0;
    $1 = $pfrslot;
    $2 = $pfrsize;
    $3 = $pfrslot + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $pfrslot + 108 | 0;
    $6 = ($gindex | 0) == 0;
    $7 = $gindex - 1 | 0;
    $gindex_ = $6 ? 0 : $7;
    $8 = ($4 | 0) == 0;
    if ($8) {
      $error_0 = 6;
      label = 21;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = $4 + 288 | 0;
    $11 = $10 + 120 | 0;
    $12 = $11;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $gindex_ >>> 0 < $13 >>> 0;
    if ($14) {
      label = 3;
      break;
    } else {
      $error_0 = 6;
      label = 21;
      break;
    }
   case 3:
    $16 = $load_flags & 9;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $19 = _pfr_slot_load_bitmap($1, $2, $gindex_) | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      $error_0 = 0;
      label = 21;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $22 = $load_flags & 16384;
    $23 = ($22 | 0) == 0;
    if ($23) {
      label = 6;
      break;
    } else {
      $error_0 = 6;
      label = 21;
      break;
    }
   case 6:
    $25 = $10 + 128 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $26;
    $28 = $pfrslot + 72 | 0;
    HEAP32[$28 >> 2] = 1869968492;
    $29 = $pfrslot + 110 | 0;
    HEAP16[$29 >> 1] = 0;
    $30 = $5 | 0;
    HEAP16[$30 >> 1] = 0;
    $31 = $4 + 188 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $pfrslot + 160 | 0;
    $34 = $33;
    $35 = $4 + 104 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $27 + ($gindex_ << 4) + 12 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $27 + ($gindex_ << 4) + 8 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = _pfr_glyph_load($34, $36, $32, $38, $40) | 0;
    $42 = ($41 | 0) == 0;
    if ($42) {
      label = 7;
      break;
    } else {
      $error_0 = $41;
      label = 21;
      break;
    }
   case 7:
    $44 = $load_flags & 1;
    $45 = $pfrslot + 188 | 0;
    $46 = $45;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $47 + 20 | 0;
    $49 = $5;
    $50 = $48;
    _memcpy($49 | 0, $50 | 0, 20);
    $51 = $pfrslot + 124 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = $52 & -6;
    $54 = $53 | 4;
    HEAP32[$51 >> 2] = $54;
    $55 = ($pfrsize | 0) == 0;
    if ($55) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $57 = $pfrsize + 14 | 0;
    $58 = HEAP16[$57 >> 1] | 0;
    $59 = ($58 & 65535) < 24;
    if ($59) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $61 = $53 | 260;
    HEAP32[$51 >> 2] = $61;
    label = 10;
    break;
   case 10:
    $63 = $pfrslot + 40 | 0;
    HEAP32[$63 >> 2] = 0;
    $64 = $pfrslot + 52 | 0;
    HEAP32[$64 >> 2] = 0;
    $65 = $27 + ($gindex_ << 4) + 4 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = $10 + 16 | 0;
    $68 = $67;
    $69 = HEAP32[$68 >> 2] | 0;
    $70 = $10 + 12 | 0;
    $71 = $70;
    $72 = HEAP32[$71 >> 2] | 0;
    $73 = ($69 | 0) == ($72 | 0);
    if ($73) {
      $advance_0 = $66;
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $75 = _FT_MulDiv($66, $72, $69) | 0;
    $advance_0 = $75;
    label = 12;
    break;
   case 12:
    $77 = $10 + 36 | 0;
    $78 = $77;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = $79 & 1;
    $81 = ($80 | 0) == 0;
    if ($81) {
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    HEAP32[$64 >> 2] = $advance_0;
    label = 15;
    break;
   case 14:
    HEAP32[$63 >> 2] = $advance_0;
    label = 15;
    break;
   case 15:
    $85 = HEAP32[$63 >> 2] | 0;
    $86 = $pfrslot + 56 | 0;
    HEAP32[$86 >> 2] = $85;
    $87 = HEAP32[$64 >> 2] | 0;
    $88 = $pfrslot + 60 | 0;
    HEAP32[$88 >> 2] = $87;
    $89 = $pfrslot + 44 | 0;
    HEAP32[$89 >> 2] = 0;
    $90 = $pfrslot + 48 | 0;
    HEAP32[$90 >> 2] = 0;
    $91 = ($44 | 0) == 0;
    if ($91) {
      label = 16;
      break;
    } else {
      label = 20;
      break;
    }
   case 16:
    $93 = $pfrsize + 16 | 0;
    $94 = HEAP32[$93 >> 2] | 0;
    $95 = $pfrsize + 20 | 0;
    $96 = HEAP32[$95 >> 2] | 0;
    $97 = HEAP16[$29 >> 1] | 0;
    $98 = $97 << 16 >> 16 > 0;
    if ($98) {
      label = 17;
      break;
    } else {
      label = 19;
      break;
    }
   case 17:
    $99 = $pfrslot + 112 | 0;
    $100 = HEAP32[$99 >> 2] | 0;
    $n_066 = 0;
    $vec_067 = $100;
    label = 18;
    break;
   case 18:
    $102 = $vec_067 | 0;
    $103 = HEAP32[$102 >> 2] | 0;
    $104 = _FT_MulFix($103, $94) | 0;
    HEAP32[$102 >> 2] = $104;
    $105 = $vec_067 + 4 | 0;
    $106 = HEAP32[$105 >> 2] | 0;
    $107 = _FT_MulFix($106, $96) | 0;
    HEAP32[$105 >> 2] = $107;
    $108 = $n_066 + 1 | 0;
    $109 = $vec_067 + 8 | 0;
    $110 = HEAP16[$29 >> 1] | 0;
    $111 = $110 << 16 >> 16;
    $112 = ($108 | 0) < ($111 | 0);
    if ($112) {
      $n_066 = $108;
      $vec_067 = $109;
      label = 18;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $113 = HEAP32[$63 >> 2] | 0;
    $114 = _FT_MulFix($113, $94) | 0;
    HEAP32[$63 >> 2] = $114;
    $115 = HEAP32[$64 >> 2] | 0;
    $116 = _FT_MulFix($115, $96) | 0;
    HEAP32[$64 >> 2] = $116;
    label = 20;
    break;
   case 20:
    _FT_Outline_Get_CBox($5, $cbox);
    $118 = $cbox + 8 | 0;
    $119 = HEAP32[$118 >> 2] | 0;
    $120 = $cbox | 0;
    $121 = HEAP32[$120 >> 2] | 0;
    $122 = $119 - $121 | 0;
    $123 = $pfrslot + 24 | 0;
    HEAP32[$123 >> 2] = $122;
    $124 = $cbox + 12 | 0;
    $125 = HEAP32[$124 >> 2] | 0;
    $126 = $cbox + 4 | 0;
    $127 = HEAP32[$126 >> 2] | 0;
    $128 = $125 - $127 | 0;
    $129 = $pfrslot + 28 | 0;
    HEAP32[$129 >> 2] = $128;
    $130 = HEAP32[$120 >> 2] | 0;
    $131 = $pfrslot + 32 | 0;
    HEAP32[$131 >> 2] = $130;
    $132 = HEAP32[$124 >> 2] | 0;
    $133 = HEAP32[$129 >> 2] | 0;
    $134 = $132 - $133 | 0;
    $135 = $pfrslot + 36 | 0;
    HEAP32[$135 >> 2] = $134;
    $error_0 = $41;
    label = 21;
    break;
   case 21:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _pfr_get_kerning($pfrface, $left, $right, $avector) {
  $pfrface = $pfrface | 0;
  $left = $left | 0;
  $right = $right | 0;
  $avector = $avector | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $pfrface + 288 | 0;
    $2 = _pfr_face_get_kerning($pfrface, $left, $right, $avector) | 0;
    $3 = $1 + 12 | 0;
    $4 = $3;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $1 + 16 | 0;
    $7 = $6;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($5 | 0) == ($8 | 0);
    if ($9) {
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $11 = $avector | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $15 = _FT_MulDiv($12, $5, $8) | 0;
    HEAP32[$11 >> 2] = $15;
    label = 4;
    break;
   case 4:
    $17 = $avector + 4 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $21 = HEAP32[$11 >> 2] | 0;
    $22 = HEAP32[$4 >> 2] | 0;
    $23 = HEAP32[$7 >> 2] | 0;
    $24 = _FT_MulDiv($21, $22, $23) | 0;
    HEAP32[$17 >> 2] = $24;
    label = 6;
    break;
   case 6:
    return 0;
  }
  return 0;
}
function _pfr_slot_load_bitmap($glyph, $size, $glyph_index) {
  $glyph = $glyph | 0;
  $size = $size | 0;
  $glyph_index = $glyph_index | 0;
  var $gps_offset = 0, $gps_size = 0, $xpos = 0, $ypos = 0, $advance = 0, $xsize = 0, $ysize = 0, $format = 0, $p = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $n_068 = 0, $strike_067 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $_lobit = 0, $50 = 0, $char_len_1 = 0, $51 = 0, $_lobit65 = 0, $char_len_1_ = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $79 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $96 = 0, $97 = 0, $98 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $error_0 = 0, $108 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $_tr = 0, $164 = 0, $165 = 0, $error_1 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 36 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $gps_offset = __stackBase__ | 0;
    $gps_size = __stackBase__ + 4 | 0;
    $xpos = __stackBase__ + 8 | 0;
    $ypos = __stackBase__ + 12 | 0;
    $advance = __stackBase__ + 16 | 0;
    $xsize = __stackBase__ + 20 | 0;
    $ysize = __stackBase__ + 24 | 0;
    $format = __stackBase__ + 28 | 0;
    $p = __stackBase__ + 32 | 0;
    $1 = $glyph | 0;
    $2 = $glyph + 4 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 + 104 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $3 + 288 | 0;
    $7 = $6 + 128 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8;
    $10 = $6 + 92 | 0;
    $11 = $10;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      $_0 = 6;
      label = 17;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $14 = $6 + 100 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15;
    $17 = $size + 12 | 0;
    $18 = HEAP16[$17 >> 1] | 0;
    $19 = $18 & 65535;
    $20 = $size + 14 | 0;
    $strike_067 = $16;
    $n_068 = 0;
    label = 3;
    break;
   case 3:
    $22 = $strike_067 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = ($23 | 0) == ($19 | 0);
    if ($24) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $26 = $strike_067 + 4 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = HEAP16[$20 >> 1] | 0;
    $29 = $28 & 65535;
    $30 = ($27 | 0) == ($29 | 0);
    if ($30) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $32 = $strike_067 + 36 | 0;
    $33 = $n_068 + 1 | 0;
    $34 = HEAP32[$11 >> 2] | 0;
    $35 = $33 >>> 0 < $34 >>> 0;
    if ($35) {
      $strike_067 = $32;
      $n_068 = $33;
      label = 3;
      break;
    } else {
      $_0 = 6;
      label = 17;
      break;
    }
   case 6:
    $37 = $strike_067 + 8 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $6 + 144 | 0;
    $40 = $39;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = $strike_067 + 24 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $43 + $41 | 0;
    $45 = _FT_Stream_Seek($5, $44) | 0;
    $46 = ($45 | 0) == 0;
    if ($46) {
      label = 7;
      break;
    } else {
      $_0 = $45;
      label = 17;
      break;
    }
   case 7:
    $48 = $38 & 1;
    $49 = $38 >>> 1;
    $_lobit = $49 & 1;
    $50 = $48 | 4;
    $char_len_1 = $50 + $_lobit | 0;
    $51 = $38 >>> 2;
    $_lobit65 = $51 & 1;
    $char_len_1_ = $char_len_1 + $_lobit65 | 0;
    $52 = $strike_067 + 28 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = Math_imul($53, $char_len_1_);
    $55 = _FT_Stream_EnterFrame($5, $54) | 0;
    $56 = ($55 | 0) == 0;
    if ($56) {
      label = 8;
      break;
    } else {
      $_0 = $55;
      label = 17;
      break;
    }
   case 8:
    $58 = $5 + 32 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = $5 + 36 | 0;
    $61 = HEAP32[$60 >> 2] | 0;
    $62 = HEAP32[$52 >> 2] | 0;
    $63 = HEAP32[$37 >> 2] | 0;
    $64 = $9 + ($glyph_index << 4) | 0;
    $65 = HEAP32[$64 >> 2] | 0;
    _pfr_lookup_bitmap_data($59, $61, $62, $63, $65, $gps_offset, $gps_size);
    _FT_Stream_ExitFrame($5);
    $66 = HEAP32[$gps_size >> 2] | 0;
    $67 = ($66 | 0) == 0;
    if ($67) {
      $_0 = 6;
      label = 17;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    HEAP32[$xpos >> 2] = 0;
    HEAP32[$ypos >> 2] = 0;
    HEAP32[$xsize >> 2] = 0;
    HEAP32[$ysize >> 2] = 0;
    HEAP32[$format >> 2] = 0;
    $69 = $9 + ($glyph_index << 4) + 4 | 0;
    $70 = HEAP32[$69 >> 2] | 0;
    HEAP32[$advance >> 2] = $70;
    $71 = $6 + 16 | 0;
    $72 = $71;
    $73 = HEAP32[$72 >> 2] | 0;
    $74 = $6 + 12 | 0;
    $75 = $74;
    $76 = HEAP32[$75 >> 2] | 0;
    $77 = ($73 | 0) == ($76 | 0);
    if ($77) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $79 = _FT_MulDiv($70, $76, $73) | 0;
    HEAP32[$advance >> 2] = $79;
    label = 11;
    break;
   case 11:
    $81 = HEAP32[$advance >> 2] | 0;
    $82 = $glyph + 56 | 0;
    HEAP32[$82 >> 2] = $81;
    $83 = HEAP16[$17 >> 1] | 0;
    $84 = $83 & 65535;
    $85 = $84 << 8;
    $86 = HEAP32[$69 >> 2] | 0;
    $87 = HEAP32[$72 >> 2] | 0;
    $88 = _FT_MulDiv($85, $86, $87) | 0;
    HEAP32[$advance >> 2] = $88;
    $89 = $3 + 188 | 0;
    $90 = HEAP32[$89 >> 2] | 0;
    $91 = HEAP32[$gps_offset >> 2] | 0;
    $92 = $91 + $90 | 0;
    $93 = _FT_Stream_Seek($5, $92) | 0;
    $94 = ($93 | 0) == 0;
    if ($94) {
      label = 12;
      break;
    } else {
      $_0 = $93;
      label = 17;
      break;
    }
   case 12:
    $96 = HEAP32[$gps_size >> 2] | 0;
    $97 = _FT_Stream_EnterFrame($5, $96) | 0;
    $98 = ($97 | 0) == 0;
    if ($98) {
      label = 13;
      break;
    } else {
      $_0 = $97;
      label = 17;
      break;
    }
   case 13:
    $100 = HEAP32[$58 >> 2] | 0;
    HEAP32[$p >> 2] = $100;
    $101 = HEAP32[$60 >> 2] | 0;
    $102 = HEAP32[$advance >> 2] | 0;
    $103 = _pfr_load_bitmap_metrics($p, $101, $102, $xpos, $ypos, $xsize, $ysize, $advance, $format) | 0;
    $104 = HEAP32[$ypos >> 2] | 0;
    $105 = HEAP32[$ysize >> 2] | 0;
    $106 = $105 + $104 | 0;
    $107 = ($106 | 0) < 0;
    $error_0 = $107 ? 23 : $103;
    $108 = ($error_0 | 0) == 0;
    if ($108) {
      label = 14;
      break;
    } else {
      $error_1 = $error_0;
      label = 16;
      break;
    }
   case 14:
    $110 = $glyph + 72 | 0;
    HEAP32[$110 >> 2] = 1651078259;
    $111 = HEAP32[$xsize >> 2] | 0;
    $112 = $glyph + 76 | 0;
    $113 = $glyph + 80 | 0;
    HEAP32[$113 >> 2] = $111;
    $114 = HEAP32[$ysize >> 2] | 0;
    $115 = $112 | 0;
    HEAP32[$115 >> 2] = $114;
    $116 = HEAP32[$xsize >> 2] | 0;
    $117 = $116 + 7 | 0;
    $118 = $117 >> 3;
    $119 = $glyph + 84 | 0;
    HEAP32[$119 >> 2] = $118;
    $120 = $glyph + 94 | 0;
    HEAP8[$120] = 1;
    $121 = HEAP32[$xsize >> 2] | 0;
    $122 = $121 << 6;
    $123 = $glyph + 24 | 0;
    HEAP32[$123 >> 2] = $122;
    $124 = HEAP32[$ysize >> 2] | 0;
    $125 = $124 << 6;
    $126 = $glyph + 28 | 0;
    HEAP32[$126 >> 2] = $125;
    $127 = HEAP32[$xpos >> 2] | 0;
    $128 = $127 << 6;
    $129 = $glyph + 32 | 0;
    HEAP32[$129 >> 2] = $128;
    $130 = HEAP32[$ypos >> 2] | 0;
    $131 = $130 << 6;
    $132 = $glyph + 36 | 0;
    HEAP32[$132 >> 2] = $131;
    $133 = HEAP32[$advance >> 2] | 0;
    $134 = $133 >> 2;
    $135 = $134 + 32 | 0;
    $136 = $135 & -64;
    $137 = $glyph + 40 | 0;
    HEAP32[$137 >> 2] = $136;
    $138 = HEAP32[$123 >> 2] | 0;
    $139 = -$138 | 0;
    $140 = $139 >> 1;
    $141 = $glyph + 44 | 0;
    HEAP32[$141 >> 2] = $140;
    $142 = $glyph + 48 | 0;
    HEAP32[$142 >> 2] = 0;
    $143 = $size + 32 | 0;
    $144 = HEAP32[$143 >> 2] | 0;
    $145 = $glyph + 52 | 0;
    HEAP32[$145 >> 2] = $144;
    $146 = HEAP32[$xpos >> 2] | 0;
    $147 = $glyph + 100 | 0;
    HEAP32[$147 >> 2] = $146;
    $148 = HEAP32[$ypos >> 2] | 0;
    $149 = HEAP32[$ysize >> 2] | 0;
    $150 = $149 + $148 | 0;
    $151 = $glyph + 104 | 0;
    HEAP32[$151 >> 2] = $150;
    $152 = HEAP32[$119 >> 2] | 0;
    $153 = HEAP32[$ysize >> 2] | 0;
    $154 = Math_imul($153, $152);
    $155 = _ft_glyphslot_alloc_bitmap($1, $154) | 0;
    $156 = ($155 | 0) == 0;
    if ($156) {
      label = 15;
      break;
    } else {
      $error_1 = $155;
      label = 16;
      break;
    }
   case 15:
    $158 = HEAP32[$p >> 2] | 0;
    $159 = HEAP32[$60 >> 2] | 0;
    $160 = HEAP32[$format >> 2] | 0;
    $161 = $3 + 208 | 0;
    $162 = $161;
    $163 = HEAP32[$162 >> 2] | 0;
    $_tr = $163 & 255;
    $164 = $_tr & 2;
    $165 = _pfr_load_bitmap_bits($158, $159, $160, $164, $112) | 0;
    $error_1 = $165;
    label = 16;
    break;
   case 16:
    _FT_Stream_ExitFrame($5);
    $_0 = $error_1;
    label = 17;
    break;
   case 17:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _pfr_glyph_load($glyph, $stream, $gps_offset, $offset, $size) {
  $glyph = $glyph | 0;
  $stream = $stream | 0;
  $gps_offset = $gps_offset | 0;
  $offset = $offset | 0;
  $size = $size | 0;
  _FT_GlyphLoader_Rewind(HEAP32[$glyph + 28 >> 2] | 0);
  HEAP32[$glyph + 16 >> 2] = 0;
  return _pfr_glyph_load_rec($glyph, $stream, $gps_offset, $offset, $size) | 0;
}
function _pfr_glyph_load_rec($glyph, $stream, $gps_offset, $offset, $size) {
  $glyph = $glyph | 0;
  $stream = $stream | 0;
  $gps_offset = $gps_offset | 0;
  $offset = $offset | 0;
  $size = $size | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $n_063 = 0, $31 = 0, $_sum = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $vec_057 = 0, $i_056 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $exitcond = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $vec1_060 = 0, $i_159 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $exitcond65 = 0, $97 = 0, $98 = 0, $100 = 0, $error_1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $offset + $gps_offset | 0;
    $2 = _FT_Stream_Seek($stream, $1) | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $error_1 = $2;
      label = 19;
      break;
    }
   case 2:
    $5 = _FT_Stream_EnterFrame($stream, $size) | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      $error_1 = $5;
      label = 19;
      break;
    }
   case 3:
    $8 = $stream + 32 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 + $size | 0;
    $11 = ($size | 0) == 0;
    if ($11) {
      label = 18;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $13 = HEAP8[$9] | 0;
    $14 = $13 << 24 >> 24 < 0;
    if ($14) {
      label = 5;
      break;
    } else {
      label = 18;
      break;
    }
   case 5:
    $16 = $glyph + 28 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $glyph + 16 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = _pfr_glyph_load_compound($glyph, $9, $10) | 0;
    _FT_Stream_ExitFrame($stream);
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 6;
      break;
    } else {
      $error_1 = $20;
      label = 19;
      break;
    }
   case 6:
    $23 = HEAP32[$18 >> 2] | 0;
    $24 = $23 - $19 | 0;
    $25 = $glyph + 24 | 0;
    $26 = ($24 | 0) > 0;
    if ($26) {
      label = 7;
      break;
    } else {
      $error_1 = 0;
      label = 19;
      break;
    }
   case 7:
    $27 = $17 + 22 | 0;
    $28 = $17 + 24 | 0;
    $29 = $17 + 24 | 0;
    $n_063 = 0;
    label = 8;
    break;
   case 8:
    $31 = HEAP32[$25 >> 2] | 0;
    $_sum = $n_063 + $19 | 0;
    $32 = HEAP16[$27 >> 1] | 0;
    $33 = $32 << 16 >> 16;
    $34 = $31 + ($_sum * 24 & -1) + 16 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $31 + ($_sum * 24 & -1) + 20 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = _pfr_glyph_load_rec($glyph, $stream, $gps_offset, $35, $37) | 0;
    $39 = ($38 | 0) == 0;
    if ($39) {
      label = 9;
      break;
    } else {
      $error_1 = $38;
      label = 19;
      break;
    }
   case 9:
    $41 = HEAP32[$25 >> 2] | 0;
    $42 = HEAP16[$27 >> 1] | 0;
    $43 = $42 << 16 >> 16;
    $44 = $43 - $33 | 0;
    $45 = $41 + ($_sum * 24 & -1) | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = ($46 | 0) == 65536;
    if ($47) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $49 = $41 + ($_sum * 24 & -1) + 4 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = ($50 | 0) == 65536;
    if ($51) {
      label = 14;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $53 = ($44 | 0) > 0;
    if ($53) {
      label = 12;
      break;
    } else {
      label = 17;
      break;
    }
   case 12:
    $54 = HEAP32[$29 >> 2] | 0;
    $55 = $54 + ($33 << 3) | 0;
    $56 = $41 + ($_sum * 24 & -1) + 8 | 0;
    $57 = $41 + ($_sum * 24 & -1) + 4 | 0;
    $58 = $41 + ($_sum * 24 & -1) + 12 | 0;
    $59 = $42 << 16 >> 16;
    $60 = $32 << 16 >> 16;
    $61 = $59 - $60 | 0;
    $i_056 = 0;
    $vec_057 = $55;
    label = 13;
    break;
   case 13:
    $63 = $vec_057 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = HEAP32[$45 >> 2] | 0;
    $66 = _FT_MulFix($64, $65) | 0;
    $67 = HEAP32[$56 >> 2] | 0;
    $68 = $67 + $66 | 0;
    HEAP32[$63 >> 2] = $68;
    $69 = $vec_057 + 4 | 0;
    $70 = HEAP32[$69 >> 2] | 0;
    $71 = HEAP32[$57 >> 2] | 0;
    $72 = _FT_MulFix($70, $71) | 0;
    $73 = HEAP32[$58 >> 2] | 0;
    $74 = $73 + $72 | 0;
    HEAP32[$69 >> 2] = $74;
    $75 = $i_056 + 1 | 0;
    $76 = $vec_057 + 8 | 0;
    $exitcond = ($75 | 0) == ($61 | 0);
    if ($exitcond) {
      label = 17;
      break;
    } else {
      $i_056 = $75;
      $vec_057 = $76;
      label = 13;
      break;
    }
   case 14:
    $78 = ($44 | 0) > 0;
    if ($78) {
      label = 15;
      break;
    } else {
      label = 17;
      break;
    }
   case 15:
    $79 = HEAP32[$28 >> 2] | 0;
    $80 = $79 + ($33 << 3) | 0;
    $81 = $41 + ($_sum * 24 & -1) + 8 | 0;
    $82 = $41 + ($_sum * 24 & -1) + 12 | 0;
    $83 = $42 << 16 >> 16;
    $84 = $32 << 16 >> 16;
    $85 = $83 - $84 | 0;
    $i_159 = 0;
    $vec1_060 = $80;
    label = 16;
    break;
   case 16:
    $87 = HEAP32[$81 >> 2] | 0;
    $88 = $vec1_060 | 0;
    $89 = HEAP32[$88 >> 2] | 0;
    $90 = $89 + $87 | 0;
    HEAP32[$88 >> 2] = $90;
    $91 = HEAP32[$82 >> 2] | 0;
    $92 = $vec1_060 + 4 | 0;
    $93 = HEAP32[$92 >> 2] | 0;
    $94 = $93 + $91 | 0;
    HEAP32[$92 >> 2] = $94;
    $95 = $i_159 + 1 | 0;
    $96 = $vec1_060 + 8 | 0;
    $exitcond65 = ($95 | 0) == ($85 | 0);
    if ($exitcond65) {
      label = 17;
      break;
    } else {
      $i_159 = $95;
      $vec1_060 = $96;
      label = 16;
      break;
    }
   case 17:
    $97 = $n_063 + 1 | 0;
    $98 = ($97 | 0) < ($24 | 0);
    if ($98) {
      $n_063 = $97;
      label = 8;
      break;
    } else {
      $error_1 = $38;
      label = 19;
      break;
    }
   case 18:
    $100 = _pfr_glyph_load_simple($glyph, $9, $10) | 0;
    _FT_Stream_ExitFrame($stream);
    $error_1 = $100;
    label = 19;
    break;
   case 19:
    return $error_1 | 0;
  }
  return 0;
}
function _pfr_glyph_start($glyph) {
  $glyph = $glyph | 0;
  HEAP8[$glyph + 32 | 0] = 0;
  return;
}
function _pfr_glyph_load_compound($glyph, $p, $limit) {
  $glyph = $glyph | 0;
  $p = $p | 0;
  $limit = $limit | 0;
  var $1 = 0, $error = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $subglyph_050 = 0, $i_049 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $71 = 0, $72 = 0, $73 = 0, $75 = 0, $76 = 0, $77 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $89 = 0, $91 = 0, $92 = 0, $93 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $104 = 0, $105 = 0, $106 = 0, $108 = 0, $109 = 0, $x_pos_0 = 0, $111 = 0, $112 = 0, $114 = 0, $115 = 0, $116 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $127 = 0, $128 = 0, $129 = 0, $131 = 0, $132 = 0, $y_pos_0 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $140 = 0, $141 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $152 = 0, $153 = 0, $155 = 0, $156 = 0, $157 = 0, $159 = 0, $160 = 0, $161 = 0, $163 = 0, $164 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $180 = 0, $181 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = __stackBase__ | 0;
    $error = __stackBase__ + 4 | 0;
    HEAP32[$1 >> 2] = $p;
    HEAP32[$error >> 2] = 0;
    $2 = $glyph + 28 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $p + 1 | 0;
    $7 = $6 >>> 0 > $limit >>> 0;
    if ($7) {
      label = 41;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $6;
    $9 = HEAP8[$p] | 0;
    $10 = $9 & 255;
    $11 = $10 & 128;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 41;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $14 = $10 & 63;
    $15 = $10 & 8;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $18 = _pfr_extra_items_skip($1, $limit) | 0;
    HEAP32[$error >> 2] = $18;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 5;
      break;
    } else {
      label = 40;
      break;
    }
   case 5:
    $21 = $glyph + 16 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22 + $14 | 0;
    $24 = $glyph + 20 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $23 >>> 0 > $25 >>> 0;
    if ($26) {
      label = 6;
      break;
    } else {
      label = 10;
      break;
    }
   case 6:
    $28 = $23 + 3 | 0;
    $29 = $28 & -4;
    $30 = $29 >>> 0 > 64;
    if ($30) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    HEAP32[$error >> 2] = 8;
    label = 40;
    break;
   case 8:
    $33 = $glyph + 24 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $34;
    $36 = _ft_mem_realloc($5, 24, $25, $29, $35, $error) | 0;
    $37 = $36;
    HEAP32[$33 >> 2] = $37;
    $38 = HEAP32[$error >> 2] | 0;
    $39 = ($38 | 0) == 0;
    if ($39) {
      label = 9;
      break;
    } else {
      label = 40;
      break;
    }
   case 9:
    HEAP32[$24 >> 2] = $29;
    label = 10;
    break;
   case 10:
    $42 = ($14 | 0) == 0;
    if ($42) {
      label = 40;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $43 = $glyph + 24 | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    $45 = $44 + ($22 * 24 & -1) | 0;
    $i_049 = 0;
    $subglyph_050 = $45;
    label = 12;
    break;
   case 12:
    $47 = HEAP32[$1 >> 2] | 0;
    $48 = $47 + 1 | 0;
    $49 = $48 >>> 0 > $limit >>> 0;
    if ($49) {
      label = 41;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    HEAP32[$1 >> 2] = $48;
    $51 = HEAP8[$47] | 0;
    $52 = $51 & 255;
    $53 = $subglyph_050 | 0;
    HEAP32[$53 >> 2] = 65536;
    $54 = $52 & 16;
    $55 = ($54 | 0) == 0;
    if ($55) {
      label = 16;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $57 = HEAP32[$1 >> 2] | 0;
    $58 = $57 + 2 | 0;
    $59 = $58 >>> 0 > $limit >>> 0;
    if ($59) {
      label = 41;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    HEAP32[$1 >> 2] = $58;
    $61 = HEAP8[$57] | 0;
    $62 = $61 & 255;
    $63 = $62 << 8;
    $64 = $57 + 1 | 0;
    $65 = HEAP8[$64] | 0;
    $66 = $65 & 255;
    $67 = $63 | $66;
    $68 = $67 << 16 >> 16;
    $69 = $68 << 4;
    HEAP32[$53 >> 2] = $69;
    label = 16;
    break;
   case 16:
    $71 = $subglyph_050 + 4 | 0;
    HEAP32[$71 >> 2] = 65536;
    $72 = $52 & 32;
    $73 = ($72 | 0) == 0;
    if ($73) {
      label = 19;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $75 = HEAP32[$1 >> 2] | 0;
    $76 = $75 + 2 | 0;
    $77 = $76 >>> 0 > $limit >>> 0;
    if ($77) {
      label = 41;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    HEAP32[$1 >> 2] = $76;
    $79 = HEAP8[$75] | 0;
    $80 = $79 & 255;
    $81 = $80 << 8;
    $82 = $75 + 1 | 0;
    $83 = HEAP8[$82] | 0;
    $84 = $83 & 255;
    $85 = $81 | $84;
    $86 = $85 << 16 >> 16;
    $87 = $86 << 4;
    HEAP32[$71 >> 2] = $87;
    label = 19;
    break;
   case 19:
    $89 = $52 & 3;
    if (($89 | 0) == 1) {
      label = 20;
      break;
    } else if (($89 | 0) == 2) {
      label = 22;
      break;
    } else {
      $x_pos_0 = 0;
      label = 24;
      break;
    }
   case 20:
    $91 = HEAP32[$1 >> 2] | 0;
    $92 = $91 + 2 | 0;
    $93 = $92 >>> 0 > $limit >>> 0;
    if ($93) {
      label = 41;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    HEAP32[$1 >> 2] = $92;
    $95 = HEAP8[$91] | 0;
    $96 = $95 & 255;
    $97 = $96 << 8;
    $98 = $91 + 1 | 0;
    $99 = HEAP8[$98] | 0;
    $100 = $99 & 255;
    $101 = $97 | $100;
    $102 = $101 << 16 >> 16;
    $x_pos_0 = $102;
    label = 24;
    break;
   case 22:
    $104 = HEAP32[$1 >> 2] | 0;
    $105 = $104 + 1 | 0;
    $106 = $105 >>> 0 > $limit >>> 0;
    if ($106) {
      label = 41;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    HEAP32[$1 >> 2] = $105;
    $108 = HEAP8[$104] | 0;
    $109 = $108 << 24 >> 24;
    $x_pos_0 = $109;
    label = 24;
    break;
   case 24:
    $111 = $52 >>> 2;
    $112 = $111 & 3;
    if (($112 | 0) == 1) {
      label = 25;
      break;
    } else if (($112 | 0) == 2) {
      label = 27;
      break;
    } else {
      $y_pos_0 = 0;
      label = 29;
      break;
    }
   case 25:
    $114 = HEAP32[$1 >> 2] | 0;
    $115 = $114 + 2 | 0;
    $116 = $115 >>> 0 > $limit >>> 0;
    if ($116) {
      label = 41;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    HEAP32[$1 >> 2] = $115;
    $118 = HEAP8[$114] | 0;
    $119 = $118 & 255;
    $120 = $119 << 8;
    $121 = $114 + 1 | 0;
    $122 = HEAP8[$121] | 0;
    $123 = $122 & 255;
    $124 = $120 | $123;
    $125 = $124 << 16 >> 16;
    $y_pos_0 = $125;
    label = 29;
    break;
   case 27:
    $127 = HEAP32[$1 >> 2] | 0;
    $128 = $127 + 1 | 0;
    $129 = $128 >>> 0 > $limit >>> 0;
    if ($129) {
      label = 41;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    HEAP32[$1 >> 2] = $128;
    $131 = HEAP8[$127] | 0;
    $132 = $131 << 24 >> 24;
    $y_pos_0 = $132;
    label = 29;
    break;
   case 29:
    $134 = $subglyph_050 + 8 | 0;
    HEAP32[$134 >> 2] = $x_pos_0;
    $135 = $subglyph_050 + 12 | 0;
    HEAP32[$135 >> 2] = $y_pos_0;
    $136 = $52 & 64;
    $137 = ($136 | 0) == 0;
    $138 = HEAP32[$1 >> 2] | 0;
    if ($137) {
      label = 32;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    $140 = $138 + 2 | 0;
    $141 = $140 >>> 0 > $limit >>> 0;
    if ($141) {
      label = 41;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    HEAP32[$1 >> 2] = $140;
    $143 = HEAP8[$138] | 0;
    $144 = $143 & 255;
    $145 = $144 << 8;
    $146 = $138 + 1 | 0;
    $147 = HEAP8[$146] | 0;
    $148 = $147 & 255;
    $149 = $145 | $148;
    $150 = $subglyph_050 + 20 | 0;
    HEAP32[$150 >> 2] = $149;
    label = 34;
    break;
   case 32:
    $152 = $138 + 1 | 0;
    $153 = $152 >>> 0 > $limit >>> 0;
    if ($153) {
      label = 41;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    HEAP32[$1 >> 2] = $152;
    $155 = HEAP8[$138] | 0;
    $156 = $155 & 255;
    $157 = $subglyph_050 + 20 | 0;
    HEAP32[$157 >> 2] = $156;
    label = 34;
    break;
   case 34:
    $159 = $52 & 128;
    $160 = ($159 | 0) == 0;
    $161 = HEAP32[$1 >> 2] | 0;
    if ($160) {
      label = 37;
      break;
    } else {
      label = 35;
      break;
    }
   case 35:
    $163 = $161 + 3 | 0;
    $164 = $163 >>> 0 > $limit >>> 0;
    if ($164) {
      label = 41;
      break;
    } else {
      label = 36;
      break;
    }
   case 36:
    HEAP32[$1 >> 2] = $163;
    $166 = HEAP8[$161] | 0;
    $167 = $166 << 24 >> 24;
    $168 = $167 << 16;
    $169 = $161 + 1 | 0;
    $170 = HEAP8[$169] | 0;
    $171 = $170 & 255;
    $172 = $171 << 8;
    $173 = $172 | $168;
    $174 = $161 + 2 | 0;
    $175 = HEAP8[$174] | 0;
    $176 = $175 & 255;
    $177 = $173 | $176;
    $178 = $subglyph_050 + 16 | 0;
    HEAP32[$178 >> 2] = $177;
    label = 39;
    break;
   case 37:
    $180 = $161 + 2 | 0;
    $181 = $180 >>> 0 > $limit >>> 0;
    if ($181) {
      label = 41;
      break;
    } else {
      label = 38;
      break;
    }
   case 38:
    HEAP32[$1 >> 2] = $180;
    $183 = HEAP8[$161] | 0;
    $184 = $183 & 255;
    $185 = $184 << 8;
    $186 = $161 + 1 | 0;
    $187 = HEAP8[$186] | 0;
    $188 = $187 & 255;
    $189 = $185 | $188;
    $190 = $subglyph_050 + 16 | 0;
    HEAP32[$190 >> 2] = $189;
    label = 39;
    break;
   case 39:
    $192 = HEAP32[$21 >> 2] | 0;
    $193 = $192 + 1 | 0;
    HEAP32[$21 >> 2] = $193;
    $194 = $i_049 + 1 | 0;
    $195 = $subglyph_050 + 24 | 0;
    $196 = $194 >>> 0 < $14 >>> 0;
    if ($196) {
      $i_049 = $194;
      $subglyph_050 = $195;
      label = 12;
      break;
    } else {
      label = 40;
      break;
    }
   case 40:
    $197 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $197 | 0;
   case 41:
    HEAP32[$error >> 2] = 8;
    label = 40;
    break;
  }
  return 0;
}
function _pfr_glyph_load_simple($glyph, $p, $limit) {
  $glyph = $glyph | 0;
  $p = $p | 0;
  $limit = $limit | 0;
  var $1 = 0, $error = 0, $pos = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $x_count_0 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $y_count_0 = 0, $x_count_1 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $i_088 = 0, $x_087 = 0, $mask_086 = 0, $65 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $72 = 0, $73 = 0, $mask_1 = 0, $75 = 0, $76 = 0, $77 = 0, $79 = 0, $80 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $94 = 0, $95 = 0, $96 = 0, $x_1 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $106 = 0, $107 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $ld$0$0 = 0, $115$0 = 0, $ld$1$1 = 0, $115$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $125 = 0, $126 = 0, $127 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $134 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $ld$4$0 = 0, $140$0 = 0, $ld$5$1 = 0, $140$1 = 0, $st$6$0 = 0, $st$7$1 = 0, $142 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $ld$8$0 = 0, $148$0 = 0, $ld$9$1 = 0, $148$1 = 0, $st$10$0 = 0, $st$11$1 = 0, $n_082 = 0, $args_count_181 = 0, $args_format_180 = 0, $cur_079 = 0, $152 = 0, $154 = 0, $155 = 0, $156 = 0, $158 = 0, $159 = 0, $160 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $167 = 0, $168 = 0, $169 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $181 = 0, $182 = 0, $183 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $191 = 0, $192 = 0, $194 = 0, $195 = 0, $197 = 0, $198 = 0, $199 = 0, $201 = 0, $202 = 0, $203 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $210 = 0, $211 = 0, $212 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $220 = 0, $221 = 0, $222 = 0, $224 = 0, $225 = 0, $226 = 0, $228 = 0, $229 = 0, $230 = 0, $231 = 0, $232 = 0, $234 = 0, $235 = 0, $237 = 0, $238 = 0, $or_cond = 0, $240 = 0, $241 = 0, $242 = 0, $244 = 0, $245 = 0, $246 = 0, $248 = 0, $args_format_2 = 0, $args_count_2 = 0, $250 = 0, $ld$12$0 = 0, $251$0 = 0, $ld$13$1 = 0, $251$1 = 0, $st$14$0 = 0, $st$15$1 = 0, $252 = 0, $253 = 0, $254 = 0, $256 = 0, $258 = 0, $260 = 0, $262 = 0, $263 = 0, $264 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 40 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = __stackBase__ | 0;
    $error = __stackBase__ + 4 | 0;
    $pos = __stackBase__ + 8 | 0;
    HEAP32[$1 >> 2] = $p;
    HEAP32[$error >> 2] = 0;
    $2 = $glyph + 28 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $p + 1 | 0;
    $7 = $6 >>> 0 > $limit >>> 0;
    if ($7) {
      label = 67;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $6;
    $9 = HEAP8[$p] | 0;
    $10 = $9 & 255;
    $11 = $10 & 128;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 3;
      break;
    } else {
      label = 67;
      break;
    }
   case 3:
    $14 = $10 & 4;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $17 = $p + 2 | 0;
    $18 = $17 >>> 0 > $limit >>> 0;
    if ($18) {
      label = 67;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    HEAP32[$1 >> 2] = $17;
    $20 = HEAP8[$6] | 0;
    $21 = $20 & 255;
    $22 = $21 & 15;
    $23 = $21 >>> 4;
    $x_count_1 = $22;
    $y_count_0 = $23;
    label = 12;
    break;
   case 6:
    $25 = $10 & 2;
    $26 = ($25 | 0) == 0;
    if ($26) {
      $x_count_0 = 0;
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $28 = $p + 2 | 0;
    $29 = $28 >>> 0 > $limit >>> 0;
    if ($29) {
      label = 67;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    HEAP32[$1 >> 2] = $28;
    $31 = HEAP8[$6] | 0;
    $32 = $31 & 255;
    $x_count_0 = $32;
    label = 9;
    break;
   case 9:
    $34 = $10 & 1;
    $35 = ($34 | 0) == 0;
    if ($35) {
      $x_count_1 = $x_count_0;
      $y_count_0 = 0;
      label = 12;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $37 = HEAP32[$1 >> 2] | 0;
    $38 = $37 + 1 | 0;
    $39 = $38 >>> 0 > $limit >>> 0;
    if ($39) {
      label = 67;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    HEAP32[$1 >> 2] = $38;
    $41 = HEAP8[$37] | 0;
    $42 = $41 & 255;
    $x_count_1 = $x_count_0;
    $y_count_0 = $42;
    label = 12;
    break;
   case 12:
    $44 = $x_count_1 + $y_count_0 | 0;
    $45 = $glyph + 4 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $44 >>> 0 > $46 >>> 0;
    if ($47) {
      label = 13;
      break;
    } else {
      label = 15;
      break;
    }
   case 13:
    $49 = $44 + 7 | 0;
    $50 = $49 & -8;
    $51 = $glyph + 8 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = $52;
    $54 = _ft_mem_realloc($5, 4, $46, $50, $53, $error) | 0;
    $55 = $54;
    HEAP32[$51 >> 2] = $55;
    $56 = HEAP32[$error >> 2] | 0;
    $57 = ($56 | 0) == 0;
    if ($57) {
      label = 14;
      break;
    } else {
      label = 66;
      break;
    }
   case 14:
    HEAP32[$45 >> 2] = $50;
    label = 15;
    break;
   case 15:
    $60 = $glyph + 8 | 0;
    $61 = HEAP32[$60 >> 2] | 0;
    $62 = $61 + ($x_count_1 << 2) | 0;
    $63 = $glyph + 12 | 0;
    HEAP32[$63 >> 2] = $62;
    $64 = ($44 | 0) == 0;
    if ($64) {
      label = 25;
      break;
    } else {
      $mask_086 = 0;
      $x_087 = 0;
      $i_088 = 0;
      label = 16;
      break;
    }
   case 16:
    $65 = $i_088 & 7;
    $66 = ($65 | 0) == 0;
    if ($66) {
      label = 17;
      break;
    } else {
      $mask_1 = $mask_086;
      label = 19;
      break;
    }
   case 17:
    $68 = HEAP32[$1 >> 2] | 0;
    $69 = $68 + 1 | 0;
    $70 = $69 >>> 0 > $limit >>> 0;
    if ($70) {
      label = 67;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    HEAP32[$1 >> 2] = $69;
    $72 = HEAP8[$68] | 0;
    $73 = $72 & 255;
    $mask_1 = $73;
    label = 19;
    break;
   case 19:
    $75 = $mask_1 & 1;
    $76 = ($75 | 0) == 0;
    $77 = HEAP32[$1 >> 2] | 0;
    if ($76) {
      label = 22;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $79 = $77 + 2 | 0;
    $80 = $79 >>> 0 > $limit >>> 0;
    if ($80) {
      label = 67;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    HEAP32[$1 >> 2] = $79;
    $82 = HEAP8[$77] | 0;
    $83 = $82 & 255;
    $84 = $83 << 8;
    $85 = $77 + 1 | 0;
    $86 = HEAP8[$85] | 0;
    $87 = $86 & 255;
    $88 = $84 | $87;
    $89 = $88 << 16 >> 16;
    $x_1 = $89;
    label = 24;
    break;
   case 22:
    $91 = $77 + 1 | 0;
    $92 = $91 >>> 0 > $limit >>> 0;
    if ($92) {
      label = 67;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    HEAP32[$1 >> 2] = $91;
    $94 = HEAP8[$77] | 0;
    $95 = $94 & 255;
    $96 = $95 + $x_087 | 0;
    $x_1 = $96;
    label = 24;
    break;
   case 24:
    $98 = HEAP32[$60 >> 2] | 0;
    $99 = $98 + ($i_088 << 2) | 0;
    HEAP32[$99 >> 2] = $x_1;
    $100 = $mask_1 >>> 1;
    $101 = $i_088 + 1 | 0;
    $102 = $101 >>> 0 < $44 >>> 0;
    if ($102) {
      $mask_086 = $100;
      $x_087 = $x_1;
      $i_088 = $101;
      label = 16;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $103 = $10 & 8;
    $104 = ($103 | 0) == 0;
    if ($104) {
      label = 27;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $106 = _pfr_extra_items_skip($1, $limit) | 0;
    HEAP32[$error >> 2] = $106;
    $107 = ($106 | 0) == 0;
    if ($107) {
      label = 27;
      break;
    } else {
      label = 66;
      break;
    }
   case 27:
    _pfr_glyph_start($glyph);
    $109 = $pos | 0;
    $110 = $pos + 4 | 0;
    HEAP32[$110 >> 2] = 0;
    $111 = $pos | 0;
    HEAP32[$111 >> 2] = 0;
    $112 = $pos + 24 | 0;
    $113 = $pos;
    $114 = $112;
    $ld$0$0 = $113 | 0;
    $115$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $113 + 4 | 0;
    $115$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $114 | 0;
    HEAP32[$st$2$0 >> 2] = $115$0;
    $st$3$1 = $114 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $115$1;
    $116 = $pos + 28 | 0;
    $117 = $112 | 0;
    $118 = $pos + 8 | 0;
    $119 = $pos + 16 | 0;
    $120 = $112 | 0;
    $121 = $pos + 28 | 0;
    $122 = $pos + 28 | 0;
    $123 = $112 | 0;
    label = 28;
    break;
   case 28:
    $125 = HEAP32[$1 >> 2] | 0;
    $126 = $125 + 1 | 0;
    $127 = $126 >>> 0 > $limit >>> 0;
    if ($127) {
      label = 67;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    HEAP32[$1 >> 2] = $126;
    $129 = HEAP8[$125] | 0;
    $130 = $129 & 255;
    $131 = $130 & 15;
    $132 = $130 >>> 4;
    if (($132 | 0) == 2) {
      label = 30;
      break;
    } else if (($132 | 0) == 3) {
      label = 32;
      break;
    } else if (($132 | 0) == 6) {
      label = 34;
      break;
    } else if (($132 | 0) == 7) {
      label = 35;
      break;
    } else if (($132 | 0) == 1 | ($132 | 0) == 4 | ($132 | 0) == 5) {
      $cur_079 = $109;
      $args_format_180 = $131;
      $args_count_181 = 1;
      $n_082 = 0;
      label = 37;
      break;
    } else if (($132 | 0) == 0) {
      label = 61;
      break;
    } else {
      label = 36;
      break;
    }
   case 30:
    $134 = $131 >>> 0 < $x_count_1 >>> 0;
    if ($134) {
      label = 31;
      break;
    } else {
      label = 67;
      break;
    }
   case 31:
    $136 = HEAP32[$60 >> 2] | 0;
    $137 = $136 + ($131 << 2) | 0;
    $138 = HEAP32[$137 >> 2] | 0;
    HEAP32[$111 >> 2] = $138;
    $139 = HEAP32[$116 >> 2] | 0;
    HEAP32[$110 >> 2] = $139;
    $ld$4$0 = $113 | 0;
    $140$0 = HEAP32[$ld$4$0 >> 2] | 0;
    $ld$5$1 = $113 + 4 | 0;
    $140$1 = HEAP32[$ld$5$1 >> 2] | 0;
    $st$6$0 = $114 | 0;
    HEAP32[$st$6$0 >> 2] = $140$0;
    $st$7$1 = $114 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $140$1;
    label = 60;
    break;
   case 32:
    $142 = $131 >>> 0 < $y_count_0 >>> 0;
    if ($142) {
      label = 33;
      break;
    } else {
      label = 67;
      break;
    }
   case 33:
    $144 = HEAP32[$117 >> 2] | 0;
    HEAP32[$111 >> 2] = $144;
    $145 = HEAP32[$63 >> 2] | 0;
    $146 = $145 + ($131 << 2) | 0;
    $147 = HEAP32[$146 >> 2] | 0;
    HEAP32[$110 >> 2] = $147;
    $ld$8$0 = $113 | 0;
    $148$0 = HEAP32[$ld$8$0 >> 2] | 0;
    $ld$9$1 = $113 + 4 | 0;
    $148$1 = HEAP32[$ld$9$1 >> 2] | 0;
    $st$10$0 = $114 | 0;
    HEAP32[$st$10$0 >> 2] = $148$0;
    $st$11$1 = $114 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $148$1;
    label = 60;
    break;
   case 34:
    $cur_079 = $109;
    $args_format_180 = 2958;
    $args_count_181 = 3;
    $n_082 = 0;
    label = 37;
    break;
   case 35:
    $cur_079 = $109;
    $args_format_180 = 3627;
    $args_count_181 = 3;
    $n_082 = 0;
    label = 37;
    break;
   case 36:
    $cur_079 = $109;
    $args_format_180 = $131;
    $args_count_181 = 4;
    $n_082 = 0;
    label = 37;
    break;
   case 37:
    $152 = $args_format_180 & 3;
    if (($152 | 0) == 0) {
      label = 38;
      break;
    } else if (($152 | 0) == 1) {
      label = 41;
      break;
    } else if (($152 | 0) == 2) {
      label = 43;
      break;
    } else {
      label = 45;
      break;
    }
   case 38:
    $154 = HEAP32[$1 >> 2] | 0;
    $155 = $154 + 1 | 0;
    $156 = $155 >>> 0 > $limit >>> 0;
    if ($156) {
      label = 67;
      break;
    } else {
      label = 39;
      break;
    }
   case 39:
    HEAP32[$1 >> 2] = $155;
    $158 = HEAP8[$154] | 0;
    $159 = $158 & 255;
    $160 = $159 >>> 0 < $x_count_1 >>> 0;
    if ($160) {
      label = 40;
      break;
    } else {
      label = 67;
      break;
    }
   case 40:
    $162 = HEAP32[$60 >> 2] | 0;
    $163 = $162 + ($159 << 2) | 0;
    $164 = HEAP32[$163 >> 2] | 0;
    $165 = $cur_079 | 0;
    HEAP32[$165 >> 2] = $164;
    label = 46;
    break;
   case 41:
    $167 = HEAP32[$1 >> 2] | 0;
    $168 = $167 + 2 | 0;
    $169 = $168 >>> 0 > $limit >>> 0;
    if ($169) {
      label = 67;
      break;
    } else {
      label = 42;
      break;
    }
   case 42:
    HEAP32[$1 >> 2] = $168;
    $171 = HEAP8[$167] | 0;
    $172 = $171 & 255;
    $173 = $172 << 8;
    $174 = $167 + 1 | 0;
    $175 = HEAP8[$174] | 0;
    $176 = $175 & 255;
    $177 = $173 | $176;
    $178 = $177 << 16 >> 16;
    $179 = $cur_079 | 0;
    HEAP32[$179 >> 2] = $178;
    label = 46;
    break;
   case 43:
    $181 = HEAP32[$1 >> 2] | 0;
    $182 = $181 + 1 | 0;
    $183 = $182 >>> 0 > $limit >>> 0;
    if ($183) {
      label = 67;
      break;
    } else {
      label = 44;
      break;
    }
   case 44:
    HEAP32[$1 >> 2] = $182;
    $185 = HEAP8[$181] | 0;
    $186 = $185 << 24 >> 24;
    $187 = HEAP32[$123 >> 2] | 0;
    $188 = $187 + $186 | 0;
    $189 = $cur_079 | 0;
    HEAP32[$189 >> 2] = $188;
    label = 46;
    break;
   case 45:
    $191 = HEAP32[$120 >> 2] | 0;
    $192 = $cur_079 | 0;
    HEAP32[$192 >> 2] = $191;
    label = 46;
    break;
   case 46:
    $194 = $args_format_180 >>> 2;
    $195 = $194 & 3;
    if (($195 | 0) == 0) {
      label = 47;
      break;
    } else if (($195 | 0) == 1) {
      label = 50;
      break;
    } else if (($195 | 0) == 2) {
      label = 52;
      break;
    } else {
      label = 54;
      break;
    }
   case 47:
    $197 = HEAP32[$1 >> 2] | 0;
    $198 = $197 + 1 | 0;
    $199 = $198 >>> 0 > $limit >>> 0;
    if ($199) {
      label = 67;
      break;
    } else {
      label = 48;
      break;
    }
   case 48:
    HEAP32[$1 >> 2] = $198;
    $201 = HEAP8[$197] | 0;
    $202 = $201 & 255;
    $203 = $202 >>> 0 < $y_count_0 >>> 0;
    if ($203) {
      label = 49;
      break;
    } else {
      label = 67;
      break;
    }
   case 49:
    $205 = HEAP32[$63 >> 2] | 0;
    $206 = $205 + ($202 << 2) | 0;
    $207 = HEAP32[$206 >> 2] | 0;
    $208 = $cur_079 + 4 | 0;
    HEAP32[$208 >> 2] = $207;
    label = 55;
    break;
   case 50:
    $210 = HEAP32[$1 >> 2] | 0;
    $211 = $210 + 2 | 0;
    $212 = $211 >>> 0 > $limit >>> 0;
    if ($212) {
      label = 67;
      break;
    } else {
      label = 51;
      break;
    }
   case 51:
    HEAP32[$1 >> 2] = $211;
    $214 = HEAP8[$210] | 0;
    $215 = $214 & 255;
    $216 = $215 << 8;
    $217 = $210 + 1 | 0;
    $218 = HEAP8[$217] | 0;
    $219 = $218 & 255;
    $220 = $216 | $219;
    $221 = $220 << 16 >> 16;
    $222 = $cur_079 + 4 | 0;
    HEAP32[$222 >> 2] = $221;
    label = 55;
    break;
   case 52:
    $224 = HEAP32[$1 >> 2] | 0;
    $225 = $224 + 1 | 0;
    $226 = $225 >>> 0 > $limit >>> 0;
    if ($226) {
      label = 67;
      break;
    } else {
      label = 53;
      break;
    }
   case 53:
    HEAP32[$1 >> 2] = $225;
    $228 = HEAP8[$224] | 0;
    $229 = $228 << 24 >> 24;
    $230 = HEAP32[$122 >> 2] | 0;
    $231 = $230 + $229 | 0;
    $232 = $cur_079 + 4 | 0;
    HEAP32[$232 >> 2] = $231;
    label = 55;
    break;
   case 54:
    $234 = HEAP32[$121 >> 2] | 0;
    $235 = $cur_079 + 4 | 0;
    HEAP32[$235 >> 2] = $234;
    label = 55;
    break;
   case 55:
    $237 = ($n_082 | 0) == 0;
    $238 = ($args_count_181 | 0) == 4;
    $or_cond = $237 & $238;
    if ($or_cond) {
      label = 56;
      break;
    } else {
      label = 58;
      break;
    }
   case 56:
    $240 = HEAP32[$1 >> 2] | 0;
    $241 = $240 + 1 | 0;
    $242 = $241 >>> 0 > $limit >>> 0;
    if ($242) {
      label = 67;
      break;
    } else {
      label = 57;
      break;
    }
   case 57:
    HEAP32[$1 >> 2] = $241;
    $244 = HEAP8[$240] | 0;
    $245 = $244 & 255;
    $246 = $args_count_181 - 1 | 0;
    $args_count_2 = $246;
    $args_format_2 = $245;
    label = 59;
    break;
   case 58:
    $248 = $args_format_180 >>> 4;
    $args_count_2 = $args_count_181;
    $args_format_2 = $248;
    label = 59;
    break;
   case 59:
    $250 = $cur_079;
    $ld$12$0 = $250 | 0;
    $251$0 = HEAP32[$ld$12$0 >> 2] | 0;
    $ld$13$1 = $250 + 4 | 0;
    $251$1 = HEAP32[$ld$13$1 >> 2] | 0;
    $st$14$0 = $114 | 0;
    HEAP32[$st$14$0 >> 2] = $251$0;
    $st$15$1 = $114 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $251$1;
    $252 = $cur_079 + 8 | 0;
    $253 = $n_082 + 1 | 0;
    $254 = $253 >>> 0 < $args_count_2 >>> 0;
    if ($254) {
      $cur_079 = $252;
      $args_format_180 = $args_format_2;
      $args_count_181 = $args_count_2;
      $n_082 = $253;
      label = 37;
      break;
    } else {
      label = 60;
      break;
    }
   case 60:
    if (($132 | 0) == 0) {
      label = 61;
      break;
    } else if (($132 | 0) == 1 | ($132 | 0) == 2 | ($132 | 0) == 3) {
      label = 62;
      break;
    } else if (($132 | 0) == 4 | ($132 | 0) == 5) {
      label = 63;
      break;
    } else {
      label = 64;
      break;
    }
   case 61:
    _pfr_glyph_end($glyph);
    label = 66;
    break;
   case 62:
    $256 = _pfr_glyph_line_to($glyph, $109) | 0;
    HEAP32[$error >> 2] = $256;
    $262 = $256;
    label = 65;
    break;
   case 63:
    $258 = _pfr_glyph_move_to($glyph, $109) | 0;
    HEAP32[$error >> 2] = $258;
    $262 = $258;
    label = 65;
    break;
   case 64:
    $260 = _pfr_glyph_curve_to($glyph, $109, $118, $119) | 0;
    HEAP32[$error >> 2] = $260;
    $262 = $260;
    label = 65;
    break;
   case 65:
    $263 = ($262 | 0) == 0;
    if ($263) {
      label = 28;
      break;
    } else {
      label = 66;
      break;
    }
   case 66:
    $264 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $264 | 0;
   case 67:
    HEAP32[$error >> 2] = 8;
    label = 66;
    break;
  }
  return 0;
}
function _pfr_extra_items_skip($pp, $limit) {
  $pp = $pp | 0;
  $limit = $limit | 0;
  return _pfr_extra_items_parse($pp, $limit, 0, 0) | 0;
}
function _pfr_glyph_end($glyph) {
  $glyph = $glyph | 0;
  _pfr_glyph_close_contour($glyph);
  _FT_GlyphLoader_Add(HEAP32[$glyph + 28 >> 2] | 0);
  return;
}
function _pfr_glyph_line_to($glyph, $to) {
  $glyph = $glyph | 0;
  $to = $to | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $ld$0$0 = 0, $28$0 = 0, $ld$1$1 = 0, $28$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $glyph + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $glyph + 32 | 0;
    $4 = HEAP8[$3] | 0;
    $5 = $4 << 24 >> 24 == 0;
    if ($5) {
      $error_0 = 8;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $2 + 22 | 0;
    $8 = HEAP16[$7 >> 1] | 0;
    $9 = $8 << 16 >> 16;
    $10 = $2 + 58 | 0;
    $11 = HEAP16[$10 >> 1] | 0;
    $12 = $11 << 16 >> 16;
    $13 = $9 + 1 | 0;
    $14 = $13 + $12 | 0;
    $15 = $2 + 4 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $14 >>> 0 > $16 >>> 0;
    if ($17) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $19 = _FT_GlyphLoader_CheckPoints($2, 1, 0) | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 4;
      break;
    } else {
      $error_0 = $19;
      label = 5;
      break;
    }
   case 4:
    $21 = HEAP16[$10 >> 1] | 0;
    $22 = $21 << 16 >> 16;
    $23 = $2 + 60 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24 + ($22 << 3) | 0;
    $26 = $to;
    $27 = $25;
    $ld$0$0 = $26 | 0;
    $28$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $26 + 4 | 0;
    $28$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $27 | 0;
    HEAP32[$st$2$0 >> 2] = $28$0;
    $st$3$1 = $27 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $28$1;
    $29 = $2 + 64 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $30 + $22 | 0;
    HEAP8[$31] = 1;
    $32 = HEAP16[$10 >> 1] | 0;
    $33 = $32 + 1 & 65535;
    HEAP16[$10 >> 1] = $33;
    $error_0 = 0;
    label = 5;
    break;
   case 5:
    return $error_0 | 0;
  }
  return 0;
}
function _pfr_glyph_move_to($glyph, $to) {
  $glyph = $glyph | 0;
  $to = $to | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $glyph + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    _pfr_glyph_close_contour($glyph);
    $3 = $glyph + 32 | 0;
    HEAP8[$3] = 1;
    $4 = $2 + 22 | 0;
    $5 = HEAP16[$4 >> 1] | 0;
    $6 = $5 << 16 >> 16;
    $7 = $2 + 58 | 0;
    $8 = HEAP16[$7 >> 1] | 0;
    $9 = $8 << 16 >> 16;
    $10 = $6 + 1 | 0;
    $11 = $10 + $9 | 0;
    $12 = $2 + 4 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $11 >>> 0 > $13 >>> 0;
    if ($14) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $16 = $2 + 20 | 0;
    $17 = HEAP16[$16 >> 1] | 0;
    $18 = $17 << 16 >> 16;
    $19 = $2 + 56 | 0;
    $20 = HEAP16[$19 >> 1] | 0;
    $21 = $20 << 16 >> 16;
    $22 = $18 + 1 | 0;
    $23 = $22 + $21 | 0;
    $24 = $2 + 8 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $23 >>> 0 > $25 >>> 0;
    if ($26) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $28 = _FT_GlyphLoader_CheckPoints($2, 1, 1) | 0;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 4;
      break;
    } else {
      $error_0 = $28;
      label = 5;
      break;
    }
   case 4:
    $30 = _pfr_glyph_line_to($glyph, $to) | 0;
    $error_0 = $30;
    label = 5;
    break;
   case 5:
    return $error_0 | 0;
  }
  return 0;
}
function _pfr_glyph_curve_to($glyph, $control1, $control2, $to) {
  $glyph = $glyph | 0;
  $control1 = $control1 | 0;
  $control2 = $control2 | 0;
  $to = $to | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $ld$0$0 = 0, $31$0 = 0, $ld$1$1 = 0, $31$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $_sum = 0, $32 = 0, $33 = 0, $34 = 0, $ld$4$0 = 0, $35$0 = 0, $ld$5$1 = 0, $35$1 = 0, $st$6$0 = 0, $st$7$1 = 0, $_sum19 = 0, $36 = 0, $37 = 0, $38 = 0, $ld$8$0 = 0, $39$0 = 0, $ld$9$1 = 0, $39$1 = 0, $st$10$0 = 0, $st$11$1 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $glyph + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $glyph + 32 | 0;
    $4 = HEAP8[$3] | 0;
    $5 = $4 << 24 >> 24 == 0;
    if ($5) {
      $error_0 = 8;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $2 + 22 | 0;
    $8 = HEAP16[$7 >> 1] | 0;
    $9 = $8 << 16 >> 16;
    $10 = $2 + 58 | 0;
    $11 = HEAP16[$10 >> 1] | 0;
    $12 = $11 << 16 >> 16;
    $13 = $9 + 3 | 0;
    $14 = $13 + $12 | 0;
    $15 = $2 + 4 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $14 >>> 0 > $16 >>> 0;
    if ($17) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $19 = _FT_GlyphLoader_CheckPoints($2, 3, 0) | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 4;
      break;
    } else {
      $error_0 = $19;
      label = 5;
      break;
    }
   case 4:
    $21 = $2 + 60 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = HEAP16[$10 >> 1] | 0;
    $24 = $23 << 16 >> 16;
    $25 = $22 + ($24 << 3) | 0;
    $26 = $2 + 64 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $27 + $24 | 0;
    $29 = $control1;
    $30 = $25;
    $ld$0$0 = $29 | 0;
    $31$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $29 + 4 | 0;
    $31$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $30 | 0;
    HEAP32[$st$2$0 >> 2] = $31$0;
    $st$3$1 = $30 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $31$1;
    $_sum = $24 + 1 | 0;
    $32 = $22 + ($_sum << 3) | 0;
    $33 = $control2;
    $34 = $32;
    $ld$4$0 = $33 | 0;
    $35$0 = HEAP32[$ld$4$0 >> 2] | 0;
    $ld$5$1 = $33 + 4 | 0;
    $35$1 = HEAP32[$ld$5$1 >> 2] | 0;
    $st$6$0 = $34 | 0;
    HEAP32[$st$6$0 >> 2] = $35$0;
    $st$7$1 = $34 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $35$1;
    $_sum19 = $24 + 2 | 0;
    $36 = $22 + ($_sum19 << 3) | 0;
    $37 = $to;
    $38 = $36;
    $ld$8$0 = $37 | 0;
    $39$0 = HEAP32[$ld$8$0 >> 2] | 0;
    $ld$9$1 = $37 + 4 | 0;
    $39$1 = HEAP32[$ld$9$1 >> 2] | 0;
    $st$10$0 = $38 | 0;
    HEAP32[$st$10$0 >> 2] = $39$0;
    $st$11$1 = $38 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $39$1;
    HEAP8[$28] = 2;
    $40 = $27 + $_sum | 0;
    HEAP8[$40] = 2;
    $41 = $27 + $_sum19 | 0;
    HEAP8[$41] = 1;
    $42 = HEAP16[$10 >> 1] | 0;
    $43 = $42 + 3 & 65535;
    HEAP16[$10 >> 1] = $43;
    $error_0 = 0;
    label = 5;
    break;
   case 5:
    return $error_0 | 0;
  }
  return 0;
}
function _pfr_glyph_close_contour($glyph) {
  $glyph = $glyph | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $first_0 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $last_0 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $glyph + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $glyph + 32 | 0;
    $4 = HEAP8[$3] | 0;
    $5 = $4 << 24 >> 24 == 0;
    if ($5) {
      label = 11;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $2 + 58 | 0;
    $8 = HEAP16[$7 >> 1] | 0;
    $9 = $8 << 16 >> 16;
    $10 = $9 - 1 | 0;
    $11 = $2 + 56 | 0;
    $12 = HEAP16[$11 >> 1] | 0;
    $13 = $12 << 16 >> 16 > 0;
    if ($13) {
      label = 3;
      break;
    } else {
      $first_0 = 0;
      label = 4;
      break;
    }
   case 3:
    $15 = $12 << 16 >> 16;
    $16 = $15 - 1 | 0;
    $17 = $2 + 68 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $18 + ($16 << 1) | 0;
    $20 = HEAP16[$19 >> 1] | 0;
    $21 = $20 << 16 >> 16;
    $first_0 = $21;
    label = 4;
    break;
   case 4:
    $23 = ($10 | 0) > ($first_0 | 0);
    if ($23) {
      label = 5;
      break;
    } else {
      $last_0 = $10;
      label = 8;
      break;
    }
   case 5:
    $25 = $2 + 60 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $26 + ($first_0 << 3) | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $26 + ($10 << 3) | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = ($28 | 0) == ($30 | 0);
    if ($31) {
      label = 6;
      break;
    } else {
      $last_0 = $10;
      label = 8;
      break;
    }
   case 6:
    $33 = $26 + ($first_0 << 3) + 4 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $26 + ($10 << 3) + 4 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = ($34 | 0) == ($36 | 0);
    if ($37) {
      label = 7;
      break;
    } else {
      $last_0 = $10;
      label = 8;
      break;
    }
   case 7:
    $39 = HEAP16[$7 >> 1] | 0;
    $40 = $39 - 1 & 65535;
    HEAP16[$7 >> 1] = $40;
    $41 = $9 - 2 | 0;
    $last_0 = $41;
    label = 8;
    break;
   case 8:
    $43 = ($last_0 | 0) < ($first_0 | 0);
    if ($43) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $45 = $last_0 & 65535;
    $46 = HEAP16[$11 >> 1] | 0;
    $47 = $46 + 1 & 65535;
    HEAP16[$11 >> 1] = $47;
    $48 = $46 << 16 >> 16;
    $49 = $2 + 68 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $50 + ($48 << 1) | 0;
    HEAP16[$51 >> 1] = $45;
    label = 10;
    break;
   case 10:
    HEAP8[$3] = 0;
    label = 11;
    break;
   case 11:
    return;
  }
}
function _pfr_lookup_bitmap_data($base, $limit, $count, $flags, $char_code, $found_offset, $found_size) {
  $base = $base | 0;
  $limit = $limit | 0;
  $count = $count | 0;
  $flags = $flags | 0;
  $char_code = $char_code | 0;
  $found_offset = $found_offset | 0;
  $found_size = $found_size | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_lobit = 0, $char_len_1 = 0, $6 = 0, $7 = 0, $_lobit45 = 0, $_char_len_1 = 0, $8 = 0, $left_047 = 0, $right_046 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $_sum = 0, $13 = 0, $14 = 0, $_sum38 = 0, $17 = 0, $18 = 0, $19 = 0, $_sum40 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $_sum37 = 0, $25 = 0, $26 = 0, $_sum38_pn = 0, $code_0 = 0, $buff_0 = 0, $28 = 0, $30 = 0, $right_0_ = 0, $_left_0 = 0, $31 = 0, $buff_0_sum41 = 0, $34 = 0, $35 = 0, $36 = 0, $buff_0_sum44 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $buff_0_sum = 0, $42 = 0, $43 = 0, $storemerge = 0, $buff_0_sum_pn = 0, $buff_1 = 0, $45 = 0, $46 = 0, $48 = 0, $buff_1_sum = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $buff_1_sum42 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $buff_1_sum43 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $flags & 1;
    $2 = ($1 | 0) == 0;
    $3 = $1 | 4;
    $4 = $flags & 2;
    $5 = ($4 | 0) == 0;
    $_lobit = $4 >>> 1;
    $char_len_1 = $3 + $_lobit | 0;
    $6 = $flags & 4;
    $7 = ($6 | 0) == 0;
    $_lobit45 = $6 >>> 2;
    $_char_len_1 = $char_len_1 + $_lobit45 | 0;
    $8 = ($count | 0) == 0;
    if ($8) {
      label = 8;
      break;
    } else {
      $right_046 = $count;
      $left_047 = 0;
      label = 2;
      break;
    }
   case 2:
    $9 = $left_047 + $right_046 | 0;
    $10 = $9 >>> 1;
    $11 = Math_imul($10, $_char_len_1);
    $12 = $base + $11 | 0;
    $_sum = $11 + $_char_len_1 | 0;
    $13 = $base + $_sum | 0;
    $14 = $13 >>> 0 > $limit >>> 0;
    if ($14) {
      label = 8;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    if ($2) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $_sum38 = $11 + 2 | 0;
    $17 = HEAP8[$12] | 0;
    $18 = $17 & 255;
    $19 = $18 << 8;
    $_sum40 = $11 + 1 | 0;
    $20 = $base + $_sum40 | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $21 & 255;
    $23 = $19 | $22;
    $code_0 = $23;
    $_sum38_pn = $_sum38;
    label = 6;
    break;
   case 5:
    $_sum37 = $11 + 1 | 0;
    $25 = HEAP8[$12] | 0;
    $26 = $25 & 255;
    $code_0 = $26;
    $_sum38_pn = $_sum37;
    label = 6;
    break;
   case 6:
    $buff_0 = $base + $_sum38_pn | 0;
    $28 = ($code_0 | 0) == ($char_code | 0);
    if ($28) {
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $30 = $code_0 >>> 0 < $char_code >>> 0;
    $right_0_ = $30 ? $right_046 : $10;
    $_left_0 = $30 ? $10 : $left_047;
    $31 = $_left_0 >>> 0 < $right_0_ >>> 0;
    if ($31) {
      $right_046 = $right_0_;
      $left_047 = $_left_0;
      label = 2;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    HEAP32[$found_size >> 2] = 0;
    HEAP32[$found_offset >> 2] = 0;
    label = 15;
    break;
   case 9:
    if ($5) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $buff_0_sum41 = $_sum38_pn + 2 | 0;
    $34 = HEAP8[$buff_0] | 0;
    $35 = $34 & 255;
    $36 = $35 << 8;
    $buff_0_sum44 = $_sum38_pn + 1 | 0;
    $37 = $base + $buff_0_sum44 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 & 255;
    $40 = $36 | $39;
    $buff_0_sum_pn = $buff_0_sum41;
    $storemerge = $40;
    label = 12;
    break;
   case 11:
    $buff_0_sum = $_sum38_pn + 1 | 0;
    $42 = HEAP8[$buff_0] | 0;
    $43 = $42 & 255;
    $buff_0_sum_pn = $buff_0_sum;
    $storemerge = $43;
    label = 12;
    break;
   case 12:
    $buff_1 = $base + $buff_0_sum_pn | 0;
    HEAP32[$found_size >> 2] = $storemerge;
    $45 = HEAP8[$buff_1] | 0;
    $46 = $45 & 255;
    if ($7) {
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $48 = $46 << 16;
    $buff_1_sum = $buff_0_sum_pn + 1 | 0;
    $49 = $base + $buff_1_sum | 0;
    $50 = HEAP8[$49] | 0;
    $51 = $50 & 255;
    $52 = $51 << 8;
    $53 = $52 | $48;
    $buff_1_sum42 = $buff_0_sum_pn + 2 | 0;
    $54 = $base + $buff_1_sum42 | 0;
    $55 = HEAP8[$54] | 0;
    $56 = $55 & 255;
    $57 = $53 | $56;
    HEAP32[$found_offset >> 2] = $57;
    label = 15;
    break;
   case 14:
    $59 = $46 << 8;
    $buff_1_sum43 = $buff_0_sum_pn + 1 | 0;
    $60 = $base + $buff_1_sum43 | 0;
    $61 = HEAP8[$60] | 0;
    $62 = $61 & 255;
    $63 = $62 | $59;
    HEAP32[$found_offset >> 2] = $63;
    label = 15;
    break;
   case 15:
    return;
  }
}
function _pfr_load_bitmap_metrics($pdata, $limit, $scaled_advance, $axpos, $aypos, $axsize, $aysize, $aadvance, $aformat) {
  $pdata = $pdata | 0;
  $limit = $limit | 0;
  $scaled_advance = $scaled_advance | 0;
  $axpos = $axpos | 0;
  $aypos = $aypos | 0;
  $axsize = $axsize | 0;
  $aysize = $aysize | 0;
  $aadvance = $aadvance | 0;
  $aformat = $aformat | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $p_0 = 0, $xpos_0 = 0, $ypos_0 = 0, $78 = 0, $79 = 0, $80 = 0, $82 = 0, $83 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $100 = 0, $101 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $p_1 = 0, $xsize_0 = 0, $ysize_0 = 0, $119 = 0, $120 = 0, $121 = 0, $124 = 0, $125 = 0, $127 = 0, $128 = 0, $129 = 0, $131 = 0, $132 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $143 = 0, $144 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $p_2 = 0, $advance_0 = 0, $159 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$pdata >> 2] | 0;
    $2 = $1 + 1 | 0;
    $3 = $2 >>> 0 > $limit >>> 0;
    if ($3) {
      $error_0 = 8;
      label = 27;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = HEAP8[$1] | 0;
    $6 = $5 & 255;
    $7 = $6 & 3;
    if (($7 | 0) == 0) {
      label = 3;
      break;
    } else if (($7 | 0) == 1) {
      label = 5;
      break;
    } else if (($7 | 0) == 2) {
      label = 7;
      break;
    } else if (($7 | 0) == 3) {
      label = 9;
      break;
    } else {
      $ypos_0 = 0;
      $xpos_0 = 0;
      $p_0 = $2;
      label = 11;
      break;
    }
   case 3:
    $9 = $1 + 2 | 0;
    $10 = $9 >>> 0 > $limit >>> 0;
    if ($10) {
      $error_0 = 8;
      label = 27;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $12 = HEAP8[$2] | 0;
    $13 = $12 << 24 >> 24;
    $14 = $13 >> 4;
    $15 = $12 << 4;
    $16 = $15 << 24 >> 24;
    $17 = $16 >> 4;
    $ypos_0 = $17;
    $xpos_0 = $14;
    $p_0 = $9;
    label = 11;
    break;
   case 5:
    $19 = $1 + 3 | 0;
    $20 = $19 >>> 0 > $limit >>> 0;
    if ($20) {
      $error_0 = 8;
      label = 27;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $22 = $1 + 2 | 0;
    $23 = HEAP8[$2] | 0;
    $24 = $23 << 24 >> 24;
    $25 = HEAP8[$22] | 0;
    $26 = $25 << 24 >> 24;
    $ypos_0 = $26;
    $xpos_0 = $24;
    $p_0 = $19;
    label = 11;
    break;
   case 7:
    $28 = $1 + 5 | 0;
    $29 = $28 >>> 0 > $limit >>> 0;
    if ($29) {
      $error_0 = 8;
      label = 27;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $31 = HEAP8[$2] | 0;
    $32 = $31 & 255;
    $33 = $32 << 8;
    $34 = $1 + 2 | 0;
    $35 = HEAP8[$34] | 0;
    $36 = $35 & 255;
    $37 = $33 | $36;
    $38 = $37 << 16 >> 16;
    $39 = $1 + 3 | 0;
    $40 = HEAP8[$39] | 0;
    $41 = $40 & 255;
    $42 = $41 << 8;
    $43 = $1 + 4 | 0;
    $44 = HEAP8[$43] | 0;
    $45 = $44 & 255;
    $46 = $42 | $45;
    $47 = $46 << 16 >> 16;
    $ypos_0 = $47;
    $xpos_0 = $38;
    $p_0 = $28;
    label = 11;
    break;
   case 9:
    $49 = $1 + 7 | 0;
    $50 = $49 >>> 0 > $limit >>> 0;
    if ($50) {
      $error_0 = 8;
      label = 27;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $52 = HEAP8[$2] | 0;
    $53 = $52 << 24 >> 24;
    $54 = $53 << 16;
    $55 = $1 + 2 | 0;
    $56 = HEAP8[$55] | 0;
    $57 = $56 & 255;
    $58 = $57 << 8;
    $59 = $58 | $54;
    $60 = $1 + 3 | 0;
    $61 = HEAP8[$60] | 0;
    $62 = $61 & 255;
    $63 = $59 | $62;
    $64 = $1 + 4 | 0;
    $65 = HEAP8[$64] | 0;
    $66 = $65 << 24 >> 24;
    $67 = $66 << 16;
    $68 = $1 + 5 | 0;
    $69 = HEAP8[$68] | 0;
    $70 = $69 & 255;
    $71 = $70 << 8;
    $72 = $71 | $67;
    $73 = $1 + 6 | 0;
    $74 = HEAP8[$73] | 0;
    $75 = $74 & 255;
    $76 = $72 | $75;
    $ypos_0 = $76;
    $xpos_0 = $63;
    $p_0 = $49;
    label = 11;
    break;
   case 11:
    $78 = ($5 & 255) >>> 2;
    $79 = $78 & 255;
    $80 = $79 & 3;
    if (($80 | 0) == 1) {
      label = 12;
      break;
    } else if (($80 | 0) == 2) {
      label = 14;
      break;
    } else if (($80 | 0) == 3) {
      label = 16;
      break;
    } else {
      $ysize_0 = 0;
      $xsize_0 = 0;
      $p_1 = $p_0;
      label = 18;
      break;
    }
   case 12:
    $82 = $p_0 + 1 | 0;
    $83 = $82 >>> 0 > $limit >>> 0;
    if ($83) {
      $error_0 = 8;
      label = 27;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $85 = HEAP8[$p_0] | 0;
    $86 = $85 << 24 >> 24;
    $87 = $86 >>> 4;
    $88 = $87 & 15;
    $89 = $86 & 15;
    $ysize_0 = $89;
    $xsize_0 = $88;
    $p_1 = $82;
    label = 18;
    break;
   case 14:
    $91 = $p_0 + 2 | 0;
    $92 = $91 >>> 0 > $limit >>> 0;
    if ($92) {
      $error_0 = 8;
      label = 27;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $94 = $p_0 + 1 | 0;
    $95 = HEAP8[$p_0] | 0;
    $96 = $95 & 255;
    $97 = HEAP8[$94] | 0;
    $98 = $97 & 255;
    $ysize_0 = $98;
    $xsize_0 = $96;
    $p_1 = $91;
    label = 18;
    break;
   case 16:
    $100 = $p_0 + 4 | 0;
    $101 = $100 >>> 0 > $limit >>> 0;
    if ($101) {
      $error_0 = 8;
      label = 27;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $103 = HEAP8[$p_0] | 0;
    $104 = $103 & 255;
    $105 = $104 << 8;
    $106 = $p_0 + 1 | 0;
    $107 = HEAP8[$106] | 0;
    $108 = $107 & 255;
    $109 = $105 | $108;
    $110 = $p_0 + 2 | 0;
    $111 = HEAP8[$110] | 0;
    $112 = $111 & 255;
    $113 = $112 << 8;
    $114 = $p_0 + 3 | 0;
    $115 = HEAP8[$114] | 0;
    $116 = $115 & 255;
    $117 = $113 | $116;
    $ysize_0 = $117;
    $xsize_0 = $109;
    $p_1 = $100;
    label = 18;
    break;
   case 18:
    $119 = ($5 & 255) >>> 4;
    $120 = $119 & 255;
    $121 = $120 & 3;
    if (($121 | 0) == 0) {
      label = 19;
      break;
    } else if (($121 | 0) == 1) {
      label = 20;
      break;
    } else if (($121 | 0) == 2) {
      label = 22;
      break;
    } else if (($121 | 0) == 3) {
      label = 24;
      break;
    } else {
      $advance_0 = 0;
      $p_2 = $p_1;
      label = 26;
      break;
    }
   case 19:
    $advance_0 = $scaled_advance;
    $p_2 = $p_1;
    label = 26;
    break;
   case 20:
    $124 = $p_1 + 1 | 0;
    $125 = $124 >>> 0 > $limit >>> 0;
    if ($125) {
      $error_0 = 8;
      label = 27;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $127 = HEAP8[$p_1] | 0;
    $128 = $127 << 24 >> 24;
    $129 = $128 << 8;
    $advance_0 = $129;
    $p_2 = $124;
    label = 26;
    break;
   case 22:
    $131 = $p_1 + 2 | 0;
    $132 = $131 >>> 0 > $limit >>> 0;
    if ($132) {
      $error_0 = 8;
      label = 27;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $134 = HEAP8[$p_1] | 0;
    $135 = $134 & 255;
    $136 = $135 << 8;
    $137 = $p_1 + 1 | 0;
    $138 = HEAP8[$137] | 0;
    $139 = $138 & 255;
    $140 = $136 | $139;
    $141 = $140 << 16 >> 16;
    $advance_0 = $141;
    $p_2 = $131;
    label = 26;
    break;
   case 24:
    $143 = $p_1 + 3 | 0;
    $144 = $143 >>> 0 > $limit >>> 0;
    if ($144) {
      $error_0 = 8;
      label = 27;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $146 = HEAP8[$p_1] | 0;
    $147 = $146 << 24 >> 24;
    $148 = $147 << 16;
    $149 = $p_1 + 1 | 0;
    $150 = HEAP8[$149] | 0;
    $151 = $150 & 255;
    $152 = $151 << 8;
    $153 = $152 | $148;
    $154 = $p_1 + 2 | 0;
    $155 = HEAP8[$154] | 0;
    $156 = $155 & 255;
    $157 = $153 | $156;
    $advance_0 = $157;
    $p_2 = $143;
    label = 26;
    break;
   case 26:
    HEAP32[$axpos >> 2] = $xpos_0;
    HEAP32[$aypos >> 2] = $ypos_0;
    HEAP32[$axsize >> 2] = $xsize_0;
    HEAP32[$aysize >> 2] = $ysize_0;
    HEAP32[$aadvance >> 2] = $advance_0;
    $159 = $120 >>> 2;
    HEAP32[$aformat >> 2] = $159;
    HEAP32[$pdata >> 2] = $p_2;
    $error_0 = 0;
    label = 27;
    break;
   case 27:
    return $error_0 | 0;
  }
  return 0;
}
function _pfr_bitwriter_init($writer, $target, $decreasing) {
  $writer = $writer | 0;
  $target = $target | 0;
  $decreasing = $decreasing | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $target + 12 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $writer | 0;
    HEAP32[$3 >> 2] = $2;
    $4 = $target + 8 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $writer + 4 | 0;
    HEAP32[$6 >> 2] = $5;
    $7 = $target + 4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $writer + 8 | 0;
    HEAP32[$9 >> 2] = $8;
    $10 = $target | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $writer + 12 | 0;
    HEAP32[$12 >> 2] = $11;
    $13 = HEAP32[$9 >> 2] | 0;
    $14 = Math_imul($13, $11);
    $15 = $writer + 16 | 0;
    HEAP32[$15 >> 2] = $14;
    $16 = $decreasing << 24 >> 24 == 0;
    if ($16) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $18 = HEAP32[$6 >> 2] | 0;
    $19 = HEAP32[$10 >> 2] | 0;
    $20 = $19 - 1 | 0;
    $21 = Math_imul($20, $18);
    $22 = HEAP32[$3 >> 2] | 0;
    $23 = $22 + $21 | 0;
    HEAP32[$3 >> 2] = $23;
    $24 = HEAP32[$6 >> 2] | 0;
    $25 = -$24 | 0;
    HEAP32[$6 >> 2] = $25;
    label = 3;
    break;
   case 3:
    return;
  }
}
function _pfr_bitwriter_decode_bytes($writer, $p, $limit) {
  $writer = $writer | 0;
  $p = $p | 0;
  $limit = $limit | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_ = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $c_031 = 0, $val_030 = 0, $mask_029 = 0, $cur_028 = 0, $left_027 = 0, $_026 = 0, $n_125 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $_1 = 0, $val_1 = 0, $23 = 0, $24 = 0, $25 = 0, $c_0_ = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $39 = 0, $40 = 0, $left_1 = 0, $cur_1 = 0, $mask_1 = 0, $c_2 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $writer + 8 | 0;
    $2 = $writer | 0;
    $3 = $limit;
    $4 = $p;
    $5 = $3 - $4 | 0;
    $6 = $5 << 3;
    $7 = $writer + 16 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($6 | 0) > ($8 | 0);
    $_ = $9 ? $8 : $6;
    $10 = ($_ | 0) > 0;
    if ($10) {
      label = 2;
      break;
    } else {
      label = 12;
      break;
    }
   case 2:
    $11 = HEAP32[$2 >> 2] | 0;
    $12 = HEAP32[$1 >> 2] | 0;
    $13 = $writer + 4 | 0;
    $n_125 = $_;
    $_026 = $p;
    $left_027 = $12;
    $cur_028 = $11;
    $mask_029 = 128;
    $val_030 = 0;
    $c_031 = 0;
    label = 3;
    break;
   case 3:
    $15 = $n_125 ^ $_;
    $16 = $15 & 7;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 4;
      break;
    } else {
      $val_1 = $val_030;
      $_1 = $_026;
      label = 5;
      break;
    }
   case 4:
    $19 = $_026 + 1 | 0;
    $20 = HEAP8[$_026] | 0;
    $21 = $20 & 255;
    $val_1 = $21;
    $_1 = $19;
    label = 5;
    break;
   case 5:
    $23 = $val_1 & 128;
    $24 = ($23 | 0) == 0;
    $25 = $24 ? 0 : $mask_029;
    $c_0_ = $25 | $c_031;
    $26 = $val_1 << 1;
    $27 = $mask_029 >>> 1;
    $28 = $left_027 - 1 | 0;
    $29 = ($28 | 0) < 1;
    if ($29) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $31 = $c_0_ & 255;
    HEAP8[$cur_028] = $31;
    $32 = HEAP32[$1 >> 2] | 0;
    $33 = HEAP32[$13 >> 2] | 0;
    $34 = HEAP32[$2 >> 2] | 0;
    $35 = $34 + $33 | 0;
    HEAP32[$2 >> 2] = $35;
    $c_2 = 0;
    $mask_1 = 128;
    $cur_1 = $35;
    $left_1 = $32;
    label = 9;
    break;
   case 7:
    $37 = ($27 | 0) == 0;
    if ($37) {
      label = 8;
      break;
    } else {
      $c_2 = $c_0_;
      $mask_1 = $27;
      $cur_1 = $cur_028;
      $left_1 = $28;
      label = 9;
      break;
    }
   case 8:
    $39 = $c_0_ & 255;
    HEAP8[$cur_028] = $39;
    $40 = $cur_028 + 1 | 0;
    $c_2 = 0;
    $mask_1 = 128;
    $cur_1 = $40;
    $left_1 = $28;
    label = 9;
    break;
   case 9:
    $42 = $n_125 - 1 | 0;
    $43 = ($42 | 0) > 0;
    if ($43) {
      $n_125 = $42;
      $_026 = $_1;
      $left_027 = $left_1;
      $cur_028 = $cur_1;
      $mask_029 = $mask_1;
      $val_030 = $26;
      $c_031 = $c_2;
      label = 3;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $44 = ($mask_1 | 0) == 128;
    if ($44) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $46 = $c_2 & 255;
    HEAP8[$cur_1] = $46;
    label = 12;
    break;
   case 12:
    return;
  }
}
function _pfr_bitwriter_decode_rle1($writer, $p, $limit) {
  $writer = $writer | 0;
  $p = $p | 0;
  $limit = $limit | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_032 = 0, $c_031 = 0, $mask_030 = 0, $cur_029 = 0, $left_028 = 0, $reload_027 = 0, $counts_sroa_1_026 = 0, $count_025 = 0, $phase_024 = 0, $n_023 = 0, $10 = 0, $phase_1 = 0, $count_1 = 0, $counts_sroa_1_1 = 0, $_1 = 0, $11 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $phase_2 = 0, $count_2 = 0, $counts_sroa_1_2 = 0, $_2 = 0, $21 = 0, $phase_3 = 0, $count_3 = 0, $counts_sroa_1_3 = 0, $_3 = 0, $22 = 0, $23 = 0, $c_0_ = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $36 = 0, $37 = 0, $left_1 = 0, $cur_1 = 0, $mask_1 = 0, $c_2 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $writer + 8 | 0;
    $2 = $writer | 0;
    $3 = $writer + 16 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) > 0;
    if ($5) {
      label = 2;
      break;
    } else {
      label = 15;
      break;
    }
   case 2:
    $6 = HEAP32[$2 >> 2] | 0;
    $7 = HEAP32[$1 >> 2] | 0;
    $8 = $writer + 4 | 0;
    $n_023 = $4;
    $phase_024 = 1;
    $count_025 = 0;
    $counts_sroa_1_026 = 0;
    $reload_027 = 1;
    $left_028 = $7;
    $cur_029 = $6;
    $mask_030 = 128;
    $c_031 = 0;
    $_032 = $p;
    label = 3;
    break;
   case 3:
    $10 = ($reload_027 | 0) == 0;
    if ($10) {
      $_3 = $_032;
      $counts_sroa_1_3 = $counts_sroa_1_026;
      $count_3 = $count_025;
      $phase_3 = $phase_024;
      label = 8;
      break;
    } else {
      $_1 = $_032;
      $counts_sroa_1_1 = $counts_sroa_1_026;
      $count_1 = $count_025;
      $phase_1 = $phase_024;
      label = 4;
      break;
    }
   case 4:
    $11 = ($phase_1 | 0) == 0;
    if ($11) {
      $_2 = $_1;
      $counts_sroa_1_2 = $counts_sroa_1_1;
      $count_2 = $counts_sroa_1_1;
      $phase_2 = 1;
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $13 = $_1 >>> 0 < $limit >>> 0;
    if ($13) {
      label = 6;
      break;
    } else {
      $_3 = $_1;
      $counts_sroa_1_3 = $counts_sroa_1_1;
      $count_3 = $count_1;
      $phase_3 = $phase_1;
      label = 8;
      break;
    }
   case 6:
    $15 = $_1 + 1 | 0;
    $16 = HEAP8[$_1] | 0;
    $17 = $16 & 255;
    $18 = $17 >>> 4;
    $19 = $17 & 15;
    $_2 = $15;
    $counts_sroa_1_2 = $19;
    $count_2 = $18;
    $phase_2 = 0;
    label = 7;
    break;
   case 7:
    $21 = ($count_2 | 0) == 0;
    if ($21) {
      $_1 = $_2;
      $counts_sroa_1_1 = $counts_sroa_1_2;
      $count_1 = 0;
      $phase_1 = $phase_2;
      label = 4;
      break;
    } else {
      $_3 = $_2;
      $counts_sroa_1_3 = $counts_sroa_1_2;
      $count_3 = $count_2;
      $phase_3 = $phase_2;
      label = 8;
      break;
    }
   case 8:
    $22 = ($phase_3 | 0) == 0;
    $23 = $22 ? 0 : $mask_030;
    $c_0_ = $23 | $c_031;
    $24 = $mask_030 >>> 1;
    $25 = $left_028 - 1 | 0;
    $26 = ($25 | 0) < 1;
    if ($26) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $28 = $c_0_ & 255;
    HEAP8[$cur_029] = $28;
    $29 = HEAP32[$1 >> 2] | 0;
    $30 = HEAP32[$8 >> 2] | 0;
    $31 = HEAP32[$2 >> 2] | 0;
    $32 = $31 + $30 | 0;
    HEAP32[$2 >> 2] = $32;
    $c_2 = 0;
    $mask_1 = 128;
    $cur_1 = $32;
    $left_1 = $29;
    label = 12;
    break;
   case 10:
    $34 = ($24 | 0) == 0;
    if ($34) {
      label = 11;
      break;
    } else {
      $c_2 = $c_0_;
      $mask_1 = $24;
      $cur_1 = $cur_029;
      $left_1 = $25;
      label = 12;
      break;
    }
   case 11:
    $36 = $c_0_ & 255;
    HEAP8[$cur_029] = $36;
    $37 = $cur_029 + 1 | 0;
    $c_2 = 0;
    $mask_1 = 128;
    $cur_1 = $37;
    $left_1 = $25;
    label = 12;
    break;
   case 12:
    $39 = $count_3 - 1 | 0;
    $40 = ($39 | 0) < 1;
    $41 = $40 & 1;
    $42 = $n_023 - 1 | 0;
    $43 = ($42 | 0) > 0;
    if ($43) {
      $n_023 = $42;
      $phase_024 = $phase_3;
      $count_025 = $39;
      $counts_sroa_1_026 = $counts_sroa_1_3;
      $reload_027 = $41;
      $left_028 = $left_1;
      $cur_029 = $cur_1;
      $mask_030 = $mask_1;
      $c_031 = $c_2;
      $_032 = $_3;
      label = 3;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $44 = ($mask_1 | 0) == 128;
    if ($44) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $46 = $c_2 & 255;
    HEAP8[$cur_1] = $46;
    label = 15;
    break;
   case 15:
    return;
  }
}
function _pfr_bitwriter_decode_rle2($writer, $p, $limit) {
  $writer = $writer | 0;
  $p = $p | 0;
  $limit = $limit | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $c_030 = 0, $mask_029 = 0, $cur_028 = 0, $left_027 = 0, $reload_026 = 0, $count_025 = 0, $phase_024 = 0, $n_023 = 0, $_022 = 0, $10 = 0, $_1 = 0, $phase_1 = 0, $count_1 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $_2 = 0, $phase_2 = 0, $count_2 = 0, $18 = 0, $19 = 0, $c_0_ = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $32 = 0, $33 = 0, $left_1 = 0, $cur_1 = 0, $mask_1 = 0, $c_2 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $writer + 8 | 0;
    $2 = $writer | 0;
    $3 = $writer + 16 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) > 0;
    if ($5) {
      label = 2;
      break;
    } else {
      label = 13;
      break;
    }
   case 2:
    $6 = HEAP32[$2 >> 2] | 0;
    $7 = HEAP32[$1 >> 2] | 0;
    $8 = $writer + 4 | 0;
    $_022 = $p;
    $n_023 = $4;
    $phase_024 = 1;
    $count_025 = 0;
    $reload_026 = 1;
    $left_027 = $7;
    $cur_028 = $6;
    $mask_029 = 128;
    $c_030 = 0;
    label = 3;
    break;
   case 3:
    $10 = ($reload_026 | 0) == 0;
    if ($10) {
      $count_2 = $count_025;
      $phase_2 = $phase_024;
      $_2 = $_022;
      label = 6;
      break;
    } else {
      $count_1 = $count_025;
      $phase_1 = $phase_024;
      $_1 = $_022;
      label = 4;
      break;
    }
   case 4:
    $11 = $_1 >>> 0 < $limit >>> 0;
    if ($11) {
      label = 5;
      break;
    } else {
      $count_2 = $count_1;
      $phase_2 = $phase_1;
      $_2 = $_1;
      label = 6;
      break;
    }
   case 5:
    $13 = $_1 + 1 | 0;
    $14 = HEAP8[$_1] | 0;
    $15 = $14 & 255;
    $16 = $phase_1 ^ 1;
    $17 = $14 << 24 >> 24 == 0;
    if ($17) {
      $count_1 = $15;
      $phase_1 = $16;
      $_1 = $13;
      label = 4;
      break;
    } else {
      $count_2 = $15;
      $phase_2 = $16;
      $_2 = $13;
      label = 6;
      break;
    }
   case 6:
    $18 = ($phase_2 | 0) == 0;
    $19 = $18 ? 0 : $mask_029;
    $c_0_ = $19 | $c_030;
    $20 = $mask_029 >>> 1;
    $21 = $left_027 - 1 | 0;
    $22 = ($21 | 0) < 1;
    if ($22) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $24 = $c_0_ & 255;
    HEAP8[$cur_028] = $24;
    $25 = HEAP32[$1 >> 2] | 0;
    $26 = HEAP32[$8 >> 2] | 0;
    $27 = HEAP32[$2 >> 2] | 0;
    $28 = $27 + $26 | 0;
    HEAP32[$2 >> 2] = $28;
    $c_2 = 0;
    $mask_1 = 128;
    $cur_1 = $28;
    $left_1 = $25;
    label = 10;
    break;
   case 8:
    $30 = ($20 | 0) == 0;
    if ($30) {
      label = 9;
      break;
    } else {
      $c_2 = $c_0_;
      $mask_1 = $20;
      $cur_1 = $cur_028;
      $left_1 = $21;
      label = 10;
      break;
    }
   case 9:
    $32 = $c_0_ & 255;
    HEAP8[$cur_028] = $32;
    $33 = $cur_028 + 1 | 0;
    $c_2 = 0;
    $mask_1 = 128;
    $cur_1 = $33;
    $left_1 = $21;
    label = 10;
    break;
   case 10:
    $35 = $count_2 - 1 | 0;
    $36 = ($35 | 0) < 1;
    $37 = $36 & 1;
    $38 = $n_023 - 1 | 0;
    $39 = ($38 | 0) > 0;
    if ($39) {
      $_022 = $_2;
      $n_023 = $38;
      $phase_024 = $phase_2;
      $count_025 = $35;
      $reload_026 = $37;
      $left_027 = $left_1;
      $cur_028 = $cur_1;
      $mask_029 = $mask_1;
      $c_030 = $c_2;
      label = 3;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $40 = ($mask_1 | 0) == 128;
    if ($40) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $42 = $c_2 & 255;
    HEAP8[$cur_1] = $42;
    label = 13;
    break;
   case 13:
    return;
  }
}
function _pfr_extra_items_parse($pp, $limit, $item_list, $item_data) {
  $pp = $pp | 0;
  $limit = $limit | 0;
  $item_list = $item_list | 0;
  $item_data = $item_data | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $p_027 = 0, $num_items_026 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $_sum = 0, $18 = 0, $19 = 0, $extra_0 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $p_1 = 0, $error_2 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$pp >> 2] | 0;
    $2 = $1 + 1 | 0;
    $3 = $2 >>> 0 > $limit >>> 0;
    if ($3) {
      $error_2 = 8;
      $p_1 = $1;
      label = 11;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = HEAP8[$1] | 0;
    $6 = $5 << 24 >> 24 == 0;
    if ($6) {
      $error_2 = 0;
      $p_1 = $2;
      label = 11;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $5 & 255;
    $8 = ($item_list | 0) == 0;
    $num_items_026 = $7;
    $p_027 = $2;
    label = 4;
    break;
   case 4:
    $10 = $p_027 + 2 | 0;
    $11 = $10 >>> 0 > $limit >>> 0;
    if ($11) {
      $error_2 = 8;
      $p_1 = $p_027;
      label = 11;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $13 = $p_027 + 1 | 0;
    $14 = HEAP8[$p_027] | 0;
    $15 = $14 & 255;
    $16 = HEAP8[$13] | 0;
    $17 = $16 & 255;
    $_sum = $15 + 2 | 0;
    $18 = $p_027 + $_sum | 0;
    $19 = $18 >>> 0 > $limit >>> 0;
    if ($19) {
      $error_2 = 8;
      $p_1 = $10;
      label = 11;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    if ($8) {
      label = 10;
      break;
    } else {
      $extra_0 = $item_list;
      label = 7;
      break;
    }
   case 7:
    $21 = $extra_0 + 4 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = ($22 | 0) == 0;
    if ($23) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $25 = $extra_0 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = ($26 | 0) == ($17 | 0);
    $28 = $extra_0 + 8 | 0;
    if ($27) {
      label = 9;
      break;
    } else {
      $extra_0 = $28;
      label = 7;
      break;
    }
   case 9:
    $30 = FUNCTION_TABLE_iiii[$22 & 1023]($10, $18, $item_data) | 0;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 10;
      break;
    } else {
      $error_2 = $30;
      $p_1 = $10;
      label = 11;
      break;
    }
   case 10:
    $32 = $num_items_026 - 1 | 0;
    $33 = ($32 | 0) == 0;
    if ($33) {
      $error_2 = 0;
      $p_1 = $18;
      label = 11;
      break;
    } else {
      $num_items_026 = $32;
      $p_027 = $18;
      label = 4;
      break;
    }
   case 11:
    HEAP32[$pp >> 2] = $p_1;
    return $error_2 | 0;
  }
  return 0;
}
function _pfr_load_bitmap_bits($p, $limit, $format, $decreasing, $target) {
  $p = $p | 0;
  $limit = $limit | 0;
  $format = $format | 0;
  $decreasing = $decreasing | 0;
  $target = $target | 0;
  var $writer = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 20 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $writer = __stackBase__ | 0;
    $1 = $target | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) > 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $error_0 = 0;
      label = 7;
      break;
    }
   case 2:
    $5 = $target + 4 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) > 0;
    if ($7) {
      label = 3;
      break;
    } else {
      $error_0 = 0;
      label = 7;
      break;
    }
   case 3:
    _pfr_bitwriter_init($writer, $target, $decreasing);
    if (($format | 0) == 0) {
      label = 4;
      break;
    } else if (($format | 0) == 1) {
      label = 5;
      break;
    } else if (($format | 0) == 2) {
      label = 6;
      break;
    } else {
      $error_0 = 3;
      label = 7;
      break;
    }
   case 4:
    _pfr_bitwriter_decode_bytes($writer, $p, $limit);
    $error_0 = 0;
    label = 7;
    break;
   case 5:
    _pfr_bitwriter_decode_rle1($writer, $p, $limit);
    $error_0 = 0;
    label = 7;
    break;
   case 6:
    _pfr_bitwriter_decode_rle2($writer, $p, $limit);
    $error_0 = 0;
    label = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _pfr_glyph_done($glyph) {
  $glyph = $glyph | 0;
  var $4 = 0, $5 = 0;
  $4 = HEAP32[HEAP32[$glyph + 28 >> 2] >> 2] | 0;
  $5 = $glyph + 8 | 0;
  _ft_mem_free($4, HEAP32[$5 >> 2] | 0);
  HEAP32[$5 >> 2] = 0;
  HEAP32[$glyph + 12 >> 2] = 0;
  HEAP32[$glyph + 4 >> 2] = 0;
  _ft_mem_free($4, HEAP32[$glyph + 24 >> 2] | 0);
  _memset($glyph + 16 | 0, 0, 17);
  return;
}
function _pfr_glyph_init($glyph, $loader) {
  $glyph = $glyph | 0;
  $loader = $loader | 0;
  _memset($glyph | 0, 0, 36);
  HEAP32[$glyph + 28 >> 2] = $loader;
  HEAP8[$glyph + 32 | 0] = 0;
  _FT_GlyphLoader_Rewind($loader);
  return;
}
function _pfr_header_check($header) {
  $header = $header | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $header | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 1346785840;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 2:
    $5 = $header + 4 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 >>> 0 > 4;
    if ($7) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = $header + 12 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10 >>> 0 < 58;
    if ($11) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $13 = $header + 8 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($14 | 0) == 3338;
    if ($15) {
      $result_0 = 1;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $result_0 = 0;
    label = 6;
    break;
   case 6:
    return $result_0 | 0;
  }
  return 0;
}
function _pfr_phy_font_done($phy_font, $memory) {
  $phy_font = $phy_font | 0;
  $memory = $memory | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $item_036 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $phy_font + 80 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    _ft_mem_free($memory, $2);
    HEAP32[$1 >> 2] = 0;
    $3 = $phy_font + 84 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    _ft_mem_free($memory, $4);
    HEAP32[$3 >> 2] = 0;
    $5 = $phy_font + 88 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    _ft_mem_free($memory, $6);
    HEAP32[$5 >> 2] = 0;
    $7 = $phy_font + 76 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8;
    _ft_mem_free($memory, $9);
    HEAP32[$7 >> 2] = 0;
    $10 = $phy_font + 72 | 0;
    HEAP32[$10 >> 2] = 0;
    $11 = $phy_font + 64 | 0;
    HEAP32[$11 >> 2] = 0;
    $12 = $phy_font + 60 | 0;
    HEAP32[$12 >> 2] = 0;
    $13 = $phy_font + 100 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14;
    _ft_mem_free($memory, $15);
    HEAP32[$13 >> 2] = 0;
    $16 = $phy_font + 92 | 0;
    HEAP32[$16 >> 2] = 0;
    $17 = $phy_font + 96 | 0;
    HEAP32[$17 >> 2] = 0;
    $18 = $phy_font + 128 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $19;
    _ft_mem_free($memory, $20);
    HEAP32[$18 >> 2] = 0;
    $21 = $phy_font + 120 | 0;
    HEAP32[$21 >> 2] = 0;
    $22 = $phy_font + 124 | 0;
    HEAP32[$22 >> 2] = 0;
    $23 = $phy_font + 108 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24;
    _ft_mem_free($memory, $25);
    HEAP32[$23 >> 2] = 0;
    $26 = $phy_font + 104 | 0;
    HEAP32[$26 >> 2] = 0;
    $27 = $phy_font + 136 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 3;
      break;
    } else {
      $item_036 = $28;
      label = 2;
      break;
    }
   case 2:
    $30 = $item_036 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $item_036;
    _ft_mem_free($memory, $32);
    $33 = ($31 | 0) == 0;
    if ($33) {
      label = 3;
      break;
    } else {
      $item_036 = $31;
      label = 2;
      break;
    }
   case 3:
    HEAP32[$27 >> 2] = 0;
    $34 = $phy_font + 140 | 0;
    HEAP32[$34 >> 2] = 0;
    $35 = $phy_font + 132 | 0;
    HEAP32[$35 >> 2] = 0;
    return;
  }
}
function _pfr_header_load($header, $stream) {
  $header = $header | 0;
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _FT_Stream_Seek($stream, 0) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $error_0 = $1;
      label = 4;
      break;
    }
   case 2:
    $4 = $header;
    $5 = _FT_Stream_ReadFields($stream, 5250304, $4) | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      $error_0 = $5;
      label = 4;
      break;
    }
   case 3:
    $8 = $header + 72 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 << 16;
    $11 = $header + 36 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + $10 | 0;
    HEAP32[$11 >> 2] = $13;
    $error_0 = 0;
    label = 4;
    break;
   case 4:
    return $error_0 | 0;
  }
  return 0;
}
function _pfr_log_font_count($stream, $section_offset, $acount) {
  $stream = $stream | 0;
  $section_offset = $section_offset | 0;
  $acount = $acount | 0;
  var $error = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_ = 0, $result_0 = 0, $9 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = _FT_Stream_Seek($stream, $section_offset) | 0;
    HEAP32[$error >> 2] = $1;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $result_0 = 0;
      label = 3;
      break;
    }
   case 2:
    $4 = _FT_Stream_ReadShort($stream, $error) | 0;
    $5 = HEAP32[$error >> 2] | 0;
    $6 = ($5 | 0) == 0;
    $7 = $4 & 65535;
    $_ = $6 ? $7 : 0;
    $result_0 = $_;
    label = 3;
    break;
   case 3:
    HEAP32[$acount >> 2] = $result_0;
    $9 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $9 | 0;
  }
  return 0;
}
function _pfr_log_font_load($log_font, $stream, $idx, $section_offset, $size_increment) {
  $log_font = $log_font | 0;
  $stream = $stream | 0;
  $idx = $idx | 0;
  $section_offset = $section_offset | 0;
  $size_increment = $size_increment | 0;
  var $error = 0, $p = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $_ = 0, $local_1 = 0, $110 = 0, $111 = 0, $113 = 0, $114 = 0, $115 = 0, $_48 = 0, $local_2 = 0, $117 = 0, $118 = 0, $119 = 0, $122 = 0, $123 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $135 = 0, $136 = 0, $137 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $161 = 0, $162 = 0, $163 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $175 = 0, $176 = 0, $177 = 0, $179 = 0, $180 = 0, $182 = 0, $183 = 0, $185 = 0, $186 = 0, $188 = 0, $189 = 0, $190 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $218 = 0, $219 = 0, $220 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $229 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $p = __stackBase__ + 4 | 0;
    $1 = _FT_Stream_Seek($stream, $section_offset) | 0;
    HEAP32[$error >> 2] = $1;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      label = 33;
      break;
    }
   case 2:
    $4 = _FT_Stream_ReadShort($stream, $error) | 0;
    $5 = HEAP32[$error >> 2] | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 33;
      break;
    }
   case 3:
    $8 = $4 & 65535;
    $9 = $8 >>> 0 > $idx >>> 0;
    if ($9) {
      label = 4;
      break;
    } else {
      $_0 = 6;
      label = 35;
      break;
    }
   case 4:
    $11 = $idx * 5 & -1;
    $12 = _FT_Stream_Skip($stream, $11) | 0;
    HEAP32[$error >> 2] = $12;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 5;
      break;
    } else {
      label = 33;
      break;
    }
   case 5:
    $15 = _FT_Stream_ReadShort($stream, $error) | 0;
    $16 = $15 & 65535;
    $17 = HEAP32[$error >> 2] | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 6;
      break;
    } else {
      label = 33;
      break;
    }
   case 6:
    $20 = _FT_Stream_ReadOffset($stream, $error) | 0;
    $21 = HEAP32[$error >> 2] | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 7;
      break;
    } else {
      label = 33;
      break;
    }
   case 7:
    $24 = $log_font | 0;
    HEAP32[$24 >> 2] = $16;
    $25 = $log_font + 4 | 0;
    HEAP32[$25 >> 2] = $20;
    $26 = _FT_Stream_Seek($stream, $20) | 0;
    HEAP32[$error >> 2] = $26;
    $27 = ($26 | 0) == 0;
    if ($27) {
      label = 8;
      break;
    } else {
      label = 33;
      break;
    }
   case 8:
    $29 = _FT_Stream_EnterFrame($stream, $16) | 0;
    HEAP32[$error >> 2] = $29;
    $30 = ($29 | 0) == 0;
    if ($30) {
      label = 9;
      break;
    } else {
      label = 33;
      break;
    }
   case 9:
    $32 = $stream + 32 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    HEAP32[$p >> 2] = $33;
    $34 = $33 + $16 | 0;
    $35 = ($15 & 65535) < 13;
    if ($35) {
      label = 34;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $37 = $33 + 3 | 0;
    HEAP32[$p >> 2] = $37;
    $38 = HEAP8[$33] | 0;
    $39 = $38 << 24 >> 24;
    $40 = $39 << 16;
    $41 = $33 + 1 | 0;
    $42 = HEAP8[$41] | 0;
    $43 = $42 & 255;
    $44 = $43 << 8;
    $45 = $44 | $40;
    $46 = $33 + 2 | 0;
    $47 = HEAP8[$46] | 0;
    $48 = $47 & 255;
    $49 = $45 | $48;
    $50 = $log_font + 8 | 0;
    HEAP32[$50 >> 2] = $49;
    $51 = HEAP32[$p >> 2] | 0;
    $52 = $51 + 3 | 0;
    HEAP32[$p >> 2] = $52;
    $53 = HEAP8[$51] | 0;
    $54 = $53 << 24 >> 24;
    $55 = $54 << 16;
    $56 = $51 + 1 | 0;
    $57 = HEAP8[$56] | 0;
    $58 = $57 & 255;
    $59 = $58 << 8;
    $60 = $59 | $55;
    $61 = $51 + 2 | 0;
    $62 = HEAP8[$61] | 0;
    $63 = $62 & 255;
    $64 = $60 | $63;
    $65 = $log_font + 12 | 0;
    HEAP32[$65 >> 2] = $64;
    $66 = HEAP32[$p >> 2] | 0;
    $67 = $66 + 3 | 0;
    HEAP32[$p >> 2] = $67;
    $68 = HEAP8[$66] | 0;
    $69 = $68 << 24 >> 24;
    $70 = $69 << 16;
    $71 = $66 + 1 | 0;
    $72 = HEAP8[$71] | 0;
    $73 = $72 & 255;
    $74 = $73 << 8;
    $75 = $74 | $70;
    $76 = $66 + 2 | 0;
    $77 = HEAP8[$76] | 0;
    $78 = $77 & 255;
    $79 = $75 | $78;
    $80 = $log_font + 16 | 0;
    HEAP32[$80 >> 2] = $79;
    $81 = HEAP32[$p >> 2] | 0;
    $82 = $81 + 3 | 0;
    HEAP32[$p >> 2] = $82;
    $83 = HEAP8[$81] | 0;
    $84 = $83 << 24 >> 24;
    $85 = $84 << 16;
    $86 = $81 + 1 | 0;
    $87 = HEAP8[$86] | 0;
    $88 = $87 & 255;
    $89 = $88 << 8;
    $90 = $89 | $85;
    $91 = $81 + 2 | 0;
    $92 = HEAP8[$91] | 0;
    $93 = $92 & 255;
    $94 = $90 | $93;
    $95 = $log_font + 20 | 0;
    HEAP32[$95 >> 2] = $94;
    $96 = HEAP32[$p >> 2] | 0;
    $97 = $96 + 1 | 0;
    HEAP32[$p >> 2] = $97;
    $98 = HEAP8[$96] | 0;
    $99 = $98 & 255;
    $100 = $99 & 4;
    $101 = ($100 | 0) != 0;
    if ($101) {
      label = 11;
      break;
    } else {
      $local_1 = 0;
      label = 12;
      break;
    }
   case 11:
    $103 = $99 >>> 3;
    $104 = $103 & 1;
    $105 = $104 + 1 | 0;
    $106 = $99 & 3;
    $107 = ($106 | 0) == 0;
    $108 = $104 | 4;
    $_ = $107 ? $108 : $105;
    $local_1 = $_;
    label = 12;
    break;
   case 12:
    $110 = $99 & 16;
    $111 = ($110 | 0) != 0;
    if ($111) {
      label = 13;
      break;
    } else {
      $local_2 = $local_1;
      label = 14;
      break;
    }
   case 13:
    $113 = $99 >>> 5;
    $114 = $113 & 1;
    $115 = $114 + 1 | 0;
    $_48 = $115 + $local_1 | 0;
    $local_2 = $_48;
    label = 14;
    break;
   case 14:
    $117 = HEAP32[$p >> 2] | 0;
    $118 = $117 + $local_2 | 0;
    $119 = $118 >>> 0 > $34 >>> 0;
    if ($119) {
      label = 34;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    if ($101) {
      label = 16;
      break;
    } else {
      label = 21;
      break;
    }
   case 16:
    $122 = $99 & 8;
    $123 = ($122 | 0) == 0;
    if ($123) {
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $125 = $117 + 2 | 0;
    HEAP32[$p >> 2] = $125;
    $126 = HEAP8[$117] | 0;
    $127 = $126 & 255;
    $128 = $127 << 8;
    $129 = $117 + 1 | 0;
    $130 = HEAP8[$129] | 0;
    $131 = $130 & 255;
    $132 = $128 | $131;
    $133 = $132 << 16 >> 16;
    $139 = $133;
    label = 19;
    break;
   case 18:
    $135 = $117 + 1 | 0;
    HEAP32[$p >> 2] = $135;
    $136 = HEAP8[$117] | 0;
    $137 = $136 & 255;
    $139 = $137;
    label = 19;
    break;
   case 19:
    $140 = $log_font + 28 | 0;
    HEAP32[$140 >> 2] = $139;
    $141 = $99 & 3;
    $142 = ($141 | 0) == 0;
    if ($142) {
      label = 20;
      break;
    } else {
      label = 21;
      break;
    }
   case 20:
    $144 = HEAP32[$p >> 2] | 0;
    $145 = $144 + 3 | 0;
    HEAP32[$p >> 2] = $145;
    $146 = HEAP8[$144] | 0;
    $147 = $146 << 24 >> 24;
    $148 = $147 << 16;
    $149 = $144 + 1 | 0;
    $150 = HEAP8[$149] | 0;
    $151 = $150 & 255;
    $152 = $151 << 8;
    $153 = $152 | $148;
    $154 = $144 + 2 | 0;
    $155 = HEAP8[$154] | 0;
    $156 = $155 & 255;
    $157 = $153 | $156;
    $158 = $log_font + 36 | 0;
    HEAP32[$158 >> 2] = $157;
    label = 21;
    break;
   case 21:
    if ($111) {
      label = 22;
      break;
    } else {
      label = 26;
      break;
    }
   case 22:
    $161 = $99 & 32;
    $162 = ($161 | 0) == 0;
    $163 = HEAP32[$p >> 2] | 0;
    if ($162) {
      label = 24;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $165 = $163 + 2 | 0;
    HEAP32[$p >> 2] = $165;
    $166 = HEAP8[$163] | 0;
    $167 = $166 & 255;
    $168 = $167 << 8;
    $169 = $163 + 1 | 0;
    $170 = HEAP8[$169] | 0;
    $171 = $170 & 255;
    $172 = $168 | $171;
    $173 = $172 << 16 >> 16;
    $179 = $173;
    label = 25;
    break;
   case 24:
    $175 = $163 + 1 | 0;
    HEAP32[$p >> 2] = $175;
    $176 = HEAP8[$163] | 0;
    $177 = $176 & 255;
    $179 = $177;
    label = 25;
    break;
   case 25:
    $180 = $log_font + 32 | 0;
    HEAP32[$180 >> 2] = $179;
    label = 26;
    break;
   case 26:
    $182 = $99 & 64;
    $183 = ($182 | 0) == 0;
    if ($183) {
      label = 28;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $185 = _pfr_extra_items_skip($p, $34) | 0;
    HEAP32[$error >> 2] = $185;
    $186 = ($185 | 0) == 0;
    if ($186) {
      label = 28;
      break;
    } else {
      label = 32;
      break;
    }
   case 28:
    $188 = HEAP32[$p >> 2] | 0;
    $189 = $188 + 5 | 0;
    $190 = $189 >>> 0 > $34 >>> 0;
    if ($190) {
      label = 34;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    $192 = $188 + 2 | 0;
    HEAP32[$p >> 2] = $192;
    $193 = HEAP8[$188] | 0;
    $194 = $193 & 255;
    $195 = $194 << 8;
    $196 = $188 + 1 | 0;
    $197 = HEAP8[$196] | 0;
    $198 = $197 & 255;
    $199 = $195 | $198;
    $200 = $log_font + 40 | 0;
    HEAP32[$200 >> 2] = $199;
    $201 = HEAP32[$p >> 2] | 0;
    $202 = $201 + 3 | 0;
    HEAP32[$p >> 2] = $202;
    $203 = HEAP8[$201] | 0;
    $204 = $203 & 255;
    $205 = $204 << 16;
    $206 = $201 + 1 | 0;
    $207 = HEAP8[$206] | 0;
    $208 = $207 & 255;
    $209 = $208 << 8;
    $210 = $209 | $205;
    $211 = $201 + 2 | 0;
    $212 = HEAP8[$211] | 0;
    $213 = $212 & 255;
    $214 = $210 | $213;
    $215 = $log_font + 44 | 0;
    HEAP32[$215 >> 2] = $214;
    $216 = $size_increment << 24 >> 24 == 0;
    if ($216) {
      label = 32;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    $218 = HEAP32[$p >> 2] | 0;
    $219 = $218 + 1 | 0;
    $220 = $219 >>> 0 > $34 >>> 0;
    if ($220) {
      label = 34;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    HEAP32[$p >> 2] = $219;
    $222 = HEAP8[$218] | 0;
    $223 = $222 & 255;
    $224 = $223 << 16;
    $225 = HEAP32[$200 >> 2] | 0;
    $226 = $224 + $225 | 0;
    HEAP32[$200 >> 2] = $226;
    label = 32;
    break;
   case 32:
    _FT_Stream_ExitFrame($stream);
    label = 33;
    break;
   case 33:
    $229 = HEAP32[$error >> 2] | 0;
    $_0 = $229;
    label = 35;
    break;
   case 34:
    HEAP32[$error >> 2] = 8;
    label = 32;
    break;
   case 35:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _pfr_phy_font_load($phy_font, $stream, $offset, $size) {
  $phy_font = $phy_font | 0;
  $stream = $stream | 0;
  $offset = $offset | 0;
  $size = $size | 0;
  var $error = 0, $p = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $101 = 0, $102 = 0, $103 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $115 = 0, $116 = 0, $118 = 0, $119 = 0, $120 = 0, $122 = 0, $123 = 0, $124 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $_sum = 0, $140 = 0, $141 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $num_aux_0130 = 0, $q_0129 = 0, $150 = 0, $151 = 0, $152 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $or_cond = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $174 = 0, $175 = 0, $176 = 0, $178 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $208 = 0, $209 = 0, $210 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $218 = 0, $219 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $235 = 0, $n_0125 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $exitcond134 = 0, $_lcssa = 0, $249 = 0, $250 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $300 = 0, $301 = 0, $302 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $Size_1 = 0, $308 = 0, $309 = 0, $_lobit = 0, $310 = 0, $311 = 0, $_lobit121 = 0, $312 = 0, $313 = 0, $_lobit122 = 0, $_Size_1 = 0, $Size_3 = 0, $_Size_3 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $n1_0123 = 0, $321 = 0, $322 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $330 = 0, $331 = 0, $333 = 0, $334 = 0, $335 = 0, $337 = 0, $338 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $351 = 0, $353 = 0, $354 = 0, $356 = 0, $357 = 0, $359 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $370 = 0, $371 = 0, $372 = 0, $374 = 0, $375 = 0, $376 = 0, $378 = 0, $379 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $390 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $401 = 0, $402 = 0, $403 = 0, $exitcond = 0, $404 = 0, $405 = 0, $406 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $p = __stackBase__ + 4 | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $phy_font | 0;
    HEAP32[$3 >> 2] = $2;
    $4 = $phy_font + 4 | 0;
    HEAP32[$4 >> 2] = $offset;
    $5 = $phy_font + 136 | 0;
    HEAP32[$5 >> 2] = 0;
    $6 = $phy_font + 140 | 0;
    HEAP32[$6 >> 2] = $5;
    $7 = _FT_Stream_Seek($stream, $offset) | 0;
    HEAP32[$error >> 2] = $7;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 49;
      break;
    }
   case 2:
    $10 = _FT_Stream_EnterFrame($stream, $size) | 0;
    HEAP32[$error >> 2] = $10;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 3;
      break;
    } else {
      label = 49;
      break;
    }
   case 3:
    $13 = $stream + 32 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $phy_font + 148 | 0;
    HEAP32[$15 >> 2] = $14;
    $16 = HEAP32[$13 >> 2] | 0;
    HEAP32[$p >> 2] = $16;
    $17 = $16 + $size | 0;
    $18 = ($size | 0) < 15;
    if ($18) {
      label = 50;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $20 = $16 + 2 | 0;
    HEAP32[$p >> 2] = $20;
    $21 = HEAP8[$16] | 0;
    $22 = $21 & 255;
    $23 = $22 << 8;
    $24 = $16 + 1 | 0;
    $25 = HEAP8[$24] | 0;
    $26 = $25 & 255;
    $27 = $23 | $26;
    $28 = $phy_font + 8 | 0;
    HEAP32[$28 >> 2] = $27;
    $29 = HEAP32[$p >> 2] | 0;
    $30 = $29 + 2 | 0;
    HEAP32[$p >> 2] = $30;
    $31 = HEAP8[$29] | 0;
    $32 = $31 & 255;
    $33 = $32 << 8;
    $34 = $29 + 1 | 0;
    $35 = HEAP8[$34] | 0;
    $36 = $35 & 255;
    $37 = $33 | $36;
    $38 = $phy_font + 12 | 0;
    HEAP32[$38 >> 2] = $37;
    $39 = HEAP32[$p >> 2] | 0;
    $40 = $39 + 2 | 0;
    HEAP32[$p >> 2] = $40;
    $41 = HEAP8[$39] | 0;
    $42 = $41 & 255;
    $43 = $42 << 8;
    $44 = $39 + 1 | 0;
    $45 = HEAP8[$44] | 0;
    $46 = $45 & 255;
    $47 = $43 | $46;
    $48 = $phy_font + 16 | 0;
    HEAP32[$48 >> 2] = $47;
    $49 = HEAP32[$p >> 2] | 0;
    $50 = $49 + 2 | 0;
    HEAP32[$p >> 2] = $50;
    $51 = HEAP8[$49] | 0;
    $52 = $51 & 255;
    $53 = $52 << 8;
    $54 = $49 + 1 | 0;
    $55 = HEAP8[$54] | 0;
    $56 = $55 & 255;
    $57 = $53 | $56;
    $58 = $57 << 16 >> 16;
    $59 = $phy_font + 20 | 0;
    HEAP32[$59 >> 2] = $58;
    $60 = HEAP32[$p >> 2] | 0;
    $61 = $60 + 2 | 0;
    HEAP32[$p >> 2] = $61;
    $62 = HEAP8[$60] | 0;
    $63 = $62 & 255;
    $64 = $63 << 8;
    $65 = $60 + 1 | 0;
    $66 = HEAP8[$65] | 0;
    $67 = $66 & 255;
    $68 = $64 | $67;
    $69 = $68 << 16 >> 16;
    $70 = $phy_font + 24 | 0;
    HEAP32[$70 >> 2] = $69;
    $71 = HEAP32[$p >> 2] | 0;
    $72 = $71 + 2 | 0;
    HEAP32[$p >> 2] = $72;
    $73 = HEAP8[$71] | 0;
    $74 = $73 & 255;
    $75 = $74 << 8;
    $76 = $71 + 1 | 0;
    $77 = HEAP8[$76] | 0;
    $78 = $77 & 255;
    $79 = $75 | $78;
    $80 = $79 << 16 >> 16;
    $81 = $phy_font + 28 | 0;
    HEAP32[$81 >> 2] = $80;
    $82 = HEAP32[$p >> 2] | 0;
    $83 = $82 + 2 | 0;
    HEAP32[$p >> 2] = $83;
    $84 = HEAP8[$82] | 0;
    $85 = $84 & 255;
    $86 = $85 << 8;
    $87 = $82 + 1 | 0;
    $88 = HEAP8[$87] | 0;
    $89 = $88 & 255;
    $90 = $86 | $89;
    $91 = $90 << 16 >> 16;
    $92 = $phy_font + 32 | 0;
    HEAP32[$92 >> 2] = $91;
    $93 = HEAP32[$p >> 2] | 0;
    $94 = $93 + 1 | 0;
    HEAP32[$p >> 2] = $94;
    $95 = HEAP8[$93] | 0;
    $96 = $95 & 255;
    $97 = $phy_font + 36 | 0;
    HEAP32[$97 >> 2] = $96;
    $98 = $96 & 4;
    $99 = ($98 | 0) != 0;
    if ($99) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $101 = HEAP32[$p >> 2] | 0;
    $102 = $101 + 2 | 0;
    $103 = $102 >>> 0 > $17 >>> 0;
    if ($103) {
      label = 50;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    HEAP32[$p >> 2] = $102;
    $105 = HEAP8[$101] | 0;
    $106 = $105 & 255;
    $107 = $106 << 8;
    $108 = $101 + 1 | 0;
    $109 = HEAP8[$108] | 0;
    $110 = $109 & 255;
    $111 = $107 | $110;
    $112 = $111 << 16 >> 16;
    $113 = $phy_font + 40 | 0;
    HEAP32[$113 >> 2] = $112;
    label = 7;
    break;
   case 7:
    $115 = $96 & 128;
    $116 = ($115 | 0) == 0;
    if ($116) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $118 = $phy_font;
    $119 = _pfr_extra_items_parse($p, $17, 5250252, $118) | 0;
    HEAP32[$error >> 2] = $119;
    $120 = ($119 | 0) == 0;
    if ($120) {
      label = 9;
      break;
    } else {
      label = 48;
      break;
    }
   case 9:
    $122 = HEAP32[$p >> 2] | 0;
    $123 = $122 + 3 | 0;
    $124 = $123 >>> 0 > $17 >>> 0;
    if ($124) {
      label = 50;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    HEAP32[$p >> 2] = $123;
    $126 = HEAP8[$122] | 0;
    $127 = $126 & 255;
    $128 = $127 << 16;
    $129 = $122 + 1 | 0;
    $130 = HEAP8[$129] | 0;
    $131 = $130 & 255;
    $132 = $131 << 8;
    $133 = $132 | $128;
    $134 = $122 + 2 | 0;
    $135 = HEAP8[$134] | 0;
    $136 = $135 & 255;
    $137 = $133 | $136;
    $138 = ($137 | 0) == 0;
    if ($138) {
      label = 22;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $_sum = $137 + 3 | 0;
    $140 = $122 + $_sum | 0;
    $141 = $140 >>> 0 > $17 >>> 0;
    if ($141) {
      label = 50;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    HEAP32[$p >> 2] = $140;
    $143 = ($137 | 0) == 0;
    if ($143) {
      label = 22;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $144 = $phy_font + 84 | 0;
    $145 = $phy_font + 44 | 0;
    $146 = $phy_font + 48 | 0;
    $147 = $phy_font + 52 | 0;
    $148 = $phy_font + 88 | 0;
    $q_0129 = $123;
    $num_aux_0130 = $137;
    label = 14;
    break;
   case 14:
    $150 = $q_0129 + 4 | 0;
    $151 = HEAP32[$p >> 2] | 0;
    $152 = $150 >>> 0 > $151 >>> 0;
    if ($152) {
      label = 22;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $154 = HEAP8[$q_0129] | 0;
    $155 = $154 & 255;
    $156 = $155 << 8;
    $157 = $q_0129 + 1 | 0;
    $158 = HEAP8[$157] | 0;
    $159 = $158 & 255;
    $160 = $156 | $159;
    $161 = $160 >>> 0 < 4;
    $162 = $160 >>> 0 > $num_aux_0130 >>> 0;
    $or_cond = $161 | $162;
    if ($or_cond) {
      label = 22;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $164 = $q_0129 + $160 | 0;
    $165 = $q_0129 + 2 | 0;
    $166 = HEAP8[$165] | 0;
    $167 = $166 & 255;
    $168 = $167 << 8;
    $169 = $q_0129 + 3 | 0;
    $170 = HEAP8[$169] | 0;
    $171 = $170 & 255;
    $172 = $168 | $171;
    if (($172 | 0) == 1) {
      label = 17;
      break;
    } else if (($172 | 0) == 2) {
      label = 18;
      break;
    } else if (($172 | 0) == 3) {
      label = 20;
      break;
    } else {
      label = 21;
      break;
    }
   case 17:
    $174 = $160 - 4 | 0;
    $175 = _pfr_aux_name_load($150, $174, $2, $144) | 0;
    HEAP32[$error >> 2] = $175;
    $176 = ($175 | 0) == 0;
    if ($176) {
      label = 21;
      break;
    } else {
      label = 49;
      break;
    }
   case 18:
    $178 = $160 >>> 0 < 36;
    if ($178) {
      label = 21;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $180 = $q_0129 + 14 | 0;
    $181 = HEAP8[$180] | 0;
    $182 = $181 & 255;
    $183 = $182 << 8;
    $184 = $q_0129 + 15 | 0;
    $185 = HEAP8[$184] | 0;
    $186 = $185 & 255;
    $187 = $183 | $186;
    $188 = $187 << 16 >> 16;
    HEAP32[$145 >> 2] = $188;
    $189 = $q_0129 + 16 | 0;
    $190 = HEAP8[$189] | 0;
    $191 = $190 & 255;
    $192 = $191 << 8;
    $193 = $q_0129 + 17 | 0;
    $194 = HEAP8[$193] | 0;
    $195 = $194 & 255;
    $196 = $192 | $195;
    $197 = $196 << 16 >> 16;
    HEAP32[$146 >> 2] = $197;
    $198 = $q_0129 + 18 | 0;
    $199 = HEAP8[$198] | 0;
    $200 = $199 & 255;
    $201 = $200 << 8;
    $202 = $q_0129 + 19 | 0;
    $203 = HEAP8[$202] | 0;
    $204 = $203 & 255;
    $205 = $201 | $204;
    $206 = $205 << 16 >> 16;
    HEAP32[$147 >> 2] = $206;
    label = 21;
    break;
   case 20:
    $208 = $160 - 4 | 0;
    $209 = _pfr_aux_name_load($150, $208, $2, $148) | 0;
    HEAP32[$error >> 2] = $209;
    $210 = ($209 | 0) == 0;
    if ($210) {
      label = 21;
      break;
    } else {
      label = 49;
      break;
    }
   case 21:
    $212 = $num_aux_0130 - $160 | 0;
    $213 = ($num_aux_0130 | 0) == ($160 | 0);
    if ($213) {
      label = 22;
      break;
    } else {
      $q_0129 = $164;
      $num_aux_0130 = $212;
      label = 14;
      break;
    }
   case 22:
    $214 = HEAP32[$p >> 2] | 0;
    $215 = $214 + 1 | 0;
    $216 = $215 >>> 0 > $17 >>> 0;
    if ($216) {
      label = 50;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    HEAP32[$p >> 2] = $215;
    $218 = HEAP8[$214] | 0;
    $219 = $218 & 255;
    $220 = $phy_font + 104 | 0;
    HEAP32[$220 >> 2] = $219;
    $221 = HEAP32[$p >> 2] | 0;
    $222 = $219 << 1;
    $223 = $221 + $222 | 0;
    $224 = $223 >>> 0 > $17 >>> 0;
    if ($224) {
      label = 50;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $226 = _ft_mem_realloc($2, 4, 0, $219, 0, $error) | 0;
    $227 = $226;
    $228 = $phy_font + 108 | 0;
    HEAP32[$228 >> 2] = $227;
    $229 = HEAP32[$error >> 2] | 0;
    $230 = ($229 | 0) == 0;
    if ($230) {
      label = 25;
      break;
    } else {
      label = 48;
      break;
    }
   case 25:
    $231 = $218 << 24 >> 24 == 0;
    $232 = HEAP32[$p >> 2] | 0;
    if ($231) {
      $_lcssa = $232;
      label = 28;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $233 = $218 & 255;
    $n_0125 = 0;
    $235 = $232;
    label = 27;
    break;
   case 27:
    $236 = $235 + 2 | 0;
    HEAP32[$p >> 2] = $236;
    $237 = HEAP8[$235] | 0;
    $238 = $237 & 255;
    $239 = $238 << 8;
    $240 = $235 + 1 | 0;
    $241 = HEAP8[$240] | 0;
    $242 = $241 & 255;
    $243 = $239 | $242;
    $244 = $243 << 16 >> 16;
    $245 = HEAP32[$228 >> 2] | 0;
    $246 = $245 + ($n_0125 << 2) | 0;
    HEAP32[$246 >> 2] = $244;
    $247 = $n_0125 + 1 | 0;
    $248 = HEAP32[$p >> 2] | 0;
    $exitcond134 = ($247 | 0) == ($233 | 0);
    if ($exitcond134) {
      $_lcssa = $248;
      label = 28;
      break;
    } else {
      $n_0125 = $247;
      $235 = $248;
      label = 27;
      break;
    }
   case 28:
    $249 = $_lcssa + 8 | 0;
    $250 = $249 >>> 0 > $17 >>> 0;
    if ($250) {
      label = 50;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    $252 = $_lcssa + 1 | 0;
    HEAP32[$p >> 2] = $252;
    $253 = HEAP8[$_lcssa] | 0;
    $254 = $253 & 255;
    $255 = $phy_font + 112 | 0;
    HEAP32[$255 >> 2] = $254;
    $256 = HEAP32[$p >> 2] | 0;
    $257 = $256 + 1 | 0;
    HEAP32[$p >> 2] = $257;
    $258 = HEAP8[$256] | 0;
    $259 = $258 & 255;
    $260 = $phy_font + 116 | 0;
    HEAP32[$260 >> 2] = $259;
    $261 = HEAP32[$p >> 2] | 0;
    $262 = $261 + 2 | 0;
    HEAP32[$p >> 2] = $262;
    $263 = HEAP8[$261] | 0;
    $264 = $263 & 255;
    $265 = $264 << 8;
    $266 = $261 + 1 | 0;
    $267 = HEAP8[$266] | 0;
    $268 = $267 & 255;
    $269 = $265 | $268;
    $270 = $phy_font + 68 | 0;
    HEAP32[$270 >> 2] = $269;
    $271 = HEAP32[$p >> 2] | 0;
    $272 = $271 + 2 | 0;
    HEAP32[$p >> 2] = $272;
    $273 = HEAP8[$271] | 0;
    $274 = $273 & 255;
    $275 = $274 << 8;
    $276 = $271 + 1 | 0;
    $277 = HEAP8[$276] | 0;
    $278 = $277 & 255;
    $279 = $275 | $278;
    $280 = $phy_font + 56 | 0;
    HEAP32[$280 >> 2] = $279;
    $281 = HEAP32[$p >> 2] | 0;
    $282 = $281 + 2 | 0;
    HEAP32[$p >> 2] = $282;
    $283 = HEAP8[$281] | 0;
    $284 = $283 & 255;
    $285 = $284 << 8;
    $286 = $281 + 1 | 0;
    $287 = HEAP8[$286] | 0;
    $288 = $287 & 255;
    $289 = $285 | $288;
    $290 = $phy_font + 120 | 0;
    HEAP32[$290 >> 2] = $289;
    $291 = HEAP32[$p >> 2] | 0;
    $292 = HEAP32[$13 >> 2] | 0;
    $293 = $291;
    $294 = $292;
    $295 = $293 + $offset | 0;
    $296 = $295 - $294 | 0;
    $297 = $phy_font + 124 | 0;
    HEAP32[$297 >> 2] = $296;
    $298 = _ft_mem_realloc($2, 16, 0, $289, 0, $error) | 0;
    $299 = $298;
    $300 = $phy_font + 128 | 0;
    HEAP32[$300 >> 2] = $299;
    $301 = HEAP32[$error >> 2] | 0;
    $302 = ($301 | 0) == 0;
    if ($302) {
      label = 30;
      break;
    } else {
      label = 48;
      break;
    }
   case 30:
    $304 = $96 & 2;
    $305 = ($304 | 0) == 0;
    $306 = $96 >>> 1;
    $307 = $306 & 3;
    $Size_1 = $307 | 4;
    $308 = $96 & 8;
    $309 = ($308 | 0) == 0;
    $_lobit = $308 >>> 3;
    $310 = $96 & 16;
    $311 = ($310 | 0) == 0;
    $_lobit121 = $310 >>> 4;
    $312 = $96 & 32;
    $313 = ($312 | 0) == 0;
    $_lobit122 = $312 >>> 5;
    $_Size_1 = $_lobit121 + $_lobit | 0;
    $Size_3 = $_Size_1 + $_lobit122 | 0;
    $_Size_3 = $Size_3 + $Size_1 | 0;
    $314 = HEAP32[$p >> 2] | 0;
    $315 = Math_imul($289, $_Size_3);
    $316 = $314 + $315 | 0;
    $317 = $316 >>> 0 > $17 >>> 0;
    if ($317) {
      label = 50;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    $318 = ($289 | 0) == 0;
    if ($318) {
      label = 48;
      break;
    } else {
      label = 32;
      break;
    }
   case 32:
    $319 = $phy_font + 40 | 0;
    $n1_0123 = 0;
    label = 33;
    break;
   case 33:
    $321 = HEAP32[$300 >> 2] | 0;
    $322 = HEAP32[$p >> 2] | 0;
    if ($305) {
      label = 35;
      break;
    } else {
      label = 34;
      break;
    }
   case 34:
    $324 = $322 + 2 | 0;
    HEAP32[$p >> 2] = $324;
    $325 = HEAP8[$322] | 0;
    $326 = $325 & 255;
    $327 = $326 << 8;
    $328 = $322 + 1 | 0;
    $329 = HEAP8[$328] | 0;
    $330 = $329 & 255;
    $331 = $327 | $330;
    $337 = $331;
    label = 36;
    break;
   case 35:
    $333 = $322 + 1 | 0;
    HEAP32[$p >> 2] = $333;
    $334 = HEAP8[$322] | 0;
    $335 = $334 & 255;
    $337 = $335;
    label = 36;
    break;
   case 36:
    $338 = $321 + ($n1_0123 << 4) | 0;
    HEAP32[$338 >> 2] = $337;
    if ($99) {
      label = 37;
      break;
    } else {
      label = 38;
      break;
    }
   case 37:
    $340 = HEAP32[$p >> 2] | 0;
    $341 = $340 + 2 | 0;
    HEAP32[$p >> 2] = $341;
    $342 = HEAP8[$340] | 0;
    $343 = $342 & 255;
    $344 = $343 << 8;
    $345 = $340 + 1 | 0;
    $346 = HEAP8[$345] | 0;
    $347 = $346 & 255;
    $348 = $344 | $347;
    $349 = $348 << 16 >> 16;
    $353 = $349;
    label = 39;
    break;
   case 38:
    $351 = HEAP32[$319 >> 2] | 0;
    $353 = $351;
    label = 39;
    break;
   case 39:
    $354 = $321 + ($n1_0123 << 4) + 4 | 0;
    HEAP32[$354 >> 2] = $353;
    if ($309) {
      label = 41;
      break;
    } else {
      label = 40;
      break;
    }
   case 40:
    $356 = HEAP32[$p >> 2] | 0;
    $357 = $356 + 1 | 0;
    HEAP32[$p >> 2] = $357;
    label = 41;
    break;
   case 41:
    $359 = HEAP32[$p >> 2] | 0;
    if ($311) {
      label = 43;
      break;
    } else {
      label = 42;
      break;
    }
   case 42:
    $361 = $359 + 2 | 0;
    HEAP32[$p >> 2] = $361;
    $362 = HEAP8[$359] | 0;
    $363 = $362 & 255;
    $364 = $363 << 8;
    $365 = $359 + 1 | 0;
    $366 = HEAP8[$365] | 0;
    $367 = $366 & 255;
    $368 = $364 | $367;
    $374 = $368;
    label = 44;
    break;
   case 43:
    $370 = $359 + 1 | 0;
    HEAP32[$p >> 2] = $370;
    $371 = HEAP8[$359] | 0;
    $372 = $371 & 255;
    $374 = $372;
    label = 44;
    break;
   case 44:
    $375 = $321 + ($n1_0123 << 4) + 8 | 0;
    HEAP32[$375 >> 2] = $374;
    $376 = HEAP32[$p >> 2] | 0;
    if ($313) {
      label = 46;
      break;
    } else {
      label = 45;
      break;
    }
   case 45:
    $378 = $376 + 3 | 0;
    HEAP32[$p >> 2] = $378;
    $379 = HEAP8[$376] | 0;
    $380 = $379 & 255;
    $381 = $380 << 16;
    $382 = $376 + 1 | 0;
    $383 = HEAP8[$382] | 0;
    $384 = $383 & 255;
    $385 = $384 << 8;
    $386 = $385 | $381;
    $387 = $376 + 2 | 0;
    $388 = HEAP8[$387] | 0;
    $389 = $388 & 255;
    $390 = $386 | $389;
    $401 = $390;
    label = 47;
    break;
   case 46:
    $392 = $376 + 2 | 0;
    HEAP32[$p >> 2] = $392;
    $393 = HEAP8[$376] | 0;
    $394 = $393 & 255;
    $395 = $394 << 8;
    $396 = $376 + 1 | 0;
    $397 = HEAP8[$396] | 0;
    $398 = $397 & 255;
    $399 = $395 | $398;
    $401 = $399;
    label = 47;
    break;
   case 47:
    $402 = $321 + ($n1_0123 << 4) + 12 | 0;
    HEAP32[$402 >> 2] = $401;
    $403 = $n1_0123 + 1 | 0;
    $exitcond = ($403 | 0) == ($289 | 0);
    if ($exitcond) {
      label = 48;
      break;
    } else {
      $n1_0123 = $403;
      label = 33;
      break;
    }
   case 48:
    _FT_Stream_ExitFrame($stream);
    $404 = _FT_Stream_Pos($stream) | 0;
    $405 = $phy_font + 144 | 0;
    HEAP32[$405 >> 2] = $404;
    HEAP32[$15 >> 2] = 0;
    label = 49;
    break;
   case 49:
    $406 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $406 | 0;
   case 50:
    HEAP32[$error >> 2] = 8;
    label = 48;
    break;
  }
  return 0;
}
function _pfr_aux_name_load($p, $len, $memory, $astring) {
  $p = $p | 0;
  $len = $len | 0;
  $memory = $memory | 0;
  $astring = $astring | 0;
  var $error = 0, $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_len = 0, $_0 = 0, $8 = 0, $n_0 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $or_cond = 0, $16 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $result_0 = 0, $25 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = ($len | 0) == 0;
    if ($1) {
      $_0 = 0;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $len - 1 | 0;
    $4 = $p + $3 | 0;
    $5 = HEAP8[$4] | 0;
    $6 = $5 << 24 >> 24 == 0;
    $_len = $6 ? $3 : $len;
    $_0 = $_len;
    label = 3;
    break;
   case 3:
    $8 = ($_0 | 0) == 0;
    $n_0 = 0;
    label = 4;
    break;
   case 4:
    $10 = $n_0 >>> 0 < $_0 >>> 0;
    if ($10) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $12 = $p + $n_0 | 0;
    $13 = HEAP8[$12] | 0;
    $14 = ($13 & 255) < 32;
    $15 = $13 << 24 >> 24 < 0;
    $or_cond = $14 | $15;
    $16 = $n_0 + 1 | 0;
    if ($or_cond) {
      $result_0 = 0;
      label = 9;
      break;
    } else {
      $n_0 = $16;
      label = 4;
      break;
    }
   case 6:
    if ($8) {
      $result_0 = 0;
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $19 = $_0 + 1 | 0;
    $20 = _ft_mem_alloc($memory, $19, $error) | 0;
    $21 = HEAP32[$error >> 2] | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 8;
      break;
    } else {
      $result_0 = $20;
      label = 9;
      break;
    }
   case 8:
    _memcpy($20 | 0, $p | 0, $_0 | 0);
    $24 = $20 + $_0 | 0;
    HEAP8[$24] = 0;
    $result_0 = $20;
    label = 9;
    break;
   case 9:
    HEAP32[$astring >> 2] = $result_0;
    $25 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $25 | 0;
  }
  return 0;
}
function _pfr_extra_item_load_bitmap_info($p, $limit, $phy_font) {
  $p = $p | 0;
  $limit = $limit | 0;
  $phy_font = $phy_font | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $_lobit = 0, $size1_1 = 0, $35 = 0, $36 = 0, $_lobit66 = 0, $_size1_1 = 0, $37 = 0, $38 = 0, $_lobit67 = 0, $size1_3 = 0, $39 = 0, $40 = 0, $_lobit68 = 0, $_size1_3 = 0, $41 = 0, $_sum = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $_071 = 0, $strike_070 = 0, $n_069 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $_1 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $80 = 0, $_2 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $_3 = 0, $113 = 0, $114 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $_4 = 0, $139 = 0, $140 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $151 = 0, $152 = 0, $153 = 0, $_5 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $exitcond = 0, $159 = 0, $160 = 0, $162 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $phy_font | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $3 = $p + 5 | 0;
    $4 = $3 >>> 0 > $limit >>> 0;
    if ($4) {
      label = 26;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $p + 3 | 0;
    $7 = $p + 4 | 0;
    $8 = HEAP8[$6] | 0;
    $9 = $8 & 255;
    $10 = HEAP8[$7] | 0;
    $11 = $10 & 255;
    $12 = $phy_font + 92 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 + $11 | 0;
    $15 = $phy_font + 96 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $14 >>> 0 > $16 >>> 0;
    if ($17) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $19 = $14 + 3 | 0;
    $20 = $19 & -4;
    $21 = $phy_font + 100 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22;
    $24 = _ft_mem_realloc($2, 36, $13, $20, $23, $error) | 0;
    $25 = $24;
    HEAP32[$21 >> 2] = $25;
    $26 = HEAP32[$error >> 2] | 0;
    $27 = ($26 | 0) == 0;
    if ($27) {
      label = 4;
      break;
    } else {
      label = 25;
      break;
    }
   case 4:
    HEAP32[$15 >> 2] = $20;
    label = 5;
    break;
   case 5:
    $30 = $9 & 1;
    $31 = ($30 | 0) == 0;
    $32 = $30 | 8;
    $33 = $9 & 2;
    $34 = ($33 | 0) == 0;
    $_lobit = $33 >>> 1;
    $size1_1 = $32 + $_lobit | 0;
    $35 = $9 & 4;
    $36 = ($35 | 0) == 0;
    $_lobit66 = $35 >>> 2;
    $_size1_1 = $size1_1 + $_lobit66 | 0;
    $37 = $9 & 8;
    $38 = ($37 | 0) == 0;
    $_lobit67 = $37 >>> 3;
    $size1_3 = $_size1_1 + $_lobit67 | 0;
    $39 = $9 & 16;
    $40 = ($39 | 0) == 0;
    $_lobit68 = $39 >>> 4;
    $_size1_3 = $size1_3 + $_lobit68 | 0;
    $41 = Math_imul($_size1_3, $11);
    $_sum = $41 + 5 | 0;
    $42 = $p + $_sum | 0;
    $43 = $42 >>> 0 > $limit >>> 0;
    if ($43) {
      label = 26;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $45 = $10 << 24 >> 24 == 0;
    if ($45) {
      label = 24;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $46 = $phy_font + 100 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = HEAP32[$12 >> 2] | 0;
    $49 = $47 + ($48 * 36 & -1) | 0;
    $50 = $10 & 255;
    $n_069 = 0;
    $strike_070 = $49;
    $_071 = $3;
    label = 8;
    break;
   case 8:
    if ($31) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $53 = $_071 + 2 | 0;
    $54 = HEAP8[$_071] | 0;
    $55 = $54 & 255;
    $56 = $55 << 8;
    $57 = $_071 + 1 | 0;
    $58 = HEAP8[$57] | 0;
    $59 = $58 & 255;
    $60 = $56 | $59;
    $66 = $60;
    $_1 = $53;
    label = 11;
    break;
   case 10:
    $62 = $_071 + 1 | 0;
    $63 = HEAP8[$_071] | 0;
    $64 = $63 & 255;
    $66 = $64;
    $_1 = $62;
    label = 11;
    break;
   case 11:
    $67 = $strike_070 | 0;
    HEAP32[$67 >> 2] = $66;
    if ($34) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $69 = $_1 + 2 | 0;
    $70 = HEAP8[$_1] | 0;
    $71 = $70 & 255;
    $72 = $71 << 8;
    $73 = $_1 + 1 | 0;
    $74 = HEAP8[$73] | 0;
    $75 = $74 & 255;
    $76 = $72 | $75;
    $82 = $76;
    $_2 = $69;
    label = 14;
    break;
   case 13:
    $78 = $_1 + 1 | 0;
    $79 = HEAP8[$_1] | 0;
    $80 = $79 & 255;
    $82 = $80;
    $_2 = $78;
    label = 14;
    break;
   case 14:
    $83 = $strike_070 + 4 | 0;
    HEAP32[$83 >> 2] = $82;
    $84 = HEAP8[$_2] | 0;
    $85 = $84 & 255;
    $86 = $strike_070 + 8 | 0;
    HEAP32[$86 >> 2] = $85;
    if ($36) {
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $88 = $_2 + 4 | 0;
    $89 = $_2 + 1 | 0;
    $90 = HEAP8[$89] | 0;
    $91 = $90 & 255;
    $92 = $91 << 16;
    $93 = $_2 + 2 | 0;
    $94 = HEAP8[$93] | 0;
    $95 = $94 & 255;
    $96 = $95 << 8;
    $97 = $96 | $92;
    $98 = $_2 + 3 | 0;
    $99 = HEAP8[$98] | 0;
    $100 = $99 & 255;
    $101 = $97 | $100;
    $113 = $101;
    $_3 = $88;
    label = 17;
    break;
   case 16:
    $103 = $_2 + 3 | 0;
    $104 = $_2 + 1 | 0;
    $105 = HEAP8[$104] | 0;
    $106 = $105 & 255;
    $107 = $106 << 8;
    $108 = $_2 + 2 | 0;
    $109 = HEAP8[$108] | 0;
    $110 = $109 & 255;
    $111 = $107 | $110;
    $113 = $111;
    $_3 = $103;
    label = 17;
    break;
   case 17:
    $114 = $strike_070 + 20 | 0;
    HEAP32[$114 >> 2] = $113;
    if ($38) {
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $116 = $_3 + 3 | 0;
    $117 = HEAP8[$_3] | 0;
    $118 = $117 & 255;
    $119 = $118 << 16;
    $120 = $_3 + 1 | 0;
    $121 = HEAP8[$120] | 0;
    $122 = $121 & 255;
    $123 = $122 << 8;
    $124 = $123 | $119;
    $125 = $_3 + 2 | 0;
    $126 = HEAP8[$125] | 0;
    $127 = $126 & 255;
    $128 = $124 | $127;
    $139 = $128;
    $_4 = $116;
    label = 20;
    break;
   case 19:
    $130 = $_3 + 2 | 0;
    $131 = HEAP8[$_3] | 0;
    $132 = $131 & 255;
    $133 = $132 << 8;
    $134 = $_3 + 1 | 0;
    $135 = HEAP8[$134] | 0;
    $136 = $135 & 255;
    $137 = $133 | $136;
    $139 = $137;
    $_4 = $130;
    label = 20;
    break;
   case 20:
    $140 = $strike_070 + 24 | 0;
    HEAP32[$140 >> 2] = $139;
    if ($40) {
      label = 22;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $142 = $_4 + 2 | 0;
    $143 = HEAP8[$_4] | 0;
    $144 = $143 & 255;
    $145 = $144 << 8;
    $146 = $_4 + 1 | 0;
    $147 = HEAP8[$146] | 0;
    $148 = $147 & 255;
    $149 = $145 | $148;
    $155 = $149;
    $_5 = $142;
    label = 23;
    break;
   case 22:
    $151 = $_4 + 1 | 0;
    $152 = HEAP8[$_4] | 0;
    $153 = $152 & 255;
    $155 = $153;
    $_5 = $151;
    label = 23;
    break;
   case 23:
    $156 = $strike_070 + 28 | 0;
    HEAP32[$156 >> 2] = $155;
    $157 = $n_069 + 1 | 0;
    $158 = $strike_070 + 36 | 0;
    $exitcond = ($157 | 0) == ($50 | 0);
    if ($exitcond) {
      label = 24;
      break;
    } else {
      $n_069 = $157;
      $strike_070 = $158;
      $_071 = $_5;
      label = 8;
      break;
    }
   case 24:
    $159 = HEAP32[$12 >> 2] | 0;
    $160 = $159 + $11 | 0;
    HEAP32[$12 >> 2] = $160;
    label = 25;
    break;
   case 25:
    $162 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $162 | 0;
   case 26:
    HEAP32[$error >> 2] = 8;
    label = 25;
    break;
  }
  return 0;
}
function _pfr_extra_item_load_font_id($p, $limit, $phy_font) {
  $p = $p | 0;
  $limit = $limit | 0;
  $phy_font = $phy_font | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $18 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $limit;
    $2 = $p;
    $3 = $1 - $2 | 0;
    $4 = $phy_font + 80 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $8 = $phy_font | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $3 + 1 | 0;
    $11 = _ft_mem_alloc($9, $10, $error) | 0;
    HEAP32[$4 >> 2] = $11;
    $12 = HEAP32[$error >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    _memcpy($11 | 0, $p | 0, $3 | 0);
    $15 = HEAP32[$4 >> 2] | 0;
    $16 = $15 + $3 | 0;
    HEAP8[$16] = 0;
    label = 4;
    break;
   case 4:
    $18 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $18 | 0;
  }
  return 0;
}
function _ps_parser_done($parser) {
  $parser = $parser | 0;
  return;
}
function _pfr_extra_item_load_stem_snaps($p, $limit, $phy_font) {
  $p = $p | 0;
  $limit = $limit | 0;
  $phy_font = $phy_font | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $_sum21 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $_024 = 0, $snaps_023 = 0, $count_022 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $phy_font | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $phy_font + 76 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      label = 7;
      break;
    }
   case 2:
    $7 = $p + 1 | 0;
    $8 = $7 >>> 0 > $limit >>> 0;
    if ($8) {
      label = 8;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $10 = HEAP8[$p] | 0;
    $11 = $10 & 255;
    $12 = $11 & 15;
    $13 = $11 >>> 4;
    $14 = $12 + $13 | 0;
    $15 = $14 << 1;
    $_sum21 = $15 | 1;
    $16 = $p + $_sum21 | 0;
    $17 = $16 >>> 0 > $limit >>> 0;
    if ($17) {
      label = 8;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $19 = _ft_mem_realloc($2, 4, 0, $14, 0, $error) | 0;
    $20 = $19;
    $21 = HEAP32[$error >> 2] | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    HEAP32[$3 >> 2] = $20;
    $24 = $20 + ($12 << 2) | 0;
    $25 = $phy_font + 64 | 0;
    HEAP32[$25 >> 2] = $24;
    $26 = ($14 | 0) == 0;
    if ($26) {
      label = 7;
      break;
    } else {
      $count_022 = $14;
      $snaps_023 = $20;
      $_024 = $7;
      label = 6;
      break;
    }
   case 6:
    $27 = $_024 + 2 | 0;
    $28 = HEAP8[$_024] | 0;
    $29 = $28 & 255;
    $30 = $29 << 8;
    $31 = $_024 + 1 | 0;
    $32 = HEAP8[$31] | 0;
    $33 = $32 & 255;
    $34 = $30 | $33;
    $35 = $34 << 16 >> 16;
    HEAP32[$snaps_023 >> 2] = $35;
    $36 = $count_022 - 1 | 0;
    $37 = $snaps_023 + 4 | 0;
    $38 = ($36 | 0) == 0;
    if ($38) {
      label = 7;
      break;
    } else {
      $count_022 = $36;
      $snaps_023 = $37;
      $_024 = $27;
      label = 6;
      break;
    }
   case 7:
    $39 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $39 | 0;
   case 8:
    HEAP32[$error >> 2] = 8;
    label = 7;
    break;
  }
  return 0;
}
function _pfr_extra_item_load_kerning_pairs($p, $limit, $phy_font) {
  $p = $p | 0;
  $limit = $limit | 0;
  $phy_font = $phy_font | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $_sum = 0, $54 = 0, $55 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $_sum71 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $_sum72 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $_sum74 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $_sum75 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $_sum67 = 0, $122 = 0, $_sum68 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $143 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $phy_font | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _ft_mem_alloc($2, 24, $error) | 0;
    $4 = $3;
    $5 = HEAP32[$error >> 2] | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 14;
      break;
    }
   case 2:
    $8 = $p + 4 | 0;
    $9 = $8 >>> 0 > $limit >>> 0;
    if ($9) {
      label = 15;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = HEAP8[$p] | 0;
    $12 = $3 + 4 | 0;
    HEAP8[$12] = $11;
    $13 = $p + 3 | 0;
    $14 = $p + 1 | 0;
    $15 = HEAP8[$14] | 0;
    $16 = $15 & 255;
    $17 = $16 << 8;
    $18 = $p + 2 | 0;
    $19 = HEAP8[$18] | 0;
    $20 = $19 & 255;
    $21 = $17 | $20;
    $22 = $3 + 6 | 0;
    $23 = $22;
    HEAP16[$23 >> 1] = $21;
    $24 = HEAP8[$13] | 0;
    $25 = $3 + 5 | 0;
    HEAP8[$25] = $24;
    $26 = $phy_font + 4 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $phy_font + 148 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $8;
    $31 = $29;
    $32 = $27 + $30 | 0;
    $33 = $32 - $31 | 0;
    $34 = $3 + 12 | 0;
    $35 = $34;
    HEAP32[$35 >> 2] = $33;
    $36 = $3 + 8 | 0;
    $37 = $36;
    HEAP32[$37 >> 2] = 3;
    $38 = HEAP8[$25] | 0;
    $39 = $38 & 1;
    $40 = $39 << 24 >> 24 == 0;
    if ($40) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    HEAP32[$37 >> 2] = 5;
    label = 5;
    break;
   case 5:
    $43 = HEAP8[$25] | 0;
    $44 = $43 & 2;
    $45 = $44 << 24 >> 24 == 0;
    if ($45) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $47 = HEAP32[$37 >> 2] | 0;
    $48 = $47 + 1 | 0;
    HEAP32[$37 >> 2] = $48;
    label = 7;
    break;
   case 7:
    $50 = HEAP8[$12] | 0;
    $51 = $50 & 255;
    $52 = HEAP32[$37 >> 2] | 0;
    $53 = Math_imul($51, $52);
    $_sum = $53 + 4 | 0;
    $54 = $p + $_sum | 0;
    $55 = $54 >>> 0 > $limit >>> 0;
    if ($55) {
      label = 15;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $57 = $50 << 24 >> 24 == 0;
    if ($57) {
      label = 13;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $59 = HEAP8[$25] | 0;
    $60 = $59 & 1;
    $61 = $60 << 24 >> 24 == 0;
    if ($61) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $63 = HEAP8[$8] | 0;
    $64 = $63 & 255;
    $65 = $64 << 8;
    $66 = $p + 5 | 0;
    $67 = HEAP8[$66] | 0;
    $68 = $67 & 255;
    $69 = $65 | $68;
    $70 = $p + 6 | 0;
    $71 = HEAP8[$70] | 0;
    $72 = $71 & 255;
    $73 = $72 << 8;
    $74 = $p + 7 | 0;
    $75 = HEAP8[$74] | 0;
    $76 = $75 & 255;
    $77 = $73 | $76;
    $78 = $69 << 16;
    $79 = $77 | $78;
    $80 = $3 + 16 | 0;
    $81 = $80;
    HEAP32[$81 >> 2] = $79;
    $82 = HEAP32[$37 >> 2] | 0;
    $83 = HEAP8[$12] | 0;
    $84 = $83 & 255;
    $85 = $84 - 1 | 0;
    $86 = Math_imul($85, $82);
    $_sum71 = $86 + 4 | 0;
    $87 = $p + $_sum71 | 0;
    $88 = HEAP8[$87] | 0;
    $89 = $88 & 255;
    $90 = $89 << 8;
    $_sum72 = $86 + 5 | 0;
    $91 = $p + $_sum72 | 0;
    $92 = HEAP8[$91] | 0;
    $93 = $92 & 255;
    $94 = $90 | $93;
    $_sum74 = $86 + 6 | 0;
    $95 = $p + $_sum74 | 0;
    $96 = HEAP8[$95] | 0;
    $97 = $96 & 255;
    $98 = $97 << 8;
    $_sum75 = $86 + 7 | 0;
    $99 = $p + $_sum75 | 0;
    $100 = HEAP8[$99] | 0;
    $101 = $100 & 255;
    $102 = $98 | $101;
    $103 = $94 << 16;
    $104 = $102 | $103;
    $105 = $3 + 20 | 0;
    $106 = $105;
    HEAP32[$106 >> 2] = $104;
    label = 12;
    break;
   case 11:
    $108 = $p + 5 | 0;
    $109 = HEAP8[$8] | 0;
    $110 = $109 & 255;
    $111 = HEAP8[$108] | 0;
    $112 = $110 << 16;
    $113 = $111 & 255;
    $114 = $112 | $113;
    $115 = $3 + 16 | 0;
    $116 = $115;
    HEAP32[$116 >> 2] = $114;
    $117 = HEAP32[$37 >> 2] | 0;
    $118 = HEAP8[$12] | 0;
    $119 = $118 & 255;
    $120 = $119 - 1 | 0;
    $121 = Math_imul($120, $117);
    $_sum67 = $121 + 4 | 0;
    $122 = $p + $_sum67 | 0;
    $_sum68 = $121 + 5 | 0;
    $123 = $p + $_sum68 | 0;
    $124 = HEAP8[$122] | 0;
    $125 = $124 & 255;
    $126 = HEAP8[$123] | 0;
    $127 = $125 << 16;
    $128 = $126 & 255;
    $129 = $127 | $128;
    $130 = $3 + 20 | 0;
    $131 = $130;
    HEAP32[$131 >> 2] = $129;
    label = 12;
    break;
   case 12:
    $133 = $3;
    HEAP32[$133 >> 2] = 0;
    $134 = $phy_font + 140 | 0;
    $135 = HEAP32[$134 >> 2] | 0;
    HEAP32[$135 >> 2] = $4;
    HEAP32[$134 >> 2] = $133;
    $136 = HEAP8[$12] | 0;
    $137 = $136 & 255;
    $138 = $phy_font + 132 | 0;
    $139 = HEAP32[$138 >> 2] | 0;
    $140 = $139 + $137 | 0;
    HEAP32[$138 >> 2] = $140;
    label = 14;
    break;
   case 13:
    _ft_mem_free($2, $3);
    label = 14;
    break;
   case 14:
    $143 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $143 | 0;
   case 15:
    _ft_mem_free($2, $3);
    HEAP32[$error >> 2] = 8;
    label = 14;
    break;
  }
  return 0;
}
function _ps_table_new($table, $count, $memory) {
  $table = $table | 0;
  $count = $count | 0;
  $memory = $memory | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $_pr = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $table + 32 | 0;
    HEAP32[$1 >> 2] = $memory;
    $2 = _ft_mem_realloc($memory, 4, 0, $count, 0, $error) | 0;
    $3 = $2;
    $4 = $table + 24 | 0;
    HEAP32[$4 >> 2] = $3;
    $5 = HEAP32[$error >> 2] | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $8 = _ft_mem_realloc($memory, 4, 0, $count, 0, $error) | 0;
    $9 = $8;
    $10 = $table + 28 | 0;
    HEAP32[$10 >> 2] = $9;
    $11 = HEAP32[$error >> 2] | 0;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $14 = $table + 16 | 0;
    HEAP32[$14 >> 2] = $count;
    $15 = $table + 12 | 0;
    HEAP32[$15 >> 2] = -559038737;
    $16 = $table + 20 | 0;
    HEAP32[$16 >> 2] = 0;
    $17 = $table | 0;
    HEAP32[$17 >> 2] = 0;
    $18 = $table + 8 | 0;
    HEAP32[$18 >> 2] = 0;
    $19 = $table + 4 | 0;
    HEAP32[$19 >> 2] = 0;
    $20 = $table + 36 | 0;
    $21 = $20;
    _memcpy($21 | 0, 5250120, 16);
    $_pr = HEAP32[$error >> 2] | 0;
    $22 = ($_pr | 0) == 0;
    if ($22) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $23 = HEAP32[$4 >> 2] | 0;
    $24 = $23;
    _ft_mem_free($memory, $24);
    HEAP32[$4 >> 2] = 0;
    label = 5;
    break;
   case 5:
    $26 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $26 | 0;
  }
  return 0;
}
function _ps_table_done($table) {
  $table = $table | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $table + 32 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $table | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $table + 4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = _ft_mem_alloc($2, $8, $error) | 0;
    HEAP32[$3 >> 2] = $9;
    $10 = HEAP32[$error >> 2] | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $13 = HEAP32[$7 >> 2] | 0;
    _memcpy($9 | 0, $4 | 0, $13 | 0);
    _shift_elements($table, $4);
    $14 = HEAP32[$7 >> 2] | 0;
    $15 = $table + 8 | 0;
    HEAP32[$15 >> 2] = $14;
    _ft_mem_free($2, $4);
    label = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
  }
}
function _ps_table_add($table, $idx, $object, $length) {
  $table = $table | 0;
  $idx = $idx | 0;
  $object = $object | 0;
  $length = $length | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $or_cond = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $_ = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $new_size_037 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $new_size_0_lcssa = 0, $32 = 0, $33 = 0, $35 = 0, $37 = 0, $38 = 0, $_036 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($idx | 0) < 0;
    if ($1) {
      $_0 = 6;
      label = 11;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $table + 16 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) <= ($idx | 0);
    $6 = ($length | 0) < 0;
    $or_cond = $5 | $6;
    if ($or_cond) {
      $_0 = 6;
      label = 11;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $8 = $table + 4 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 + $length | 0;
    $11 = $table + 8 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $10 >>> 0 > $12 >>> 0;
    if ($13) {
      label = 4;
      break;
    } else {
      $_036 = $object;
      label = 10;
      break;
    }
   case 4:
    $15 = $table | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $object;
    $18 = $16;
    $19 = $17 - $18 | 0;
    $20 = $19 >>> 0 < $12 >>> 0;
    $_ = $20 ? $19 : -1;
    $21 = HEAP32[$8 >> 2] | 0;
    $22 = $21 + $length | 0;
    $23 = $12 >>> 0 < $22 >>> 0;
    if ($23) {
      label = 5;
      break;
    } else {
      $new_size_0_lcssa = $12;
      label = 7;
      break;
    }
   case 5:
    $24 = HEAP32[$8 >> 2] | 0;
    $25 = $24 + $length | 0;
    $new_size_037 = $12;
    label = 6;
    break;
   case 6:
    $27 = $new_size_037 >>> 2;
    $28 = $new_size_037 + 1024 | 0;
    $29 = $28 + $27 | 0;
    $30 = $29 & -1024;
    $31 = $30 >>> 0 < $25 >>> 0;
    if ($31) {
      $new_size_037 = $30;
      label = 6;
      break;
    } else {
      $new_size_0_lcssa = $30;
      label = 7;
      break;
    }
   case 7:
    $32 = _reallocate_t1_table($table, $new_size_0_lcssa) | 0;
    $33 = ($32 | 0) == 0;
    if ($33) {
      label = 8;
      break;
    } else {
      $_0 = $32;
      label = 11;
      break;
    }
   case 8:
    $35 = ($_ | 0) > -1;
    if ($35) {
      label = 9;
      break;
    } else {
      $_036 = $object;
      label = 10;
      break;
    }
   case 9:
    $37 = HEAP32[$15 >> 2] | 0;
    $38 = $37 + $_ | 0;
    $_036 = $38;
    label = 10;
    break;
   case 10:
    $40 = $table | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = HEAP32[$8 >> 2] | 0;
    $43 = $41 + $42 | 0;
    $44 = $table + 24 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = $45 + ($idx << 2) | 0;
    HEAP32[$46 >> 2] = $43;
    $47 = $table + 28 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $48 + ($idx << 2) | 0;
    HEAP32[$49 >> 2] = $length;
    $50 = HEAP32[$40 >> 2] | 0;
    $51 = HEAP32[$8 >> 2] | 0;
    $52 = $50 + $51 | 0;
    _memcpy($52 | 0, $_036 | 0, $length | 0);
    $53 = HEAP32[$8 >> 2] | 0;
    $54 = $53 + $length | 0;
    HEAP32[$8 >> 2] = $54;
    $_0 = 0;
    label = 11;
    break;
   case 11:
    return $_0 | 0;
  }
  return 0;
}
function _ps_table_release($table) {
  $table = $table | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table + 32 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $table + 12 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == -559038737;
    if ($5) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $7 = $table | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    _ft_mem_free($2, $8);
    HEAP32[$7 >> 2] = 0;
    $9 = $table + 24 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10;
    _ft_mem_free($2, $11);
    HEAP32[$9 >> 2] = 0;
    $12 = $table + 28 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13;
    _ft_mem_free($2, $14);
    HEAP32[$12 >> 2] = 0;
    HEAP32[$3 >> 2] = 0;
    label = 3;
    break;
   case 3:
    return;
  }
}
function _ps_parser_init($parser, $base, $limit, $memory) {
  $parser = $parser | 0;
  $base = $base | 0;
  $limit = $limit | 0;
  $memory = $memory | 0;
  HEAP32[$parser + 12 >> 2] = 0;
  HEAP32[$parser + 4 >> 2] = $base;
  HEAP32[$parser + 8 >> 2] = $limit;
  HEAP32[$parser >> 2] = $base;
  HEAP32[$parser + 16 >> 2] = $memory;
  _memcpy($parser + 20 | 0, 5250136, 52);
  return;
}
function _ps_parser_skip_spaces($parser) {
  $parser = $parser | 0;
  _skip_spaces($parser | 0, HEAP32[$parser + 8 >> 2] | 0);
  return;
}
function _ps_parser_skip_PS_token($parser) {
  $parser = $parser | 0;
  var $cur = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $15 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $error_0 = 0, $43 = 0, $44 = 0, $45 = 0, $_error_0 = 0, $46 = 0, $47 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $cur = __stackBase__ | 0;
    $1 = $parser | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$cur >> 2] = $2;
    $3 = $parser + 8 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    _skip_spaces($cur, $4);
    $5 = HEAP32[$cur >> 2] | 0;
    $6 = $5 >>> 0 < $4 >>> 0;
    if ($6) {
      label = 2;
      break;
    } else {
      $error_0 = 0;
      label = 17;
      break;
    }
   case 2:
    $8 = HEAP8[$5] | 0;
    if (($8 << 24 >> 24 | 0) == 91 | ($8 << 24 >> 24 | 0) == 93) {
      label = 3;
      break;
    } else if (($8 << 24 >> 24 | 0) == 123) {
      label = 4;
      break;
    } else if (($8 << 24 >> 24 | 0) == 40) {
      label = 5;
      break;
    } else if (($8 << 24 >> 24 | 0) == 60) {
      label = 6;
      break;
    } else if (($8 << 24 >> 24 | 0) == 62) {
      label = 10;
      break;
    } else if (($8 << 24 >> 24 | 0) == 47) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 3:
    $10 = HEAP32[$cur >> 2] | 0;
    $11 = $10 + 1 | 0;
    HEAP32[$cur >> 2] = $11;
    $error_0 = 0;
    label = 17;
    break;
   case 4:
    $13 = _skip_procedure($cur, $4) | 0;
    $error_0 = $13;
    label = 17;
    break;
   case 5:
    $15 = _skip_literal_string($cur, $4) | 0;
    $error_0 = $15;
    label = 17;
    break;
   case 6:
    $17 = $5 + 1 | 0;
    $18 = $17 >>> 0 < $4 >>> 0;
    if ($18) {
      label = 7;
      break;
    } else {
      label = 9;
      break;
    }
   case 7:
    $20 = HEAP8[$17] | 0;
    $21 = $20 << 24 >> 24 == 60;
    if ($21) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $23 = $5 + 2 | 0;
    HEAP32[$cur >> 2] = $23;
    $error_0 = 0;
    label = 17;
    break;
   case 9:
    $25 = _skip_string($cur, $4) | 0;
    $error_0 = $25;
    label = 17;
    break;
   case 10:
    $27 = $5 + 1 | 0;
    HEAP32[$cur >> 2] = $27;
    $28 = $27 >>> 0 < $4 >>> 0;
    if ($28) {
      label = 11;
      break;
    } else {
      $error_0 = 3;
      label = 17;
      break;
    }
   case 11:
    $30 = HEAP8[$27] | 0;
    $31 = $30 << 24 >> 24 == 62;
    if ($31) {
      label = 12;
      break;
    } else {
      $error_0 = 3;
      label = 17;
      break;
    }
   case 12:
    $33 = $5 + 2 | 0;
    HEAP32[$cur >> 2] = $33;
    $error_0 = 0;
    label = 17;
    break;
   case 13:
    $35 = $5 + 1 | 0;
    HEAP32[$cur >> 2] = $35;
    label = 14;
    break;
   case 14:
    $36 = HEAP32[$cur >> 2] | 0;
    $37 = $36 >>> 0 < $4 >>> 0;
    if ($37) {
      $38 = $36;
      label = 15;
      break;
    } else {
      $error_0 = 0;
      label = 17;
      break;
    }
   case 15:
    $39 = HEAP8[$38] | 0;
    if (($39 << 24 >> 24 | 0) == 32 | ($39 << 24 >> 24 | 0) == 13 | ($39 << 24 >> 24 | 0) == 10 | ($39 << 24 >> 24 | 0) == 9 | ($39 << 24 >> 24 | 0) == 12 | ($39 << 24 >> 24 | 0) == 0 | ($39 << 24 >> 24 | 0) == 47 | ($39 << 24 >> 24 | 0) == 40 | ($39 << 24 >> 24 | 0) == 41 | ($39 << 24 >> 24 | 0) == 60 | ($39 << 24 >> 24 | 0) == 62 | ($39 << 24 >> 24 | 0) == 91 | ($39 << 24 >> 24 | 0) == 93 | ($39 << 24 >> 24 | 0) == 123 | ($39 << 24 >> 24 | 0) == 125 | ($39 << 24 >> 24 | 0) == 37) {
      $error_0 = 0;
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $41 = $38 + 1 | 0;
    HEAP32[$cur >> 2] = $41;
    $42 = $41 >>> 0 < $4 >>> 0;
    if ($42) {
      $38 = $41;
      label = 15;
      break;
    } else {
      $error_0 = 0;
      label = 17;
      break;
    }
   case 17:
    $43 = HEAP32[$cur >> 2] | 0;
    $44 = HEAP32[$1 >> 2] | 0;
    $45 = ($43 | 0) == ($44 | 0);
    $_error_0 = $45 ? 3 : $error_0;
    $46 = $parser + 12 | 0;
    HEAP32[$46 >> 2] = $_error_0;
    $47 = HEAP32[$cur >> 2] | 0;
    HEAP32[$1 >> 2] = $47;
    STACKTOP = __stackBase__;
    return;
  }
}
function _ps_parser_to_int($parser) {
  $parser = $parser | 0;
  _ps_parser_skip_spaces($parser);
  return _PS_Conv_ToInt($parser | 0, HEAP32[$parser + 8 >> 2] | 0) | 0;
}
function _ps_parser_to_fixed($parser, $power_ten) {
  $parser = $parser | 0;
  $power_ten = $power_ten | 0;
  _ps_parser_skip_spaces($parser);
  return _PS_Conv_ToFixed($parser | 0, HEAP32[$parser + 8 >> 2] | 0, $power_ten) | 0;
}
function _ps_parser_to_bytes($parser, $bytes, $max_bytes, $pnum_bytes, $delimiters) {
  $parser = $parser | 0;
  $bytes = $bytes | 0;
  $max_bytes = $max_bytes | 0;
  $pnum_bytes = $pnum_bytes | 0;
  $delimiters = $delimiters | 0;
  var $cur = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $cur = __stackBase__ | 0;
    _ps_parser_skip_spaces($parser);
    $1 = $parser | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$cur >> 2] = $2;
    $3 = $parser + 8 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 >>> 0 < $4 >>> 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $error_0 = 0;
      label = 10;
      break;
    }
   case 2:
    $7 = $delimiters << 24 >> 24 != 0;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 8;
      break;
    }
   case 3:
    $9 = HEAP8[$2] | 0;
    $10 = $9 << 24 >> 24 == 60;
    if ($10) {
      label = 4;
      break;
    } else {
      $error_0 = 3;
      label = 10;
      break;
    }
   case 4:
    $12 = $2 + 1 | 0;
    HEAP32[$cur >> 2] = $12;
    $13 = HEAP32[$3 >> 2] | 0;
    $14 = _PS_Conv_ASCIIHexDecode($cur, $13, $bytes, $max_bytes) | 0;
    HEAP32[$pnum_bytes >> 2] = $14;
    if ($7) {
      label = 5;
      break;
    } else {
      label = 9;
      break;
    }
   case 5:
    $16 = HEAP32[$cur >> 2] | 0;
    $17 = HEAP32[$3 >> 2] | 0;
    $18 = $16 >>> 0 < $17 >>> 0;
    if ($18) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $20 = HEAP8[$16] | 0;
    $21 = $20 << 24 >> 24 == 62;
    if ($21) {
      label = 7;
      break;
    } else {
      $error_0 = 3;
      label = 10;
      break;
    }
   case 7:
    $23 = HEAP32[$cur >> 2] | 0;
    $24 = $23 + 1 | 0;
    HEAP32[$cur >> 2] = $24;
    label = 9;
    break;
   case 8:
    $25 = _PS_Conv_ASCIIHexDecode($cur, $4, $bytes, $max_bytes) | 0;
    HEAP32[$pnum_bytes >> 2] = $25;
    label = 9;
    break;
   case 9:
    $27 = HEAP32[$cur >> 2] | 0;
    HEAP32[$1 >> 2] = $27;
    $error_0 = 0;
    label = 10;
    break;
   case 10:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _ps_parser_to_coord_array($parser, $max_coords, $coords) {
  $parser = $parser | 0;
  $max_coords = $max_coords | 0;
  $coords = $coords | 0;
  _ps_parser_skip_spaces($parser);
  return _ps_tocoordarray($parser | 0, HEAP32[$parser + 8 >> 2] | 0, $max_coords, $coords) | 0;
}
function _ps_parser_to_fixed_array($parser, $max_values, $values, $power_ten) {
  $parser = $parser | 0;
  $max_values = $max_values | 0;
  $values = $values | 0;
  $power_ten = $power_ten | 0;
  _ps_parser_skip_spaces($parser);
  return _ps_tofixedarray($parser | 0, HEAP32[$parser + 8 >> 2] | 0, $max_values, $values, $power_ten) | 0;
}
function _ps_parser_to_token($parser, $token) {
  $parser = $parser | 0;
  $token = $token | 0;
  var $cur = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $storemerge39 = 0, $28 = 0, $29 = 0, $storemerge41 = 0, $embed_040 = 0, $31 = 0, $32 = 0, $34 = 0, $36 = 0, $38 = 0, $39 = 0, $41 = 0, $embed_1 = 0, $43 = 0, $storemerge = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $_pr = 0, $55 = 0, $56 = 0, $59 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $cur = __stackBase__ | 0;
    $1 = $token + 8 | 0;
    HEAP32[$1 >> 2] = 0;
    $2 = $token | 0;
    HEAP32[$2 >> 2] = 0;
    $3 = $token + 4 | 0;
    HEAP32[$3 >> 2] = 0;
    _ps_parser_skip_spaces($parser);
    $4 = $parser | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    HEAP32[$cur >> 2] = $5;
    $6 = $parser + 8 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $5 >>> 0 < $7 >>> 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 21;
      break;
    }
   case 2:
    $10 = HEAP8[$5] | 0;
    $11 = $10 & 255;
    if (($11 | 0) == 40) {
      label = 3;
      break;
    } else if (($11 | 0) == 123) {
      label = 5;
      break;
    } else if (($11 | 0) == 91) {
      label = 7;
      break;
    } else {
      label = 15;
      break;
    }
   case 3:
    HEAP32[$1 >> 2] = 2;
    $13 = HEAP32[$cur >> 2] | 0;
    HEAP32[$2 >> 2] = $13;
    $14 = _skip_literal_string($cur, $7) | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 4;
      break;
    } else {
      label = 17;
      break;
    }
   case 4:
    $17 = HEAP32[$cur >> 2] | 0;
    HEAP32[$3 >> 2] = $17;
    $55 = $17;
    label = 18;
    break;
   case 5:
    HEAP32[$1 >> 2] = 3;
    $19 = HEAP32[$cur >> 2] | 0;
    HEAP32[$2 >> 2] = $19;
    $20 = _skip_procedure($cur, $7) | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 6;
      break;
    } else {
      label = 17;
      break;
    }
   case 6:
    $23 = HEAP32[$cur >> 2] | 0;
    HEAP32[$3 >> 2] = $23;
    $55 = $23;
    label = 18;
    break;
   case 7:
    HEAP32[$1 >> 2] = 3;
    $25 = HEAP32[$cur >> 2] | 0;
    $26 = $25 + 1 | 0;
    HEAP32[$cur >> 2] = $26;
    HEAP32[$2 >> 2] = $25;
    $27 = HEAP32[$cur >> 2] | 0;
    HEAP32[$4 >> 2] = $27;
    _ps_parser_skip_spaces($parser);
    $storemerge39 = HEAP32[$4 >> 2] | 0;
    HEAP32[$cur >> 2] = $storemerge39;
    $28 = $storemerge39 >>> 0 < $7 >>> 0;
    if ($28) {
      label = 8;
      break;
    } else {
      label = 17;
      break;
    }
   case 8:
    $29 = $parser + 12 | 0;
    $embed_040 = 1;
    $storemerge41 = $storemerge39;
    label = 9;
    break;
   case 9:
    $31 = HEAP32[$29 >> 2] | 0;
    $32 = ($31 | 0) == 0;
    if ($32) {
      label = 10;
      break;
    } else {
      label = 17;
      break;
    }
   case 10:
    $34 = HEAP8[$storemerge41] | 0;
    if (($34 << 24 >> 24 | 0) == 91) {
      label = 11;
      break;
    } else if (($34 << 24 >> 24 | 0) == 93) {
      label = 12;
      break;
    } else {
      $embed_1 = $embed_040;
      label = 14;
      break;
    }
   case 11:
    $36 = $embed_040 + 1 | 0;
    $embed_1 = $36;
    label = 14;
    break;
   case 12:
    $38 = $embed_040 - 1 | 0;
    $39 = ($38 | 0) < 1;
    if ($39) {
      label = 13;
      break;
    } else {
      $embed_1 = $38;
      label = 14;
      break;
    }
   case 13:
    $41 = $storemerge41 + 1 | 0;
    HEAP32[$cur >> 2] = $41;
    HEAP32[$3 >> 2] = $41;
    $55 = $41;
    label = 18;
    break;
   case 14:
    $43 = HEAP32[$cur >> 2] | 0;
    HEAP32[$4 >> 2] = $43;
    _ps_parser_skip_PS_token($parser);
    _ps_parser_skip_spaces($parser);
    $storemerge = HEAP32[$4 >> 2] | 0;
    HEAP32[$cur >> 2] = $storemerge;
    $44 = $storemerge >>> 0 < $7 >>> 0;
    if ($44) {
      $embed_040 = $embed_1;
      $storemerge41 = $storemerge;
      label = 9;
      break;
    } else {
      label = 17;
      break;
    }
   case 15:
    HEAP32[$2 >> 2] = $5;
    $46 = HEAP32[$cur >> 2] | 0;
    $47 = HEAP8[$46] | 0;
    $48 = $47 << 24 >> 24 == 47;
    $49 = $48 ? 4 : 1;
    HEAP32[$1 >> 2] = $49;
    _ps_parser_skip_PS_token($parser);
    $50 = HEAP32[$4 >> 2] | 0;
    HEAP32[$cur >> 2] = $50;
    $51 = $parser + 12 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = ($52 | 0) == 0;
    if ($53) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    HEAP32[$3 >> 2] = $50;
    $55 = $50;
    label = 18;
    break;
   case 17:
    $_pr = HEAP32[$3 >> 2] | 0;
    $55 = $_pr;
    label = 18;
    break;
   case 18:
    $56 = ($55 | 0) == 0;
    if ($56) {
      label = 19;
      break;
    } else {
      label = 20;
      break;
    }
   case 19:
    HEAP32[$2 >> 2] = 0;
    HEAP32[$1 >> 2] = 0;
    label = 20;
    break;
   case 20:
    $59 = HEAP32[$cur >> 2] | 0;
    HEAP32[$4 >> 2] = $59;
    label = 21;
    break;
   case 21:
    STACKTOP = __stackBase__;
    return;
  }
}
function _ps_parser_to_token_array($parser, $tokens, $max_tokens, $pnum_tokens) {
  $parser = $parser | 0;
  $tokens = $tokens | 0;
  $max_tokens = $max_tokens | 0;
  $pnum_tokens = $pnum_tokens | 0;
  var $master = 0, $token = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $cur_020 = 0, $22 = 0, $23 = 0, $25 = 0, $or_cond = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $cur_0_lcssa = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 24 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $master = __stackBase__ | 0;
    $token = __stackBase__ + 12 | 0;
    HEAP32[$pnum_tokens >> 2] = -1;
    _ps_parser_to_token($parser, $master);
    $1 = $master + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 3;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 9;
      break;
    }
   case 2:
    $5 = $parser | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $parser + 8 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $tokens + ($max_tokens * 12 & -1) | 0;
    $10 = $master | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 + 1 | 0;
    HEAP32[$5 >> 2] = $12;
    $13 = $master + 4 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 - 1 | 0;
    HEAP32[$7 >> 2] = $15;
    $16 = HEAP32[$5 >> 2] | 0;
    $17 = $16 >>> 0 < $15 >>> 0;
    if ($17) {
      label = 3;
      break;
    } else {
      $cur_0_lcssa = $tokens;
      label = 8;
      break;
    }
   case 3:
    $18 = $token + 8 | 0;
    $19 = ($tokens | 0) != 0;
    $20 = $token;
    $cur_020 = $tokens;
    label = 4;
    break;
   case 4:
    _ps_parser_to_token($parser, $token);
    $22 = HEAP32[$18 >> 2] | 0;
    $23 = ($22 | 0) == 0;
    if ($23) {
      $cur_0_lcssa = $cur_020;
      label = 8;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $25 = $cur_020 >>> 0 < $9 >>> 0;
    $or_cond = $19 & $25;
    if ($or_cond) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $27 = $cur_020;
    _memcpy($27 | 0, $20 | 0, 12);
    label = 7;
    break;
   case 7:
    $29 = $cur_020 + 12 | 0;
    $30 = HEAP32[$5 >> 2] | 0;
    $31 = HEAP32[$7 >> 2] | 0;
    $32 = $30 >>> 0 < $31 >>> 0;
    if ($32) {
      $cur_020 = $29;
      label = 4;
      break;
    } else {
      $cur_0_lcssa = $29;
      label = 8;
      break;
    }
   case 8:
    $33 = $cur_0_lcssa;
    $34 = $tokens;
    $35 = $33 - $34 | 0;
    $36 = ($35 | 0) / 12 & -1;
    HEAP32[$pnum_tokens >> 2] = $36;
    HEAP32[$5 >> 2] = $6;
    HEAP32[$7 >> 2] = $8;
    label = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
  }
}
function _t1_builder_close_contour($builder) {
  $builder = $builder | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $_sum = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $builder + 20 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 13;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 | 0;
    $6 = HEAP16[$5 >> 1] | 0;
    $7 = $6 << 16 >> 16 < 2;
    if ($7) {
      $18 = 0;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = $6 << 16 >> 16;
    $10 = $9 - 2 | 0;
    $11 = $2 + 12 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + ($10 << 1) | 0;
    $14 = HEAP16[$13 >> 1] | 0;
    $15 = $14 << 16 >> 16;
    $16 = $15 + 1 | 0;
    $18 = $16;
    label = 4;
    break;
   case 4:
    $19 = $2 + 2 | 0;
    $20 = HEAP16[$19 >> 1] | 0;
    $21 = $20 << 16 >> 16 > 1;
    if ($21) {
      label = 5;
      break;
    } else {
      label = 9;
      break;
    }
   case 5:
    $23 = $20 << 16 >> 16;
    $24 = $2 + 4 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $_sum = $23 - 1 | 0;
    $26 = $2 + 8 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $27 + $_sum | 0;
    $29 = $25 + ($18 << 3) | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $25 + ($_sum << 3) | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = ($30 | 0) == ($32 | 0);
    if ($33) {
      label = 6;
      break;
    } else {
      label = 9;
      break;
    }
   case 6:
    $35 = $25 + ($18 << 3) + 4 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $25 + ($_sum << 3) + 4 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = ($36 | 0) == ($38 | 0);
    if ($39) {
      label = 7;
      break;
    } else {
      label = 9;
      break;
    }
   case 7:
    $41 = HEAP8[$28] | 0;
    $42 = $41 << 24 >> 24 == 1;
    if ($42) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $44 = $20 - 1 & 65535;
    HEAP16[$19 >> 1] = $44;
    label = 9;
    break;
   case 9:
    $46 = HEAP16[$5 >> 1] | 0;
    $47 = $46 << 16 >> 16;
    $48 = $46 << 16 >> 16 > 0;
    if ($48) {
      label = 10;
      break;
    } else {
      label = 13;
      break;
    }
   case 10:
    $50 = HEAP16[$19 >> 1] | 0;
    $51 = $50 << 16 >> 16;
    $52 = $51 - 1 | 0;
    $53 = ($18 | 0) == ($52 | 0);
    if ($53) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $55 = $46 - 1 & 65535;
    HEAP16[$5 >> 1] = $55;
    $56 = HEAP16[$19 >> 1] | 0;
    $57 = $56 - 1 & 65535;
    HEAP16[$19 >> 1] = $57;
    label = 13;
    break;
   case 12:
    $59 = $52 & 65535;
    $60 = $47 - 1 | 0;
    $61 = $2 + 12 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = $62 + ($60 << 1) | 0;
    HEAP16[$63 >> 1] = $59;
    label = 13;
    break;
   case 13:
    return;
  }
}
function _ps_parser_load_field($parser, $field, $objects, $max_objects, $pflags) {
  $parser = $parser | 0;
  $field = $field | 0;
  $objects = $objects | 0;
  $max_objects = $max_objects | 0;
  $pflags = $pflags | 0;
  var $token = 0, $cur = 0, $error = 0, $token2 = 0, $temp = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $limit_0_ph56 = 0, $count_0_ph55 = 0, $idx_0_ph54 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $count_053 = 0, $idx_052 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $50 = 0, $52 = 0, $54 = 0, $val_0 = 0, $56 = 0, $57 = 0, $59 = 0, $61 = 0, $62 = 0, $64 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $len_0 = 0, $82 = 0, $83 = 0, $84 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $92 = 0, $93 = 0, $95 = 0, $96 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $_sum = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $_sum49 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $_sum50 = 0, $112 = 0, $113 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 48 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $token = __stackBase__ | 0;
    $cur = __stackBase__ + 12 | 0;
    $error = __stackBase__ + 16 | 0;
    $token2 = __stackBase__ + 20 | 0;
    $temp = __stackBase__ + 32 | 0;
    _ps_parser_to_token($parser, $token);
    $1 = $token + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 33;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $token | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    HEAP32[$cur >> 2] = $6;
    $7 = $token + 4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $field + 8 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($10 | 0) == 7;
    if ($11) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $13 = $parser | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $parser + 8 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = HEAP32[$5 >> 2] | 0;
    $18 = $17 + 1 | 0;
    HEAP32[$13 >> 2] = $18;
    $19 = HEAP32[$7 >> 2] | 0;
    $20 = $19 - 1 | 0;
    HEAP32[$15 >> 2] = $20;
    _ps_parser_to_token($parser, $token2);
    HEAP32[$13 >> 2] = $14;
    HEAP32[$15 >> 2] = $16;
    $21 = $token2 + 8 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = ($22 | 0) == 3;
    if ($23) {
      label = 5;
      break;
    } else {
      $idx_0_ph54 = 0;
      $count_0_ph55 = 1;
      $limit_0_ph56 = $8;
      label = 7;
      break;
    }
   case 4:
    $25 = HEAP32[$1 >> 2] | 0;
    $26 = ($25 | 0) == 3;
    if ($26) {
      label = 5;
      break;
    } else {
      $idx_0_ph54 = 0;
      $count_0_ph55 = 1;
      $limit_0_ph56 = $8;
      label = 7;
      break;
    }
   case 5:
    $28 = ($max_objects | 0) == 0;
    if ($28) {
      label = 33;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $29 = HEAP32[$cur >> 2] | 0;
    $30 = $29 + 1 | 0;
    HEAP32[$cur >> 2] = $30;
    $31 = $8 - 1 | 0;
    $idx_0_ph54 = 1;
    $count_0_ph55 = $max_objects;
    $limit_0_ph56 = $31;
    label = 7;
    break;
   case 7:
    $32 = $field + 16 | 0;
    $33 = $field + 20 | 0;
    $34 = $parser + 16 | 0;
    $35 = $limit_0_ph56;
    $36 = HEAP32[$1 >> 2] | 0;
    $37 = $temp | 0;
    $38 = $temp + 4 | 0;
    $39 = $temp + 8 | 0;
    $40 = $temp + 12 | 0;
    $idx_052 = $idx_0_ph54;
    $count_053 = $count_0_ph55;
    label = 8;
    break;
   case 8:
    $42 = $objects + ($idx_052 << 2) | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = HEAP32[$32 >> 2] | 0;
    $45 = $43 + $44 | 0;
    _skip_spaces($cur, $limit_0_ph56);
    $46 = HEAP32[$9 >> 2] | 0;
    if (($46 | 0) == 1) {
      label = 9;
      break;
    } else if (($46 | 0) == 3) {
      label = 10;
      break;
    } else if (($46 | 0) == 4) {
      label = 11;
      break;
    } else if (($46 | 0) == 2) {
      label = 12;
      break;
    } else if (($46 | 0) == 5 | ($46 | 0) == 6) {
      label = 18;
      break;
    } else if (($46 | 0) == 7) {
      label = 27;
      break;
    } else {
      label = 33;
      break;
    }
   case 9:
    $48 = _ps_tobool($cur, $limit_0_ph56) | 0;
    $val_0 = $48;
    label = 13;
    break;
   case 10:
    $50 = _PS_Conv_ToFixed($cur, $limit_0_ph56, 0) | 0;
    $val_0 = $50;
    label = 13;
    break;
   case 11:
    $52 = _PS_Conv_ToFixed($cur, $limit_0_ph56, 3) | 0;
    $val_0 = $52;
    label = 13;
    break;
   case 12:
    $54 = _PS_Conv_ToInt($cur, $limit_0_ph56) | 0;
    $val_0 = $54;
    label = 13;
    break;
   case 13:
    $56 = HEAP8[$33] | 0;
    $57 = $56 & 255;
    if (($57 | 0) == 1) {
      label = 14;
      break;
    } else if (($57 | 0) == 2) {
      label = 15;
      break;
    } else if (($57 | 0) == 4) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 14:
    $59 = $val_0 & 255;
    HEAP8[$45] = $59;
    label = 30;
    break;
   case 15:
    $61 = $val_0 & 65535;
    $62 = $45;
    HEAP16[$62 >> 1] = $61;
    label = 30;
    break;
   case 16:
    $64 = $45;
    HEAP32[$64 >> 2] = $val_0;
    label = 30;
    break;
   case 17:
    $66 = $45;
    HEAP32[$66 >> 2] = $val_0;
    label = 30;
    break;
   case 18:
    $68 = HEAP32[$34 >> 2] | 0;
    $69 = HEAP32[$cur >> 2] | 0;
    $70 = $69;
    $71 = $35 - $70 | 0;
    $72 = $69 >>> 0 < $limit_0_ph56 >>> 0;
    if ($72) {
      label = 19;
      break;
    } else {
      label = 30;
      break;
    }
   case 19:
    if (($36 | 0) == 4) {
      label = 20;
      break;
    } else if (($36 | 0) == 2) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 20:
    $75 = $71 - 1 | 0;
    $76 = $69 + 1 | 0;
    HEAP32[$cur >> 2] = $76;
    $len_0 = $75;
    label = 23;
    break;
   case 21:
    $78 = $69 + 1 | 0;
    HEAP32[$cur >> 2] = $78;
    $79 = $71 - 2 | 0;
    $len_0 = $79;
    label = 23;
    break;
   case 22:
    HEAP32[$error >> 2] = 3;
    label = 32;
    break;
   case 23:
    $82 = $45;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = ($83 | 0) == 0;
    if ($84) {
      label = 25;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    _ft_mem_free($68, $83);
    HEAP32[$82 >> 2] = 0;
    label = 25;
    break;
   case 25:
    $87 = $len_0 + 1 | 0;
    $88 = _ft_mem_alloc($68, $87, $error) | 0;
    $89 = HEAP32[$error >> 2] | 0;
    $90 = ($89 | 0) == 0;
    if ($90) {
      label = 26;
      break;
    } else {
      label = 32;
      break;
    }
   case 26:
    $92 = HEAP32[$cur >> 2] | 0;
    _memcpy($88 | 0, $92 | 0, $len_0 | 0);
    $93 = $88 + $len_0 | 0;
    HEAP8[$93] = 0;
    HEAP32[$82 >> 2] = $88;
    label = 30;
    break;
   case 27:
    $95 = _ps_tofixedarray($cur, $limit_0_ph56, 4, $37, 0) | 0;
    $96 = ($95 | 0) < 0;
    if ($96) {
      label = 28;
      break;
    } else {
      label = 29;
      break;
    }
   case 28:
    HEAP32[$error >> 2] = 3;
    label = 32;
    break;
   case 29:
    $99 = HEAP32[$37 >> 2] | 0;
    $100 = _FT_RoundFix($99) | 0;
    $101 = $45;
    HEAP32[$101 >> 2] = $100;
    $102 = HEAP32[$38 >> 2] | 0;
    $103 = _FT_RoundFix($102) | 0;
    $_sum = $44 + 4 | 0;
    $104 = $43 + $_sum | 0;
    $105 = $104;
    HEAP32[$105 >> 2] = $103;
    $106 = HEAP32[$39 >> 2] | 0;
    $107 = _FT_RoundFix($106) | 0;
    $_sum49 = $44 + 8 | 0;
    $108 = $43 + $_sum49 | 0;
    $109 = $108;
    HEAP32[$109 >> 2] = $107;
    $110 = HEAP32[$40 >> 2] | 0;
    $111 = _FT_RoundFix($110) | 0;
    $_sum50 = $44 + 12 | 0;
    $112 = $43 + $_sum50 | 0;
    $113 = $112;
    HEAP32[$113 >> 2] = $111;
    label = 30;
    break;
   case 30:
    $115 = $count_053 - 1 | 0;
    $116 = $idx_052 + 1 | 0;
    $117 = ($115 | 0) == 0;
    if ($117) {
      label = 31;
      break;
    } else {
      $idx_052 = $116;
      $count_053 = $115;
      label = 8;
      break;
    }
   case 31:
    HEAP32[$error >> 2] = 0;
    label = 32;
    break;
   case 32:
    $118 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $118 | 0;
   case 33:
    HEAP32[$error >> 2] = 3;
    label = 32;
    break;
  }
  return 0;
}
function _ps_parser_load_field_table($parser, $field, $objects, $max_objects, $pflags) {
  $parser = $parser | 0;
  $field = $field | 0;
  $objects = $objects | 0;
  $max_objects = $max_objects | 0;
  $pflags = $pflags | 0;
  var $elements = 0, $num_elements = 0, $fieldrec = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $_pr = 0, $32 = 0, $33 = 0, $34 = 0, $token_022 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 424 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $elements = __stackBase__ | 0;
    $num_elements = __stackBase__ + 384 | 0;
    $fieldrec = __stackBase__ + 388 | 0;
    $1 = $fieldrec;
    $2 = $field;
    _memcpy($1 | 0, $2 | 0, 36);
    $3 = $fieldrec + 8 | 0;
    HEAP32[$3 >> 2] = 2;
    $4 = $field + 8 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    if (($5 | 0) == 9 | ($5 | 0) == 7) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    HEAP32[$3 >> 2] = 3;
    label = 3;
    break;
   case 3:
    $8 = $elements | 0;
    _ps_parser_to_token_array($parser, $8, 32, $num_elements);
    $9 = HEAP32[$num_elements >> 2] | 0;
    $10 = ($9 | 0) < 0;
    if ($10) {
      $error_0 = 162;
      label = 13;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $12 = $field + 24 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $9 >>> 0 > $13 >>> 0;
    if ($14) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    HEAP32[$num_elements >> 2] = $13;
    label = 6;
    break;
   case 6:
    $17 = $parser | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $parser + 8 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = HEAP32[$4 >> 2] | 0;
    $22 = ($21 | 0) == 7;
    if ($22) {
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $24 = $field + 28 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $28 = HEAP32[$num_elements >> 2] | 0;
    $29 = $28 & 255;
    $30 = HEAP32[$objects >> 2] | 0;
    $31 = $30 + $25 | 0;
    HEAP8[$31] = $29;
    label = 9;
    break;
   case 9:
    $_pr = HEAP32[$num_elements >> 2] | 0;
    $32 = ($_pr | 0) > 0;
    if ($32) {
      label = 10;
      break;
    } else {
      label = 12;
      break;
    }
   case 10:
    $33 = $fieldrec + 20 | 0;
    $34 = $fieldrec + 16 | 0;
    $token_022 = $8;
    label = 11;
    break;
   case 11:
    $36 = $token_022 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    HEAP32[$17 >> 2] = $37;
    $38 = $token_022 + 4 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    HEAP32[$19 >> 2] = $39;
    $40 = _ps_parser_load_field($parser, $fieldrec, $objects, $max_objects, 0) | 0;
    $41 = HEAP8[$33] | 0;
    $42 = $41 & 255;
    $43 = HEAP32[$34 >> 2] | 0;
    $44 = $43 + $42 | 0;
    HEAP32[$34 >> 2] = $44;
    $45 = HEAP32[$num_elements >> 2] | 0;
    $46 = $45 - 1 | 0;
    HEAP32[$num_elements >> 2] = $46;
    $47 = $token_022 + 12 | 0;
    $48 = ($46 | 0) > 0;
    if ($48) {
      $token_022 = $47;
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    HEAP32[$17 >> 2] = $18;
    HEAP32[$19 >> 2] = $20;
    $error_0 = 0;
    label = 13;
    break;
   case 13:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _t1_builder_init($builder, $face, $size, $glyph, $hinting) {
  $builder = $builder | 0;
  $face = $face | 0;
  $size = $size | 0;
  $glyph = $glyph | 0;
  $hinting = $hinting | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $builder + 64 | 0;
    HEAP32[$1 >> 2] = 0;
    $2 = $builder + 68 | 0;
    HEAP8[$2] = 1;
    $3 = $builder + 4 | 0;
    HEAP32[$3 >> 2] = $face;
    $4 = $builder + 8 | 0;
    HEAP32[$4 >> 2] = $glyph;
    $5 = $face + 100 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $builder | 0;
    HEAP32[$7 >> 2] = $6;
    $8 = ($glyph | 0) == 0;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = $glyph + 156 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $builder + 12 | 0;
    HEAP32[$14 >> 2] = $13;
    $15 = $13 + 20 | 0;
    $16 = $builder + 16 | 0;
    HEAP32[$16 >> 2] = $15;
    $17 = $13 + 56 | 0;
    $18 = $builder + 20 | 0;
    HEAP32[$18 >> 2] = $17;
    _FT_GlyphLoader_Rewind($13);
    $19 = $size + 40 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $20;
    $22 = $builder + 76 | 0;
    HEAP32[$22 >> 2] = $21;
    $23 = $builder + 72 | 0;
    HEAP32[$23 >> 2] = 0;
    $24 = $hinting << 24 >> 24 == 0;
    if ($24) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $26 = HEAP32[$10 >> 2] | 0;
    $27 = $26 + 36 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    HEAP32[$23 >> 2] = $28;
    label = 4;
    break;
   case 4:
    $30 = $builder + 24 | 0;
    $31 = $builder + 80 | 0;
    $32 = $31;
    $33 = $30;
    _memset($33 | 0, 0, 24);
    _memcpy($32 | 0, 5249248, 32);
    return;
  }
}
function _t1_builder_done($builder) {
  $builder = $builder | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $builder + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 + 108 | 0;
    $6 = $builder + 16 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $5;
    $9 = $7;
    _memcpy($8 | 0, $9 | 0, 20);
    label = 3;
    break;
   case 3:
    return;
  }
}
function _t1_builder_check_points($builder, $count) {
  $builder = $builder | 0;
  $count = $count | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($count | 0) == 0;
    if ($1) {
      $19 = 0;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $builder + 12 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 22 | 0;
    $6 = HEAP16[$5 >> 1] | 0;
    $7 = $6 << 16 >> 16;
    $8 = $4 + 58 | 0;
    $9 = HEAP16[$8 >> 1] | 0;
    $10 = $9 << 16 >> 16;
    $11 = $7 + $count | 0;
    $12 = $11 + $10 | 0;
    $13 = $4 + 4 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $12 >>> 0 > $14 >>> 0;
    if ($15) {
      label = 3;
      break;
    } else {
      $19 = 0;
      label = 4;
      break;
    }
   case 3:
    $17 = _FT_GlyphLoader_CheckPoints($4, $count, 0) | 0;
    $19 = $17;
    label = 4;
    break;
   case 4:
    return $19 | 0;
  }
  return 0;
}
function _t1_builder_add_point($builder, $x, $y, $flag) {
  $builder = $builder | 0;
  $x = $x | 0;
  $y = $y | 0;
  $flag = $flag | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $builder + 20 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $builder + 68 | 0;
    $4 = HEAP8[$3] | 0;
    $5 = $4 << 24 >> 24 == 0;
    if ($5) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $2 + 4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $2 + 2 | 0;
    $10 = HEAP16[$9 >> 1] | 0;
    $11 = $10 << 16 >> 16;
    $12 = $2 + 8 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 + $11 | 0;
    $15 = _FT_RoundFix($x) | 0;
    $16 = $15 >> 16;
    $17 = $8 + ($11 << 3) | 0;
    HEAP32[$17 >> 2] = $16;
    $18 = _FT_RoundFix($y) | 0;
    $19 = $18 >> 16;
    $20 = $8 + ($11 << 3) + 4 | 0;
    HEAP32[$20 >> 2] = $19;
    $21 = $flag << 24 >> 24 != 0;
    $22 = $21 ? 1 : 2;
    HEAP8[$14] = $22;
    label = 3;
    break;
   case 3:
    $24 = $2 + 2 | 0;
    $25 = HEAP16[$24 >> 1] | 0;
    $26 = $25 + 1 & 65535;
    HEAP16[$24 >> 1] = $26;
    return;
  }
}
function _t1_builder_add_point1($builder, $x, $y) {
  $builder = $builder | 0;
  $x = $x | 0;
  $y = $y | 0;
  var $1 = 0, $2 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _t1_builder_check_points($builder, 1) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    _t1_builder_add_point($builder, $x, $y, 1);
    label = 3;
    break;
   case 3:
    return $1 | 0;
  }
  return 0;
}
function _t1_builder_add_contour($builder) {
  $builder = $builder | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $builder + 20 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      $_0 = 3;
      label = 9;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $builder + 68 | 0;
    $6 = HEAP8[$5] | 0;
    $7 = $6 << 24 >> 24 == 0;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $9 = $2 | 0;
    $10 = HEAP16[$9 >> 1] | 0;
    $11 = $10 + 1 & 65535;
    HEAP16[$9 >> 1] = $11;
    $_0 = 0;
    label = 9;
    break;
   case 4:
    $13 = $builder + 12 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 + 20 | 0;
    $16 = HEAP16[$15 >> 1] | 0;
    $17 = $16 << 16 >> 16;
    $18 = $14 + 56 | 0;
    $19 = HEAP16[$18 >> 1] | 0;
    $20 = $19 << 16 >> 16;
    $21 = $17 + 1 | 0;
    $22 = $21 + $20 | 0;
    $23 = $14 + 8 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $22 >>> 0 > $24 >>> 0;
    if ($25) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $27 = _FT_GlyphLoader_CheckPoints($14, 0, 1) | 0;
    $28 = ($27 | 0) == 0;
    if ($28) {
      label = 6;
      break;
    } else {
      $_0 = $27;
      label = 9;
      break;
    }
   case 6:
    $29 = $2 | 0;
    $30 = HEAP16[$29 >> 1] | 0;
    $31 = $30 << 16 >> 16 > 0;
    if ($31) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $33 = $30 << 16 >> 16;
    $34 = $2 + 2 | 0;
    $35 = HEAP16[$34 >> 1] | 0;
    $36 = $35 - 1 & 65535;
    $37 = $33 - 1 | 0;
    $38 = $2 + 12 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = $39 + ($37 << 1) | 0;
    HEAP16[$40 >> 1] = $36;
    label = 8;
    break;
   case 8:
    $42 = HEAP16[$29 >> 1] | 0;
    $43 = $42 + 1 & 65535;
    HEAP16[$29 >> 1] = $43;
    $_0 = 0;
    label = 9;
    break;
   case 9:
    return $_0 | 0;
  }
  return 0;
}
function _t1_builder_start_point($builder, $x, $y) {
  $builder = $builder | 0;
  $x = $x | 0;
  $y = $y | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $builder + 64 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 3;
    if ($3) {
      $error_0 = 0;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = 3;
    $5 = _t1_builder_add_contour($builder) | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      $error_0 = $5;
      label = 4;
      break;
    }
   case 3:
    $8 = _t1_builder_add_point1($builder, $x, $y) | 0;
    $error_0 = $8;
    label = 4;
    break;
   case 4:
    return $error_0 | 0;
  }
  return 0;
}
function _t1_decoder_init($decoder, $face, $size, $slot, $glyph_names, $blend, $hinting, $hint_mode, $parse_callback) {
  $decoder = $decoder | 0;
  $face = $face | 0;
  $size = $size | 0;
  $slot = $slot | 0;
  $glyph_names = $glyph_names | 0;
  $blend = $blend | 0;
  $hinting = $hinting | 0;
  $hint_mode = $hint_mode | 0;
  $parse_callback = $parse_callback | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $decoder;
    _memset($1 | 0, 0, 1500);
    $2 = $face + 96 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 | 0;
    $5 = _ft_module_get_service($4, 5319892) | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      $_0 = 7;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $5;
    $9 = $decoder + 1348 | 0;
    HEAP32[$9 >> 2] = $8;
    $10 = $decoder | 0;
    _t1_builder_init($10, $face, $size, $slot, $hinting);
    $11 = $face + 16 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $decoder + 1352 | 0;
    HEAP32[$13 >> 2] = $12;
    $14 = $decoder + 1356 | 0;
    HEAP32[$14 >> 2] = $glyph_names;
    $15 = $decoder + 1468 | 0;
    HEAP32[$15 >> 2] = $hint_mode;
    $16 = $decoder + 1464 | 0;
    HEAP32[$16 >> 2] = $blend;
    $17 = $decoder + 1472 | 0;
    HEAP32[$17 >> 2] = $parse_callback;
    $18 = $decoder + 1476 | 0;
    $19 = $18;
    _memcpy($19 | 0, 5249060, 12);
    $_0 = 0;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _t1_decoder_done($decoder) {
  $decoder = $decoder | 0;
  _t1_builder_done($decoder | 0);
  return;
}
function _t1_decoder_parse_charstrings($decoder, $charstring_base, $charstring_len) {
  $decoder = $decoder | 0;
  $charstring_base = $charstring_base | 0;
  $charstring_len = $charstring_len | 0;
  var $1 = 0, $2 = 0, $seed = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $_ = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $zone_0_ph_ph435 = 0, $ip_0_ph_ph434 = 0, $limit_0_ph_ph433 = 0, $x_0_ph_ph432 = 0, $y_0_ph_ph431 = 0, $orig_x_0_ph_ph430 = 0, $known_othersubr_result_cnt_0_ph_ph429 = 0, $unknown_othersubr_result_cnt_0_ph_ph428 = 0, $large_int_0_ph_ph427 = 0, $ip_0_ph414 = 0, $known_othersubr_result_cnt_0_ph413 = 0, $unknown_othersubr_result_cnt_0_ph412 = 0, $large_int_0_ph411 = 0, $ip_0402 = 0, $unknown_othersubr_result_cnt_0401 = 0, $large_int_0400 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $104 = 0, $106 = 0, $107 = 0, $108 = 0, $118 = 0, $119 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $_off = 0, $138 = 0, $139 = 0, $large_int_0_ = 0, $142 = 0, $_380 = 0, $144 = 0, $146 = 0, $148 = 0, $150 = 0, $151 = 0, $153 = 0, $154 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $value_0 = 0, $ip_1 = 0, $168 = 0, $170 = 0, $value_1 = 0, $op_0 = 0, $large_int_1 = 0, $ip_2 = 0, $172 = 0, $unknown_othersubr_result_cnt_1 = 0, $176 = 0, $large_int_2 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $_sum367 = 0, $211 = 0, $213 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $221 = 0, $222 = 0, $224 = 0, $226 = 0, $227 = 0, $228 = 0, $_off378 = 0, $229 = 0, $231 = 0, $232 = 0, $_381 = 0, $233 = 0, $235 = 0, $237 = 0, $238 = 0, $239 = 0, $241 = 0, $242 = 0, $243 = 0, $_sum377 = 0, $245 = 0, $247 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $257 = 0, $258 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $270 = 0, $271 = 0, $272 = 0, $274 = 0, $_sum376 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $values_0391 = 0, $delta_0390 = 0, $nn_0389 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $tmp_0387 = 0, $delta_1386 = 0, $mm_0385 = 0, $288 = 0, $289 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $_op = 0, $scevgep_sum = 0, $scevgep448 = 0, $tmp_0_lcssa = 0, $delta_1_lcssa = 0, $297 = 0, $298 = 0, $exitcond = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $or_cond = 0, $305 = 0, $306 = 0, $307 = 0, $309 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $325 = 0, $_sum375 = 0, $327 = 0, $328 = 0, $329 = 0, $330 = 0, $332 = 0, $_sum374 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $339 = 0, $341 = 0, $_sum373 = 0, $342 = 0, $343 = 0, $344 = 0, $346 = 0, $_sum372 = 0, $348 = 0, $349 = 0, $350 = 0, $352 = 0, $353 = 0, $355 = 0, $357 = 0, $358 = 0, $359 = 0, $_sum371 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $366 = 0, $367 = 0, $368 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $375 = 0, $377 = 0, $378 = 0, $379 = 0, $381 = 0, $382 = 0, $383 = 0, $385 = 0, $386 = 0, $387 = 0, $389 = 0, $390 = 0, $391 = 0, $392 = 0, $394 = 0, $_sum368 = 0, $396 = 0, $397 = 0, $_sum369 = 0, $398 = 0, $399 = 0, $400 = 0, $_sum370 = 0, $402 = 0, $403 = 0, $405 = 0, $407 = 0, $408 = 0, $409 = 0, $_382 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $storemerge = 0, $top_0 = 0, $unknown_othersubr_result_cnt_2 = 0, $known_othersubr_result_cnt_1 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $430 = 0, $431 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $447 = 0, $448 = 0, $449 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $460 = 0, $461 = 0, $463 = 0, $464 = 0, $465 = 0, $_sum366 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $475 = 0, $_sum362 = 0, $476 = 0, $477 = 0, $_sum363 = 0, $478 = 0, $479 = 0, $_sum364 = 0, $480 = 0, $481 = 0, $482 = 0, $_sum365 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $488 = 0, $489 = 0, $490 = 0, $_sum359 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $_sum360 = 0, $495 = 0, $496 = 0, $_sum361 = 0, $497 = 0, $498 = 0, $499 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $508 = 0, $_off384 = 0, $switch = 0, $512 = 0, $513 = 0, $515 = 0, $516 = 0, $518 = 0, $519 = 0, $520 = 0, $521 = 0, $522 = 0, $524 = 0, $525 = 0, $528 = 0, $529 = 0, $531 = 0, $532 = 0, $534 = 0, $535 = 0, $_sum356 = 0, $536 = 0, $537 = 0, $538 = 0, $_sum357 = 0, $539 = 0, $540 = 0, $541 = 0, $_sum358 = 0, $542 = 0, $543 = 0, $544 = 0, $546 = 0, $547 = 0, $549 = 0, $550 = 0, $_sum355 = 0, $551 = 0, $552 = 0, $553 = 0, $y_1 = 0, $x_1 = 0, $555 = 0, $556 = 0, $558 = 0, $559 = 0, $_sum354 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $567 = 0, $568 = 0, $571 = 0, $572 = 0, $574 = 0, $575 = 0, $577 = 0, $578 = 0, $_sum349 = 0, $579 = 0, $580 = 0, $581 = 0, $_sum350 = 0, $582 = 0, $583 = 0, $584 = 0, $_sum351 = 0, $585 = 0, $586 = 0, $587 = 0, $_sum352 = 0, $588 = 0, $589 = 0, $590 = 0, $_sum353 = 0, $591 = 0, $592 = 0, $593 = 0, $595 = 0, $596 = 0, $598 = 0, $599 = 0, $601 = 0, $602 = 0, $_sum346 = 0, $603 = 0, $604 = 0, $605 = 0, $_sum347 = 0, $606 = 0, $607 = 0, $608 = 0, $_sum348 = 0, $609 = 0, $610 = 0, $611 = 0, $613 = 0, $614 = 0, $616 = 0, $617 = 0, $619 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $625 = 0, $626 = 0, $629 = 0, $_sum345 = 0, $630 = 0, $631 = 0, $632 = 0, $634 = 0, $635 = 0, $636 = 0, $638 = 0, $639 = 0, $640 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $648 = 0, $649 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $666 = 0, $667 = 0, $668 = 0, $_383 = 0, $669 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $678 = 0, $679 = 0, $680 = 0, $681 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $689 = 0, $691 = 0, $693 = 0, $695 = 0, $_sum344 = 0, $696 = 0, $698 = 0, $699 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $709 = 0, $710 = 0, $713 = 0, $714 = 0, $717 = 0, $718 = 0, $719 = 0, $720 = 0, $723 = 0, $724 = 0, $_sum342 = 0, $725 = 0, $726 = 0, $727 = 0, $_sum343 = 0, $728 = 0, $729 = 0, $730 = 0, $731 = 0, $732 = 0, $734 = 0, $_sum = 0, $735 = 0, $736 = 0, $737 = 0, $top_1 = 0, $large_int_3 = 0, $unknown_othersubr_result_cnt_3 = 0, $known_othersubr_result_cnt_2 = 0, $orig_x_1 = 0, $y_2 = 0, $x_2 = 0, $limit_1 = 0, $ip_3 = 0, $zone_1 = 0, $738 = 0, $739 = 0, $740 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = __stackBase__ | 0;
    $2 = __stackBase__ + 4 | 0;
    $seed = __stackBase__ + 8 | 0;
    HEAP32[$1 >> 2] = $decoder;
    HEAP32[$2 >> 2] = $charstring_base;
    $3 = $decoder | 0;
    $4 = $seed;
    $5 = $1;
    $6 = $2;
    $7 = $6 ^ $5;
    $8 = $7 ^ $4;
    $9 = $8 >>> 10;
    $10 = $9 ^ $8;
    $11 = $8 >> 20;
    $12 = $10 ^ $11;
    $13 = $12 & 65535;
    $14 = ($13 | 0) == 0;
    $_ = $14 ? 29572 : $13;
    HEAP32[$seed >> 2] = $_;
    $15 = HEAP32[$1 >> 2] | 0;
    $16 = $15 + 112 | 0;
    $17 = $15 + 1136 | 0;
    HEAP32[$17 >> 2] = $16;
    $18 = HEAP32[$1 >> 2] | 0;
    $19 = $18 + 1140 | 0;
    $20 = $18 + 1344 | 0;
    HEAP32[$20 >> 2] = $19;
    $21 = HEAP32[$1 >> 2] | 0;
    $22 = $21 + 1140 | 0;
    $23 = $decoder + 64 | 0;
    HEAP32[$23 >> 2] = 0;
    $24 = $decoder + 72 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = HEAP32[$1 >> 2] | 0;
    $27 = $26 + 1492 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $31 = $26 + 1488 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $32;
    $34 = $28 << 2;
    _memset($33 | 0, 0, $34 | 0);
    label = 3;
    break;
   case 3:
    $36 = HEAP32[$2 >> 2] | 0;
    $37 = $21 + 1144 | 0;
    HEAP32[$37 >> 2] = $36;
    $38 = HEAP32[$2 >> 2] | 0;
    $39 = $38 + $charstring_len | 0;
    $40 = $21 + 1148 | 0;
    HEAP32[$40 >> 2] = $39;
    $41 = HEAP32[$37 >> 2] | 0;
    $42 = $22 | 0;
    HEAP32[$42 >> 2] = $41;
    $43 = $decoder + 24 | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    $45 = $decoder + 28 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = ($25 | 0) != 0;
    if ($47) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $49 = $25 + 4 | 0;
    $50 = $49;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = $25;
    $53 = HEAP32[$52 >> 2] | 0;
    FUNCTION_TABLE_vi[$51 & 1023]($53);
    label = 5;
    break;
   case 5:
    $54 = $41 >>> 0 < $39 >>> 0;
    if ($54) {
      label = 6;
      break;
    } else {
      $_0 = 0;
      label = 175;
      break;
    }
   case 6:
    $55 = $25 + 20 | 0;
    $56 = $55;
    $57 = $25;
    $58 = $decoder + 20 | 0;
    $59 = $decoder + 32 | 0;
    $60 = $decoder + 40 | 0;
    $61 = $decoder + 44 | 0;
    $62 = $decoder + 70 | 0;
    $63 = $decoder + 32 | 0;
    $64 = $decoder + 36 | 0;
    $65 = $decoder + 40 | 0;
    $66 = $decoder + 44 | 0;
    $67 = $decoder + 70 | 0;
    $68 = $25 + 12 | 0;
    $69 = $68;
    $70 = $25;
    $71 = $25 + 16 | 0;
    $72 = $71;
    $73 = $25;
    $74 = $25 + 12 | 0;
    $75 = $74;
    $76 = $25;
    $77 = $25 + 16 | 0;
    $78 = $77;
    $79 = $25;
    $large_int_0_ph_ph427 = 0;
    $unknown_othersubr_result_cnt_0_ph_ph428 = 0;
    $known_othersubr_result_cnt_0_ph_ph429 = 0;
    $orig_x_0_ph_ph430 = $44;
    $y_0_ph_ph431 = $46;
    $x_0_ph_ph432 = $44;
    $limit_0_ph_ph433 = $39;
    $ip_0_ph_ph434 = $41;
    $zone_0_ph_ph435 = $22;
    label = 7;
    break;
   case 7:
    $large_int_0_ph411 = $large_int_0_ph_ph427;
    $unknown_othersubr_result_cnt_0_ph412 = $unknown_othersubr_result_cnt_0_ph_ph428;
    $known_othersubr_result_cnt_0_ph413 = $known_othersubr_result_cnt_0_ph_ph429;
    $ip_0_ph414 = $ip_0_ph_ph434;
    label = 8;
    break;
   case 8:
    $large_int_0400 = $large_int_0_ph411;
    $unknown_othersubr_result_cnt_0401 = $unknown_othersubr_result_cnt_0_ph412;
    $ip_0402 = $ip_0_ph414;
    label = 9;
    break;
   case 9:
    $81 = HEAP32[$1 >> 2] | 0;
    $82 = $81 + 1136 | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = $ip_0402 + 1 | 0;
    $85 = HEAP8[$ip_0402] | 0;
    $86 = $85 & 255;
    if (($86 | 0) == 3) {
      label = 10;
      break;
    } else if (($86 | 0) == 4) {
      label = 11;
      break;
    } else if (($86 | 0) == 5) {
      label = 12;
      break;
    } else if (($86 | 0) == 6) {
      label = 13;
      break;
    } else if (($86 | 0) == 7) {
      label = 14;
      break;
    } else if (($86 | 0) == 8) {
      label = 15;
      break;
    } else if (($86 | 0) == 9) {
      label = 16;
      break;
    } else if (($86 | 0) == 10) {
      label = 17;
      break;
    } else if (($86 | 0) == 11) {
      label = 18;
      break;
    } else if (($86 | 0) == 13) {
      label = 19;
      break;
    } else if (($86 | 0) == 14) {
      label = 20;
      break;
    } else if (($86 | 0) == 15) {
      label = 21;
      break;
    } else if (($86 | 0) == 21) {
      label = 22;
      break;
    } else if (($86 | 0) == 22) {
      label = 23;
      break;
    } else if (($86 | 0) == 30) {
      label = 24;
      break;
    } else if (($86 | 0) == 31) {
      label = 25;
      break;
    } else if (($86 | 0) == 12) {
      label = 26;
      break;
    } else if (($86 | 0) == 255) {
      label = 36;
      break;
    } else if (($86 | 0) == 1) {
      $ip_2 = $84;
      $large_int_1 = $large_int_0400;
      $op_0 = 16;
      $value_1 = 0;
      label = 49;
      break;
    } else {
      label = 40;
      break;
    }
   case 10:
    $ip_2 = $84;
    $large_int_1 = $large_int_0400;
    $op_0 = 18;
    $value_1 = 0;
    label = 49;
    break;
   case 11:
    $ip_2 = $84;
    $large_int_1 = $large_int_0400;
    $op_0 = 14;
    $value_1 = 0;
    label = 49;
    break;
   case 12:
    $ip_2 = $84;
    $large_int_1 = $large_int_0400;
    $op_0 = 9;
    $value_1 = 0;
    label = 49;
    break;
   case 13:
    $ip_2 = $84;
    $large_int_1 = $large_int_0400;
    $op_0 = 6;
    $value_1 = 0;
    label = 49;
    break;
   case 14:
    $ip_2 = $84;
    $large_int_1 = $large_int_0400;
    $op_0 = 13;
    $value_1 = 0;
    label = 49;
    break;
   case 15:
    $ip_2 = $84;
    $large_int_1 = $large_int_0400;
    $op_0 = 11;
    $value_1 = 0;
    label = 49;
    break;
   case 16:
    $ip_2 = $84;
    $large_int_1 = $large_int_0400;
    $op_0 = 5;
    $value_1 = 0;
    label = 49;
    break;
   case 17:
    $ip_2 = $84;
    $large_int_1 = $large_int_0400;
    $op_0 = 22;
    $value_1 = 0;
    label = 49;
    break;
   case 18:
    $ip_2 = $84;
    $large_int_1 = $large_int_0400;
    $op_0 = 24;
    $value_1 = 0;
    label = 49;
    break;
   case 19:
    $ip_2 = $84;
    $large_int_1 = $large_int_0400;
    $op_0 = 2;
    $value_1 = 0;
    label = 49;
    break;
   case 20:
    $ip_2 = $84;
    $large_int_1 = $large_int_0400;
    $op_0 = 1;
    $value_1 = 0;
    label = 49;
    break;
   case 21:
    $ip_2 = $84;
    $large_int_1 = $large_int_0400;
    $op_0 = 26;
    $value_1 = 0;
    label = 49;
    break;
   case 22:
    $ip_2 = $84;
    $large_int_1 = $large_int_0400;
    $op_0 = 10;
    $value_1 = 0;
    label = 49;
    break;
   case 23:
    $ip_2 = $84;
    $large_int_1 = $large_int_0400;
    $op_0 = 7;
    $value_1 = 0;
    label = 49;
    break;
   case 24:
    $ip_2 = $84;
    $large_int_1 = $large_int_0400;
    $op_0 = 12;
    $value_1 = 0;
    label = 49;
    break;
   case 25:
    $ip_2 = $84;
    $large_int_1 = $large_int_0400;
    $op_0 = 8;
    $value_1 = 0;
    label = 49;
    break;
   case 26:
    $104 = $84 >>> 0 > $limit_0_ph_ph433 >>> 0;
    if ($104) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $106 = $ip_0402 + 2 | 0;
    $107 = HEAP8[$84] | 0;
    $108 = $107 & 255;
    if (($108 | 0) == 1) {
      label = 28;
      break;
    } else if (($108 | 0) == 2) {
      label = 29;
      break;
    } else if (($108 | 0) == 6) {
      label = 30;
      break;
    } else if (($108 | 0) == 7) {
      label = 31;
      break;
    } else if (($108 | 0) == 12) {
      label = 32;
      break;
    } else if (($108 | 0) == 16) {
      label = 33;
      break;
    } else if (($108 | 0) == 17) {
      label = 34;
      break;
    } else if (($108 | 0) == 33) {
      label = 35;
      break;
    } else if (($108 | 0) == 0) {
      $ip_2 = $106;
      $large_int_1 = $large_int_0400;
      $op_0 = 15;
      $value_1 = 0;
      label = 49;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 28:
    $ip_2 = $106;
    $large_int_1 = $large_int_0400;
    $op_0 = 19;
    $value_1 = 0;
    label = 49;
    break;
   case 29:
    $ip_2 = $106;
    $large_int_1 = $large_int_0400;
    $op_0 = 17;
    $value_1 = 0;
    label = 49;
    break;
   case 30:
    $ip_2 = $106;
    $large_int_1 = $large_int_0400;
    $op_0 = 3;
    $value_1 = 0;
    label = 49;
    break;
   case 31:
    $ip_2 = $106;
    $large_int_1 = $large_int_0400;
    $op_0 = 4;
    $value_1 = 0;
    label = 49;
    break;
   case 32:
    $ip_2 = $106;
    $large_int_1 = $large_int_0400;
    $op_0 = 20;
    $value_1 = 0;
    label = 49;
    break;
   case 33:
    $ip_2 = $106;
    $large_int_1 = $large_int_0400;
    $op_0 = 21;
    $value_1 = 0;
    label = 49;
    break;
   case 34:
    $ip_2 = $106;
    $large_int_1 = $large_int_0400;
    $op_0 = 23;
    $value_1 = 0;
    label = 49;
    break;
   case 35:
    $ip_2 = $106;
    $large_int_1 = $large_int_0400;
    $op_0 = 25;
    $value_1 = 0;
    label = 49;
    break;
   case 36:
    $118 = $ip_0402 + 5 | 0;
    $119 = $118 >>> 0 > $limit_0_ph_ph433 >>> 0;
    if ($119) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 37;
      break;
    }
   case 37:
    $121 = HEAP8[$84] | 0;
    $122 = $121 & 255;
    $123 = $122 << 24;
    $124 = $ip_0402 + 2 | 0;
    $125 = HEAP8[$124] | 0;
    $126 = $125 & 255;
    $127 = $126 << 16;
    $128 = $127 | $123;
    $129 = $ip_0402 + 3 | 0;
    $130 = HEAP8[$129] | 0;
    $131 = $130 & 255;
    $132 = $131 << 8;
    $133 = $128 | $132;
    $134 = $ip_0402 + 4 | 0;
    $135 = HEAP8[$134] | 0;
    $136 = $135 & 255;
    $137 = $133 | $136;
    $_off = $137 + 32e3 | 0;
    $138 = $_off >>> 0 > 64e3;
    $139 = $large_int_0400 << 24 >> 24 != 0;
    if ($138) {
      label = 38;
      break;
    } else {
      label = 39;
      break;
    }
   case 38:
    $large_int_0_ = $139 ? $large_int_0400 : 1;
    $ip_2 = $118;
    $large_int_1 = $large_int_0_;
    $op_0 = 0;
    $value_1 = $137;
    label = 49;
    break;
   case 39:
    $142 = $137 << 16;
    $_380 = $139 ? $137 : $142;
    $ip_2 = $118;
    $large_int_1 = $large_int_0400;
    $op_0 = 0;
    $value_1 = $_380;
    label = 49;
    break;
   case 40:
    $144 = ($85 & 255) > 31;
    if ($144) {
      label = 41;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 41:
    $146 = ($85 & 255) < 247;
    if ($146) {
      label = 42;
      break;
    } else {
      label = 43;
      break;
    }
   case 42:
    $148 = $86 - 139 | 0;
    $ip_1 = $84;
    $value_0 = $148;
    label = 47;
    break;
   case 43:
    $150 = $ip_0402 + 2 | 0;
    $151 = $150 >>> 0 > $limit_0_ph_ph433 >>> 0;
    if ($151) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 44;
      break;
    }
   case 44:
    $153 = ($85 & 255) < 251;
    $154 = $86 << 8;
    if ($153) {
      label = 45;
      break;
    } else {
      label = 46;
      break;
    }
   case 45:
    $156 = $154 - 63232 | 0;
    $157 = HEAP8[$84] | 0;
    $158 = $157 & 255;
    $159 = $158 | $156;
    $160 = $159 + 108 | 0;
    $ip_1 = $150;
    $value_0 = $160;
    label = 47;
    break;
   case 46:
    $162 = $154 - 64256 | 0;
    $163 = HEAP8[$84] | 0;
    $164 = $163 & 255;
    $165 = $164 | $162;
    $166 = -108 - $165 | 0;
    $ip_1 = $150;
    $value_0 = $166;
    label = 47;
    break;
   case 47:
    $168 = $large_int_0400 << 24 >> 24 == 0;
    if ($168) {
      label = 48;
      break;
    } else {
      $ip_2 = $ip_1;
      $large_int_1 = $large_int_0400;
      $op_0 = 0;
      $value_1 = $value_0;
      label = 49;
      break;
    }
   case 48:
    $170 = $value_0 << 16;
    $ip_2 = $ip_1;
    $large_int_1 = 0;
    $op_0 = 0;
    $value_1 = $170;
    label = 49;
    break;
   case 49:
    $172 = ($unknown_othersubr_result_cnt_0401 | 0) > 0;
    if ($172) {
      label = 50;
      break;
    } else {
      $unknown_othersubr_result_cnt_1 = $unknown_othersubr_result_cnt_0401;
      label = 52;
      break;
    }
   case 50:
    if (($op_0 | 0) == 22 | ($op_0 | 0) == 24 | ($op_0 | 0) == 0 | ($op_0 | 0) == 23) {
      $unknown_othersubr_result_cnt_1 = $unknown_othersubr_result_cnt_0401;
      label = 52;
      break;
    } else {
      label = 51;
      break;
    }
   case 51:
    $unknown_othersubr_result_cnt_1 = 0;
    label = 52;
    break;
   case 52:
    $176 = $large_int_1 << 24 >> 24 == 0;
    if ($176) {
      $large_int_2 = 0;
      label = 55;
      break;
    } else {
      label = 53;
      break;
    }
   case 53:
    if (($op_0 | 0) == 20 | ($op_0 | 0) == 0) {
      $large_int_2 = $large_int_1;
      label = 55;
      break;
    } else {
      label = 54;
      break;
    }
   case 54:
    $large_int_2 = 0;
    label = 55;
    break;
   case 55:
    if (($op_0 | 0) == 0) {
      label = 56;
      break;
    } else if (($op_0 | 0) == 21) {
      label = 58;
      break;
    } else {
      label = 113;
      break;
    }
   case 56:
    $181 = HEAP32[$1 >> 2] | 0;
    $182 = $181 + 112 | 0;
    $183 = $83;
    $184 = $182;
    $185 = $183 - $184 | 0;
    $186 = ($185 | 0) > 1020;
    if ($186) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 57;
      break;
    }
   case 57:
    $188 = $83 + 4 | 0;
    HEAP32[$83 >> 2] = $value_1;
    $189 = HEAP32[$1 >> 2] | 0;
    $190 = $189 + 1136 | 0;
    HEAP32[$190 >> 2] = $188;
    $191 = $ip_2 >>> 0 < $limit_0_ph_ph433 >>> 0;
    if ($191) {
      $large_int_0400 = $large_int_2;
      $unknown_othersubr_result_cnt_0401 = $unknown_othersubr_result_cnt_1;
      $ip_0402 = $ip_2;
      label = 9;
      break;
    } else {
      $_0 = 0;
      label = 175;
      break;
    }
   case 58:
    $193 = HEAP32[$1 >> 2] | 0;
    $194 = $193 + 112 | 0;
    $195 = $83;
    $196 = $194;
    $197 = $195 - $196 | 0;
    $198 = ($197 | 0) < 8;
    if ($198) {
      $_0 = 161;
      label = 175;
      break;
    } else {
      label = 59;
      break;
    }
   case 59:
    $200 = $83 - 8 | 0;
    $201 = $83 - 4 | 0;
    $202 = HEAP32[$201 >> 2] | 0;
    $203 = $202 >> 16;
    $204 = HEAP32[$200 >> 2] | 0;
    $205 = $204 >> 16;
    $206 = $200;
    $207 = $206 - $196 | 0;
    $208 = $207 >> 2;
    $209 = ($205 | 0) > ($208 | 0);
    if ($209) {
      $_0 = 161;
      label = 175;
      break;
    } else {
      label = 60;
      break;
    }
   case 60:
    $_sum367 = -2 - $205 | 0;
    $211 = $83 + ($_sum367 << 2) | 0;
    if (($203 | 0) == 1) {
      label = 61;
      break;
    } else if (($203 | 0) == 2) {
      label = 64;
      break;
    } else if (($203 | 0) == 0) {
      label = 67;
      break;
    } else if (($203 | 0) == 3) {
      label = 71;
      break;
    } else if (($203 | 0) == 12 | ($203 | 0) == 13) {
      label = 74;
      break;
    } else if (($203 | 0) == 14 | ($203 | 0) == 15 | ($203 | 0) == 16 | ($203 | 0) == 17 | ($203 | 0) == 18) {
      label = 75;
      break;
    } else if (($203 | 0) == 19) {
      label = 84;
      break;
    } else if (($203 | 0) == 20) {
      label = 88;
      break;
    } else if (($203 | 0) == 21) {
      label = 90;
      break;
    } else if (($203 | 0) == 22) {
      label = 92;
      break;
    } else if (($203 | 0) == 23) {
      label = 94;
      break;
    } else if (($203 | 0) == 24) {
      label = 97;
      break;
    } else if (($203 | 0) == 25) {
      label = 102;
      break;
    } else if (($203 | 0) == 27) {
      label = 107;
      break;
    } else if (($203 | 0) == 28) {
      label = 110;
      break;
    } else {
      $known_othersubr_result_cnt_1 = 0;
      $unknown_othersubr_result_cnt_2 = $205;
      $top_0 = $211;
      label = 112;
      break;
    }
   case 61:
    $213 = ($205 | 0) == 0;
    if ($213) {
      label = 62;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 62:
    $215 = $193 + 1400 | 0;
    HEAP32[$215 >> 2] = 1;
    $216 = HEAP32[$1 >> 2] | 0;
    $217 = $216 + 1404 | 0;
    HEAP32[$217 >> 2] = 0;
    $218 = _t1_builder_start_point($3, $x_0_ph_ph432, $y_0_ph_ph431) | 0;
    $219 = ($218 | 0) == 0;
    if ($219) {
      label = 63;
      break;
    } else {
      $_0 = $218;
      label = 175;
      break;
    }
   case 63:
    $221 = _t1_builder_check_points($3, 6) | 0;
    $222 = ($221 | 0) == 0;
    if ($222) {
      $known_othersubr_result_cnt_1 = 0;
      $unknown_othersubr_result_cnt_2 = 0;
      $top_0 = $211;
      label = 112;
      break;
    } else {
      $_0 = $221;
      label = 175;
      break;
    }
   case 64:
    $224 = ($205 | 0) == 0;
    if ($224) {
      label = 65;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 65:
    $226 = $193 + 1404 | 0;
    $227 = HEAP32[$226 >> 2] | 0;
    $228 = $227 + 1 | 0;
    HEAP32[$226 >> 2] = $228;
    $_off378 = $227 - 1 | 0;
    $229 = $_off378 >>> 0 < 6;
    if ($229) {
      label = 66;
      break;
    } else {
      $known_othersubr_result_cnt_1 = 0;
      $unknown_othersubr_result_cnt_2 = 0;
      $top_0 = $211;
      label = 112;
      break;
    }
   case 66:
    $231 = ($227 | 0) == 3;
    $232 = ($227 | 0) == 6;
    $_381 = $231 | $232;
    $233 = $_381 & 1;
    _t1_builder_add_point($3, $x_0_ph_ph432, $y_0_ph_ph431, $233);
    $known_othersubr_result_cnt_1 = 0;
    $unknown_othersubr_result_cnt_2 = 0;
    $top_0 = $211;
    label = 112;
    break;
   case 67:
    $235 = ($205 | 0) == 3;
    if ($235) {
      label = 68;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 68:
    $237 = $193 + 1400 | 0;
    $238 = HEAP32[$237 >> 2] | 0;
    $239 = ($238 | 0) == 0;
    if ($239) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 69;
      break;
    }
   case 69:
    $241 = $193 + 1404 | 0;
    $242 = HEAP32[$241 >> 2] | 0;
    $243 = ($242 | 0) == 7;
    if ($243) {
      label = 70;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 70:
    HEAP32[$211 >> 2] = $x_0_ph_ph432;
    $_sum377 = $_sum367 + 1 | 0;
    $245 = $83 + ($_sum377 << 2) | 0;
    HEAP32[$245 >> 2] = $y_0_ph_ph431;
    $known_othersubr_result_cnt_1 = 2;
    $unknown_othersubr_result_cnt_2 = 0;
    $top_0 = $211;
    label = 112;
    break;
   case 71:
    $247 = ($205 | 0) == 1;
    if ($247) {
      label = 72;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 72:
    if ($47) {
      label = 73;
      break;
    } else {
      $known_othersubr_result_cnt_1 = 1;
      $unknown_othersubr_result_cnt_2 = 0;
      $top_0 = $211;
      label = 112;
      break;
    }
   case 73:
    $250 = HEAP32[$56 >> 2] | 0;
    $251 = HEAP32[$57 >> 2] | 0;
    $252 = HEAP32[$58 >> 2] | 0;
    $253 = $252 + 2 | 0;
    $254 = HEAP16[$253 >> 1] | 0;
    $255 = $254 << 16 >> 16;
    FUNCTION_TABLE_vii[$250 & 1023]($251, $255);
    $known_othersubr_result_cnt_1 = 1;
    $unknown_othersubr_result_cnt_2 = 0;
    $top_0 = $211;
    label = 112;
    break;
   case 74:
    $257 = HEAP32[$1 >> 2] | 0;
    $258 = $257 + 112 | 0;
    $known_othersubr_result_cnt_1 = 0;
    $unknown_othersubr_result_cnt_2 = 0;
    $top_0 = $258;
    label = 112;
    break;
   case 75:
    $260 = HEAP32[$1 >> 2] | 0;
    $261 = $260 + 1464 | 0;
    $262 = HEAP32[$261 >> 2] | 0;
    $263 = ($262 | 0) == 0;
    if ($263) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 76;
      break;
    }
   case 76:
    $265 = $203 - 13 | 0;
    $266 = ($203 | 0) == 18;
    $267 = $266 & 1;
    $268 = $265 + $267 | 0;
    $269 = $262 | 0;
    $270 = HEAP32[$269 >> 2] | 0;
    $271 = Math_imul($270, $268);
    $272 = ($205 | 0) == ($271 | 0);
    if ($272) {
      label = 77;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 77:
    $274 = ($268 | 0) == 0;
    if ($274) {
      $known_othersubr_result_cnt_1 = 0;
      $unknown_othersubr_result_cnt_2 = 0;
      $top_0 = $211;
      label = 112;
      break;
    } else {
      label = 78;
      break;
    }
   case 78:
    $_sum376 = $268 + $_sum367 | 0;
    $275 = $83 + ($_sum376 << 2) | 0;
    $276 = $262 + 136 | 0;
    $277 = $203 - 13 | 0;
    $278 = $266 & 1;
    $279 = $277 + $278 | 0;
    $nn_0389 = 0;
    $delta_0390 = $275;
    $values_0391 = $211;
    label = 79;
    break;
   case 79:
    $281 = HEAP32[$values_0391 >> 2] | 0;
    $282 = HEAP32[$269 >> 2] | 0;
    $283 = $282 >>> 0 > 1;
    if ($283) {
      label = 80;
      break;
    } else {
      $delta_1_lcssa = $delta_0390;
      $tmp_0_lcssa = $281;
      label = 83;
      break;
    }
   case 80:
    $284 = HEAP32[$276 >> 2] | 0;
    $285 = HEAP32[$269 >> 2] | 0;
    $286 = $285 >>> 0 > 2;
    $mm_0385 = 1;
    $delta_1386 = $delta_0390;
    $tmp_0387 = $281;
    label = 81;
    break;
   case 81:
    $288 = $delta_1386 + 4 | 0;
    $289 = HEAP32[$delta_1386 >> 2] | 0;
    $290 = $284 + ($mm_0385 << 2) | 0;
    $291 = HEAP32[$290 >> 2] | 0;
    $292 = _FT_MulFix($289, $291) | 0;
    $293 = $292 + $tmp_0387 | 0;
    $294 = $mm_0385 + 1 | 0;
    $295 = $294 >>> 0 < $285 >>> 0;
    if ($295) {
      $mm_0385 = $294;
      $delta_1386 = $288;
      $tmp_0387 = $293;
      label = 81;
      break;
    } else {
      label = 82;
      break;
    }
   case 82:
    $_op = $285 - 1 | 0;
    $scevgep_sum = $286 ? $_op : 1;
    $scevgep448 = $delta_0390 + ($scevgep_sum << 2) | 0;
    $delta_1_lcssa = $scevgep448;
    $tmp_0_lcssa = $293;
    label = 83;
    break;
   case 83:
    $297 = $values_0391 + 4 | 0;
    HEAP32[$values_0391 >> 2] = $tmp_0_lcssa;
    $298 = $nn_0389 + 1 | 0;
    $exitcond = ($298 | 0) == ($279 | 0);
    if ($exitcond) {
      $known_othersubr_result_cnt_1 = $268;
      $unknown_othersubr_result_cnt_2 = 0;
      $top_0 = $211;
      label = 112;
      break;
    } else {
      $nn_0389 = $298;
      $delta_0390 = $delta_1_lcssa;
      $values_0391 = $297;
      label = 79;
      break;
    }
   case 84:
    $300 = $193 + 1464 | 0;
    $301 = HEAP32[$300 >> 2] | 0;
    $302 = ($205 | 0) != 1;
    $303 = ($301 | 0) == 0;
    $or_cond = $302 | $303;
    if ($or_cond) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 85;
      break;
    }
   case 85:
    $305 = HEAP32[$211 >> 2] | 0;
    $306 = $305 >> 16;
    $307 = ($306 | 0) < 0;
    if ($307) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 86;
      break;
    }
   case 86:
    $309 = $301 | 0;
    $310 = HEAP32[$309 >> 2] | 0;
    $311 = $310 + $306 | 0;
    $312 = $193 + 1492 | 0;
    $313 = HEAP32[$312 >> 2] | 0;
    $314 = $311 >>> 0 > $313 >>> 0;
    if ($314) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 87;
      break;
    }
   case 87:
    $316 = $193 + 1488 | 0;
    $317 = HEAP32[$316 >> 2] | 0;
    $318 = $317 + ($306 << 2) | 0;
    $319 = $318;
    $320 = $301 + 136 | 0;
    $321 = HEAP32[$320 >> 2] | 0;
    $322 = $321;
    $323 = $310 << 2;
    _memcpy($319 | 0, $322 | 0, $323 | 0);
    $known_othersubr_result_cnt_1 = 0;
    $unknown_othersubr_result_cnt_2 = 0;
    $top_0 = $211;
    label = 112;
    break;
   case 88:
    $325 = ($205 | 0) == 2;
    if ($325) {
      label = 89;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 89:
    $_sum375 = $_sum367 + 1 | 0;
    $327 = $83 + ($_sum375 << 2) | 0;
    $328 = HEAP32[$327 >> 2] | 0;
    $329 = HEAP32[$211 >> 2] | 0;
    $330 = $329 + $328 | 0;
    HEAP32[$211 >> 2] = $330;
    $known_othersubr_result_cnt_1 = 1;
    $unknown_othersubr_result_cnt_2 = 0;
    $top_0 = $211;
    label = 112;
    break;
   case 90:
    $332 = ($205 | 0) == 2;
    if ($332) {
      label = 91;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 91:
    $_sum374 = $_sum367 + 1 | 0;
    $334 = $83 + ($_sum374 << 2) | 0;
    $335 = HEAP32[$334 >> 2] | 0;
    $336 = HEAP32[$211 >> 2] | 0;
    $337 = $336 - $335 | 0;
    HEAP32[$211 >> 2] = $337;
    $known_othersubr_result_cnt_1 = 1;
    $unknown_othersubr_result_cnt_2 = 0;
    $top_0 = $211;
    label = 112;
    break;
   case 92:
    $339 = ($205 | 0) == 2;
    if ($339) {
      label = 93;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 93:
    $341 = HEAP32[$211 >> 2] | 0;
    $_sum373 = $_sum367 + 1 | 0;
    $342 = $83 + ($_sum373 << 2) | 0;
    $343 = HEAP32[$342 >> 2] | 0;
    $344 = _FT_MulFix($341, $343) | 0;
    HEAP32[$211 >> 2] = $344;
    $known_othersubr_result_cnt_1 = 1;
    $unknown_othersubr_result_cnt_2 = 0;
    $top_0 = $211;
    label = 112;
    break;
   case 94:
    $346 = ($205 | 0) == 2;
    if ($346) {
      label = 95;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 95:
    $_sum372 = $_sum367 + 1 | 0;
    $348 = $83 + ($_sum372 << 2) | 0;
    $349 = HEAP32[$348 >> 2] | 0;
    $350 = ($349 | 0) == 0;
    if ($350) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 96;
      break;
    }
   case 96:
    $352 = HEAP32[$211 >> 2] | 0;
    $353 = _FT_DivFix($352, $349) | 0;
    HEAP32[$211 >> 2] = $353;
    $known_othersubr_result_cnt_1 = 1;
    $unknown_othersubr_result_cnt_2 = 0;
    $top_0 = $211;
    label = 112;
    break;
   case 97:
    $355 = ($205 | 0) == 2;
    if ($355) {
      label = 98;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 98:
    $357 = $193 + 1464 | 0;
    $358 = HEAP32[$357 >> 2] | 0;
    $359 = ($358 | 0) == 0;
    if ($359) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 99;
      break;
    }
   case 99:
    $_sum371 = $_sum367 + 1 | 0;
    $361 = $83 + ($_sum371 << 2) | 0;
    $362 = HEAP32[$361 >> 2] | 0;
    $363 = $362 >> 16;
    $364 = ($363 | 0) < 0;
    if ($364) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 100;
      break;
    }
   case 100:
    $366 = $193 + 1492 | 0;
    $367 = HEAP32[$366 >> 2] | 0;
    $368 = $363 >>> 0 < $367 >>> 0;
    if ($368) {
      label = 101;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 101:
    $370 = HEAP32[$211 >> 2] | 0;
    $371 = $193 + 1488 | 0;
    $372 = HEAP32[$371 >> 2] | 0;
    $373 = $372 + ($363 << 2) | 0;
    HEAP32[$373 >> 2] = $370;
    $known_othersubr_result_cnt_1 = 0;
    $unknown_othersubr_result_cnt_2 = 0;
    $top_0 = $211;
    label = 112;
    break;
   case 102:
    $375 = ($205 | 0) == 1;
    if ($375) {
      label = 103;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 103:
    $377 = $193 + 1464 | 0;
    $378 = HEAP32[$377 >> 2] | 0;
    $379 = ($378 | 0) == 0;
    if ($379) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 104;
      break;
    }
   case 104:
    $381 = HEAP32[$211 >> 2] | 0;
    $382 = $381 >> 16;
    $383 = ($382 | 0) < 0;
    if ($383) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 105;
      break;
    }
   case 105:
    $385 = $193 + 1492 | 0;
    $386 = HEAP32[$385 >> 2] | 0;
    $387 = $382 >>> 0 < $386 >>> 0;
    if ($387) {
      label = 106;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 106:
    $389 = $193 + 1488 | 0;
    $390 = HEAP32[$389 >> 2] | 0;
    $391 = $390 + ($382 << 2) | 0;
    $392 = HEAP32[$391 >> 2] | 0;
    HEAP32[$211 >> 2] = $392;
    $known_othersubr_result_cnt_1 = 1;
    $unknown_othersubr_result_cnt_2 = 0;
    $top_0 = $211;
    label = 112;
    break;
   case 107:
    $394 = ($205 | 0) == 4;
    if ($394) {
      label = 108;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 108:
    $_sum368 = $_sum367 + 2 | 0;
    $396 = $83 + ($_sum368 << 2) | 0;
    $397 = HEAP32[$396 >> 2] | 0;
    $_sum369 = $_sum367 + 3 | 0;
    $398 = $83 + ($_sum369 << 2) | 0;
    $399 = HEAP32[$398 >> 2] | 0;
    $400 = ($397 | 0) > ($399 | 0);
    if ($400) {
      label = 109;
      break;
    } else {
      $known_othersubr_result_cnt_1 = 1;
      $unknown_othersubr_result_cnt_2 = 0;
      $top_0 = $211;
      label = 112;
      break;
    }
   case 109:
    $_sum370 = $_sum367 + 1 | 0;
    $402 = $83 + ($_sum370 << 2) | 0;
    $403 = HEAP32[$402 >> 2] | 0;
    HEAP32[$211 >> 2] = $403;
    $known_othersubr_result_cnt_1 = 1;
    $unknown_othersubr_result_cnt_2 = 0;
    $top_0 = $211;
    label = 112;
    break;
   case 110:
    $405 = ($205 | 0) == 0;
    if ($405) {
      label = 111;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 111:
    $407 = HEAP32[$seed >> 2] | 0;
    $408 = ($407 | 0) > 32767;
    $409 = $408 & 1;
    $_382 = $409 + $407 | 0;
    HEAP32[$211 >> 2] = $_382;
    $410 = HEAP32[$seed >> 2] | 0;
    $411 = 65536 - $410 | 0;
    $412 = _FT_MulFix($410, $411) | 0;
    $413 = ($412 | 0) == 0;
    $414 = $412 + 10355 | 0;
    $storemerge = $413 ? $414 : $412;
    HEAP32[$seed >> 2] = $storemerge;
    $known_othersubr_result_cnt_1 = 1;
    $unknown_othersubr_result_cnt_2 = 0;
    $top_0 = $211;
    label = 112;
    break;
   case 112:
    $415 = $top_0 + ($known_othersubr_result_cnt_1 << 2) | 0;
    $416 = HEAP32[$1 >> 2] | 0;
    $417 = $416 + 1136 | 0;
    HEAP32[$417 >> 2] = $415;
    $418 = $ip_2 >>> 0 < $limit_0_ph_ph433 >>> 0;
    if ($418) {
      $large_int_0_ph411 = $large_int_2;
      $unknown_othersubr_result_cnt_0_ph412 = $unknown_othersubr_result_cnt_2;
      $known_othersubr_result_cnt_0_ph413 = $known_othersubr_result_cnt_1;
      $ip_0_ph414 = $ip_2;
      label = 8;
      break;
    } else {
      $_0 = 0;
      label = 175;
      break;
    }
   case 113:
    $420 = 5249280 + ($op_0 << 2) | 0;
    $421 = HEAP32[$420 >> 2] | 0;
    $422 = HEAP32[$1 >> 2] | 0;
    $423 = $422 + 112 | 0;
    $424 = $83;
    $425 = $423;
    $426 = $424 - $425 | 0;
    $427 = $426 >> 2;
    $428 = ($427 | 0) < ($421 | 0);
    if ($428) {
      $_0 = 161;
      label = 175;
      break;
    } else {
      label = 114;
      break;
    }
   case 114:
    $430 = -$421 | 0;
    $431 = $83 + ($430 << 2) | 0;
    if (($op_0 | 0) == 1) {
      label = 115;
      break;
    } else if (($op_0 | 0) == 2) {
      label = 119;
      break;
    } else if (($op_0 | 0) == 3) {
      label = 120;
      break;
    } else if (($op_0 | 0) == 4) {
      label = 121;
      break;
    } else if (($op_0 | 0) == 5) {
      label = 122;
      break;
    } else if (($op_0 | 0) == 6) {
      label = 125;
      break;
    } else if (($op_0 | 0) == 7) {
      label = 127;
      break;
    } else if (($op_0 | 0) == 8) {
      label = 130;
      break;
    } else if (($op_0 | 0) == 9) {
      label = 133;
      break;
    } else if (($op_0 | 0) == 10) {
      label = 136;
      break;
    } else if (($op_0 | 0) == 11) {
      label = 139;
      break;
    } else if (($op_0 | 0) == 12) {
      label = 142;
      break;
    } else if (($op_0 | 0) == 13) {
      label = 145;
      break;
    } else if (($op_0 | 0) == 14) {
      label = 147;
      break;
    } else if (($op_0 | 0) == 20) {
      label = 150;
      break;
    } else if (($op_0 | 0) == 22) {
      label = 151;
      break;
    } else if (($op_0 | 0) == 23) {
      label = 159;
      break;
    } else if (($op_0 | 0) == 24) {
      label = 163;
      break;
    } else if (($op_0 | 0) == 16) {
      label = 165;
      break;
    } else if (($op_0 | 0) == 17) {
      label = 167;
      break;
    } else if (($op_0 | 0) == 18) {
      label = 169;
      break;
    } else if (($op_0 | 0) == 19) {
      label = 171;
      break;
    } else if (($op_0 | 0) == 25) {
      label = 173;
      break;
    } else if (($op_0 | 0) == 15 | ($op_0 | 0) == 26) {
      $zone_1 = $zone_0_ph_ph435;
      $ip_3 = $ip_2;
      $limit_1 = $limit_0_ph_ph433;
      $x_2 = $x_0_ph_ph432;
      $y_2 = $y_0_ph_ph431;
      $orig_x_1 = $orig_x_0_ph_ph430;
      $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
      $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
      $large_int_3 = $large_int_2;
      $top_1 = $431;
      label = 174;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 115:
    _t1_builder_close_contour($3);
    if ($47) {
      label = 116;
      break;
    } else {
      label = 118;
      break;
    }
   case 116:
    $434 = $25 + 8 | 0;
    $435 = $434;
    $436 = HEAP32[$435 >> 2] | 0;
    $437 = $25;
    $438 = HEAP32[$437 >> 2] | 0;
    $439 = $decoder + 20 | 0;
    $440 = HEAP32[$439 >> 2] | 0;
    $441 = $440 + 2 | 0;
    $442 = HEAP16[$441 >> 1] | 0;
    $443 = $442 << 16 >> 16;
    $444 = FUNCTION_TABLE_iii[$436 & 1023]($438, $443) | 0;
    $445 = ($444 | 0) == 0;
    if ($445) {
      label = 117;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 117:
    $447 = $25 + 24 | 0;
    $448 = $447;
    $449 = HEAP32[$448 >> 2] | 0;
    $450 = HEAP32[$437 >> 2] | 0;
    $451 = HEAP32[$439 >> 2] | 0;
    $452 = $decoder + 76 | 0;
    $453 = HEAP32[$452 >> 2] | 0;
    $454 = $453;
    $455 = HEAP32[$1 >> 2] | 0;
    $456 = $455 + 1468 | 0;
    $457 = HEAP32[$456 >> 2] | 0;
    $458 = FUNCTION_TABLE_iiiii[$449 & 1023]($450, $451, $454, $457) | 0;
    label = 118;
    break;
   case 118:
    $460 = $decoder + 12 | 0;
    $461 = HEAP32[$460 >> 2] | 0;
    _FT_GlyphLoader_Add($461);
    $_0 = 0;
    label = 175;
    break;
   case 119:
    HEAP32[$23 >> 2] = 1;
    $463 = HEAP32[$431 >> 2] | 0;
    $464 = HEAP32[$59 >> 2] | 0;
    $465 = $464 + $463 | 0;
    HEAP32[$59 >> 2] = $465;
    $_sum366 = 1 - $421 | 0;
    $466 = $83 + ($_sum366 << 2) | 0;
    $467 = HEAP32[$466 >> 2] | 0;
    HEAP32[$60 >> 2] = $467;
    HEAP32[$61 >> 2] = 0;
    $468 = HEAP32[$43 >> 2] | 0;
    $469 = HEAP32[$431 >> 2] | 0;
    $470 = $469 + $468 | 0;
    $471 = HEAP32[$45 >> 2] | 0;
    $472 = HEAP8[$62] | 0;
    $473 = $472 << 24 >> 24 == 0;
    if ($473) {
      $zone_1 = $zone_0_ph_ph435;
      $ip_3 = $ip_2;
      $limit_1 = $limit_0_ph_ph433;
      $x_2 = $470;
      $y_2 = $471;
      $orig_x_1 = $470;
      $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
      $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
      $large_int_3 = $large_int_2;
      $top_1 = $431;
      label = 174;
      break;
    } else {
      $_0 = 0;
      label = 175;
      break;
    }
   case 120:
    $475 = HEAP32[$431 >> 2] | 0;
    $_sum362 = 1 - $421 | 0;
    $476 = $83 + ($_sum362 << 2) | 0;
    $477 = HEAP32[$476 >> 2] | 0;
    $_sum363 = 2 - $421 | 0;
    $478 = $83 + ($_sum363 << 2) | 0;
    $479 = HEAP32[$478 >> 2] | 0;
    $_sum364 = 3 - $421 | 0;
    $480 = $83 + ($_sum364 << 2) | 0;
    $481 = HEAP32[$480 >> 2] | 0;
    $482 = $481 >> 16;
    $_sum365 = 4 - $421 | 0;
    $483 = $83 + ($_sum365 << 2) | 0;
    $484 = HEAP32[$483 >> 2] | 0;
    $485 = $484 >> 16;
    $486 = _t1operator_seac($422, $475, $477, $479, $482, $485) | 0;
    $_0 = $486;
    label = 175;
    break;
   case 121:
    HEAP32[$23 >> 2] = 1;
    $488 = HEAP32[$431 >> 2] | 0;
    $489 = HEAP32[$63 >> 2] | 0;
    $490 = $489 + $488 | 0;
    HEAP32[$63 >> 2] = $490;
    $_sum359 = 1 - $421 | 0;
    $491 = $83 + ($_sum359 << 2) | 0;
    $492 = HEAP32[$491 >> 2] | 0;
    $493 = HEAP32[$64 >> 2] | 0;
    $494 = $493 + $492 | 0;
    HEAP32[$64 >> 2] = $494;
    $_sum360 = 2 - $421 | 0;
    $495 = $83 + ($_sum360 << 2) | 0;
    $496 = HEAP32[$495 >> 2] | 0;
    HEAP32[$65 >> 2] = $496;
    $_sum361 = 3 - $421 | 0;
    $497 = $83 + ($_sum361 << 2) | 0;
    $498 = HEAP32[$497 >> 2] | 0;
    HEAP32[$66 >> 2] = $498;
    $499 = HEAP32[$43 >> 2] | 0;
    $500 = HEAP32[$431 >> 2] | 0;
    $501 = $500 + $499 | 0;
    $502 = HEAP32[$45 >> 2] | 0;
    $503 = HEAP32[$491 >> 2] | 0;
    $504 = $503 + $502 | 0;
    $505 = HEAP8[$67] | 0;
    $506 = $505 << 24 >> 24 == 0;
    if ($506) {
      $zone_1 = $zone_0_ph_ph435;
      $ip_3 = $ip_2;
      $limit_1 = $limit_0_ph_ph433;
      $x_2 = $501;
      $y_2 = $504;
      $orig_x_1 = $orig_x_0_ph_ph430;
      $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
      $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
      $large_int_3 = $large_int_2;
      $top_1 = $431;
      label = 174;
      break;
    } else {
      $_0 = 0;
      label = 175;
      break;
    }
   case 122:
    $508 = HEAP32[$23 >> 2] | 0;
    $_off384 = $508 - 2 | 0;
    $switch = $_off384 >>> 0 < 2;
    if ($switch) {
      label = 123;
      break;
    } else {
      label = 124;
      break;
    }
   case 123:
    _t1_builder_close_contour($3);
    label = 124;
    break;
   case 124:
    HEAP32[$23 >> 2] = 1;
    $zone_1 = $zone_0_ph_ph435;
    $ip_3 = $ip_2;
    $limit_1 = $limit_0_ph_ph433;
    $x_2 = $x_0_ph_ph432;
    $y_2 = $y_0_ph_ph431;
    $orig_x_1 = $orig_x_0_ph_ph430;
    $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
    $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
    $large_int_3 = $large_int_2;
    $top_1 = $431;
    label = 174;
    break;
   case 125:
    $512 = _t1_builder_start_point($3, $x_0_ph_ph432, $y_0_ph_ph431) | 0;
    $513 = ($512 | 0) == 0;
    if ($513) {
      label = 126;
      break;
    } else {
      $_0 = $512;
      label = 175;
      break;
    }
   case 126:
    $515 = HEAP32[$431 >> 2] | 0;
    $516 = $515 + $x_0_ph_ph432 | 0;
    $x_1 = $516;
    $y_1 = $y_0_ph_ph431;
    label = 135;
    break;
   case 127:
    $518 = HEAP32[$431 >> 2] | 0;
    $519 = $518 + $x_0_ph_ph432 | 0;
    $520 = $422 + 1400 | 0;
    $521 = HEAP32[$520 >> 2] | 0;
    $522 = ($521 | 0) == 0;
    if ($522) {
      label = 128;
      break;
    } else {
      $zone_1 = $zone_0_ph_ph435;
      $ip_3 = $ip_2;
      $limit_1 = $limit_0_ph_ph433;
      $x_2 = $519;
      $y_2 = $y_0_ph_ph431;
      $orig_x_1 = $orig_x_0_ph_ph430;
      $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
      $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
      $large_int_3 = $large_int_2;
      $top_1 = $431;
      label = 174;
      break;
    }
   case 128:
    $524 = HEAP32[$23 >> 2] | 0;
    $525 = ($524 | 0) == 0;
    if ($525) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 129;
      break;
    }
   case 129:
    HEAP32[$23 >> 2] = 2;
    $zone_1 = $zone_0_ph_ph435;
    $ip_3 = $ip_2;
    $limit_1 = $limit_0_ph_ph433;
    $x_2 = $519;
    $y_2 = $y_0_ph_ph431;
    $orig_x_1 = $orig_x_0_ph_ph430;
    $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
    $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
    $large_int_3 = $large_int_2;
    $top_1 = $431;
    label = 174;
    break;
   case 130:
    $528 = _t1_builder_start_point($3, $x_0_ph_ph432, $y_0_ph_ph431) | 0;
    $529 = ($528 | 0) == 0;
    if ($529) {
      label = 131;
      break;
    } else {
      $_0 = $528;
      label = 175;
      break;
    }
   case 131:
    $531 = _t1_builder_check_points($3, 3) | 0;
    $532 = ($531 | 0) == 0;
    if ($532) {
      label = 132;
      break;
    } else {
      $_0 = $531;
      label = 175;
      break;
    }
   case 132:
    $534 = HEAP32[$431 >> 2] | 0;
    $535 = $534 + $x_0_ph_ph432 | 0;
    _t1_builder_add_point($3, $535, $y_0_ph_ph431, 0);
    $_sum356 = 1 - $421 | 0;
    $536 = $83 + ($_sum356 << 2) | 0;
    $537 = HEAP32[$536 >> 2] | 0;
    $538 = $537 + $535 | 0;
    $_sum357 = 2 - $421 | 0;
    $539 = $83 + ($_sum357 << 2) | 0;
    $540 = HEAP32[$539 >> 2] | 0;
    $541 = $540 + $y_0_ph_ph431 | 0;
    _t1_builder_add_point($3, $538, $541, 0);
    $_sum358 = 3 - $421 | 0;
    $542 = $83 + ($_sum358 << 2) | 0;
    $543 = HEAP32[$542 >> 2] | 0;
    $544 = $543 + $541 | 0;
    _t1_builder_add_point($3, $538, $544, 1);
    $zone_1 = $zone_0_ph_ph435;
    $ip_3 = $ip_2;
    $limit_1 = $limit_0_ph_ph433;
    $x_2 = $538;
    $y_2 = $544;
    $orig_x_1 = $orig_x_0_ph_ph430;
    $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
    $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
    $large_int_3 = $large_int_2;
    $top_1 = $431;
    label = 174;
    break;
   case 133:
    $546 = _t1_builder_start_point($3, $x_0_ph_ph432, $y_0_ph_ph431) | 0;
    $547 = ($546 | 0) == 0;
    if ($547) {
      label = 134;
      break;
    } else {
      $_0 = $546;
      label = 175;
      break;
    }
   case 134:
    $549 = HEAP32[$431 >> 2] | 0;
    $550 = $549 + $x_0_ph_ph432 | 0;
    $_sum355 = 1 - $421 | 0;
    $551 = $83 + ($_sum355 << 2) | 0;
    $552 = HEAP32[$551 >> 2] | 0;
    $553 = $552 + $y_0_ph_ph431 | 0;
    $x_1 = $550;
    $y_1 = $553;
    label = 135;
    break;
   case 135:
    $555 = _t1_builder_add_point1($3, $x_1, $y_1) | 0;
    $556 = ($555 | 0) == 0;
    if ($556) {
      $zone_1 = $zone_0_ph_ph435;
      $ip_3 = $ip_2;
      $limit_1 = $limit_0_ph_ph433;
      $x_2 = $x_1;
      $y_2 = $y_1;
      $orig_x_1 = $orig_x_0_ph_ph430;
      $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
      $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
      $large_int_3 = $large_int_2;
      $top_1 = $431;
      label = 174;
      break;
    } else {
      $_0 = $555;
      label = 175;
      break;
    }
   case 136:
    $558 = HEAP32[$431 >> 2] | 0;
    $559 = $558 + $x_0_ph_ph432 | 0;
    $_sum354 = 1 - $421 | 0;
    $560 = $83 + ($_sum354 << 2) | 0;
    $561 = HEAP32[$560 >> 2] | 0;
    $562 = $561 + $y_0_ph_ph431 | 0;
    $563 = $422 + 1400 | 0;
    $564 = HEAP32[$563 >> 2] | 0;
    $565 = ($564 | 0) == 0;
    if ($565) {
      label = 137;
      break;
    } else {
      $zone_1 = $zone_0_ph_ph435;
      $ip_3 = $ip_2;
      $limit_1 = $limit_0_ph_ph433;
      $x_2 = $559;
      $y_2 = $562;
      $orig_x_1 = $orig_x_0_ph_ph430;
      $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
      $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
      $large_int_3 = $large_int_2;
      $top_1 = $431;
      label = 174;
      break;
    }
   case 137:
    $567 = HEAP32[$23 >> 2] | 0;
    $568 = ($567 | 0) == 0;
    if ($568) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 138;
      break;
    }
   case 138:
    HEAP32[$23 >> 2] = 2;
    $zone_1 = $zone_0_ph_ph435;
    $ip_3 = $ip_2;
    $limit_1 = $limit_0_ph_ph433;
    $x_2 = $559;
    $y_2 = $562;
    $orig_x_1 = $orig_x_0_ph_ph430;
    $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
    $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
    $large_int_3 = $large_int_2;
    $top_1 = $431;
    label = 174;
    break;
   case 139:
    $571 = _t1_builder_start_point($3, $x_0_ph_ph432, $y_0_ph_ph431) | 0;
    $572 = ($571 | 0) == 0;
    if ($572) {
      label = 140;
      break;
    } else {
      $_0 = $571;
      label = 175;
      break;
    }
   case 140:
    $574 = _t1_builder_check_points($3, 3) | 0;
    $575 = ($574 | 0) == 0;
    if ($575) {
      label = 141;
      break;
    } else {
      $_0 = $574;
      label = 175;
      break;
    }
   case 141:
    $577 = HEAP32[$431 >> 2] | 0;
    $578 = $577 + $x_0_ph_ph432 | 0;
    $_sum349 = 1 - $421 | 0;
    $579 = $83 + ($_sum349 << 2) | 0;
    $580 = HEAP32[$579 >> 2] | 0;
    $581 = $580 + $y_0_ph_ph431 | 0;
    _t1_builder_add_point($3, $578, $581, 0);
    $_sum350 = 2 - $421 | 0;
    $582 = $83 + ($_sum350 << 2) | 0;
    $583 = HEAP32[$582 >> 2] | 0;
    $584 = $583 + $578 | 0;
    $_sum351 = 3 - $421 | 0;
    $585 = $83 + ($_sum351 << 2) | 0;
    $586 = HEAP32[$585 >> 2] | 0;
    $587 = $586 + $581 | 0;
    _t1_builder_add_point($3, $584, $587, 0);
    $_sum352 = 4 - $421 | 0;
    $588 = $83 + ($_sum352 << 2) | 0;
    $589 = HEAP32[$588 >> 2] | 0;
    $590 = $589 + $584 | 0;
    $_sum353 = 5 - $421 | 0;
    $591 = $83 + ($_sum353 << 2) | 0;
    $592 = HEAP32[$591 >> 2] | 0;
    $593 = $592 + $587 | 0;
    _t1_builder_add_point($3, $590, $593, 1);
    $zone_1 = $zone_0_ph_ph435;
    $ip_3 = $ip_2;
    $limit_1 = $limit_0_ph_ph433;
    $x_2 = $590;
    $y_2 = $593;
    $orig_x_1 = $orig_x_0_ph_ph430;
    $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
    $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
    $large_int_3 = $large_int_2;
    $top_1 = $431;
    label = 174;
    break;
   case 142:
    $595 = _t1_builder_start_point($3, $x_0_ph_ph432, $y_0_ph_ph431) | 0;
    $596 = ($595 | 0) == 0;
    if ($596) {
      label = 143;
      break;
    } else {
      $_0 = $595;
      label = 175;
      break;
    }
   case 143:
    $598 = _t1_builder_check_points($3, 3) | 0;
    $599 = ($598 | 0) == 0;
    if ($599) {
      label = 144;
      break;
    } else {
      $_0 = $598;
      label = 175;
      break;
    }
   case 144:
    $601 = HEAP32[$431 >> 2] | 0;
    $602 = $601 + $y_0_ph_ph431 | 0;
    _t1_builder_add_point($3, $x_0_ph_ph432, $602, 0);
    $_sum346 = 1 - $421 | 0;
    $603 = $83 + ($_sum346 << 2) | 0;
    $604 = HEAP32[$603 >> 2] | 0;
    $605 = $604 + $x_0_ph_ph432 | 0;
    $_sum347 = 2 - $421 | 0;
    $606 = $83 + ($_sum347 << 2) | 0;
    $607 = HEAP32[$606 >> 2] | 0;
    $608 = $607 + $602 | 0;
    _t1_builder_add_point($3, $605, $608, 0);
    $_sum348 = 3 - $421 | 0;
    $609 = $83 + ($_sum348 << 2) | 0;
    $610 = HEAP32[$609 >> 2] | 0;
    $611 = $610 + $605 | 0;
    _t1_builder_add_point($3, $611, $608, 1);
    $zone_1 = $zone_0_ph_ph435;
    $ip_3 = $ip_2;
    $limit_1 = $limit_0_ph_ph433;
    $x_2 = $611;
    $y_2 = $608;
    $orig_x_1 = $orig_x_0_ph_ph430;
    $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
    $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
    $large_int_3 = $large_int_2;
    $top_1 = $431;
    label = 174;
    break;
   case 145:
    $613 = _t1_builder_start_point($3, $x_0_ph_ph432, $y_0_ph_ph431) | 0;
    $614 = ($613 | 0) == 0;
    if ($614) {
      label = 146;
      break;
    } else {
      $_0 = $613;
      label = 175;
      break;
    }
   case 146:
    $616 = HEAP32[$431 >> 2] | 0;
    $617 = $616 + $y_0_ph_ph431 | 0;
    $x_1 = $x_0_ph_ph432;
    $y_1 = $617;
    label = 135;
    break;
   case 147:
    $619 = HEAP32[$431 >> 2] | 0;
    $620 = $619 + $y_0_ph_ph431 | 0;
    $621 = $422 + 1400 | 0;
    $622 = HEAP32[$621 >> 2] | 0;
    $623 = ($622 | 0) == 0;
    if ($623) {
      label = 148;
      break;
    } else {
      $zone_1 = $zone_0_ph_ph435;
      $ip_3 = $ip_2;
      $limit_1 = $limit_0_ph_ph433;
      $x_2 = $x_0_ph_ph432;
      $y_2 = $620;
      $orig_x_1 = $orig_x_0_ph_ph430;
      $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
      $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
      $large_int_3 = $large_int_2;
      $top_1 = $431;
      label = 174;
      break;
    }
   case 148:
    $625 = HEAP32[$23 >> 2] | 0;
    $626 = ($625 | 0) == 0;
    if ($626) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 149;
      break;
    }
   case 149:
    HEAP32[$23 >> 2] = 2;
    $zone_1 = $zone_0_ph_ph435;
    $ip_3 = $ip_2;
    $limit_1 = $limit_0_ph_ph433;
    $x_2 = $x_0_ph_ph432;
    $y_2 = $620;
    $orig_x_1 = $orig_x_0_ph_ph430;
    $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
    $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
    $large_int_3 = $large_int_2;
    $top_1 = $431;
    label = 174;
    break;
   case 150:
    $629 = HEAP32[$431 >> 2] | 0;
    $_sum345 = 1 - $421 | 0;
    $630 = $83 + ($_sum345 << 2) | 0;
    $631 = HEAP32[$630 >> 2] | 0;
    $632 = _FT_DivFix($629, $631) | 0;
    HEAP32[$431 >> 2] = $632;
    $zone_1 = $zone_0_ph_ph435;
    $ip_3 = $ip_2;
    $limit_1 = $limit_0_ph_ph433;
    $x_2 = $x_0_ph_ph432;
    $y_2 = $y_0_ph_ph431;
    $orig_x_1 = $orig_x_0_ph_ph430;
    $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
    $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
    $large_int_3 = 0;
    $top_1 = $630;
    label = 174;
    break;
   case 151:
    $634 = HEAP32[$431 >> 2] | 0;
    $635 = $634 >> 16;
    $636 = ($635 | 0) < 0;
    if ($636) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 152;
      break;
    }
   case 152:
    $638 = $422 + 1364 | 0;
    $639 = HEAP32[$638 >> 2] | 0;
    $640 = ($635 | 0) < ($639 | 0);
    if ($640) {
      label = 153;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 153:
    $642 = $422 + 1140 | 0;
    $643 = $zone_0_ph_ph435;
    $644 = $642;
    $645 = $643 - $644 | 0;
    $646 = ($645 | 0) > 180;
    if ($646) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 154;
      break;
    }
   case 154:
    $648 = $zone_0_ph_ph435 | 0;
    HEAP32[$648 >> 2] = $ip_2;
    $649 = $zone_0_ph_ph435 + 12 | 0;
    $650 = HEAP32[$1 >> 2] | 0;
    $651 = $650 + 1368 | 0;
    $652 = HEAP32[$651 >> 2] | 0;
    $653 = $652 + ($635 << 2) | 0;
    $654 = HEAP32[$653 >> 2] | 0;
    $655 = $zone_0_ph_ph435 + 16 | 0;
    HEAP32[$655 >> 2] = $654;
    $656 = HEAP32[$1 >> 2] | 0;
    $657 = $656 + 1372 | 0;
    $658 = HEAP32[$657 >> 2] | 0;
    $659 = ($658 | 0) == 0;
    if ($659) {
      label = 156;
      break;
    } else {
      label = 155;
      break;
    }
   case 155:
    $661 = $658 + ($635 << 2) | 0;
    $662 = HEAP32[$661 >> 2] | 0;
    $663 = $654 + $662 | 0;
    $664 = $zone_0_ph_ph435 + 20 | 0;
    HEAP32[$664 >> 2] = $663;
    label = 157;
    break;
   case 156:
    $666 = $656 + 1360 | 0;
    $667 = HEAP32[$666 >> 2] | 0;
    $668 = ($667 | 0) < 0;
    $_383 = $668 ? 0 : $667;
    $669 = $654 + $_383 | 0;
    HEAP32[$655 >> 2] = $669;
    $670 = $635 + 1 | 0;
    $671 = HEAP32[$1 >> 2] | 0;
    $672 = $671 + 1368 | 0;
    $673 = HEAP32[$672 >> 2] | 0;
    $674 = $673 + ($670 << 2) | 0;
    $675 = HEAP32[$674 >> 2] | 0;
    $676 = $zone_0_ph_ph435 + 20 | 0;
    HEAP32[$676 >> 2] = $675;
    label = 157;
    break;
   case 157:
    $678 = HEAP32[$655 >> 2] | 0;
    $679 = $649 | 0;
    HEAP32[$679 >> 2] = $678;
    $680 = HEAP32[$655 >> 2] | 0;
    $681 = ($680 | 0) == 0;
    if ($681) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 158;
      break;
    }
   case 158:
    $683 = HEAP32[$1 >> 2] | 0;
    $684 = $683 + 1344 | 0;
    HEAP32[$684 >> 2] = $649;
    $685 = HEAP32[$655 >> 2] | 0;
    $686 = $zone_0_ph_ph435 + 20 | 0;
    $687 = HEAP32[$686 >> 2] | 0;
    $zone_1 = $649;
    $ip_3 = $685;
    $limit_1 = $687;
    $x_2 = $x_0_ph_ph432;
    $y_2 = $y_0_ph_ph431;
    $orig_x_1 = $orig_x_0_ph_ph430;
    $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
    $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
    $large_int_3 = $large_int_2;
    $top_1 = $431;
    label = 174;
    break;
   case 159:
    $689 = ($known_othersubr_result_cnt_0_ph413 | 0) > 0;
    if ($689) {
      label = 160;
      break;
    } else {
      label = 161;
      break;
    }
   case 160:
    $691 = $known_othersubr_result_cnt_0_ph413 - 1 | 0;
    $zone_1 = $zone_0_ph_ph435;
    $ip_3 = $ip_2;
    $limit_1 = $limit_0_ph_ph433;
    $x_2 = $x_0_ph_ph432;
    $y_2 = $y_0_ph_ph431;
    $orig_x_1 = $orig_x_0_ph_ph430;
    $known_othersubr_result_cnt_2 = $691;
    $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
    $large_int_3 = $large_int_2;
    $top_1 = $431;
    label = 174;
    break;
   case 161:
    $693 = ($unknown_othersubr_result_cnt_1 | 0) == 0;
    if ($693) {
      $_0 = 160;
      label = 175;
      break;
    } else {
      label = 162;
      break;
    }
   case 162:
    $695 = $unknown_othersubr_result_cnt_1 - 1 | 0;
    $_sum344 = 1 - $421 | 0;
    $696 = $83 + ($_sum344 << 2) | 0;
    $zone_1 = $zone_0_ph_ph435;
    $ip_3 = $ip_2;
    $limit_1 = $limit_0_ph_ph433;
    $x_2 = $x_0_ph_ph432;
    $y_2 = $y_0_ph_ph431;
    $orig_x_1 = $orig_x_0_ph_ph430;
    $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
    $unknown_othersubr_result_cnt_3 = $695;
    $large_int_3 = $large_int_2;
    $top_1 = $696;
    label = 174;
    break;
   case 163:
    $698 = $422 + 1140 | 0;
    $699 = $zone_0_ph_ph435 >>> 0 > $698 >>> 0;
    if ($699) {
      label = 164;
      break;
    } else {
      $_0 = 160;
      label = 175;
      break;
    }
   case 164:
    $701 = $zone_0_ph_ph435 - 12 | 0;
    $702 = $701 | 0;
    $703 = HEAP32[$702 >> 2] | 0;
    $704 = $zone_0_ph_ph435 - 12 + 8 | 0;
    $705 = HEAP32[$704 >> 2] | 0;
    $706 = $422 + 1344 | 0;
    HEAP32[$706 >> 2] = $701;
    $zone_1 = $701;
    $ip_3 = $703;
    $limit_1 = $705;
    $x_2 = $x_0_ph_ph432;
    $y_2 = $y_0_ph_ph431;
    $orig_x_1 = $orig_x_0_ph_ph430;
    $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
    $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
    $large_int_3 = $large_int_2;
    $top_1 = $431;
    label = 174;
    break;
   case 165:
    if ($47) {
      label = 166;
      break;
    } else {
      $zone_1 = $zone_0_ph_ph435;
      $ip_3 = $ip_2;
      $limit_1 = $limit_0_ph_ph433;
      $x_2 = $x_0_ph_ph432;
      $y_2 = $y_0_ph_ph431;
      $orig_x_1 = $orig_x_0_ph_ph430;
      $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
      $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
      $large_int_3 = $large_int_2;
      $top_1 = $431;
      label = 174;
      break;
    }
   case 166:
    $709 = HEAP32[$69 >> 2] | 0;
    $710 = HEAP32[$70 >> 2] | 0;
    FUNCTION_TABLE_viii[$709 & 1023]($710, 1, $431);
    $zone_1 = $zone_0_ph_ph435;
    $ip_3 = $ip_2;
    $limit_1 = $limit_0_ph_ph433;
    $x_2 = $x_0_ph_ph432;
    $y_2 = $y_0_ph_ph431;
    $orig_x_1 = $orig_x_0_ph_ph430;
    $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
    $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
    $large_int_3 = $large_int_2;
    $top_1 = $431;
    label = 174;
    break;
   case 167:
    if ($47) {
      label = 168;
      break;
    } else {
      $zone_1 = $zone_0_ph_ph435;
      $ip_3 = $ip_2;
      $limit_1 = $limit_0_ph_ph433;
      $x_2 = $x_0_ph_ph432;
      $y_2 = $y_0_ph_ph431;
      $orig_x_1 = $orig_x_0_ph_ph430;
      $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
      $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
      $large_int_3 = $large_int_2;
      $top_1 = $431;
      label = 174;
      break;
    }
   case 168:
    $713 = HEAP32[$72 >> 2] | 0;
    $714 = HEAP32[$73 >> 2] | 0;
    FUNCTION_TABLE_viii[$713 & 1023]($714, 1, $431);
    $zone_1 = $zone_0_ph_ph435;
    $ip_3 = $ip_2;
    $limit_1 = $limit_0_ph_ph433;
    $x_2 = $x_0_ph_ph432;
    $y_2 = $y_0_ph_ph431;
    $orig_x_1 = $orig_x_0_ph_ph430;
    $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
    $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
    $large_int_3 = $large_int_2;
    $top_1 = $431;
    label = 174;
    break;
   case 169:
    if ($47) {
      label = 170;
      break;
    } else {
      $zone_1 = $zone_0_ph_ph435;
      $ip_3 = $ip_2;
      $limit_1 = $limit_0_ph_ph433;
      $x_2 = $x_0_ph_ph432;
      $y_2 = $y_0_ph_ph431;
      $orig_x_1 = $orig_x_0_ph_ph430;
      $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
      $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
      $large_int_3 = $large_int_2;
      $top_1 = $431;
      label = 174;
      break;
    }
   case 170:
    $717 = HEAP32[$431 >> 2] | 0;
    $718 = $717 + $orig_x_0_ph_ph430 | 0;
    HEAP32[$431 >> 2] = $718;
    $719 = HEAP32[$75 >> 2] | 0;
    $720 = HEAP32[$76 >> 2] | 0;
    FUNCTION_TABLE_viii[$719 & 1023]($720, 0, $431);
    $zone_1 = $zone_0_ph_ph435;
    $ip_3 = $ip_2;
    $limit_1 = $limit_0_ph_ph433;
    $x_2 = $x_0_ph_ph432;
    $y_2 = $y_0_ph_ph431;
    $orig_x_1 = $orig_x_0_ph_ph430;
    $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
    $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
    $large_int_3 = $large_int_2;
    $top_1 = $431;
    label = 174;
    break;
   case 171:
    if ($47) {
      label = 172;
      break;
    } else {
      $zone_1 = $zone_0_ph_ph435;
      $ip_3 = $ip_2;
      $limit_1 = $limit_0_ph_ph433;
      $x_2 = $x_0_ph_ph432;
      $y_2 = $y_0_ph_ph431;
      $orig_x_1 = $orig_x_0_ph_ph430;
      $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
      $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
      $large_int_3 = $large_int_2;
      $top_1 = $431;
      label = 174;
      break;
    }
   case 172:
    $723 = HEAP32[$431 >> 2] | 0;
    $724 = $723 + $orig_x_0_ph_ph430 | 0;
    HEAP32[$431 >> 2] = $724;
    $_sum342 = 2 - $421 | 0;
    $725 = $83 + ($_sum342 << 2) | 0;
    $726 = HEAP32[$725 >> 2] | 0;
    $727 = $726 + $orig_x_0_ph_ph430 | 0;
    HEAP32[$725 >> 2] = $727;
    $_sum343 = 4 - $421 | 0;
    $728 = $83 + ($_sum343 << 2) | 0;
    $729 = HEAP32[$728 >> 2] | 0;
    $730 = $729 + $orig_x_0_ph_ph430 | 0;
    HEAP32[$728 >> 2] = $730;
    $731 = HEAP32[$78 >> 2] | 0;
    $732 = HEAP32[$79 >> 2] | 0;
    FUNCTION_TABLE_viii[$731 & 1023]($732, 0, $431);
    $zone_1 = $zone_0_ph_ph435;
    $ip_3 = $ip_2;
    $limit_1 = $limit_0_ph_ph433;
    $x_2 = $x_0_ph_ph432;
    $y_2 = $y_0_ph_ph431;
    $orig_x_1 = $orig_x_0_ph_ph430;
    $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
    $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
    $large_int_3 = $large_int_2;
    $top_1 = $431;
    label = 174;
    break;
   case 173:
    $734 = HEAP32[$431 >> 2] | 0;
    $_sum = 1 - $421 | 0;
    $735 = $83 + ($_sum << 2) | 0;
    $736 = HEAP32[$735 >> 2] | 0;
    $737 = $422 + 1400 | 0;
    HEAP32[$737 >> 2] = 0;
    $zone_1 = $zone_0_ph_ph435;
    $ip_3 = $ip_2;
    $limit_1 = $limit_0_ph_ph433;
    $x_2 = $734;
    $y_2 = $736;
    $orig_x_1 = $orig_x_0_ph_ph430;
    $known_othersubr_result_cnt_2 = $known_othersubr_result_cnt_0_ph413;
    $unknown_othersubr_result_cnt_3 = $unknown_othersubr_result_cnt_1;
    $large_int_3 = $large_int_2;
    $top_1 = $431;
    label = 174;
    break;
   case 174:
    $738 = HEAP32[$1 >> 2] | 0;
    $739 = $738 + 1136 | 0;
    HEAP32[$739 >> 2] = $top_1;
    $740 = $ip_3 >>> 0 < $limit_1 >>> 0;
    if ($740) {
      $large_int_0_ph_ph427 = $large_int_3;
      $unknown_othersubr_result_cnt_0_ph_ph428 = $unknown_othersubr_result_cnt_3;
      $known_othersubr_result_cnt_0_ph_ph429 = $known_othersubr_result_cnt_2;
      $orig_x_0_ph_ph430 = $orig_x_1;
      $y_0_ph_ph431 = $y_2;
      $x_0_ph_ph432 = $x_2;
      $limit_0_ph_ph433 = $limit_1;
      $ip_0_ph_ph434 = $ip_3;
      $zone_0_ph_ph435 = $zone_1;
      label = 7;
      break;
    } else {
      $_0 = 0;
      label = 175;
      break;
    }
   case 175:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _t1_cmap_custom_init($cmap) {
  $cmap = $cmap | 0;
  var $2 = 0, $3 = 0, $6 = 0;
  $2 = HEAP32[$cmap >> 2] | 0;
  $3 = $2 + 372 | 0;
  $6 = HEAP32[$2 + 376 >> 2] | 0;
  HEAP32[$cmap + 16 >> 2] = $6;
  HEAP32[$cmap + 20 >> 2] = (HEAP32[$3 + 8 >> 2] | 0) - $6 | 0;
  HEAP32[$cmap + 24 >> 2] = HEAP32[$3 + 12 >> 2] | 0;
  return 0;
}
function _t1_cmap_custom_done($cmap) {
  $cmap = $cmap | 0;
  HEAP32[$cmap + 24 >> 2] = 0;
  HEAP32[$cmap + 16 >> 2] = 0;
  HEAP32[$cmap + 20 >> 2] = 0;
  return;
}
function _t1_cmap_custom_char_index($cmap, $char_code) {
  $cmap = $cmap | 0;
  $char_code = $char_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 >>> 0 > $char_code >>> 0;
    if ($3) {
      $result_0 = 0;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $cmap + 20 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + $2 | 0;
    $8 = $7 >>> 0 > $char_code >>> 0;
    if ($8) {
      label = 3;
      break;
    } else {
      $result_0 = 0;
      label = 4;
      break;
    }
   case 3:
    $10 = $cmap + 24 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 + ($char_code << 1) | 0;
    $13 = HEAP16[$12 >> 1] | 0;
    $14 = $13 & 65535;
    $result_0 = $14;
    label = 4;
    break;
   case 4:
    return $result_0 | 0;
  }
  return 0;
}
function _t1_cmap_custom_char_next($cmap, $pchar_code) {
  $cmap = $cmap | 0;
  $pchar_code = $pchar_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_ = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $result_0 = 0, $char_code_0 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $result_1 = 0, $char_code_1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$pchar_code >> 2] | 0;
    $2 = $1 + 1 | 0;
    $3 = $cmap + 16 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 >>> 0 < $4 >>> 0;
    $_ = $5 ? $4 : $2;
    $6 = $cmap + 24 | 0;
    $7 = $cmap + 20 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 + $4 | 0;
    $char_code_0 = $_;
    $result_0 = 0;
    label = 2;
    break;
   case 2:
    $11 = $char_code_0 >>> 0 < $9 >>> 0;
    if ($11) {
      label = 3;
      break;
    } else {
      $char_code_1 = 0;
      $result_1 = $result_0;
      label = 4;
      break;
    }
   case 3:
    $13 = HEAP32[$6 >> 2] | 0;
    $14 = $13 + ($char_code_0 << 1) | 0;
    $15 = HEAP16[$14 >> 1] | 0;
    $16 = $15 & 65535;
    $17 = $15 << 16 >> 16 == 0;
    $18 = $char_code_0 + 1 | 0;
    if ($17) {
      $char_code_0 = $18;
      $result_0 = $16;
      label = 2;
      break;
    } else {
      $char_code_1 = $char_code_0;
      $result_1 = $16;
      label = 4;
      break;
    }
   case 4:
    HEAP32[$pchar_code >> 2] = $char_code_1;
    return $result_1 | 0;
  }
  return 0;
}
function _afm_parser_init($parser, $memory, $base, $limit) {
  $parser = $parser | 0;
  $memory = $memory | 0;
  $base = $base | 0;
  $limit = $limit | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = _ft_mem_alloc($memory, 16, $error) | 0;
    $2 = HEAP32[$error >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $_0 = $2;
      label = 3;
      break;
    }
   case 2:
    $5 = $1;
    $6 = $1 + 4 | 0;
    $7 = $6;
    HEAP32[$7 >> 2] = $base;
    $8 = $1;
    HEAP32[$8 >> 2] = $base;
    $9 = $1 + 8 | 0;
    $10 = $9;
    HEAP32[$10 >> 2] = $limit;
    $11 = $1 + 12 | 0;
    $12 = $11;
    HEAP32[$12 >> 2] = 2;
    $13 = $parser | 0;
    HEAP32[$13 >> 2] = $memory;
    $14 = $parser + 4 | 0;
    HEAP32[$14 >> 2] = $5;
    $15 = $parser + 8 | 0;
    HEAP32[$15 >> 2] = 0;
    $16 = $parser + 12 | 0;
    HEAP32[$16 >> 2] = 0;
    $_0 = 0;
    label = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _afm_parser_done($parser) {
  $parser = $parser | 0;
  var $3 = 0;
  $3 = $parser + 4 | 0;
  _ft_mem_free(HEAP32[$parser >> 2] | 0, HEAP32[$3 >> 2] | 0);
  HEAP32[$3 >> 2] = 0;
  return;
}
function _afm_parser_parse($parser) {
  $parser = $parser | 0;
  var $len = 0, $metrics_sets = 0, $shared_vals = 0, $n = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $or_cond35 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $error_037 = 0, $50 = 0, $51 = 0, $error_0_be = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $58 = 0, $60 = 0, $61 = 0, $63 = 0, $65 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $73 = 0, $74 = 0, $76 = 0, $78 = 0, $79 = 0, $81 = 0, $83 = 0, $84 = 0, $86 = 0, $87 = 0, $88 = 0, $90 = 0, $91 = 0, $error_1 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 44 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $len = __stackBase__ | 0;
    $metrics_sets = __stackBase__ + 4 | 0;
    $shared_vals = __stackBase__ + 8 | 0;
    $n = __stackBase__ + 40 | 0;
    $1 = $parser | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $parser + 8 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    HEAP32[$metrics_sets >> 2] = 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $_0 = 6;
      label = 22;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = _afm_parser_next_key($parser, $len) | 0;
    $8 = ($7 | 0) != 0;
    $9 = HEAP32[$len >> 2] | 0;
    $10 = ($9 | 0) == 16;
    $or_cond35 = $8 & $10;
    if ($or_cond35) {
      label = 3;
      break;
    } else {
      $_0 = 2;
      label = 22;
      break;
    }
   case 3:
    $12 = _strncmp($7 | 0, 5323984, 16) | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 4;
      break;
    } else {
      $_0 = 2;
      label = 22;
      break;
    }
   case 4:
    $14 = _afm_parser_next_key($parser, $len) | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      $error_1 = 160;
      label = 21;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $16 = $shared_vals | 0;
    $17 = $shared_vals | 0;
    $18 = $shared_vals + 4 | 0;
    $19 = $18;
    $20 = $4 | 0;
    $21 = $shared_vals | 0;
    $22 = $shared_vals | 0;
    $23 = $shared_vals + 8 | 0;
    $24 = $shared_vals + 16 | 0;
    $25 = $shared_vals + 24 | 0;
    $26 = $shared_vals + 4 | 0;
    $27 = $26;
    $28 = $4 + 4 | 0;
    $29 = $shared_vals + 12 | 0;
    $30 = $29;
    $31 = $4 + 8 | 0;
    $32 = $shared_vals + 20 | 0;
    $33 = $32;
    $34 = $4 + 12 | 0;
    $35 = $shared_vals + 28 | 0;
    $36 = $35;
    $37 = $4 + 16 | 0;
    $38 = $shared_vals | 0;
    $39 = $shared_vals | 0;
    $40 = $shared_vals + 4 | 0;
    $41 = $40;
    $42 = $4 + 20 | 0;
    $43 = $shared_vals | 0;
    $44 = $shared_vals | 0;
    $45 = $shared_vals + 4 | 0;
    $46 = $45;
    $47 = $4 + 24 | 0;
    $error_037 = 160;
    $49 = $14;
    label = 6;
    break;
   case 6:
    $50 = HEAP32[$len >> 2] | 0;
    $51 = _afm_tokenize($49, $50) | 0;
    if (($51 | 0) == 40) {
      label = 8;
      break;
    } else if (($51 | 0) == 30) {
      label = 10;
      break;
    } else if (($51 | 0) == 26) {
      label = 12;
      break;
    } else if (($51 | 0) == 0) {
      label = 14;
      break;
    } else if (($51 | 0) == 14) {
      label = 16;
      break;
    } else if (($51 | 0) == 45) {
      label = 18;
      break;
    } else if (($51 | 0) == 49) {
      label = 20;
      break;
    } else if (($51 | 0) == 20) {
      $_0 = 0;
      label = 22;
      break;
    } else {
      $error_0_be = $error_037;
      label = 7;
      break;
    }
   case 7:
    $52 = _afm_parser_next_key($parser, $len) | 0;
    $53 = ($52 | 0) == 0;
    if ($53) {
      $error_1 = $error_0_be;
      label = 21;
      break;
    } else {
      $error_037 = $error_0_be;
      $49 = $52;
      label = 6;
      break;
    }
   case 8:
    $55 = _afm_parser_read_int($parser, $metrics_sets) | 0;
    $56 = ($55 | 0) == 0;
    if ($56) {
      label = 9;
      break;
    } else {
      $error_1 = $error_037;
      label = 21;
      break;
    }
   case 9:
    $58 = HEAP32[$metrics_sets >> 2] | 0;
    if (($58 | 0) == 2 | ($58 | 0) == 0) {
      $error_0_be = $error_037;
      label = 7;
      break;
    } else {
      $error_1 = 7;
      label = 21;
      break;
    }
   case 10:
    HEAP32[$17 >> 2] = 4;
    $60 = _afm_parser_read_vals($parser, $16, 1) | 0;
    $61 = ($60 | 0) == 1;
    if ($61) {
      label = 11;
      break;
    } else {
      $error_1 = $error_037;
      label = 21;
      break;
    }
   case 11:
    $63 = HEAP8[$19] | 0;
    HEAP8[$20] = $63;
    $error_0_be = $error_037;
    label = 7;
    break;
   case 12:
    HEAP32[$22 >> 2] = 2;
    HEAP32[$23 >> 2] = 2;
    HEAP32[$24 >> 2] = 2;
    HEAP32[$25 >> 2] = 2;
    $65 = _afm_parser_read_vals($parser, $21, 4) | 0;
    $66 = ($65 | 0) == 4;
    if ($66) {
      label = 13;
      break;
    } else {
      $error_1 = $error_037;
      label = 21;
      break;
    }
   case 13:
    $68 = HEAP32[$27 >> 2] | 0;
    HEAP32[$28 >> 2] = $68;
    $69 = HEAP32[$30 >> 2] | 0;
    HEAP32[$31 >> 2] = $69;
    $70 = HEAP32[$33 >> 2] | 0;
    HEAP32[$34 >> 2] = $70;
    $71 = HEAP32[$36 >> 2] | 0;
    HEAP32[$37 >> 2] = $71;
    $error_0_be = $error_037;
    label = 7;
    break;
   case 14:
    HEAP32[$39 >> 2] = 2;
    $73 = _afm_parser_read_vals($parser, $38, 1) | 0;
    $74 = ($73 | 0) == 1;
    if ($74) {
      label = 15;
      break;
    } else {
      $error_1 = $error_037;
      label = 21;
      break;
    }
   case 15:
    $76 = HEAP32[$41 >> 2] | 0;
    HEAP32[$42 >> 2] = $76;
    $error_0_be = $error_037;
    label = 7;
    break;
   case 16:
    HEAP32[$44 >> 2] = 2;
    $78 = _afm_parser_read_vals($parser, $43, 1) | 0;
    $79 = ($78 | 0) == 1;
    if ($79) {
      label = 17;
      break;
    } else {
      $error_1 = $error_037;
      label = 21;
      break;
    }
   case 17:
    $81 = HEAP32[$46 >> 2] | 0;
    HEAP32[$47 >> 2] = $81;
    $error_0_be = $error_037;
    label = 7;
    break;
   case 18:
    HEAP32[$n >> 2] = 0;
    $83 = _afm_parser_read_int($parser, $n) | 0;
    $84 = ($83 | 0) == 0;
    if ($84) {
      label = 19;
      break;
    } else {
      $error_1 = $error_037;
      label = 21;
      break;
    }
   case 19:
    $86 = HEAP32[$n >> 2] | 0;
    $87 = _afm_parser_skip_section($parser, $86) | 0;
    $88 = ($87 | 0) == 0;
    if ($88) {
      $error_0_be = 0;
      label = 7;
      break;
    } else {
      $_0 = $87;
      label = 22;
      break;
    }
   case 20:
    $90 = _afm_parse_kern_data($parser) | 0;
    $91 = ($90 | 0) == 0;
    if ($91) {
      $_0 = 0;
      label = 22;
      break;
    } else {
      $error_1 = $90;
      label = 21;
      break;
    }
   case 21:
    $92 = $4 + 28 | 0;
    $93 = HEAP32[$92 >> 2] | 0;
    $94 = $93;
    _ft_mem_free($2, $94);
    HEAP32[$92 >> 2] = 0;
    $95 = $4 + 32 | 0;
    HEAP32[$95 >> 2] = 0;
    $96 = $4 + 36 | 0;
    $97 = HEAP32[$96 >> 2] | 0;
    $98 = $97;
    _ft_mem_free($2, $98);
    HEAP32[$96 >> 2] = 0;
    $99 = $4 + 40 | 0;
    HEAP32[$99 >> 2] = 0;
    $100 = $4 | 0;
    HEAP8[$100] = 0;
    $_0 = $error_1;
    label = 22;
    break;
   case 22:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _t1_cmap_standard_init($cmap) {
  $cmap = $cmap | 0;
  _t1_cmap_std_init($cmap, 0);
  return 0;
}
function _t1_cmap_std_done($cmap) {
  $cmap = $cmap | 0;
  _memset($cmap + 16 | 0, 0, 16);
  return;
}
function _t1_cmap_std_char_index($cmap, $char_code) {
  $cmap = $cmap | 0;
  $char_code = $char_code | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $n_012 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $char_code >>> 0 < 256;
    if ($1) {
      label = 2;
      break;
    } else {
      $result_0 = 0;
      label = 8;
      break;
    }
   case 2:
    $3 = $cmap + 16 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + ($char_code << 1) | 0;
    $6 = HEAP16[$5 >> 1] | 0;
    $7 = $6 & 65535;
    $8 = $cmap + 20 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = FUNCTION_TABLE_ii[$9 & 1023]($7) | 0;
    $11 = $cmap + 24 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      $result_0 = 0;
      label = 8;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $14 = $cmap + 28 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $n_012 = 0;
    label = 4;
    break;
   case 4:
    $17 = $15 + ($n_012 << 2) | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $21 = HEAP8[$18] | 0;
    $22 = HEAP8[$10] | 0;
    $23 = $21 << 24 >> 24 == $22 << 24 >> 24;
    if ($23) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $25 = _strcmp($18 | 0, $10 | 0) | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      $result_0 = $n_012;
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $28 = $n_012 + 1 | 0;
    $29 = HEAP32[$11 >> 2] | 0;
    $30 = $28 >>> 0 < $29 >>> 0;
    if ($30) {
      $n_012 = $28;
      label = 4;
      break;
    } else {
      $result_0 = 0;
      label = 8;
      break;
    }
   case 8:
    return $result_0 | 0;
  }
  return 0;
}
function _t1_cmap_std_char_next($cmap, $pchar_code) {
  $cmap = $cmap | 0;
  $pchar_code = $pchar_code | 0;
  var $1 = 0, $char_code_0_in = 0, $char_code_0 = 0, $3 = 0, $5 = 0, $6 = 0, $result_1 = 0, $char_code_1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$pchar_code >> 2] | 0;
    $char_code_0_in = $1;
    label = 2;
    break;
   case 2:
    $char_code_0 = $char_code_0_in + 1 | 0;
    $3 = $char_code_0 >>> 0 < 256;
    if ($3) {
      label = 3;
      break;
    } else {
      $char_code_1 = 0;
      $result_1 = 0;
      label = 4;
      break;
    }
   case 3:
    $5 = _t1_cmap_std_char_index($cmap, $char_code_0) | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      $char_code_0_in = $char_code_0;
      label = 2;
      break;
    } else {
      $char_code_1 = $char_code_0;
      $result_1 = $5;
      label = 4;
      break;
    }
   case 4:
    HEAP32[$pchar_code >> 2] = $char_code_1;
    return $result_1 | 0;
  }
  return 0;
}
function _t1_cmap_expert_init($cmap) {
  $cmap = $cmap | 0;
  _t1_cmap_std_init($cmap, 1);
  return 0;
}
function _t1_cmap_unicode_init($unicodes) {
  $unicodes = $unicodes | 0;
  var $2 = 0;
  $2 = HEAP32[$unicodes >> 2] | 0;
  return FUNCTION_TABLE_iiiiiii[HEAP32[(HEAP32[$2 + 484 >> 2] | 0) + 4 >> 2] & 1023](HEAP32[$2 + 100 >> 2] | 0, $unicodes, HEAP32[$2 + 416 >> 2] | 0, 548, 0, $2) | 0;
}
function _t1_cmap_unicode_done($unicodes) {
  $unicodes = $unicodes | 0;
  var $5 = 0;
  $5 = $unicodes + 20 | 0;
  _ft_mem_free(HEAP32[(HEAP32[$unicodes >> 2] | 0) + 100 >> 2] | 0, HEAP32[$5 >> 2] | 0);
  HEAP32[$5 >> 2] = 0;
  HEAP32[$unicodes + 16 >> 2] = 0;
  return;
}
function _t1_cmap_unicode_char_index($unicodes, $char_code) {
  $unicodes = $unicodes | 0;
  $char_code = $char_code | 0;
  return FUNCTION_TABLE_iii[HEAP32[(HEAP32[(HEAP32[$unicodes >> 2] | 0) + 484 >> 2] | 0) + 8 >> 2] & 1023]($unicodes, $char_code) | 0;
}
function _t1_cmap_unicode_char_next($unicodes, $pchar_code) {
  $unicodes = $unicodes | 0;
  $pchar_code = $pchar_code | 0;
  return FUNCTION_TABLE_iii[HEAP32[(HEAP32[(HEAP32[$unicodes >> 2] | 0) + 484 >> 2] | 0) + 12 >> 2] & 1023]($unicodes, $pchar_code) | 0;
}
function _afm_parser_next_key($parser, $len) {
  $parser = $parser | 0;
  $len = $len | 0;
  var $1 = 0, $2 = 0, $3 = 0, $_pr = 0, $phitmp = 0, $5 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $15 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $parser + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 12 | 0;
    $_pr = HEAP32[$3 >> 2] | 0;
    $phitmp = ($_pr | 0) > 1;
    $5 = $phitmp;
    label = 2;
    break;
   case 2:
    if ($5) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = _afm_stream_read_string($2) | 0;
    label = 4;
    break;
   case 4:
    HEAP32[$3 >> 2] = 0;
    $9 = _afm_stream_read_one($2) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $12 = HEAP32[$3 >> 2] | 0;
    $13 = ($12 | 0) == 2;
    if ($13) {
      $5 = 1;
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $15 = ($len | 0) == 0;
    if ($15) {
      label = 10;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    if ($10) {
      $25 = 0;
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $18 = $2 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $19;
    $21 = $9;
    $22 = $21 ^ -1;
    $23 = $20 + $22 | 0;
    $25 = $23;
    label = 9;
    break;
   case 9:
    HEAP32[$len >> 2] = $25;
    label = 10;
    break;
   case 10:
    return $9 | 0;
  }
  return 0;
}
function _afm_tokenize($key, $len) {
  $key = $key | 0;
  $len = $len | 0;
  var $1 = 0, $n_014 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $n_1 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $n_2 = 0, $18 = 0, $19 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP8[$key] | 0;
    $n_014 = 0;
    label = 2;
    break;
   case 2:
    $3 = 5318060 + ($n_014 << 2) | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = HEAP8[$4] | 0;
    $6 = $5 << 24 >> 24 == $1 << 24 >> 24;
    if ($6) {
      $n_1 = $n_014;
      label = 3;
      break;
    } else {
      $n_2 = $n_014;
      label = 6;
      break;
    }
   case 3:
    $7 = ($n_1 | 0) < 74;
    if ($7) {
      label = 4;
      break;
    } else {
      $n_2 = $n_1;
      label = 6;
      break;
    }
   case 4:
    $9 = 5318060 + ($n_1 << 2) | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = HEAP8[$10] | 0;
    $12 = HEAP8[$key] | 0;
    $13 = $11 << 24 >> 24 == $12 << 24 >> 24;
    if ($13) {
      label = 5;
      break;
    } else {
      $_0 = 75;
      label = 7;
      break;
    }
   case 5:
    $15 = _strncmp($10 | 0, $key | 0, $len | 0) | 0;
    $16 = ($15 | 0) == 0;
    $17 = $n_1 + 1 | 0;
    if ($16) {
      $_0 = $n_1;
      label = 7;
      break;
    } else {
      $n_1 = $17;
      label = 3;
      break;
    }
   case 6:
    $18 = $n_2 + 1 | 0;
    $19 = ($18 | 0) < 74;
    if ($19) {
      $n_014 = $18;
      label = 2;
      break;
    } else {
      $_0 = 75;
      label = 7;
      break;
    }
   case 7:
    return $_0 | 0;
  }
  return 0;
}
function _afm_parser_read_int($parser, $aint) {
  $parser = $parser | 0;
  $aint = $aint | 0;
  var $val = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $val = __stackBase__ | 0;
    $1 = $val | 0;
    HEAP32[$1 >> 2] = 3;
    $2 = _afm_parser_read_vals($parser, $val, 1) | 0;
    $3 = ($2 | 0) == 1;
    if ($3) {
      label = 2;
      break;
    } else {
      $_0 = 160;
      label = 3;
      break;
    }
   case 2:
    $5 = $val + 4 | 0;
    $6 = $5;
    $7 = HEAP32[$6 >> 2] | 0;
    HEAP32[$aint >> 2] = $7;
    $_0 = 0;
    label = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _afm_parser_read_vals($parser, $vals, $n) {
  $parser = $parser | 0;
  $vals = $vals | 0;
  $n = $n | 0;
  var $str = 0, $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $or_cond = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $i_030 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $16 = 0, $storemerge = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $_c29 = 0, $41 = 0, $42 = 0, $43 = 0, $_c28 = 0, $45 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $_c = 0, $62 = 0, $64 = 0, $65 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $str = __stackBase__ | 0;
    $error = __stackBase__ + 4 | 0;
    $1 = $parser + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $n >>> 0 > 5;
    $4 = ($n | 0) == 0;
    $or_cond = $3 | $4;
    if ($or_cond) {
      $_0 = 0;
      label = 19;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 | 0;
    $6 = $parser | 0;
    $7 = $parser + 12 | 0;
    $8 = $parser + 16 | 0;
    $i_030 = 0;
    label = 3;
    break;
   case 3:
    $10 = $vals + ($i_030 << 3) | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $14 = _afm_stream_read_string($2) | 0;
    $storemerge = $14;
    label = 6;
    break;
   case 5:
    $16 = _afm_stream_read_one($2) | 0;
    $storemerge = $16;
    label = 6;
    break;
   case 6:
    HEAP32[$str >> 2] = $storemerge;
    $18 = ($storemerge | 0) == 0;
    if ($18) {
      $_0 = $i_030;
      label = 19;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $20 = HEAP32[$5 >> 2] | 0;
    $21 = $20;
    $22 = $storemerge;
    $23 = $21 - $22 | 0;
    $24 = $23 - 1 | 0;
    $25 = HEAP32[$10 >> 2] | 0;
    if (($25 | 0) == 0 | ($25 | 0) == 1) {
      label = 8;
      break;
    } else if (($25 | 0) == 2) {
      label = 10;
      break;
    } else if (($25 | 0) == 3) {
      label = 11;
      break;
    } else if (($25 | 0) == 4) {
      label = 12;
      break;
    } else if (($25 | 0) == 5) {
      label = 15;
      break;
    } else {
      label = 18;
      break;
    }
   case 8:
    $27 = HEAP32[$6 >> 2] | 0;
    $28 = _ft_mem_qalloc($27, $23, $error) | 0;
    $29 = $vals + ($i_030 << 3) + 4 | 0;
    HEAP32[$29 >> 2] = $28;
    $30 = HEAP32[$error >> 2] | 0;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 9;
      break;
    } else {
      label = 18;
      break;
    }
   case 9:
    $33 = HEAP32[$str >> 2] | 0;
    _memcpy($28 | 0, $33 | 0, $24 | 0);
    $34 = HEAP32[$29 >> 2] | 0;
    $35 = $34 + $24 | 0;
    HEAP8[$35] = 0;
    label = 18;
    break;
   case 10:
    $37 = $storemerge + $24 | 0;
    $38 = _PS_Conv_ToFixed($str, $37, 0) | 0;
    $39 = $vals + ($i_030 << 3) + 4 | 0;
    $_c29 = $38;
    HEAP32[$39 >> 2] = $_c29;
    label = 18;
    break;
   case 11:
    $41 = $storemerge + $24 | 0;
    $42 = _PS_Conv_ToInt($str, $41) | 0;
    $43 = $vals + ($i_030 << 3) + 4 | 0;
    $_c28 = $42;
    HEAP32[$43 >> 2] = $_c28;
    label = 18;
    break;
   case 12:
    $45 = ($24 | 0) == 4;
    if ($45) {
      label = 13;
      break;
    } else {
      $50 = 0;
      label = 14;
      break;
    }
   case 13:
    $47 = _strncmp($storemerge | 0, 5323016, 4) | 0;
    $48 = ($47 | 0) == 0;
    $50 = $48;
    label = 14;
    break;
   case 14:
    $51 = $50 & 1;
    $52 = $vals + ($i_030 << 3) + 4 | 0;
    $53 = $52;
    HEAP8[$53] = $51;
    label = 18;
    break;
   case 15:
    $55 = HEAP32[$7 >> 2] | 0;
    $56 = ($55 | 0) == 0;
    if ($56) {
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $58 = HEAP32[$8 >> 2] | 0;
    $59 = FUNCTION_TABLE_iiii[$55 & 1023]($storemerge, $24, $58) | 0;
    $60 = $vals + ($i_030 << 3) + 4 | 0;
    $_c = $59;
    HEAP32[$60 >> 2] = $_c;
    label = 18;
    break;
   case 17:
    $62 = $vals + ($i_030 << 3) + 4 | 0;
    HEAP32[$62 >> 2] = 0;
    label = 18;
    break;
   case 18:
    $64 = $i_030 + 1 | 0;
    $65 = $64 >>> 0 < $n >>> 0;
    if ($65) {
      $i_030 = $64;
      label = 3;
      break;
    } else {
      $_0 = $64;
      label = 19;
      break;
    }
   case 19:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _afm_parser_skip_section($parser, $n) {
  $parser = $parser | 0;
  $n = $n | 0;
  var $len = 0, $_08 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $len = __stackBase__ | 0;
    $_08 = $n;
    label = 2;
    break;
   case 2:
    $2 = ($_08 | 0) == 0;
    if ($2) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $4 = $_08 - 1 | 0;
    $5 = _afm_parser_next_key($parser, 0) | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      $_0 = 160;
      label = 6;
      break;
    } else {
      $_08 = $4;
      label = 2;
      break;
    }
   case 4:
    $7 = _afm_parser_next_key($parser, $len) | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      $_0 = 160;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $10 = HEAP32[$len >> 2] | 0;
    $11 = _afm_tokenize($7, $10) | 0;
    if (($11 | 0) == 20 | ($11 | 0) == 17) {
      $_0 = 0;
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _afm_parse_kern_data($parser) {
  $parser = $parser | 0;
  var $len = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $_0_ph = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $len = __stackBase__ | 0;
    $1 = _afm_parser_next_key($parser, $len) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      $_0 = 160;
      label = 7;
      break;
    } else {
      $3 = $1;
      label = 2;
      break;
    }
   case 2:
    $4 = HEAP32[$len >> 2] | 0;
    $5 = _afm_tokenize($3, $4) | 0;
    if (($5 | 0) == 75) {
      label = 3;
      break;
    } else if (($5 | 0) == 53) {
      label = 4;
      break;
    } else if (($5 | 0) == 50 | ($5 | 0) == 51) {
      label = 5;
      break;
    } else if (($5 | 0) == 21 | ($5 | 0) == 20) {
      $_0_ph = 0;
      label = 6;
      break;
    } else {
      $_0 = 160;
      label = 7;
      break;
    }
   case 3:
    $6 = _afm_parser_next_key($parser, $len) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      $_0 = 160;
      label = 7;
      break;
    } else {
      $3 = $6;
      label = 2;
      break;
    }
   case 4:
    $9 = _afm_parse_track_kern($parser) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 3;
      break;
    } else {
      $_0_ph = $9;
      label = 6;
      break;
    }
   case 5:
    $12 = _afm_parse_kern_pairs($parser) | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 3;
      break;
    } else {
      $_0_ph = $12;
      label = 6;
      break;
    }
   case 6:
    $_0 = $_0_ph;
    label = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _afm_parse_track_kern($parser) {
  $parser = $parser | 0;
  var $len = 0, $error = 0, $shared_vals = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $n_0_ph = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $61 = 0, $62 = 0, $64 = 0, $phitmp = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 48 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $len = __stackBase__ | 0;
    $error = __stackBase__ + 4 | 0;
    $shared_vals = __stackBase__ + 8 | 0;
    $1 = $parser + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 32 | 0;
    $4 = _afm_parser_read_int($parser, $3) | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $_0 = 160;
      label = 15;
      break;
    }
   case 2:
    $7 = HEAP32[$3 >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $10 = $parser | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = _ft_mem_realloc($11, 20, 0, $7, 0, $error) | 0;
    $13 = $12;
    $14 = $2 + 28 | 0;
    HEAP32[$14 >> 2] = $13;
    $15 = HEAP32[$error >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 4;
      break;
    } else {
      $_0 = $15;
      label = 15;
      break;
    }
   case 4:
    $17 = $2 + 28 | 0;
    $18 = $shared_vals | 0;
    $19 = $shared_vals | 0;
    $20 = $shared_vals + 8 | 0;
    $21 = $shared_vals + 16 | 0;
    $22 = $shared_vals + 24 | 0;
    $23 = $shared_vals + 32 | 0;
    $24 = $shared_vals + 4 | 0;
    $25 = $24;
    $26 = $shared_vals + 12 | 0;
    $27 = $26;
    $28 = $shared_vals + 20 | 0;
    $29 = $28;
    $30 = $shared_vals + 28 | 0;
    $31 = $30;
    $32 = $shared_vals + 36 | 0;
    $33 = $32;
    $n_0_ph = 0;
    label = 5;
    break;
   case 5:
    label = 6;
    break;
   case 6:
    $35 = _afm_parser_next_key($parser, $len) | 0;
    $36 = ($35 | 0) == 0;
    if ($36) {
      $_0 = 160;
      label = 15;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $38 = HEAP32[$len >> 2] | 0;
    $39 = _afm_tokenize($35, $38) | 0;
    if (($39 | 0) == 75) {
      label = 6;
      break;
    } else if (($39 | 0) == 56) {
      label = 8;
      break;
    } else if (($39 | 0) == 23 | ($39 | 0) == 21 | ($39 | 0) == 20) {
      label = 14;
      break;
    } else {
      $_0 = 160;
      label = 15;
      break;
    }
   case 8:
    $41 = HEAP32[$3 >> 2] | 0;
    $42 = ($n_0_ph | 0) < ($41 | 0);
    if ($42) {
      label = 9;
      break;
    } else {
      $_0 = 160;
      label = 15;
      break;
    }
   case 9:
    $44 = HEAP32[$17 >> 2] | 0;
    HEAP32[$19 >> 2] = 3;
    HEAP32[$20 >> 2] = 2;
    HEAP32[$21 >> 2] = 2;
    HEAP32[$22 >> 2] = 2;
    HEAP32[$23 >> 2] = 2;
    $45 = _afm_parser_read_vals($parser, $18, 5) | 0;
    $46 = ($45 | 0) == 5;
    if ($46) {
      label = 10;
      break;
    } else {
      $_0 = 160;
      label = 15;
      break;
    }
   case 10:
    $48 = HEAP32[$25 >> 2] | 0;
    $49 = $44 + ($n_0_ph * 20 & -1) | 0;
    HEAP32[$49 >> 2] = $48;
    $50 = HEAP32[$27 >> 2] | 0;
    $51 = $44 + ($n_0_ph * 20 & -1) + 4 | 0;
    HEAP32[$51 >> 2] = $50;
    $52 = HEAP32[$29 >> 2] | 0;
    $53 = $44 + ($n_0_ph * 20 & -1) + 8 | 0;
    HEAP32[$53 >> 2] = $52;
    $54 = HEAP32[$31 >> 2] | 0;
    $55 = $44 + ($n_0_ph * 20 & -1) + 12 | 0;
    HEAP32[$55 >> 2] = $54;
    $56 = HEAP32[$33 >> 2] | 0;
    $57 = $44 + ($n_0_ph * 20 & -1) + 16 | 0;
    HEAP32[$57 >> 2] = $56;
    $58 = HEAP32[$49 >> 2] | 0;
    $59 = ($58 | 0) < 0;
    if ($59) {
      label = 11;
      break;
    } else {
      label = 13;
      break;
    }
   case 11:
    $61 = HEAP32[$53 >> 2] | 0;
    $62 = ($61 | 0) > 0;
    if ($62) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $64 = -$61 | 0;
    HEAP32[$53 >> 2] = $64;
    label = 13;
    break;
   case 13:
    $phitmp = $n_0_ph + 1 | 0;
    $n_0_ph = $phitmp;
    label = 5;
    break;
   case 14:
    HEAP32[$3 >> 2] = $n_0_ph;
    $_0 = 0;
    label = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _afm_compare_kern_pairs($a, $b) {
  $a = $a | 0;
  $b = $b | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $_ = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $a;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 << 16;
    $4 = $a + 4 | 0;
    $5 = $4;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $3 | $6;
    $8 = $b;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 << 16;
    $11 = $b + 4 | 0;
    $12 = $11;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $10 | $13;
    $15 = $7 >>> 0 > $14 >>> 0;
    if ($15) {
      $_0 = 1;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $17 = $7 >>> 0 < $14 >>> 0;
    $_ = $17 << 31 >> 31;
    $_0 = $_;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _PS_Conv_Strtol($cursor, $limit, $base) {
  $cursor = $cursor | 0;
  $limit = $limit | 0;
  $base = $base | 0;
  var $1 = 0, $2 = 0, $base_off = 0, $4 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $p_0_ph = 0, $sign_0_ph = 0, $13 = 0, $num_032 = 0, $p_031 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $or_cond = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $num_0_lcssa = 0, $p_0_lcssa = 0, $30 = 0, $31 = 0, $num_0_ = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$cursor >> 2] | 0;
    $2 = ($1 | 0) == ($limit | 0);
    if ($2) {
      $_0 = 0;
      label = 11;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $base_off = $base - 2 | 0;
    $4 = $base_off >>> 0 > 34;
    if ($4) {
      $_0 = 0;
      label = 11;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $6 = HEAP8[$1] | 0;
    if (($6 << 24 >> 24 | 0) == 45 | ($6 << 24 >> 24 | 0) == 43) {
      label = 4;
      break;
    } else {
      $sign_0_ph = 0;
      $p_0_ph = $1;
      label = 5;
      break;
    }
   case 4:
    $8 = HEAP8[$1] | 0;
    $9 = $8 << 24 >> 24 == 45;
    $10 = $9 & 1;
    $11 = $1 + 1 | 0;
    $12 = ($11 | 0) == ($limit | 0);
    if ($12) {
      $_0 = 0;
      label = 11;
      break;
    } else {
      $sign_0_ph = $10;
      $p_0_ph = $11;
      label = 5;
      break;
    }
   case 5:
    $13 = $p_0_ph >>> 0 < $limit >>> 0;
    if ($13) {
      $p_031 = $p_0_ph;
      $num_032 = 0;
      label = 6;
      break;
    } else {
      $p_0_lcssa = $p_0_ph;
      $num_0_lcssa = 0;
      label = 10;
      break;
    }
   case 6:
    $14 = HEAP8[$p_031] | 0;
    $15 = $14 & 255;
    if (($14 << 24 >> 24 | 0) == 32 | ($14 << 24 >> 24 | 0) == 13 | ($14 << 24 >> 24 | 0) == 10 | ($14 << 24 >> 24 | 0) == 9 | ($14 << 24 >> 24 | 0) == 12 | ($14 << 24 >> 24 | 0) == 0) {
      $p_0_lcssa = $p_031;
      $num_0_lcssa = $num_032;
      label = 10;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $17 = $14 << 24 >> 24 < 0;
    if ($17) {
      $p_0_lcssa = $p_031;
      $num_0_lcssa = $num_032;
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $19 = $15 & 127;
    $20 = $19 + 5257092 | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $21 << 24 >> 24;
    $23 = $21 << 24 >> 24 > -1;
    $24 = ($22 | 0) < ($base | 0);
    $or_cond = $23 & $24;
    if ($or_cond) {
      label = 9;
      break;
    } else {
      $p_0_lcssa = $p_031;
      $num_0_lcssa = $num_032;
      label = 10;
      break;
    }
   case 9:
    $26 = Math_imul($num_032, $base);
    $27 = $22 + $26 | 0;
    $28 = $p_031 + 1 | 0;
    $29 = $28 >>> 0 < $limit >>> 0;
    if ($29) {
      $p_031 = $28;
      $num_032 = $27;
      label = 6;
      break;
    } else {
      $p_0_lcssa = $28;
      $num_0_lcssa = $27;
      label = 10;
      break;
    }
   case 10:
    $30 = $sign_0_ph << 24 >> 24 == 0;
    $31 = -$num_0_lcssa | 0;
    $num_0_ = $30 ? $num_0_lcssa : $31;
    HEAP32[$cursor >> 2] = $p_0_lcssa;
    $_0 = $num_0_;
    label = 11;
    break;
   case 11:
    return $_0 | 0;
  }
  return 0;
}
function _afm_stream_skip_spaces($stream) {
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $stream + 12 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) > 0;
    if ($3) {
      label = 8;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $stream | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $stream + 8 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $5 >>> 0 < $7 >>> 0;
    if ($8) {
      $9 = $5;
      label = 3;
      break;
    } else {
      label = 7;
      break;
    }
   case 3:
    $10 = $9 + 1 | 0;
    HEAP32[$4 >> 2] = $10;
    $11 = HEAP8[$9] | 0;
    $12 = $11 & 255;
    if (($12 | 0) == 32 | ($12 | 0) == 9) {
      label = 4;
      break;
    } else if (($12 | 0) == 13 | ($12 | 0) == 10) {
      label = 5;
      break;
    } else if (($12 | 0) == 59) {
      label = 6;
      break;
    } else if (($12 | 0) == 26) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 4:
    $13 = HEAP32[$4 >> 2] | 0;
    $14 = HEAP32[$6 >> 2] | 0;
    $15 = $13 >>> 0 < $14 >>> 0;
    if ($15) {
      $9 = $13;
      label = 3;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    HEAP32[$1 >> 2] = 2;
    label = 8;
    break;
   case 6:
    HEAP32[$1 >> 2] = 1;
    label = 8;
    break;
   case 7:
    HEAP32[$1 >> 2] = 3;
    label = 8;
    break;
   case 8:
    return;
  }
}
function _t1_get_glyph_name($face, $idx) {
  $face = $face | 0;
  $idx = $idx | 0;
  return HEAP32[(HEAP32[$face + 420 >> 2] | 0) + ($idx << 2) >> 2] | 0;
}
function _t1_cmap_std_init($cmap, $is_expert) {
  $cmap = $cmap | 0;
  $is_expert = $is_expert | 0;
  var $2 = 0, $4 = 0;
  $2 = HEAP32[$cmap >> 2] | 0;
  $4 = HEAP32[$2 + 484 >> 2] | 0;
  HEAP32[$cmap + 24 >> 2] = HEAP32[$2 + 416 >> 2] | 0;
  HEAP32[$cmap + 28 >> 2] = HEAP32[$2 + 420 >> 2] | 0;
  HEAP32[$cmap + 20 >> 2] = HEAP32[$4 + 20 >> 2] | 0;
  HEAP32[$cmap + 16 >> 2] = HEAP32[(($is_expert | 0) == 0 ? $4 + 24 | 0 : $4 + 28 | 0) >> 2] | 0;
  return;
}
function _PS_Conv_EexecDecode($cursor, $limit, $buffer, $n, $seed) {
  $cursor = $cursor | 0;
  $limit = $limit | 0;
  $buffer = $buffer | 0;
  $n = $n | 0;
  $seed = $seed | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_n = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $umax = 0, $13 = 0, $r_02 = 0, $s_01 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $exitcond = 0, $s_0_lcssa = 0, $27 = 0, $28 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP16[$seed >> 1] | 0;
    $2 = $1 & 65535;
    $3 = HEAP32[$cursor >> 2] | 0;
    $4 = $limit;
    $5 = $3;
    $6 = $4 - $5 | 0;
    $7 = $6 >>> 0 < $n >>> 0;
    $_n = $7 ? $6 : $n;
    $8 = ($_n | 0) == 0;
    if ($8) {
      $s_0_lcssa = $2;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = $5 - 1 | 0;
    $10 = $9 - $4 | 0;
    $11 = $n ^ -1;
    $12 = $10 >>> 0 > $11 >>> 0;
    $umax = $12 ? $10 : $11;
    $13 = $umax ^ -1;
    $s_01 = $2;
    $r_02 = 0;
    label = 3;
    break;
   case 3:
    $15 = $3 + $r_02 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 & 255;
    $18 = $s_01 >>> 8;
    $19 = $17 ^ $18;
    $20 = $17 + $s_01 | 0;
    $21 = $20 * 52845 & -1;
    $22 = $21 + 22719 | 0;
    $23 = $22 & 65535;
    $24 = $19 & 255;
    $25 = $buffer + $r_02 | 0;
    HEAP8[$25] = $24;
    $26 = $r_02 + 1 | 0;
    $exitcond = ($26 | 0) == ($13 | 0);
    if ($exitcond) {
      $s_0_lcssa = $23;
      label = 4;
      break;
    } else {
      $s_01 = $23;
      $r_02 = $26;
      label = 3;
      break;
    }
   case 4:
    $27 = $3 + $_n | 0;
    HEAP32[$cursor >> 2] = $27;
    $28 = $s_0_lcssa & 65535;
    HEAP16[$seed >> 1] = $28;
    return;
  }
}
function _afm_parse_kern_pairs($parser) {
  $parser = $parser | 0;
  var $len = 0, $error = 0, $shared_vals = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $n_0_ph = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $phitmp = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $or_cond = 0, $62 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $69 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 40 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $len = __stackBase__ | 0;
    $error = __stackBase__ + 4 | 0;
    $shared_vals = __stackBase__ + 8 | 0;
    $1 = $parser + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 40 | 0;
    $4 = _afm_parser_read_int($parser, $3) | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $_0 = 160;
      label = 17;
      break;
    }
   case 2:
    $7 = HEAP32[$3 >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $10 = $parser | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = _ft_mem_realloc($11, 16, 0, $7, 0, $error) | 0;
    $13 = $12;
    $14 = $2 + 36 | 0;
    HEAP32[$14 >> 2] = $13;
    $15 = HEAP32[$error >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 4;
      break;
    } else {
      $_0 = $15;
      label = 17;
      break;
    }
   case 4:
    $17 = $2 + 36 | 0;
    $18 = $shared_vals | 0;
    $19 = $shared_vals | 0;
    $20 = $shared_vals + 8 | 0;
    $21 = $shared_vals + 16 | 0;
    $22 = $shared_vals + 24 | 0;
    $23 = $shared_vals + 4 | 0;
    $24 = $23;
    $25 = $shared_vals + 12 | 0;
    $26 = $25;
    $27 = $shared_vals + 20 | 0;
    $28 = $27;
    $29 = $shared_vals + 20 | 0;
    $30 = $29;
    $31 = $shared_vals + 28 | 0;
    $32 = $31;
    $n_0_ph = 0;
    label = 5;
    break;
   case 5:
    label = 6;
    break;
   case 6:
    $34 = _afm_parser_next_key($parser, $len) | 0;
    $35 = ($34 | 0) == 0;
    if ($35) {
      $_0 = 160;
      label = 17;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $37 = HEAP32[$len >> 2] | 0;
    $38 = _afm_tokenize($34, $37) | 0;
    if (($38 | 0) == 75) {
      label = 6;
      break;
    } else if (($38 | 0) == 34 | ($38 | 0) == 36 | ($38 | 0) == 37) {
      label = 8;
      break;
    } else if (($38 | 0) == 22 | ($38 | 0) == 21 | ($38 | 0) == 20) {
      label = 16;
      break;
    } else {
      $_0 = 160;
      label = 17;
      break;
    }
   case 8:
    $40 = HEAP32[$3 >> 2] | 0;
    $41 = ($n_0_ph | 0) < ($40 | 0);
    if ($41) {
      label = 9;
      break;
    } else {
      $_0 = 160;
      label = 17;
      break;
    }
   case 9:
    $43 = HEAP32[$17 >> 2] | 0;
    HEAP32[$19 >> 2] = 5;
    HEAP32[$20 >> 2] = 5;
    HEAP32[$21 >> 2] = 3;
    HEAP32[$22 >> 2] = 3;
    $44 = _afm_parser_read_vals($parser, $18, 4) | 0;
    $45 = ($44 | 0) < 3;
    if ($45) {
      $_0 = 160;
      label = 17;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $47 = HEAP32[$24 >> 2] | 0;
    $48 = $43 + ($n_0_ph << 4) | 0;
    HEAP32[$48 >> 2] = $47;
    $49 = HEAP32[$26 >> 2] | 0;
    $50 = $43 + ($n_0_ph << 4) + 4 | 0;
    HEAP32[$50 >> 2] = $49;
    $51 = ($38 | 0) == 37;
    if ($51) {
      label = 11;
      break;
    } else {
      label = 13;
      break;
    }
   case 11:
    $53 = $43 + ($n_0_ph << 4) + 8 | 0;
    HEAP32[$53 >> 2] = 0;
    $54 = HEAP32[$28 >> 2] | 0;
    $55 = $43 + ($n_0_ph << 4) + 12 | 0;
    HEAP32[$55 >> 2] = $54;
    label = 12;
    break;
   case 12:
    $phitmp = $n_0_ph + 1 | 0;
    $n_0_ph = $phitmp;
    label = 5;
    break;
   case 13:
    $57 = HEAP32[$30 >> 2] | 0;
    $58 = $43 + ($n_0_ph << 4) + 8 | 0;
    HEAP32[$58 >> 2] = $57;
    $59 = ($38 | 0) == 34;
    $60 = ($44 | 0) == 4;
    $or_cond = $59 & $60;
    if ($or_cond) {
      label = 14;
      break;
    } else {
      $64 = 0;
      label = 15;
      break;
    }
   case 14:
    $62 = HEAP32[$32 >> 2] | 0;
    $64 = $62;
    label = 15;
    break;
   case 15:
    $65 = $43 + ($n_0_ph << 4) + 12 | 0;
    HEAP32[$65 >> 2] = $64;
    label = 12;
    break;
   case 16:
    HEAP32[$3 >> 2] = $n_0_ph;
    $67 = $2 + 36 | 0;
    $68 = HEAP32[$67 >> 2] | 0;
    $69 = $68;
    _qsort($69 | 0, $n_0_ph | 0, 16, 560);
    $_0 = 0;
    label = 17;
    break;
   case 17:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _afm_stream_read_string($stream) {
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $cond = 0, $storemerge = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    _afm_stream_skip_spaces($stream);
    $1 = $stream + 12 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) > 1;
    if ($3) {
      $_0 = 0;
      label = 7;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $stream | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 - 1 | 0;
    $8 = $stream + 8 | 0;
    label = 3;
    break;
   case 3:
    $10 = HEAP32[$5 >> 2] | 0;
    $11 = HEAP32[$8 >> 2] | 0;
    $12 = $10 >>> 0 < $11 >>> 0;
    if ($12) {
      label = 4;
      break;
    } else {
      $storemerge = 3;
      label = 6;
      break;
    }
   case 4:
    $14 = $10 + 1 | 0;
    HEAP32[$5 >> 2] = $14;
    $15 = HEAP8[$10] | 0;
    $16 = $15 & 255;
    if (($16 | 0) == 13 | ($16 | 0) == 10) {
      $storemerge = 2;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $cond = $15 << 24 >> 24 == 26;
    if ($cond) {
      $storemerge = 3;
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 6:
    HEAP32[$1 >> 2] = $storemerge;
    $_0 = $7;
    label = 7;
    break;
   case 7:
    return $_0 | 0;
  }
  return 0;
}
function _afm_stream_read_one($stream) {
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    _afm_stream_skip_spaces($stream);
    $1 = $stream + 12 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) > 0;
    if ($3) {
      $_0 = 0;
      label = 8;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $stream | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 - 1 | 0;
    $8 = $stream + 8 | 0;
    label = 3;
    break;
   case 3:
    $10 = HEAP32[$5 >> 2] | 0;
    $11 = HEAP32[$8 >> 2] | 0;
    $12 = $10 >>> 0 < $11 >>> 0;
    if ($12) {
      label = 4;
      break;
    } else {
      label = 7;
      break;
    }
   case 4:
    $14 = $10 + 1 | 0;
    HEAP32[$5 >> 2] = $14;
    $15 = HEAP8[$10] | 0;
    $16 = $15 & 255;
    if (($16 | 0) == 13 | ($16 | 0) == 10) {
      label = 5;
      break;
    } else if (($16 | 0) == 59) {
      label = 6;
      break;
    } else if (($16 | 0) == 26) {
      label = 7;
      break;
    } else if (($16 | 0) == 32 | ($16 | 0) == 9) {
      $_0 = $7;
      label = 8;
      break;
    } else {
      label = 3;
      break;
    }
   case 5:
    HEAP32[$1 >> 2] = 2;
    $_0 = $7;
    label = 8;
    break;
   case 6:
    HEAP32[$1 >> 2] = 1;
    $_0 = $7;
    label = 8;
    break;
   case 7:
    HEAP32[$1 >> 2] = 3;
    $_0 = $7;
    label = 8;
    break;
   case 8:
    return $_0 | 0;
  }
  return 0;
}
function _PS_Conv_ToFixed($cursor, $limit, $power_ten) {
  $cursor = $cursor | 0;
  $limit = $limit | 0;
  $power_ten = $power_ten | 0;
  var $p = 0, $1 = 0, $2 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $sign_0 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $integral_0 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $storemerge47 = 0, $25 = 0, $26 = 0, $storemerge51 = 0, $divider_050 = 0, $decimal_049 = 0, $_03248 = 0, $28 = 0, $29 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $or_cond33 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $_1 = 0, $decimal_1 = 0, $divider_1 = 0, $52 = 0, $storemerge = 0, $53 = 0, $_2 = 0, $decimal_2 = 0, $divider_2 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $_3_ph = 0, $64 = 0, $65 = 0, $decimal_341 = 0, $integral_140 = 0, $_339 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $divider_336 = 0, $integral_235 = 0, $_434 = 0, $70 = 0, $71 = 0, $72 = 0, $exitcond = 0, $decimal_3_lcssa63 = 0, $divider_3_lcssa = 0, $integral_2_lcssa = 0, $73 = 0, $75 = 0, $76 = 0, $integral_3 = 0, $78 = 0, $79 = 0, $integral_4 = 0, $80 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $p = __stackBase__ | 0;
    $1 = HEAP32[$cursor >> 2] | 0;
    HEAP32[$p >> 2] = $1;
    $2 = ($1 | 0) == ($limit | 0);
    if ($2) {
      $_0 = 0;
      label = 28;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = HEAP8[$1] | 0;
    if (($4 << 24 >> 24 | 0) == 45 | ($4 << 24 >> 24 | 0) == 43) {
      label = 3;
      break;
    } else {
      $sign_0 = 0;
      label = 4;
      break;
    }
   case 3:
    $6 = HEAP32[$p >> 2] | 0;
    $7 = HEAP8[$6] | 0;
    $8 = $7 << 24 >> 24 == 45;
    $9 = $8 & 1;
    $10 = $6 + 1 | 0;
    HEAP32[$p >> 2] = $10;
    $11 = ($10 | 0) == ($limit | 0);
    if ($11) {
      $_0 = 0;
      label = 28;
      break;
    } else {
      $sign_0 = $9;
      label = 4;
      break;
    }
   case 4:
    $13 = HEAP32[$p >> 2] | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 << 24 >> 24 == 46;
    if ($15) {
      $integral_0 = 0;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = _PS_Conv_ToInt($p, $limit) | 0;
    $18 = $17 << 16;
    $integral_0 = $18;
    label = 6;
    break;
   case 6:
    $20 = HEAP32[$p >> 2] | 0;
    $21 = $20 >>> 0 < $limit >>> 0;
    if ($21) {
      label = 7;
      break;
    } else {
      $divider_2 = 1;
      $decimal_2 = 0;
      $_2 = $power_ten;
      label = 18;
      break;
    }
   case 7:
    $23 = HEAP8[$20] | 0;
    $24 = $23 << 24 >> 24 == 46;
    if ($24) {
      label = 8;
      break;
    } else {
      $divider_2 = 1;
      $decimal_2 = 0;
      $_2 = $power_ten;
      label = 18;
      break;
    }
   case 8:
    $storemerge47 = $20 + 1 | 0;
    HEAP32[$p >> 2] = $storemerge47;
    $25 = $storemerge47 >>> 0 < $limit >>> 0;
    if ($25) {
      label = 9;
      break;
    } else {
      $divider_2 = 1;
      $decimal_2 = 0;
      $_2 = $power_ten;
      label = 18;
      break;
    }
   case 9:
    $26 = ($integral_0 | 0) == 0;
    $_03248 = $power_ten;
    $decimal_049 = 0;
    $divider_050 = 1;
    $storemerge51 = $storemerge47;
    label = 10;
    break;
   case 10:
    $28 = HEAP8[$storemerge51] | 0;
    $29 = $28 & 255;
    if (($28 << 24 >> 24 | 0) == 32 | ($28 << 24 >> 24 | 0) == 13 | ($28 << 24 >> 24 | 0) == 10 | ($28 << 24 >> 24 | 0) == 9 | ($28 << 24 >> 24 | 0) == 12 | ($28 << 24 >> 24 | 0) == 0) {
      $divider_2 = $divider_050;
      $decimal_2 = $decimal_049;
      $_2 = $_03248;
      label = 18;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $31 = $28 << 24 >> 24 < 0;
    if ($31) {
      $divider_2 = $divider_050;
      $decimal_2 = $decimal_049;
      $_2 = $_03248;
      label = 18;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $33 = $29 & 127;
    $34 = $33 + 5257092 | 0;
    $35 = HEAP8[$34] | 0;
    $36 = $35 << 24 >> 24;
    $37 = $33 - 48 | 0;
    $38 = $37 >>> 0 > 9;
    if ($38) {
      $divider_2 = $divider_050;
      $decimal_2 = $decimal_049;
      $_2 = $_03248;
      label = 18;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $40 = ($_03248 | 0) > 0;
    $or_cond33 = $26 & $40;
    if ($or_cond33) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $42 = $_03248 - 1 | 0;
    $43 = $decimal_049 * 10 & -1;
    $44 = $36 + $43 | 0;
    $divider_1 = $divider_050;
    $decimal_1 = $44;
    $_1 = $42;
    label = 17;
    break;
   case 15:
    $46 = ($divider_050 | 0) < 1e7;
    if ($46) {
      label = 16;
      break;
    } else {
      $divider_1 = $divider_050;
      $decimal_1 = $decimal_049;
      $_1 = $_03248;
      label = 17;
      break;
    }
   case 16:
    $48 = $decimal_049 * 10 & -1;
    $49 = $36 + $48 | 0;
    $50 = $divider_050 * 10 & -1;
    $divider_1 = $50;
    $decimal_1 = $49;
    $_1 = $_03248;
    label = 17;
    break;
   case 17:
    $52 = HEAP32[$p >> 2] | 0;
    $storemerge = $52 + 1 | 0;
    HEAP32[$p >> 2] = $storemerge;
    $53 = $storemerge >>> 0 < $limit >>> 0;
    if ($53) {
      $_03248 = $_1;
      $decimal_049 = $decimal_1;
      $divider_050 = $divider_1;
      $storemerge51 = $storemerge;
      label = 10;
      break;
    } else {
      $divider_2 = $divider_1;
      $decimal_2 = $decimal_1;
      $_2 = $_1;
      label = 18;
      break;
    }
   case 18:
    $54 = HEAP32[$p >> 2] | 0;
    $55 = $54 + 1 | 0;
    $56 = $55 >>> 0 < $limit >>> 0;
    if ($56) {
      label = 19;
      break;
    } else {
      $_3_ph = $_2;
      label = 21;
      break;
    }
   case 19:
    $58 = HEAP8[$54] | 0;
    if (($58 << 24 >> 24 | 0) == 101 | ($58 << 24 >> 24 | 0) == 69) {
      label = 20;
      break;
    } else {
      $_3_ph = $_2;
      label = 21;
      break;
    }
   case 20:
    $60 = HEAP32[$p >> 2] | 0;
    $61 = $60 + 1 | 0;
    HEAP32[$p >> 2] = $61;
    $62 = _PS_Conv_ToInt($p, $limit) | 0;
    $63 = $62 + $_2 | 0;
    $_3_ph = $63;
    label = 21;
    break;
   case 21:
    $64 = ($_3_ph | 0) > 0;
    if ($64) {
      $_339 = $_3_ph;
      $integral_140 = $integral_0;
      $decimal_341 = $decimal_2;
      label = 23;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $65 = ($_3_ph | 0) < 0;
    if ($65) {
      $_434 = $_3_ph;
      $integral_235 = $integral_0;
      $divider_336 = $divider_2;
      label = 24;
      break;
    } else {
      $integral_2_lcssa = $integral_0;
      $divider_3_lcssa = $divider_2;
      $decimal_3_lcssa63 = $decimal_2;
      label = 25;
      break;
    }
   case 23:
    $66 = $integral_140 * 10 & -1;
    $67 = $decimal_341 * 10 & -1;
    $68 = $_339 - 1 | 0;
    $69 = ($68 | 0) > 0;
    if ($69) {
      $_339 = $68;
      $integral_140 = $66;
      $decimal_341 = $67;
      label = 23;
      break;
    } else {
      $integral_2_lcssa = $66;
      $divider_3_lcssa = $divider_2;
      $decimal_3_lcssa63 = $67;
      label = 25;
      break;
    }
   case 24:
    $70 = ($integral_235 | 0) / 10 & -1;
    $71 = $divider_336 * 10 & -1;
    $72 = $_434 + 1 | 0;
    $exitcond = ($72 | 0) == 0;
    if ($exitcond) {
      $integral_2_lcssa = $70;
      $divider_3_lcssa = $71;
      $decimal_3_lcssa63 = $decimal_2;
      label = 25;
      break;
    } else {
      $_434 = $72;
      $integral_235 = $70;
      $divider_336 = $71;
      label = 24;
      break;
    }
   case 25:
    $73 = ($decimal_3_lcssa63 | 0) == 0;
    if ($73) {
      $integral_3 = $integral_2_lcssa;
      label = 27;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $75 = _FT_DivFix($decimal_3_lcssa63, $divider_3_lcssa) | 0;
    $76 = $75 + $integral_2_lcssa | 0;
    $integral_3 = $76;
    label = 27;
    break;
   case 27:
    $78 = $sign_0 << 24 >> 24 == 0;
    $79 = -$integral_3 | 0;
    $integral_4 = $78 ? $integral_3 : $79;
    $80 = HEAP32[$p >> 2] | 0;
    HEAP32[$cursor >> 2] = $80;
    $_0 = $integral_4;
    label = 28;
    break;
   case 28:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _PS_Conv_ToInt($cursor, $limit) {
  $cursor = $cursor | 0;
  $limit = $limit | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _PS_Conv_Strtol($cursor, $limit, 10) | 0;
    $2 = HEAP32[$cursor >> 2] | 0;
    $3 = $2 >>> 0 < $limit >>> 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $_0 = $1;
      label = 4;
      break;
    }
   case 2:
    $5 = HEAP8[$2] | 0;
    $6 = $5 << 24 >> 24 == 35;
    if ($6) {
      label = 3;
      break;
    } else {
      $_0 = $1;
      label = 4;
      break;
    }
   case 3:
    $8 = $2 + 1 | 0;
    HEAP32[$cursor >> 2] = $8;
    $9 = _PS_Conv_Strtol($cursor, $limit, $1) | 0;
    $_0 = $9;
    label = 4;
    break;
   case 4:
    return $_0 | 0;
  }
  return 0;
}
function _t1operator_seac($decoder, $asb, $adx, $ady, $bchar, $achar) {
  $decoder = $decoder | 0;
  $asb = $asb | 0;
  $adx = $adx | 0;
  $ady = $ady | 0;
  $bchar = $bchar | 0;
  $achar = $achar | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $achar_index_0 = 0, $bchar_index_0 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $73 = 0, $ld$0$0 = 0, $74$0 = 0, $ld$1$1 = 0, $74$1 = 0, $75 = 0, $76 = 0, $ld$2$0 = 0, $77$0 = 0, $ld$3$1 = 0, $77$1 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $st$4$0 = 0, $st$5$1 = 0, $st$6$0 = 0, $st$7$1 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $decoder + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $decoder + 1496 | 0;
    $4 = HEAP8[$3] | 0;
    $5 = $4 << 24 >> 24 == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $_0 = 160;
      label = 13;
      break;
    }
   case 2:
    $7 = $decoder + 32 | 0;
    $8 = $7 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 + $adx | 0;
    $11 = $decoder + 1356 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $15 = $2 + 128 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $16 + 52 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      $_0 = 160;
      label = 13;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $21 = $2 + 128 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22 + 52 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 5;
      break;
    } else {
      $bchar_index_0 = $bchar;
      $achar_index_0 = $achar;
      label = 6;
      break;
    }
   case 5:
    $27 = _t1_lookup_glyph_by_stdcharcode($decoder, $bchar) | 0;
    $28 = _t1_lookup_glyph_by_stdcharcode($decoder, $achar) | 0;
    $bchar_index_0 = $27;
    $achar_index_0 = $28;
    label = 6;
    break;
   case 6:
    $30 = $bchar_index_0 | $achar_index_0;
    $31 = ($30 | 0) < 0;
    if ($31) {
      $_0 = 160;
      label = 13;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $33 = $decoder + 69 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 << 24 >> 24 == 0;
    if ($35) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $37 = $decoder + 8 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $38 + 156 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $40 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = _FT_GlyphLoader_CheckSubGlyphs($42, 2) | 0;
    $44 = ($43 | 0) == 0;
    if ($44) {
      label = 9;
      break;
    } else {
      $_0 = $43;
      label = 13;
      break;
    }
   case 9:
    $46 = $42 + 88 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $47 | 0;
    HEAP32[$48 >> 2] = $bchar_index_0;
    $49 = $47 + 4 | 0;
    HEAP16[$49 >> 1] = 514;
    $50 = $47 + 8 | 0;
    HEAP32[$50 >> 2] = 0;
    $51 = $47 + 12 | 0;
    HEAP32[$51 >> 2] = 0;
    $52 = $47 + 32 | 0;
    HEAP32[$52 >> 2] = $achar_index_0;
    $53 = $47 + 36 | 0;
    HEAP16[$53 >> 1] = 2;
    $54 = $10 - $asb | 0;
    $55 = _FT_RoundFix($54) | 0;
    $56 = $55 >> 16;
    $57 = $47 + 40 | 0;
    HEAP32[$57 >> 2] = $56;
    $58 = _FT_RoundFix($ady) | 0;
    $59 = $58 >> 16;
    $60 = $47 + 44 | 0;
    HEAP32[$60 >> 2] = $59;
    $61 = $38 + 128 | 0;
    HEAP32[$61 >> 2] = 2;
    $62 = $42 + 52 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = $38 + 132 | 0;
    HEAP32[$64 >> 2] = $63;
    $65 = $38 + 72 | 0;
    HEAP32[$65 >> 2] = 1668246896;
    $66 = $42 + 84 | 0;
    HEAP32[$66 >> 2] = 2;
    $_0 = 0;
    label = 13;
    break;
   case 10:
    $68 = $decoder + 12 | 0;
    $69 = HEAP32[$68 >> 2] | 0;
    _FT_GlyphLoader_Prepare($69);
    HEAP8[$3] = 1;
    $70 = _t1_decoder_parse_glyph($decoder, $bchar_index_0) | 0;
    HEAP8[$3] = 0;
    $71 = ($70 | 0) == 0;
    if ($71) {
      label = 11;
      break;
    } else {
      $_0 = $70;
      label = 13;
      break;
    }
   case 11:
    $73 = $7;
    $ld$0$0 = $73 | 0;
    $74$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $73 + 4 | 0;
    $74$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $75 = $decoder + 40 | 0;
    $76 = $75;
    $ld$2$0 = $76 | 0;
    $77$0 = HEAP32[$ld$2$0 >> 2] | 0;
    $ld$3$1 = $76 + 4 | 0;
    $77$1 = HEAP32[$ld$3$1 >> 2] | 0;
    HEAP32[$8 >> 2] = 0;
    $78 = $decoder + 36 | 0;
    HEAP32[$78 >> 2] = 0;
    $79 = $10 - $asb | 0;
    $80 = $decoder + 24 | 0;
    HEAP32[$80 >> 2] = $79;
    $81 = $decoder + 28 | 0;
    HEAP32[$81 >> 2] = $ady;
    HEAP8[$3] = 1;
    $82 = _t1_decoder_parse_glyph($decoder, $achar_index_0) | 0;
    HEAP8[$3] = 0;
    $83 = ($82 | 0) == 0;
    if ($83) {
      label = 12;
      break;
    } else {
      $_0 = $82;
      label = 13;
      break;
    }
   case 12:
    $st$4$0 = $73 | 0;
    HEAP32[$st$4$0 >> 2] = $74$0;
    $st$5$1 = $73 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $74$1;
    $st$6$0 = $76 | 0;
    HEAP32[$st$6$0 >> 2] = $77$0;
    $st$7$1 = $76 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $77$1;
    HEAP32[$80 >> 2] = 0;
    HEAP32[$81 >> 2] = 0;
    $_0 = 0;
    label = 13;
    break;
   case 13:
    return $_0 | 0;
  }
  return 0;
}
function _t1_lookup_glyph_by_stdcharcode($decoder, $charcode) {
  $decoder = $decoder | 0;
  $charcode = $charcode | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $n_015 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $decoder + 1348 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $charcode >>> 0 > 255;
    if ($3) {
      $_0 = -1;
      label = 8;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 + 20 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $2 + 24 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 + ($charcode << 1) | 0;
    $10 = HEAP16[$9 >> 1] | 0;
    $11 = $10 & 65535;
    $12 = FUNCTION_TABLE_ii[$6 & 1023]($11) | 0;
    $13 = $decoder + 1352 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      $_0 = -1;
      label = 8;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $16 = $decoder + 1356 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $n_015 = 0;
    label = 4;
    break;
   case 4:
    $19 = $17 + ($n_015 << 2) | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $23 = HEAP8[$20] | 0;
    $24 = HEAP8[$12] | 0;
    $25 = $23 << 24 >> 24 == $24 << 24 >> 24;
    if ($25) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $27 = _strcmp($20 | 0, $12 | 0) | 0;
    $28 = ($27 | 0) == 0;
    if ($28) {
      $_0 = $n_015;
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $30 = $n_015 + 1 | 0;
    $31 = HEAP32[$13 >> 2] | 0;
    $32 = $30 >>> 0 < $31 >>> 0;
    if ($32) {
      $n_015 = $30;
      label = 4;
      break;
    } else {
      $_0 = -1;
      label = 8;
      break;
    }
   case 8:
    return $_0 | 0;
  }
  return 0;
}
function _t1_decoder_parse_glyph($decoder, $glyph) {
  $decoder = $decoder | 0;
  $glyph = $glyph | 0;
  return FUNCTION_TABLE_iii[HEAP32[$decoder + 1472 >> 2] & 1023]($decoder, $glyph) | 0;
}
function _t1_decrypt($buffer, $length, $seed) {
  $buffer = $buffer | 0;
  $length = $length | 0;
  $seed = $seed | 0;
  var $1 = 0, $2 = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  $1 = __stackBase__ | 0;
  $2 = __stackBase__ + 4 | 0;
  HEAP32[$1 >> 2] = $buffer;
  HEAP16[$2 >> 1] = $seed;
  _PS_Conv_EexecDecode($1, $buffer + $length | 0, $buffer, $length, $2);
  STACKTOP = __stackBase__;
  return;
}
function _skip_spaces($acur, $limit) {
  $acur = $acur | 0;
  $limit = $limit | 0;
  var $cur = 0, $1 = 0, $2 = 0, $storemerge4 = 0, $3 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $cur = __stackBase__ | 0;
    $1 = HEAP32[$acur >> 2] | 0;
    HEAP32[$cur >> 2] = $1;
    $2 = $1 >>> 0 < $limit >>> 0;
    if ($2) {
      $storemerge4 = $1;
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 2:
    $3 = HEAP8[$storemerge4] | 0;
    if (($3 << 24 >> 24 | 0) == 37) {
      label = 3;
      break;
    } else if (($3 << 24 >> 24 | 0) == 32 | ($3 << 24 >> 24 | 0) == 13 | ($3 << 24 >> 24 | 0) == 10 | ($3 << 24 >> 24 | 0) == 9 | ($3 << 24 >> 24 | 0) == 12 | ($3 << 24 >> 24 | 0) == 0) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    _skip_comment($cur, $limit);
    label = 4;
    break;
   case 4:
    $6 = HEAP32[$cur >> 2] | 0;
    $7 = $6 + 1 | 0;
    HEAP32[$cur >> 2] = $7;
    $8 = $7 >>> 0 < $limit >>> 0;
    if ($8) {
      $storemerge4 = $7;
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $9 = HEAP32[$cur >> 2] | 0;
    HEAP32[$acur >> 2] = $9;
    STACKTOP = __stackBase__;
    return;
  }
}
function _ps_tobool($acur, $limit) {
  $acur = $acur | 0;
  $limit = $limit | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $19 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $_ = 0, $cur_0 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$acur >> 2] | 0;
    $2 = $1 + 3 | 0;
    $3 = $2 >>> 0 < $limit >>> 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 7;
      break;
    }
   case 2:
    $5 = HEAP8[$1] | 0;
    $6 = $5 << 24 >> 24 == 116;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 7;
      break;
    }
   case 3:
    $8 = $1 + 1 | 0;
    $9 = HEAP8[$8] | 0;
    $10 = $9 << 24 >> 24 == 114;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 7;
      break;
    }
   case 4:
    $12 = $1 + 2 | 0;
    $13 = HEAP8[$12] | 0;
    $14 = $13 << 24 >> 24 == 117;
    if ($14) {
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    $16 = HEAP8[$2] | 0;
    $17 = $16 << 24 >> 24 == 101;
    if ($17) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $19 = $1 + 5 | 0;
    $result_0 = 1;
    $cur_0 = $19;
    label = 13;
    break;
   case 7:
    $21 = $1 + 4 | 0;
    $22 = $21 >>> 0 < $limit >>> 0;
    if ($22) {
      label = 8;
      break;
    } else {
      $result_0 = 0;
      $cur_0 = $1;
      label = 13;
      break;
    }
   case 8:
    $24 = HEAP8[$1] | 0;
    $25 = $24 << 24 >> 24 == 102;
    if ($25) {
      label = 9;
      break;
    } else {
      $result_0 = 0;
      $cur_0 = $1;
      label = 13;
      break;
    }
   case 9:
    $27 = $1 + 1 | 0;
    $28 = HEAP8[$27] | 0;
    $29 = $28 << 24 >> 24 == 97;
    if ($29) {
      label = 10;
      break;
    } else {
      $result_0 = 0;
      $cur_0 = $1;
      label = 13;
      break;
    }
   case 10:
    $31 = $1 + 2 | 0;
    $32 = HEAP8[$31] | 0;
    $33 = $32 << 24 >> 24 == 108;
    if ($33) {
      label = 11;
      break;
    } else {
      $result_0 = 0;
      $cur_0 = $1;
      label = 13;
      break;
    }
   case 11:
    $35 = HEAP8[$2] | 0;
    $36 = $35 << 24 >> 24 == 115;
    if ($36) {
      label = 12;
      break;
    } else {
      $result_0 = 0;
      $cur_0 = $1;
      label = 13;
      break;
    }
   case 12:
    $38 = HEAP8[$21] | 0;
    $39 = $38 << 24 >> 24 == 101;
    $40 = $1 + 6 | 0;
    $_ = $39 ? $40 : $1;
    $result_0 = 0;
    $cur_0 = $_;
    label = 13;
    break;
   case 13:
    HEAP32[$acur >> 2] = $cur_0;
    return $result_0 | 0;
  }
  return 0;
}
function _skip_comment($acur, $limit) {
  $acur = $acur | 0;
  $limit = $limit | 0;
  var $1 = 0, $2 = 0, $cur_07 = 0, $3 = 0, $5 = 0, $6 = 0, $cur_0_lcssa = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$acur >> 2] | 0;
    $2 = $1 >>> 0 < $limit >>> 0;
    if ($2) {
      $cur_07 = $1;
      label = 2;
      break;
    } else {
      $cur_0_lcssa = $1;
      label = 4;
      break;
    }
   case 2:
    $3 = HEAP8[$cur_07] | 0;
    if (($3 << 24 >> 24 | 0) == 13 | ($3 << 24 >> 24 | 0) == 10) {
      $cur_0_lcssa = $cur_07;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $5 = $cur_07 + 1 | 0;
    $6 = $5 >>> 0 < $limit >>> 0;
    if ($6) {
      $cur_07 = $5;
      label = 2;
      break;
    } else {
      $cur_0_lcssa = $5;
      label = 4;
      break;
    }
   case 4:
    HEAP32[$acur >> 2] = $cur_0_lcssa;
    return;
  }
}
function _skip_literal_string($acur, $limit) {
  $acur = $acur | 0;
  $limit = $limit | 0;
  var $1 = 0, $2 = 0, $cur_0_ph33 = 0, $embed_0_ph32 = 0, $cur_025 = 0, $4 = 0, $5 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $cur_0_be = 0, $14 = 0, $cur_123 = 0, $i_022 = 0, $15 = 0, $_off = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $or_cond = 0, $23 = 0, $embed_0_ph_be = 0, $24 = 0, $26 = 0, $27 = 0, $error_0 = 0, $cur_2 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$acur >> 2] | 0;
    $2 = $1 >>> 0 < $limit >>> 0;
    if ($2) {
      $embed_0_ph32 = 0;
      $cur_0_ph33 = $1;
      label = 2;
      break;
    } else {
      $cur_2 = $1;
      $error_0 = 3;
      label = 14;
      break;
    }
   case 2:
    $cur_025 = $cur_0_ph33;
    label = 3;
    break;
   case 3:
    $4 = HEAP8[$cur_025] | 0;
    $5 = $cur_025 + 1 | 0;
    if (($4 << 24 >> 24 | 0) == 92) {
      label = 4;
      break;
    } else if (($4 << 24 >> 24 | 0) == 40) {
      label = 11;
      break;
    } else if (($4 << 24 >> 24 | 0) == 41) {
      label = 13;
      break;
    } else {
      $cur_0_be = $5;
      label = 8;
      break;
    }
   case 4:
    $7 = ($5 | 0) == ($limit | 0);
    if ($7) {
      $cur_2 = $5;
      $error_0 = 3;
      label = 14;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $9 = HEAP8[$5] | 0;
    $10 = $9 & 255;
    if (($10 | 0) == 110 | ($10 | 0) == 114 | ($10 | 0) == 116 | ($10 | 0) == 98 | ($10 | 0) == 102 | ($10 | 0) == 92 | ($10 | 0) == 40 | ($10 | 0) == 41) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $11 = $5 >>> 0 < $limit >>> 0;
    if ($11) {
      $i_022 = 0;
      $cur_123 = $5;
      label = 9;
      break;
    } else {
      $cur_0_be = $5;
      label = 8;
      break;
    }
   case 7:
    $13 = $cur_025 + 2 | 0;
    $cur_0_be = $13;
    label = 8;
    break;
   case 8:
    $14 = $cur_0_be >>> 0 < $limit >>> 0;
    if ($14) {
      $cur_025 = $cur_0_be;
      label = 3;
      break;
    } else {
      $cur_2 = $cur_0_be;
      $error_0 = 3;
      label = 14;
      break;
    }
   case 9:
    $15 = HEAP8[$cur_123] | 0;
    $_off = $15 - 48 & 255;
    $16 = ($_off & 255) < 8;
    if ($16) {
      label = 10;
      break;
    } else {
      $cur_0_be = $cur_123;
      label = 8;
      break;
    }
   case 10:
    $18 = $cur_123 + 1 | 0;
    $19 = $i_022 + 1 | 0;
    $20 = $19 >>> 0 < 3;
    $21 = $18 >>> 0 < $limit >>> 0;
    $or_cond = $20 & $21;
    if ($or_cond) {
      $i_022 = $19;
      $cur_123 = $18;
      label = 9;
      break;
    } else {
      $cur_0_be = $18;
      label = 8;
      break;
    }
   case 11:
    $23 = $embed_0_ph32 + 1 | 0;
    $embed_0_ph_be = $23;
    label = 12;
    break;
   case 12:
    $24 = $5 >>> 0 < $limit >>> 0;
    if ($24) {
      $embed_0_ph32 = $embed_0_ph_be;
      $cur_0_ph33 = $5;
      label = 2;
      break;
    } else {
      $cur_2 = $5;
      $error_0 = 3;
      label = 14;
      break;
    }
   case 13:
    $26 = $embed_0_ph32 - 1 | 0;
    $27 = ($26 | 0) == 0;
    if ($27) {
      $cur_2 = $5;
      $error_0 = 0;
      label = 14;
      break;
    } else {
      $embed_0_ph_be = $26;
      label = 12;
      break;
    }
   case 14:
    HEAP32[$acur >> 2] = $cur_2;
    return $error_0 | 0;
  }
  return 0;
}
function _PS_Conv_ASCIIHexDecode($cursor, $limit, $buffer, $n) {
  $cursor = $cursor | 0;
  $limit = $limit | 0;
  $buffer = $buffer | 0;
  $n = $n | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_ = 0, $7 = 0, $pad_041 = 0, $w_040 = 0, $r_039 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $w_1 = 0, $pad_1 = 0, $29 = 0, $30 = 0, $pad_0_lcssa = 0, $w_0_lcssa = 0, $r_0_lcssa = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $r_0_lcssa48 = 0, $w_2 = 0, $37 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $n << 1;
    $2 = HEAP32[$cursor >> 2] | 0;
    $3 = $limit;
    $4 = $2;
    $5 = $3 - $4 | 0;
    $6 = $1 >>> 0 > $5 >>> 0;
    $_ = $6 ? $5 : $1;
    $7 = ($_ | 0) == 0;
    if ($7) {
      $w_2 = 0;
      $r_0_lcssa48 = 0;
      label = 10;
      break;
    } else {
      $r_039 = 0;
      $w_040 = 0;
      $pad_041 = 1;
      label = 2;
      break;
    }
   case 2:
    $8 = $2 + $r_039 | 0;
    $9 = HEAP8[$8] | 0;
    $10 = $9 & 255;
    if (($9 << 24 >> 24 | 0) == 32 | ($9 << 24 >> 24 | 0) == 13 | ($9 << 24 >> 24 | 0) == 12 | ($9 << 24 >> 24 | 0) == 10 | ($9 << 24 >> 24 | 0) == 9 | ($9 << 24 >> 24 | 0) == 0) {
      $pad_1 = $pad_041;
      $w_1 = $w_040;
      label = 7;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = $9 << 24 >> 24 < 0;
    if ($12) {
      $r_0_lcssa = $r_039;
      $w_0_lcssa = $w_040;
      $pad_0_lcssa = $pad_041;
      label = 8;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $14 = $10 & 127;
    $15 = $14 + 5257092 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = ($16 & 255) > 15;
    if ($17) {
      $r_0_lcssa = $r_039;
      $w_0_lcssa = $w_040;
      $pad_0_lcssa = $pad_041;
      label = 8;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $19 = $16 << 24 >> 24;
    $20 = $pad_041 << 4;
    $21 = $19 | $20;
    $22 = $21 & 256;
    $23 = ($22 | 0) == 0;
    if ($23) {
      $pad_1 = $21;
      $w_1 = $w_040;
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $25 = $21 & 255;
    $26 = $w_040 + 1 | 0;
    $27 = $buffer + $w_040 | 0;
    HEAP8[$27] = $25;
    $pad_1 = 1;
    $w_1 = $26;
    label = 7;
    break;
   case 7:
    $29 = $r_039 + 1 | 0;
    $30 = $29 >>> 0 < $_ >>> 0;
    if ($30) {
      $r_039 = $29;
      $w_040 = $w_1;
      $pad_041 = $pad_1;
      label = 2;
      break;
    } else {
      $r_0_lcssa = $29;
      $w_0_lcssa = $w_1;
      $pad_0_lcssa = $pad_1;
      label = 8;
      break;
    }
   case 8:
    $31 = ($pad_0_lcssa | 0) == 1;
    if ($31) {
      $w_2 = $w_0_lcssa;
      $r_0_lcssa48 = $r_0_lcssa;
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $33 = $pad_0_lcssa << 4;
    $34 = $33 & 255;
    $35 = $w_0_lcssa + 1 | 0;
    $36 = $buffer + $w_0_lcssa | 0;
    HEAP8[$36] = $34;
    $w_2 = $35;
    $r_0_lcssa48 = $r_0_lcssa;
    label = 10;
    break;
   case 10:
    $37 = $2 + $r_0_lcssa48 | 0;
    HEAP32[$cursor >> 2] = $37;
    return $w_2 | 0;
  }
  return 0;
}
function _shift_elements($table, $old_base) {
  $table = $table | 0;
  $old_base = $old_base | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $offset_08 = 0, $12 = 0, $13 = 0, $15 = 0, $17 = 0, $18 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    $4 = $old_base;
    $5 = $3 - $4 | 0;
    $6 = $table + 24 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $table + 16 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $7 + ($9 << 2) | 0;
    $11 = ($9 | 0) > 0;
    if ($11) {
      $offset_08 = $7;
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 2:
    $12 = HEAP32[$offset_08 >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $15 = $12 + $5 | 0;
    HEAP32[$offset_08 >> 2] = $15;
    label = 4;
    break;
   case 4:
    $17 = $offset_08 + 4 | 0;
    $18 = $17 >>> 0 < $10 >>> 0;
    if ($18) {
      $offset_08 = $17;
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    return;
  }
}
function _ps_tofixedarray($acur, $limit, $max_values, $values, $power_ten) {
  $acur = $acur | 0;
  $limit = $limit | 0;
  $max_values = $max_values | 0;
  $values = $values | 0;
  $power_ten = $power_ten | 0;
  var $cur = 0, $dummy = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $7 = 0, $_ = 0, $ender_019 = 0, $8 = 0, $9 = 0, $_ph = 0, $ender_018_ph = 0, $10 = 0, $_not = 0, $12 = 0, $count_0 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $22 = 0, $24 = 0, $or_cond = 0, $26 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $count_1 = 0, $35 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $cur = __stackBase__ | 0;
    $dummy = __stackBase__ + 4 | 0;
    $1 = HEAP32[$acur >> 2] | 0;
    HEAP32[$cur >> 2] = $1;
    $2 = $1 >>> 0 < $limit >>> 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $count_1 = 0;
      label = 15;
      break;
    }
   case 2:
    $4 = HEAP8[$1] | 0;
    $5 = $4 << 24 >> 24 == 91;
    if ($5) {
      $ender_019 = 93;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $4 << 24 >> 24 == 123;
    $_ = $7 ? 125 : 0;
    if ($7) {
      $ender_019 = $_;
      label = 4;
      break;
    } else {
      $ender_018_ph = 0;
      $_ph = 0;
      label = 5;
      break;
    }
   case 4:
    $8 = HEAP32[$cur >> 2] | 0;
    $9 = $8 + 1 | 0;
    HEAP32[$cur >> 2] = $9;
    $ender_018_ph = $ender_019;
    $_ph = 1;
    label = 5;
    break;
   case 5:
    $10 = ($values | 0) != 0;
    $_not = $10 ^ 1;
    $count_0 = 0;
    $12 = $_ph;
    label = 6;
    break;
   case 6:
    $13 = HEAP32[$cur >> 2] | 0;
    $14 = $13 >>> 0 < $limit >>> 0;
    if ($14) {
      label = 7;
      break;
    } else {
      $count_1 = $count_0;
      label = 15;
      break;
    }
   case 7:
    _skip_spaces($cur, $limit);
    $16 = HEAP32[$cur >> 2] | 0;
    $17 = $16 >>> 0 < $limit >>> 0;
    if ($17) {
      label = 8;
      break;
    } else {
      $count_1 = $count_0;
      label = 15;
      break;
    }
   case 8:
    $19 = HEAP8[$16] | 0;
    $20 = $19 << 24 >> 24 == $ender_018_ph << 24 >> 24;
    if ($20) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $22 = $16 + 1 | 0;
    HEAP32[$cur >> 2] = $22;
    $count_1 = $count_0;
    label = 15;
    break;
   case 10:
    $24 = ($count_0 | 0) < ($max_values | 0);
    $or_cond = $24 | $_not;
    if ($or_cond) {
      label = 11;
      break;
    } else {
      $count_1 = $count_0;
      label = 15;
      break;
    }
   case 11:
    $26 = _PS_Conv_ToFixed($cur, $limit, $power_ten) | 0;
    if ($10) {
      label = 12;
      break;
    } else {
      $30 = $dummy;
      label = 13;
      break;
    }
   case 12:
    $28 = $values + ($count_0 << 2) | 0;
    $30 = $28;
    label = 13;
    break;
   case 13:
    HEAP32[$30 >> 2] = $26;
    $31 = HEAP32[$cur >> 2] | 0;
    $32 = ($16 | 0) == ($31 | 0);
    if ($32) {
      $count_1 = -1;
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $34 = $count_0 + 1 | 0;
    if ($12) {
      $count_0 = $34;
      $12 = 1;
      label = 6;
      break;
    } else {
      $count_1 = $34;
      label = 15;
      break;
    }
   case 15:
    $35 = HEAP32[$cur >> 2] | 0;
    HEAP32[$acur >> 2] = $35;
    STACKTOP = __stackBase__;
    return $count_1 | 0;
  }
  return 0;
}
function _skip_procedure($acur, $limit) {
  $acur = $acur | 0;
  $limit = $limit | 0;
  var $cur = 0, $1 = 0, $2 = 0, $error_016 = 0, $embed_015 = 0, $storemerge14 = 0, $3 = 0, $4 = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $13 = 0, $15 = 0, $embed_1 = 0, $error_1 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $or_cond = 0, $error_013 = 0, $embed_2 = 0, $22 = 0, $error_0_ = 0, $23 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $cur = __stackBase__ | 0;
    $1 = HEAP32[$acur >> 2] | 0;
    HEAP32[$cur >> 2] = $1;
    $2 = $1 >>> 0 < $limit >>> 0;
    if ($2) {
      $storemerge14 = $1;
      $embed_015 = 0;
      $error_016 = 0;
      label = 2;
      break;
    } else {
      $embed_2 = 0;
      $error_013 = 0;
      label = 10;
      break;
    }
   case 2:
    $3 = HEAP8[$storemerge14] | 0;
    $4 = $3 & 255;
    if (($4 | 0) == 123) {
      label = 3;
      break;
    } else if (($4 | 0) == 125) {
      label = 4;
      break;
    } else if (($4 | 0) == 40) {
      label = 6;
      break;
    } else if (($4 | 0) == 60) {
      label = 7;
      break;
    } else if (($4 | 0) == 37) {
      label = 8;
      break;
    } else {
      $error_1 = $error_016;
      $embed_1 = $embed_015;
      label = 9;
      break;
    }
   case 3:
    $6 = $embed_015 + 1 | 0;
    $error_1 = $error_016;
    $embed_1 = $6;
    label = 9;
    break;
   case 4:
    $8 = $embed_015 - 1 | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 5;
      break;
    } else {
      $error_1 = $error_016;
      $embed_1 = $8;
      label = 9;
      break;
    }
   case 5:
    $11 = $storemerge14 + 1 | 0;
    HEAP32[$cur >> 2] = $11;
    $embed_2 = 0;
    $error_013 = $error_016;
    label = 10;
    break;
   case 6:
    $13 = _skip_literal_string($cur, $limit) | 0;
    $error_1 = $13;
    $embed_1 = $embed_015;
    label = 9;
    break;
   case 7:
    $15 = _skip_string($cur, $limit) | 0;
    $error_1 = $15;
    $embed_1 = $embed_015;
    label = 9;
    break;
   case 8:
    _skip_comment($cur, $limit);
    $error_1 = $error_016;
    $embed_1 = $embed_015;
    label = 9;
    break;
   case 9:
    $18 = HEAP32[$cur >> 2] | 0;
    $19 = $18 + 1 | 0;
    HEAP32[$cur >> 2] = $19;
    $20 = $19 >>> 0 < $limit >>> 0;
    $21 = ($error_1 | 0) == 0;
    $or_cond = $20 & $21;
    if ($or_cond) {
      $storemerge14 = $19;
      $embed_015 = $embed_1;
      $error_016 = $error_1;
      label = 2;
      break;
    } else {
      $embed_2 = $embed_1;
      $error_013 = $error_1;
      label = 10;
      break;
    }
   case 10:
    $22 = ($embed_2 | 0) == 0;
    $error_0_ = $22 ? $error_013 : 3;
    $23 = HEAP32[$cur >> 2] | 0;
    HEAP32[$acur >> 2] = $23;
    STACKTOP = __stackBase__;
    return $error_0_ | 0;
  }
  return 0;
}
function _skip_string($acur, $limit) {
  $acur = $acur | 0;
  $limit = $limit | 0;
  var $cur = 0, $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $_off = 0, $11 = 0, $_off8 = 0, $12 = 0, $or_cond = 0, $_off9 = 0, $13 = 0, $or_cond12 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $err_0 = 0, $24 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $cur = __stackBase__ | 0;
    $1 = HEAP32[$acur >> 2] | 0;
    HEAP32[$cur >> 2] = $1;
    label = 2;
    break;
   case 2:
    $3 = HEAP32[$cur >> 2] | 0;
    $4 = $3 + 1 | 0;
    HEAP32[$cur >> 2] = $4;
    $5 = $4 >>> 0 < $limit >>> 0;
    if ($5) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    _skip_spaces($cur, $limit);
    $7 = HEAP32[$cur >> 2] | 0;
    $8 = $7 >>> 0 < $limit >>> 0;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $10 = HEAP8[$7] | 0;
    $_off = $10 - 48 & 255;
    $11 = ($_off & 255) < 10;
    $_off8 = $10 - 65 & 255;
    $12 = ($_off8 & 255) < 6;
    $or_cond = $11 | $12;
    $_off9 = $10 - 97 & 255;
    $13 = ($_off9 & 255) < 6;
    $or_cond12 = $or_cond | $13;
    if ($or_cond12) {
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $15 = HEAP32[$cur >> 2] | 0;
    $16 = $15 >>> 0 < $limit >>> 0;
    if ($16) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $18 = HEAP8[$15] | 0;
    $19 = $18 << 24 >> 24 == 62;
    if ($19) {
      label = 7;
      break;
    } else {
      $err_0 = 3;
      label = 8;
      break;
    }
   case 7:
    $21 = HEAP32[$cur >> 2] | 0;
    $22 = $21 + 1 | 0;
    HEAP32[$cur >> 2] = $22;
    $err_0 = 0;
    label = 8;
    break;
   case 8:
    $24 = HEAP32[$cur >> 2] | 0;
    HEAP32[$acur >> 2] = $24;
    STACKTOP = __stackBase__;
    return $err_0 | 0;
  }
  return 0;
}
function _ps_tocoordarray($acur, $limit, $max_coords, $coords) {
  $acur = $acur | 0;
  $limit = $limit | 0;
  $max_coords = $max_coords | 0;
  $coords = $coords | 0;
  var $cur = 0, $dummy = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $7 = 0, $_ = 0, $ender_018 = 0, $8 = 0, $9 = 0, $_ph = 0, $ender_017_ph = 0, $10 = 0, $_not = 0, $12 = 0, $count_0 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $22 = 0, $24 = 0, $or_cond = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $count_1 = 0, $37 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $cur = __stackBase__ | 0;
    $dummy = __stackBase__ + 4 | 0;
    $1 = HEAP32[$acur >> 2] | 0;
    HEAP32[$cur >> 2] = $1;
    $2 = $1 >>> 0 < $limit >>> 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $count_1 = 0;
      label = 15;
      break;
    }
   case 2:
    $4 = HEAP8[$1] | 0;
    $5 = $4 << 24 >> 24 == 91;
    if ($5) {
      $ender_018 = 93;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $4 << 24 >> 24 == 123;
    $_ = $7 ? 125 : 0;
    if ($7) {
      $ender_018 = $_;
      label = 4;
      break;
    } else {
      $ender_017_ph = 0;
      $_ph = 0;
      label = 5;
      break;
    }
   case 4:
    $8 = HEAP32[$cur >> 2] | 0;
    $9 = $8 + 1 | 0;
    HEAP32[$cur >> 2] = $9;
    $ender_017_ph = $ender_018;
    $_ph = 1;
    label = 5;
    break;
   case 5:
    $10 = ($coords | 0) != 0;
    $_not = $10 ^ 1;
    $count_0 = 0;
    $12 = $_ph;
    label = 6;
    break;
   case 6:
    $13 = HEAP32[$cur >> 2] | 0;
    $14 = $13 >>> 0 < $limit >>> 0;
    if ($14) {
      label = 7;
      break;
    } else {
      $count_1 = $count_0;
      label = 15;
      break;
    }
   case 7:
    _skip_spaces($cur, $limit);
    $16 = HEAP32[$cur >> 2] | 0;
    $17 = $16 >>> 0 < $limit >>> 0;
    if ($17) {
      label = 8;
      break;
    } else {
      $count_1 = $count_0;
      label = 15;
      break;
    }
   case 8:
    $19 = HEAP8[$16] | 0;
    $20 = $19 << 24 >> 24 == $ender_017_ph << 24 >> 24;
    if ($20) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $22 = $16 + 1 | 0;
    HEAP32[$cur >> 2] = $22;
    $count_1 = $count_0;
    label = 15;
    break;
   case 10:
    $24 = ($count_0 | 0) < ($max_coords | 0);
    $or_cond = $24 | $_not;
    if ($or_cond) {
      label = 11;
      break;
    } else {
      $count_1 = $count_0;
      label = 15;
      break;
    }
   case 11:
    $26 = _PS_Conv_ToFixed($cur, $limit, 0) | 0;
    $27 = $26 >>> 16;
    $28 = $27 & 65535;
    if ($10) {
      label = 12;
      break;
    } else {
      $32 = $dummy;
      label = 13;
      break;
    }
   case 12:
    $30 = $coords + ($count_0 << 1) | 0;
    $32 = $30;
    label = 13;
    break;
   case 13:
    HEAP16[$32 >> 1] = $28;
    $33 = HEAP32[$cur >> 2] | 0;
    $34 = ($16 | 0) == ($33 | 0);
    if ($34) {
      $count_1 = -1;
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $36 = $count_0 + 1 | 0;
    if ($12) {
      $count_0 = $36;
      $12 = 1;
      label = 6;
      break;
    } else {
      $count_1 = $36;
      label = 15;
      break;
    }
   case 15:
    $37 = HEAP32[$cur >> 2] | 0;
    HEAP32[$acur >> 2] = $37;
    STACKTOP = __stackBase__;
    return $count_1 | 0;
  }
  return 0;
}
function _reallocate_t1_table($table, $new_size) {
  $table = $table | 0;
  $new_size = $new_size | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $11 = 0, $13 = 0, $14 = 0, $16 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $table + 32 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $table | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = _ft_mem_alloc($2, $new_size, $error) | 0;
    HEAP32[$3 >> 2] = $5;
    $6 = HEAP32[$error >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    HEAP32[$3 >> 2] = $4;
    $9 = HEAP32[$error >> 2] | 0;
    $_0 = $9;
    label = 6;
    break;
   case 3:
    $11 = ($4 | 0) == 0;
    if ($11) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $13 = $table + 8 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    _memcpy($5 | 0, $4 | 0, $14 | 0);
    _shift_elements($table, $4);
    _ft_mem_free($2, $4);
    label = 5;
    break;
   case 5:
    $16 = $table + 8 | 0;
    HEAP32[$16 >> 2] = $new_size;
    $_0 = 0;
    label = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _ps_hints_apply($ps_hints, $outline, $globals, $hint_mode) {
  $ps_hints = $ps_hints | 0;
  $outline = $outline | 0;
  $globals = $globals | 0;
  $hint_mode = $hint_mode | 0;
  var $glyphrec = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $or_cond = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $x_scale_0 = 0, $33 = 0, $34 = 0, $rescale_0 = 0, $36 = 0, $37 = 0, $38 = 0, $hint_mode_off = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $dimension_057 = 0, $50 = 0, $51 = 0, $52 = 0, $56 = 0, $57 = 0, $59 = 0, $exitcond = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 128 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $glyphrec = __stackBase__ | 0;
    $1 = $outline + 2 | 0;
    $2 = HEAP16[$1 >> 1] | 0;
    $3 = $2 << 16 >> 16 == 0;
    if ($3) {
      $_0 = 0;
      label = 15;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $outline | 0;
    $6 = HEAP16[$5 >> 1] | 0;
    $7 = $6 << 16 >> 16 == 0;
    if ($7) {
      $_0 = 0;
      label = 15;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = _psh_glyph_init($glyphrec, $outline, $ps_hints, $globals) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 14;
      break;
    }
   case 4:
    $12 = $glyphrec + 24 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 + 200 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $13 + 404 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $globals + 412 | 0;
    $19 = $globals + 416 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = _FT_MulFix($20, $17) | 0;
    $22 = $21 + 32 | 0;
    $23 = $22 & -64;
    $24 = ($23 | 0) == 0;
    $25 = ($21 | 0) == ($23 | 0);
    $or_cond = $24 | $25;
    if ($or_cond) {
      $rescale_0 = 1;
      label = 8;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $27 = _FT_MulDiv($17, $23, $21) | 0;
    $28 = ($23 | 0) < ($21 | 0);
    if ($28) {
      label = 6;
      break;
    } else {
      $x_scale_0 = $15;
      label = 7;
      break;
    }
   case 6:
    $30 = ($15 | 0) / 50 & -1;
    $31 = $15 - $30 | 0;
    $x_scale_0 = $31;
    label = 7;
    break;
   case 7:
    $33 = HEAP32[$12 >> 2] | 0;
    $34 = _psh_globals_set_scale($33, $x_scale_0, $27, 0, 0) | 0;
    $rescale_0 = 0;
    label = 8;
    break;
   case 8:
    $36 = $glyphrec + 120 | 0;
    HEAP8[$36] = 1;
    $37 = $glyphrec + 121 | 0;
    HEAP8[$37] = 1;
    $38 = ($hint_mode | 0) == 2;
    $hint_mode_off = $hint_mode - 2 | 0;
    $39 = $hint_mode_off >>> 0 < 2;
    $40 = $39 & 1;
    $41 = $glyphrec + 122 | 0;
    HEAP8[$41] = $40;
    $42 = ($hint_mode | 0) == 4;
    $43 = $38 | $42;
    $44 = $43 & 1;
    $45 = $glyphrec + 123 | 0;
    HEAP8[$45] = $44;
    $46 = ($hint_mode | 0) != 1;
    $47 = $46 & 1;
    $48 = $glyphrec + 124 | 0;
    HEAP8[$48] = $47;
    $dimension_057 = 0;
    label = 9;
    break;
   case 9:
    _psh_glyph_load_points($glyphrec, $dimension_057);
    _psh_glyph_compute_extrema($glyphrec);
    $50 = $glyphrec + 28 + ($dimension_057 * 40 & -1) | 0;
    $51 = HEAP32[$12 >> 2] | 0;
    _psh_hint_table_align_hints($50, $51, $dimension_057, $glyphrec);
    _psh_glyph_find_strong_points($glyphrec, $dimension_057);
    $52 = ($dimension_057 | 0) == 1;
    if ($52) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    _psh_glyph_find_blue_points($18, $glyphrec);
    label = 11;
    break;
   case 11:
    _psh_glyph_interpolate_strong_points($glyphrec, $dimension_057);
    _psh_glyph_interpolate_normal_points($glyphrec, $dimension_057);
    _psh_glyph_interpolate_other_points($glyphrec, $dimension_057);
    _psh_glyph_save_points($glyphrec, $dimension_057);
    if ($rescale_0) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $56 = HEAP32[$12 >> 2] | 0;
    $57 = _psh_globals_set_scale($56, $15, $17, 0, 0) | 0;
    label = 13;
    break;
   case 13:
    $59 = $dimension_057 + 1 | 0;
    $exitcond = ($59 | 0) == 2;
    if ($exitcond) {
      label = 14;
      break;
    } else {
      $dimension_057 = $59;
      label = 9;
      break;
    }
   case 14:
    _psh_glyph_done($glyphrec);
    $_0 = $9;
    label = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _psh_glyph_init($glyph, $outline, $ps_hints, $globals) {
  $glyph = $glyph | 0;
  $outline = $outline | 0;
  $ps_hints = $ps_hints | 0;
  $globals = $globals | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $first_0101 = 0, $n_0100 = 0, $contour_099 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $count_095 = 0, $point_094 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $scevgep = 0, $point_0_lcssa = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $point2_093 = 0, $n3_092 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $88 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $119 = 0, $121 = 0, $122 = 0, $sext = 0, $123 = 0, $124 = 0, $126 = 0, $128 = 0, $129 = 0, $131 = 0, $132 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $151 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $glyph;
    _memset($1 | 0, 0, 128);
    $2 = $globals | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $glyph + 16 | 0;
    HEAP32[$4 >> 2] = $3;
    $5 = $outline + 2 | 0;
    $6 = HEAP16[$5 >> 1] | 0;
    $7 = $6 << 16 >> 16;
    $8 = _ft_mem_realloc($3, 48, 0, $7, 0, $error) | 0;
    $9 = $8;
    $10 = $glyph + 8 | 0;
    HEAP32[$10 >> 2] = $9;
    $11 = HEAP32[$error >> 2] | 0;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 2;
      break;
    } else {
      label = 25;
      break;
    }
   case 2:
    $14 = $outline | 0;
    $15 = HEAP16[$14 >> 1] | 0;
    $16 = $15 << 16 >> 16;
    $17 = _ft_mem_realloc($3, 8, 0, $16, 0, $error) | 0;
    $18 = $17;
    $19 = $glyph + 12 | 0;
    HEAP32[$19 >> 2] = $18;
    $20 = HEAP32[$error >> 2] | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 3;
      break;
    } else {
      label = 25;
      break;
    }
   case 3:
    $23 = HEAP16[$5 >> 1] | 0;
    $24 = $23 << 16 >> 16;
    $25 = $glyph | 0;
    HEAP32[$25 >> 2] = $24;
    $26 = HEAP16[$14 >> 1] | 0;
    $27 = $26 << 16 >> 16;
    $28 = $glyph + 4 | 0;
    HEAP32[$28 >> 2] = $27;
    $29 = HEAP32[$10 >> 2] | 0;
    $30 = $26 << 16 >> 16 == 0;
    if ($30) {
      label = 12;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $31 = HEAP32[$19 >> 2] | 0;
    $32 = $outline + 12 | 0;
    $contour_099 = $31;
    $n_0100 = 0;
    $first_0101 = 0;
    label = 5;
    break;
   case 5:
    $34 = HEAP32[$32 >> 2] | 0;
    $35 = $34 + ($n_0100 << 1) | 0;
    $36 = HEAP16[$35 >> 1] | 0;
    $37 = $36 << 16 >> 16;
    $38 = $37 + 1 | 0;
    $39 = $38 - $first_0101 | 0;
    $40 = $29 + ($first_0101 * 48 & -1) | 0;
    $41 = $contour_099 | 0;
    HEAP32[$41 >> 2] = $40;
    $42 = $contour_099 + 4 | 0;
    HEAP32[$42 >> 2] = $39;
    $43 = ($39 | 0) > 0;
    if ($43) {
      label = 6;
      break;
    } else {
      label = 11;
      break;
    }
   case 6:
    $45 = $29 + ($37 * 48 & -1) | 0;
    $46 = $40 | 0;
    HEAP32[$46 >> 2] = $45;
    $47 = $29 + ($first_0101 * 48 & -1) + 8 | 0;
    HEAP32[$47 >> 2] = $contour_099;
    $48 = ($39 | 0) > 1;
    if ($48) {
      label = 7;
      break;
    } else {
      $point_0_lcssa = $40;
      label = 10;
      break;
    }
   case 7:
    $49 = $36 << 16 >> 16;
    $point_094 = $40;
    $count_095 = $39;
    label = 8;
    break;
   case 8:
    $51 = $point_094 + 48 | 0;
    $52 = $point_094 + 4 | 0;
    HEAP32[$52 >> 2] = $51;
    $53 = $51 | 0;
    HEAP32[$53 >> 2] = $point_094;
    $54 = $point_094 + 56 | 0;
    HEAP32[$54 >> 2] = $contour_099;
    $55 = $count_095 - 1 | 0;
    $56 = ($55 | 0) > 1;
    if ($56) {
      $point_094 = $51;
      $count_095 = $55;
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $scevgep = $29 + ($49 * 48 & -1) | 0;
    $point_0_lcssa = $scevgep;
    label = 10;
    break;
   case 10:
    $58 = $point_0_lcssa + 4 | 0;
    HEAP32[$58 >> 2] = $40;
    label = 11;
    break;
   case 11:
    $60 = $contour_099 + 8 | 0;
    $61 = $n_0100 + 1 | 0;
    $62 = HEAP32[$28 >> 2] | 0;
    $63 = $61 >>> 0 < $62 >>> 0;
    if ($63) {
      $contour_099 = $60;
      $n_0100 = $61;
      $first_0101 = $38;
      label = 5;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $64 = HEAP32[$10 >> 2] | 0;
    $65 = $outline + 4 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = HEAP32[$25 >> 2] | 0;
    $68 = ($67 | 0) == 0;
    if ($68) {
      label = 23;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $69 = $64;
    $70 = $outline + 8 | 0;
    $n3_092 = 0;
    $point2_093 = $64;
    label = 14;
    break;
   case 14:
    $72 = $point2_093 | 0;
    $73 = HEAP32[$72 >> 2] | 0;
    $74 = $73;
    $75 = $74 - $69 | 0;
    $76 = ($75 | 0) / 48 & -1;
    $77 = $point2_093 + 4 | 0;
    $78 = HEAP32[$77 >> 2] | 0;
    $79 = $78;
    $80 = $79 - $69 | 0;
    $81 = ($80 | 0) / 48 & -1;
    $82 = HEAP32[$70 >> 2] | 0;
    $83 = $82 + $n3_092 | 0;
    $84 = HEAP8[$83] | 0;
    $85 = $84 & 1;
    $86 = $85 << 24 >> 24 == 0;
    if ($86) {
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 15:
    $88 = $point2_093 + 12 | 0;
    HEAP32[$88 >> 2] = 1;
    label = 16;
    break;
   case 16:
    $90 = $66 + ($n3_092 << 3) | 0;
    $91 = HEAP32[$90 >> 2] | 0;
    $92 = $66 + ($76 << 3) | 0;
    $93 = HEAP32[$92 >> 2] | 0;
    $94 = $91 - $93 | 0;
    $95 = $66 + ($n3_092 << 3) + 4 | 0;
    $96 = HEAP32[$95 >> 2] | 0;
    $97 = $66 + ($76 << 3) + 4 | 0;
    $98 = HEAP32[$97 >> 2] | 0;
    $99 = $96 - $98 | 0;
    $100 = _psh_compute_dir($94, $99) | 0;
    $101 = $100 & 255;
    $102 = $point2_093 + 20 | 0;
    HEAP8[$102] = $101;
    $103 = $66 + ($81 << 3) | 0;
    $104 = HEAP32[$103 >> 2] | 0;
    $105 = HEAP32[$90 >> 2] | 0;
    $106 = $104 - $105 | 0;
    $107 = $66 + ($81 << 3) + 4 | 0;
    $108 = HEAP32[$107 >> 2] | 0;
    $109 = HEAP32[$95 >> 2] | 0;
    $110 = $108 - $109 | 0;
    $111 = _psh_compute_dir($106, $110) | 0;
    $112 = $111 & 255;
    $113 = $point2_093 + 21 | 0;
    HEAP8[$113] = $112;
    $114 = $point2_093 + 12 | 0;
    $115 = HEAP32[$114 >> 2] | 0;
    $116 = $115 & 1;
    $117 = ($116 | 0) == 0;
    if ($117) {
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $119 = $115 | 2;
    HEAP32[$114 >> 2] = $119;
    label = 22;
    break;
   case 18:
    $121 = HEAP8[$102] | 0;
    $122 = $121 << 24 >> 24;
    $sext = $111 << 24;
    $123 = $sext >> 24;
    $124 = ($122 | 0) == ($123 | 0);
    if ($124) {
      label = 19;
      break;
    } else {
      label = 22;
      break;
    }
   case 19:
    $126 = ($123 | 0) == 4;
    if ($126) {
      label = 20;
      break;
    } else {
      label = 21;
      break;
    }
   case 20:
    $128 = _ft_corner_is_flat($94, $99, $106, $110) | 0;
    $129 = ($128 | 0) == 0;
    if ($129) {
      label = 22;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $131 = HEAP32[$114 >> 2] | 0;
    $132 = $131 | 2;
    HEAP32[$114 >> 2] = $132;
    label = 22;
    break;
   case 22:
    $134 = $n3_092 + 1 | 0;
    $135 = $point2_093 + 48 | 0;
    $136 = HEAP32[$25 >> 2] | 0;
    $137 = $134 >>> 0 < $136 >>> 0;
    if ($137) {
      $n3_092 = $134;
      $point2_093 = $135;
      label = 14;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $138 = $glyph + 20 | 0;
    HEAP32[$138 >> 2] = $outline;
    $139 = $glyph + 24 | 0;
    HEAP32[$139 >> 2] = $globals;
    _psh_glyph_load_points($glyph, 0);
    _psh_glyph_compute_inflections($glyph);
    $140 = $glyph + 28 | 0;
    $141 = $ps_hints + 16 | 0;
    $142 = $ps_hints + 28 | 0;
    $143 = _psh_hint_table_init($140, $141, $142, $3) | 0;
    HEAP32[$error >> 2] = $143;
    $144 = ($143 | 0) == 0;
    if ($144) {
      label = 24;
      break;
    } else {
      label = 25;
      break;
    }
   case 24:
    $146 = $glyph + 68 | 0;
    $147 = $ps_hints + 52 | 0;
    $148 = $ps_hints + 64 | 0;
    $149 = _psh_hint_table_init($146, $147, $148, $3) | 0;
    HEAP32[$error >> 2] = $149;
    label = 25;
    break;
   case 25:
    $151 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $151 | 0;
  }
  return 0;
}
function _psh_glyph_load_points($glyph, $dimension) {
  $glyph = $glyph | 0;
  $dimension = $dimension | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $count_016 = 0, $point_015 = 0, $vec_014 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $glyph | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 7;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $glyph + 20 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $glyph + 8 | 0;
    $7 = $5 + 4 | 0;
    $8 = HEAP32[$6 >> 2] | 0;
    $9 = HEAP32[$7 >> 2] | 0;
    $10 = ($dimension | 0) == 0;
    $vec_014 = $9;
    $point_015 = $8;
    $count_016 = $2;
    label = 3;
    break;
   case 3:
    $12 = $point_015 + 16 | 0;
    HEAP32[$12 >> 2] = 0;
    $13 = $point_015 + 32 | 0;
    HEAP32[$13 >> 2] = 0;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $15 = $vec_014 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $point_015 + 36 | 0;
    HEAP32[$17 >> 2] = $16;
    $18 = $vec_014 + 4 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $point_015 + 40 | 0;
    HEAP32[$20 >> 2] = $19;
    label = 6;
    break;
   case 5:
    $22 = $vec_014 + 4 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $point_015 + 36 | 0;
    HEAP32[$24 >> 2] = $23;
    $25 = $vec_014 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $point_015 + 40 | 0;
    HEAP32[$27 >> 2] = $26;
    label = 6;
    break;
   case 6:
    $29 = $count_016 - 1 | 0;
    $30 = $point_015 + 48 | 0;
    $31 = $vec_014 + 8 | 0;
    $32 = ($29 | 0) == 0;
    if ($32) {
      label = 7;
      break;
    } else {
      $vec_014 = $31;
      $point_015 = $30;
      $count_016 = $29;
      label = 3;
      break;
    }
   case 7:
    return;
  }
}
function _psh_glyph_compute_extrema($glyph) {
  $glyph = $glyph | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $n_070 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $before_0 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $point_0 = 0, $before_1 = 0, $26 = 0, $after_0 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $43 = 0, $point_1 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $n_1 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $before2_0 = 0, $68 = 0, $69 = 0, $70 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $after3_0 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $before2_1 = 0, $after3_1 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $90 = 0, $91 = 0, $92 = 0, $94 = 0, $95 = 0, $97 = 0, $98 = 0, $99 = 0, $101 = 0, $102 = 0, $103 = 0, $105 = 0, $106 = 0, $n_2 = 0, $107 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $glyph + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      $n_1 = 0;
      label = 17;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $glyph + 12 | 0;
    $n_070 = 0;
    label = 3;
    break;
   case 3:
    $6 = HEAP32[$4 >> 2] | 0;
    $7 = $6 + ($n_070 << 3) | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $6 + ($n_070 << 3) + 4 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 16;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $12 = $8 + 36 | 0;
    $before_0 = $8;
    label = 5;
    break;
   case 5:
    $14 = $before_0 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = ($15 | 0) == ($8 | 0);
    if ($16) {
      $n_2 = $n_070;
      label = 30;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $18 = $15 + 36 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = HEAP32[$12 >> 2] | 0;
    $21 = ($19 | 0) == ($20 | 0);
    if ($21) {
      $before_0 = $15;
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $23 = $15 + 4 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $before_1 = $15;
    $point_0 = $24;
    label = 8;
    break;
   case 8:
    $26 = $point_0 + 36 | 0;
    $after_0 = $point_0;
    label = 9;
    break;
   case 9:
    $28 = $after_0 + 4 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = ($29 | 0) == ($24 | 0);
    if ($30) {
      label = 16;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $32 = $29 + 36 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = HEAP32[$26 >> 2] | 0;
    $35 = ($33 | 0) == ($34 | 0);
    if ($35) {
      $after_0 = $29;
      label = 9;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $37 = $before_1 + 36 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = ($38 | 0) < ($34 | 0);
    if ($39) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $41 = ($33 | 0) < ($34 | 0);
    if ($41) {
      $point_1 = $point_0;
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 13:
    $43 = ($33 | 0) > ($34 | 0);
    if ($43) {
      $point_1 = $point_0;
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $44 = $point_1 + 16 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = $45 | 64;
    HEAP32[$44 >> 2] = $46;
    $47 = $point_1 + 4 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = ($48 | 0) == ($29 | 0);
    if ($49) {
      label = 15;
      break;
    } else {
      $point_1 = $48;
      label = 14;
      break;
    }
   case 15:
    $50 = $29 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $before_1 = $51;
    $point_0 = $29;
    label = 8;
    break;
   case 16:
    $52 = $n_070 + 1 | 0;
    $53 = HEAP32[$1 >> 2] | 0;
    $54 = $52 >>> 0 < $53 >>> 0;
    if ($54) {
      $n_070 = $52;
      label = 3;
      break;
    } else {
      $n_1 = 0;
      label = 17;
      break;
    }
   case 17:
    $55 = $glyph | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = $n_1 >>> 0 < $56 >>> 0;
    if ($57) {
      label = 18;
      break;
    } else {
      label = 31;
      break;
    }
   case 18:
    $59 = $glyph + 8 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = $60 + ($n_1 * 48 & -1) | 0;
    $62 = $60 + ($n_1 * 48 & -1) + 16 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = $63 & 64;
    $65 = ($64 | 0) == 0;
    if ($65) {
      $after3_1 = $61;
      $before2_1 = $61;
      label = 24;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $66 = $60 + ($n_1 * 48 & -1) + 40 | 0;
    $before2_0 = $61;
    label = 20;
    break;
   case 20:
    $68 = $before2_0 | 0;
    $69 = HEAP32[$68 >> 2] | 0;
    $70 = ($69 | 0) == ($61 | 0);
    if ($70) {
      $n_2 = $n_1;
      label = 30;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $72 = $69 + 40 | 0;
    $73 = HEAP32[$72 >> 2] | 0;
    $74 = HEAP32[$66 >> 2] | 0;
    $75 = ($73 | 0) == ($74 | 0);
    if ($75) {
      $before2_0 = $69;
      label = 20;
      break;
    } else {
      $after3_0 = $61;
      label = 22;
      break;
    }
   case 22:
    $76 = $after3_0 + 4 | 0;
    $77 = HEAP32[$76 >> 2] | 0;
    $78 = ($77 | 0) == ($61 | 0);
    if ($78) {
      $n_2 = $n_1;
      label = 30;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $80 = $77 + 40 | 0;
    $81 = HEAP32[$80 >> 2] | 0;
    $82 = HEAP32[$66 >> 2] | 0;
    $83 = ($81 | 0) == ($82 | 0);
    if ($83) {
      $after3_0 = $77;
      label = 22;
      break;
    } else {
      $after3_1 = $77;
      $before2_1 = $69;
      label = 24;
      break;
    }
   case 24:
    $84 = $before2_1 + 40 | 0;
    $85 = HEAP32[$84 >> 2] | 0;
    $86 = $60 + ($n_1 * 48 & -1) + 40 | 0;
    $87 = HEAP32[$86 >> 2] | 0;
    $88 = ($85 | 0) < ($87 | 0);
    if ($88) {
      label = 25;
      break;
    } else {
      label = 27;
      break;
    }
   case 25:
    $90 = $after3_1 + 40 | 0;
    $91 = HEAP32[$90 >> 2] | 0;
    $92 = ($91 | 0) > ($87 | 0);
    if ($92) {
      label = 26;
      break;
    } else {
      label = 27;
      break;
    }
   case 26:
    $94 = HEAP32[$62 >> 2] | 0;
    $95 = $94 | 128;
    HEAP32[$62 >> 2] = $95;
    $n_2 = $n_1;
    label = 30;
    break;
   case 27:
    $97 = HEAP32[$84 >> 2] | 0;
    $98 = HEAP32[$86 >> 2] | 0;
    $99 = ($97 | 0) > ($98 | 0);
    if ($99) {
      label = 28;
      break;
    } else {
      $n_2 = $n_1;
      label = 30;
      break;
    }
   case 28:
    $101 = $after3_1 + 40 | 0;
    $102 = HEAP32[$101 >> 2] | 0;
    $103 = ($102 | 0) < ($98 | 0);
    if ($103) {
      label = 29;
      break;
    } else {
      $n_2 = $n_1;
      label = 30;
      break;
    }
   case 29:
    $105 = HEAP32[$62 >> 2] | 0;
    $106 = $105 | 256;
    HEAP32[$62 >> 2] = $106;
    $n_2 = $n_1;
    label = 30;
    break;
   case 30:
    $107 = $n_2 + 1 | 0;
    $n_1 = $107;
    label = 17;
    break;
   case 31:
    return;
  }
}
function _psh_glyph_find_blue_points($blues, $glyph) {
  $blues = $blues | 0;
  $glyph = $glyph | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $glyph_count_052 = 0, $point_050 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $zone_045 = 0, $blue_count_044 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $_sum = 0, $61 = 0, $62 = 0, $zone_147 = 0, $blue_count_146 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $76 = 0, $77 = 0, $79 = 0, $80 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $glyph | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 23;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $glyph + 8 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $blues | 0;
    $7 = $blues + 4 | 0;
    $8 = $blues + 516 | 0;
    $9 = $blues + 2076 | 0;
    $10 = $blues + 2080 | 0;
    $11 = $blues + 2072 | 0;
    $12 = $blues + 2076 | 0;
    $13 = $blues + 2080 | 0;
    $14 = $blues + 2072 | 0;
    $point_050 = $5;
    $glyph_count_052 = $2;
    label = 3;
    break;
   case 3:
    $16 = $point_050 + 20 | 0;
    $17 = HEAP8[$16] | 0;
    if (($17 << 24 >> 24 | 0) == 2 | ($17 << 24 >> 24 | 0) == (-2 | 0)) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $19 = $point_050 + 21 | 0;
    $20 = HEAP8[$19] | 0;
    if (($20 << 24 >> 24 | 0) == 2 | ($20 << 24 >> 24 | 0) == (-2 | 0)) {
      label = 5;
      break;
    } else {
      label = 22;
      break;
    }
   case 5:
    $22 = $point_050 + 16 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $23 & 16;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 6;
      break;
    } else {
      label = 22;
      break;
    }
   case 6:
    $27 = $point_050 + 36 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = HEAP32[$6 >> 2] | 0;
    $30 = ($29 | 0) == 0;
    if ($30) {
      label = 14;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $31 = $point_050 + 44 | 0;
    $blue_count_044 = $29;
    $zone_045 = $7;
    label = 8;
    break;
   case 8:
    $33 = $zone_045 + 12 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $28 - $34 | 0;
    $36 = HEAP32[$12 >> 2] | 0;
    $37 = -$36 | 0;
    $38 = ($35 | 0) < ($37 | 0);
    if ($38) {
      label = 14;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $40 = $zone_045 + 8 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = $41 + $36 | 0;
    $43 = ($28 | 0) > ($42 | 0);
    if ($43) {
      label = 13;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $45 = HEAP8[$13] | 0;
    $46 = $45 << 24 >> 24 == 0;
    if ($46) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $48 = HEAP32[$14 >> 2] | 0;
    $49 = ($35 | 0) > ($48 | 0);
    if ($49) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $51 = $zone_045 + 24 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    HEAP32[$31 >> 2] = $52;
    $53 = HEAP32[$22 >> 2] | 0;
    $54 = $53 | 48;
    HEAP32[$22 >> 2] = $54;
    label = 13;
    break;
   case 13:
    $56 = $blue_count_044 - 1 | 0;
    $57 = $zone_045 + 32 | 0;
    $58 = ($56 | 0) == 0;
    if ($58) {
      label = 14;
      break;
    } else {
      $blue_count_044 = $56;
      $zone_045 = $57;
      label = 8;
      break;
    }
   case 14:
    $59 = HEAP32[$8 >> 2] | 0;
    $60 = ($59 | 0) == 0;
    if ($60) {
      label = 22;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $_sum = $59 - 1 | 0;
    $61 = $blues + 520 + ($_sum << 5) | 0;
    $62 = $point_050 + 44 | 0;
    $blue_count_146 = $59;
    $zone_147 = $61;
    label = 16;
    break;
   case 16:
    $64 = $zone_147 + 8 | 0;
    $65 = HEAP32[$64 >> 2] | 0;
    $66 = $65 - $28 | 0;
    $67 = HEAP32[$9 >> 2] | 0;
    $68 = -$67 | 0;
    $69 = ($66 | 0) < ($68 | 0);
    if ($69) {
      label = 22;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $71 = $zone_147 + 12 | 0;
    $72 = HEAP32[$71 >> 2] | 0;
    $73 = $72 - $67 | 0;
    $74 = ($28 | 0) < ($73 | 0);
    if ($74) {
      label = 21;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $76 = HEAP8[$10] | 0;
    $77 = $76 << 24 >> 24 == 0;
    if ($77) {
      label = 19;
      break;
    } else {
      label = 20;
      break;
    }
   case 19:
    $79 = HEAP32[$11 >> 2] | 0;
    $80 = ($66 | 0) < ($79 | 0);
    if ($80) {
      label = 20;
      break;
    } else {
      label = 21;
      break;
    }
   case 20:
    $82 = $zone_147 + 28 | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    HEAP32[$62 >> 2] = $83;
    $84 = HEAP32[$22 >> 2] | 0;
    $85 = $84 | 48;
    HEAP32[$22 >> 2] = $85;
    label = 21;
    break;
   case 21:
    $87 = $blue_count_146 - 1 | 0;
    $88 = $zone_147 - 32 | 0;
    $89 = ($87 | 0) == 0;
    if ($89) {
      label = 22;
      break;
    } else {
      $blue_count_146 = $87;
      $zone_147 = $88;
      label = 16;
      break;
    }
   case 22:
    $90 = $glyph_count_052 - 1 | 0;
    $91 = $point_050 + 48 | 0;
    $92 = ($90 | 0) == 0;
    if ($92) {
      label = 23;
      break;
    } else {
      $point_050 = $91;
      $glyph_count_052 = $90;
      label = 3;
      break;
    }
   case 23:
    return;
  }
}
function _psh_globals_set_scale($globals, $x_scale, $y_scale, $x_delta, $y_delta) {
  $globals = $globals | 0;
  $x_scale = $x_scale | 0;
  $y_scale = $y_scale | 0;
  $x_delta = $x_delta | 0;
  $y_delta = $y_delta | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $globals + 200 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == ($x_scale | 0);
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $5 = $globals + 204 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == ($x_delta | 0);
    if ($7) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    HEAP32[$1 >> 2] = $x_scale;
    $9 = $globals + 204 | 0;
    HEAP32[$9 >> 2] = $x_delta;
    _psh_globals_scale_widths($globals, 0);
    label = 4;
    break;
   case 4:
    $11 = $globals + 404 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($12 | 0) == ($y_scale | 0);
    if ($13) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $15 = $globals + 408 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($16 | 0) == ($y_delta | 0);
    if ($17) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    HEAP32[$11 >> 2] = $y_scale;
    $19 = $globals + 408 | 0;
    HEAP32[$19 >> 2] = $y_delta;
    _psh_globals_scale_widths($globals, 1);
    $20 = $globals + 412 | 0;
    _psh_blues_scale_zones($20, $y_scale, $y_delta);
    label = 7;
    break;
   case 7:
    return 0;
  }
  return 0;
}
function _psh_hint_table_align_hints($table, $globals, $dimension, $glyph) {
  $table = $table | 0;
  $globals = $globals | 0;
  $dimension = $dimension | 0;
  $glyph = $glyph | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $count_08 = 0, $hint_07 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $table + 8 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $hint_07 = $5;
    $count_08 = $2;
    label = 3;
    break;
   case 3:
    _psh_hint_align($hint_07, $globals, $dimension, $glyph);
    $7 = $count_08 - 1 | 0;
    $8 = $hint_07 + 28 | 0;
    $9 = ($7 | 0) == 0;
    if ($9) {
      label = 4;
      break;
    } else {
      $hint_07 = $8;
      $count_08 = $7;
      label = 3;
      break;
    }
   case 4:
    return;
  }
}
function _psh_glyph_find_strong_points($glyph, $dimension) {
  $glyph = $glyph | 0;
  $dimension = $dimension | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $_ = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $_40 = 0, $24 = 0, $_pn = 0, $num_masks_046 = 0, $first_045 = 0, $mask_048 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $_41 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $point4_043 = 0, $count3_042 = 0, $52 = 0, $53 = 0, $54 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $glyph + 28 + ($dimension * 40 & -1) | 0;
    $2 = $glyph + 28 + ($dimension * 40 & -1) + 32 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 + 8 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $3 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = ($dimension | 0) == 0;
    $9 = $8 ? 1 : 2;
    $10 = $glyph + 24 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 + 4 + ($dimension * 204 & -1) + 196 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = _FT_DivFix(32, $13) | 0;
    $15 = ($14 | 0) > 30;
    $_ = $15 ? 30 : $14;
    $16 = $7 >>> 0 > 1;
    if ($16) {
      label = 2;
      break;
    } else {
      label = 7;
      break;
    }
   case 2:
    $18 = $glyph | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 9;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $21 = $5 + 12 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22 >>> 0 > $19 >>> 0;
    $_40 = $23 ? $19 : $22;
    $24 = $glyph + 8 | 0;
    $first_045 = $_40;
    $num_masks_046 = $7;
    $_pn = $5;
    label = 4;
    break;
   case 4:
    $mask_048 = $_pn + 16 | 0;
    $26 = $_pn + 28 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = HEAP32[$18 >> 2] | 0;
    $29 = $27 >>> 0 > $28 >>> 0;
    $_41 = $29 ? $28 : $27;
    $30 = $_41 - $first_045 | 0;
    $31 = ($30 | 0) > 0;
    if ($31) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $33 = HEAP32[$24 >> 2] | 0;
    $34 = $33 + ($first_045 * 48 & -1) | 0;
    _psh_hint_table_activate_mask($1, $mask_048);
    _psh_hint_table_find_strong_points($1, $34, $30, $_, $9);
    label = 6;
    break;
   case 6:
    $36 = $num_masks_046 - 1 | 0;
    $37 = $36 >>> 0 > 1;
    if ($37) {
      $first_045 = $_41;
      $num_masks_046 = $36;
      $_pn = $mask_048;
      label = 4;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $38 = ($7 | 0) == 1;
    if ($38) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $39 = $glyph | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $glyph + 8 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = HEAP32[$2 >> 2] | 0;
    $44 = $43 + 8 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    _psh_hint_table_activate_mask($1, $45);
    _psh_hint_table_find_strong_points($1, $42, $40, $_, $9);
    label = 9;
    break;
   case 9:
    $46 = $glyph | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = ($47 | 0) == 0;
    if ($48) {
      label = 15;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $49 = $glyph + 8 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $count3_042 = $47;
    $point4_043 = $50;
    label = 11;
    break;
   case 11:
    $52 = $point4_043 + 32 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = ($53 | 0) == 0;
    if ($54) {
      label = 14;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $56 = $point4_043 + 16 | 0;
    $57 = HEAP32[$56 >> 2] | 0;
    $58 = $57 & 16;
    $59 = ($58 | 0) == 0;
    if ($59) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    $61 = $57 | 16;
    HEAP32[$56 >> 2] = $61;
    label = 14;
    break;
   case 14:
    $63 = $count3_042 - 1 | 0;
    $64 = $point4_043 + 48 | 0;
    $65 = ($63 | 0) == 0;
    if ($65) {
      label = 15;
      break;
    } else {
      $count3_042 = $63;
      $point4_043 = $64;
      label = 11;
      break;
    }
   case 15:
    return;
  }
}
function _psh_glyph_interpolate_strong_points($glyph, $dimension) {
  $glyph = $glyph | 0;
  $dimension = $dimension | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count_032 = 0, $point_031 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $glyph + 24 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 4 + ($dimension * 204 & -1) + 196 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $glyph | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 15;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $glyph + 8 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $point_031 = $9;
    $count_032 = $6;
    label = 3;
    break;
   case 3:
    $11 = $point_031 + 32 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 14;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $15 = $point_031 + 16 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $16 & 512;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $20 = $12 + 8 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $point_031 + 44 | 0;
    HEAP32[$22 >> 2] = $21;
    label = 13;
    break;
   case 6:
    $24 = $16 & 1024;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $27 = $12 + 8 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $12 + 12 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $30 + $28 | 0;
    $32 = $point_031 + 44 | 0;
    HEAP32[$32 >> 2] = $31;
    label = 13;
    break;
   case 8:
    $34 = $point_031 + 36 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $12 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $35 - $37 | 0;
    $39 = ($38 | 0) < 1;
    if ($39) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $41 = $12 + 8 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = _FT_MulFix($38, $4) | 0;
    $44 = $43 + $42 | 0;
    $45 = $point_031 + 44 | 0;
    HEAP32[$45 >> 2] = $44;
    label = 13;
    break;
   case 10:
    $47 = $12 + 4 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = ($38 | 0) < ($48 | 0);
    $50 = $12 + 8 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = $12 + 12 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    if ($49) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $55 = $53 + $51 | 0;
    $56 = $38 - $48 | 0;
    $57 = _FT_MulFix($56, $4) | 0;
    $58 = $55 + $57 | 0;
    $59 = $point_031 + 44 | 0;
    HEAP32[$59 >> 2] = $58;
    label = 13;
    break;
   case 12:
    $61 = _FT_MulDiv($38, $53, $48) | 0;
    $62 = $61 + $51 | 0;
    $63 = $point_031 + 44 | 0;
    HEAP32[$63 >> 2] = $62;
    label = 13;
    break;
   case 13:
    $65 = HEAP32[$15 >> 2] | 0;
    $66 = $65 | 32;
    HEAP32[$15 >> 2] = $66;
    label = 14;
    break;
   case 14:
    $68 = $count_032 - 1 | 0;
    $69 = $point_031 + 48 | 0;
    $70 = ($68 | 0) == 0;
    if ($70) {
      label = 15;
      break;
    } else {
      $point_031 = $69;
      $count_032 = $68;
      label = 3;
      break;
    }
   case 15:
    return;
  }
}
function _psh_glyph_save_points($glyph, $dimension) {
  $glyph = $glyph | 0;
  $dimension = $dimension | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $n_012 = 0, $point_011 = 0, $15 = 0, $16 = 0, $18 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $glyph + 20 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + 8 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $glyph | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 9;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = $glyph + 8 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($dimension | 0) == 0;
    $13 = $12 ? 32 : 64;
    $point_011 = $11;
    $n_012 = 0;
    label = 3;
    break;
   case 3:
    $15 = $point_011 + 44 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    if ($12) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $18 = $4 + ($n_012 << 3) | 0;
    HEAP32[$18 >> 2] = $16;
    label = 6;
    break;
   case 5:
    $20 = $4 + ($n_012 << 3) + 4 | 0;
    HEAP32[$20 >> 2] = $16;
    label = 6;
    break;
   case 6:
    $22 = $point_011 + 16 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $23 & 16;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $27 = $6 + $n_012 | 0;
    $28 = HEAP8[$27] | 0;
    $29 = $28 | $13;
    HEAP8[$27] = $29;
    label = 8;
    break;
   case 8:
    $31 = $point_011 + 48 | 0;
    $32 = $n_012 + 1 | 0;
    $33 = HEAP32[$7 >> 2] | 0;
    $34 = $32 >>> 0 < $33 >>> 0;
    if ($34) {
      $point_011 = $31;
      $n_012 = $32;
      label = 3;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    return;
  }
}
function _psh_globals_funcs_init($funcs) {
  $funcs = $funcs | 0;
  HEAP32[$funcs >> 2] = 806;
  HEAP32[$funcs + 4 >> 2] = 166;
  HEAP32[$funcs + 8 >> 2] = 66;
  return;
}
function _psh_glyph_interpolate_normal_points($glyph, $dimension) {
  $glyph = $glyph | 0;
  $dimension = $dimension | 0;
  var $strongs_0 = 0, $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $point_0100 = 0, $num_strongs_099 = 0, $13 = 0, $14 = 0, $15 = 0, $_lobit = 0, $num_strongs_0_ = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $point_195 = 0, $num_strongs_294 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $insert_089 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $insert_0_lcssa = 0, $48 = 0, $num_strongs_3 = 0, $50 = 0, $51 = 0, $point_286 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $73 = 0, $74 = 0, $76 = 0, $77 = 0, $78 = 0, $nn_0 = 0, $80 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $90 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $nn_1 = 0, $109 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $119 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $143 = 0, $144 = 0, $145 = 0, $147 = 0, $148 = 0, $149 = 0, $151 = 0, $152 = 0, $153 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $166 = 0, $167 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $174 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 68 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $strongs_0 = __stackBase__ | 0;
    $error = __stackBase__ + 64 | 0;
    $1 = $glyph + 24 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 4 + ($dimension * 204 & -1) + 196 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $glyph + 16 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $glyph + 8 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $glyph | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $8 + ($10 * 48 & -1) | 0;
    $12 = ($10 | 0) > 0;
    if ($12) {
      $num_strongs_099 = 0;
      $point_0100 = $8;
      label = 2;
      break;
    } else {
      label = 42;
      break;
    }
   case 2:
    $13 = $point_0100 + 16 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 >>> 4;
    $_lobit = $15 & 1;
    $num_strongs_0_ = $_lobit + $num_strongs_099 | 0;
    $16 = $point_0100 + 48 | 0;
    $17 = $16 >>> 0 < $11 >>> 0;
    if ($17) {
      $num_strongs_099 = $num_strongs_0_;
      $point_0100 = $16;
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $18 = ($num_strongs_0_ | 0) == 0;
    if ($18) {
      label = 42;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $20 = $num_strongs_0_ >>> 0 < 17;
    if ($20) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $22 = $strongs_0 | 0;
    $strongs_0 = $22;
    label = 7;
    break;
   case 6:
    $24 = _ft_mem_realloc($6, 4, 0, $num_strongs_0_, 0, $error) | 0;
    $25 = $24;
    $26 = HEAP32[$error >> 2] | 0;
    $27 = ($26 | 0) == 0;
    if ($27) {
      $strongs_0 = $25;
      label = 7;
      break;
    } else {
      label = 42;
      break;
    }
   case 7:
    $29 = ($10 | 0) > 0;
    if ($29) {
      $num_strongs_294 = 0;
      $point_195 = $8;
      label = 9;
      break;
    } else {
      label = 40;
      break;
    }
   case 8:
    $30 = ($10 | 0) > 0;
    if ($30) {
      $point_286 = $8;
      label = 16;
      break;
    } else {
      label = 40;
      break;
    }
   case 9:
    $31 = $point_195 + 16 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $32 & 16;
    $34 = ($33 | 0) == 0;
    if ($34) {
      $num_strongs_3 = $num_strongs_294;
      label = 15;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $36 = $strongs_0 + ($num_strongs_294 << 2) | 0;
    $37 = ($num_strongs_294 | 0) > 0;
    if ($37) {
      label = 11;
      break;
    } else {
      $insert_0_lcssa = $36;
      label = 14;
      break;
    }
   case 11:
    $38 = $point_195 + 36 | 0;
    $insert_089 = $36;
    label = 12;
    break;
   case 12:
    $40 = $insert_089 - 4 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = $41 + 36 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = HEAP32[$38 >> 2] | 0;
    $45 = ($43 | 0) > ($44 | 0);
    if ($45) {
      label = 13;
      break;
    } else {
      $insert_0_lcssa = $insert_089;
      label = 14;
      break;
    }
   case 13:
    HEAP32[$insert_089 >> 2] = $41;
    $47 = $40 >>> 0 > $strongs_0 >>> 0;
    if ($47) {
      $insert_089 = $40;
      label = 12;
      break;
    } else {
      $insert_0_lcssa = $40;
      label = 14;
      break;
    }
   case 14:
    HEAP32[$insert_0_lcssa >> 2] = $point_195;
    $48 = $num_strongs_294 + 1 | 0;
    $num_strongs_3 = $48;
    label = 15;
    break;
   case 15:
    $50 = $point_195 + 48 | 0;
    $51 = $50 >>> 0 < $11 >>> 0;
    if ($51) {
      $num_strongs_294 = $num_strongs_3;
      $point_195 = $50;
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 16:
    $52 = $point_286 + 16 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $53 & 16;
    $55 = ($54 | 0) == 0;
    if ($55) {
      label = 17;
      break;
    } else {
      label = 39;
      break;
    }
   case 17:
    $57 = $point_286 + 12 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = $58 & 2;
    $60 = ($59 | 0) == 0;
    if ($60) {
      label = 23;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $62 = $point_286 + 20 | 0;
    $63 = HEAP8[$62] | 0;
    $64 = $63 << 24 >> 24 == 4;
    if ($64) {
      label = 39;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $66 = $point_286 + 21 | 0;
    $67 = HEAP8[$66] | 0;
    $68 = $63 << 24 >> 24 == $67 << 24 >> 24;
    if ($68) {
      label = 20;
      break;
    } else {
      label = 39;
      break;
    }
   case 20:
    $70 = $53 & 64;
    $71 = ($70 | 0) == 0;
    if ($71) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    $73 = $58 & 4;
    $74 = ($73 | 0) == 0;
    if ($74) {
      label = 39;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $76 = HEAP32[$57 >> 2] | 0;
    $77 = $76 & -3;
    HEAP32[$57 >> 2] = $77;
    label = 23;
    break;
   case 23:
    $78 = $point_286 + 36 | 0;
    $nn_0 = 0;
    label = 24;
    break;
   case 24:
    $80 = $nn_0 >>> 0 < $num_strongs_3 >>> 0;
    if ($80) {
      label = 25;
      break;
    } else {
      label = 26;
      break;
    }
   case 25:
    $82 = $strongs_0 + ($nn_0 << 2) | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = $83 + 36 | 0;
    $85 = HEAP32[$84 >> 2] | 0;
    $86 = HEAP32[$78 >> 2] | 0;
    $87 = ($85 | 0) > ($86 | 0);
    $88 = $nn_0 + 1 | 0;
    if ($87) {
      label = 26;
      break;
    } else {
      $nn_0 = $88;
      label = 24;
      break;
    }
   case 26:
    $90 = ($nn_0 | 0) == 0;
    if ($90) {
      label = 27;
      break;
    } else {
      label = 28;
      break;
    }
   case 27:
    $92 = HEAP32[$strongs_0 >> 2] | 0;
    $93 = $92 + 44 | 0;
    $94 = HEAP32[$93 >> 2] | 0;
    $95 = $point_286 + 36 | 0;
    $96 = HEAP32[$95 >> 2] | 0;
    $97 = $92 + 36 | 0;
    $98 = HEAP32[$97 >> 2] | 0;
    $99 = $96 - $98 | 0;
    $100 = _FT_MulFix($99, $4) | 0;
    $101 = $100 + $94 | 0;
    $102 = $point_286 + 44 | 0;
    HEAP32[$102 >> 2] = $101;
    label = 38;
    break;
   case 28:
    $104 = $nn_0 - 1 | 0;
    $105 = $strongs_0 + ($104 << 2) | 0;
    $106 = HEAP32[$105 >> 2] | 0;
    $107 = $point_286 + 36 | 0;
    $nn_1 = $num_strongs_3;
    label = 29;
    break;
   case 29:
    $109 = ($nn_1 | 0) == 0;
    if ($109) {
      label = 31;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    $111 = $nn_1 - 1 | 0;
    $112 = $strongs_0 + ($111 << 2) | 0;
    $113 = HEAP32[$112 >> 2] | 0;
    $114 = $113 + 36 | 0;
    $115 = HEAP32[$114 >> 2] | 0;
    $116 = HEAP32[$107 >> 2] | 0;
    $117 = ($115 | 0) < ($116 | 0);
    if ($117) {
      label = 31;
      break;
    } else {
      $nn_1 = $111;
      label = 29;
      break;
    }
   case 31:
    $119 = ($nn_1 | 0) == ($num_strongs_3 | 0);
    if ($119) {
      label = 32;
      break;
    } else {
      label = 33;
      break;
    }
   case 32:
    $121 = $nn_1 - 1 | 0;
    $122 = $strongs_0 + ($121 << 2) | 0;
    $123 = HEAP32[$122 >> 2] | 0;
    $124 = $123 + 44 | 0;
    $125 = HEAP32[$124 >> 2] | 0;
    $126 = $point_286 + 36 | 0;
    $127 = HEAP32[$126 >> 2] | 0;
    $128 = $123 + 36 | 0;
    $129 = HEAP32[$128 >> 2] | 0;
    $130 = $127 - $129 | 0;
    $131 = _FT_MulFix($130, $4) | 0;
    $132 = $131 + $125 | 0;
    $133 = $point_286 + 44 | 0;
    HEAP32[$133 >> 2] = $132;
    label = 38;
    break;
   case 33:
    $135 = $strongs_0 + ($nn_1 << 2) | 0;
    $136 = HEAP32[$135 >> 2] | 0;
    $137 = $point_286 + 36 | 0;
    $138 = HEAP32[$137 >> 2] | 0;
    $139 = $106 + 36 | 0;
    $140 = HEAP32[$139 >> 2] | 0;
    $141 = ($138 | 0) == ($140 | 0);
    if ($141) {
      label = 34;
      break;
    } else {
      label = 35;
      break;
    }
   case 34:
    $143 = $106 + 44 | 0;
    $144 = HEAP32[$143 >> 2] | 0;
    $145 = $point_286 + 44 | 0;
    HEAP32[$145 >> 2] = $144;
    label = 38;
    break;
   case 35:
    $147 = $136 + 36 | 0;
    $148 = HEAP32[$147 >> 2] | 0;
    $149 = ($138 | 0) == ($148 | 0);
    if ($149) {
      label = 36;
      break;
    } else {
      label = 37;
      break;
    }
   case 36:
    $151 = $136 + 44 | 0;
    $152 = HEAP32[$151 >> 2] | 0;
    $153 = $point_286 + 44 | 0;
    HEAP32[$153 >> 2] = $152;
    label = 38;
    break;
   case 37:
    $155 = $106 + 44 | 0;
    $156 = HEAP32[$155 >> 2] | 0;
    $157 = $138 - $140 | 0;
    $158 = $136 + 44 | 0;
    $159 = HEAP32[$158 >> 2] | 0;
    $160 = $159 - $156 | 0;
    $161 = $148 - $140 | 0;
    $162 = _FT_MulDiv($157, $160, $161) | 0;
    $163 = $162 + $156 | 0;
    $164 = $point_286 + 44 | 0;
    HEAP32[$164 >> 2] = $163;
    label = 38;
    break;
   case 38:
    $166 = HEAP32[$52 >> 2] | 0;
    $167 = $166 | 32;
    HEAP32[$52 >> 2] = $167;
    label = 39;
    break;
   case 39:
    $169 = $point_286 + 48 | 0;
    $170 = $169 >>> 0 < $11 >>> 0;
    if ($170) {
      $point_286 = $169;
      label = 16;
      break;
    } else {
      label = 40;
      break;
    }
   case 40:
    $171 = $strongs_0 | 0;
    $172 = ($strongs_0 | 0) == ($171 | 0);
    if ($172) {
      label = 42;
      break;
    } else {
      label = 41;
      break;
    }
   case 41:
    $174 = $strongs_0;
    _ft_mem_free($6, $174);
    label = 42;
    break;
   case 42:
    STACKTOP = __stackBase__;
    return;
  }
}
function _psh_glyph_interpolate_other_points($glyph, $dimension) {
  $glyph = $glyph | 0;
  $dimension = $dimension | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $delta_081 = 0, $contour_080 = 0, $num_contours_079 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $fit_count_070 = 0, $point_069 = 0, $first_068 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $point_0_first_0 = 0, $25 = 0, $first_2 = 0, $fit_count_1 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $delta_1 = 0, $42 = 0, $point_176 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $first_473 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $next_0 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $org_a_0 = 0, $org_ab_0 = 0, $cur_a_0 = 0, $cur_ab_0 = 0, $86 = 0, $88 = 0, $scale_ab_0 = 0, $90 = 0, $91 = 0, $point_2 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $98 = 0, $99 = 0, $101 = 0, $103 = 0, $104 = 0, $105 = 0, $107 = 0, $108 = 0, $cur_c_0 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $115 = 0, $first_4_be = 0, $116 = 0, $117 = 0, $118 = 0, $delta_2 = 0, $119 = 0, $120 = 0, $121 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $glyph + 24 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 4 + ($dimension * 204 & -1) + 196 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $glyph + 4 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 32;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $glyph + 12 | 0;
    $9 = $2 + 4 + ($dimension * 204 & -1) + 200 | 0;
    $10 = HEAP32[$8 >> 2] | 0;
    $11 = HEAP32[$9 >> 2] | 0;
    $num_contours_079 = $6;
    $contour_080 = $10;
    $delta_081 = $11;
    label = 3;
    break;
   case 3:
    $13 = $contour_080 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $contour_080 + 4 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $14 + ($16 * 48 & -1) | 0;
    $18 = ($16 | 0) > 0;
    if ($18) {
      $first_068 = 0;
      $point_069 = $14;
      $fit_count_070 = 0;
      label = 4;
      break;
    } else {
      $delta_2 = $delta_081;
      label = 31;
      break;
    }
   case 4:
    $19 = $point_069 + 16 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $20 & 32;
    $22 = ($21 | 0) == 0;
    if ($22) {
      $fit_count_1 = $fit_count_070;
      $first_2 = $first_068;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $24 = ($first_068 | 0) == 0;
    $point_0_first_0 = $24 ? $point_069 : $first_068;
    $25 = $fit_count_070 + 1 | 0;
    $fit_count_1 = $25;
    $first_2 = $point_0_first_0;
    label = 6;
    break;
   case 6:
    $27 = $point_069 + 48 | 0;
    $28 = $27 >>> 0 < $17 >>> 0;
    if ($28) {
      $first_068 = $first_2;
      $point_069 = $27;
      $fit_count_070 = $fit_count_1;
      label = 4;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $29 = $fit_count_1 >>> 0 < 2;
    if ($29) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $30 = $first_2 + 4 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = ($31 | 0) == ($first_2 | 0);
    if ($32) {
      $delta_2 = $delta_081;
      label = 31;
      break;
    } else {
      $first_473 = $first_2;
      $54 = $30;
      $53 = $31;
      label = 15;
      break;
    }
   case 9:
    $34 = ($fit_count_1 | 0) == 1;
    if ($34) {
      label = 10;
      break;
    } else {
      $delta_1 = $delta_081;
      label = 11;
      break;
    }
   case 10:
    $36 = $first_2 + 44 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $first_2 + 36 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = _FT_MulFix($39, $4) | 0;
    $41 = $37 - $40 | 0;
    $delta_1 = $41;
    label = 11;
    break;
   case 11:
    $42 = ($16 | 0) > 0;
    if ($42) {
      $point_176 = $14;
      label = 12;
      break;
    } else {
      $delta_2 = $delta_1;
      label = 31;
      break;
    }
   case 12:
    $43 = ($point_176 | 0) == ($first_2 | 0);
    if ($43) {
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $45 = $point_176 + 36 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = _FT_MulFix($46, $4) | 0;
    $48 = $47 + $delta_1 | 0;
    $49 = $point_176 + 44 | 0;
    HEAP32[$49 >> 2] = $48;
    label = 14;
    break;
   case 14:
    $51 = $point_176 + 48 | 0;
    $52 = $51 >>> 0 < $17 >>> 0;
    if ($52) {
      $point_176 = $51;
      label = 12;
      break;
    } else {
      $delta_2 = $delta_1;
      label = 31;
      break;
    }
   case 15:
    $55 = $53 + 16 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = $56 & 32;
    $58 = ($57 | 0) == 0;
    if ($58) {
      $next_0 = $53;
      label = 16;
      break;
    } else {
      $first_4_be = $53;
      label = 30;
      break;
    }
   case 16:
    $59 = $next_0 + 4 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = $60 + 16 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = $62 & 32;
    $64 = ($63 | 0) == 0;
    if ($64) {
      $next_0 = $60;
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $66 = $first_473 + 36 | 0;
    $67 = HEAP32[$66 >> 2] | 0;
    $68 = $60 + 36 | 0;
    $69 = HEAP32[$68 >> 2] | 0;
    $70 = ($67 | 0) > ($69 | 0);
    if ($70) {
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $72 = $first_473 + 44 | 0;
    $73 = HEAP32[$72 >> 2] | 0;
    $74 = $69 - $67 | 0;
    $75 = $60 + 44 | 0;
    $76 = HEAP32[$75 >> 2] | 0;
    $77 = $76 - $73 | 0;
    $cur_ab_0 = $77;
    $cur_a_0 = $73;
    $org_ab_0 = $74;
    $org_a_0 = $67;
    label = 20;
    break;
   case 19:
    $79 = $60 + 44 | 0;
    $80 = HEAP32[$79 >> 2] | 0;
    $81 = $67 - $69 | 0;
    $82 = $first_473 + 44 | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = $83 - $80 | 0;
    $cur_ab_0 = $84;
    $cur_a_0 = $80;
    $org_ab_0 = $81;
    $org_a_0 = $69;
    label = 20;
    break;
   case 20:
    $86 = ($org_ab_0 | 0) > 0;
    if ($86) {
      label = 21;
      break;
    } else {
      $scale_ab_0 = 65536;
      label = 22;
      break;
    }
   case 21:
    $88 = _FT_DivFix($cur_ab_0, $org_ab_0) | 0;
    $scale_ab_0 = $88;
    label = 22;
    break;
   case 22:
    $90 = HEAP32[$54 >> 2] | 0;
    $91 = $cur_ab_0 + $cur_a_0 | 0;
    $point_2 = $90;
    label = 23;
    break;
   case 23:
    $93 = $point_2 + 36 | 0;
    $94 = HEAP32[$93 >> 2] | 0;
    $95 = $94 - $org_a_0 | 0;
    $96 = ($95 | 0) < 1;
    if ($96) {
      label = 24;
      break;
    } else {
      label = 25;
      break;
    }
   case 24:
    $98 = _FT_MulFix($95, $4) | 0;
    $99 = $98 + $cur_a_0 | 0;
    $cur_c_0 = $99;
    label = 28;
    break;
   case 25:
    $101 = ($95 | 0) < ($org_ab_0 | 0);
    if ($101) {
      label = 27;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $103 = $95 - $org_ab_0 | 0;
    $104 = _FT_MulFix($103, $4) | 0;
    $105 = $91 + $104 | 0;
    $cur_c_0 = $105;
    label = 28;
    break;
   case 27:
    $107 = _FT_MulFix($95, $scale_ab_0) | 0;
    $108 = $107 + $cur_a_0 | 0;
    $cur_c_0 = $108;
    label = 28;
    break;
   case 28:
    $110 = $point_2 + 44 | 0;
    HEAP32[$110 >> 2] = $cur_c_0;
    $111 = $point_2 + 4 | 0;
    $112 = HEAP32[$111 >> 2] | 0;
    $113 = ($112 | 0) == ($60 | 0);
    if ($113) {
      label = 29;
      break;
    } else {
      $point_2 = $112;
      label = 23;
      break;
    }
   case 29:
    $115 = ($60 | 0) == ($first_2 | 0);
    if ($115) {
      $delta_2 = $delta_081;
      label = 31;
      break;
    } else {
      $first_4_be = $60;
      label = 30;
      break;
    }
   case 30:
    $116 = $first_4_be + 4 | 0;
    $117 = HEAP32[$116 >> 2] | 0;
    $118 = ($117 | 0) == ($first_2 | 0);
    if ($118) {
      $delta_2 = $delta_081;
      label = 31;
      break;
    } else {
      $first_473 = $first_4_be;
      $54 = $116;
      $53 = $117;
      label = 15;
      break;
    }
   case 31:
    $119 = $num_contours_079 - 1 | 0;
    $120 = $contour_080 + 8 | 0;
    $121 = ($119 | 0) == 0;
    if ($121) {
      label = 32;
      break;
    } else {
      $num_contours_079 = $119;
      $contour_080 = $120;
      $delta_081 = $delta_2;
      label = 3;
      break;
    }
   case 32:
    return;
  }
}
function _psh_glyph_done($glyph) {
  $glyph = $glyph | 0;
  var $1 = 0, $2 = 0, $5 = 0, $8 = 0;
  $1 = $glyph + 16 | 0;
  $2 = HEAP32[$1 >> 2] | 0;
  _psh_hint_table_done($glyph + 68 | 0, $2);
  _psh_hint_table_done($glyph + 28 | 0, $2);
  $5 = $glyph + 8 | 0;
  _ft_mem_free($2, HEAP32[$5 >> 2] | 0);
  HEAP32[$5 >> 2] = 0;
  $8 = $glyph + 12 | 0;
  _ft_mem_free($2, HEAP32[$8 >> 2] | 0);
  HEAP32[$8 >> 2] = 0;
  HEAP32[$glyph >> 2] = 0;
  HEAP32[$glyph + 4 >> 2] = 0;
  HEAP32[$1 >> 2] = 0;
  return;
}
function _ps_hinter_init($module) {
  $module = $module | 0;
  var $3 = 0, $5 = 0, $8 = 0;
  $3 = $module + 20 | 0;
  _ps_hints_init($3, HEAP32[$module + 8 >> 2] | 0);
  _psh_globals_funcs_init($module + 108 | 0);
  $5 = $module + 120 | 0;
  _t1_hints_funcs_init($5);
  HEAP32[$5 >> 2] = $3;
  $8 = $module + 148 | 0;
  _t2_hints_funcs_init($8);
  HEAP32[$8 >> 2] = $3;
  return 0;
}
function _ps_hinter_done($module) {
  $module = $module | 0;
  HEAP32[$module + 120 >> 2] = 0;
  HEAP32[$module + 148 >> 2] = 0;
  _ps_hints_done($module + 20 | 0);
  return;
}
function _ps_hints_done($hints) {
  $hints = $hints | 0;
  var $1 = 0, $2 = 0;
  $1 = $hints | 0;
  $2 = HEAP32[$1 >> 2] | 0;
  _ps_dimension_done($hints + 16 | 0, $2);
  _ps_dimension_done($hints + 52 | 0, $2);
  HEAP32[$hints + 4 >> 2] = 0;
  HEAP32[$1 >> 2] = 0;
  return;
}
function _ps_dimension_done($dimension, $memory) {
  $dimension = $dimension | 0;
  $memory = $memory | 0;
  _ps_mask_table_done($dimension + 24 | 0, $memory);
  _ps_mask_table_done($dimension + 12 | 0, $memory);
  _ps_hint_table_done($dimension | 0, $memory);
  return;
}
function _ps_mask_table_done($table, $memory) {
  $table = $table | 0;
  $memory = $memory | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $mask_011 = 0, $count_010 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $table + 8 | 0;
    $4 = ($2 | 0) == 0;
    if ($4) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = HEAP32[$3 >> 2] | 0;
    $count_010 = $2;
    $mask_011 = $5;
    label = 3;
    break;
   case 3:
    _ps_mask_done($mask_011, $memory);
    $7 = $count_010 - 1 | 0;
    $8 = $mask_011 + 16 | 0;
    $9 = ($7 | 0) == 0;
    if ($9) {
      label = 4;
      break;
    } else {
      $count_010 = $7;
      $mask_011 = $8;
      label = 3;
      break;
    }
   case 4:
    $10 = HEAP32[$3 >> 2] | 0;
    $11 = $10;
    _ft_mem_free($memory, $11);
    HEAP32[$3 >> 2] = 0;
    $12 = $table | 0;
    HEAP32[$12 >> 2] = 0;
    HEAP32[$1 >> 2] = 0;
    return;
  }
}
function _ps_hint_table_done($table, $memory) {
  $table = $table | 0;
  $memory = $memory | 0;
  var $1 = 0;
  $1 = $table + 8 | 0;
  _ft_mem_free($memory, HEAP32[$1 >> 2] | 0);
  HEAP32[$1 >> 2] = 0;
  HEAP32[$table >> 2] = 0;
  HEAP32[$table + 4 >> 2] = 0;
  return;
}
function _ps_mask_done($mask, $memory) {
  $mask = $mask | 0;
  $memory = $memory | 0;
  _ft_mem_free($memory, HEAP32[$mask + 8 >> 2] | 0);
  _memset($mask | 0, 0, 16);
  return;
}
function _ps_hints_init($hints, $memory) {
  $hints = $hints | 0;
  $memory = $memory | 0;
  _memset($hints | 0, 0, 88);
  HEAP32[$hints >> 2] = $memory;
  return;
}
function _t1_hints_funcs_init($funcs) {
  $funcs = $funcs | 0;
  _memset($funcs | 0, 0, 24);
  HEAP32[$funcs + 4 >> 2] = 878;
  HEAP32[$funcs + 8 >> 2] = 364;
  HEAP32[$funcs + 12 >> 2] = 156;
  HEAP32[$funcs + 16 >> 2] = 892;
  HEAP32[$funcs + 20 >> 2] = 2;
  HEAP32[$funcs + 24 >> 2] = 284;
  return;
}
function _t2_hints_funcs_init($funcs) {
  $funcs = $funcs | 0;
  _memset($funcs | 0, 0, 24);
  HEAP32[$funcs + 4 >> 2] = 286;
  HEAP32[$funcs + 8 >> 2] = 364;
  HEAP32[$funcs + 12 >> 2] = 860;
  HEAP32[$funcs + 16 >> 2] = 54;
  HEAP32[$funcs + 20 >> 2] = 934;
  HEAP32[$funcs + 24 >> 2] = 284;
  return;
}
function _t2_hints_open($hints) {
  $hints = $hints | 0;
  _ps_hints_open($hints, 2);
  return;
}
function _ps_hints_close($hints, $end_point) {
  $hints = $hints | 0;
  $end_point = $end_point | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $error_0 = $2;
      label = 4;
      break;
    }
   case 2:
    $5 = $hints | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $hints + 16 | 0;
    $8 = _ps_dimension_end($7, $end_point, $6) | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 3;
      break;
    } else {
      $error_0 = $8;
      label = 4;
      break;
    }
   case 3:
    $11 = $hints + 52 | 0;
    $12 = _ps_dimension_end($11, $end_point, $6) | 0;
    $error_0 = $12;
    label = 4;
    break;
   case 4:
    return $error_0 | 0;
  }
  return 0;
}
function _t2_hints_stems($hints, $dimension, $count, $coords) {
  $hints = $hints | 0;
  $dimension = $dimension | 0;
  $count = $count | 0;
  $coords = $coords | 0;
  var $stems = 0, $1 = 0, $2 = 0, $3 = 0, $total_026 = 0, $y_025 = 0, $5 = 0, $_total_0 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_op = 0, $_op_op = 0, $10 = 0, $n_021 = 0, $y_120 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $exitcond = 0, $19 = 0, $n_123 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $y_1_lcssa30 = 0, $28 = 0, $29 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 128 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $stems = __stackBase__ | 0;
    $1 = ($count | 0) > 0;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 9;
      break;
    }
   case 2:
    $2 = $hints;
    $3 = $stems | 0;
    $y_025 = 0;
    $total_026 = $count;
    label = 3;
    break;
   case 3:
    $5 = ($total_026 | 0) > 16;
    $_total_0 = $5 ? 16 : $total_026;
    $6 = $_total_0 << 1;
    $7 = ($6 | 0) > 0;
    if ($7) {
      label = 4;
      break;
    } else {
      $y_1_lcssa30 = $y_025;
      label = 8;
      break;
    }
   case 4:
    $8 = ($total_026 | 0) < 16;
    $9 = $total_026 << 1;
    $_op = $9 ^ -2;
    $_op_op = -2 - $_op | 0;
    $10 = $8 ? $_op_op : 32;
    $y_120 = $y_025;
    $n_021 = 0;
    label = 5;
    break;
   case 5:
    $12 = $coords + ($n_021 << 2) | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 + $y_120 | 0;
    $15 = _FT_RoundFix($14) | 0;
    $16 = $15 >> 16;
    $17 = $stems + ($n_021 << 2) | 0;
    HEAP32[$17 >> 2] = $16;
    $18 = $n_021 + 1 | 0;
    $exitcond = ($18 | 0) == ($10 | 0);
    if ($exitcond) {
      label = 6;
      break;
    } else {
      $y_120 = $14;
      $n_021 = $18;
      label = 5;
      break;
    }
   case 6:
    $19 = ($6 | 0) > 0;
    if ($19) {
      $n_123 = 0;
      label = 7;
      break;
    } else {
      $y_1_lcssa30 = $14;
      label = 8;
      break;
    }
   case 7:
    $20 = $n_123 | 1;
    $21 = $stems + ($20 << 2) | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $stems + ($n_123 << 2) | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $22 - $24 | 0;
    HEAP32[$21 >> 2] = $25;
    $26 = $n_123 + 2 | 0;
    $27 = ($26 | 0) < ($6 | 0);
    if ($27) {
      $n_123 = $26;
      label = 7;
      break;
    } else {
      $y_1_lcssa30 = $14;
      label = 8;
      break;
    }
   case 8:
    _ps_hints_stem($2, $dimension, $_total_0, $3);
    $28 = $total_026 - $_total_0 | 0;
    $29 = ($28 | 0) > 0;
    if ($29) {
      $y_025 = $y_1_lcssa30;
      $total_026 = $28;
      label = 3;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    STACKTOP = __stackBase__;
    return;
  }
}
function _ps_hints_t2mask($hints, $end_point, $bit_count, $bytes) {
  $hints = $hints | 0;
  $end_point = $end_point | 0;
  $bit_count = $bit_count | 0;
  $bytes = $bytes | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $5 = $hints + 16 | 0;
    $6 = $hints | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $5 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $hints + 52 | 0;
    $11 = $10 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + $9 | 0;
    $14 = ($13 | 0) == ($bit_count | 0);
    if ($14) {
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 3:
    $16 = _ps_dimension_set_mask_bits($5, $bytes, $12, $9, $end_point, $7) | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 4;
      break;
    } else {
      $error_0 = $16;
      label = 5;
      break;
    }
   case 4:
    $19 = _ps_dimension_set_mask_bits($10, $bytes, 0, $12, $end_point, $7) | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 6;
      break;
    } else {
      $error_0 = $19;
      label = 5;
      break;
    }
   case 5:
    HEAP32[$1 >> 2] = $error_0;
    label = 6;
    break;
   case 6:
    return;
  }
}
function _ps_hints_t2counter($hints, $bit_count, $bytes) {
  $hints = $hints | 0;
  $bit_count = $bit_count | 0;
  $bytes = $bytes | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $5 = $hints + 16 | 0;
    $6 = $hints | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $5 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $hints + 52 | 0;
    $11 = $10 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + $9 | 0;
    $14 = ($13 | 0) == ($bit_count | 0);
    if ($14) {
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 3:
    $16 = _ps_dimension_set_mask_bits($5, $bytes, 0, $9, 0, $7) | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 4;
      break;
    } else {
      $error_0 = $16;
      label = 5;
      break;
    }
   case 4:
    $19 = _ps_dimension_set_mask_bits($10, $bytes, $9, $12, 0, $7) | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 6;
      break;
    } else {
      $error_0 = $19;
      label = 5;
      break;
    }
   case 5:
    HEAP32[$1 >> 2] = $error_0;
    label = 6;
    break;
   case 6:
    return;
  }
}
function _ps_dimension_set_mask_bits($dim, $source, $source_pos, $source_bits, $end_point, $memory) {
  $dim = $dim | 0;
  $source = $source | 0;
  $source_pos = $source_pos | 0;
  $source_bits = $source_bits | 0;
  $end_point = $end_point | 0;
  $memory = $memory | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _ps_dimension_reset_mask($dim, $end_point, $memory) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $error_0 = $1;
      label = 3;
      break;
    }
   case 2:
    $4 = $dim + 12 | 0;
    $5 = _ps_mask_table_set_bits($4, $source, $source_pos, $source_bits, $memory) | 0;
    $error_0 = $5;
    label = 3;
    break;
   case 3:
    return $error_0 | 0;
  }
  return 0;
}
function _ps_dimension_reset_mask($dim, $end_point, $memory) {
  $dim = $dim | 0;
  $end_point = $end_point | 0;
  $memory = $memory | 0;
  var $2 = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  _ps_dimension_end_mask($dim, $end_point);
  $2 = _ps_mask_table_alloc($dim + 12 | 0, $memory, __stackBase__ | 0) | 0;
  STACKTOP = __stackBase__;
  return $2 | 0;
}
function _ps_dimension_end_mask($dim, $end_point) {
  $dim = $dim | 0;
  $end_point = $end_point | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $_sum = 0, $7 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $dim + 12 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $dim + 20 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $_sum = $2 - 1 | 0;
    $7 = $6 + ($_sum << 4) + 12 | 0;
    HEAP32[$7 >> 2] = $end_point;
    label = 3;
    break;
   case 3:
    return;
  }
}
function _ps_mask_table_test_intersect($table, $index1, $index2) {
  $table = $table | 0;
  $index1 = $index1 | 0;
  $index2 = $index2 | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $count_021 = 0, $p1_020 = 0, $p2_019 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $count_0_lcssa = 0, $p1_0_lcssa = 0, $p2_0_lcssa = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + ($index1 << 4) + 8 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + ($index2 << 4) + 8 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $2 + ($index1 << 4) | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $2 + ($index2 << 4) | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $8 >>> 0 <= $10 >>> 0;
    $12 = $11 ? $8 : $10;
    $13 = $12 >>> 0 > 7;
    if ($13) {
      $p2_019 = $6;
      $p1_020 = $4;
      $count_021 = $12;
      label = 2;
      break;
    } else {
      $p2_0_lcssa = $6;
      $p1_0_lcssa = $4;
      $count_0_lcssa = $12;
      label = 4;
      break;
    }
   case 2:
    $14 = HEAP8[$p1_020] | 0;
    $15 = HEAP8[$p2_019] | 0;
    $16 = $15 & $14;
    $17 = $16 << 24 >> 24 == 0;
    if ($17) {
      label = 3;
      break;
    } else {
      $_0 = 1;
      label = 6;
      break;
    }
   case 3:
    $19 = $p1_020 + 1 | 0;
    $20 = $p2_019 + 1 | 0;
    $21 = $count_021 - 8 | 0;
    $22 = $21 >>> 0 > 7;
    if ($22) {
      $p2_019 = $20;
      $p1_020 = $19;
      $count_021 = $21;
      label = 2;
      break;
    } else {
      $p2_0_lcssa = $20;
      $p1_0_lcssa = $19;
      $count_0_lcssa = $21;
      label = 4;
      break;
    }
   case 4:
    $23 = ($count_0_lcssa | 0) == 0;
    if ($23) {
      $_0 = 0;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $25 = HEAP8[$p1_0_lcssa] | 0;
    $26 = HEAP8[$p2_0_lcssa] | 0;
    $27 = $26 & $25;
    $28 = $27 & 255;
    $29 = 255 >>> ($count_0_lcssa >>> 0);
    $30 = $29 ^ -1;
    $31 = $28 & $30;
    $_0 = $31;
    label = 6;
    break;
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _ps_mask_clear_bit($mask, $idx) {
  $mask = $mask | 0;
  $idx = $idx | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $mask | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 >>> 0 > $idx >>> 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $5 = $mask + 8 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $idx >> 3;
    $8 = $6 + $7 | 0;
    $9 = HEAP8[$8] | 0;
    $10 = $9 & 255;
    $11 = $idx & 7;
    $12 = 128 >>> ($11 >>> 0);
    $13 = $12 ^ 255;
    $14 = $10 & $13;
    $15 = $14 & 255;
    HEAP8[$8] = $15;
    label = 3;
    break;
   case 3:
    return;
  }
}
function _ps_dimension_init($dimension) {
  $dimension = $dimension | 0;
  HEAP32[$dimension >> 2] = 0;
  HEAP32[$dimension + 12 >> 2] = 0;
  HEAP32[$dimension + 24 >> 2] = 0;
  return;
}
function _ps_mask_test_bit($mask, $idx) {
  $mask = $mask | 0;
  $idx = $idx | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $mask | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 >>> 0 > $idx >>> 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 3;
      break;
    }
   case 2:
    $5 = $idx >> 3;
    $6 = $mask + 8 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 + $5 | 0;
    $9 = HEAP8[$8] | 0;
    $10 = $9 & 255;
    $11 = $idx & 7;
    $12 = 128 >>> ($11 >>> 0);
    $13 = $10 & $12;
    $_0 = $13;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _ps_mask_table_set_bits($table, $source, $bit_pos, $bit_count, $memory) {
  $table = $table | 0;
  $source = $source | 0;
  $bit_pos = $bit_pos | 0;
  $bit_count = $bit_count | 0;
  $memory = $memory | 0;
  var $mask = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $wmask_025 = 0, $write_024 = 0, $rmask_023 = 0, $read_022 = 0, $_021 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $val_0 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $_read_0 = 0, $_ = 0, $32 = 0, $33 = 0, $34 = 0, $write_1 = 0, $wmask_1 = 0, $35 = 0, $36 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $mask = __stackBase__ | 0;
    $1 = _ps_mask_table_last($table, $memory, $mask) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $error_0 = $1;
      label = 6;
      break;
    }
   case 2:
    $4 = HEAP32[$mask >> 2] | 0;
    $5 = _ps_mask_ensure($4, $bit_count, $memory) | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      $error_0 = $5;
      label = 6;
      break;
    }
   case 3:
    $8 = HEAP32[$mask >> 2] | 0;
    $9 = $8 | 0;
    HEAP32[$9 >> 2] = $bit_count;
    $10 = ($bit_count | 0) == 0;
    if ($10) {
      $error_0 = 0;
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $11 = HEAP32[$mask >> 2] | 0;
    $12 = $11 + 8 | 0;
    $13 = $bit_pos & 7;
    $14 = $bit_pos >>> 3;
    $15 = HEAP32[$12 >> 2] | 0;
    $16 = 128 >>> ($13 >>> 0);
    $17 = $source + $14 | 0;
    $_021 = $bit_count;
    $read_022 = $17;
    $rmask_023 = $16;
    $write_024 = $15;
    $wmask_025 = 128;
    label = 5;
    break;
   case 5:
    $19 = HEAP8[$write_024] | 0;
    $20 = $19 & 255;
    $21 = $wmask_025 ^ 255;
    $22 = $20 & $21;
    $23 = HEAP8[$read_022] | 0;
    $24 = $23 & 255;
    $25 = $24 & $rmask_023;
    $26 = ($25 | 0) == 0;
    $27 = $26 ? 0 : $wmask_025;
    $val_0 = $27 | $22;
    $28 = $val_0 & 255;
    HEAP8[$write_024] = $28;
    $29 = $rmask_023 >> 1;
    $30 = ($29 | 0) == 0;
    $31 = $read_022 + 1 | 0;
    $_read_0 = $30 ? $31 : $read_022;
    $_ = $30 ? 128 : $29;
    $32 = $wmask_025 >> 1;
    $33 = ($32 | 0) == 0;
    $34 = $write_024 + 1 | 0;
    $write_1 = $33 ? $34 : $write_024;
    $wmask_1 = $33 ? 128 : $32;
    $35 = $_021 - 1 | 0;
    $36 = ($35 | 0) == 0;
    if ($36) {
      $error_0 = $5;
      label = 6;
      break;
    } else {
      $_021 = $35;
      $read_022 = $_read_0;
      $rmask_023 = $_;
      $write_024 = $write_1;
      $wmask_025 = $wmask_1;
      label = 5;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _ps_mask_table_last($table, $memory, $amask) {
  $table = $table | 0;
  $memory = $memory | 0;
  $amask = $amask | 0;
  var $mask = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $7 = 0, $8 = 0, $_sum = 0, $9 = 0, $error_0 = 0, $11 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $mask = __stackBase__ | 0;
    $1 = $table | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $5 = _ps_mask_table_alloc($table, $memory, $mask) | 0;
    $error_0 = $5;
    label = 4;
    break;
   case 3:
    $7 = $table + 8 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $_sum = $2 - 1 | 0;
    $9 = $8 + ($_sum << 4) | 0;
    HEAP32[$mask >> 2] = $9;
    $error_0 = 0;
    label = 4;
    break;
   case 4:
    $11 = HEAP32[$mask >> 2] | 0;
    HEAP32[$amask >> 2] = $11;
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _ps_mask_ensure($mask, $count, $memory) {
  $mask = $mask | 0;
  $count = $count | 0;
  $memory = $memory | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $mask + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 7 | 0;
    $4 = $3 >>> 3;
    $5 = $count + 7 | 0;
    $6 = $5 >>> 3;
    HEAP32[$error >> 2] = 0;
    $7 = $6 >>> 0 > $4 >>> 0;
    if ($7) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $9 = $6 + 7 | 0;
    $10 = $9 & 1073741816;
    $11 = $mask + 8 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = _ft_mem_realloc($memory, 1, $4, $10, $12, $error) | 0;
    HEAP32[$11 >> 2] = $13;
    $14 = HEAP32[$error >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $17 = $10 << 3;
    HEAP32[$1 >> 2] = $17;
    label = 4;
    break;
   case 4:
    $19 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $19 | 0;
  }
  return 0;
}
function _ps_mask_table_alloc($table, $memory, $amask) {
  $table = $table | 0;
  $memory = $memory | 0;
  $amask = $amask | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $error_1 = 0, $mask_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 1 | 0;
    $4 = $table + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $3 >>> 0 > $5 >>> 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $8 = _ps_mask_table_ensure($table, $3, $memory) | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 3;
      break;
    } else {
      $mask_0 = 0;
      $error_1 = $8;
      label = 4;
      break;
    }
   case 3:
    $11 = $table + 8 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + ($2 << 4) | 0;
    $14 = $13 | 0;
    HEAP32[$14 >> 2] = 0;
    $15 = $12 + ($2 << 4) + 12 | 0;
    HEAP32[$15 >> 2] = 0;
    HEAP32[$1 >> 2] = $3;
    $mask_0 = $13;
    $error_1 = 0;
    label = 4;
    break;
   case 4:
    HEAP32[$amask >> 2] = $mask_0;
    return $error_1 | 0;
  }
  return 0;
}
function _ps_mask_table_ensure($table, $count, $memory) {
  $table = $table | 0;
  $count = $count | 0;
  $memory = $memory | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $16 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $table + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $3 = $2 >>> 0 < $count >>> 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $5 = $count + 7 | 0;
    $6 = $5 & -8;
    $7 = $table + 8 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8;
    $10 = _ft_mem_realloc($memory, 16, $2, $6, $9, $error) | 0;
    $11 = $10;
    HEAP32[$7 >> 2] = $11;
    $12 = HEAP32[$error >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    HEAP32[$1 >> 2] = $6;
    label = 4;
    break;
   case 4:
    $16 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $16 | 0;
  }
  return 0;
}
function _ps_hints_stem($hints, $dimension, $count, $stems) {
  $hints = $hints | 0;
  $dimension = $dimension | 0;
  $count = $count | 0;
  $stems = $stems | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $_off = 0, $switch = 0, $8 = 0, $_dimension = 0, $9 = 0, $10 = 0, $11 = 0, $_01619 = 0, $_01718 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $21 = 0, $22 = 0, $23 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 8;
      break;
    }
   case 2:
    $5 = $hints + 12 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $_off = $6 - 1 | 0;
    $switch = $_off >>> 0 < 2;
    if ($switch) {
      label = 3;
      break;
    } else {
      label = 8;
      break;
    }
   case 3:
    $8 = $dimension >>> 0 > 1;
    $_dimension = $8 ? 1 : $dimension;
    $9 = $hints + 16 + ($_dimension * 36 & -1) | 0;
    $10 = ($count | 0) == 0;
    if ($10) {
      label = 8;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $11 = $hints | 0;
    $_01718 = $stems;
    $_01619 = $count;
    label = 5;
    break;
   case 5:
    $13 = HEAP32[$11 >> 2] | 0;
    $14 = HEAP32[$_01718 >> 2] | 0;
    $15 = $_01718 + 4 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = _ps_dimension_add_t1stem($9, $14, $16, $13, 0) | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    HEAP32[$1 >> 2] = $17;
    label = 8;
    break;
   case 7:
    $21 = $_01619 - 1 | 0;
    $22 = $_01718 + 8 | 0;
    $23 = ($21 | 0) == 0;
    if ($23) {
      label = 8;
      break;
    } else {
      $_01718 = $22;
      $_01619 = $21;
      label = 5;
      break;
    }
   case 8:
    return;
  }
}
function _ps_dimension_add_t1stem($dim, $pos, $len, $memory, $aindex) {
  $dim = $dim | 0;
  $pos = $pos | 0;
  $len = $len | 0;
  $memory = $memory | 0;
  $aindex = $aindex | 0;
  var $mask = 0, $hint = 0, $1 = 0, $3 = 0, $_ = 0, $4 = 0, $_pos = 0, $_029 = 0, $flags_1 = 0, $_1 = 0, $6 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $idx_036 = 0, $storemerge35 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $idx_032 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $idx_033 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $_not = 0, $_not30 = 0, $brmerge = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $mask = __stackBase__ | 0;
    $hint = __stackBase__ + 4 | 0;
    $1 = ($len | 0) < 0;
    if ($1) {
      label = 2;
      break;
    } else {
      $_1 = $pos;
      $flags_1 = 0;
      $_029 = $len;
      label = 3;
      break;
    }
   case 2:
    $3 = ($len | 0) == -21;
    $_ = $3 ? 3 : 1;
    $4 = $3 ? -21 : 0;
    $_pos = $4 + $pos | 0;
    $_1 = $_pos;
    $flags_1 = $_;
    $_029 = 0;
    label = 3;
    break;
   case 3:
    $6 = ($aindex | 0) != 0;
    if ($6) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    HEAP32[$aindex >> 2] = -1;
    label = 5;
    break;
   case 5:
    $9 = $dim | 0;
    $10 = $dim | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $dim + 8 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    HEAP32[$hint >> 2] = $13;
    $14 = ($11 | 0) == 0;
    if ($14) {
      $idx_032 = 0;
      label = 9;
      break;
    } else {
      $storemerge35 = $13;
      $idx_036 = 0;
      label = 6;
      break;
    }
   case 6:
    $15 = $storemerge35 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($16 | 0) == ($_1 | 0);
    if ($17) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $19 = $storemerge35 + 4 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = ($20 | 0) == ($_029 | 0);
    if ($21) {
      $idx_033 = $idx_036;
      label = 11;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $23 = $idx_036 + 1 | 0;
    $24 = HEAP32[$hint >> 2] | 0;
    $25 = $24 + 12 | 0;
    HEAP32[$hint >> 2] = $25;
    $26 = $23 >>> 0 < $11 >>> 0;
    if ($26) {
      $storemerge35 = $25;
      $idx_036 = $23;
      label = 6;
      break;
    } else {
      $idx_032 = $23;
      label = 9;
      break;
    }
   case 9:
    $27 = _ps_hint_table_alloc($9, $memory, $hint) | 0;
    $28 = ($27 | 0) == 0;
    if ($28) {
      label = 10;
      break;
    } else {
      $error_0 = $27;
      label = 14;
      break;
    }
   case 10:
    $30 = HEAP32[$hint >> 2] | 0;
    $31 = $30 | 0;
    HEAP32[$31 >> 2] = $_1;
    $32 = HEAP32[$hint >> 2] | 0;
    $33 = $32 + 4 | 0;
    HEAP32[$33 >> 2] = $_029;
    $34 = HEAP32[$hint >> 2] | 0;
    $35 = $34 + 8 | 0;
    HEAP32[$35 >> 2] = $flags_1;
    $idx_033 = $idx_032;
    label = 11;
    break;
   case 11:
    $37 = $dim + 12 | 0;
    $38 = _ps_mask_table_last($37, $memory, $mask) | 0;
    $39 = ($38 | 0) == 0;
    if ($39) {
      label = 12;
      break;
    } else {
      $error_0 = $38;
      label = 14;
      break;
    }
   case 12:
    $41 = HEAP32[$mask >> 2] | 0;
    $42 = _ps_mask_set_bit($41, $idx_033, $memory) | 0;
    $_not = ($42 | 0) != 0;
    $_not30 = $6 ^ 1;
    $brmerge = $_not | $_not30;
    if ($brmerge) {
      $error_0 = $42;
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    HEAP32[$aindex >> 2] = $idx_033;
    $error_0 = $42;
    label = 14;
    break;
   case 14:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _ps_hint_table_alloc($table, $memory, $ahint) {
  $table = $table | 0;
  $memory = $memory | 0;
  $ahint = $ahint | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $error_1 = 0, $hint_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 1 | 0;
    $4 = $table + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $3 >>> 0 < $5 >>> 0;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = _ps_hint_table_ensure($table, $3, $memory) | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 3;
      break;
    } else {
      $hint_0 = 0;
      $error_1 = $8;
      label = 4;
      break;
    }
   case 3:
    $11 = $table + 8 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + ($2 * 12 & -1) | 0;
    $14 = $13 | 0;
    HEAP32[$14 >> 2] = 0;
    $15 = $12 + ($2 * 12 & -1) + 4 | 0;
    HEAP32[$15 >> 2] = 0;
    $16 = $12 + ($2 * 12 & -1) + 8 | 0;
    HEAP32[$16 >> 2] = 0;
    HEAP32[$1 >> 2] = $3;
    $hint_0 = $13;
    $error_1 = 0;
    label = 4;
    break;
   case 4:
    HEAP32[$ahint >> 2] = $hint_0;
    return $error_1 | 0;
  }
  return 0;
}
function _ps_mask_set_bit($mask, $idx, $memory) {
  $mask = $mask | 0;
  $idx = $idx | 0;
  $memory = $memory | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $error_1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($idx | 0) < 0;
    if ($1) {
      $error_1 = 0;
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $mask | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 >>> 0 > $idx >>> 0;
    if ($5) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $idx + 1 | 0;
    $8 = _ps_mask_ensure($mask, $7, $memory) | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 4;
      break;
    } else {
      $error_1 = $8;
      label = 6;
      break;
    }
   case 4:
    HEAP32[$3 >> 2] = $7;
    label = 5;
    break;
   case 5:
    $12 = $mask + 8 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $idx >> 3;
    $15 = $13 + $14 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 & 255;
    $18 = $idx & 7;
    $19 = 128 >>> ($18 >>> 0);
    $20 = $17 | $19;
    $21 = $20 & 255;
    HEAP8[$15] = $21;
    $error_1 = 0;
    label = 6;
    break;
   case 6:
    return $error_1 | 0;
  }
  return 0;
}
function _ps_hint_table_ensure($table, $count, $memory) {
  $table = $table | 0;
  $count = $count | 0;
  $memory = $memory | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $16 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $table + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $3 = $2 >>> 0 < $count >>> 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $5 = $count + 7 | 0;
    $6 = $5 & -8;
    $7 = $table + 8 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8;
    $10 = _ft_mem_realloc($memory, 12, $2, $6, $9, $error) | 0;
    $11 = $10;
    HEAP32[$7 >> 2] = $11;
    $12 = HEAP32[$error >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    HEAP32[$1 >> 2] = $6;
    label = 4;
    break;
   case 4:
    $16 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $16 | 0;
  }
  return 0;
}
function _ps_dimension_end($dim, $end_point, $memory) {
  $dim = $dim | 0;
  $end_point = $end_point | 0;
  $memory = $memory | 0;
  _ps_dimension_end_mask($dim, $end_point);
  return _ps_mask_table_merge_all($dim + 24 | 0, $memory) | 0;
}
function _ps_mask_table_merge_all($table, $memory) {
  $table = $table | 0;
  $memory = $memory | 0;
  var $1 = 0, $2 = 0, $index1_013 = 0, $3 = 0, $index1_015 = 0, $index1_0_in14 = 0, $4 = 0, $index2_0 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $index1_0 = 0, $14 = 0, $error_2 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $index1_013 = $2 - 1 | 0;
    $3 = ($index1_013 | 0) > 0;
    if ($3) {
      $index1_0_in14 = $2;
      $index1_015 = $index1_013;
      label = 2;
      break;
    } else {
      $error_2 = 0;
      label = 7;
      break;
    }
   case 2:
    $4 = $index1_0_in14 - 2 | 0;
    $index2_0 = $4;
    label = 3;
    break;
   case 3:
    $6 = ($index2_0 | 0) > -1;
    if ($6) {
      label = 4;
      break;
    } else {
      label = 6;
      break;
    }
   case 4:
    $8 = _ps_mask_table_test_intersect($table, $index1_015, $index2_0) | 0;
    $9 = ($8 | 0) == 0;
    $10 = $index2_0 - 1 | 0;
    if ($9) {
      $index2_0 = $10;
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $12 = _ps_mask_table_merge($table, $index2_0, $index1_015, $memory) | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 6;
      break;
    } else {
      $error_2 = $12;
      label = 7;
      break;
    }
   case 6:
    $index1_0 = $index1_015 - 1 | 0;
    $14 = ($index1_0 | 0) > 0;
    if ($14) {
      $index1_0_in14 = $index1_015;
      $index1_015 = $index1_0;
      label = 2;
      break;
    } else {
      $error_2 = 0;
      label = 7;
      break;
    }
   case 7:
    return $error_2 | 0;
  }
  return 0;
}
function _ps_mask_table_merge($table, $index1, $index2, $memory) {
  $table = $table | 0;
  $index1 = $index1 | 0;
  $index2 = $index2 | 0;
  $memory = $memory | 0;
  var $dummy = 0, $1 = 0, $index1_index2 = 0, $index2_index1 = 0, $2 = 0, $3 = 0, $or_cond = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $pos_049 = 0, $24 = 0, $exitcond = 0, $error_0 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $write_047 = 0, $read_046 = 0, $pos_145 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $error_1 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $_sum = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $error_2 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $dummy = __stackBase__ | 0;
    $1 = ($index1 | 0) > ($index2 | 0);
    $index1_index2 = $1 ? $index1 : $index2;
    $index2_index1 = $1 ? $index2 : $index1;
    $2 = ($index2_index1 | 0) < ($index1_index2 | 0);
    $3 = ($index2_index1 | 0) > -1;
    $or_cond = $2 & $3;
    if ($or_cond) {
      label = 2;
      break;
    } else {
      $error_2 = 0;
      label = 14;
      break;
    }
   case 2:
    $5 = $table | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($index1_index2 | 0) < ($6 | 0);
    if ($7) {
      label = 3;
      break;
    } else {
      $error_2 = 0;
      label = 14;
      break;
    }
   case 3:
    $9 = $table + 8 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10 + ($index2_index1 << 4) | 0;
    $12 = $10 + ($index1_index2 << 4) | 0;
    $13 = $11 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $12 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      $error_1 = 0;
      label = 11;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $19 = $16 >>> 0 > $14 >>> 0;
    if ($19) {
      label = 5;
      break;
    } else {
      $error_0 = 0;
      label = 8;
      break;
    }
   case 5:
    $21 = _ps_mask_ensure($11, $16, $memory) | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 6;
      break;
    } else {
      $error_2 = $21;
      label = 14;
      break;
    }
   case 6:
    $23 = $14 >>> 0 < $16 >>> 0;
    if ($23) {
      $pos_049 = $14;
      label = 7;
      break;
    } else {
      $error_0 = 0;
      label = 8;
      break;
    }
   case 7:
    _ps_mask_clear_bit($11, $pos_049);
    $24 = $pos_049 + 1 | 0;
    $exitcond = ($24 | 0) == ($16 | 0);
    if ($exitcond) {
      $error_0 = $21;
      label = 8;
      break;
    } else {
      $pos_049 = $24;
      label = 7;
      break;
    }
   case 8:
    $25 = $16 + 7 | 0;
    $26 = $25 >>> 3;
    $27 = ($26 | 0) == 0;
    if ($27) {
      $error_1 = $error_0;
      label = 11;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $28 = $10 + ($index2_index1 << 4) + 8 | 0;
    $29 = $10 + ($index1_index2 << 4) + 8 | 0;
    $30 = HEAP32[$28 >> 2] | 0;
    $31 = HEAP32[$29 >> 2] | 0;
    $pos_145 = $26;
    $read_046 = $31;
    $write_047 = $30;
    label = 10;
    break;
   case 10:
    $33 = HEAP8[$write_047] | 0;
    $34 = HEAP8[$read_046] | 0;
    $35 = $34 | $33;
    HEAP8[$write_047] = $35;
    $36 = $write_047 + 1 | 0;
    $37 = $read_046 + 1 | 0;
    $38 = $pos_145 - 1 | 0;
    $39 = ($38 | 0) == 0;
    if ($39) {
      $error_1 = $error_0;
      label = 11;
      break;
    } else {
      $pos_145 = $38;
      $read_046 = $37;
      $write_047 = $36;
      label = 10;
      break;
    }
   case 11:
    HEAP32[$15 >> 2] = 0;
    $40 = $10 + ($index1_index2 << 4) + 12 | 0;
    HEAP32[$40 >> 2] = 0;
    $41 = HEAP32[$5 >> 2] | 0;
    $42 = $41 - 1 | 0;
    $43 = $42 - $index1_index2 | 0;
    $44 = ($43 | 0) > 0;
    if ($44) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $46 = $dummy;
    $47 = $12;
    _memcpy($46 | 0, $47 | 0, 16);
    $_sum = $index1_index2 + 1 | 0;
    $48 = $10 + ($_sum << 4) | 0;
    $49 = $48;
    $50 = $43 << 4;
    _memmove($47 | 0, $49 | 0, $50 | 0);
    $51 = $10 + ($42 << 4) | 0;
    $52 = $51;
    _memcpy($52 | 0, $46 | 0, 16);
    label = 13;
    break;
   case 13:
    $54 = HEAP32[$5 >> 2] | 0;
    $55 = $54 - 1 | 0;
    HEAP32[$5 >> 2] = $55;
    $error_2 = $error_1;
    label = 14;
    break;
   case 14:
    STACKTOP = __stackBase__;
    return $error_2 | 0;
  }
  return 0;
}
function _ps_hints_open($hints, $hint_type) {
  $hints = $hints | 0;
  $hint_type = $hint_type | 0;
  var $_off = 0, $switch = 0, $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $_off = $hint_type - 1 | 0;
    $switch = $_off >>> 0 < 2;
    $1 = $hints + 4 | 0;
    if ($switch) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = 0;
    $3 = $hints + 12 | 0;
    HEAP32[$3 >> 2] = $hint_type;
    $4 = $hints + 16 | 0;
    _ps_dimension_init($4);
    $5 = $hints + 52 | 0;
    _ps_dimension_init($5);
    label = 4;
    break;
   case 3:
    HEAP32[$1 >> 2] = 6;
    $7 = $hints + 12 | 0;
    HEAP32[$7 >> 2] = $hint_type;
    label = 4;
    break;
   case 4:
    return;
  }
}
function _t1_hints_open($hints) {
  $hints = $hints | 0;
  _ps_hints_open($hints, 1);
  return;
}
function _t1_hints_stem($hints, $dimension, $coords) {
  $hints = $hints | 0;
  $dimension = $dimension | 0;
  $coords = $coords | 0;
  var $stems = 0, $4 = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  $stems = __stackBase__ | 0;
  $4 = $stems | 0;
  HEAP32[$4 >> 2] = _FT_RoundFix(HEAP32[$coords >> 2] | 0) >> 16;
  HEAP32[$stems + 4 >> 2] = _FT_RoundFix(HEAP32[$coords + 4 >> 2] | 0) >> 16;
  _ps_hints_stem($hints, $dimension, 1, $4);
  STACKTOP = __stackBase__;
  return;
}
function _ps_hints_t1stem3($hints, $dimension, $stems) {
  $hints = $hints | 0;
  $dimension = $dimension | 0;
  $stems = $stems | 0;
  var $idx = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $_dimension = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $error_0 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $idx = __stackBase__ | 0;
    $1 = $hints + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $5 = $hints | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $dimension >>> 0 > 1;
    $_dimension = $7 ? 1 : $dimension;
    $8 = $hints + 16 + ($_dimension * 36 & -1) | 0;
    $9 = $hints + 12 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($10 | 0) == 1;
    if ($11) {
      label = 3;
      break;
    } else {
      $error_0 = 6;
      label = 5;
      break;
    }
   case 3:
    $12 = HEAP32[$stems >> 2] | 0;
    $13 = _FT_RoundFix($12) | 0;
    $14 = $13 >> 16;
    $15 = $stems + 4 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = _FT_RoundFix($16) | 0;
    $18 = $17 >> 16;
    $19 = $idx | 0;
    $20 = _ps_dimension_add_t1stem($8, $14, $18, $6, $19) | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 4;
      break;
    } else {
      $error_0 = $20;
      label = 5;
      break;
    }
   case 4:
    $23 = $stems + 8 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = _FT_RoundFix($24) | 0;
    $26 = $25 >> 16;
    $27 = $stems + 12 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = _FT_RoundFix($28) | 0;
    $30 = $29 >> 16;
    $31 = $idx + 4 | 0;
    $32 = _ps_dimension_add_t1stem($8, $26, $30, $6, $31) | 0;
    $33 = ($32 | 0) == 0;
    if ($33) {
      label = 7;
      break;
    } else {
      $error_0 = $32;
      label = 5;
      break;
    }
   case 5:
    HEAP32[$1 >> 2] = $error_0;
    label = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   case 7:
    $36 = $stems + 16 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = _FT_RoundFix($37) | 0;
    $39 = $38 >> 16;
    $40 = $stems + 20 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = _FT_RoundFix($41) | 0;
    $43 = $42 >> 16;
    $44 = $idx + 8 | 0;
    $45 = _ps_dimension_add_t1stem($8, $39, $43, $6, $44) | 0;
    $46 = ($45 | 0) == 0;
    if ($46) {
      label = 8;
      break;
    } else {
      $error_0 = $45;
      label = 5;
      break;
    }
   case 8:
    $48 = $idx | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = $idx + 4 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = $idx + 8 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = _ps_dimension_add_counter($8, $49, $51, $53, $6) | 0;
    $55 = ($54 | 0) == 0;
    if ($55) {
      label = 6;
      break;
    } else {
      $error_0 = $54;
      label = 5;
      break;
    }
  }
}
function _ps_hints_t1reset($hints, $end_point) {
  $hints = $hints | 0;
  $end_point = $end_point | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $5 = $hints | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $hints + 12 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 1;
    if ($9) {
      label = 3;
      break;
    } else {
      $error_0 = 6;
      label = 5;
      break;
    }
   case 3:
    $11 = $hints + 16 | 0;
    $12 = _ps_dimension_reset_mask($11, $end_point, $6) | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 4;
      break;
    } else {
      $error_0 = $12;
      label = 5;
      break;
    }
   case 4:
    $15 = $hints + 52 | 0;
    $16 = _ps_dimension_reset_mask($15, $end_point, $6) | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 6;
      break;
    } else {
      $error_0 = $16;
      label = 5;
      break;
    }
   case 5:
    HEAP32[$1 >> 2] = $error_0;
    label = 6;
    break;
   case 6:
    return;
  }
}
function _ps_dimension_add_counter($dim, $hint1, $hint2, $hint3, $memory) {
  $dim = $dim | 0;
  $hint1 = $hint1 | 0;
  $hint2 = $hint2 | 0;
  $hint3 = $hint3 | 0;
  $memory = $memory | 0;
  var $counter = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $cond20 = 0, $count_022 = 0, $storemerge21 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $cond = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $counter = __stackBase__ | 0;
    $1 = $dim + 24 | 0;
    $2 = $1 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $dim + 32 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    HEAP32[$counter >> 2] = $5;
    $cond20 = ($3 | 0) == 0;
    if ($cond20) {
      label = 6;
      break;
    } else {
      $storemerge21 = $5;
      $count_022 = $3;
      label = 2;
      break;
    }
   case 2:
    $6 = _ps_mask_test_bit($storemerge21, $hint1) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 7;
      break;
    }
   case 3:
    $9 = _ps_mask_test_bit($storemerge21, $hint2) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 7;
      break;
    }
   case 4:
    $12 = _ps_mask_test_bit($storemerge21, $hint3) | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    $15 = $count_022 - 1 | 0;
    $16 = $storemerge21 + 16 | 0;
    HEAP32[$counter >> 2] = $16;
    $cond = ($15 | 0) == 0;
    if ($cond) {
      label = 6;
      break;
    } else {
      $storemerge21 = $16;
      $count_022 = $15;
      label = 2;
      break;
    }
   case 6:
    $17 = _ps_mask_table_alloc($1, $memory, $counter) | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 7;
      break;
    } else {
      $error_0 = $17;
      label = 10;
      break;
    }
   case 7:
    $19 = HEAP32[$counter >> 2] | 0;
    $20 = _ps_mask_set_bit($19, $hint1, $memory) | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 8;
      break;
    } else {
      $error_0 = $20;
      label = 10;
      break;
    }
   case 8:
    $23 = HEAP32[$counter >> 2] | 0;
    $24 = _ps_mask_set_bit($23, $hint2, $memory) | 0;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 9;
      break;
    } else {
      $error_0 = $24;
      label = 10;
      break;
    }
   case 9:
    $27 = HEAP32[$counter >> 2] | 0;
    $28 = _ps_mask_set_bit($27, $hint3, $memory) | 0;
    $error_0 = $28;
    label = 10;
    break;
   case 10:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _pshinter_get_globals_funcs($module) {
  $module = $module | 0;
  return $module + 108 | 0;
}
function _pshinter_get_t1_funcs($module) {
  $module = $module | 0;
  return $module + 120 | 0;
}
function _pshinter_get_t2_funcs($module) {
  $module = $module | 0;
  return $module + 148 | 0;
}
function _psh_hint_table_find_strong_points($table, $point, $count, $threshold, $major_dir) {
  $table = $table | 0;
  $point = $point | 0;
  $count = $count | 0;
  $threshold = $threshold | 0;
  $major_dir = $major_dir | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_ = 0, $_90 = 0, $8 = 0, $9 = 0, $_0110 = 0, $_085109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $or_cond119 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $or_cond = 0, $point_dir_0 = 0, $33 = 0, $35 = 0, $nn_0 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $or_cond87 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $nn1_0 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $or_cond89 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $75 = 0, $76 = 0, $nn4_0 = 0, $77 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $or_cond92 = 0, $87 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $95 = 0, $96 = 0, $nn4_1 = 0, $97 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $or_cond94 = 0, $110 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $_not = 0, $brmerge = 0, $nn4_2108 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table + 12 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $table + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($count | 0) == 0;
    if ($5) {
      label = 31;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = -$major_dir | 0;
    $7 = ($major_dir | 0) == 2;
    $_ = $7 ? 128 : 256;
    $_90 = $7 ? 256 : 128;
    $8 = ($4 | 0) == 0;
    $9 = -$major_dir | 0;
    $_085109 = $count;
    $_0110 = $point;
    label = 3;
    break;
   case 3:
    $11 = $_0110 + 36 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $_0110 + 16 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 & 16;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 4;
      break;
    } else {
      label = 30;
      break;
    }
   case 4:
    $18 = $_0110 + 20 | 0;
    $19 = HEAP8[$18] | 0;
    $20 = $19 << 24 >> 24;
    $21 = ($20 | 0) == ($major_dir | 0);
    $22 = ($20 | 0) == ($9 | 0);
    $or_cond119 = $21 | $22;
    if ($or_cond119) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $24 = HEAP8[$18] | 0;
    $25 = $24 << 24 >> 24;
    $point_dir_0 = $25;
    label = 7;
    break;
   case 6:
    $27 = $_0110 + 21 | 0;
    $28 = HEAP8[$27] | 0;
    $29 = $28 << 24 >> 24;
    $30 = ($29 | 0) == ($major_dir | 0);
    $31 = ($29 | 0) == ($9 | 0);
    $or_cond = $30 | $31;
    if ($or_cond) {
      $point_dir_0 = $29;
      label = 7;
      break;
    } else {
      label = 16;
      break;
    }
   case 7:
    $33 = ($point_dir_0 | 0) == 0;
    if ($33) {
      label = 16;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $35 = ($point_dir_0 | 0) == ($major_dir | 0);
    if ($35) {
      $nn_0 = 0;
      label = 9;
      break;
    } else {
      label = 12;
      break;
    }
   case 9:
    $36 = $nn_0 >>> 0 < $4 >>> 0;
    if ($36) {
      label = 10;
      break;
    } else {
      label = 30;
      break;
    }
   case 10:
    $38 = $2 + ($nn_0 << 2) | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = $39 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = $12 - $41 | 0;
    $43 = ($42 | 0) < ($threshold | 0);
    $44 = -$42 | 0;
    $45 = ($44 | 0) < ($threshold | 0);
    $or_cond87 = $43 & $45;
    $46 = $nn_0 + 1 | 0;
    if ($or_cond87) {
      label = 11;
      break;
    } else {
      $nn_0 = $46;
      label = 9;
      break;
    }
   case 11:
    $48 = HEAP32[$13 >> 2] | 0;
    $49 = $48 | 528;
    HEAP32[$13 >> 2] = $49;
    $50 = $_0110 + 32 | 0;
    HEAP32[$50 >> 2] = $39;
    label = 30;
    break;
   case 12:
    $52 = ($point_dir_0 | 0) == ($6 | 0);
    if ($52) {
      $nn1_0 = 0;
      label = 13;
      break;
    } else {
      label = 30;
      break;
    }
   case 13:
    $53 = $nn1_0 >>> 0 < $4 >>> 0;
    if ($53) {
      label = 14;
      break;
    } else {
      label = 30;
      break;
    }
   case 14:
    $55 = $2 + ($nn1_0 << 2) | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = $56 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = $12 - $58 | 0;
    $60 = $56 + 4 | 0;
    $61 = HEAP32[$60 >> 2] | 0;
    $62 = $59 - $61 | 0;
    $63 = ($62 | 0) < ($threshold | 0);
    $64 = -$62 | 0;
    $65 = ($64 | 0) < ($threshold | 0);
    $or_cond89 = $63 & $65;
    $66 = $nn1_0 + 1 | 0;
    if ($or_cond89) {
      label = 15;
      break;
    } else {
      $nn1_0 = $66;
      label = 13;
      break;
    }
   case 15:
    $68 = HEAP32[$13 >> 2] | 0;
    $69 = $68 | 1040;
    HEAP32[$13 >> 2] = $69;
    $70 = $_0110 + 32 | 0;
    HEAP32[$70 >> 2] = $56;
    label = 30;
    break;
   case 16:
    $71 = HEAP32[$13 >> 2] | 0;
    $72 = $71 & 64;
    $73 = ($72 | 0) == 0;
    if ($73) {
      label = 30;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $75 = $71 & $_;
    $76 = ($75 | 0) == 0;
    if ($76) {
      label = 21;
      break;
    } else {
      $nn4_0 = 0;
      label = 18;
      break;
    }
   case 18:
    $77 = $nn4_0 >>> 0 < $4 >>> 0;
    if ($77) {
      label = 19;
      break;
    } else {
      label = 25;
      break;
    }
   case 19:
    $79 = $2 + ($nn4_0 << 2) | 0;
    $80 = HEAP32[$79 >> 2] | 0;
    $81 = $80 | 0;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = $12 - $82 | 0;
    $84 = ($83 | 0) < ($threshold | 0);
    $85 = -$83 | 0;
    $86 = ($85 | 0) < ($threshold | 0);
    $or_cond92 = $84 & $86;
    $87 = $nn4_0 + 1 | 0;
    if ($or_cond92) {
      label = 20;
      break;
    } else {
      $nn4_0 = $87;
      label = 18;
      break;
    }
   case 20:
    $89 = HEAP32[$13 >> 2] | 0;
    $90 = $89 | 512;
    HEAP32[$13 >> 2] = $90;
    $91 = $_0110 + 32 | 0;
    HEAP32[$91 >> 2] = $80;
    $92 = HEAP32[$13 >> 2] | 0;
    $93 = $92 | 16;
    HEAP32[$13 >> 2] = $93;
    label = 25;
    break;
   case 21:
    $95 = $71 & $_90;
    $96 = ($95 | 0) == 0;
    if ($96) {
      label = 25;
      break;
    } else {
      $nn4_1 = 0;
      label = 22;
      break;
    }
   case 22:
    $97 = $nn4_1 >>> 0 < $4 >>> 0;
    if ($97) {
      label = 23;
      break;
    } else {
      label = 25;
      break;
    }
   case 23:
    $99 = $2 + ($nn4_1 << 2) | 0;
    $100 = HEAP32[$99 >> 2] | 0;
    $101 = $100 | 0;
    $102 = HEAP32[$101 >> 2] | 0;
    $103 = $12 - $102 | 0;
    $104 = $100 + 4 | 0;
    $105 = HEAP32[$104 >> 2] | 0;
    $106 = $103 - $105 | 0;
    $107 = ($106 | 0) < ($threshold | 0);
    $108 = -$106 | 0;
    $109 = ($108 | 0) < ($threshold | 0);
    $or_cond94 = $107 & $109;
    $110 = $nn4_1 + 1 | 0;
    if ($or_cond94) {
      label = 24;
      break;
    } else {
      $nn4_1 = $110;
      label = 22;
      break;
    }
   case 24:
    $112 = HEAP32[$13 >> 2] | 0;
    $113 = $112 | 1024;
    HEAP32[$13 >> 2] = $113;
    $114 = $_0110 + 32 | 0;
    HEAP32[$114 >> 2] = $100;
    $115 = HEAP32[$13 >> 2] | 0;
    $116 = $115 | 16;
    HEAP32[$13 >> 2] = $116;
    label = 25;
    break;
   case 25:
    $117 = $_0110 + 32 | 0;
    $118 = HEAP32[$117 >> 2] | 0;
    $_not = ($118 | 0) != 0;
    $brmerge = $_not | $8;
    if ($brmerge) {
      label = 30;
      break;
    } else {
      $nn4_2108 = 0;
      label = 26;
      break;
    }
   case 26:
    $119 = $2 + ($nn4_2108 << 2) | 0;
    $120 = HEAP32[$119 >> 2] | 0;
    $121 = $120 | 0;
    $122 = HEAP32[$121 >> 2] | 0;
    $123 = ($12 | 0) < ($122 | 0);
    if ($123) {
      label = 29;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $125 = $120 + 4 | 0;
    $126 = HEAP32[$125 >> 2] | 0;
    $127 = $126 + $122 | 0;
    $128 = ($12 | 0) > ($127 | 0);
    if ($128) {
      label = 29;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    HEAP32[$117 >> 2] = $120;
    label = 30;
    break;
   case 29:
    $131 = $nn4_2108 + 1 | 0;
    $132 = $131 >>> 0 < $4 >>> 0;
    if ($132) {
      $nn4_2108 = $131;
      label = 26;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    $133 = $_085109 - 1 | 0;
    $134 = $_0110 + 48 | 0;
    $135 = ($133 | 0) == 0;
    if ($135) {
      label = 31;
      break;
    } else {
      $_085109 = $133;
      $_0110 = $134;
      label = 3;
      break;
    }
   case 31:
    return;
  }
}
function _psh_hint_table_deactivate($table) {
  $table = $table | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $hint_06 = 0, $count_05 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $table + 8 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $count_05 = $2;
    $hint_06 = $5;
    label = 3;
    break;
   case 3:
    $7 = $hint_06 + 16 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 & -5;
    HEAP32[$7 >> 2] = $9;
    $10 = $hint_06 + 24 | 0;
    HEAP32[$10 >> 2] = -1;
    $11 = $count_05 - 1 | 0;
    $12 = $hint_06 + 28 | 0;
    $13 = ($11 | 0) == 0;
    if ($13) {
      label = 4;
      break;
    } else {
      $count_05 = $11;
      $hint_06 = $12;
      label = 3;
      break;
    }
   case 4:
    return;
  }
}
function _psh_globals_new($memory, $priv, $aglobals) {
  $memory = $memory | 0;
  $priv = $priv | 0;
  $aglobals = $aglobals | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $write_055 = 0, $count_054 = 0, $read_053 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $write2_052 = 0, $count_151 = 0, $read_150 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $98 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = _ft_mem_alloc($memory, 2496, $error) | 0;
    $2 = $1;
    $3 = HEAP32[$error >> 2] | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 9;
      break;
    }
   case 2:
    $6 = $1;
    HEAP32[$6 >> 2] = $memory;
    $7 = $1 + 4 | 0;
    $8 = $1 + 208 | 0;
    $9 = $1 + 212 | 0;
    $10 = $priv + 120 | 0;
    $11 = HEAP16[$10 >> 1] | 0;
    $12 = $11 & 65535;
    $13 = $9;
    HEAP32[$13 >> 2] = $12;
    $14 = $priv + 124 | 0;
    $15 = HEAP8[$14] | 0;
    $16 = $15 << 24 >> 24 == 0;
    if ($16) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $17 = $1 + 224 | 0;
    $18 = $15 & 255;
    $19 = $priv + 128 | 0;
    $20 = $17;
    $read_053 = $19;
    $count_054 = $18;
    $write_055 = $20;
    label = 4;
    break;
   case 4:
    $22 = HEAP16[$read_053 >> 1] | 0;
    $23 = $22 << 16 >> 16;
    $24 = $write_055 | 0;
    HEAP32[$24 >> 2] = $23;
    $25 = $write_055 + 12 | 0;
    $26 = $read_053 + 2 | 0;
    $27 = $count_054 - 1 | 0;
    $28 = ($27 | 0) == 0;
    if ($28) {
      label = 5;
      break;
    } else {
      $read_053 = $26;
      $count_054 = $27;
      $write_055 = $25;
      label = 4;
      break;
    }
   case 5:
    $29 = HEAP8[$14] | 0;
    $30 = $29 & 255;
    $31 = $30 + 1 | 0;
    $32 = $8;
    HEAP32[$32 >> 2] = $31;
    $33 = $1 + 8 | 0;
    $34 = $priv + 122 | 0;
    $35 = HEAP16[$34 >> 1] | 0;
    $36 = $35 & 65535;
    $37 = $33;
    HEAP32[$37 >> 2] = $36;
    $38 = $priv + 125 | 0;
    $39 = HEAP8[$38] | 0;
    $40 = $39 << 24 >> 24 == 0;
    if ($40) {
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $41 = $1 + 20 | 0;
    $42 = $39 & 255;
    $43 = $priv + 154 | 0;
    $44 = $41;
    $read_150 = $43;
    $count_151 = $42;
    $write2_052 = $44;
    label = 7;
    break;
   case 7:
    $46 = HEAP16[$read_150 >> 1] | 0;
    $47 = $46 << 16 >> 16;
    $48 = $write2_052 | 0;
    HEAP32[$48 >> 2] = $47;
    $49 = $write2_052 + 12 | 0;
    $50 = $read_150 + 2 | 0;
    $51 = $count_151 - 1 | 0;
    $52 = ($51 | 0) == 0;
    if ($52) {
      label = 8;
      break;
    } else {
      $read_150 = $50;
      $count_151 = $51;
      $write2_052 = $49;
      label = 7;
      break;
    }
   case 8:
    $53 = HEAP8[$38] | 0;
    $54 = $53 & 255;
    $55 = $54 + 1 | 0;
    $56 = $7;
    HEAP32[$56 >> 2] = $55;
    $57 = $1 + 412 | 0;
    $58 = $57;
    $59 = $priv + 8 | 0;
    $60 = HEAP8[$59] | 0;
    $61 = $60 & 255;
    $62 = $priv + 12 | 0;
    $63 = $priv + 9 | 0;
    $64 = HEAP8[$63] | 0;
    $65 = $64 & 255;
    $66 = $priv + 40 | 0;
    $67 = $priv + 116 | 0;
    $68 = HEAP32[$67 >> 2] | 0;
    _psh_blues_set_zones($58, $61, $62, $65, $66, $68, 0);
    $69 = $priv + 10 | 0;
    $70 = HEAP8[$69] | 0;
    $71 = $70 & 255;
    $72 = $priv + 60 | 0;
    $73 = $priv + 11 | 0;
    $74 = HEAP8[$73] | 0;
    $75 = $74 & 255;
    $76 = $priv + 88 | 0;
    $77 = HEAP32[$67 >> 2] | 0;
    _psh_blues_set_zones($58, $71, $72, $75, $76, $77, 1);
    $78 = $priv + 108 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = $1 + 2476 | 0;
    $81 = $80;
    HEAP32[$81 >> 2] = $79;
    $82 = $priv + 112 | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = $1 + 2480 | 0;
    $85 = $84;
    HEAP32[$85 >> 2] = $83;
    $86 = HEAP32[$67 >> 2] | 0;
    $87 = $1 + 2488 | 0;
    $88 = $87;
    HEAP32[$88 >> 2] = $86;
    $89 = $1 + 200 | 0;
    $90 = $89;
    HEAP32[$90 >> 2] = 0;
    $91 = $1 + 204 | 0;
    $92 = $91;
    HEAP32[$92 >> 2] = 0;
    $93 = $1 + 404 | 0;
    $94 = $93;
    HEAP32[$94 >> 2] = 0;
    $95 = $1 + 408 | 0;
    $96 = $95;
    HEAP32[$96 >> 2] = 0;
    label = 9;
    break;
   case 9:
    HEAP32[$aglobals >> 2] = $2;
    $98 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $98 | 0;
  }
  return 0;
}
function _psh_globals_destroy($globals) {
  $globals = $globals | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($globals | 0) == 0;
    if ($1) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $globals | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $globals + 4 | 0;
    HEAP32[$5 >> 2] = 0;
    $6 = $globals + 208 | 0;
    HEAP32[$6 >> 2] = 0;
    $7 = $globals + 412 | 0;
    HEAP32[$7 >> 2] = 0;
    $8 = $globals + 928 | 0;
    HEAP32[$8 >> 2] = 0;
    $9 = $globals + 1444 | 0;
    HEAP32[$9 >> 2] = 0;
    $10 = $globals + 1960 | 0;
    HEAP32[$10 >> 2] = 0;
    $11 = $globals;
    _ft_mem_free($4, $11);
    label = 3;
    break;
   case 3:
    return;
  }
}
function _psh_blues_set_zones($target, $count, $blues, $count_others, $other_blues, $fuzz, $family) {
  $target = $target | 0;
  $count = $count | 0;
  $blues = $blues | 0;
  $count_others = $count_others | 0;
  $other_blues = $other_blues | 0;
  $fuzz = $fuzz | 0;
  $family = $family | 0;
  var $1 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $bot_table_0 = 0, $top_table_0 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $_089 = 0, $zone_088 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $_185 = 0, $zone1_084 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $66 = 0, $zone4_083 = 0, $67 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $_373 = 0, $top_074 = 0, $73 = 0, $uglygep = 0, $74 = 0, $scevgep95 = 0, $top_077 = 0, $_376 = 0, $zone4_175 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $82 = 0, $83 = 0, $84 = 0, $86 = 0, $87 = 0, $88 = 0, $90 = 0, $_3 = 0, $top_0 = 0, $91 = 0, $scevgep94 = 0, $top_0_lcssa = 0, $zone4_1_lcssa = 0, $93 = 0, $94 = 0, $zone4_083_1 = 0, $96 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $_373_1 = 0, $top_074_1 = 0, $102 = 0, $uglygep_1 = 0, $103 = 0, $scevgep_196 = 0, $top_077_1 = 0, $_376_1 = 0, $zone4_175_1 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $111 = 0, $112 = 0, $113 = 0, $115 = 0, $116 = 0, $117 = 0, $119 = 0, $_3_1 = 0, $top_0_1 = 0, $120 = 0, $scevgep94_1 = 0, $top_0_lcssa_1 = 0, $zone4_1_lcssa_1 = 0, $122 = 0, $123 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($family | 0) == 0;
    if ($1) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $target + 1032 | 0;
    $4 = $target + 1548 | 0;
    $top_table_0 = $3;
    $bot_table_0 = $4;
    label = 4;
    break;
   case 3:
    $6 = $target | 0;
    $7 = $target + 516 | 0;
    $top_table_0 = $6;
    $bot_table_0 = $7;
    label = 4;
    break;
   case 4:
    $9 = $top_table_0 | 0;
    HEAP32[$9 >> 2] = 0;
    $10 = $bot_table_0 | 0;
    HEAP32[$10 >> 2] = 0;
    _psh_blues_set_zones_0(0, $count, $blues, $top_table_0, $bot_table_0);
    _psh_blues_set_zones_0(1, $count_others, $other_blues, $top_table_0, $bot_table_0);
    $11 = HEAP32[$9 >> 2] | 0;
    $12 = HEAP32[$10 >> 2] | 0;
    $13 = ($11 | 0) > 0;
    if ($13) {
      label = 5;
      break;
    } else {
      label = 10;
      break;
    }
   case 5:
    $14 = $top_table_0 + 4 | 0;
    $zone_088 = $14;
    $_089 = $11;
    label = 6;
    break;
   case 6:
    $16 = $_089 >>> 0 > 1;
    if ($16) {
      label = 7;
      break;
    } else {
      label = 9;
      break;
    }
   case 7:
    $18 = $zone_088 + 32 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $zone_088 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $19 - $21 | 0;
    $23 = $zone_088 + 4 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = ($24 | 0) > ($22 | 0);
    if ($25) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    HEAP32[$23 >> 2] = $22;
    label = 9;
    break;
   case 9:
    $28 = $zone_088 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $zone_088 + 12 | 0;
    HEAP32[$30 >> 2] = $29;
    $31 = $zone_088 + 4 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = HEAP32[$28 >> 2] | 0;
    $34 = $33 + $32 | 0;
    $35 = $zone_088 + 8 | 0;
    HEAP32[$35 >> 2] = $34;
    $36 = $_089 - 1 | 0;
    $37 = $zone_088 + 32 | 0;
    $38 = ($36 | 0) == 0;
    if ($38) {
      label = 10;
      break;
    } else {
      $zone_088 = $37;
      $_089 = $36;
      label = 6;
      break;
    }
   case 10:
    $39 = ($12 | 0) > 0;
    if ($39) {
      label = 11;
      break;
    } else {
      label = 16;
      break;
    }
   case 11:
    $40 = $bot_table_0 + 4 | 0;
    $zone1_084 = $40;
    $_185 = $12;
    label = 12;
    break;
   case 12:
    $42 = $_185 >>> 0 > 1;
    if ($42) {
      label = 13;
      break;
    } else {
      label = 15;
      break;
    }
   case 13:
    $44 = $zone1_084 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = $zone1_084 + 32 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $45 - $47 | 0;
    $49 = $zone1_084 + 4 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = ($50 | 0) < ($48 | 0);
    if ($51) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    HEAP32[$49 >> 2] = $48;
    label = 15;
    break;
   case 15:
    $54 = $zone1_084 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = $zone1_084 + 8 | 0;
    HEAP32[$56 >> 2] = $55;
    $57 = $zone1_084 + 4 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = HEAP32[$54 >> 2] | 0;
    $60 = $59 + $58 | 0;
    $61 = $zone1_084 + 12 | 0;
    HEAP32[$61 >> 2] = $60;
    $62 = $_185 - 1 | 0;
    $63 = $zone1_084 + 32 | 0;
    $64 = ($62 | 0) == 0;
    if ($64) {
      label = 16;
      break;
    } else {
      $zone1_084 = $63;
      $_185 = $62;
      label = 12;
      break;
    }
   case 16:
    $66 = $fuzz << 1;
    $zone4_083 = $top_table_0 + 4 | 0;
    $67 = ($11 | 0) == 0;
    if ($67) {
      label = 25;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $69 = $top_table_0 + 16 | 0;
    $70 = HEAP32[$69 >> 2] | 0;
    $71 = $70 - $fuzz | 0;
    HEAP32[$69 >> 2] = $71;
    $72 = $top_table_0 + 12 | 0;
    $_373 = $11 - 1 | 0;
    $top_074 = HEAP32[$72 >> 2] | 0;
    $73 = ($_373 | 0) == 0;
    if ($73) {
      $zone4_1_lcssa = $zone4_083;
      $top_0_lcssa = $top_074;
      label = 24;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $uglygep = $top_table_0 - 516 + 488 | 0;
    $74 = $11 << 3;
    $scevgep95 = $uglygep + ($74 << 2) | 0;
    $zone4_175 = $zone4_083;
    $_376 = $_373;
    $top_077 = $top_074;
    label = 19;
    break;
   case 19:
    $76 = $zone4_175 + 32 | 0;
    $77 = $zone4_175 + 44 | 0;
    $78 = HEAP32[$77 >> 2] | 0;
    $79 = $78 - $top_077 | 0;
    $80 = ($79 | 0) < ($66 | 0);
    if ($80) {
      label = 20;
      break;
    } else {
      label = 21;
      break;
    }
   case 20:
    $82 = ($79 | 0) / 2 & -1;
    $83 = $82 + $top_077 | 0;
    HEAP32[$77 >> 2] = $83;
    $84 = $zone4_175 + 8 | 0;
    HEAP32[$84 >> 2] = $83;
    label = 22;
    break;
   case 21:
    $86 = $top_077 + $fuzz | 0;
    $87 = $zone4_175 + 8 | 0;
    HEAP32[$87 >> 2] = $86;
    $88 = $78 - $fuzz | 0;
    HEAP32[$77 >> 2] = $88;
    label = 22;
    break;
   case 22:
    $90 = $zone4_175 + 40 | 0;
    $_3 = $_376 - 1 | 0;
    $top_0 = HEAP32[$90 >> 2] | 0;
    $91 = ($_3 | 0) == 0;
    if ($91) {
      label = 23;
      break;
    } else {
      $zone4_175 = $76;
      $_376 = $_3;
      $top_077 = $top_0;
      label = 19;
      break;
    }
   case 23:
    $scevgep94 = $scevgep95;
    $zone4_1_lcssa = $scevgep94;
    $top_0_lcssa = $top_0;
    label = 24;
    break;
   case 24:
    $93 = $top_0_lcssa + $fuzz | 0;
    $94 = $zone4_1_lcssa + 8 | 0;
    HEAP32[$94 >> 2] = $93;
    label = 25;
    break;
   case 25:
    $zone4_083_1 = $bot_table_0 + 4 | 0;
    $96 = ($12 | 0) == 0;
    if ($96) {
      label = 34;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $98 = $bot_table_0 + 16 | 0;
    $99 = HEAP32[$98 >> 2] | 0;
    $100 = $99 - $fuzz | 0;
    HEAP32[$98 >> 2] = $100;
    $101 = $bot_table_0 + 12 | 0;
    $_373_1 = $12 - 1 | 0;
    $top_074_1 = HEAP32[$101 >> 2] | 0;
    $102 = ($_373_1 | 0) == 0;
    if ($102) {
      $zone4_1_lcssa_1 = $zone4_083_1;
      $top_0_lcssa_1 = $top_074_1;
      label = 33;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $uglygep_1 = $bot_table_0 - 516 + 488 | 0;
    $103 = $12 << 3;
    $scevgep_196 = $uglygep_1 + ($103 << 2) | 0;
    $zone4_175_1 = $zone4_083_1;
    $_376_1 = $_373_1;
    $top_077_1 = $top_074_1;
    label = 28;
    break;
   case 28:
    $105 = $zone4_175_1 + 32 | 0;
    $106 = $zone4_175_1 + 44 | 0;
    $107 = HEAP32[$106 >> 2] | 0;
    $108 = $107 - $top_077_1 | 0;
    $109 = ($108 | 0) < ($66 | 0);
    if ($109) {
      label = 30;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    $111 = $top_077_1 + $fuzz | 0;
    $112 = $zone4_175_1 + 8 | 0;
    HEAP32[$112 >> 2] = $111;
    $113 = $107 - $fuzz | 0;
    HEAP32[$106 >> 2] = $113;
    label = 31;
    break;
   case 30:
    $115 = ($108 | 0) / 2 & -1;
    $116 = $115 + $top_077_1 | 0;
    HEAP32[$106 >> 2] = $116;
    $117 = $zone4_175_1 + 8 | 0;
    HEAP32[$117 >> 2] = $116;
    label = 31;
    break;
   case 31:
    $119 = $zone4_175_1 + 40 | 0;
    $_3_1 = $_376_1 - 1 | 0;
    $top_0_1 = HEAP32[$119 >> 2] | 0;
    $120 = ($_3_1 | 0) == 0;
    if ($120) {
      label = 32;
      break;
    } else {
      $zone4_175_1 = $105;
      $_376_1 = $_3_1;
      $top_077_1 = $top_0_1;
      label = 28;
      break;
    }
   case 32:
    $scevgep94_1 = $scevgep_196;
    $zone4_1_lcssa_1 = $scevgep94_1;
    $top_0_lcssa_1 = $top_0_1;
    label = 33;
    break;
   case 33:
    $122 = $top_0_lcssa_1 + $fuzz | 0;
    $123 = $zone4_1_lcssa_1 + 8 | 0;
    HEAP32[$123 >> 2] = $122;
    label = 34;
    break;
   case 34:
    return;
  }
}
function _psh_blues_set_zones_0($is_others, $read_count, $read, $top_table, $bot_table) {
  $is_others = $is_others | 0;
  $read_count = $read_count | 0;
  $read = $read | 0;
  $top_table = $top_table | 0;
  $bot_table = $bot_table | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_013 = 0, $first_012 = 0, $count_bot_010 = 0, $count_top_08 = 0, $_0417 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $first_1 = 0, $reference_0 = 0, $delta_0 = 0, $count_0 = 0, $bot_table_pn = 0, $top_0 = 0, $zones_0 = 0, $23 = 0, $zone_03 = 0, $count_12 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $37 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $count_25 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $zone_0_lcssa23 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $56 = 0, $count_top_1 = 0, $count_bot_1 = 0, $58 = 0, $59 = 0, $60 = 0, $count_bot_0_lcssa = 0, $count_top_0_lcssa = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $top_table | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $bot_table | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $read_count >>> 0 > 1;
    if ($5) {
      $_0417 = $read;
      $count_top_08 = $2;
      $count_bot_010 = $4;
      $first_012 = 1;
      $_013 = $read_count;
      label = 2;
      break;
    } else {
      $count_top_0_lcssa = $2;
      $count_bot_0_lcssa = $4;
      label = 20;
      break;
    }
   case 2:
    $6 = $first_012 | $is_others;
    $7 = $6 << 24 >> 24 == 0;
    if ($7) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = $_0417 + 2 | 0;
    $10 = HEAP16[$9 >> 1] | 0;
    $11 = $10 << 16 >> 16;
    $12 = HEAP16[$_0417 >> 1] | 0;
    $13 = $12 << 16 >> 16;
    $14 = $13 - $11 | 0;
    $top_0 = 0;
    $bot_table_pn = $bot_table;
    $count_0 = $count_bot_010;
    $delta_0 = $14;
    $reference_0 = $11;
    $first_1 = 0;
    label = 5;
    break;
   case 4:
    $16 = HEAP16[$_0417 >> 1] | 0;
    $17 = $16 << 16 >> 16;
    $18 = $_0417 + 2 | 0;
    $19 = HEAP16[$18 >> 1] | 0;
    $20 = $19 << 16 >> 16;
    $21 = $20 - $17 | 0;
    $top_0 = 1;
    $bot_table_pn = $top_table;
    $count_0 = $count_top_08;
    $delta_0 = $21;
    $reference_0 = $17;
    $first_1 = $first_012;
    label = 5;
    break;
   case 5:
    $zones_0 = $bot_table_pn + 4 | 0;
    $23 = ($count_0 | 0) == 0;
    if ($23) {
      $zone_0_lcssa23 = $zones_0;
      label = 16;
      break;
    } else {
      $count_12 = $count_0;
      $zone_03 = $zones_0;
      label = 6;
      break;
    }
   case 6:
    $24 = $zone_03 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = ($reference_0 | 0) < ($25 | 0);
    if ($26) {
      label = 14;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $28 = ($reference_0 | 0) == ($25 | 0);
    if ($28) {
      label = 8;
      break;
    } else {
      label = 13;
      break;
    }
   case 8:
    $30 = $zone_03 + 4 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = ($delta_0 | 0) < 0;
    if ($32) {
      label = 9;
      break;
    } else {
      label = 11;
      break;
    }
   case 9:
    $34 = ($delta_0 | 0) < ($31 | 0);
    if ($34) {
      label = 10;
      break;
    } else {
      $count_bot_1 = $count_bot_010;
      $count_top_1 = $count_top_08;
      label = 19;
      break;
    }
   case 10:
    HEAP32[$30 >> 2] = $delta_0;
    $count_bot_1 = $count_bot_010;
    $count_top_1 = $count_top_08;
    label = 19;
    break;
   case 11:
    $37 = ($delta_0 | 0) > ($31 | 0);
    if ($37) {
      label = 12;
      break;
    } else {
      $count_bot_1 = $count_bot_010;
      $count_top_1 = $count_top_08;
      label = 19;
      break;
    }
   case 12:
    HEAP32[$30 >> 2] = $delta_0;
    $count_bot_1 = $count_bot_010;
    $count_top_1 = $count_top_08;
    label = 19;
    break;
   case 13:
    $40 = $count_12 - 1 | 0;
    $41 = $zone_03 + 32 | 0;
    $42 = ($40 | 0) == 0;
    if ($42) {
      $zone_0_lcssa23 = $41;
      label = 16;
      break;
    } else {
      $count_12 = $40;
      $zone_03 = $41;
      label = 6;
      break;
    }
   case 14:
    $43 = ($count_12 | 0) == 0;
    if ($43) {
      $zone_0_lcssa23 = $zone_03;
      label = 16;
      break;
    } else {
      $count_25 = $count_12;
      label = 15;
      break;
    }
   case 15:
    $44 = $zone_03 + ($count_25 << 5) | 0;
    $45 = $count_25 - 1 | 0;
    $46 = $zone_03 + ($45 << 5) | 0;
    $47 = $44;
    $48 = $46;
    _memcpy($47 | 0, $48 | 0, 32);
    $49 = ($45 | 0) == 0;
    if ($49) {
      $zone_0_lcssa23 = $zone_03;
      label = 16;
      break;
    } else {
      $count_25 = $45;
      label = 15;
      break;
    }
   case 16:
    $50 = $zone_0_lcssa23 | 0;
    HEAP32[$50 >> 2] = $reference_0;
    $51 = $zone_0_lcssa23 + 4 | 0;
    HEAP32[$51 >> 2] = $delta_0;
    $52 = $top_0 << 24 >> 24 == 0;
    if ($52) {
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $54 = $count_top_08 + 1 | 0;
    $count_bot_1 = $count_bot_010;
    $count_top_1 = $54;
    label = 19;
    break;
   case 18:
    $56 = $count_bot_010 + 1 | 0;
    $count_bot_1 = $56;
    $count_top_1 = $count_top_08;
    label = 19;
    break;
   case 19:
    $58 = $_0417 + 4 | 0;
    $59 = $_013 - 2 | 0;
    $60 = $59 >>> 0 > 1;
    if ($60) {
      $_0417 = $58;
      $count_top_08 = $count_top_1;
      $count_bot_010 = $count_bot_1;
      $first_012 = $first_1;
      $_013 = $59;
      label = 2;
      break;
    } else {
      $count_top_0_lcssa = $count_top_1;
      $count_bot_0_lcssa = $count_bot_1;
      label = 20;
      break;
    }
   case 20:
    HEAP32[$1 >> 2] = $count_top_0_lcssa;
    HEAP32[$3 >> 2] = $count_bot_0_lcssa;
    return;
  }
}
function _psh_hint_table_done($table, $memory) {
  $table = $table | 0;
  $memory = $memory | 0;
  var $1 = 0, $6 = 0, $9 = 0;
  $1 = $table + 24 | 0;
  _ft_mem_free($memory, HEAP32[$1 >> 2] | 0);
  HEAP32[$1 >> 2] = 0;
  HEAP32[$table + 20 >> 2] = 0;
  HEAP32[$table + 28 >> 2] = 0;
  $6 = $table + 12 | 0;
  _ft_mem_free($memory, HEAP32[$6 >> 2] | 0);
  HEAP32[$6 >> 2] = 0;
  $9 = $table + 8 | 0;
  _ft_mem_free($memory, HEAP32[$9 >> 2] | 0);
  HEAP32[$9 >> 2] = 0;
  HEAP32[$table + 4 >> 2] = 0;
  HEAP32[$table >> 2] = 0;
  HEAP32[$table + 16 >> 2] = 0;
  return;
}
function _psh_hint_table_activate_mask($table, $hint_mask) {
  $table = $table | 0;
  $hint_mask = $hint_mask | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mask_040 = 0, $val_039 = 0, $cursor_038 = 0, $idx_037 = 0, $count_036 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $cursor_1 = 0, $val_1 = 0, $mask_1 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $count_1 = 0, $35 = 0, $36 = 0, $exitcond45 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $i1_032 = 0, $41 = 0, $42 = 0, $43 = 0, $i2_031_in = 0, $i2_031 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $53 = 0, $54 = 0, $exitcond = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hint_mask + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $hint_mask | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    _psh_hint_table_deactivate($table);
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $6 = $table + 4 | 0;
    HEAP32[$6 >> 2] = 0;
    label = 16;
    break;
   case 3:
    $7 = $table + 8 | 0;
    $8 = $table | 0;
    $9 = $table + 12 | 0;
    $count_036 = 0;
    $idx_037 = 0;
    $cursor_038 = $2;
    $val_039 = 0;
    $mask_040 = 0;
    label = 4;
    break;
   case 4:
    $11 = ($mask_040 | 0) == 0;
    if ($11) {
      label = 5;
      break;
    } else {
      $mask_1 = $mask_040;
      $val_1 = $val_039;
      $cursor_1 = $cursor_038;
      label = 6;
      break;
    }
   case 5:
    $13 = $cursor_038 + 1 | 0;
    $14 = HEAP8[$cursor_038] | 0;
    $15 = $14 & 255;
    $mask_1 = 128;
    $val_1 = $15;
    $cursor_1 = $13;
    label = 6;
    break;
   case 6:
    $17 = $mask_1 & $val_1;
    $18 = ($17 | 0) == 0;
    if ($18) {
      $count_1 = $count_036;
      label = 10;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $20 = HEAP32[$7 >> 2] | 0;
    $21 = $20 + ($idx_037 * 28 & -1) | 0;
    $22 = $20 + ($idx_037 * 28 & -1) + 16 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $23 & 4;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 8;
      break;
    } else {
      $count_1 = $count_036;
      label = 10;
      break;
    }
   case 8:
    $27 = $23 | 4;
    HEAP32[$22 >> 2] = $27;
    $28 = HEAP32[$8 >> 2] | 0;
    $29 = $count_036 >>> 0 < $28 >>> 0;
    if ($29) {
      label = 9;
      break;
    } else {
      $count_1 = $count_036;
      label = 10;
      break;
    }
   case 9:
    $31 = $count_036 + 1 | 0;
    $32 = HEAP32[$9 >> 2] | 0;
    $33 = $32 + ($count_036 << 2) | 0;
    HEAP32[$33 >> 2] = $21;
    $count_1 = $31;
    label = 10;
    break;
   case 10:
    $35 = $mask_1 >> 1;
    $36 = $idx_037 + 1 | 0;
    $exitcond45 = ($36 | 0) == ($4 | 0);
    if ($exitcond45) {
      label = 11;
      break;
    } else {
      $count_036 = $count_1;
      $idx_037 = $36;
      $cursor_038 = $cursor_1;
      $val_039 = $val_1;
      $mask_040 = $35;
      label = 4;
      break;
    }
   case 11:
    $37 = $table + 4 | 0;
    HEAP32[$37 >> 2] = $count_1;
    $38 = $table + 12 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = ($count_1 | 0) > 1;
    if ($40) {
      $i1_032 = 1;
      label = 12;
      break;
    } else {
      label = 16;
      break;
    }
   case 12:
    $41 = $39 + ($i1_032 << 2) | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = $42 | 0;
    $i2_031_in = $i1_032;
    label = 13;
    break;
   case 13:
    $i2_031 = $i2_031_in - 1 | 0;
    $45 = $39 + ($i2_031 << 2) | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $46 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = HEAP32[$43 >> 2] | 0;
    $50 = ($48 | 0) < ($49 | 0);
    if ($50) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $52 = $39 + ($i2_031_in << 2) | 0;
    HEAP32[$52 >> 2] = $46;
    HEAP32[$45 >> 2] = $42;
    $53 = ($i2_031 | 0) > 0;
    if ($53) {
      $i2_031_in = $i2_031;
      label = 13;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $54 = $i1_032 + 1 | 0;
    $exitcond = ($54 | 0) == ($count_1 | 0);
    if ($exitcond) {
      label = 16;
      break;
    } else {
      $i1_032 = $54;
      label = 12;
      break;
    }
   case 16:
    return;
  }
}
function _psh_hint_snap_stem_side_delta($pos, $len) {
  $pos = $pos | 0;
  $len = $len | 0;
  var $3 = 0, $8 = 0;
  $3 = ($pos + 32 & -64) - $pos | 0;
  $8 = ((($pos + 32 | 0) + $len & -64) - $pos | 0) - $len | 0;
  return (((($3 | 0) < 0 ? -$3 | 0 : $3) | 0) > ((($8 | 0) < 0 ? -$8 | 0 : $8) | 0) ? $8 : $3) | 0;
}
function _psh_compute_dir($dx, $dy) {
  $dx = $dx | 0;
  $dy = $dy | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($dx | 0) > -1;
    $2 = -$dx | 0;
    $3 = $1 ? $dx : $2;
    $4 = ($dy | 0) > -1;
    $5 = -$dy | 0;
    $6 = $4 ? $dy : $5;
    $7 = $6 * 12 & -1;
    $8 = ($7 | 0) < ($3 | 0);
    if ($8) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $10 = $dx >> 31;
    $11 = $10 & -4;
    $12 = $11 | 2;
    $result_0 = $12;
    label = 5;
    break;
   case 3:
    $14 = $3 * 12 & -1;
    $15 = ($14 | 0) < ($6 | 0);
    if ($15) {
      label = 4;
      break;
    } else {
      $result_0 = 4;
      label = 5;
      break;
    }
   case 4:
    $17 = $dy >> 31;
    $18 = $17 & 2;
    $19 = $18 - 1 | 0;
    $result_0 = $19;
    label = 5;
    break;
   case 5:
    return $result_0 | 0;
  }
  return 0;
}
function _psh_blues_snap_stem($blues, $stem_top, $stem_bot, $alignment) {
  $blues = $blues | 0;
  $stem_top = $stem_top | 0;
  $stem_bot = $stem_bot | 0;
  $alignment = $alignment | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $zone_043 = 0, $count_042 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $_sum = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $zone_138 = 0, $count_137 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $69 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $alignment | 0;
    HEAP32[$1 >> 2] = 0;
    $2 = $blues + 2080 | 0;
    $3 = HEAP8[$2] | 0;
    $4 = $blues | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 9;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $blues + 4 | 0;
    $8 = $blues + 2076 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = -$9 | 0;
    $count_042 = $5;
    $zone_043 = $7;
    label = 3;
    break;
   case 3:
    $12 = $zone_043 + 12 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $stem_top - $13 | 0;
    $15 = ($14 | 0) < ($10 | 0);
    if ($15) {
      label = 9;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $17 = $zone_043 + 8 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $18 + $9 | 0;
    $20 = ($19 | 0) < ($stem_top | 0);
    if ($20) {
      label = 8;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $22 = $3 << 24 >> 24 == 0;
    if ($22) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $24 = $blues + 2072 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = ($14 | 0) > ($25 | 0);
    if ($26) {
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $28 = HEAP32[$1 >> 2] | 0;
    $29 = $28 | 1;
    HEAP32[$1 >> 2] = $29;
    $30 = $zone_043 + 16 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $alignment + 4 | 0;
    HEAP32[$32 >> 2] = $31;
    label = 9;
    break;
   case 8:
    $34 = $count_042 - 1 | 0;
    $35 = $zone_043 + 32 | 0;
    $36 = ($34 | 0) == 0;
    if ($36) {
      label = 9;
      break;
    } else {
      $count_042 = $34;
      $zone_043 = $35;
      label = 3;
      break;
    }
   case 9:
    $37 = $blues + 516 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = ($38 | 0) == 0;
    if ($39) {
      label = 17;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $_sum = $38 - 1 | 0;
    $40 = $blues + 520 + ($_sum << 5) | 0;
    $41 = $blues + 2076 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = -$42 | 0;
    $count_137 = $38;
    $zone_138 = $40;
    label = 11;
    break;
   case 11:
    $45 = $zone_138 + 8 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $46 - $stem_bot | 0;
    $48 = ($47 | 0) < ($43 | 0);
    if ($48) {
      label = 17;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $50 = $zone_138 + 12 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = $51 - $42 | 0;
    $53 = ($52 | 0) > ($stem_bot | 0);
    if ($53) {
      label = 16;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $55 = $3 << 24 >> 24 == 0;
    if ($55) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $57 = $blues + 2072 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = ($47 | 0) < ($58 | 0);
    if ($59) {
      label = 15;
      break;
    } else {
      label = 17;
      break;
    }
   case 15:
    $61 = HEAP32[$1 >> 2] | 0;
    $62 = $61 | 2;
    HEAP32[$1 >> 2] = $62;
    $63 = $zone_138 + 16 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = $alignment + 8 | 0;
    HEAP32[$65 >> 2] = $64;
    label = 17;
    break;
   case 16:
    $67 = $count_137 - 1 | 0;
    $68 = $zone_138 - 32 | 0;
    $69 = ($67 | 0) == 0;
    if ($69) {
      label = 17;
      break;
    } else {
      $count_137 = $67;
      $zone_138 = $68;
      label = 11;
      break;
    }
   case 17:
    return;
  }
}
function _psh_dimension_quantize_len($dim, $len) {
  $dim = $dim | 0;
  $len = $len | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_ = 0, $8 = 0, $10 = 0, $_2 = 0, $_0 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $20 = 0, $22 = 0, $23 = 0, $__0 = 0, $25 = 0, $26 = 0, $_1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($len | 0) < 65;
    if ($1) {
      $_1 = 64;
      label = 10;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $dim + 8 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $len - $4 | 0;
    $6 = ($5 | 0) < 0;
    $7 = -$5 | 0;
    $_ = $6 ? $7 : $5;
    $8 = ($_ | 0) < 40;
    if ($8) {
      label = 3;
      break;
    } else {
      $_0 = $len;
      label = 4;
      break;
    }
   case 3:
    $10 = ($4 | 0) < 48;
    $_2 = $10 ? 48 : $4;
    $_0 = $_2;
    label = 4;
    break;
   case 4:
    $12 = ($_0 | 0) < 192;
    if ($12) {
      label = 5;
      break;
    } else {
      label = 9;
      break;
    }
   case 5:
    $14 = $_0 & 63;
    $15 = $_0 & -64;
    $16 = $14 >>> 0 < 10;
    if ($16) {
      $_1 = $_0;
      label = 10;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $18 = $14 >>> 0 < 32;
    if ($18) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $20 = $15 | 10;
    $_1 = $20;
    label = 10;
    break;
   case 8:
    $22 = $14 >>> 0 < 54;
    $23 = $15 | 54;
    $__0 = $22 ? $23 : $_0;
    return $__0 | 0;
   case 9:
    $25 = $_0 + 32 | 0;
    $26 = $25 & -64;
    $_1 = $26;
    label = 10;
    break;
   case 10:
    return $_1 | 0;
  }
  return 0;
}
function _psh_hint_align($hint, $globals, $dimension, $glyph) {
  $hint = $hint | 0;
  $globals = $globals | 0;
  $dimension = $dimension | 0;
  $glyph = $glyph | 0;
  var $align = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $_not102 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $sum = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $pos_0 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $99 = 0, $101 = 0, $103 = 0, $104 = 0, $105 = 0, $107 = 0, $108 = 0, $109 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $left_disp_0 = 0, $118 = 0, $119 = 0, $_ = 0, $120 = 0, $_95 = 0, $122 = 0, $len_0 = 0, $pos_1 = 0, $124 = 0, $125 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $133 = 0, $134 = 0, $len_1 = 0, $136 = 0, $138 = 0, $139 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $147 = 0, $148 = 0, $150 = 0, $151 = 0, $pos_2 = 0, $153 = 0, $155 = 0, $156 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $align = __stackBase__ | 0;
    $1 = $globals + 4 + ($dimension * 204 & -1) | 0;
    $2 = $globals + 4 + ($dimension * 204 & -1) + 196 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $hint + 16 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 & 8;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 2;
      break;
    } else {
      label = 37;
      break;
    }
   case 2:
    $9 = $globals + 4 + ($dimension * 204 & -1) + 200 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $hint | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = _FT_MulFix($12, $3) | 0;
    $14 = $13 + $10 | 0;
    $15 = $hint + 4 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = _FT_MulFix($16, $3) | 0;
    if (($dimension | 0) == 0) {
      label = 3;
      break;
    } else if (($dimension | 0) == 1) {
      label = 5;
      break;
    } else {
      $37 = 0;
      $36 = 0;
      label = 8;
      break;
    }
   case 3:
    $19 = $glyph + 120 | 0;
    $20 = HEAP8[$19] | 0;
    $21 = $20 << 24 >> 24 == 0;
    if ($21) {
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $22 = $glyph + 122 | 0;
    $23 = HEAP8[$22] | 0;
    $_not102 = $23 << 24 >> 24 != 0;
    $37 = $_not102;
    $36 = 0;
    label = 8;
    break;
   case 5:
    $25 = $glyph + 121 | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 << 24 >> 24 == 0;
    if ($27) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $29 = $hint + 8 | 0;
    HEAP32[$29 >> 2] = $14;
    $30 = $hint + 12 | 0;
    HEAP32[$30 >> 2] = $17;
    $31 = HEAP32[$4 >> 2] | 0;
    $32 = $31 | 8;
    HEAP32[$4 >> 2] = $32;
    label = 37;
    break;
   case 7:
    $33 = $glyph + 123 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 << 24 >> 24 != 0;
    $37 = $35;
    $36 = 1;
    label = 8;
    break;
   case 8:
    $38 = $hint + 12 | 0;
    HEAP32[$38 >> 2] = $17;
    $39 = $align | 0;
    HEAP32[$39 >> 2] = 0;
    $40 = $align + 4 | 0;
    HEAP32[$40 >> 2] = 0;
    $41 = $align + 8 | 0;
    HEAP32[$41 >> 2] = 0;
    if ($36) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $43 = $globals + 412 | 0;
    $44 = HEAP32[$11 >> 2] | 0;
    $45 = HEAP32[$15 >> 2] | 0;
    $46 = $45 + $44 | 0;
    _psh_blues_snap_stem($43, $46, $44, $align);
    label = 10;
    break;
   case 10:
    $48 = HEAP32[$39 >> 2] | 0;
    if (($48 | 0) == 1) {
      label = 11;
      break;
    } else if (($48 | 0) == 2) {
      label = 12;
      break;
    } else if (($48 | 0) == 3) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 11:
    $50 = HEAP32[$40 >> 2] | 0;
    $51 = $50 - $17 | 0;
    $52 = $hint + 8 | 0;
    HEAP32[$52 >> 2] = $51;
    label = 26;
    break;
   case 12:
    $54 = HEAP32[$41 >> 2] | 0;
    $55 = $hint + 8 | 0;
    HEAP32[$55 >> 2] = $54;
    label = 26;
    break;
   case 13:
    $57 = HEAP32[$41 >> 2] | 0;
    $58 = $hint + 8 | 0;
    HEAP32[$58 >> 2] = $57;
    $59 = HEAP32[$40 >> 2] | 0;
    $60 = HEAP32[$41 >> 2] | 0;
    $61 = $59 - $60 | 0;
    HEAP32[$38 >> 2] = $61;
    label = 26;
    break;
   case 14:
    $63 = $hint + 20 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = ($64 | 0) == 0;
    if ($65) {
      $pos_0 = $14;
      label = 18;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $67 = $64 + 16 | 0;
    $68 = HEAP32[$67 >> 2] | 0;
    $69 = $68 & 8;
    $70 = ($69 | 0) == 0;
    if ($70) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    _psh_hint_align($64, $globals, $dimension, $glyph);
    label = 17;
    break;
   case 17:
    $73 = $64 | 0;
    $74 = HEAP32[$73 >> 2] | 0;
    $75 = $64 + 4 | 0;
    $76 = HEAP32[$75 >> 2] | 0;
    $77 = $76 >> 1;
    $78 = $64 + 8 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = $64 + 12 | 0;
    $81 = HEAP32[$80 >> 2] | 0;
    $82 = $81 >> 1;
    $83 = HEAP32[$11 >> 2] | 0;
    $84 = HEAP32[$15 >> 2] | 0;
    $85 = $84 >> 1;
    $sum = $77 + $74 | 0;
    $86 = $83 - $sum | 0;
    $87 = $86 + $85 | 0;
    $88 = _FT_MulFix($87, $3) | 0;
    $89 = $17 >> 1;
    $90 = $79 - $89 | 0;
    $91 = $90 + $82 | 0;
    $92 = $91 + $88 | 0;
    $pos_0 = $92;
    label = 18;
    break;
   case 18:
    $94 = $hint + 8 | 0;
    HEAP32[$94 >> 2] = $pos_0;
    HEAP32[$38 >> 2] = $17;
    $95 = $glyph + 124 | 0;
    $96 = HEAP8[$95] | 0;
    $97 = $96 << 24 >> 24 == 0;
    if ($97) {
      $pos_1 = $pos_0;
      $len_0 = $17;
      label = 25;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $99 = ($17 | 0) < 65;
    if ($99) {
      label = 20;
      break;
    } else {
      label = 24;
      break;
    }
   case 20:
    $101 = ($17 | 0) > 31;
    if ($101) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    $103 = $17 >> 1;
    $104 = $pos_0 + $103 | 0;
    $105 = $104 & -64;
    $pos_1 = $105;
    $len_0 = 64;
    label = 25;
    break;
   case 22:
    $107 = ($17 | 0) > 0;
    $108 = $pos_0 + 32 | 0;
    $109 = $108 & -64;
    if ($107) {
      label = 23;
      break;
    } else {
      $pos_1 = $109;
      $len_0 = $17;
      label = 25;
      break;
    }
   case 23:
    $111 = $pos_0 + $17 | 0;
    $112 = $111 + 32 | 0;
    $113 = $112 & -64;
    $114 = $109 - $pos_0 | 0;
    $115 = $113 - $111 | 0;
    $116 = ($114 | 0) < 0;
    $117 = -$114 | 0;
    $left_disp_0 = $116 ? $117 : $114;
    $118 = ($115 | 0) < 0;
    $119 = -$115 | 0;
    $_ = $118 ? $119 : $115;
    $120 = ($left_disp_0 | 0) > ($_ | 0);
    $_95 = $120 ? $113 : $109;
    $pos_1 = $_95;
    $len_0 = $17;
    label = 25;
    break;
   case 24:
    $122 = _psh_dimension_quantize_len($1, $17) | 0;
    $pos_1 = $pos_0;
    $len_0 = $122;
    label = 25;
    break;
   case 25:
    $124 = _psh_hint_snap_stem_side_delta($pos_1, $len_0) | 0;
    $125 = $124 + $pos_1 | 0;
    HEAP32[$94 >> 2] = $125;
    HEAP32[$38 >> 2] = $len_0;
    label = 26;
    break;
   case 26:
    if ($37) {
      label = 27;
      break;
    } else {
      label = 36;
      break;
    }
   case 27:
    $128 = $hint + 8 | 0;
    $129 = HEAP32[$128 >> 2] | 0;
    $130 = HEAP32[$38 >> 2] | 0;
    $131 = ($130 | 0) < 64;
    if ($131) {
      $len_1 = 64;
      label = 29;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $133 = $130 + 32 | 0;
    $134 = $133 & -64;
    $len_1 = $134;
    label = 29;
    break;
   case 29:
    $136 = HEAP32[$39 >> 2] | 0;
    if (($136 | 0) == 1) {
      label = 30;
      break;
    } else if (($136 | 0) == 2) {
      label = 31;
      break;
    } else if (($136 | 0) == 3) {
      label = 36;
      break;
    } else {
      label = 32;
      break;
    }
   case 30:
    $138 = HEAP32[$40 >> 2] | 0;
    $139 = $138 - $len_1 | 0;
    HEAP32[$128 >> 2] = $139;
    HEAP32[$38 >> 2] = $len_1;
    label = 36;
    break;
   case 31:
    HEAP32[$38 >> 2] = $len_1;
    label = 36;
    break;
   case 32:
    HEAP32[$38 >> 2] = $len_1;
    $142 = $len_1 & 64;
    $143 = ($142 | 0) == 0;
    $144 = $len_1 >> 1;
    $145 = $144 + $129 | 0;
    if ($143) {
      label = 34;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    $147 = $145 & -64;
    $148 = $147 | 32;
    $pos_2 = $148;
    label = 35;
    break;
   case 34:
    $150 = $145 + 32 | 0;
    $151 = $150 & -64;
    $pos_2 = $151;
    label = 35;
    break;
   case 35:
    $153 = $pos_2 - $144 | 0;
    HEAP32[$128 >> 2] = $153;
    HEAP32[$38 >> 2] = $len_1;
    label = 36;
    break;
   case 36:
    $155 = HEAP32[$4 >> 2] | 0;
    $156 = $155 | 8;
    HEAP32[$4 >> 2] = $156;
    label = 37;
    break;
   case 37:
    STACKTOP = __stackBase__;
    return;
  }
}
function _psh_globals_scale_widths($globals, $direction) {
  $globals = $globals | 0;
  $direction = $direction | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $count_022 = 0, $14 = 0, $15 = 0, $count_024 = 0, $width_023 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $dist_0 = 0, $24 = 0, $_ = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $count_0 = 0, $30 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $globals + 4 + ($direction * 204 & -1) | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $globals + 4 + ($direction * 204 & -1) + 196 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) == 0;
    if ($5) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $globals + 4 + ($direction * 204 & -1) + 4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = _FT_MulFix($8, $4) | 0;
    $10 = $globals + 4 + ($direction * 204 & -1) + 8 | 0;
    HEAP32[$10 >> 2] = $9;
    $11 = $9 + 32 | 0;
    $12 = $11 & -64;
    $13 = $globals + 4 + ($direction * 204 & -1) + 12 | 0;
    HEAP32[$13 >> 2] = $12;
    $count_022 = $2 - 1 | 0;
    $14 = ($count_022 | 0) == 0;
    if ($14) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $15 = $globals + 4 + ($direction * 204 & -1) + 16 | 0;
    $width_023 = $15;
    $count_024 = $count_022;
    label = 4;
    break;
   case 4:
    $17 = $width_023 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = _FT_MulFix($18, $4) | 0;
    $20 = HEAP32[$10 >> 2] | 0;
    $21 = $19 - $20 | 0;
    $22 = ($21 | 0) < 0;
    $23 = -$21 | 0;
    $dist_0 = $22 ? $23 : $21;
    $24 = ($dist_0 | 0) < 128;
    $_ = $24 ? $20 : $19;
    $25 = $width_023 + 4 | 0;
    HEAP32[$25 >> 2] = $_;
    $26 = $_ + 32 | 0;
    $27 = $26 & -64;
    $28 = $width_023 + 8 | 0;
    HEAP32[$28 >> 2] = $27;
    $29 = $width_023 + 12 | 0;
    $count_0 = $count_024 - 1 | 0;
    $30 = ($count_0 | 0) == 0;
    if ($30) {
      label = 5;
      break;
    } else {
      $width_023 = $29;
      $count_024 = $count_0;
      label = 4;
      break;
    }
   case 5:
    return;
  }
}
function _psh_blues_scale_zones($blues, $scale, $delta) {
  $blues = $blues | 0;
  $scale = $scale | 0;
  $delta = $delta | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $threshold_0 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $num_071 = 0, $table_0 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $zone_067 = 0, $count_066 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $exitcond = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $count1_063 = 0, $zone1_062 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $count2_061 = 0, $zone2_060 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $Delta_0 = 0, $86 = 0, $87 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $count1_063_1 = 0, $zone1_062_1 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $count2_061_1 = 0, $zone2_060_1 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $Delta_0_1 = 0, $125 = 0, $126 = 0, $128 = 0, $129 = 0, $130 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($scale | 0) > 34359737;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = $blues + 2064 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 << 3;
    $6 = ($5 | 0) / 125 & -1;
    $7 = ($6 | 0) > ($scale | 0);
    $8 = $7 & 1;
    $9 = $blues + 2080 | 0;
    HEAP8[$9] = $8;
    label = 4;
    break;
   case 3:
    $11 = $scale * 125 & -1;
    $12 = $blues + 2064 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 << 3;
    $15 = ($11 | 0) < ($14 | 0);
    $16 = $15 & 1;
    $17 = $blues + 2080 | 0;
    HEAP8[$17] = $16;
    label = 4;
    break;
   case 4:
    $19 = $blues + 2068 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $threshold_0 = $20;
    label = 5;
    break;
   case 5:
    $22 = ($threshold_0 | 0) > 0;
    if ($22) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $24 = _FT_MulFix($threshold_0, $scale) | 0;
    $25 = ($24 | 0) > 32;
    $26 = $threshold_0 - 1 | 0;
    if ($25) {
      $threshold_0 = $26;
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $27 = $blues + 2072 | 0;
    HEAP32[$27 >> 2] = $threshold_0;
    $28 = $blues + 1548 | 0;
    $29 = $blues | 0;
    $30 = $blues + 516 | 0;
    $31 = $blues + 1032 | 0;
    $num_071 = 0;
    label = 8;
    break;
   case 8:
    if (($num_071 | 0) == 1) {
      label = 9;
      break;
    } else if (($num_071 | 0) == 2) {
      label = 10;
      break;
    } else if (($num_071 | 0) == 0) {
      $table_0 = $29;
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 9:
    $table_0 = $30;
    label = 12;
    break;
   case 10:
    $table_0 = $31;
    label = 12;
    break;
   case 11:
    $table_0 = $28;
    label = 12;
    break;
   case 12:
    $37 = $table_0 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = ($38 | 0) == 0;
    if ($39) {
      label = 15;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $40 = $table_0 + 4 | 0;
    $count_066 = $38;
    $zone_067 = $40;
    label = 14;
    break;
   case 14:
    $42 = $zone_067 + 8 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = _FT_MulFix($43, $scale) | 0;
    $45 = $44 + $delta | 0;
    $46 = $zone_067 + 28 | 0;
    HEAP32[$46 >> 2] = $45;
    $47 = $zone_067 + 12 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = _FT_MulFix($48, $scale) | 0;
    $50 = $49 + $delta | 0;
    $51 = $zone_067 + 24 | 0;
    HEAP32[$51 >> 2] = $50;
    $52 = $zone_067 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = _FT_MulFix($53, $scale) | 0;
    $55 = $54 + $delta | 0;
    $56 = $zone_067 + 16 | 0;
    HEAP32[$56 >> 2] = $55;
    $57 = $zone_067 + 4 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = _FT_MulFix($58, $scale) | 0;
    $60 = $zone_067 + 20 | 0;
    HEAP32[$60 >> 2] = $59;
    $61 = HEAP32[$56 >> 2] | 0;
    $62 = $61 + 32 | 0;
    $63 = $62 & -64;
    HEAP32[$56 >> 2] = $63;
    $64 = $count_066 - 1 | 0;
    $65 = $zone_067 + 32 | 0;
    $66 = ($64 | 0) == 0;
    if ($66) {
      label = 15;
      break;
    } else {
      $count_066 = $64;
      $zone_067 = $65;
      label = 14;
      break;
    }
   case 15:
    $67 = $num_071 + 1 | 0;
    $exitcond = ($67 | 0) == 4;
    if ($exitcond) {
      label = 16;
      break;
    } else {
      $num_071 = $67;
      label = 8;
      break;
    }
   case 16:
    $69 = $blues | 0;
    $70 = HEAP32[$69 >> 2] | 0;
    $71 = ($70 | 0) == 0;
    if ($71) {
      label = 24;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $72 = $blues + 4 | 0;
    $73 = $blues + 1036 | 0;
    $74 = $blues + 1032 | 0;
    $zone1_062 = $72;
    $count1_063 = $70;
    label = 18;
    break;
   case 18:
    $76 = HEAP32[$74 >> 2] | 0;
    $77 = ($76 | 0) == 0;
    if ($77) {
      label = 23;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $78 = $zone1_062 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $zone2_060 = $73;
    $count2_061 = $76;
    label = 20;
    break;
   case 20:
    $81 = $zone2_060 | 0;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = $79 - $82 | 0;
    $84 = ($83 | 0) < 0;
    $85 = -$83 | 0;
    $Delta_0 = $84 ? $85 : $83;
    $86 = _FT_MulFix($Delta_0, $scale) | 0;
    $87 = ($86 | 0) < 64;
    if ($87) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    $89 = $zone2_060 + 28 | 0;
    $90 = HEAP32[$89 >> 2] | 0;
    $91 = $zone1_062 + 28 | 0;
    HEAP32[$91 >> 2] = $90;
    $92 = $zone2_060 + 24 | 0;
    $93 = HEAP32[$92 >> 2] | 0;
    $94 = $zone1_062 + 24 | 0;
    HEAP32[$94 >> 2] = $93;
    $95 = $zone2_060 + 16 | 0;
    $96 = HEAP32[$95 >> 2] | 0;
    $97 = $zone1_062 + 16 | 0;
    HEAP32[$97 >> 2] = $96;
    $98 = $zone2_060 + 20 | 0;
    $99 = HEAP32[$98 >> 2] | 0;
    $100 = $zone1_062 + 20 | 0;
    HEAP32[$100 >> 2] = $99;
    label = 23;
    break;
   case 22:
    $102 = $count2_061 - 1 | 0;
    $103 = $zone2_060 + 32 | 0;
    $104 = ($102 | 0) == 0;
    if ($104) {
      label = 23;
      break;
    } else {
      $zone2_060 = $103;
      $count2_061 = $102;
      label = 20;
      break;
    }
   case 23:
    $105 = $count1_063 - 1 | 0;
    $106 = $zone1_062 + 32 | 0;
    $107 = ($105 | 0) == 0;
    if ($107) {
      label = 24;
      break;
    } else {
      $zone1_062 = $106;
      $count1_063 = $105;
      label = 18;
      break;
    }
   case 24:
    $108 = $blues + 516 | 0;
    $109 = HEAP32[$108 >> 2] | 0;
    $110 = ($109 | 0) == 0;
    if ($110) {
      label = 32;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $111 = $blues + 520 | 0;
    $112 = $blues + 1552 | 0;
    $113 = $blues + 1548 | 0;
    $zone1_062_1 = $111;
    $count1_063_1 = $109;
    label = 26;
    break;
   case 26:
    $115 = HEAP32[$113 >> 2] | 0;
    $116 = ($115 | 0) == 0;
    if ($116) {
      label = 31;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $117 = $zone1_062_1 | 0;
    $118 = HEAP32[$117 >> 2] | 0;
    $zone2_060_1 = $112;
    $count2_061_1 = $115;
    label = 28;
    break;
   case 28:
    $120 = $zone2_060_1 | 0;
    $121 = HEAP32[$120 >> 2] | 0;
    $122 = $118 - $121 | 0;
    $123 = ($122 | 0) < 0;
    $124 = -$122 | 0;
    $Delta_0_1 = $123 ? $124 : $122;
    $125 = _FT_MulFix($Delta_0_1, $scale) | 0;
    $126 = ($125 | 0) < 64;
    if ($126) {
      label = 30;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    $128 = $count2_061_1 - 1 | 0;
    $129 = $zone2_060_1 + 32 | 0;
    $130 = ($128 | 0) == 0;
    if ($130) {
      label = 31;
      break;
    } else {
      $zone2_060_1 = $129;
      $count2_061_1 = $128;
      label = 28;
      break;
    }
   case 30:
    $132 = $zone2_060_1 + 28 | 0;
    $133 = HEAP32[$132 >> 2] | 0;
    $134 = $zone1_062_1 + 28 | 0;
    HEAP32[$134 >> 2] = $133;
    $135 = $zone2_060_1 + 24 | 0;
    $136 = HEAP32[$135 >> 2] | 0;
    $137 = $zone1_062_1 + 24 | 0;
    HEAP32[$137 >> 2] = $136;
    $138 = $zone2_060_1 + 16 | 0;
    $139 = HEAP32[$138 >> 2] | 0;
    $140 = $zone1_062_1 + 16 | 0;
    HEAP32[$140 >> 2] = $139;
    $141 = $zone2_060_1 + 20 | 0;
    $142 = HEAP32[$141 >> 2] | 0;
    $143 = $zone1_062_1 + 20 | 0;
    HEAP32[$143 >> 2] = $142;
    label = 31;
    break;
   case 31:
    $144 = $count1_063_1 - 1 | 0;
    $145 = $zone1_062_1 + 32 | 0;
    $146 = ($144 | 0) == 0;
    if ($146) {
      label = 32;
      break;
    } else {
      $zone1_062_1 = $145;
      $count1_063_1 = $144;
      label = 26;
      break;
    }
   case 32:
    return;
  }
}
function _psh_glyph_compute_inflections($glyph) {
  $glyph = $glyph | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $n_071 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $end_0 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $or_cond = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $before_064 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $or_cond54 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $start_0 = 0, $end_1 = 0, $in_x_0 = 0, $in_y_0 = 0, $orient_prev_0 = 0, $after_0 = 0, $finished_1 = 0, $51 = 0, $52 = 0, $53 = 0, $_finished_1 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $or_cond55 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $start_1 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $80 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $glyph + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 19;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $glyph + 12 | 0;
    $n_071 = 0;
    label = 3;
    break;
   case 3:
    $6 = HEAP32[$4 >> 2] | 0;
    $7 = $6 + ($n_071 << 3) + 4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 >>> 0 < 4;
    if ($9) {
      label = 18;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $11 = $6 + ($n_071 << 3) | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + 36 | 0;
    $14 = $12 + 40 | 0;
    $end_0 = $12;
    label = 5;
    break;
   case 5:
    $16 = $end_0 + 4 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($17 | 0) == ($12 | 0);
    if ($18) {
      label = 18;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $20 = $17 + 36 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = HEAP32[$13 >> 2] | 0;
    $23 = $21 - $22 | 0;
    $24 = $17 + 40 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = HEAP32[$14 >> 2] | 0;
    $27 = $25 - $26 | 0;
    $28 = ($21 | 0) == ($22 | 0);
    $29 = ($25 | 0) == ($26 | 0);
    $or_cond = $28 & $29;
    if ($or_cond) {
      $end_0 = $17;
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $30 = $12 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = ($31 | 0) == ($12 | 0);
    if ($32) {
      label = 18;
      break;
    } else {
      $before_064 = $12;
      $33 = $31;
      label = 8;
      break;
    }
   case 8:
    $34 = $before_064 + 36 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $33 + 36 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $35 - $37 | 0;
    $39 = $before_064 + 40 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $33 + 40 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = $40 - $42 | 0;
    $44 = ($35 | 0) == ($37 | 0);
    $45 = ($40 | 0) == ($42 | 0);
    $or_cond54 = $44 & $45;
    if ($or_cond54) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $46 = _ft_corner_orientation($23, $27, $38, $43) | 0;
    $47 = ($46 | 0) == 0;
    if ($47) {
      label = 10;
      break;
    } else {
      $orient_prev_0 = $46;
      $in_y_0 = $43;
      $in_x_0 = $38;
      $end_1 = $17;
      $start_0 = $before_064;
      label = 11;
      break;
    }
   case 10:
    $48 = $33 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = ($49 | 0) == ($12 | 0);
    if ($50) {
      label = 18;
      break;
    } else {
      $before_064 = $33;
      $33 = $49;
      label = 8;
      break;
    }
   case 11:
    $finished_1 = 0;
    $after_0 = $end_1;
    label = 12;
    break;
   case 12:
    $51 = $after_0 + 4 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = ($52 | 0) == ($before_064 | 0);
    $_finished_1 = $53 ? 1 : $finished_1;
    $54 = $52 + 36 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = $after_0 + 36 | 0;
    $57 = HEAP32[$56 >> 2] | 0;
    $58 = $55 - $57 | 0;
    $59 = $52 + 40 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = $after_0 + 40 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = $60 - $62 | 0;
    $64 = ($55 | 0) == ($57 | 0);
    $65 = ($60 | 0) == ($62 | 0);
    $or_cond55 = $64 & $65;
    if ($or_cond55) {
      $finished_1 = $_finished_1;
      $after_0 = $52;
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $66 = _ft_corner_orientation($in_x_0, $in_y_0, $58, $63) | 0;
    $67 = ($66 | 0) == 0;
    if ($67) {
      $finished_1 = $_finished_1;
      $after_0 = $52;
      label = 12;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $69 = $66 ^ $orient_prev_0;
    $70 = ($69 | 0) < 0;
    if ($70) {
      $start_1 = $start_0;
      label = 15;
      break;
    } else {
      label = 17;
      break;
    }
   case 15:
    $71 = $start_1 + 12 | 0;
    $72 = HEAP32[$71 >> 2] | 0;
    $73 = $72 | 4;
    HEAP32[$71 >> 2] = $73;
    $74 = $start_1 + 4 | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    $76 = ($75 | 0) == ($after_0 | 0);
    if ($76) {
      label = 16;
      break;
    } else {
      $start_1 = $75;
      label = 15;
      break;
    }
   case 16:
    $78 = $75 + 12 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = $79 | 4;
    HEAP32[$78 >> 2] = $80;
    label = 17;
    break;
   case 17:
    $82 = ($_finished_1 | 0) == 0;
    if ($82) {
      $orient_prev_0 = $66;
      $in_y_0 = $63;
      $in_x_0 = $58;
      $end_1 = $52;
      $start_0 = $after_0;
      label = 11;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $83 = $n_071 + 1 | 0;
    $84 = HEAP32[$1 >> 2] | 0;
    $85 = $83 >>> 0 < $84 >>> 0;
    if ($85) {
      $n_071 = $83;
      label = 3;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    return;
  }
}
function _psh_hint_overlap($hint1, $hint2) {
  $hint1 = $hint1 | 0;
  $hint2 = $hint2 | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hint1 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $hint1 + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + $2 | 0;
    $6 = $hint2 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = ($5 | 0) < ($7 | 0);
    if ($8) {
      $15 = 0;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = $hint2 + 4 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 + $7 | 0;
    $13 = ($12 | 0) >= ($2 | 0);
    $15 = $13;
    label = 3;
    break;
   case 3:
    $16 = $15 & 1;
    return $16 | 0;
  }
  return 0;
}
function _ps_unicodes_char_index($table, $unicode) {
  $table = $table | 0;
  $unicode = $unicode | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_sum = 0, $5 = 0, $6 = 0, $result_0_ph27 = 0, $min_0_ph26 = 0, $max_0_ph25 = 0, $7 = 0, $result_021 = 0, $min_020 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $_result_0 = 0, $19 = 0, $21 = 0, $_sum18 = 0, $23 = 0, $24 = 0, $_sum17 = 0, $25 = 0, $26 = 0, $result_2 = 0, $27 = 0, $29 = 0, $30 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table + 20 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $table + 16 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $_sum = $4 - 1 | 0;
    $5 = ($_sum | 0) < 0;
    if ($5) {
      $_0 = 0;
      label = 11;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $2 + ($_sum << 3) | 0;
    $max_0_ph25 = $6;
    $min_0_ph26 = $2;
    $result_0_ph27 = 0;
    label = 3;
    break;
   case 3:
    $7 = $max_0_ph25;
    $min_020 = $min_0_ph26;
    $result_021 = $result_0_ph27;
    label = 4;
    break;
   case 4:
    $9 = $min_020;
    $10 = $7 - $9 | 0;
    $11 = $10 >> 4;
    $12 = $min_020 + ($11 << 3) | 0;
    $13 = $12 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($14 | 0) == ($unicode | 0);
    if ($15) {
      $result_2 = $12;
      label = 9;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = $14 & 2147483647;
    $18 = ($17 | 0) == ($unicode | 0);
    $_result_0 = $18 ? $12 : $result_021;
    $19 = ($min_020 | 0) == ($max_0_ph25 | 0);
    if ($19) {
      $result_2 = $_result_0;
      label = 9;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $21 = $17 >>> 0 < $unicode >>> 0;
    if ($21) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $_sum18 = $11 + 1 | 0;
    $23 = $min_020 + ($_sum18 << 3) | 0;
    $24 = $23 >>> 0 > $max_0_ph25 >>> 0;
    if ($24) {
      $result_2 = $_result_0;
      label = 9;
      break;
    } else {
      $min_020 = $23;
      $result_021 = $_result_0;
      label = 4;
      break;
    }
   case 8:
    $_sum17 = $11 - 1 | 0;
    $25 = $min_020 + ($_sum17 << 3) | 0;
    $26 = ($_sum17 | 0) < 0;
    if ($26) {
      $result_2 = $_result_0;
      label = 9;
      break;
    } else {
      $max_0_ph25 = $25;
      $min_0_ph26 = $min_020;
      $result_0_ph27 = $_result_0;
      label = 3;
      break;
    }
   case 9:
    $27 = ($result_2 | 0) == 0;
    if ($27) {
      $_0 = 0;
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $29 = $result_2 + 4 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $_0 = $30;
    label = 11;
    break;
   case 11:
    return $_0 | 0;
  }
  return 0;
}
function _ps_unicodes_char_next($table, $unicode) {
  $table = $table | 0;
  $unicode = $unicode | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $result_026 = 0, $max_025 = 0, $min_024 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $result_1 = 0, $25 = 0, $26 = 0, $_min_0 = 0, $max_0_ = 0, $27 = 0, $28 = 0, $min_0_lcssa29 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $char_code_0 = 0, $result_2 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$unicode >> 2] | 0;
    $2 = $1 + 1 | 0;
    $3 = $table + 16 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $min_0_lcssa29 = 0;
      label = 9;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $table + 20 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $min_024 = 0;
    $max_025 = $4;
    $result_026 = 0;
    label = 3;
    break;
   case 3:
    $9 = $max_025 - $min_024 | 0;
    $10 = $9 >>> 1;
    $11 = $10 + $min_024 | 0;
    $12 = $7 + ($11 << 3) | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = ($13 | 0) == ($2 | 0);
    if ($14) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $16 = $7 + ($11 << 3) + 4 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $result_2 = $17;
    $char_code_0 = $2;
    label = 11;
    break;
   case 5:
    $19 = $13 & 2147483647;
    $20 = ($19 | 0) == ($2 | 0);
    if ($20) {
      label = 6;
      break;
    } else {
      $result_1 = $result_026;
      label = 7;
      break;
    }
   case 6:
    $22 = $7 + ($11 << 3) + 4 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $result_1 = $23;
    label = 7;
    break;
   case 7:
    $25 = $19 >>> 0 < $2 >>> 0;
    $26 = $11 + 1 | 0;
    $_min_0 = $25 ? $26 : $min_024;
    $max_0_ = $25 ? $max_025 : $11;
    $27 = $_min_0 >>> 0 < $max_0_ >>> 0;
    if ($27) {
      $min_024 = $_min_0;
      $max_025 = $max_0_;
      $result_026 = $result_1;
      label = 3;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $28 = ($result_1 | 0) == 0;
    if ($28) {
      $min_0_lcssa29 = $_min_0;
      label = 9;
      break;
    } else {
      $result_2 = $result_1;
      $char_code_0 = $2;
      label = 11;
      break;
    }
   case 9:
    $29 = HEAP32[$3 >> 2] | 0;
    $30 = $min_0_lcssa29 >>> 0 < $29 >>> 0;
    if ($30) {
      label = 10;
      break;
    } else {
      $result_2 = 0;
      $char_code_0 = 0;
      label = 11;
      break;
    }
   case 10:
    $32 = $table + 20 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $33 + ($min_0_lcssa29 << 3) + 4 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $33 + ($min_0_lcssa29 << 3) | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $37 & 2147483647;
    $result_2 = $35;
    $char_code_0 = $38;
    label = 11;
    break;
   case 11:
    HEAP32[$unicode >> 2] = $char_code_0;
    return $result_2 | 0;
  }
  return 0;
}
function _ps_get_macintosh_name($name_index) {
  $name_index = $name_index | 0;
  return 5251528 + (HEAP16[5256308 + (($name_index >>> 0 > 257 ? 0 : $name_index) << 1) >> 1] << 16 >> 16) | 0;
}
function _ps_get_standard_strings($sid) {
  $sid = $sid | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $sid >>> 0 > 390;
    if ($1) {
      $_0 = 0;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = 5255404 + ($sid << 1) | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 << 16 >> 16;
    $6 = $5 + 5251528 | 0;
    $_0 = $6;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _psh_hint_table_init($table, $hints, $hint_masks, $memory) {
  $table = $table | 0;
  $hints = $hints | 0;
  $hint_masks = $hint_masks | 0;
  $memory = $memory | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $read_08 = 0, $write_07 = 0, $count_06 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $mask_04 = 0, $count_13 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $or_cond = 0, $idx_01 = 0, $63 = 0, $exitcond = 0, $64 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $hints | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 << 1;
    $4 = _ft_mem_realloc($memory, 4, 0, $3, 0, $error) | 0;
    $5 = $4;
    $6 = $table + 12 | 0;
    HEAP32[$6 >> 2] = $5;
    $7 = HEAP32[$error >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 12;
      break;
    }
   case 2:
    $10 = _ft_mem_realloc($memory, 28, 0, $2, 0, $error) | 0;
    $11 = $10;
    $12 = $table + 8 | 0;
    HEAP32[$12 >> 2] = $11;
    $13 = HEAP32[$error >> 2] | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 3;
      break;
    } else {
      label = 12;
      break;
    }
   case 3:
    $16 = $3 | 1;
    $17 = _ft_mem_realloc($memory, 16, 0, $16, 0, $error) | 0;
    $18 = $17;
    $19 = $table + 24 | 0;
    HEAP32[$19 >> 2] = $18;
    $20 = HEAP32[$error >> 2] | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 4;
      break;
    } else {
      label = 12;
      break;
    }
   case 4:
    $23 = $table | 0;
    HEAP32[$23 >> 2] = $2;
    $24 = HEAP32[$6 >> 2] | 0;
    $25 = $24 + ($2 << 2) | 0;
    $26 = $table + 16 | 0;
    HEAP32[$26 >> 2] = $25;
    $27 = $table + 4 | 0;
    HEAP32[$27 >> 2] = 0;
    $28 = $table + 20 | 0;
    HEAP32[$28 >> 2] = 0;
    $29 = $table + 28 | 0;
    HEAP32[$29 >> 2] = 0;
    $30 = ($2 | 0) == 0;
    if ($30) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $31 = $hints + 8 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = HEAP32[$12 >> 2] | 0;
    $count_06 = $2;
    $write_07 = $33;
    $read_08 = $32;
    label = 6;
    break;
   case 6:
    $35 = $read_08 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $write_07 | 0;
    HEAP32[$37 >> 2] = $36;
    $38 = $read_08 + 4 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = $write_07 + 4 | 0;
    HEAP32[$40 >> 2] = $39;
    $41 = $read_08 + 8 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = $write_07 + 16 | 0;
    HEAP32[$43 >> 2] = $42;
    $44 = $count_06 - 1 | 0;
    $45 = $write_07 + 28 | 0;
    $46 = $read_08 + 12 | 0;
    $47 = ($44 | 0) == 0;
    if ($47) {
      label = 7;
      break;
    } else {
      $count_06 = $44;
      $write_07 = $45;
      $read_08 = $46;
      label = 6;
      break;
    }
   case 7:
    $48 = ($hint_masks | 0) == 0;
    if ($48) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $50 = $hint_masks + 8 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = $hint_masks | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $table + 32 | 0;
    HEAP32[$54 >> 2] = $hint_masks;
    $55 = ($53 | 0) == 0;
    if ($55) {
      label = 10;
      break;
    } else {
      $count_13 = $53;
      $mask_04 = $51;
      label = 9;
      break;
    }
   case 9:
    _psh_hint_table_record_mask($table, $mask_04);
    $56 = $count_13 - 1 | 0;
    $57 = $mask_04 + 16 | 0;
    $58 = ($56 | 0) == 0;
    if ($58) {
      label = 10;
      break;
    } else {
      $count_13 = $56;
      $mask_04 = $57;
      label = 9;
      break;
    }
   case 10:
    $59 = HEAP32[$27 >> 2] | 0;
    $60 = HEAP32[$23 >> 2] | 0;
    $61 = ($59 | 0) == ($60 | 0);
    $62 = ($60 | 0) == 0;
    $or_cond = $61 | $62;
    if ($or_cond) {
      label = 12;
      break;
    } else {
      $idx_01 = 0;
      label = 11;
      break;
    }
   case 11:
    _psh_hint_table_record($table, $idx_01);
    $63 = $idx_01 + 1 | 0;
    $exitcond = ($63 | 0) == ($60 | 0);
    if ($exitcond) {
      label = 12;
      break;
    } else {
      $idx_01 = $63;
      label = 11;
      break;
    }
   case 12:
    $64 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $64 | 0;
  }
  return 0;
}
function _psh_hint_table_record_mask($table, $hint_mask) {
  $table = $table | 0;
  $hint_mask = $hint_mask | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $mask_010 = 0, $idx_09 = 0, $cursor_08 = 0, $val_07 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $val_1 = 0, $cursor_1 = 0, $mask_1 = 0, $13 = 0, $14 = 0, $17 = 0, $18 = 0, $exitcond = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hint_mask | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 8;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $hint_mask + 8 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $val_07 = 0;
    $cursor_08 = $5;
    $idx_09 = 0;
    $mask_010 = 0;
    label = 3;
    break;
   case 3:
    $7 = ($mask_010 | 0) == 0;
    if ($7) {
      label = 4;
      break;
    } else {
      $mask_1 = $mask_010;
      $cursor_1 = $cursor_08;
      $val_1 = $val_07;
      label = 5;
      break;
    }
   case 4:
    $9 = $cursor_08 + 1 | 0;
    $10 = HEAP8[$cursor_08] | 0;
    $11 = $10 & 255;
    $mask_1 = 128;
    $cursor_1 = $9;
    $val_1 = $11;
    label = 5;
    break;
   case 5:
    $13 = $mask_1 & $val_1;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    _psh_hint_table_record($table, $idx_09);
    label = 7;
    break;
   case 7:
    $17 = $mask_1 >> 1;
    $18 = $idx_09 + 1 | 0;
    $exitcond = ($18 | 0) == ($2 | 0);
    if ($exitcond) {
      label = 8;
      break;
    } else {
      $val_07 = $val_1;
      $cursor_08 = $cursor_1;
      $idx_09 = $18;
      $mask_010 = $17;
      label = 3;
      break;
    }
   case 8:
    return;
  }
}
function _psh_hint_table_record($table, $idx) {
  $table = $table | 0;
  $idx = $idx | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $sorted_019 = 0, $count_018 = 0, $20 = 0, $21 = 0, $22 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + ($idx * 28 & -1) | 0;
    $4 = $table | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 >>> 0 > $idx >>> 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 9;
      break;
    }
   case 2:
    $8 = $2 + ($idx * 28 & -1) + 16 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 & 4;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 3;
      break;
    } else {
      label = 9;
      break;
    }
   case 3:
    $13 = $9 | 4;
    HEAP32[$8 >> 2] = $13;
    $14 = $table + 16 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $table + 4 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $2 + ($idx * 28 & -1) + 20 | 0;
    HEAP32[$18 >> 2] = 0;
    $19 = ($17 | 0) == 0;
    if ($19) {
      label = 7;
      break;
    } else {
      $count_018 = $17;
      $sorted_019 = $15;
      label = 4;
      break;
    }
   case 4:
    $20 = HEAP32[$sorted_019 >> 2] | 0;
    $21 = _psh_hint_overlap($3, $20) | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    HEAP32[$18 >> 2] = $20;
    label = 7;
    break;
   case 6:
    $25 = $count_018 - 1 | 0;
    $26 = $sorted_019 + 4 | 0;
    $27 = ($25 | 0) == 0;
    if ($27) {
      label = 7;
      break;
    } else {
      $count_018 = $25;
      $sorted_019 = $26;
      label = 4;
      break;
    }
   case 7:
    $28 = HEAP32[$16 >> 2] | 0;
    $29 = HEAP32[$4 >> 2] | 0;
    $30 = $28 >>> 0 < $29 >>> 0;
    if ($30) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $32 = $28 + 1 | 0;
    HEAP32[$16 >> 2] = $32;
    $33 = HEAP32[$14 >> 2] | 0;
    $34 = $33 + ($28 << 2) | 0;
    HEAP32[$34 >> 2] = $3;
    label = 9;
    break;
   case 9:
    return;
  }
}
function _psnames_get_service($module, $service_id) {
  $module = $module | 0;
  $service_id = $service_id | 0;
  return _ft_service_list_lookup(5250008, $service_id) | 0;
}
function _ps_unicode_value($glyph_name) {
  $glyph_name = $glyph_name | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $_ = 0, $21 = 0, $d_041 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $d_041_3 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $_pr = 0, $34 = 0, $p3_054 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $_40 = 0, $44 = 0, $d5_044 = 0, $p3_0 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $p3_053 = 0, $value2_051 = 0, $49 = 0, $51 = 0, $p6_0 = 0, $52 = 0, $54 = 0, $56 = 0, $58 = 0, $59 = 0, $61 = 0, $62 = 0, $_0 = 0, $65 = 0, $66 = 0, $67 = 0, $_40_1 = 0, $68 = 0, $d5_044_1 = 0, $69 = 0, $70 = 0, $p3_0_1 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $76 = 0, $77 = 0, $78 = 0, $_40_2 = 0, $79 = 0, $d5_044_2 = 0, $80 = 0, $81 = 0, $p3_0_2 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $87 = 0, $88 = 0, $89 = 0, $_40_3 = 0, $90 = 0, $d5_044_3 = 0, $91 = 0, $92 = 0, $p3_0_3 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $98 = 0, $99 = 0, $100 = 0, $_40_4 = 0, $101 = 0, $d5_044_4 = 0, $102 = 0, $103 = 0, $p3_0_4 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $109 = 0, $110 = 0, $111 = 0, $_40_5 = 0, $112 = 0, $d5_044_5 = 0, $113 = 0, $114 = 0, $p3_0_5 = 0, $116 = 0, $117 = 0, $118 = 0, $__1 = 0, $119 = 0, $d_041_1 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $128 = 0, $129 = 0, $130 = 0, $__2 = 0, $131 = 0, $d_041_2 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $140 = 0, $141 = 0, $142 = 0, $__3 = 0, $143 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP8[$glyph_name] | 0;
    $2 = $1 << 24 >> 24 == 117;
    if ($2) {
      label = 2;
      break;
    } else {
      $p6_0 = $glyph_name;
      label = 15;
      break;
    }
   case 2:
    $4 = $glyph_name + 1 | 0;
    $5 = HEAP8[$4] | 0;
    $6 = $5 << 24 >> 24 == 110;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 9;
      break;
    }
   case 3:
    $8 = $glyph_name + 2 | 0;
    $9 = HEAP8[$8] | 0;
    $10 = $9 << 24 >> 24 == 105;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 9;
      break;
    }
   case 4:
    $12 = $glyph_name + 3 | 0;
    $13 = HEAP8[$12] | 0;
    $14 = $13 & 255;
    $15 = $14 - 48 | 0;
    $16 = $15 >>> 0 > 9;
    if ($16) {
      label = 5;
      break;
    } else {
      $d_041 = $15;
      label = 6;
      break;
    }
   case 5:
    $18 = $14 - 65 | 0;
    $19 = $18 >>> 0 > 5;
    $20 = $14 - 55 | 0;
    $_ = $19 ? 16 : $20;
    $21 = $_ >>> 0 > 15;
    if ($21) {
      label = 9;
      break;
    } else {
      $d_041 = $_;
      label = 6;
      break;
    }
   case 6:
    $22 = $glyph_name + 4 | 0;
    $23 = HEAP8[$22] | 0;
    $24 = $23 & 255;
    $25 = $24 - 48 | 0;
    $26 = $25 >>> 0 > 9;
    if ($26) {
      label = 32;
      break;
    } else {
      $d_041_1 = $25;
      label = 33;
      break;
    }
   case 7:
    $28 = $133 << 4;
    $29 = $d_041_3 + $28 | 0;
    $30 = $glyph_name + 7 | 0;
    $31 = HEAP8[$30] | 0;
    if (($31 << 24 >> 24 | 0) == 46) {
      label = 8;
      break;
    } else if (($31 << 24 >> 24 | 0) == 0) {
      $_0 = $29;
      label = 21;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $33 = $29 | -2147483648;
    $_0 = $33;
    label = 21;
    break;
   case 9:
    $_pr = HEAP8[$glyph_name] | 0;
    $34 = $_pr << 24 >> 24 == 117;
    if ($34) {
      label = 10;
      break;
    } else {
      $p6_0 = $glyph_name;
      label = 15;
      break;
    }
   case 10:
    $p3_054 = $glyph_name + 1 | 0;
    $36 = HEAP8[$p3_054] | 0;
    $37 = $36 & 255;
    $38 = $37 - 48 | 0;
    $39 = $38 >>> 0 > 9;
    if ($39) {
      label = 11;
      break;
    } else {
      $d5_044 = $38;
      label = 12;
      break;
    }
   case 11:
    $41 = $37 - 65 | 0;
    $42 = $41 >>> 0 > 5;
    $43 = $37 - 55 | 0;
    $_40 = $42 ? 16 : $43;
    $44 = $_40 >>> 0 > 15;
    if ($44) {
      $p6_0 = $glyph_name;
      label = 15;
      break;
    } else {
      $d5_044 = $_40;
      label = 12;
      break;
    }
   case 12:
    $p3_0 = $glyph_name + 2 | 0;
    $45 = HEAP8[$p3_0] | 0;
    $46 = $45 & 255;
    $47 = $46 - 48 | 0;
    $48 = $47 >>> 0 > 9;
    if ($48) {
      label = 22;
      break;
    } else {
      $d5_044_1 = $47;
      label = 23;
      break;
    }
   case 13:
    $49 = HEAP8[$p3_053] | 0;
    if (($49 << 24 >> 24 | 0) == 46) {
      label = 14;
      break;
    } else if (($49 << 24 >> 24 | 0) == 0) {
      $_0 = $value2_051;
      label = 21;
      break;
    } else {
      $p6_0 = $glyph_name;
      label = 15;
      break;
    }
   case 14:
    $51 = $value2_051 | -2147483648;
    $_0 = $51;
    label = 21;
    break;
   case 15:
    $52 = HEAP8[$p6_0] | 0;
    if (($52 << 24 >> 24 | 0) == 46) {
      label = 16;
      break;
    } else if (($52 << 24 >> 24 | 0) == 0) {
      label = 19;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    $54 = $p6_0 >>> 0 > $glyph_name >>> 0;
    if ($54) {
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $56 = $p6_0 + 1 | 0;
    $p6_0 = $56;
    label = 15;
    break;
   case 18:
    $58 = ($p6_0 | 0) == 0;
    if ($58) {
      label = 19;
      break;
    } else {
      label = 20;
      break;
    }
   case 19:
    $59 = _ft_get_adobe_glyph_index($glyph_name, $p6_0) | 0;
    $_0 = $59;
    label = 21;
    break;
   case 20:
    $61 = _ft_get_adobe_glyph_index($glyph_name, $p6_0) | 0;
    $62 = $61 | -2147483648;
    $_0 = $62;
    label = 21;
    break;
   case 21:
    return $_0 | 0;
   case 22:
    $65 = $46 - 65 | 0;
    $66 = $65 >>> 0 > 5;
    $67 = $46 - 55 | 0;
    $_40_1 = $66 ? 16 : $67;
    $68 = $_40_1 >>> 0 > 15;
    if ($68) {
      $p6_0 = $glyph_name;
      label = 15;
      break;
    } else {
      $d5_044_1 = $_40_1;
      label = 23;
      break;
    }
   case 23:
    $69 = $d5_044 << 4;
    $70 = $d5_044_1 + $69 | 0;
    $p3_0_1 = $glyph_name + 3 | 0;
    $71 = HEAP8[$p3_0_1] | 0;
    $72 = $71 & 255;
    $73 = $72 - 48 | 0;
    $74 = $73 >>> 0 > 9;
    if ($74) {
      label = 24;
      break;
    } else {
      $d5_044_2 = $73;
      label = 25;
      break;
    }
   case 24:
    $76 = $72 - 65 | 0;
    $77 = $76 >>> 0 > 5;
    $78 = $72 - 55 | 0;
    $_40_2 = $77 ? 16 : $78;
    $79 = $_40_2 >>> 0 > 15;
    if ($79) {
      $p6_0 = $glyph_name;
      label = 15;
      break;
    } else {
      $d5_044_2 = $_40_2;
      label = 25;
      break;
    }
   case 25:
    $80 = $70 << 4;
    $81 = $d5_044_2 + $80 | 0;
    $p3_0_2 = $glyph_name + 4 | 0;
    $82 = HEAP8[$p3_0_2] | 0;
    $83 = $82 & 255;
    $84 = $83 - 48 | 0;
    $85 = $84 >>> 0 > 9;
    if ($85) {
      label = 26;
      break;
    } else {
      $d5_044_3 = $84;
      label = 27;
      break;
    }
   case 26:
    $87 = $83 - 65 | 0;
    $88 = $87 >>> 0 > 5;
    $89 = $83 - 55 | 0;
    $_40_3 = $88 ? 16 : $89;
    $90 = $_40_3 >>> 0 > 15;
    if ($90) {
      $p6_0 = $glyph_name;
      label = 15;
      break;
    } else {
      $d5_044_3 = $_40_3;
      label = 27;
      break;
    }
   case 27:
    $91 = $81 << 4;
    $92 = $d5_044_3 + $91 | 0;
    $p3_0_3 = $glyph_name + 5 | 0;
    $93 = HEAP8[$p3_0_3] | 0;
    $94 = $93 & 255;
    $95 = $94 - 48 | 0;
    $96 = $95 >>> 0 > 9;
    if ($96) {
      label = 28;
      break;
    } else {
      $d5_044_4 = $95;
      label = 29;
      break;
    }
   case 28:
    $98 = $94 - 65 | 0;
    $99 = $98 >>> 0 > 5;
    $100 = $94 - 55 | 0;
    $_40_4 = $99 ? 16 : $100;
    $101 = $_40_4 >>> 0 > 15;
    if ($101) {
      $value2_051 = $92;
      $p3_053 = $p3_0_3;
      label = 13;
      break;
    } else {
      $d5_044_4 = $_40_4;
      label = 29;
      break;
    }
   case 29:
    $102 = $92 << 4;
    $103 = $d5_044_4 + $102 | 0;
    $p3_0_4 = $glyph_name + 6 | 0;
    $104 = HEAP8[$p3_0_4] | 0;
    $105 = $104 & 255;
    $106 = $105 - 48 | 0;
    $107 = $106 >>> 0 > 9;
    if ($107) {
      label = 30;
      break;
    } else {
      $d5_044_5 = $106;
      label = 31;
      break;
    }
   case 30:
    $109 = $105 - 65 | 0;
    $110 = $109 >>> 0 > 5;
    $111 = $105 - 55 | 0;
    $_40_5 = $110 ? 16 : $111;
    $112 = $_40_5 >>> 0 > 15;
    if ($112) {
      $value2_051 = $103;
      $p3_053 = $p3_0_4;
      label = 13;
      break;
    } else {
      $d5_044_5 = $_40_5;
      label = 31;
      break;
    }
   case 31:
    $113 = $103 << 4;
    $114 = $d5_044_5 + $113 | 0;
    $p3_0_5 = $glyph_name + 7 | 0;
    $value2_051 = $114;
    $p3_053 = $p3_0_5;
    label = 13;
    break;
   case 32:
    $116 = $24 - 65 | 0;
    $117 = $116 >>> 0 > 5;
    $118 = $24 - 55 | 0;
    $__1 = $117 ? 16 : $118;
    $119 = $__1 >>> 0 > 15;
    if ($119) {
      label = 9;
      break;
    } else {
      $d_041_1 = $__1;
      label = 33;
      break;
    }
   case 33:
    $120 = $d_041 << 4;
    $121 = $d_041_1 + $120 | 0;
    $122 = $glyph_name + 5 | 0;
    $123 = HEAP8[$122] | 0;
    $124 = $123 & 255;
    $125 = $124 - 48 | 0;
    $126 = $125 >>> 0 > 9;
    if ($126) {
      label = 34;
      break;
    } else {
      $d_041_2 = $125;
      label = 35;
      break;
    }
   case 34:
    $128 = $124 - 65 | 0;
    $129 = $128 >>> 0 > 5;
    $130 = $124 - 55 | 0;
    $__2 = $129 ? 16 : $130;
    $131 = $__2 >>> 0 > 15;
    if ($131) {
      label = 9;
      break;
    } else {
      $d_041_2 = $__2;
      label = 35;
      break;
    }
   case 35:
    $132 = $121 << 4;
    $133 = $d_041_2 + $132 | 0;
    $134 = $glyph_name + 6 | 0;
    $135 = HEAP8[$134] | 0;
    $136 = $135 & 255;
    $137 = $136 - 48 | 0;
    $138 = $137 >>> 0 > 9;
    if ($138) {
      label = 36;
      break;
    } else {
      $d_041_3 = $137;
      label = 7;
      break;
    }
   case 36:
    $140 = $136 - 65 | 0;
    $141 = $140 >>> 0 > 5;
    $142 = $136 - 55 | 0;
    $__3 = $141 ? 16 : $142;
    $143 = $__3 >>> 0 > 15;
    if ($143) {
      label = 9;
      break;
    } else {
      $d_041_3 = $__3;
      label = 7;
      break;
    }
  }
  return 0;
}
function _ps_unicodes_init($memory, $table, $num_glyphs, $get_glyph_name, $free_glyph_name, $glyph_data) {
  $memory = $memory | 0;
  $table = $table | 0;
  $num_glyphs = $num_glyphs | 0;
  $get_glyph_name = $get_glyph_name | 0;
  $free_glyph_name = $free_glyph_name | 0;
  $glyph_data = $glyph_data | 0;
  var $error = 0, $extra_glyph_list_states = 0, $extra_glyphs = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $n_051 = 0, $map_050 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $map_1 = 0, $map_2 = 0, $27 = 0, $exitcond = 0, $map_0_lcssa = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $map_4 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $map_4_1 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $map_4_2 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $map_4_3 = 0, $86 = 0, $87 = 0, $88 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $map_4_4 = 0, $96 = 0, $97 = 0, $98 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $map_4_5 = 0, $106 = 0, $107 = 0, $108 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $map_4_6 = 0, $116 = 0, $117 = 0, $118 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $map_4_7 = 0, $126 = 0, $127 = 0, $128 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $map_4_8 = 0, $136 = 0, $137 = 0, $138 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $map_4_9 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 84 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $extra_glyph_list_states = __stackBase__ + 4 | 0;
    $extra_glyphs = __stackBase__ + 44 | 0;
    $1 = $extra_glyph_list_states;
    _memset($1 | 0, 0, 40);
    $2 = $table + 16 | 0;
    HEAP32[$2 >> 2] = 0;
    $3 = $table + 20 | 0;
    HEAP32[$3 >> 2] = 0;
    $4 = $num_glyphs + 10 | 0;
    $5 = _ft_mem_realloc($memory, 8, 0, $4, 0, $error) | 0;
    $6 = $5;
    HEAP32[$3 >> 2] = $6;
    $7 = HEAP32[$error >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 19;
      break;
    }
   case 2:
    $9 = ($num_glyphs | 0) == 0;
    if ($9) {
      $map_0_lcssa = $6;
      label = 10;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $10 = $extra_glyphs | 0;
    $11 = $extra_glyph_list_states | 0;
    $12 = ($free_glyph_name | 0) == 0;
    $map_050 = $6;
    $n_051 = 0;
    label = 4;
    break;
   case 4:
    $14 = FUNCTION_TABLE_iii[$get_glyph_name & 1023]($glyph_data, $n_051) | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      $map_2 = $map_050;
      label = 9;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    _ps_check_extra_glyph_name($14, $n_051, $10, $11);
    $17 = _ps_unicode_value($14) | 0;
    $18 = $17 & 2147483647;
    $19 = ($18 | 0) == 0;
    if ($19) {
      $map_1 = $map_050;
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    _ps_check_extra_glyph_unicode($17, $11);
    $21 = $map_050 | 0;
    HEAP32[$21 >> 2] = $17;
    $22 = $map_050 + 4 | 0;
    HEAP32[$22 >> 2] = $n_051;
    $23 = $map_050 + 8 | 0;
    $map_1 = $23;
    label = 7;
    break;
   case 7:
    if ($12) {
      $map_2 = $map_1;
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    FUNCTION_TABLE_vii[$free_glyph_name & 1023]($glyph_data, $14);
    $map_2 = $map_1;
    label = 9;
    break;
   case 9:
    $27 = $n_051 + 1 | 0;
    $exitcond = ($27 | 0) == ($num_glyphs | 0);
    if ($exitcond) {
      $map_0_lcssa = $map_2;
      label = 10;
      break;
    } else {
      $map_050 = $map_2;
      $n_051 = $27;
      label = 4;
      break;
    }
   case 10:
    $28 = $extra_glyph_list_states | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = ($29 | 0) == 1;
    if ($30) {
      label = 11;
      break;
    } else {
      $map_4 = $map_0_lcssa;
      label = 12;
      break;
    }
   case 11:
    $32 = $map_0_lcssa | 0;
    HEAP32[$32 >> 2] = 916;
    $33 = $extra_glyphs | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $map_0_lcssa + 4 | 0;
    HEAP32[$35 >> 2] = $34;
    $36 = $map_0_lcssa + 8 | 0;
    $map_4 = $36;
    label = 12;
    break;
   case 12:
    $38 = $extra_glyph_list_states + 4 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = ($39 | 0) == 1;
    if ($40) {
      label = 20;
      break;
    } else {
      $map_4_1 = $map_4;
      label = 21;
      break;
    }
   case 13:
    $42 = $146;
    _ft_mem_free($memory, $42);
    HEAP32[$3 >> 2] = 0;
    $43 = HEAP32[$error >> 2] | 0;
    $44 = ($43 | 0) == 0;
    if ($44) {
      label = 14;
      break;
    } else {
      label = 18;
      break;
    }
   case 14:
    HEAP32[$error >> 2] = 163;
    label = 18;
    break;
   case 15:
    $47 = $num_glyphs >>> 1;
    $48 = $150 >>> 0 < $47 >>> 0;
    if ($48) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    $50 = $146;
    $51 = _ft_mem_realloc($memory, 8, $num_glyphs, $150, $50, $error) | 0;
    $52 = $51;
    HEAP32[$3 >> 2] = $52;
    HEAP32[$error >> 2] = 0;
    label = 17;
    break;
   case 17:
    $54 = HEAP32[$3 >> 2] | 0;
    $55 = $54;
    _qsort($55 | 0, $150 | 0, 8, 738);
    label = 18;
    break;
   case 18:
    HEAP32[$2 >> 2] = $150;
    label = 19;
    break;
   case 19:
    $58 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $58 | 0;
   case 20:
    $60 = $map_4 | 0;
    HEAP32[$60 >> 2] = 937;
    $61 = $extra_glyphs + 4 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = $map_4 + 4 | 0;
    HEAP32[$63 >> 2] = $62;
    $64 = $map_4 + 8 | 0;
    $map_4_1 = $64;
    label = 21;
    break;
   case 21:
    $66 = $extra_glyph_list_states + 8 | 0;
    $67 = HEAP32[$66 >> 2] | 0;
    $68 = ($67 | 0) == 1;
    if ($68) {
      label = 22;
      break;
    } else {
      $map_4_2 = $map_4_1;
      label = 23;
      break;
    }
   case 22:
    $70 = $map_4_1 | 0;
    HEAP32[$70 >> 2] = 8725;
    $71 = $extra_glyphs + 8 | 0;
    $72 = HEAP32[$71 >> 2] | 0;
    $73 = $map_4_1 + 4 | 0;
    HEAP32[$73 >> 2] = $72;
    $74 = $map_4_1 + 8 | 0;
    $map_4_2 = $74;
    label = 23;
    break;
   case 23:
    $76 = $extra_glyph_list_states + 12 | 0;
    $77 = HEAP32[$76 >> 2] | 0;
    $78 = ($77 | 0) == 1;
    if ($78) {
      label = 24;
      break;
    } else {
      $map_4_3 = $map_4_2;
      label = 25;
      break;
    }
   case 24:
    $80 = $map_4_2 | 0;
    HEAP32[$80 >> 2] = 173;
    $81 = $extra_glyphs + 12 | 0;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = $map_4_2 + 4 | 0;
    HEAP32[$83 >> 2] = $82;
    $84 = $map_4_2 + 8 | 0;
    $map_4_3 = $84;
    label = 25;
    break;
   case 25:
    $86 = $extra_glyph_list_states + 16 | 0;
    $87 = HEAP32[$86 >> 2] | 0;
    $88 = ($87 | 0) == 1;
    if ($88) {
      label = 26;
      break;
    } else {
      $map_4_4 = $map_4_3;
      label = 27;
      break;
    }
   case 26:
    $90 = $map_4_3 | 0;
    HEAP32[$90 >> 2] = 713;
    $91 = $extra_glyphs + 16 | 0;
    $92 = HEAP32[$91 >> 2] | 0;
    $93 = $map_4_3 + 4 | 0;
    HEAP32[$93 >> 2] = $92;
    $94 = $map_4_3 + 8 | 0;
    $map_4_4 = $94;
    label = 27;
    break;
   case 27:
    $96 = $extra_glyph_list_states + 20 | 0;
    $97 = HEAP32[$96 >> 2] | 0;
    $98 = ($97 | 0) == 1;
    if ($98) {
      label = 28;
      break;
    } else {
      $map_4_5 = $map_4_4;
      label = 29;
      break;
    }
   case 28:
    $100 = $map_4_4 | 0;
    HEAP32[$100 >> 2] = 956;
    $101 = $extra_glyphs + 20 | 0;
    $102 = HEAP32[$101 >> 2] | 0;
    $103 = $map_4_4 + 4 | 0;
    HEAP32[$103 >> 2] = $102;
    $104 = $map_4_4 + 8 | 0;
    $map_4_5 = $104;
    label = 29;
    break;
   case 29:
    $106 = $extra_glyph_list_states + 24 | 0;
    $107 = HEAP32[$106 >> 2] | 0;
    $108 = ($107 | 0) == 1;
    if ($108) {
      label = 30;
      break;
    } else {
      $map_4_6 = $map_4_5;
      label = 31;
      break;
    }
   case 30:
    $110 = $map_4_5 | 0;
    HEAP32[$110 >> 2] = 8729;
    $111 = $extra_glyphs + 24 | 0;
    $112 = HEAP32[$111 >> 2] | 0;
    $113 = $map_4_5 + 4 | 0;
    HEAP32[$113 >> 2] = $112;
    $114 = $map_4_5 + 8 | 0;
    $map_4_6 = $114;
    label = 31;
    break;
   case 31:
    $116 = $extra_glyph_list_states + 28 | 0;
    $117 = HEAP32[$116 >> 2] | 0;
    $118 = ($117 | 0) == 1;
    if ($118) {
      label = 32;
      break;
    } else {
      $map_4_7 = $map_4_6;
      label = 33;
      break;
    }
   case 32:
    $120 = $map_4_6 | 0;
    HEAP32[$120 >> 2] = 160;
    $121 = $extra_glyphs + 28 | 0;
    $122 = HEAP32[$121 >> 2] | 0;
    $123 = $map_4_6 + 4 | 0;
    HEAP32[$123 >> 2] = $122;
    $124 = $map_4_6 + 8 | 0;
    $map_4_7 = $124;
    label = 33;
    break;
   case 33:
    $126 = $extra_glyph_list_states + 32 | 0;
    $127 = HEAP32[$126 >> 2] | 0;
    $128 = ($127 | 0) == 1;
    if ($128) {
      label = 34;
      break;
    } else {
      $map_4_8 = $map_4_7;
      label = 35;
      break;
    }
   case 34:
    $130 = $map_4_7 | 0;
    HEAP32[$130 >> 2] = 538;
    $131 = $extra_glyphs + 32 | 0;
    $132 = HEAP32[$131 >> 2] | 0;
    $133 = $map_4_7 + 4 | 0;
    HEAP32[$133 >> 2] = $132;
    $134 = $map_4_7 + 8 | 0;
    $map_4_8 = $134;
    label = 35;
    break;
   case 35:
    $136 = $extra_glyph_list_states + 36 | 0;
    $137 = HEAP32[$136 >> 2] | 0;
    $138 = ($137 | 0) == 1;
    if ($138) {
      label = 36;
      break;
    } else {
      $map_4_9 = $map_4_8;
      label = 37;
      break;
    }
   case 36:
    $140 = $map_4_8 | 0;
    HEAP32[$140 >> 2] = 539;
    $141 = $extra_glyphs + 36 | 0;
    $142 = HEAP32[$141 >> 2] | 0;
    $143 = $map_4_8 + 4 | 0;
    HEAP32[$143 >> 2] = $142;
    $144 = $map_4_8 + 8 | 0;
    $map_4_9 = $144;
    label = 37;
    break;
   case 37:
    $146 = HEAP32[$3 >> 2] | 0;
    $147 = $map_4_9;
    $148 = $146;
    $149 = $147 - $148 | 0;
    $150 = $149 >> 3;
    $151 = ($150 | 0) == 0;
    if ($151) {
      label = 13;
      break;
    } else {
      label = 15;
      break;
    }
  }
  return 0;
}
function _ft_black_set_mode($raster, $mode, $palette) {
  $raster = $raster | 0;
  $mode = $mode | 0;
  $palette = $palette | 0;
  return;
}
function _compare_uni_maps($a, $b) {
  $a = $a | 0;
  $b = $b | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $11 = 0, $_ = 0, $13 = 0, $15 = 0, $_11 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $a;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 & 2147483647;
    $4 = $b;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 & 2147483647;
    $7 = ($3 | 0) == ($6 | 0);
    if ($7) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $9 = $2 >>> 0 > $5 >>> 0;
    if ($9) {
      $_0 = 1;
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = $2 >>> 0 < $5 >>> 0;
    $_ = $11 << 31 >> 31;
    $_0 = $_;
    label = 6;
    break;
   case 4:
    $13 = $3 >>> 0 > $6 >>> 0;
    if ($13) {
      $_0 = 1;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $15 = $3 >>> 0 < $6 >>> 0;
    $_11 = $15 << 31 >> 31;
    $_0 = $_11;
    label = 6;
    break;
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _ps_check_extra_glyph_unicode($uni_char, $states) {
  $uni_char = $uni_char | 0;
  $states = $states | 0;
  var $n_0 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $n_0 = 0;
    label = 2;
    break;
   case 2:
    $2 = $n_0 >>> 0 < 10;
    if ($2) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $4 = 5256848 + ($n_0 << 2) | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($5 | 0) == ($uni_char | 0);
    $7 = $n_0 + 1 | 0;
    if ($6) {
      label = 4;
      break;
    } else {
      $n_0 = $7;
      label = 2;
      break;
    }
   case 4:
    $9 = $states + ($n_0 << 2) | 0;
    HEAP32[$9 >> 2] = 2;
    label = 5;
    break;
   case 5:
    return;
  }
}
function _ft_get_adobe_glyph_index($name, $limit) {
  $name = $name | 0;
  $limit = $limit | 0;
  var $1 = 0, $2 = 0, $or_cond = 0, $4 = 0, $5 = 0, $6 = 0, $max_052 = 0, $min_051 = 0, $8 = 0, $9 = 0, $10 = 0, $_sum = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $_sum38 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $_min_0 = 0, $max_0_ = 0, $28 = 0, $p_0_lcssa = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $_03747 = 0, $p_046 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $p_0_be = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $_ = 0, $61 = 0, $count_041 = 0, $p_240 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $76 = 0, $77 = 0, $78 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($name | 0) != 0;
    $2 = $name >>> 0 < $limit >>> 0;
    $or_cond = $1 & $2;
    if ($or_cond) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 16;
      break;
    }
   case 2:
    $4 = $name + 1 | 0;
    $5 = HEAP8[$name] | 0;
    $6 = $5 << 24 >> 24;
    $min_051 = 0;
    $max_052 = 52;
    label = 3;
    break;
   case 3:
    $8 = $max_052 + $min_051 | 0;
    $9 = $8 >> 1;
    $10 = $9 << 1;
    $_sum = $10 + 2 | 0;
    $11 = $_sum + 5257220 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $12 & 255;
    $14 = $13 << 8;
    $_sum38 = $10 + 3 | 0;
    $15 = $_sum38 + 5257220 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 & 255;
    $18 = $14 | $17;
    $19 = $18 + 5257220 | 0;
    $20 = HEAP8[$19] | 0;
    $21 = $20 & 255;
    $22 = $21 & 127;
    $23 = ($22 | 0) == ($6 | 0);
    if ($23) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $24 = $4 >>> 0 < $limit >>> 0;
    if ($24) {
      $p_046 = $19;
      $_03747 = $4;
      label = 9;
      break;
    } else {
      $p_0_lcssa = $19;
      label = 6;
      break;
    }
   case 5:
    $26 = ($22 | 0) < ($6 | 0);
    $27 = $9 + 1 | 0;
    $_min_0 = $26 ? $27 : $min_051;
    $max_0_ = $26 ? $max_052 : $9;
    $28 = ($_min_0 | 0) < ($max_0_ | 0);
    if ($28) {
      $min_051 = $_min_0;
      $max_052 = $max_0_;
      label = 3;
      break;
    } else {
      $_0 = 0;
      label = 16;
      break;
    }
   case 6:
    $29 = HEAP8[$p_0_lcssa] | 0;
    $30 = $29 << 24 >> 24 > -1;
    if ($30) {
      label = 7;
      break;
    } else {
      $_0 = 0;
      label = 16;
      break;
    }
   case 7:
    $32 = $p_0_lcssa + 1 | 0;
    $33 = HEAP8[$32] | 0;
    $34 = $33 << 24 >> 24 < 0;
    if ($34) {
      label = 8;
      break;
    } else {
      $_0 = 0;
      label = 16;
      break;
    }
   case 8:
    $36 = $p_0_lcssa + 2 | 0;
    $37 = HEAP8[$36] | 0;
    $38 = $37 & 255;
    $39 = $38 << 8;
    $40 = $p_0_lcssa + 3 | 0;
    $41 = HEAP8[$40] | 0;
    $42 = $41 & 255;
    $43 = $39 | $42;
    $_0 = $43;
    label = 16;
    break;
   case 9:
    $44 = $_03747 + 1 | 0;
    $45 = HEAP8[$_03747] | 0;
    $46 = $45 << 24 >> 24;
    $47 = HEAP8[$p_046] | 0;
    $48 = $47 << 24 >> 24 < 0;
    $49 = $p_046 + 1 | 0;
    $50 = HEAP8[$49] | 0;
    $51 = $50 & 255;
    $52 = $51 & 127;
    if ($48) {
      label = 10;
      break;
    } else {
      label = 12;
      break;
    }
   case 10:
    $54 = ($46 | 0) == ($52 | 0);
    if ($54) {
      $p_0_be = $49;
      label = 11;
      break;
    } else {
      $_0 = 0;
      label = 16;
      break;
    }
   case 11:
    $55 = $44 >>> 0 < $limit >>> 0;
    if ($55) {
      $p_046 = $p_0_be;
      $_03747 = $44;
      label = 9;
      break;
    } else {
      $p_0_lcssa = $p_0_be;
      label = 6;
      break;
    }
   case 12:
    $57 = ($52 | 0) == 0;
    if ($57) {
      $_0 = 0;
      label = 16;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $58 = $51 & 128;
    $59 = $p_046 + 3 | 0;
    $60 = ($58 | 0) == 0;
    $_ = $60 ? $49 : $59;
    $61 = $_ + 1 | 0;
    $p_240 = $61;
    $count_041 = $52;
    label = 14;
    break;
   case 14:
    $63 = HEAP8[$p_240] | 0;
    $64 = $63 & 255;
    $65 = $64 << 8;
    $66 = $p_240 + 1 | 0;
    $67 = HEAP8[$66] | 0;
    $68 = $67 & 255;
    $69 = $65 | $68;
    $70 = $69 + 5257220 | 0;
    $71 = HEAP8[$70] | 0;
    $72 = $71 & 255;
    $73 = $72 & 127;
    $74 = ($46 | 0) == ($73 | 0);
    if ($74) {
      $p_0_be = $70;
      label = 11;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $76 = $count_041 - 1 | 0;
    $77 = $p_240 + 2 | 0;
    $78 = ($76 | 0) > 0;
    if ($78) {
      $p_240 = $77;
      $count_041 = $76;
      label = 14;
      break;
    } else {
      $_0 = 0;
      label = 16;
      break;
    }
   case 16:
    return $_0 | 0;
  }
  return 0;
}
function _ft_black_reset($raster, $pool_base, $pool_size) {
  $raster = $raster | 0;
  $pool_base = $pool_base | 0;
  $pool_size = $pool_size | 0;
  var $1 = 0, $3 = 0, $4 = 0, $or_cond = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($raster | 0) == 0;
    if ($1) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = ($pool_base | 0) != 0;
    $4 = ($pool_size | 0) > 3075;
    $or_cond = $3 & $4;
    if ($or_cond) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $6 = $pool_base;
    $7 = $pool_base + 1032 | 0;
    $8 = $raster | 0;
    HEAP32[$8 >> 2] = $7;
    $9 = $pool_size - 1032 | 0;
    $10 = $raster + 4 | 0;
    HEAP32[$10 >> 2] = $9;
    $11 = $raster + 12 | 0;
    HEAP32[$11 >> 2] = $6;
    label = 5;
    break;
   case 4:
    $13 = $raster | 0;
    HEAP32[$13 >> 2] = 0;
    $14 = $raster + 4 | 0;
    HEAP32[$14 >> 2] = 0;
    $15 = $raster + 12 | 0;
    HEAP32[$15 >> 2] = 0;
    label = 5;
    break;
   case 5:
    return;
  }
}
function _Set_High_Precision($worker, $High) {
  $worker = $worker | 0;
  $High = $High | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($High | 0) == 0;
    $2 = $worker | 0;
    if ($1) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    HEAP32[$2 >> 2] = 12;
    $4 = $worker + 16 | 0;
    HEAP32[$4 >> 2] = 256;
    $5 = $worker + 20 | 0;
    HEAP32[$5 >> 2] = 50;
    label = 4;
    break;
   case 3:
    HEAP32[$2 >> 2] = 6;
    $7 = $worker + 16 | 0;
    HEAP32[$7 >> 2] = 32;
    $8 = $worker + 20 | 0;
    HEAP32[$8 >> 2] = 2;
    label = 4;
    break;
   case 4:
    $10 = HEAP32[$2 >> 2] | 0;
    $11 = 1 << $10;
    $12 = $worker + 4 | 0;
    HEAP32[$12 >> 2] = $11;
    $13 = ($11 | 0) / 2 & -1;
    $14 = $worker + 8 | 0;
    HEAP32[$14 >> 2] = $13;
    $15 = HEAP32[$2 >> 2] | 0;
    $16 = $15 - 6 | 0;
    $17 = $worker + 12 | 0;
    HEAP32[$17 >> 2] = $16;
    return;
  }
}
function _Vertical_Sweep_Init($worker, $min, $max) {
  $worker = $worker | 0;
  $min = $min | 0;
  $max = $max | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 112 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = -$2 | 0;
    $4 = $3 & 65535;
    $5 = $worker + 156 | 0;
    HEAP16[$5 >> 1] = $4;
    $6 = HEAP16[$min >> 1] | 0;
    $7 = $6 << 16 >> 16;
    $8 = -$2 | 0;
    $9 = Math_imul($7, $8);
    $10 = $worker + 148 | 0;
    HEAP32[$10 >> 2] = $9;
    $11 = ($2 | 0) > 0;
    if ($11) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $13 = $worker + 104 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $7 ^ -1;
    $16 = $14 + $15 | 0;
    $17 = Math_imul($16, $2);
    HEAP32[$10 >> 2] = $17;
    label = 3;
    break;
   case 3:
    $19 = $worker + 158 | 0;
    HEAP16[$19 >> 1] = 0;
    $20 = $worker + 160 | 0;
    HEAP16[$20 >> 1] = 0;
    return;
  }
}
function _ps_check_extra_glyph_name($gname, $glyph, $extra_glyphs, $states) {
  $gname = $gname | 0;
  $glyph = $glyph | 0;
  $extra_glyphs = $extra_glyphs | 0;
  $states = $states | 0;
  var $n_0 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $n_0 = 0;
    label = 2;
    break;
   case 2:
    $2 = $n_0 >>> 0 < 10;
    if ($2) {
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 3:
    $4 = 5256976 + ($n_0 << 2) | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 + 5256888 | 0;
    $7 = _strcmp($6 | 0, $gname | 0) | 0;
    $8 = ($7 | 0) == 0;
    $9 = $n_0 + 1 | 0;
    if ($8) {
      label = 4;
      break;
    } else {
      $n_0 = $9;
      label = 2;
      break;
    }
   case 4:
    $11 = $states + ($n_0 << 2) | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    HEAP32[$11 >> 2] = 1;
    $15 = $extra_glyphs + ($n_0 << 2) | 0;
    HEAP32[$15 >> 2] = $glyph;
    label = 6;
    break;
   case 6:
    return;
  }
}
function _ft_black_new($memory, $araster) {
  $memory = $memory | 0;
  $araster = $araster | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$araster >> 2] = 0;
    $1 = _ft_mem_alloc($memory, 24, $error) | 0;
    $2 = HEAP32[$error >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $5 = $1;
    $6 = $memory;
    $7 = $1 + 8 | 0;
    $8 = $7;
    HEAP32[$8 >> 2] = $6;
    HEAP32[$araster >> 2] = $5;
    label = 3;
    break;
   case 3:
    $10 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $10 | 0;
  }
  return 0;
}
function _ft_black_render($raster, $params) {
  $raster = $raster | 0;
  $params = $params | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $82 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $params + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $params | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($raster | 0) == 0;
    if ($5) {
      $_0 = 96;
      label = 17;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $raster | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      $_0 = 96;
      label = 17;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = $raster + 4 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      $_0 = 96;
      label = 17;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $15 = ($2 | 0) == 0;
    if ($15) {
      $_0 = 20;
      label = 17;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = $2 + 2 | 0;
    $18 = $17;
    $19 = HEAP16[$18 >> 1] | 0;
    $20 = $19 << 16 >> 16;
    $21 = $19 << 16 >> 16 == 0;
    if ($21) {
      $_0 = 0;
      label = 17;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $23 = $2;
    $24 = HEAP16[$23 >> 1] | 0;
    $25 = $24 << 16 >> 16;
    $26 = $24 << 16 >> 16 < 1;
    if ($26) {
      $_0 = 0;
      label = 17;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $28 = $2 + 12 | 0;
    $29 = $28;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = ($30 | 0) == 0;
    if ($31) {
      $_0 = 20;
      label = 17;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $33 = $2 + 4 | 0;
    $34 = $33;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = ($35 | 0) == 0;
    if ($36) {
      $_0 = 20;
      label = 17;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $38 = $25 - 1 | 0;
    $39 = $30 + ($38 << 1) | 0;
    $40 = HEAP16[$39 >> 1] | 0;
    $41 = $40 << 16 >> 16;
    $42 = $41 + 1 | 0;
    $43 = ($20 | 0) == ($42 | 0);
    if ($43) {
      label = 10;
      break;
    } else {
      $_0 = 20;
      label = 17;
      break;
    }
   case 10:
    $45 = $raster + 12 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $params + 8 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $48 & 2;
    $50 = ($49 | 0) == 0;
    if ($50) {
      label = 11;
      break;
    } else {
      $_0 = 19;
      label = 17;
      break;
    }
   case 11:
    $52 = ($4 | 0) == 0;
    if ($52) {
      $_0 = 20;
      label = 17;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $54 = $4 + 4 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = ($55 | 0) == 0;
    if ($56) {
      $_0 = 0;
      label = 17;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $58 = $4 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = ($59 | 0) == 0;
    if ($60) {
      $_0 = 0;
      label = 17;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $62 = $4 + 12 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = ($63 | 0) == 0;
    if ($64) {
      $_0 = 20;
      label = 17;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $66 = $46 + 128 | 0;
    $67 = $66;
    _memcpy($67 | 0, $2 | 0, 20);
    $68 = $46 + 104 | 0;
    $69 = $68;
    $70 = $4;
    _memcpy($69 | 0, $70 | 0, 24);
    $71 = HEAP32[$7 >> 2] | 0;
    $72 = $71;
    $73 = $46 + 28 | 0;
    HEAP32[$73 >> 2] = $72;
    $74 = HEAP32[$11 >> 2] | 0;
    $75 = $74 >>> 2;
    $76 = $72 + ($75 << 2) | 0;
    $77 = $46 + 32 | 0;
    HEAP32[$77 >> 2] = $76;
    $78 = HEAP32[$47 >> 2] | 0;
    $79 = $78 & 1;
    $80 = ($79 | 0) == 0;
    if ($80) {
      label = 16;
      break;
    } else {
      $_0 = 19;
      label = 17;
      break;
    }
   case 16:
    $82 = _Render_Glyph($46) | 0;
    $_0 = $82;
    label = 17;
    break;
   case 17:
    return $_0 | 0;
  }
  return 0;
}
function _ft_black_done($raster) {
  $raster = $raster | 0;
  _ft_mem_free(HEAP32[$raster + 8 >> 2] | 0, $raster);
  return;
}
function _ft_raster1_init($render) {
  $render = $render | 0;
  var $2 = 0;
  $2 = HEAP32[$render + 4 >> 2] | 0;
  FUNCTION_TABLE_viii[HEAP32[(HEAP32[(HEAP32[$render + 20 >> 2] | 0) + 56 >> 2] | 0) + 8 >> 2] & 1023](HEAP32[$render + 60 >> 2] | 0, HEAP32[$2 + 172 >> 2] | 0, HEAP32[$2 + 176 >> 2] | 0);
  return 0;
}
function _ft_raster1_render($render, $slot, $mode, $origin) {
  $render = $render | 0;
  $slot = $slot | 0;
  $mode = $mode | 0;
  $origin = $origin | 0;
  var $error = 0, $cbox = 0, $params = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $14 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $pitch_0 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $117 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 68 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $cbox = __stackBase__ + 4 | 0;
    $params = __stackBase__ + 20 | 0;
    $1 = $slot + 72 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $render + 24 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) == ($4 | 0);
    if ($5) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    HEAP32[$error >> 2] = 6;
    label = 18;
    break;
   case 3:
    $8 = ($mode | 0) == 2;
    $9 = $render + 20 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    if ($8) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $12 = ($10 | 0) == 5256248;
    if ($12) {
      $_0 = 19;
      label = 19;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $14 = ($10 | 0) == 5256188;
    if ($14) {
      $_0 = 19;
      label = 19;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $16 = $slot + 108 | 0;
    $17 = ($origin | 0) == 0;
    if ($17) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $19 = $origin | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $origin + 4 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    _FT_Outline_Translate($16, $20, $22);
    label = 8;
    break;
   case 8:
    _FT_Outline_Get_CBox($16, $cbox);
    $24 = $cbox | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $25 & -64;
    HEAP32[$24 >> 2] = $26;
    $27 = $cbox + 4 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $28 & -64;
    HEAP32[$27 >> 2] = $29;
    $30 = $cbox + 8 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $31 + 63 | 0;
    $33 = $32 & -64;
    HEAP32[$30 >> 2] = $33;
    $34 = $cbox + 12 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $35 + 63 | 0;
    $37 = $36 & -64;
    HEAP32[$34 >> 2] = $37;
    $38 = HEAP32[$30 >> 2] | 0;
    $39 = HEAP32[$24 >> 2] | 0;
    $40 = $38 - $39 | 0;
    $41 = $40 >> 6;
    $42 = HEAP32[$27 >> 2] | 0;
    $43 = $37 - $42 | 0;
    $44 = $43 >> 6;
    $45 = $slot + 76 | 0;
    $46 = $render + 8 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $slot + 156 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = $49 + 4 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = $51 & 1;
    $53 = ($52 | 0) == 0;
    if ($53) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $55 = $slot + 88 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    _ft_mem_free($47, $56);
    HEAP32[$55 >> 2] = 0;
    $57 = HEAP32[$48 >> 2] | 0;
    $58 = $57 + 4 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = $59 & -2;
    HEAP32[$58 >> 2] = $60;
    label = 10;
    break;
   case 10:
    $62 = $mode & 2;
    $63 = ($62 | 0) == 0;
    if ($63) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $65 = $41 + 3 | 0;
    $66 = $65 & -4;
    $67 = $slot + 94 | 0;
    HEAP8[$67] = 2;
    $68 = $slot + 92 | 0;
    HEAP16[$68 >> 1] = 256;
    $pitch_0 = $66;
    label = 13;
    break;
   case 12:
    $70 = $41 + 15 | 0;
    $71 = $70 >>> 4;
    $72 = $71 << 1;
    $73 = $slot + 94 | 0;
    HEAP8[$73] = 1;
    $pitch_0 = $72;
    label = 13;
    break;
   case 13:
    $75 = $slot + 80 | 0;
    HEAP32[$75 >> 2] = $41;
    $76 = $45 | 0;
    HEAP32[$76 >> 2] = $44;
    $77 = $slot + 84 | 0;
    HEAP32[$77 >> 2] = $pitch_0;
    $78 = _ft_mem_realloc($47, $44, 0, $pitch_0, 0, $error) | 0;
    $79 = $slot + 88 | 0;
    HEAP32[$79 >> 2] = $78;
    $80 = HEAP32[$error >> 2] | 0;
    $81 = ($80 | 0) == 0;
    if ($81) {
      label = 14;
      break;
    } else {
      label = 18;
      break;
    }
   case 14:
    $83 = HEAP32[$48 >> 2] | 0;
    $84 = $83 + 4 | 0;
    $85 = HEAP32[$84 >> 2] | 0;
    $86 = $85 | 1;
    HEAP32[$84 >> 2] = $86;
    $87 = HEAP32[$24 >> 2] | 0;
    $88 = -$87 | 0;
    $89 = HEAP32[$27 >> 2] | 0;
    $90 = -$89 | 0;
    _FT_Outline_Translate($16, $88, $90);
    $91 = $params | 0;
    HEAP32[$91 >> 2] = $45;
    $92 = $16;
    $93 = $params + 4 | 0;
    HEAP32[$93 >> 2] = $92;
    $94 = $params + 8 | 0;
    HEAP32[$94 >> 2] = 0;
    $95 = $slot + 94 | 0;
    $96 = HEAP8[$95] | 0;
    $97 = $96 << 24 >> 24 == 2;
    if ($97) {
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 15:
    HEAP32[$94 >> 2] = 1;
    label = 16;
    break;
   case 16:
    $100 = $render + 64 | 0;
    $101 = HEAP32[$100 >> 2] | 0;
    $102 = $render + 60 | 0;
    $103 = HEAP32[$102 >> 2] | 0;
    $104 = FUNCTION_TABLE_iii[$101 & 1023]($103, $params) | 0;
    HEAP32[$error >> 2] = $104;
    $105 = HEAP32[$24 >> 2] | 0;
    $106 = HEAP32[$27 >> 2] | 0;
    _FT_Outline_Translate($16, $105, $106);
    $107 = HEAP32[$error >> 2] | 0;
    $108 = ($107 | 0) == 0;
    if ($108) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    HEAP32[$1 >> 2] = 1651078259;
    $110 = HEAP32[$24 >> 2] | 0;
    $111 = $110 >> 6;
    $112 = $slot + 100 | 0;
    HEAP32[$112 >> 2] = $111;
    $113 = HEAP32[$34 >> 2] | 0;
    $114 = $113 >> 6;
    $115 = $slot + 104 | 0;
    HEAP32[$115 >> 2] = $114;
    label = 18;
    break;
   case 18:
    $117 = HEAP32[$error >> 2] | 0;
    $_0 = $117;
    label = 19;
    break;
   case 19:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _ft_raster1_transform($render, $slot, $matrix, $delta) {
  $render = $render | 0;
  $slot = $slot | 0;
  $matrix = $matrix | 0;
  $delta = $delta | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $9 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $slot + 72 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $render + 24 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) == ($4 | 0);
    if ($5) {
      label = 2;
      break;
    } else {
      $error_0 = 6;
      label = 6;
      break;
    }
   case 2:
    $7 = ($matrix | 0) == 0;
    if ($7) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = $slot + 108 | 0;
    _FT_Outline_Transform($9, $matrix);
    label = 4;
    break;
   case 4:
    $11 = ($delta | 0) == 0;
    if ($11) {
      $error_0 = 0;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $13 = $slot + 108 | 0;
    $14 = $delta | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $delta + 4 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    _FT_Outline_Translate($13, $15, $17);
    $error_0 = 0;
    label = 6;
    break;
   case 6:
    return $error_0 | 0;
  }
  return 0;
}
function _ft_raster1_get_cbox($render, $slot, $cbox) {
  $render = $render | 0;
  $slot = $slot | 0;
  $cbox = $cbox | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cbox;
    _memset($1 | 0, 0, 16);
    $2 = $slot + 72 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $render + 24 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($3 | 0) == ($5 | 0);
    if ($6) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $8 = $slot + 108 | 0;
    _FT_Outline_Get_CBox($8, $cbox);
    label = 3;
    break;
   case 3:
    return;
  }
}
function _ft_raster1_set_mode($render, $mode_tag, $data) {
  $render = $render | 0;
  $mode_tag = $mode_tag | 0;
  $data = $data | 0;
  return FUNCTION_TABLE_iiii[HEAP32[(HEAP32[(HEAP32[$render + 20 >> 2] | 0) + 56 >> 2] | 0) + 12 >> 2] & 1023](HEAP32[$render + 60 >> 2] | 0, $mode_tag, $data) | 0;
}
function _Render_Glyph($worker) {
  $worker = $worker | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $_ = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, $23 = 0, $_lobit = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 144 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 & 256;
    _Set_High_Precision($worker, $3);
    $4 = $worker + 12 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $worker + 24 | 0;
    HEAP32[$6 >> 2] = $5;
    $7 = HEAP32[$1 >> 2] | 0;
    $8 = $7 & 8;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $11 = $worker + 180 | 0;
    HEAP8[$11] = 2;
    label = 5;
    break;
   case 3:
    $13 = $7 & 16;
    $14 = ($13 | 0) == 0;
    $15 = $worker + 180 | 0;
    $_ = $14 ? 0 : 4;
    HEAP8[$15] = $_;
    $16 = HEAP32[$1 >> 2] | 0;
    $17 = $16 & 32;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $20 = $_ | 1;
    HEAP8[$15] = $20;
    label = 5;
    break;
   case 5:
    $22 = HEAP32[$1 >> 2] | 0;
    $23 = $22 >>> 9;
    $_lobit = $23 & 1;
    $24 = $_lobit ^ 1;
    $25 = $24 & 255;
    $26 = $worker + 181 | 0;
    HEAP8[$26] = $25;
    $27 = $worker + 164 | 0;
    HEAP32[$27 >> 2] = 692;
    $28 = $worker + 168 | 0;
    HEAP32[$28 >> 2] = 624;
    $29 = $worker + 172 | 0;
    HEAP32[$29 >> 2] = 218;
    $30 = $worker + 176 | 0;
    HEAP32[$30 >> 2] = 782;
    $31 = $worker + 1024 | 0;
    HEAP32[$31 >> 2] = 0;
    $32 = $worker + 960 | 0;
    HEAP16[$32 >> 1] = 0;
    $33 = $worker + 104 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $34 + 65535 | 0;
    $36 = $35 & 65535;
    $37 = $worker + 962 | 0;
    HEAP16[$37 >> 1] = $36;
    $38 = $worker + 108 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = $39 & 65535;
    $41 = $worker + 56 | 0;
    HEAP16[$41 >> 1] = $40;
    $42 = $worker + 116 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $worker + 60 | 0;
    HEAP32[$44 >> 2] = $43;
    $45 = _Render_Single_Pass($worker, 0) | 0;
    $46 = ($45 | 0) == 0;
    if ($46) {
      label = 6;
      break;
    } else {
      $_0 = $45;
      label = 10;
      break;
    }
   case 6:
    $48 = HEAP8[$26] | 0;
    $49 = $48 << 24 >> 24 == 0;
    if ($49) {
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $51 = $worker + 180 | 0;
    $52 = HEAP8[$51] | 0;
    $53 = $52 << 24 >> 24 == 2;
    if ($53) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    HEAP32[$27 >> 2] = 250;
    HEAP32[$28 >> 2] = 128;
    HEAP32[$29 >> 2] = 532;
    HEAP32[$30 >> 2] = 906;
    HEAP32[$31 >> 2] = 0;
    HEAP16[$32 >> 1] = 0;
    $55 = HEAP32[$38 >> 2] | 0;
    $56 = $55 + 65535 | 0;
    $57 = $56 & 65535;
    HEAP16[$37 >> 1] = $57;
    $58 = _Render_Single_Pass($worker, 1) | 0;
    $59 = ($58 | 0) == 0;
    if ($59) {
      label = 9;
      break;
    } else {
      $_0 = $58;
      label = 10;
      break;
    }
   case 9:
    $_0 = 0;
    label = 10;
    break;
   case 10:
    return $_0 | 0;
  }
  return 0;
}
function _Vertical_Sweep_Span($worker, $y, $x1, $x2, $left, $right) {
  $worker = $worker | 0;
  $y = $y | 0;
  $x1 = $x1 | 0;
  $x2 = $x2 | 0;
  $left = $left | 0;
  $right = $right | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $e2_0 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $_ = 0, $27 = 0, $28 = 0, $e2_1 = 0, $29 = 0, $sext = 0, $30 = 0, $31 = 0, $sext43 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $_sum = 0, $56 = 0, $57 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $c2_044 = 0, $64 = 0, $_sum46 = 0, $65 = 0, $_op = 0, $sext50 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $scevgep48 = 0, $70 = 0, $sext51 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $sext49 = 0, $75 = 0, $76 = 0, $_pn = 0, $_lcssa = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = -$2 | 0;
    $4 = $x1 - 1 | 0;
    $5 = $4 + $2 | 0;
    $6 = $5 & $3;
    $7 = $worker | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $6 >> $8;
    $10 = $x2 - $x1 | 0;
    $11 = $10 - $2 | 0;
    $12 = $worker + 20 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = ($11 | 0) > ($13 | 0);
    if ($14) {
      label = 2;
      break;
    } else {
      $e2_0 = $9;
      label = 3;
      break;
    }
   case 2:
    $16 = $3 & $x2;
    $17 = $16 >> $8;
    $e2_0 = $17;
    label = 3;
    break;
   case 3:
    $19 = ($e2_0 | 0) > -1;
    if ($19) {
      label = 4;
      break;
    } else {
      label = 14;
      break;
    }
   case 4:
    $21 = $worker + 56 | 0;
    $22 = HEAP16[$21 >> 1] | 0;
    $23 = $22 & 65535;
    $24 = ($9 | 0) < ($23 | 0);
    if ($24) {
      label = 5;
      break;
    } else {
      label = 14;
      break;
    }
   case 5:
    $26 = ($9 | 0) < 0;
    $_ = $26 ? 0 : $9;
    $27 = ($e2_0 | 0) < ($23 | 0);
    $28 = $23 - 1 | 0;
    $e2_1 = $27 ? $e2_0 : $28;
    $29 = $_ >>> 3;
    $sext = $29 << 16;
    $30 = $sext >> 16;
    $31 = $e2_1 >>> 3;
    $sext43 = $31 << 16;
    $32 = $sext43 >> 16;
    $33 = $_ & 7;
    $34 = 255 >>> ($33 >>> 0);
    $35 = $e2_1 & 7;
    $36 = 127 >>> ($35 >>> 0);
    $37 = $36 ^ 255;
    $38 = $worker + 158 | 0;
    $39 = HEAP16[$38 >> 1] | 0;
    $40 = $39 << 16 >> 16;
    $41 = ($40 | 0) > ($30 | 0);
    if ($41) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $43 = $30 & 65535;
    HEAP16[$38 >> 1] = $43;
    label = 7;
    break;
   case 7:
    $45 = $worker + 160 | 0;
    $46 = HEAP16[$45 >> 1] | 0;
    $47 = $46 << 16 >> 16;
    $48 = ($47 | 0) < ($32 | 0);
    if ($48) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $50 = $32 & 65535;
    HEAP16[$45 >> 1] = $50;
    label = 9;
    break;
   case 9:
    $52 = $worker + 60 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $worker + 148 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $_sum = $55 + $30 | 0;
    $56 = $53 + $_sum | 0;
    $57 = $32 - $30 | 0;
    $58 = ($57 | 0) > 0;
    if ($58) {
      label = 10;
      break;
    } else {
      label = 13;
      break;
    }
   case 10:
    $60 = HEAP8[$56] | 0;
    $61 = $60 & 255;
    $62 = $61 | $34;
    $63 = $62 & 255;
    HEAP8[$56] = $63;
    $c2_044 = $57 - 1 | 0;
    $64 = ($c2_044 | 0) > 0;
    $_sum46 = $_sum + 1 | 0;
    if ($64) {
      label = 11;
      break;
    } else {
      $_pn = $_sum46;
      label = 12;
      break;
    }
   case 11:
    $65 = ($9 | 0) > 0;
    $_op = $9 >>> 3;
    $sext50 = $_op << 16;
    $66 = $sext50 >> 16;
    $67 = $65 ? $66 : 0;
    $68 = $55 + $67 | 0;
    $69 = $68 + 1 | 0;
    $scevgep48 = $53 + $69 | 0;
    $70 = $e2_1 >>> 3;
    $sext51 = $70 << 16;
    $71 = $sext51 >> 16;
    $72 = $71 - 1 | 0;
    $73 = $72 - $67 | 0;
    _memset($scevgep48 | 0, -1 | 0, $73 | 0);
    $74 = $e2_1 >>> 3;
    $sext49 = $74 << 16;
    $75 = $sext49 >> 16;
    $76 = $55 + $75 | 0;
    $_pn = $76;
    label = 12;
    break;
   case 12:
    $_lcssa = $53 + $_pn | 0;
    $78 = HEAP8[$_lcssa] | 0;
    $79 = $78 & 255;
    $80 = $79 | $37;
    $81 = $80 & 255;
    HEAP8[$_lcssa] = $81;
    label = 14;
    break;
   case 13:
    $83 = $37 & $34;
    $84 = HEAP8[$56] | 0;
    $85 = $84 & 255;
    $86 = $85 | $83;
    $87 = $86 & 255;
    HEAP8[$56] = $87;
    label = 14;
    break;
   case 14:
    return;
  }
}
function _Horizontal_Sweep_Init($worker, $min, $max) {
  $worker = $worker | 0;
  $min = $min | 0;
  $max = $max | 0;
  return;
}
function _Horizontal_Sweep_Step($worker) {
  $worker = $worker | 0;
  return;
}
function _Vertical_Sweep_Drop($worker, $y, $x1, $x2, $left, $right) {
  $worker = $worker | 0;
  $y = $y | 0;
  $x1 = $x1 | 0;
  $x2 = $x2 | 0;
  $left = $left | 0;
  $right = $right | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $pxl_0 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $86 = 0, $87 = 0, $sext68 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $pxl_1 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $sext = 0, $115 = 0, $116 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $x1 - 1 | 0;
    $4 = $3 + $2 | 0;
    $5 = -$2 | 0;
    $6 = $4 & $5;
    $7 = $5 & $x2;
    $8 = ($6 | 0) > ($7 | 0);
    if ($8) {
      label = 2;
      break;
    } else {
      $pxl_1 = $6;
      label = 18;
      break;
    }
   case 2:
    $10 = $left + 12 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 & 7;
    $13 = $7 + $2 | 0;
    $14 = ($6 | 0) == ($13 | 0);
    if ($14) {
      label = 3;
      break;
    } else {
      label = 25;
      break;
    }
   case 3:
    if (($12 | 0) == 4) {
      label = 4;
      break;
    } else if (($12 | 0) == 1 | ($12 | 0) == 5) {
      label = 5;
      break;
    } else if (($12 | 0) == 0) {
      $pxl_0 = $7;
      label = 15;
      break;
    } else {
      label = 25;
      break;
    }
   case 4:
    $17 = $x1 - 1 | 0;
    $18 = $17 + $x2 | 0;
    $19 = ($18 | 0) / 2 & -1;
    $20 = $worker + 8 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $21 + $19 | 0;
    $23 = $22 & $5;
    $pxl_0 = $23;
    label = 15;
    break;
   case 5:
    $25 = $left + 28 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = ($26 | 0) == ($right | 0);
    if ($27) {
      label = 6;
      break;
    } else {
      label = 9;
      break;
    }
   case 6:
    $29 = $left + 16 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = ($30 | 0) < 1;
    if ($31) {
      label = 7;
      break;
    } else {
      label = 9;
      break;
    }
   case 7:
    $33 = HEAP32[$10 >> 2] | 0;
    $34 = $33 & 16;
    $35 = ($34 | 0) == 0;
    if ($35) {
      label = 25;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $37 = $x2 - $x1 | 0;
    $38 = $worker + 8 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = ($37 | 0) < ($39 | 0);
    if ($40) {
      label = 25;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $42 = $right + 28 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = ($43 | 0) == ($left | 0);
    if ($44) {
      label = 10;
      break;
    } else {
      label = 13;
      break;
    }
   case 10:
    $46 = $left + 20 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $y << 16 >> 16;
    $49 = ($47 | 0) == ($48 | 0);
    if ($49) {
      label = 11;
      break;
    } else {
      label = 13;
      break;
    }
   case 11:
    $51 = HEAP32[$10 >> 2] | 0;
    $52 = $51 & 32;
    $53 = ($52 | 0) == 0;
    if ($53) {
      label = 25;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $55 = $x2 - $x1 | 0;
    $56 = $worker + 8 | 0;
    $57 = HEAP32[$56 >> 2] | 0;
    $58 = ($55 | 0) < ($57 | 0);
    if ($58) {
      label = 25;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $60 = ($12 | 0) == 1;
    if ($60) {
      $pxl_0 = $7;
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $62 = $x1 - 1 | 0;
    $63 = $62 + $x2 | 0;
    $64 = ($63 | 0) / 2 & -1;
    $65 = $worker + 8 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = $66 + $64 | 0;
    $68 = HEAP32[$1 >> 2] | 0;
    $69 = -$68 | 0;
    $70 = $67 & $69;
    $pxl_0 = $70;
    label = 15;
    break;
   case 15:
    $72 = ($pxl_0 | 0) == ($6 | 0);
    $73 = $72 ? $7 : $6;
    $74 = $worker | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    $76 = $73 >> $75;
    $77 = $76 >>> 3;
    $78 = $76 & 7;
    $79 = ($76 | 0) > -1;
    if ($79) {
      label = 16;
      break;
    } else {
      $pxl_1 = $pxl_0;
      label = 18;
      break;
    }
   case 16:
    $81 = $worker + 56 | 0;
    $82 = HEAP16[$81 >> 1] | 0;
    $83 = $82 & 65535;
    $84 = ($76 | 0) < ($83 | 0);
    if ($84) {
      label = 17;
      break;
    } else {
      $pxl_1 = $pxl_0;
      label = 18;
      break;
    }
   case 17:
    $86 = $worker + 148 | 0;
    $87 = HEAP32[$86 >> 2] | 0;
    $sext68 = $77 << 16;
    $88 = $sext68 >> 16;
    $89 = $87 + $88 | 0;
    $90 = $worker + 60 | 0;
    $91 = HEAP32[$90 >> 2] | 0;
    $92 = $91 + $89 | 0;
    $93 = HEAP8[$92] | 0;
    $94 = $93 & 255;
    $95 = 128 >>> ($78 >>> 0);
    $96 = $94 & $95;
    $97 = ($96 | 0) == 0;
    if ($97) {
      $pxl_1 = $pxl_0;
      label = 18;
      break;
    } else {
      label = 25;
      break;
    }
   case 18:
    $99 = $worker | 0;
    $100 = HEAP32[$99 >> 2] | 0;
    $101 = $pxl_1 >> $100;
    $102 = ($101 | 0) > -1;
    if ($102) {
      label = 19;
      break;
    } else {
      label = 25;
      break;
    }
   case 19:
    $104 = $worker + 56 | 0;
    $105 = HEAP16[$104 >> 1] | 0;
    $106 = $105 & 65535;
    $107 = ($101 | 0) < ($106 | 0);
    if ($107) {
      label = 20;
      break;
    } else {
      label = 25;
      break;
    }
   case 20:
    $109 = $101 >>> 3;
    $110 = $109 & 65535;
    $111 = $101 & 7;
    $112 = $worker + 158 | 0;
    $113 = HEAP16[$112 >> 1] | 0;
    $114 = $113 << 16 >> 16;
    $sext = $109 << 16;
    $115 = $sext >> 16;
    $116 = ($114 | 0) > ($115 | 0);
    if ($116) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    HEAP16[$112 >> 1] = $110;
    label = 22;
    break;
   case 22:
    $119 = $worker + 160 | 0;
    $120 = HEAP16[$119 >> 1] | 0;
    $121 = $120 << 16 >> 16;
    $122 = ($121 | 0) < ($115 | 0);
    if ($122) {
      label = 23;
      break;
    } else {
      label = 24;
      break;
    }
   case 23:
    HEAP16[$119 >> 1] = $110;
    label = 24;
    break;
   case 24:
    $125 = 128 >>> ($111 >>> 0);
    $126 = $worker + 148 | 0;
    $127 = HEAP32[$126 >> 2] | 0;
    $128 = $127 + $115 | 0;
    $129 = $worker + 60 | 0;
    $130 = HEAP32[$129 >> 2] | 0;
    $131 = $130 + $128 | 0;
    $132 = HEAP8[$131] | 0;
    $133 = $132 & 255;
    $134 = $133 | $125;
    $135 = $134 & 255;
    HEAP8[$131] = $135;
    label = 25;
    break;
   case 25:
    return;
  }
}
function _Vertical_Sweep_Step($worker) {
  $worker = $worker | 0;
  var $4 = 0;
  $4 = $worker + 148 | 0;
  HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + (HEAP16[$worker + 156 >> 1] << 16 >> 16) | 0;
  return;
}
function _Horizontal_Sweep_Span($worker, $y, $x1, $x2, $left, $right) {
  $worker = $worker | 0;
  $y = $y | 0;
  $x1 = $x1 | 0;
  $x2 = $x2 | 0;
  $left = $left | 0;
  $right = $right | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $_sum = 0, $31 = 0, $33 = 0, $34 = 0, $_sum24 = 0, $_sum24_pn = 0, $p_0 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $x2 - $x1 | 0;
    $2 = $worker + 4 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = ($1 | 0) < ($3 | 0);
    if ($4) {
      label = 2;
      break;
    } else {
      label = 8;
      break;
    }
   case 2:
    $6 = $x1 - 1 | 0;
    $7 = $6 + $3 | 0;
    $8 = -$3 | 0;
    $9 = $7 & $8;
    $10 = $8 & $x2;
    $11 = ($9 | 0) == ($10 | 0);
    if ($11) {
      label = 3;
      break;
    } else {
      label = 8;
      break;
    }
   case 3:
    $13 = $worker + 60 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $y << 16 >> 16;
    $16 = $15 >> 3;
    $17 = $15 & 7;
    $18 = 128 >>> ($17 >>> 0);
    $19 = $worker | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $9 >> $20;
    $22 = ($21 | 0) > -1;
    if ($22) {
      label = 4;
      break;
    } else {
      label = 8;
      break;
    }
   case 4:
    $24 = $worker + 104 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = ($21 | 0) < ($25 | 0);
    if ($26) {
      label = 5;
      break;
    } else {
      label = 8;
      break;
    }
   case 5:
    $28 = $worker + 112 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = Math_imul($29, $21);
    $_sum = $16 - $30 | 0;
    $31 = ($29 | 0) > 0;
    if ($31) {
      label = 6;
      break;
    } else {
      $_sum24_pn = $_sum;
      label = 7;
      break;
    }
   case 6:
    $33 = $25 - 1 | 0;
    $34 = Math_imul($29, $33);
    $_sum24 = $_sum + $34 | 0;
    $_sum24_pn = $_sum24;
    label = 7;
    break;
   case 7:
    $p_0 = $14 + $_sum24_pn | 0;
    $36 = HEAP8[$p_0] | 0;
    $37 = $36 & 255;
    $38 = $37 | $18;
    $39 = $38 & 255;
    HEAP8[$p_0] = $39;
    label = 8;
    break;
   case 8:
    return;
  }
}
function _Horizontal_Sweep_Drop($worker, $y, $x1, $x2, $left, $right) {
  $worker = $worker | 0;
  $y = $y | 0;
  $x1 = $x1 | 0;
  $x2 = $x2 | 0;
  $left = $left | 0;
  $right = $right | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $pxl_0 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $_sum72 = 0, $87 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $_sum73 = 0, $_sum73_pn = 0, $bits_0 = 0, $94 = 0, $96 = 0, $97 = 0, $98 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $pxl_1 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $116 = 0, $117 = 0, $118 = 0, $120 = 0, $121 = 0, $122 = 0, $_sum = 0, $123 = 0, $125 = 0, $126 = 0, $_sum71 = 0, $_sum71_pn = 0, $bits_1 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $x1 - 1 | 0;
    $4 = $3 + $2 | 0;
    $5 = -$2 | 0;
    $6 = $4 & $5;
    $7 = $5 & $x2;
    $8 = ($6 | 0) > ($7 | 0);
    if ($8) {
      label = 2;
      break;
    } else {
      $pxl_1 = $6;
      label = 20;
      break;
    }
   case 2:
    $10 = $left + 12 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 & 7;
    $13 = $7 + $2 | 0;
    $14 = ($6 | 0) == ($13 | 0);
    if ($14) {
      label = 3;
      break;
    } else {
      label = 25;
      break;
    }
   case 3:
    if (($12 | 0) == 4) {
      label = 4;
      break;
    } else if (($12 | 0) == 1 | ($12 | 0) == 5) {
      label = 5;
      break;
    } else if (($12 | 0) == 0) {
      $pxl_0 = $7;
      label = 15;
      break;
    } else {
      label = 25;
      break;
    }
   case 4:
    $17 = $x1 - 1 | 0;
    $18 = $17 + $x2 | 0;
    $19 = ($18 | 0) / 2 & -1;
    $20 = $worker + 8 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $21 + $19 | 0;
    $23 = $22 & $5;
    $pxl_0 = $23;
    label = 15;
    break;
   case 5:
    $25 = $left + 28 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = ($26 | 0) == ($right | 0);
    if ($27) {
      label = 6;
      break;
    } else {
      label = 9;
      break;
    }
   case 6:
    $29 = $left + 16 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = ($30 | 0) < 1;
    if ($31) {
      label = 7;
      break;
    } else {
      label = 9;
      break;
    }
   case 7:
    $33 = HEAP32[$10 >> 2] | 0;
    $34 = $33 & 16;
    $35 = ($34 | 0) == 0;
    if ($35) {
      label = 25;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $37 = $x2 - $x1 | 0;
    $38 = $worker + 8 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = ($37 | 0) < ($39 | 0);
    if ($40) {
      label = 25;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $42 = $right + 28 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = ($43 | 0) == ($left | 0);
    if ($44) {
      label = 10;
      break;
    } else {
      label = 13;
      break;
    }
   case 10:
    $46 = $left + 20 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $y << 16 >> 16;
    $49 = ($47 | 0) == ($48 | 0);
    if ($49) {
      label = 11;
      break;
    } else {
      label = 13;
      break;
    }
   case 11:
    $51 = HEAP32[$10 >> 2] | 0;
    $52 = $51 & 32;
    $53 = ($52 | 0) == 0;
    if ($53) {
      label = 25;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $55 = $x2 - $x1 | 0;
    $56 = $worker + 8 | 0;
    $57 = HEAP32[$56 >> 2] | 0;
    $58 = ($55 | 0) < ($57 | 0);
    if ($58) {
      label = 25;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $60 = ($12 | 0) == 1;
    if ($60) {
      $pxl_0 = $7;
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $62 = $x1 - 1 | 0;
    $63 = $62 + $x2 | 0;
    $64 = ($63 | 0) / 2 & -1;
    $65 = $worker + 8 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = $66 + $64 | 0;
    $68 = HEAP32[$1 >> 2] | 0;
    $69 = -$68 | 0;
    $70 = $67 & $69;
    $pxl_0 = $70;
    label = 15;
    break;
   case 15:
    $72 = ($pxl_0 | 0) == ($6 | 0);
    $73 = $72 ? $7 : $6;
    $74 = $worker | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    $76 = $73 >> $75;
    $77 = $worker + 60 | 0;
    $78 = HEAP32[$77 >> 2] | 0;
    $79 = $y << 16 >> 16;
    $80 = $79 >> 3;
    $81 = $79 & 7;
    $82 = 128 >>> ($81 >>> 0);
    $83 = $worker + 104 | 0;
    $84 = $worker + 112 | 0;
    $85 = HEAP32[$84 >> 2] | 0;
    $86 = Math_imul($76, $85);
    $_sum72 = $80 - $86 | 0;
    $87 = ($85 | 0) > 0;
    if ($87) {
      label = 16;
      break;
    } else {
      $_sum73_pn = $_sum72;
      label = 17;
      break;
    }
   case 16:
    $89 = $83 | 0;
    $90 = HEAP32[$89 >> 2] | 0;
    $91 = $90 - 1 | 0;
    $92 = Math_imul($91, $85);
    $_sum73 = $92 + $_sum72 | 0;
    $_sum73_pn = $_sum73;
    label = 17;
    break;
   case 17:
    $bits_0 = $78 + $_sum73_pn | 0;
    $94 = ($76 | 0) > -1;
    if ($94) {
      label = 18;
      break;
    } else {
      $pxl_1 = $pxl_0;
      label = 20;
      break;
    }
   case 18:
    $96 = $83 | 0;
    $97 = HEAP32[$96 >> 2] | 0;
    $98 = ($76 | 0) < ($97 | 0);
    if ($98) {
      label = 19;
      break;
    } else {
      $pxl_1 = $pxl_0;
      label = 20;
      break;
    }
   case 19:
    $100 = HEAP8[$bits_0] | 0;
    $101 = $100 & 255;
    $102 = $82 & $101;
    $103 = ($102 | 0) == 0;
    if ($103) {
      $pxl_1 = $pxl_0;
      label = 20;
      break;
    } else {
      label = 25;
      break;
    }
   case 20:
    $105 = $worker + 60 | 0;
    $106 = HEAP32[$105 >> 2] | 0;
    $107 = $y << 16 >> 16;
    $108 = $107 >> 3;
    $109 = $107 & 7;
    $110 = 128 >>> ($109 >>> 0);
    $111 = $worker | 0;
    $112 = HEAP32[$111 >> 2] | 0;
    $113 = $pxl_1 >> $112;
    $114 = ($113 | 0) > -1;
    if ($114) {
      label = 21;
      break;
    } else {
      label = 25;
      break;
    }
   case 21:
    $116 = $worker + 104 | 0;
    $117 = HEAP32[$116 >> 2] | 0;
    $118 = ($113 | 0) < ($117 | 0);
    if ($118) {
      label = 22;
      break;
    } else {
      label = 25;
      break;
    }
   case 22:
    $120 = $worker + 112 | 0;
    $121 = HEAP32[$120 >> 2] | 0;
    $122 = Math_imul($121, $113);
    $_sum = $108 - $122 | 0;
    $123 = ($121 | 0) > 0;
    if ($123) {
      label = 23;
      break;
    } else {
      $_sum71_pn = $_sum;
      label = 24;
      break;
    }
   case 23:
    $125 = $117 - 1 | 0;
    $126 = Math_imul($121, $125);
    $_sum71 = $_sum + $126 | 0;
    $_sum71_pn = $_sum71;
    label = 24;
    break;
   case 24:
    $bits_1 = $106 + $_sum71_pn | 0;
    $128 = HEAP8[$bits_1] | 0;
    $129 = $128 & 255;
    $130 = $129 | $110;
    $131 = $130 & 255;
    HEAP8[$bits_1] = $131;
    label = 25;
    break;
   case 25:
    return;
  }
}
function _Render_Single_Pass($worker, $flipped) {
  $worker = $worker | 0;
  $flipped = $flipped | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $sext = 0, $44 = 0, $45 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $66 = 0, $68 = 0, $69 = 0, $storemerge = 0, $70 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 1024 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) > -1;
    if ($3) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 14;
      break;
    }
   case 2:
    $4 = $worker + 4 | 0;
    $5 = $worker + 80 | 0;
    $6 = $worker + 76 | 0;
    $7 = $worker + 28 | 0;
    $8 = $worker + 40 | 0;
    $9 = $worker + 44 | 0;
    $10 = $flipped << 24 >> 24;
    $11 = $worker + 92 | 0;
    $13 = $2;
    label = 3;
    break;
   case 3:
    $14 = $worker + 960 + ($13 << 2) + 2 | 0;
    $15 = HEAP16[$14 >> 1] | 0;
    $16 = $15 << 16 >> 16;
    $17 = HEAP32[$4 >> 2] | 0;
    $18 = Math_imul($16, $17);
    HEAP32[$5 >> 2] = $18;
    $19 = HEAP32[$1 >> 2] | 0;
    $20 = $worker + 960 + ($19 << 2) | 0;
    $21 = HEAP16[$20 >> 1] | 0;
    $22 = $21 << 16 >> 16;
    $23 = HEAP32[$4 >> 2] | 0;
    $24 = Math_imul($22, $23);
    HEAP32[$6 >> 2] = $24;
    $25 = HEAP32[$7 >> 2] | 0;
    HEAP32[$8 >> 2] = $25;
    HEAP32[$9 >> 2] = 0;
    $26 = _Convert_Glyph($worker, $10) | 0;
    $27 = $26 << 24 >> 24 == 0;
    if ($27) {
      label = 9;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $29 = HEAP32[$9 >> 2] | 0;
    $30 = ($29 | 0) == 98;
    if ($30) {
      label = 5;
      break;
    } else {
      $_0 = 1;
      label = 14;
      break;
    }
   case 5:
    HEAP32[$9 >> 2] = 0;
    $32 = HEAP32[$1 >> 2] | 0;
    $33 = $worker + 960 + ($32 << 2) | 0;
    $34 = HEAP16[$33 >> 1] | 0;
    $35 = $worker + 960 + ($32 << 2) + 2 | 0;
    $36 = HEAP16[$35 >> 1] | 0;
    $37 = $34 << 16 >> 16;
    $38 = $36 << 16 >> 16;
    $39 = $38 + $37 | 0;
    $40 = ($39 | 0) / 2 & -1;
    $41 = $40 & 65535;
    $42 = ($32 | 0) > 6;
    if ($42) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $sext = $40 << 16;
    $44 = $sext >> 16;
    $45 = ($44 | 0) < ($37 | 0);
    if ($45) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    HEAP32[$1 >> 2] = 0;
    HEAP32[$9 >> 2] = 20;
    $_0 = 20;
    label = 14;
    break;
   case 8:
    $48 = $32 + 1 | 0;
    $49 = $worker + 960 + ($48 << 2) | 0;
    HEAP16[$49 >> 1] = $41;
    $50 = HEAP32[$1 >> 2] | 0;
    $51 = $50 + 1 | 0;
    $52 = $worker + 960 + ($51 << 2) + 2 | 0;
    HEAP16[$52 >> 1] = $36;
    $53 = $44 + 65535 | 0;
    $54 = $53 & 65535;
    $55 = HEAP32[$1 >> 2] | 0;
    $56 = $worker + 960 + ($55 << 2) + 2 | 0;
    HEAP16[$56 >> 1] = $54;
    $57 = HEAP32[$1 >> 2] | 0;
    $58 = $57 + 1 | 0;
    $storemerge = $58;
    label = 13;
    break;
   case 9:
    $60 = HEAP32[$11 >> 2] | 0;
    $61 = ($60 | 0) == 0;
    if ($61) {
      label = 12;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $63 = _Draw_Sweep($worker) | 0;
    $64 = $63 << 24 >> 24 == 0;
    if ($64) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $66 = HEAP32[$9 >> 2] | 0;
    $_0 = $66;
    label = 14;
    break;
   case 12:
    $68 = HEAP32[$1 >> 2] | 0;
    $69 = $68 - 1 | 0;
    $storemerge = $69;
    label = 13;
    break;
   case 13:
    HEAP32[$1 >> 2] = $storemerge;
    $70 = ($storemerge | 0) > -1;
    if ($70) {
      $13 = $storemerge;
      label = 3;
      break;
    } else {
      $_0 = 0;
      label = 14;
      break;
    }
   case 14:
    return $_0 | 0;
  }
  return 0;
}
function _Convert_Glyph($worker, $flipped) {
  $worker = $worker | 0;
  $flipped = $flipped | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $_c = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $start_047 = 0, $i_046 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $_not = 0, $74 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $_sink = 0, $86 = 0, $87 = 0, $88 = 0, $90 = 0, $91 = 0, $93 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $102 = 0, $103 = 0, $not_ = 0, $104 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 92 | 0;
    HEAP32[$1 >> 2] = 0;
    $2 = $worker + 87 | 0;
    HEAP8[$2] = 0;
    $3 = $worker + 86 | 0;
    HEAP8[$3] = 0;
    $4 = $worker + 32 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 - 32 | 0;
    $7 = $worker + 36 | 0;
    HEAP32[$7 >> 2] = $6;
    $8 = $worker + 48 | 0;
    HEAP32[$8 >> 2] = 0;
    $9 = $worker + 40 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10;
    $12 = $worker + 88 | 0;
    HEAP32[$12 >> 2] = $11;
    $13 = HEAP32[$9 >> 2] | 0;
    $14 = $10 + 8 | 0;
    $_c = $13;
    HEAP32[$14 >> 2] = $_c;
    $15 = $worker + 84 | 0;
    HEAP16[$15 >> 1] = 0;
    $16 = $worker + 128 | 0;
    $17 = HEAP16[$16 >> 1] | 0;
    $18 = $17 << 16 >> 16 > 0;
    if ($18) {
      label = 2;
      break;
    } else {
      label = 17;
      break;
    }
   case 2:
    $19 = $worker + 100 | 0;
    $20 = $worker + 96 | 0;
    $21 = $worker + 140 | 0;
    $22 = $worker + 72 | 0;
    $23 = $worker + 4 | 0;
    $24 = $worker + 76 | 0;
    $25 = $worker + 80 | 0;
    $26 = $worker + 8 | 0;
    $27 = $worker + 8 | 0;
    $i_046 = 0;
    $start_047 = 0;
    label = 3;
    break;
   case 3:
    HEAP32[$19 >> 2] = 0;
    HEAP32[$20 >> 2] = 0;
    $29 = HEAP32[$21 >> 2] | 0;
    $30 = $29 + ($i_046 << 1) | 0;
    $31 = HEAP16[$30 >> 1] | 0;
    $32 = _Decompose_Curve($worker, $start_047, $31, $flipped) | 0;
    $33 = $32 << 24 >> 24 == 0;
    if ($33) {
      label = 4;
      break;
    } else {
      $_0 = 1;
      label = 19;
      break;
    }
   case 4:
    $35 = HEAP32[$21 >> 2] | 0;
    $36 = $35 + ($i_046 << 1) | 0;
    $37 = HEAP16[$36 >> 1] | 0;
    $38 = $37 + 1 & 65535;
    $39 = HEAP32[$22 >> 2] | 0;
    $40 = HEAP32[$23 >> 2] | 0;
    $41 = $40 - 1 | 0;
    $42 = $41 & $39;
    $43 = ($42 | 0) == 0;
    if ($43) {
      label = 5;
      break;
    } else {
      label = 10;
      break;
    }
   case 5:
    $45 = HEAP32[$24 >> 2] | 0;
    $46 = ($39 | 0) < ($45 | 0);
    if ($46) {
      label = 10;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $48 = HEAP32[$25 >> 2] | 0;
    $49 = ($39 | 0) > ($48 | 0);
    if ($49) {
      label = 10;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $51 = HEAP32[$20 >> 2] | 0;
    $52 = ($51 | 0) == 0;
    if ($52) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $54 = $51 + 12 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = HEAP32[$12 >> 2] | 0;
    $57 = $56 + 12 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = $58 ^ $55;
    $60 = $59 & 8;
    $61 = ($60 | 0) == 0;
    if ($61) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $63 = HEAP32[$9 >> 2] | 0;
    $64 = $63 - 4 | 0;
    HEAP32[$9 >> 2] = $64;
    label = 10;
    break;
   case 10:
    $66 = HEAP32[$12 >> 2] | 0;
    $67 = $66 + 12 | 0;
    $68 = HEAP32[$67 >> 2] | 0;
    $69 = $68 & 8;
    $70 = ($69 | 0) == 0;
    $71 = HEAP32[$22 >> 2] | 0;
    $72 = HEAP32[$23 >> 2] | 0;
    if ($70) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $_not = $72 - 1 | 0;
    $74 = $_not & $71;
    $75 = HEAP32[$27 >> 2] | 0;
    $76 = ($74 | 0) >= ($75 | 0);
    $_sink = $76;
    label = 13;
    break;
   case 12:
    $78 = $71 - 1 | 0;
    $79 = $78 + $72 | 0;
    $80 = -$72 | 0;
    $81 = $79 & $80;
    $82 = $81 - $71 | 0;
    $83 = HEAP32[$26 >> 2] | 0;
    $84 = ($82 | 0) >= ($83 | 0);
    $_sink = $84;
    label = 13;
    break;
   case 13:
    $86 = $_sink & 1;
    $87 = _End_Profile($worker, $86) | 0;
    $88 = $87 << 24 >> 24 == 0;
    if ($88) {
      label = 14;
      break;
    } else {
      $_0 = 1;
      label = 19;
      break;
    }
   case 14:
    $90 = HEAP32[$20 >> 2] | 0;
    $91 = ($90 | 0) == 0;
    if ($91) {
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $93 = $66 + 28 | 0;
    HEAP32[$93 >> 2] = $90;
    label = 16;
    break;
   case 16:
    $95 = $i_046 + 1 | 0;
    $96 = HEAP16[$16 >> 1] | 0;
    $97 = $96 << 16 >> 16;
    $98 = ($95 | 0) < ($97 | 0);
    if ($98) {
      $i_046 = $95;
      $start_047 = $38;
      label = 3;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $99 = _Finalize_Profile_Table($worker) | 0;
    $100 = $99 << 24 >> 24 == 0;
    if ($100) {
      label = 18;
      break;
    } else {
      $_0 = 1;
      label = 19;
      break;
    }
   case 18:
    $102 = HEAP32[$9 >> 2] | 0;
    $103 = HEAP32[$7 >> 2] | 0;
    $not_ = $102 >>> 0 >= $103 >>> 0;
    $104 = $not_ & 1;
    $_0 = $104;
    label = 19;
    break;
   case 19:
    return $_0 | 0;
  }
  return 0;
}
function _Init_Linked($l) {
  $l = $l | 0;
  HEAP32[$l >> 2] = 0;
  return;
}
function _InsNew($list, $profile) {
  $list = $list | 0;
  $profile = $profile | 0;
  var $1 = 0, $2 = 0, $current_0_in = 0, $current_0 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $profile | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $current_0_in = $list;
    label = 2;
    break;
   case 2:
    $current_0 = HEAP32[$current_0_in >> 2] | 0;
    $4 = ($current_0 | 0) == 0;
    if ($4) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $6 = $current_0 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = ($2 | 0) < ($7 | 0);
    $9 = $current_0 + 4 | 0;
    if ($8) {
      label = 4;
      break;
    } else {
      $current_0_in = $9;
      label = 2;
      break;
    }
   case 4:
    $11 = $profile + 4 | 0;
    HEAP32[$11 >> 2] = $current_0;
    HEAP32[$current_0_in >> 2] = $profile;
    return;
  }
}
function _DelOld($list, $profile) {
  $list = $list | 0;
  $profile = $profile | 0;
  var $old_0 = 0, $current_0 = 0, $2 = 0, $4 = 0, $5 = 0, $7 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $old_0 = $list;
    label = 2;
    break;
   case 2:
    $current_0 = HEAP32[$old_0 >> 2] | 0;
    $2 = ($current_0 | 0) == 0;
    if ($2) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $4 = ($current_0 | 0) == ($profile | 0);
    $5 = $current_0 + 4 | 0;
    if ($4) {
      label = 4;
      break;
    } else {
      $old_0 = $5;
      label = 2;
      break;
    }
   case 4:
    $7 = HEAP32[$5 >> 2] | 0;
    HEAP32[$old_0 >> 2] = $7;
    label = 5;
    break;
   case 5:
    return;
  }
}
function _Sort($list) {
  $list = $list | 0;
  var $current_030 = 0, $1 = 0, $current_031 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $current_0 = 0, $17 = 0, $_pr = 0, $18 = 0, $next_0_in24 = 0, $next_025 = 0, $19 = 0, $next_029 = 0, $next_0_in28 = 0, $current_127 = 0, $old_026 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $old_0_be = 0, $current_1_be = 0, $next_0_in = 0, $next_0 = 0, $29 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $current_030 = HEAP32[$list >> 2] | 0;
    $1 = ($current_030 | 0) == 0;
    if ($1) {
      label = 8;
      break;
    } else {
      $current_031 = $current_030;
      label = 2;
      break;
    }
   case 2:
    $2 = $current_031 + 8 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $current_031 | 0;
    HEAP32[$5 >> 2] = $4;
    $6 = $current_031 + 12 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 >>> 2;
    $9 = $8 & 2;
    $10 = $9 - 1 | 0;
    $11 = HEAP32[$2 >> 2] | 0;
    $12 = $11 + ($10 << 2) | 0;
    HEAP32[$2 >> 2] = $12;
    $13 = $current_031 + 16 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 - 1 | 0;
    HEAP32[$13 >> 2] = $15;
    $16 = $current_031 + 4 | 0;
    $current_0 = HEAP32[$16 >> 2] | 0;
    $17 = ($current_0 | 0) == 0;
    if ($17) {
      label = 3;
      break;
    } else {
      $current_031 = $current_0;
      label = 2;
      break;
    }
   case 3:
    $_pr = HEAP32[$list >> 2] | 0;
    $18 = ($_pr | 0) == 0;
    if ($18) {
      label = 8;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $next_0_in24 = $_pr + 4 | 0;
    $next_025 = HEAP32[$next_0_in24 >> 2] | 0;
    $19 = ($next_025 | 0) == 0;
    if ($19) {
      label = 8;
      break;
    } else {
      $old_026 = $list;
      $current_127 = $_pr;
      $next_0_in28 = $next_0_in24;
      $next_029 = $next_025;
      label = 5;
      break;
    }
   case 5:
    $20 = $current_127 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $next_029 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = ($21 | 0) > ($23 | 0);
    if ($24) {
      label = 6;
      break;
    } else {
      $current_1_be = $next_029;
      $old_0_be = $next_0_in28;
      label = 7;
      break;
    }
   case 6:
    HEAP32[$old_026 >> 2] = $next_029;
    $26 = $next_029 + 4 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    HEAP32[$next_0_in28 >> 2] = $27;
    HEAP32[$26 >> 2] = $current_127;
    $28 = HEAP32[$list >> 2] | 0;
    $current_1_be = $28;
    $old_0_be = $list;
    label = 7;
    break;
   case 7:
    $next_0_in = $current_1_be + 4 | 0;
    $next_0 = HEAP32[$next_0_in >> 2] | 0;
    $29 = ($next_0 | 0) == 0;
    if ($29) {
      label = 8;
      break;
    } else {
      $old_026 = $old_0_be;
      $current_127 = $current_1_be;
      $next_0_in28 = $next_0_in;
      $next_029 = $next_0;
      label = 5;
      break;
    }
   case 8:
    return;
  }
}
function _End_Profile($worker, $overshoot) {
  $worker = $worker | 0;
  $overshoot = $overshoot | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $15 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $53 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 40 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $worker + 88 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 8 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $2;
    $8 = $6;
    $9 = $7 - $8 | 0;
    $10 = $9 >> 2;
    $11 = ($9 | 0) < 0;
    if ($11) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $13 = $worker + 44 | 0;
    HEAP32[$13 >> 2] = 99;
    $_0 = 1;
    label = 12;
    break;
   case 3:
    $15 = ($9 | 0) > 0;
    if ($15) {
      label = 4;
      break;
    } else {
      label = 9;
      break;
    }
   case 4:
    $17 = $4 + 16 | 0;
    HEAP32[$17 >> 2] = $10;
    $18 = $overshoot << 24 >> 24 == 0;
    if ($18) {
      label = 8;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $20 = HEAP32[$3 >> 2] | 0;
    $21 = $20 + 12 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22 & 8;
    $24 = ($23 | 0) == 0;
    if ($24) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $26 = $22 | 16;
    HEAP32[$21 >> 2] = $26;
    label = 8;
    break;
   case 7:
    $28 = $22 | 32;
    HEAP32[$21 >> 2] = $28;
    label = 8;
    break;
   case 8:
    $30 = HEAP32[$3 >> 2] | 0;
    $31 = HEAP32[$1 >> 2] | 0;
    $32 = $31;
    HEAP32[$3 >> 2] = $32;
    $33 = HEAP32[$1 >> 2] | 0;
    $34 = $33 + 32 | 0;
    HEAP32[$1 >> 2] = $34;
    $35 = HEAP32[$3 >> 2] | 0;
    $36 = $35 + 16 | 0;
    HEAP32[$36 >> 2] = 0;
    $37 = HEAP32[$1 >> 2] | 0;
    $38 = HEAP32[$3 >> 2] | 0;
    $39 = $38 + 8 | 0;
    HEAP32[$39 >> 2] = $37;
    $40 = HEAP32[$3 >> 2] | 0;
    $41 = $30 + 28 | 0;
    HEAP32[$41 >> 2] = $40;
    $42 = $worker + 84 | 0;
    $43 = HEAP16[$42 >> 1] | 0;
    $44 = $43 + 1 & 65535;
    HEAP16[$42 >> 1] = $44;
    label = 9;
    break;
   case 9:
    $46 = HEAP32[$1 >> 2] | 0;
    $47 = $worker + 36 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $46 >>> 0 < $48 >>> 0;
    if ($49) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $51 = $worker + 44 | 0;
    HEAP32[$51 >> 2] = 98;
    $_0 = 1;
    label = 12;
    break;
   case 11:
    $53 = $worker + 87 | 0;
    HEAP8[$53] = 0;
    $_0 = 0;
    label = 12;
    break;
   case 12:
    return $_0 | 0;
  }
  return 0;
}
function _Draw_Sweep($worker) {
  $worker = $worker | 0;
  var $min_Y = 0, $max_Y = 0, $waiting = 0, $draw_left = 0, $draw_right = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $P_0145 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $sext104 = 0, $26 = 0, $27 = 0, $29 = 0, $31 = 0, $32 = 0, $sext105 = 0, $33 = 0, $34 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $45 = 0, $46 = 0, $P_1140 = 0, $47 = 0, $48 = 0, $49 = 0, $P_1141 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $P_1 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $y_height_0_ph = 0, $y_0_ph = 0, $_pr = 0, $72 = 0, $y_height_0 = 0, $y_0 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $sext103 = 0, $80 = 0, $P_2132 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $94 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $sext = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $y_1128 = 0, $P_Left_0114 = 0, $112 = 0, $P_Right_0118_in = 0, $P_Left_0117 = 0, $dropouts_0116 = 0, $P_Right_0118 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $_ = 0, $_106 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $or_cond = 0, $127 = 0, $or_cond107 = 0, $129 = 0, $130 = 0, $131 = 0, $or_cond109 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $138 = 0, $139 = 0, $141 = 0, $dropouts_1 = 0, $143 = 0, $144 = 0, $P_Left_0 = 0, $145 = 0, $146 = 0, $P_Left_1122 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $153 = 0, $154 = 0, $y_1_lcssa = 0, $155 = 0, $156 = 0, $P_3112 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $163 = 0, $164 = 0, $165 = 0, $P_4110 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $172 = 0, $y_2138 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $P_Right_1125_in = 0, $P_Left_1124 = 0, $P_Right_1125 = 0, $178 = 0, $179 = 0, $180 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $188 = 0, $189 = 0, $P_Left_1 = 0, $190 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 20 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $min_Y = __stackBase__ | 0;
    $max_Y = __stackBase__ + 4 | 0;
    $waiting = __stackBase__ + 8 | 0;
    $draw_left = __stackBase__ + 12 | 0;
    $draw_right = __stackBase__ + 16 | 0;
    _Init_Linked($waiting);
    _Init_Linked($draw_left);
    _Init_Linked($draw_right);
    $1 = $worker + 92 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $worker + 76 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $worker | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $4 >> $6;
    $8 = $7 & 65535;
    HEAP16[$max_Y >> 1] = $8;
    $9 = $worker + 80 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = HEAP32[$5 >> 2] | 0;
    $12 = $10 >> $11;
    $13 = $12 & 65535;
    HEAP16[$min_Y >> 1] = $13;
    $14 = ($2 | 0) == 0;
    if ($14) {
      label = 7;
      break;
    } else {
      $P_0145 = $2;
      label = 2;
      break;
    }
   case 2:
    $15 = $P_0145 + 4 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $P_0145 + 20 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $P_0145 + 16 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $18 + 65535 | 0;
    $22 = $21 + $20 | 0;
    $23 = $22 & 65535;
    $24 = HEAP16[$min_Y >> 1] | 0;
    $25 = $24 << 16 >> 16;
    $sext104 = $18 << 16;
    $26 = $sext104 >> 16;
    $27 = ($25 | 0) > ($26 | 0);
    if ($27) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $29 = $18 & 65535;
    HEAP16[$min_Y >> 1] = $29;
    label = 4;
    break;
   case 4:
    $31 = HEAP16[$max_Y >> 1] | 0;
    $32 = $31 << 16 >> 16;
    $sext105 = $22 << 16;
    $33 = $sext105 >> 16;
    $34 = ($32 | 0) < ($33 | 0);
    if ($34) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    HEAP16[$max_Y >> 1] = $23;
    label = 6;
    break;
   case 6:
    $37 = $P_0145 | 0;
    HEAP32[$37 >> 2] = 0;
    _InsNew($waiting, $P_0145);
    $38 = ($16 | 0) == 0;
    if ($38) {
      label = 7;
      break;
    } else {
      $P_0145 = $16;
      label = 2;
      break;
    }
   case 7:
    $39 = $worker + 48 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = ($40 | 0) == 0;
    if ($41) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $43 = $worker + 44 | 0;
    HEAP32[$43 >> 2] = 20;
    $_0 = 1;
    label = 52;
    break;
   case 9:
    $45 = $worker + 164 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    FUNCTION_TABLE_viii[$46 & 1023]($worker, $min_Y, $max_Y);
    $P_1140 = HEAP32[$waiting >> 2] | 0;
    $47 = ($P_1140 | 0) == 0;
    if ($47) {
      label = 12;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $48 = HEAP16[$min_Y >> 1] | 0;
    $49 = $48 & 65535;
    $P_1141 = $P_1140;
    label = 11;
    break;
   case 11:
    $51 = $P_1141 + 20 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = $52 - $49 | 0;
    $54 = $53 & 65535;
    $55 = $P_1141 + 24 | 0;
    HEAP32[$55 >> 2] = $54;
    $56 = $P_1141 + 4 | 0;
    $P_1 = HEAP32[$56 >> 2] | 0;
    $57 = ($P_1 | 0) == 0;
    if ($57) {
      label = 12;
      break;
    } else {
      $P_1141 = $P_1;
      label = 11;
      break;
    }
   case 12:
    $58 = HEAP16[$min_Y >> 1] | 0;
    $59 = HEAP32[$39 >> 2] | 0;
    $60 = ($59 | 0) > 0;
    if ($60) {
      label = 13;
      break;
    } else {
      $y_0 = $58;
      $y_height_0 = 0;
      $72 = $59;
      label = 16;
      break;
    }
   case 13:
    $62 = -$59 | 0;
    $63 = $worker + 32 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = $64 + ($62 << 2) | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = $58 << 16 >> 16;
    $68 = ($66 | 0) == ($67 | 0);
    if ($68) {
      label = 14;
      break;
    } else {
      $y_0_ph = $58;
      $y_height_0_ph = 0;
      label = 15;
      break;
    }
   case 14:
    $70 = $59 - 1 | 0;
    HEAP32[$39 >> 2] = $70;
    $y_0 = $58;
    $y_height_0 = 0;
    $72 = $70;
    label = 16;
    break;
   case 15:
    $_pr = HEAP32[$39 >> 2] | 0;
    $y_0 = $y_0_ph;
    $y_height_0 = $y_height_0_ph;
    $72 = $_pr;
    label = 16;
    break;
   case 16:
    $73 = ($72 | 0) > 0;
    if ($73) {
      label = 19;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $74 = HEAP16[$max_Y >> 1] | 0;
    $75 = $y_0 << 16 >> 16 > $74 << 16 >> 16;
    if ($75) {
      $_0 = 0;
      label = 52;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $76 = $worker + 176 | 0;
    $y_2138 = $y_0;
    label = 48;
    break;
   case 19:
    $78 = HEAP32[$waiting >> 2] | 0;
    $79 = ($78 | 0) == 0;
    if ($79) {
      label = 26;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $sext103 = $y_height_0 << 16;
    $80 = $sext103 >> 16;
    $P_2132 = $78;
    label = 21;
    break;
   case 21:
    $82 = $P_2132 + 4 | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = $P_2132 + 24 | 0;
    $85 = HEAP32[$84 >> 2] | 0;
    $86 = $85 - $80 | 0;
    HEAP32[$84 >> 2] = $86;
    $87 = ($85 | 0) == ($80 | 0);
    if ($87) {
      label = 22;
      break;
    } else {
      label = 24;
      break;
    }
   case 22:
    _DelOld($waiting, $P_2132);
    $89 = $P_2132 + 12 | 0;
    $90 = HEAP32[$89 >> 2] | 0;
    $91 = $90 & 8;
    $92 = ($91 | 0) == 0;
    if ($92) {
      label = 25;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    _InsNew($draw_left, $P_2132);
    label = 24;
    break;
   case 24:
    $94 = ($83 | 0) == 0;
    if ($94) {
      label = 26;
      break;
    } else {
      $P_2132 = $83;
      label = 21;
      break;
    }
   case 25:
    _InsNew($draw_right, $P_2132);
    label = 24;
    break;
   case 26:
    _Sort($draw_left);
    _Sort($draw_right);
    $96 = HEAP32[$39 >> 2] | 0;
    $97 = $96 - 1 | 0;
    HEAP32[$39 >> 2] = $97;
    $98 = -$96 | 0;
    $99 = $worker + 32 | 0;
    $100 = HEAP32[$99 >> 2] | 0;
    $101 = $100 + ($98 << 2) | 0;
    $102 = HEAP32[$101 >> 2] | 0;
    $sext = $102 << 16;
    $103 = $sext >> 16;
    $104 = $y_0 & 65535;
    $105 = $103 - $104 | 0;
    $106 = $y_0 << 16 >> 16;
    $107 = ($106 | 0) < ($103 | 0);
    if ($107) {
      label = 27;
      break;
    } else {
      $y_1_lcssa = $y_0;
      label = 40;
      break;
    }
   case 27:
    $108 = $worker + 176 | 0;
    $109 = $worker + 172 | 0;
    $110 = $worker + 4 | 0;
    $111 = $worker + 168 | 0;
    $y_1128 = $y_0;
    label = 28;
    break;
   case 28:
    $P_Left_0114 = HEAP32[$draw_left >> 2] | 0;
    $112 = ($P_Left_0114 | 0) == 0;
    if ($112) {
      label = 37;
      break;
    } else {
      $dropouts_0116 = 0;
      $P_Left_0117 = $P_Left_0114;
      $P_Right_0118_in = $draw_right;
      label = 29;
      break;
    }
   case 29:
    $P_Right_0118 = HEAP32[$P_Right_0118_in >> 2] | 0;
    $113 = $P_Left_0117 | 0;
    $114 = HEAP32[$113 >> 2] | 0;
    $115 = $P_Right_0118 | 0;
    $116 = HEAP32[$115 >> 2] | 0;
    $117 = ($114 | 0) > ($116 | 0);
    $_ = $117 ? $116 : $114;
    $_106 = $117 ? $114 : $116;
    $118 = HEAP32[$110 >> 2] | 0;
    $119 = -$118 | 0;
    $120 = $_ & $119;
    $121 = $118 - 1 | 0;
    $122 = $121 + $_106 | 0;
    $123 = $122 & $119;
    $124 = $_106 - $_ | 0;
    $125 = ($124 | 0) > ($118 | 0);
    $126 = ($120 | 0) == ($_ | 0);
    $or_cond = $125 | $126;
    $127 = ($123 | 0) == ($_106 | 0);
    $or_cond107 = $or_cond | $127;
    if ($or_cond107) {
      label = 33;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    $129 = ($120 | 0) > ($123 | 0);
    $130 = $120 + $118 | 0;
    $131 = ($123 | 0) == ($130 | 0);
    $or_cond109 = $129 | $131;
    if ($or_cond109) {
      label = 31;
      break;
    } else {
      label = 33;
      break;
    }
   case 31:
    $133 = $P_Left_0117 + 12 | 0;
    $134 = HEAP32[$133 >> 2] | 0;
    $135 = $134 & 7;
    $136 = ($135 | 0) == 2;
    if ($136) {
      $dropouts_1 = $dropouts_0116;
      label = 34;
      break;
    } else {
      label = 32;
      break;
    }
   case 32:
    HEAP32[$113 >> 2] = $_;
    HEAP32[$115 >> 2] = $_106;
    $138 = $P_Left_0117 + 24 | 0;
    HEAP32[$138 >> 2] = 1;
    $139 = $dropouts_0116 + 1 & 65535;
    $dropouts_1 = $139;
    label = 34;
    break;
   case 33:
    $141 = HEAP32[$111 >> 2] | 0;
    FUNCTION_TABLE_viiiiii[$141 & 1023]($worker, $y_1128, $_, $_106, $P_Left_0117, $P_Right_0118);
    $dropouts_1 = $dropouts_0116;
    label = 34;
    break;
   case 34:
    $143 = $P_Left_0117 + 4 | 0;
    $144 = $P_Right_0118 + 4 | 0;
    $P_Left_0 = HEAP32[$143 >> 2] | 0;
    $145 = ($P_Left_0 | 0) == 0;
    if ($145) {
      label = 35;
      break;
    } else {
      $dropouts_0116 = $dropouts_1;
      $P_Left_0117 = $P_Left_0;
      $P_Right_0118_in = $144;
      label = 29;
      break;
    }
   case 35:
    $146 = $dropouts_1 << 16 >> 16 > 0;
    if ($146) {
      label = 36;
      break;
    } else {
      label = 37;
      break;
    }
   case 36:
    $P_Left_1122 = HEAP32[$draw_left >> 2] | 0;
    $147 = ($P_Left_1122 | 0) == 0;
    if ($147) {
      label = 37;
      break;
    } else {
      $P_Left_1124 = $P_Left_1122;
      $P_Right_1125_in = $draw_right;
      label = 49;
      break;
    }
   case 37:
    $148 = HEAP32[$108 >> 2] | 0;
    FUNCTION_TABLE_vi[$148 & 1023]($worker);
    $149 = $y_1128 + 1 & 65535;
    $150 = $149 << 16 >> 16;
    $151 = ($150 | 0) < ($103 | 0);
    if ($151) {
      label = 38;
      break;
    } else {
      label = 39;
      break;
    }
   case 38:
    _Sort($draw_left);
    _Sort($draw_right);
    label = 39;
    break;
   case 39:
    $153 = $149 << 16 >> 16;
    $154 = ($153 | 0) < ($103 | 0);
    if ($154) {
      $y_1128 = $149;
      label = 28;
      break;
    } else {
      $y_1_lcssa = $149;
      label = 40;
      break;
    }
   case 40:
    $155 = HEAP32[$draw_left >> 2] | 0;
    $156 = ($155 | 0) == 0;
    if ($156) {
      label = 44;
      break;
    } else {
      $P_3112 = $155;
      label = 41;
      break;
    }
   case 41:
    $157 = $P_3112 + 4 | 0;
    $158 = HEAP32[$157 >> 2] | 0;
    $159 = $P_3112 + 16 | 0;
    $160 = HEAP32[$159 >> 2] | 0;
    $161 = ($160 | 0) == 0;
    if ($161) {
      label = 42;
      break;
    } else {
      label = 43;
      break;
    }
   case 42:
    _DelOld($draw_left, $P_3112);
    label = 43;
    break;
   case 43:
    $163 = ($158 | 0) == 0;
    if ($163) {
      label = 44;
      break;
    } else {
      $P_3112 = $158;
      label = 41;
      break;
    }
   case 44:
    $164 = HEAP32[$draw_right >> 2] | 0;
    $165 = ($164 | 0) == 0;
    if ($165) {
      $y_0_ph = $y_1_lcssa;
      $y_height_0_ph = $105;
      label = 15;
      break;
    } else {
      $P_4110 = $164;
      label = 45;
      break;
    }
   case 45:
    $166 = $P_4110 + 4 | 0;
    $167 = HEAP32[$166 >> 2] | 0;
    $168 = $P_4110 + 16 | 0;
    $169 = HEAP32[$168 >> 2] | 0;
    $170 = ($169 | 0) == 0;
    if ($170) {
      label = 46;
      break;
    } else {
      label = 47;
      break;
    }
   case 46:
    _DelOld($draw_right, $P_4110);
    label = 47;
    break;
   case 47:
    $172 = ($167 | 0) == 0;
    if ($172) {
      $y_0_ph = $y_1_lcssa;
      $y_height_0_ph = $105;
      label = 15;
      break;
    } else {
      $P_4110 = $167;
      label = 45;
      break;
    }
   case 48:
    $174 = HEAP32[$76 >> 2] | 0;
    FUNCTION_TABLE_vi[$174 & 1023]($worker);
    $175 = $y_2138 + 1 & 65535;
    $176 = HEAP16[$max_Y >> 1] | 0;
    $177 = $175 << 16 >> 16 > $176 << 16 >> 16;
    if ($177) {
      $_0 = 0;
      label = 52;
      break;
    } else {
      $y_2138 = $175;
      label = 48;
      break;
    }
   case 49:
    $P_Right_1125 = HEAP32[$P_Right_1125_in >> 2] | 0;
    $178 = $P_Left_1124 + 24 | 0;
    $179 = HEAP32[$178 >> 2] | 0;
    $180 = ($179 | 0) == 0;
    if ($180) {
      label = 51;
      break;
    } else {
      label = 50;
      break;
    }
   case 50:
    HEAP32[$178 >> 2] = 0;
    $182 = HEAP32[$109 >> 2] | 0;
    $183 = $P_Left_1124 | 0;
    $184 = HEAP32[$183 >> 2] | 0;
    $185 = $P_Right_1125 | 0;
    $186 = HEAP32[$185 >> 2] | 0;
    FUNCTION_TABLE_viiiiii[$182 & 1023]($worker, $y_1128, $184, $186, $P_Left_1124, $P_Right_1125);
    label = 51;
    break;
   case 51:
    $188 = $P_Left_1124 + 4 | 0;
    $189 = $P_Right_1125 + 4 | 0;
    $P_Left_1 = HEAP32[$188 >> 2] | 0;
    $190 = ($P_Left_1 | 0) == 0;
    if ($190) {
      label = 37;
      break;
    } else {
      $P_Left_1124 = $P_Left_1;
      $P_Right_1125_in = $189;
      label = 49;
      break;
    }
   case 52:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _Decompose_Curve($worker, $first, $last, $flipped) {
  $worker = $worker | 0;
  $first = $first | 0;
  $last = $last | 0;
  $flipped = $flipped | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $_ = 0, $_153 = 0, $_154 = 0, $_155 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $_sum152 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $limit_0 = 0, $v_start_sroa_0_1 = 0, $v_start_sroa_1_1 = 0, $_sum = 0, $55 = 0, $56 = 0, $tags_0 = 0, $limit_1 = 0, $point_0 = 0, $v_start_sroa_0_2 = 0, $v_start_sroa_1_2 = 0, $58 = 0, $59 = 0, $60 = 0, $point_1186 = 0, $tags_1185 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $_156 = 0, $_157 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $_158 = 0, $_159 = 0, $tags_2 = 0, $point_2 = 0, $v_control_sroa_0_0 = 0, $v_control_sroa_1_0 = 0, $91 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $_160 = 0, $_161 = 0, $109 = 0, $110 = 0, $tags_1_be = 0, $point_1_be = 0, $111 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $120 = 0, $121 = 0, $123 = 0, $124 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $_162 = 0, $_163 = 0, $_164 = 0, $_165 = 0, $150 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $_166 = 0, $_167 = 0, $161 = 0, $162 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 132 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $last & 65535;
    $4 = $2 + ($3 << 3) | 0;
    $5 = $first & 65535;
    $6 = $2 + ($5 << 3) | 0;
    $7 = $6 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $worker + 24 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $8 << $10;
    $12 = $worker + 8 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $11 - $13 | 0;
    $15 = $2 + ($5 << 3) + 4 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $16 << $10;
    $18 = $17 - $13 | 0;
    $19 = $4 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $20 << $10;
    $22 = $21 - $13 | 0;
    $23 = $2 + ($3 << 3) + 4 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24 << $10;
    $26 = $25 - $13 | 0;
    $27 = ($flipped | 0) != 0;
    $_ = $27 ? $18 : $14;
    $_153 = $27 ? $14 : $18;
    $_154 = $27 ? $26 : $22;
    $_155 = $27 ? $22 : $26;
    $28 = $worker + 136 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $29 + $5 | 0;
    $31 = HEAP8[$30] | 0;
    $32 = $31 & 4;
    $33 = $32 << 24 >> 24 == 0;
    if ($33) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $35 = ($31 & 255) >>> 5;
    $36 = $worker + 180 | 0;
    HEAP8[$36] = $35;
    label = 3;
    break;
   case 3:
    $38 = HEAP8[$30] | 0;
    $39 = $38 & 255;
    $40 = $39 & 3;
    if (($40 | 0) == 0) {
      label = 4;
      break;
    } else if (($40 | 0) == 2) {
      label = 24;
      break;
    } else {
      $v_start_sroa_1_2 = $_153;
      $v_start_sroa_0_2 = $_;
      $point_0 = $6;
      $limit_1 = $4;
      $tags_0 = $30;
      label = 8;
      break;
    }
   case 4:
    $42 = HEAP32[$28 >> 2] | 0;
    $43 = $42 + $3 | 0;
    $44 = HEAP8[$43] | 0;
    $45 = $44 & 3;
    $46 = $45 << 24 >> 24 == 1;
    if ($46) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $_sum152 = $3 - 1 | 0;
    $48 = $2 + ($_sum152 << 3) | 0;
    $v_start_sroa_1_1 = $_155;
    $v_start_sroa_0_1 = $_154;
    $limit_0 = $48;
    label = 7;
    break;
   case 6:
    $50 = $_154 + $_ | 0;
    $51 = ($50 | 0) / 2 & -1;
    $52 = $_155 + $_153 | 0;
    $53 = ($52 | 0) / 2 & -1;
    $v_start_sroa_1_1 = $53;
    $v_start_sroa_0_1 = $51;
    $limit_0 = $4;
    label = 7;
    break;
   case 7:
    $_sum = $5 - 1 | 0;
    $55 = $2 + ($_sum << 3) | 0;
    $56 = $29 + $_sum | 0;
    $v_start_sroa_1_2 = $v_start_sroa_1_1;
    $v_start_sroa_0_2 = $v_start_sroa_0_1;
    $point_0 = $55;
    $limit_1 = $limit_0;
    $tags_0 = $56;
    label = 8;
    break;
   case 8:
    $58 = $worker + 68 | 0;
    HEAP32[$58 >> 2] = $v_start_sroa_0_2;
    $59 = $worker + 72 | 0;
    HEAP32[$59 >> 2] = $v_start_sroa_1_2;
    $60 = $point_0 >>> 0 < $limit_1 >>> 0;
    if ($60) {
      $tags_1185 = $tags_0;
      $point_1186 = $point_0;
      label = 9;
      break;
    } else {
      label = 23;
      break;
    }
   case 9:
    $61 = $point_1186 + 8 | 0;
    $62 = $tags_1185 + 1 | 0;
    $63 = HEAP8[$62] | 0;
    $64 = $63 & 255;
    $65 = $64 & 3;
    if (($65 | 0) == 1) {
      label = 10;
      break;
    } else if (($65 | 0) == 0) {
      label = 11;
      break;
    } else {
      label = 18;
      break;
    }
   case 10:
    $67 = $61 | 0;
    $68 = HEAP32[$67 >> 2] | 0;
    $69 = HEAP32[$9 >> 2] | 0;
    $70 = $68 << $69;
    $71 = HEAP32[$12 >> 2] | 0;
    $72 = $70 - $71 | 0;
    $73 = $point_1186 + 12 | 0;
    $74 = HEAP32[$73 >> 2] | 0;
    $75 = $74 << $69;
    $76 = $75 - $71 | 0;
    $_156 = $27 ? $76 : $72;
    $_157 = $27 ? $72 : $76;
    $77 = _Line_To($worker, $_156, $_157) | 0;
    $78 = $77 << 24 >> 24 == 0;
    if ($78) {
      $point_1_be = $61;
      $tags_1_be = $62;
      label = 15;
      break;
    } else {
      label = 25;
      break;
    }
   case 11:
    $80 = $61 | 0;
    $81 = HEAP32[$80 >> 2] | 0;
    $82 = HEAP32[$9 >> 2] | 0;
    $83 = $81 << $82;
    $84 = HEAP32[$12 >> 2] | 0;
    $85 = $83 - $84 | 0;
    $86 = $point_1186 + 12 | 0;
    $87 = HEAP32[$86 >> 2] | 0;
    $88 = $87 << $82;
    $89 = $88 - $84 | 0;
    $_158 = $27 ? $89 : $85;
    $_159 = $27 ? $85 : $89;
    $v_control_sroa_1_0 = $_159;
    $v_control_sroa_0_0 = $_158;
    $point_2 = $61;
    $tags_2 = $62;
    label = 12;
    break;
   case 12:
    $91 = $point_2 >>> 0 < $limit_1 >>> 0;
    if ($91) {
      label = 13;
      break;
    } else {
      label = 17;
      break;
    }
   case 13:
    $93 = $point_2 + 8 | 0;
    $94 = $tags_2 + 1 | 0;
    $95 = HEAP8[$94] | 0;
    $96 = $95 & 255;
    $97 = $96 & 3;
    $98 = $93 | 0;
    $99 = HEAP32[$98 >> 2] | 0;
    $100 = HEAP32[$9 >> 2] | 0;
    $101 = $99 << $100;
    $102 = HEAP32[$12 >> 2] | 0;
    $103 = $101 - $102 | 0;
    $104 = $point_2 + 12 | 0;
    $105 = HEAP32[$104 >> 2] | 0;
    $106 = $105 << $100;
    $107 = $106 - $102 | 0;
    $_160 = $27 ? $107 : $103;
    $_161 = $27 ? $103 : $107;
    if (($97 | 0) == 1) {
      label = 14;
      break;
    } else if (($97 | 0) == 0) {
      label = 16;
      break;
    } else {
      label = 24;
      break;
    }
   case 14:
    $109 = _Conic_To($worker, $v_control_sroa_0_0, $v_control_sroa_1_0, $_160, $_161) | 0;
    $110 = $109 << 24 >> 24 == 0;
    if ($110) {
      $point_1_be = $93;
      $tags_1_be = $94;
      label = 15;
      break;
    } else {
      label = 25;
      break;
    }
   case 15:
    $111 = $point_1_be >>> 0 < $limit_1 >>> 0;
    if ($111) {
      $tags_1185 = $tags_1_be;
      $point_1186 = $point_1_be;
      label = 9;
      break;
    } else {
      label = 23;
      break;
    }
   case 16:
    $113 = $_160 + $v_control_sroa_0_0 | 0;
    $114 = ($113 | 0) / 2 & -1;
    $115 = $_161 + $v_control_sroa_1_0 | 0;
    $116 = ($115 | 0) / 2 & -1;
    $117 = _Conic_To($worker, $v_control_sroa_0_0, $v_control_sroa_1_0, $114, $116) | 0;
    $118 = $117 << 24 >> 24 == 0;
    if ($118) {
      $v_control_sroa_1_0 = $_161;
      $v_control_sroa_0_0 = $_160;
      $point_2 = $93;
      $tags_2 = $94;
      label = 12;
      break;
    } else {
      label = 25;
      break;
    }
   case 17:
    $120 = _Conic_To($worker, $v_control_sroa_0_0, $v_control_sroa_1_0, $v_start_sroa_0_2, $v_start_sroa_1_2) | 0;
    $121 = $120 << 24 >> 24 == 0;
    if ($121) {
      $_0 = 0;
      label = 26;
      break;
    } else {
      label = 25;
      break;
    }
   case 18:
    $123 = $point_1186 + 16 | 0;
    $124 = $123 >>> 0 > $limit_1 >>> 0;
    if ($124) {
      label = 24;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $126 = $tags_1185 + 2 | 0;
    $127 = HEAP8[$126] | 0;
    $128 = $127 & 3;
    $129 = $128 << 24 >> 24 == 2;
    if ($129) {
      label = 20;
      break;
    } else {
      label = 24;
      break;
    }
   case 20:
    $131 = $point_1186 + 24 | 0;
    $132 = $point_1186 + 8 | 0;
    $133 = HEAP32[$132 >> 2] | 0;
    $134 = HEAP32[$9 >> 2] | 0;
    $135 = $133 << $134;
    $136 = HEAP32[$12 >> 2] | 0;
    $137 = $135 - $136 | 0;
    $138 = $point_1186 + 12 | 0;
    $139 = HEAP32[$138 >> 2] | 0;
    $140 = $139 << $134;
    $141 = $140 - $136 | 0;
    $142 = $point_1186 + 16 | 0;
    $143 = HEAP32[$142 >> 2] | 0;
    $144 = $143 << $134;
    $145 = $144 - $136 | 0;
    $146 = $point_1186 + 20 | 0;
    $147 = HEAP32[$146 >> 2] | 0;
    $148 = $147 << $134;
    $149 = $148 - $136 | 0;
    $_162 = $27 ? $141 : $137;
    $_163 = $27 ? $137 : $141;
    $_164 = $27 ? $149 : $145;
    $_165 = $27 ? $145 : $149;
    $150 = $131 >>> 0 > $limit_1 >>> 0;
    if ($150) {
      label = 22;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $152 = $tags_1185 + 3 | 0;
    $153 = $131 | 0;
    $154 = HEAP32[$153 >> 2] | 0;
    $155 = $154 << $134;
    $156 = $155 - $136 | 0;
    $157 = $point_1186 + 28 | 0;
    $158 = HEAP32[$157 >> 2] | 0;
    $159 = $158 << $134;
    $160 = $159 - $136 | 0;
    $_166 = $27 ? $160 : $156;
    $_167 = $27 ? $156 : $160;
    $161 = _Cubic_To($worker, $_162, $_163, $_164, $_165, $_166, $_167) | 0;
    $162 = $161 << 24 >> 24 == 0;
    if ($162) {
      $point_1_be = $131;
      $tags_1_be = $152;
      label = 15;
      break;
    } else {
      label = 25;
      break;
    }
   case 22:
    $164 = _Cubic_To($worker, $_162, $_163, $_164, $_165, $v_start_sroa_0_2, $v_start_sroa_1_2) | 0;
    $165 = $164 << 24 >> 24 == 0;
    if ($165) {
      $_0 = 0;
      label = 26;
      break;
    } else {
      label = 25;
      break;
    }
   case 23:
    $166 = _Line_To($worker, $v_start_sroa_0_2, $v_start_sroa_1_2) | 0;
    $167 = $166 << 24 >> 24 == 0;
    if ($167) {
      $_0 = 0;
      label = 26;
      break;
    } else {
      label = 25;
      break;
    }
   case 24:
    $168 = $worker + 44 | 0;
    HEAP32[$168 >> 2] = 20;
    label = 25;
    break;
   case 25:
    $_0 = 1;
    label = 26;
    break;
   case 26:
    return $_0 | 0;
  }
  return 0;
}
function _Finalize_Profile_Table($worker) {
  $worker = $worker | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $or_cond = 0, $7 = 0, $p_024 = 0, $n_023 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $bottom_0 = 0, $top_0 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 84 | 0;
    $2 = HEAP16[$1 >> 1] | 0;
    $3 = $worker + 92 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 & 65535) < 2;
    $6 = ($4 | 0) == 0;
    $or_cond = $5 | $6;
    if ($or_cond) {
      label = 12;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $2 << 16 >> 16 == 0;
    if ($7) {
      $_0 = 0;
      label = 13;
      break;
    } else {
      $n_023 = $2;
      $p_024 = $4;
      label = 3;
      break;
    }
   case 3:
    $8 = ($n_023 & 65535) > 1;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $10 = $p_024 + 8 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $p_024 + 16 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $11 + ($13 << 2) | 0;
    $15 = $14;
    $16 = $p_024 + 4 | 0;
    HEAP32[$16 >> 2] = $15;
    label = 6;
    break;
   case 5:
    $18 = $p_024 + 4 | 0;
    HEAP32[$18 >> 2] = 0;
    label = 6;
    break;
   case 6:
    $20 = $p_024 + 12 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $21 & 8;
    $23 = ($22 | 0) == 0;
    $24 = $p_024 + 20 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $p_024 + 16 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    if ($23) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $29 = $25 - 1 | 0;
    $30 = $29 + $27 | 0;
    $top_0 = $30;
    $bottom_0 = $25;
    label = 9;
    break;
   case 8:
    $32 = $25 - $27 | 0;
    $33 = $32 + 1 | 0;
    HEAP32[$24 >> 2] = $33;
    $34 = HEAP32[$26 >> 2] | 0;
    $35 = $34 - 1 | 0;
    $36 = $p_024 + 8 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $37 + ($35 << 2) | 0;
    HEAP32[$36 >> 2] = $38;
    $top_0 = $25;
    $bottom_0 = $33;
    label = 9;
    break;
   case 9:
    $40 = _Insert_Y_Turn($worker, $bottom_0) | 0;
    $41 = $40 << 24 >> 24 == 0;
    if ($41) {
      label = 10;
      break;
    } else {
      $_0 = 1;
      label = 13;
      break;
    }
   case 10:
    $43 = $top_0 + 1 | 0;
    $44 = _Insert_Y_Turn($worker, $43) | 0;
    $45 = $44 << 24 >> 24 == 0;
    if ($45) {
      label = 11;
      break;
    } else {
      $_0 = 1;
      label = 13;
      break;
    }
   case 11:
    $47 = $p_024 + 4 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $n_023 - 1 & 65535;
    $50 = $49 << 16 >> 16 == 0;
    if ($50) {
      $_0 = 0;
      label = 13;
      break;
    } else {
      $n_023 = $49;
      $p_024 = $48;
      label = 3;
      break;
    }
   case 12:
    HEAP32[$3 >> 2] = 0;
    $_0 = 0;
    label = 13;
    break;
   case 13:
    return $_0 | 0;
  }
  return 0;
}
function _Insert_Y_Turn($worker, $y) {
  $worker = $worker | 0;
  $y = $y | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $n_0_in = 0, $n_0 = 0, $6 = 0, $_sum27 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $n_131 = 0, $_02530 = 0, $_sum26 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $_129 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 48 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $worker + 32 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $n_0_in = $2;
    label = 2;
    break;
   case 2:
    $n_0 = $n_0_in - 1 | 0;
    $6 = ($n_0_in | 0) > 0;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 7;
      break;
    }
   case 3:
    $_sum27 = $n_0 - $2 | 0;
    $8 = $4 + ($_sum27 << 2) | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) > ($y | 0);
    if ($10) {
      $n_0_in = $n_0;
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $12 = ($9 | 0) < ($y | 0);
    if ($12) {
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    $13 = ($n_0_in | 0) > 0;
    if ($13) {
      $_02530 = $y;
      $n_131 = $n_0;
      label = 6;
      break;
    } else {
      $_129 = $y;
      label = 8;
      break;
    }
   case 6:
    $_sum26 = $n_131 - $2 | 0;
    $14 = $4 + ($_sum26 << 2) | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    HEAP32[$14 >> 2] = $_02530;
    $16 = $n_131 - 1 | 0;
    $17 = ($n_131 | 0) > 0;
    if ($17) {
      $_02530 = $15;
      $n_131 = $16;
      label = 6;
      break;
    } else {
      $_129 = $15;
      label = 8;
      break;
    }
   case 7:
    $18 = ($n_0 | 0) < 0;
    if ($18) {
      $_129 = $y;
      label = 8;
      break;
    } else {
      $_0 = 0;
      label = 11;
      break;
    }
   case 8:
    $19 = $worker + 36 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $20 - 4 | 0;
    HEAP32[$19 >> 2] = $21;
    $22 = $worker + 40 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $21 >>> 0 > $23 >>> 0;
    if ($24) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $26 = $worker + 44 | 0;
    HEAP32[$26 >> 2] = 98;
    $_0 = 1;
    label = 11;
    break;
   case 10:
    $28 = HEAP32[$1 >> 2] | 0;
    $29 = $28 + 1 | 0;
    HEAP32[$1 >> 2] = $29;
    $30 = $28 ^ -1;
    $31 = HEAP32[$3 >> 2] | 0;
    $32 = $31 + ($30 << 2) | 0;
    HEAP32[$32 >> 2] = $_129;
    $_0 = 0;
    label = 11;
    break;
   case 11:
    return $_0 | 0;
  }
  return 0;
}
function _Split_Cubic($base) {
  $base = $base | 0;
  var $1 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $12 = 0, $16 = 0, $20 = 0, $23 = 0, $26 = 0, $31 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $42 = 0, $46 = 0, $50 = 0, $53 = 0, $56 = 0;
  $1 = $base + 24 | 0;
  HEAP32[$base + 48 >> 2] = HEAP32[$1 >> 2] | 0;
  $4 = $base + 8 | 0;
  $5 = HEAP32[$4 >> 2] | 0;
  $6 = $base + 16 | 0;
  $7 = HEAP32[$6 >> 2] | 0;
  $12 = ($5 + 1 | 0) + (HEAP32[$base >> 2] | 0) >> 1;
  HEAP32[$4 >> 2] = $12;
  $16 = ($7 + 1 | 0) + (HEAP32[$1 >> 2] | 0) >> 1;
  HEAP32[$base + 40 >> 2] = $16;
  $20 = ($5 + 1 | 0) + $7 >> 1;
  $23 = ($20 + 1 | 0) + $12 >> 1;
  HEAP32[$6 >> 2] = $23;
  $26 = ($20 + 1 | 0) + $16 >> 1;
  HEAP32[$base + 32 >> 2] = $26;
  HEAP32[$1 >> 2] = ($23 + 1 | 0) + $26 >> 1;
  $31 = $base + 28 | 0;
  HEAP32[$base + 52 >> 2] = HEAP32[$31 >> 2] | 0;
  $34 = $base + 12 | 0;
  $35 = HEAP32[$34 >> 2] | 0;
  $36 = $base + 20 | 0;
  $37 = HEAP32[$36 >> 2] | 0;
  $42 = ($35 + 1 | 0) + (HEAP32[$base + 4 >> 2] | 0) >> 1;
  HEAP32[$34 >> 2] = $42;
  $46 = ($37 + 1 | 0) + (HEAP32[$31 >> 2] | 0) >> 1;
  HEAP32[$base + 44 >> 2] = $46;
  $50 = ($35 + 1 | 0) + $37 >> 1;
  $53 = ($50 + 1 | 0) + $42 >> 1;
  HEAP32[$36 >> 2] = $53;
  $56 = ($50 + 1 | 0) + $46 >> 1;
  HEAP32[$base + 36 >> 2] = $56;
  HEAP32[$31 >> 2] = ($53 + 1 | 0) + $56 >> 1;
  return;
}
function _New_Profile($worker, $aState, $overshoot) {
  $worker = $worker | 0;
  $aState = $aState | 0;
  $overshoot = $overshoot | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $64 = 0, $66 = 0, $67 = 0, $68 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 92 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $5 = $worker + 40 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6;
    $8 = $worker + 88 | 0;
    HEAP32[$8 >> 2] = $7;
    HEAP32[$1 >> 2] = $7;
    $9 = HEAP32[$5 >> 2] | 0;
    $10 = $9 + 32 | 0;
    HEAP32[$5 >> 2] = $10;
    label = 3;
    break;
   case 3:
    $12 = $worker + 40 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $worker + 36 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $13 >>> 0 < $15 >>> 0;
    if ($16) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $18 = $worker + 44 | 0;
    HEAP32[$18 >> 2] = 98;
    $_0 = 1;
    label = 14;
    break;
   case 5:
    $20 = $worker + 88 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $21 + 12 | 0;
    HEAP32[$22 >> 2] = 0;
    $23 = HEAP32[$20 >> 2] | 0;
    $24 = $23 + 20 | 0;
    HEAP32[$24 >> 2] = 0;
    $25 = HEAP32[$20 >> 2] | 0;
    $26 = $25 + 16 | 0;
    HEAP32[$26 >> 2] = 0;
    $27 = HEAP32[$12 >> 2] | 0;
    $28 = HEAP32[$20 >> 2] | 0;
    $29 = $28 + 8 | 0;
    HEAP32[$29 >> 2] = $27;
    $30 = HEAP32[$20 >> 2] | 0;
    $31 = $30 + 4 | 0;
    HEAP32[$31 >> 2] = 0;
    $32 = HEAP32[$20 >> 2] | 0;
    $33 = $32 + 28 | 0;
    HEAP32[$33 >> 2] = 0;
    $34 = $worker + 180 | 0;
    $35 = HEAP8[$34] | 0;
    $36 = $35 & 255;
    $37 = HEAP32[$20 >> 2] | 0;
    $38 = $37 + 12 | 0;
    HEAP32[$38 >> 2] = $36;
    if (($aState | 0) == 1) {
      label = 6;
      break;
    } else if (($aState | 0) == 2) {
      label = 8;
      break;
    } else {
      label = 10;
      break;
    }
   case 6:
    $40 = HEAP32[$20 >> 2] | 0;
    $41 = $40 + 12 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = $42 | 8;
    HEAP32[$41 >> 2] = $43;
    $44 = $overshoot << 24 >> 24 == 0;
    if ($44) {
      label = 11;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $46 = HEAP32[$20 >> 2] | 0;
    $47 = $46 + 12 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $48 | 32;
    HEAP32[$47 >> 2] = $49;
    label = 11;
    break;
   case 8:
    $51 = $overshoot << 24 >> 24 == 0;
    if ($51) {
      label = 11;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $53 = HEAP32[$20 >> 2] | 0;
    $54 = $53 + 12 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = $55 | 16;
    HEAP32[$54 >> 2] = $56;
    label = 11;
    break;
   case 10:
    $58 = $worker + 44 | 0;
    HEAP32[$58 >> 2] = 20;
    $_0 = 1;
    label = 14;
    break;
   case 11:
    $60 = $worker + 96 | 0;
    $61 = HEAP32[$60 >> 2] | 0;
    $62 = ($61 | 0) == 0;
    if ($62) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $64 = HEAP32[$20 >> 2] | 0;
    HEAP32[$60 >> 2] = $64;
    label = 13;
    break;
   case 13:
    $66 = $worker + 100 | 0;
    HEAP32[$66 >> 2] = $aState;
    $67 = $worker + 86 | 0;
    HEAP8[$67] = 1;
    $68 = $worker + 87 | 0;
    HEAP8[$68] = 0;
    $_0 = 0;
    label = 14;
    break;
   case 14:
    return $_0 | 0;
  }
  return 0;
}
function _Line_To($worker, $x, $y) {
  $worker = $worker | 0;
  $x = $x | 0;
  $y = $y | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $24 = 0, $25 = 0, $_not63 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $_not = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $_not62 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $_pr = 0, $88 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $112 = 0, $113 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    if (($2 | 0) == 0) {
      label = 2;
      break;
    } else if (($2 | 0) == 1) {
      label = 6;
      break;
    } else if (($2 | 0) == 2) {
      label = 9;
      break;
    } else {
      $88 = $2;
      label = 13;
      break;
    }
   case 2:
    $4 = $worker + 72 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($5 | 0) < ($y | 0);
    if ($6) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $8 = $worker + 4 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $5 - 1 | 0;
    $11 = $10 + $9 | 0;
    $12 = -$9 | 0;
    $13 = $11 & $12;
    $14 = $13 - $5 | 0;
    $15 = $worker + 8 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($14 | 0) >= ($16 | 0);
    $18 = $17 & 1;
    $19 = _New_Profile($worker, 1, $18) | 0;
    $20 = $19 << 24 >> 24 == 0;
    if ($20) {
      label = 12;
      break;
    } else {
      $_0 = 1;
      label = 17;
      break;
    }
   case 4:
    $22 = ($5 | 0) > ($y | 0);
    if ($22) {
      label = 5;
      break;
    } else {
      label = 12;
      break;
    }
   case 5:
    $24 = $worker + 4 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $_not63 = $25 - 1 | 0;
    $26 = $_not63 & $5;
    $27 = $worker + 8 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = ($26 | 0) >= ($28 | 0);
    $30 = $29 & 1;
    $31 = _New_Profile($worker, 2, $30) | 0;
    $32 = $31 << 24 >> 24 == 0;
    if ($32) {
      label = 12;
      break;
    } else {
      $_0 = 1;
      label = 17;
      break;
    }
   case 6:
    $34 = $worker + 72 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = ($35 | 0) > ($y | 0);
    if ($36) {
      label = 7;
      break;
    } else {
      label = 12;
      break;
    }
   case 7:
    $38 = $worker + 4 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $_not = $39 - 1 | 0;
    $40 = $_not & $35;
    $41 = $worker + 8 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = ($40 | 0) >= ($42 | 0);
    $44 = $43 & 1;
    $45 = _End_Profile($worker, $44) | 0;
    $46 = $45 << 24 >> 24 == 0;
    if ($46) {
      label = 8;
      break;
    } else {
      $_0 = 1;
      label = 17;
      break;
    }
   case 8:
    $48 = HEAP32[$34 >> 2] | 0;
    $49 = HEAP32[$38 >> 2] | 0;
    $_not62 = $49 - 1 | 0;
    $50 = $_not62 & $48;
    $51 = HEAP32[$41 >> 2] | 0;
    $52 = ($50 | 0) >= ($51 | 0);
    $53 = $52 & 1;
    $54 = _New_Profile($worker, 2, $53) | 0;
    $55 = $54 << 24 >> 24 == 0;
    if ($55) {
      label = 12;
      break;
    } else {
      $_0 = 1;
      label = 17;
      break;
    }
   case 9:
    $57 = $worker + 72 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = ($58 | 0) < ($y | 0);
    if ($59) {
      label = 10;
      break;
    } else {
      label = 12;
      break;
    }
   case 10:
    $61 = $worker + 4 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = $58 - 1 | 0;
    $64 = $63 + $62 | 0;
    $65 = -$62 | 0;
    $66 = $64 & $65;
    $67 = $66 - $58 | 0;
    $68 = $worker + 8 | 0;
    $69 = HEAP32[$68 >> 2] | 0;
    $70 = ($67 | 0) >= ($69 | 0);
    $71 = $70 & 1;
    $72 = _End_Profile($worker, $71) | 0;
    $73 = $72 << 24 >> 24 == 0;
    if ($73) {
      label = 11;
      break;
    } else {
      $_0 = 1;
      label = 17;
      break;
    }
   case 11:
    $75 = HEAP32[$57 >> 2] | 0;
    $76 = HEAP32[$61 >> 2] | 0;
    $77 = $75 - 1 | 0;
    $78 = $77 + $76 | 0;
    $79 = -$76 | 0;
    $80 = $78 & $79;
    $81 = $80 - $75 | 0;
    $82 = HEAP32[$68 >> 2] | 0;
    $83 = ($81 | 0) >= ($82 | 0);
    $84 = $83 & 1;
    $85 = _New_Profile($worker, 1, $84) | 0;
    $86 = $85 << 24 >> 24 == 0;
    if ($86) {
      label = 12;
      break;
    } else {
      $_0 = 1;
      label = 17;
      break;
    }
   case 12:
    $_pr = HEAP32[$1 >> 2] | 0;
    $88 = $_pr;
    label = 13;
    break;
   case 13:
    if (($88 | 0) == 1) {
      label = 14;
      break;
    } else if (($88 | 0) == 2) {
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 14:
    $90 = $worker + 68 | 0;
    $91 = HEAP32[$90 >> 2] | 0;
    $92 = $worker + 72 | 0;
    $93 = HEAP32[$92 >> 2] | 0;
    $94 = $worker + 76 | 0;
    $95 = HEAP32[$94 >> 2] | 0;
    $96 = $worker + 80 | 0;
    $97 = HEAP32[$96 >> 2] | 0;
    $98 = _Line_Up($worker, $91, $93, $x, $y, $95, $97) | 0;
    $99 = $98 << 24 >> 24 == 0;
    if ($99) {
      label = 16;
      break;
    } else {
      $_0 = 1;
      label = 17;
      break;
    }
   case 15:
    $101 = $worker + 68 | 0;
    $102 = HEAP32[$101 >> 2] | 0;
    $103 = $worker + 72 | 0;
    $104 = HEAP32[$103 >> 2] | 0;
    $105 = $worker + 76 | 0;
    $106 = HEAP32[$105 >> 2] | 0;
    $107 = $worker + 80 | 0;
    $108 = HEAP32[$107 >> 2] | 0;
    $109 = _Line_Down($worker, $102, $104, $x, $y, $106, $108) | 0;
    $110 = $109 << 24 >> 24 == 0;
    if ($110) {
      label = 16;
      break;
    } else {
      $_0 = 1;
      label = 17;
      break;
    }
   case 16:
    $112 = $worker + 68 | 0;
    HEAP32[$112 >> 2] = $x;
    $113 = $worker + 72 | 0;
    HEAP32[$113 >> 2] = $y;
    $_0 = 0;
    label = 17;
    break;
   case 17:
    return $_0 | 0;
  }
  return 0;
}
function _Conic_To($worker, $cx, $cy, $x, $y) {
  $worker = $worker | 0;
  $cx = $cx | 0;
  $cy = $cy | 0;
  $x = $x | 0;
  $y = $y | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $_ = 0, $_55 = 0, $35 = 0, $36 = 0, $or_cond = 0, $38 = 0, $39 = 0, $41 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $_not = 0, $60 = 0, $61 = 0, $62 = 0, $_sink = 0, $64 = 0, $65 = 0, $66 = 0, $68 = 0, $69 = 0, $71 = 0, $72 = 0, $74 = 0, $75 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $83 = 0, $84 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 184 | 0;
    $2 = $worker + 52 | 0;
    HEAP32[$2 >> 2] = $1;
    $3 = $worker + 68 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $worker + 200 | 0;
    HEAP32[$5 >> 2] = $4;
    $6 = $worker + 72 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = HEAP32[$2 >> 2] | 0;
    $9 = $8 + 20 | 0;
    HEAP32[$9 >> 2] = $7;
    $10 = HEAP32[$2 >> 2] | 0;
    $11 = $10 + 8 | 0;
    HEAP32[$11 >> 2] = $cx;
    $12 = HEAP32[$2 >> 2] | 0;
    $13 = $12 + 12 | 0;
    HEAP32[$13 >> 2] = $cy;
    $14 = HEAP32[$2 >> 2] | 0;
    $15 = $14 | 0;
    HEAP32[$15 >> 2] = $x;
    $16 = HEAP32[$2 >> 2] | 0;
    $17 = $16 + 4 | 0;
    HEAP32[$17 >> 2] = $y;
    $18 = $worker + 100 | 0;
    $19 = $worker + 76 | 0;
    $20 = $worker + 80 | 0;
    $21 = $worker + 4 | 0;
    $22 = $worker + 8 | 0;
    $23 = $worker + 8 | 0;
    label = 2;
    break;
   case 2:
    $25 = HEAP32[$2 >> 2] | 0;
    $26 = $25 + 20 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $25 + 12 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $25 + 4 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $25 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = ($27 | 0) > ($31 | 0);
    $_ = $34 ? $27 : $31;
    $_55 = $34 ? $31 : $27;
    $35 = ($29 | 0) < ($_55 | 0);
    $36 = ($29 | 0) > ($_ | 0);
    $or_cond = $35 | $36;
    if ($or_cond) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    _Split_Conic($25);
    $38 = HEAP32[$2 >> 2] | 0;
    $39 = $38 + 16 | 0;
    HEAP32[$2 >> 2] = $39;
    label = 16;
    break;
   case 4:
    $41 = ($27 | 0) == ($31 | 0);
    if ($41) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $43 = $25 - 16 | 0;
    HEAP32[$2 >> 2] = $43;
    label = 16;
    break;
   case 6:
    $45 = ($27 | 0) < ($31 | 0);
    $46 = $45 ? 1 : 2;
    $47 = HEAP32[$18 >> 2] | 0;
    $48 = ($47 | 0) == ($46 | 0);
    if ($48) {
      label = 13;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $50 = HEAP32[$21 >> 2] | 0;
    if ($45) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $52 = $27 - 1 | 0;
    $53 = $52 + $50 | 0;
    $54 = -$50 | 0;
    $55 = $53 & $54;
    $56 = $55 - $27 | 0;
    $57 = HEAP32[$22 >> 2] | 0;
    $58 = ($56 | 0) >= ($57 | 0);
    $_sink = $58;
    label = 10;
    break;
   case 9:
    $_not = $50 - 1 | 0;
    $60 = $_not & $27;
    $61 = HEAP32[$23 >> 2] | 0;
    $62 = ($60 | 0) >= ($61 | 0);
    $_sink = $62;
    label = 10;
    break;
   case 10:
    $64 = $_sink & 1;
    $65 = HEAP32[$18 >> 2] | 0;
    $66 = ($65 | 0) == 0;
    if ($66) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $68 = _End_Profile($worker, $64) | 0;
    $69 = $68 << 24 >> 24 == 0;
    if ($69) {
      label = 12;
      break;
    } else {
      $_0 = 1;
      label = 18;
      break;
    }
   case 12:
    $71 = _New_Profile($worker, $46, $64) | 0;
    $72 = $71 << 24 >> 24 == 0;
    if ($72) {
      label = 13;
      break;
    } else {
      $_0 = 1;
      label = 18;
      break;
    }
   case 13:
    $74 = HEAP32[$19 >> 2] | 0;
    $75 = HEAP32[$20 >> 2] | 0;
    if ($45) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $77 = _Bezier_Up($worker, 2, 202, $74, $75) | 0;
    $78 = $77 << 24 >> 24 == 0;
    if ($78) {
      label = 16;
      break;
    } else {
      $_0 = 1;
      label = 18;
      break;
    }
   case 15:
    $80 = _Bezier_Down($worker, 2, 202, $74, $75) | 0;
    $81 = $80 << 24 >> 24 == 0;
    if ($81) {
      label = 16;
      break;
    } else {
      $_0 = 1;
      label = 18;
      break;
    }
   case 16:
    $83 = HEAP32[$2 >> 2] | 0;
    $84 = $83 >>> 0 < $1 >>> 0;
    if ($84) {
      label = 17;
      break;
    } else {
      label = 2;
      break;
    }
   case 17:
    HEAP32[$3 >> 2] = $33;
    HEAP32[$6 >> 2] = $31;
    $_0 = 0;
    label = 18;
    break;
   case 18:
    return $_0 | 0;
  }
  return 0;
}
function _Cubic_To($worker, $cx1, $cy1, $cx2, $cy2, $x, $y) {
  $worker = $worker | 0;
  $cx1 = $cx1 | 0;
  $cy1 = $cy1 | 0;
  $cx2 = $cx2 | 0;
  $cy2 = $cy2 | 0;
  $x = $x | 0;
  $y = $y | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $_ = 0, $_63 = 0, $41 = 0, $ymin2_0 = 0, $ymax2_0 = 0, $42 = 0, $43 = 0, $or_cond = 0, $45 = 0, $46 = 0, $48 = 0, $50 = 0, $52 = 0, $53 = 0, $54 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $_not = 0, $66 = 0, $67 = 0, $68 = 0, $_sink = 0, $70 = 0, $71 = 0, $72 = 0, $74 = 0, $75 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $83 = 0, $84 = 0, $86 = 0, $87 = 0, $89 = 0, $90 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 184 | 0;
    $2 = $worker + 52 | 0;
    HEAP32[$2 >> 2] = $1;
    $3 = $worker + 68 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $worker + 208 | 0;
    HEAP32[$5 >> 2] = $4;
    $6 = $worker + 72 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = HEAP32[$2 >> 2] | 0;
    $9 = $8 + 28 | 0;
    HEAP32[$9 >> 2] = $7;
    $10 = HEAP32[$2 >> 2] | 0;
    $11 = $10 + 16 | 0;
    HEAP32[$11 >> 2] = $cx1;
    $12 = HEAP32[$2 >> 2] | 0;
    $13 = $12 + 20 | 0;
    HEAP32[$13 >> 2] = $cy1;
    $14 = HEAP32[$2 >> 2] | 0;
    $15 = $14 + 8 | 0;
    HEAP32[$15 >> 2] = $cx2;
    $16 = HEAP32[$2 >> 2] | 0;
    $17 = $16 + 12 | 0;
    HEAP32[$17 >> 2] = $cy2;
    $18 = HEAP32[$2 >> 2] | 0;
    $19 = $18 | 0;
    HEAP32[$19 >> 2] = $x;
    $20 = HEAP32[$2 >> 2] | 0;
    $21 = $20 + 4 | 0;
    HEAP32[$21 >> 2] = $y;
    $22 = $worker + 100 | 0;
    $23 = $worker + 76 | 0;
    $24 = $worker + 80 | 0;
    $25 = $worker + 4 | 0;
    $26 = $worker + 8 | 0;
    $27 = $worker + 8 | 0;
    label = 2;
    break;
   case 2:
    $29 = HEAP32[$2 >> 2] | 0;
    $30 = $29 + 28 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $29 + 20 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $29 + 12 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $29 + 4 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $29 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = ($31 | 0) <= ($37 | 0);
    $_ = $40 ? $37 : $31;
    $_63 = $40 ? $31 : $37;
    $41 = ($33 | 0) > ($35 | 0);
    $ymin2_0 = $41 ? $35 : $33;
    $ymax2_0 = $41 ? $33 : $35;
    $42 = ($ymin2_0 | 0) < ($_63 | 0);
    $43 = ($ymax2_0 | 0) > ($_ | 0);
    $or_cond = $42 | $43;
    if ($or_cond) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    _Split_Cubic($29);
    $45 = HEAP32[$2 >> 2] | 0;
    $46 = $45 + 24 | 0;
    HEAP32[$2 >> 2] = $46;
    label = 16;
    break;
   case 4:
    $48 = ($31 | 0) == ($37 | 0);
    if ($48) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $50 = $29 - 24 | 0;
    HEAP32[$2 >> 2] = $50;
    label = 16;
    break;
   case 6:
    $52 = $40 ? 1 : 2;
    $53 = HEAP32[$22 >> 2] | 0;
    $54 = ($53 | 0) == ($52 | 0);
    if ($54) {
      label = 13;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $56 = HEAP32[$25 >> 2] | 0;
    if ($40) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $58 = $31 - 1 | 0;
    $59 = $58 + $56 | 0;
    $60 = -$56 | 0;
    $61 = $59 & $60;
    $62 = $61 - $31 | 0;
    $63 = HEAP32[$26 >> 2] | 0;
    $64 = ($62 | 0) >= ($63 | 0);
    $_sink = $64;
    label = 10;
    break;
   case 9:
    $_not = $56 - 1 | 0;
    $66 = $_not & $31;
    $67 = HEAP32[$27 >> 2] | 0;
    $68 = ($66 | 0) >= ($67 | 0);
    $_sink = $68;
    label = 10;
    break;
   case 10:
    $70 = $_sink & 1;
    $71 = HEAP32[$22 >> 2] | 0;
    $72 = ($71 | 0) == 0;
    if ($72) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $74 = _End_Profile($worker, $70) | 0;
    $75 = $74 << 24 >> 24 == 0;
    if ($75) {
      label = 12;
      break;
    } else {
      $_0 = 1;
      label = 18;
      break;
    }
   case 12:
    $77 = _New_Profile($worker, $52, $70) | 0;
    $78 = $77 << 24 >> 24 == 0;
    if ($78) {
      label = 13;
      break;
    } else {
      $_0 = 1;
      label = 18;
      break;
    }
   case 13:
    $80 = HEAP32[$23 >> 2] | 0;
    $81 = HEAP32[$24 >> 2] | 0;
    if ($40) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $83 = _Bezier_Up($worker, 3, 538, $80, $81) | 0;
    $84 = $83 << 24 >> 24 == 0;
    if ($84) {
      label = 16;
      break;
    } else {
      $_0 = 1;
      label = 18;
      break;
    }
   case 15:
    $86 = _Bezier_Down($worker, 3, 538, $80, $81) | 0;
    $87 = $86 << 24 >> 24 == 0;
    if ($87) {
      label = 16;
      break;
    } else {
      $_0 = 1;
      label = 18;
      break;
    }
   case 16:
    $89 = HEAP32[$2 >> 2] | 0;
    $90 = $89 >>> 0 < $1 >>> 0;
    if ($90) {
      label = 17;
      break;
    } else {
      label = 2;
      break;
    }
   case 17:
    HEAP32[$3 >> 2] = $39;
    HEAP32[$6 >> 2] = $37;
    $_0 = 0;
    label = 18;
    break;
   case 18:
    return $_0 | 0;
  }
  return 0;
}
function _Bezier_Up($worker, $degree, $splitter, $miny, $maxy) {
  $worker = $worker | 0;
  $degree = $degree | 0;
  $splitter = $splitter | 0;
  $miny = $miny | 0;
  $maxy = $maxy | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $or_cond = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $maxy_ = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $sext_mask = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $top_0 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $e_0 = 0, $e0_0 = 0, $top_1 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $_sum = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $arc_095 = 0, $65 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $76 = 0, $or_cond85 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $e_1_ph_be = 0, $top_2_ph_be = 0, $_pn = 0, $arc_0_ph_be = 0, $90 = 0, $91 = 0, $or_cond8594 = 0, $92 = 0, $top_2_ph100 = 0, $arc_0_ph99 = 0, $e_1_ph98 = 0, $94 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $top_4 = 0, $101 = 0, $102 = 0, $103 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 52 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + ($degree << 3) + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + 4 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $worker + 40 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($6 | 0) < ($miny | 0);
    $10 = ($4 | 0) > ($maxy | 0);
    $or_cond = $9 | $10;
    if ($or_cond) {
      $top_4 = $8;
      label = 22;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $12 = $worker + 4 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = -$13 | 0;
    $15 = $6 & $14;
    $16 = ($15 | 0) > ($maxy | 0);
    $maxy_ = $16 ? $maxy : $15;
    $17 = ($4 | 0) < ($miny | 0);
    if ($17) {
      $top_1 = $8;
      $e0_0 = $miny;
      $e_0 = $miny;
      label = 7;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $19 = $4 - 1 | 0;
    $20 = $19 + $13 | 0;
    $21 = $20 & $14;
    $22 = $13 + 65535 | 0;
    $23 = $4 & 65535;
    $sext_mask = $23 & $22;
    $24 = ($sext_mask | 0) == 0;
    if ($24) {
      label = 4;
      break;
    } else {
      $top_1 = $8;
      $e0_0 = $21;
      $e_0 = $21;
      label = 7;
      break;
    }
   case 4:
    $26 = $worker + 87 | 0;
    $27 = HEAP8[$26] | 0;
    $28 = $27 << 24 >> 24 == 0;
    if ($28) {
      $top_0 = $8;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $30 = $8 - 4 | 0;
    HEAP8[$26] = 0;
    $top_0 = $30;
    label = 6;
    break;
   case 6:
    $32 = $2 + ($degree << 3) | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $top_0 + 4 | 0;
    HEAP32[$top_0 >> 2] = $33;
    $35 = HEAP32[$12 >> 2] | 0;
    $36 = $35 + $21 | 0;
    $top_1 = $34;
    $e0_0 = $21;
    $e_0 = $36;
    label = 7;
    break;
   case 7:
    $38 = $worker + 86 | 0;
    $39 = HEAP8[$38] | 0;
    $40 = $39 << 24 >> 24 == 0;
    if ($40) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $42 = $worker | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $e0_0 >> $43;
    $45 = $worker + 88 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $46 + 20 | 0;
    HEAP32[$47 >> 2] = $44;
    HEAP8[$38] = 0;
    label = 9;
    break;
   case 9:
    $49 = ($maxy_ | 0) < ($e_0 | 0);
    if ($49) {
      $top_4 = $top_1;
      label = 22;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $51 = $maxy_ - $e_0 | 0;
    $52 = $worker | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $51 >> $53;
    $_sum = $54 + 1 | 0;
    $55 = $top_1 + ($_sum << 2) | 0;
    $56 = $worker + 36 | 0;
    $57 = HEAP32[$56 >> 2] | 0;
    $58 = $55 >>> 0 < $57 >>> 0;
    if ($58) {
      label = 11;
      break;
    } else {
      label = 13;
      break;
    }
   case 11:
    $59 = ($e_0 | 0) > ($maxy_ | 0);
    if ($59) {
      $top_4 = $top_1;
      label = 22;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $60 = $worker + 87 | 0;
    $61 = $worker + 16 | 0;
    $e_1_ph98 = $e_0;
    $arc_0_ph99 = $2;
    $top_2_ph100 = $top_1;
    $92 = 0;
    label = 19;
    break;
   case 13:
    HEAP32[$7 >> 2] = $top_1;
    $63 = $worker + 44 | 0;
    HEAP32[$63 >> 2] = 98;
    $_0 = 1;
    label = 23;
    break;
   case 14:
    HEAP8[$60] = 0;
    $65 = $arc_095 + 4 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = ($66 | 0) > ($e_1_ph98 | 0);
    if ($67) {
      label = 15;
      break;
    } else {
      label = 20;
      break;
    }
   case 15:
    $69 = $arc_095 + ($degree << 3) | 0;
    $70 = $arc_095 + ($degree << 3) + 4 | 0;
    $71 = HEAP32[$70 >> 2] | 0;
    $72 = $66 - $71 | 0;
    $73 = HEAP32[$61 >> 2] | 0;
    $74 = ($72 | 0) < ($73 | 0);
    if ($74) {
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    FUNCTION_TABLE_vi[$splitter & 1023]($arc_095);
    $76 = $69 >>> 0 < $2 >>> 0;
    $or_cond85 = $76 | $92;
    if ($or_cond85) {
      $top_4 = $top_2_ph100;
      label = 22;
      break;
    } else {
      $arc_095 = $69;
      label = 14;
      break;
    }
   case 17:
    $78 = $69 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = $arc_095 | 0;
    $81 = HEAP32[$80 >> 2] | 0;
    $82 = $81 - $79 | 0;
    $83 = $e_1_ph98 - $71 | 0;
    $84 = Math_imul($82, $83);
    $85 = ($84 | 0) / ($72 | 0) & -1;
    $86 = $85 + $79 | 0;
    $87 = $top_2_ph100 + 4 | 0;
    HEAP32[$top_2_ph100 >> 2] = $86;
    $88 = HEAP32[$12 >> 2] | 0;
    $89 = $88 + $e_1_ph98 | 0;
    $top_2_ph_be = $87;
    $e_1_ph_be = $89;
    label = 18;
    break;
   case 18:
    $_pn = -$degree | 0;
    $arc_0_ph_be = $arc_095 + ($_pn << 3) | 0;
    $90 = $arc_0_ph_be >>> 0 < $2 >>> 0;
    $91 = ($e_1_ph_be | 0) > ($maxy_ | 0);
    $or_cond8594 = $90 | $91;
    if ($or_cond8594) {
      $top_4 = $top_2_ph_be;
      label = 22;
      break;
    } else {
      $e_1_ph98 = $e_1_ph_be;
      $arc_0_ph99 = $arc_0_ph_be;
      $top_2_ph100 = $top_2_ph_be;
      $92 = $91;
      label = 19;
      break;
    }
   case 19:
    $arc_095 = $arc_0_ph99;
    label = 14;
    break;
   case 20:
    $94 = ($66 | 0) == ($e_1_ph98 | 0);
    if ($94) {
      label = 21;
      break;
    } else {
      $top_2_ph_be = $top_2_ph100;
      $e_1_ph_be = $e_1_ph98;
      label = 18;
      break;
    }
   case 21:
    HEAP8[$60] = 1;
    $96 = $arc_095 | 0;
    $97 = HEAP32[$96 >> 2] | 0;
    $98 = $top_2_ph100 + 4 | 0;
    HEAP32[$top_2_ph100 >> 2] = $97;
    $99 = HEAP32[$12 >> 2] | 0;
    $100 = $99 + $e_1_ph98 | 0;
    $top_2_ph_be = $98;
    $e_1_ph_be = $100;
    label = 18;
    break;
   case 22:
    HEAP32[$7 >> 2] = $top_4;
    $101 = HEAP32[$1 >> 2] | 0;
    $102 = -$degree | 0;
    $103 = $101 + ($102 << 3) | 0;
    HEAP32[$1 >> 2] = $103;
    $_0 = 0;
    label = 23;
    break;
   case 23:
    return $_0 | 0;
  }
  return 0;
}
function _Bezier_Down($worker, $degree, $splitter, $miny, $maxy) {
  $worker = $worker | 0;
  $degree = $degree | 0;
  $splitter = $splitter | 0;
  $miny = $miny | 0;
  $maxy = $maxy | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 52 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = -$4 | 0;
    HEAP32[$3 >> 2] = $5;
    $6 = $2 + 12 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = -$7 | 0;
    HEAP32[$6 >> 2] = $8;
    $9 = $2 + 20 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = -$10 | 0;
    HEAP32[$9 >> 2] = $11;
    $12 = ($degree | 0) > 2;
    if ($12) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $14 = $2 + 28 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = -$15 | 0;
    HEAP32[$14 >> 2] = $16;
    label = 3;
    break;
   case 3:
    $18 = $worker + 86 | 0;
    $19 = HEAP8[$18] | 0;
    $20 = -$maxy | 0;
    $21 = -$miny | 0;
    $22 = _Bezier_Up($worker, $degree, $splitter, $20, $21) | 0;
    $23 = $19 << 24 >> 24 == 0;
    if ($23) {
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $25 = HEAP8[$18] | 0;
    $26 = $25 << 24 >> 24 == 0;
    if ($26) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $28 = $worker + 88 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $29 + 20 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = -$31 | 0;
    HEAP32[$30 >> 2] = $32;
    label = 6;
    break;
   case 6:
    $34 = HEAP32[$3 >> 2] | 0;
    $35 = -$34 | 0;
    HEAP32[$3 >> 2] = $35;
    return $22 | 0;
  }
  return 0;
}
function _Split_Conic($base) {
  $base = $base | 0;
  var $1 = 0, $4 = 0, $5 = 0, $8 = 0, $13 = 0, $16 = 0, $19 = 0, $20 = 0, $23 = 0, $28 = 0;
  $1 = $base + 16 | 0;
  HEAP32[$base + 32 >> 2] = HEAP32[$1 >> 2] | 0;
  $4 = $base + 8 | 0;
  $5 = HEAP32[$4 >> 2] | 0;
  $8 = ((HEAP32[$1 >> 2] | 0) + $5 | 0) / 2 & -1;
  HEAP32[$base + 24 >> 2] = $8;
  $13 = ((HEAP32[$base >> 2] | 0) + $5 | 0) / 2 & -1;
  HEAP32[$4 >> 2] = $13;
  HEAP32[$1 >> 2] = ($13 + $8 | 0) / 2 & -1;
  $16 = $base + 20 | 0;
  HEAP32[$base + 36 >> 2] = HEAP32[$16 >> 2] | 0;
  $19 = $base + 12 | 0;
  $20 = HEAP32[$19 >> 2] | 0;
  $23 = ((HEAP32[$16 >> 2] | 0) + $20 | 0) / 2 & -1;
  HEAP32[$base + 28 >> 2] = $23;
  $28 = ((HEAP32[$base + 4 >> 2] | 0) + $20 | 0) / 2 & -1;
  HEAP32[$19 >> 2] = $28;
  HEAP32[$16 >> 2] = ($28 + $23 | 0) / 2 & -1;
  return;
}
function _tt_cmap_init($cmap, $table) {
  $cmap = $cmap | 0;
  $table = $table | 0;
  HEAP32[$cmap + 16 >> 2] = $table;
  return 0;
}
function _tt_cmap0_char_index($cmap, $char_code) {
  $cmap = $cmap | 0;
  $char_code = $char_code | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $char_code >>> 0 < 256;
    if ($1) {
      label = 2;
      break;
    } else {
      $10 = 0;
      label = 3;
      break;
    }
   case 2:
    $3 = $cmap + 16 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $char_code + 6 | 0;
    $6 = $4 + $5 | 0;
    $7 = HEAP8[$6] | 0;
    $8 = $7 & 255;
    $10 = $8;
    label = 3;
    break;
   case 3:
    return $10 | 0;
  }
  return 0;
}
function _tt_cmap0_char_next($cmap, $pchar_code) {
  $cmap = $cmap | 0;
  $pchar_code = $pchar_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $charcode_0 = 0, $gindex_0 = 0, $5 = 0, $6 = 0, $_sum = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $result_0 = 0, $gindex_1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = HEAP32[$pchar_code >> 2] | 0;
    $gindex_0 = 0;
    $charcode_0 = $3;
    label = 2;
    break;
   case 2:
    $5 = $charcode_0 + 1 | 0;
    $6 = $5 >>> 0 < 256;
    if ($6) {
      label = 3;
      break;
    } else {
      $gindex_1 = $gindex_0;
      $result_0 = 0;
      label = 4;
      break;
    }
   case 3:
    $_sum = $charcode_0 + 7 | 0;
    $8 = $2 + $_sum | 0;
    $9 = HEAP8[$8] | 0;
    $10 = $9 & 255;
    $11 = $9 << 24 >> 24 == 0;
    if ($11) {
      $gindex_0 = $10;
      $charcode_0 = $5;
      label = 2;
      break;
    } else {
      $gindex_1 = $10;
      $result_0 = $5;
      label = 4;
      break;
    }
   case 4:
    HEAP32[$pchar_code >> 2] = $result_0;
    return $gindex_1 | 0;
  }
  return 0;
}
function _tt_cmap0_get_info($cmap, $cmap_info) {
  $cmap = $cmap | 0;
  $cmap_info = $cmap_info | 0;
  var $2 = 0;
  $2 = HEAP32[$cmap + 16 >> 2] | 0;
  HEAP32[$cmap_info + 4 >> 2] = 0;
  HEAP32[$cmap_info >> 2] = (HEAPU8[$2 + 4 | 0] | 0) << 8 | (HEAPU8[$2 + 5 | 0] | 0);
  return 0;
}
function _Line_Up($worker, $x1, $y1, $x2, $y2, $miny, $maxy) {
  $worker = $worker | 0;
  $x1 = $x1 | 0;
  $y1 = $y1 | 0;
  $x2 = $x2 | 0;
  $y2 = $y2 | 0;
  $miny = $miny | 0;
  $maxy = $maxy | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $or_cond = 0, $5 = 0, $or_cond73 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $_072 = 0, $e1_0 = 0, $f1_0 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $maxy_pn = 0, $f2_0 = 0, $e2_0 = 0, $33 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $_1 = 0, $e1_1 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $72 = 0, $74 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $80 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $Dx_0 = 0, $Ix_0 = 0, $_pn = 0, $Rx_0 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $top_077 = 0, $Ax_076 = 0, $size_075 = 0, $_274 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $99 = 0, $100 = 0, $_3 = 0, $Ax_1 = 0, $102 = 0, $103 = 0, $scevgep = 0, $top_0_lcssa = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $x2 - $x1 | 0;
    $2 = $y2 - $y1 | 0;
    $3 = ($2 | 0) < 1;
    $4 = ($y2 | 0) < ($miny | 0);
    $or_cond = $3 | $4;
    $5 = ($y1 | 0) > ($maxy | 0);
    $or_cond73 = $or_cond | $5;
    if ($or_cond73) {
      $_0 = 0;
      label = 26;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = ($y1 | 0) < ($miny | 0);
    if ($7) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $9 = $miny - $y1 | 0;
    $10 = _FT_MulDiv($1, $9, $2) | 0;
    $11 = $10 + $x1 | 0;
    $12 = $worker | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $miny >> $13;
    $f1_0 = 0;
    $e1_0 = $14;
    $_072 = $11;
    label = 5;
    break;
   case 4:
    $16 = $worker | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $y1 >> $17;
    $19 = $worker + 4 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $20 - 1 | 0;
    $22 = $21 & $y1;
    $f1_0 = $22;
    $e1_0 = $18;
    $_072 = $x1;
    label = 5;
    break;
   case 5:
    $24 = ($y2 | 0) > ($maxy | 0);
    $25 = $worker | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    if ($24) {
      $f2_0 = 0;
      $maxy_pn = $maxy;
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $28 = $worker + 4 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $29 - 1 | 0;
    $31 = $30 & $y2;
    $f2_0 = $31;
    $maxy_pn = $y2;
    label = 7;
    break;
   case 7:
    $e2_0 = $maxy_pn >> $26;
    $33 = ($f1_0 | 0) > 0;
    if ($33) {
      label = 8;
      break;
    } else {
      label = 10;
      break;
    }
   case 8:
    $35 = ($e1_0 | 0) == ($e2_0 | 0);
    if ($35) {
      $_0 = 0;
      label = 26;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $37 = $worker + 4 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $38 - $f1_0 | 0;
    $40 = _FT_MulDiv($1, $39, $2) | 0;
    $41 = $40 + $_072 | 0;
    $42 = $e1_0 + 1 | 0;
    $e1_1 = $42;
    $_1 = $41;
    label = 12;
    break;
   case 10:
    $44 = $worker + 87 | 0;
    $45 = HEAP8[$44] | 0;
    $46 = $45 << 24 >> 24 == 0;
    if ($46) {
      $e1_1 = $e1_0;
      $_1 = $_072;
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $48 = $worker + 40 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = $49 - 4 | 0;
    HEAP32[$48 >> 2] = $50;
    HEAP8[$44] = 0;
    $e1_1 = $e1_0;
    $_1 = $_072;
    label = 12;
    break;
   case 12:
    $52 = ($f2_0 | 0) == 0;
    $53 = $52 & 1;
    $54 = $worker + 87 | 0;
    HEAP8[$54] = $53;
    $55 = $worker + 86 | 0;
    $56 = HEAP8[$55] | 0;
    $57 = $56 << 24 >> 24 == 0;
    if ($57) {
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $59 = $worker + 88 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = $60 + 20 | 0;
    HEAP32[$61 >> 2] = $e1_1;
    HEAP8[$55] = 0;
    label = 14;
    break;
   case 14:
    $63 = $e2_0 - $e1_1 | 0;
    $64 = $63 + 1 | 0;
    $65 = $worker + 40 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = $66 + ($64 << 2) | 0;
    $68 = $worker + 36 | 0;
    $69 = HEAP32[$68 >> 2] | 0;
    $70 = $67 >>> 0 < $69 >>> 0;
    if ($70) {
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $72 = $worker + 44 | 0;
    HEAP32[$72 >> 2] = 98;
    $_0 = 1;
    label = 26;
    break;
   case 16:
    $74 = ($1 | 0) > 0;
    $75 = $worker + 4 | 0;
    $76 = HEAP32[$75 >> 2] | 0;
    if ($74) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    $78 = _FT_MulDiv($76, $1, $2) | 0;
    $79 = HEAP32[$75 >> 2] | 0;
    $80 = Math_imul($79, $1);
    $_pn = $80;
    $Ix_0 = $78;
    $Dx_0 = 1;
    label = 19;
    break;
   case 18:
    $82 = -$1 | 0;
    $83 = _FT_MulDiv($76, $82, $2) | 0;
    $84 = -$83 | 0;
    $85 = HEAP32[$75 >> 2] | 0;
    $86 = Math_imul($85, $82);
    $_pn = $86;
    $Ix_0 = $84;
    $Dx_0 = -1;
    label = 19;
    break;
   case 19:
    $Rx_0 = ($_pn | 0) % ($2 | 0);
    $88 = HEAP32[$65 >> 2] | 0;
    $89 = ($64 | 0) > 0;
    if ($89) {
      label = 20;
      break;
    } else {
      $top_0_lcssa = $88;
      label = 25;
      break;
    }
   case 20:
    $90 = -$2 | 0;
    $91 = $e2_0 + 1 | 0;
    $92 = $91 - $e1_1 | 0;
    $_274 = $_1;
    $size_075 = $64;
    $Ax_076 = $90;
    $top_077 = $88;
    label = 21;
    break;
   case 21:
    $94 = $top_077 + 4 | 0;
    HEAP32[$top_077 >> 2] = $_274;
    $95 = $_274 + $Ix_0 | 0;
    $96 = $Ax_076 + $Rx_0 | 0;
    $97 = ($96 | 0) > -1;
    if ($97) {
      label = 22;
      break;
    } else {
      $Ax_1 = $96;
      $_3 = $95;
      label = 23;
      break;
    }
   case 22:
    $99 = $96 - $2 | 0;
    $100 = $95 + $Dx_0 | 0;
    $Ax_1 = $99;
    $_3 = $100;
    label = 23;
    break;
   case 23:
    $102 = $size_075 - 1 | 0;
    $103 = ($102 | 0) > 0;
    if ($103) {
      $_274 = $_3;
      $size_075 = $102;
      $Ax_076 = $Ax_1;
      $top_077 = $94;
      label = 21;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $scevgep = $88 + ($92 << 2) | 0;
    $top_0_lcssa = $scevgep;
    label = 25;
    break;
   case 25:
    HEAP32[$65 >> 2] = $top_0_lcssa;
    $_0 = 0;
    label = 26;
    break;
   case 26:
    return $_0 | 0;
  }
  return 0;
}
function _Line_Down($worker, $x1, $y1, $x2, $y2, $miny, $maxy) {
  $worker = $worker | 0;
  $x1 = $x1 | 0;
  $y1 = $y1 | 0;
  $x2 = $x2 | 0;
  $y2 = $y2 | 0;
  $miny = $miny | 0;
  $maxy = $maxy | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 86 | 0;
    $2 = HEAP8[$1] | 0;
    $3 = -$y1 | 0;
    $4 = -$y2 | 0;
    $5 = -$maxy | 0;
    $6 = -$miny | 0;
    $7 = _Line_Up($worker, $x1, $3, $x2, $4, $5, $6) | 0;
    $8 = $2 << 24 >> 24 == 0;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = HEAP8[$1] | 0;
    $11 = $10 << 24 >> 24 == 0;
    if ($11) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $13 = $worker + 88 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 + 20 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = -$16 | 0;
    HEAP32[$15 >> 2] = $17;
    label = 4;
    break;
   case 4:
    return $7 | 0;
  }
  return 0;
}
function _tt_cmap2_char_index($cmap, $char_code) {
  $cmap = $cmap | 0;
  $char_code = $char_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $or_cond = 0, $42 = 0, $43 = 0, $_sum = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $_sum22 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _tt_cmap2_get_subheader($2, $char_code) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      $result_0 = 0;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $char_code & 255;
    $7 = HEAP8[$3] | 0;
    $8 = $7 & 255;
    $9 = $8 << 8;
    $10 = $3 + 1 | 0;
    $11 = HEAP8[$10] | 0;
    $12 = $11 & 255;
    $13 = $9 | $12;
    $14 = $3 + 2 | 0;
    $15 = HEAP8[$14] | 0;
    $16 = $15 & 255;
    $17 = $16 << 8;
    $18 = $3 + 3 | 0;
    $19 = HEAP8[$18] | 0;
    $20 = $19 & 255;
    $21 = $17 | $20;
    $22 = $3 + 6 | 0;
    $23 = $3 + 4 | 0;
    $24 = HEAP8[$23] | 0;
    $25 = $24 & 255;
    $26 = $25 << 8;
    $27 = $3 + 5 | 0;
    $28 = HEAP8[$27] | 0;
    $29 = $28 & 255;
    $30 = $26 | $29;
    $31 = HEAP8[$22] | 0;
    $32 = $31 & 255;
    $33 = $32 << 8;
    $34 = $3 + 7 | 0;
    $35 = HEAP8[$34] | 0;
    $36 = $35 & 255;
    $37 = $33 | $36;
    $38 = $6 - $13 | 0;
    $39 = $38 >>> 0 >= $21 >>> 0;
    $40 = ($37 | 0) == 0;
    $or_cond = $39 | $40;
    if ($or_cond) {
      $result_0 = 0;
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $42 = $38 << 1;
    $43 = $37 + $42 | 0;
    $_sum = $43 + 6 | 0;
    $44 = $3 + $_sum | 0;
    $45 = HEAP8[$44] | 0;
    $46 = $45 & 255;
    $47 = $46 << 8;
    $_sum22 = $43 + 7 | 0;
    $48 = $3 + $_sum22 | 0;
    $49 = HEAP8[$48] | 0;
    $50 = $49 & 255;
    $51 = $47 | $50;
    $52 = ($51 | 0) == 0;
    if ($52) {
      $result_0 = 0;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $54 = $51 + $30 | 0;
    $55 = $54 & 65535;
    $result_0 = $55;
    label = 5;
    break;
   case 5:
    return $result_0 | 0;
  }
  return 0;
}
function _tt_cmap2_char_next($cmap, $pcharcode) {
  $cmap = $cmap | 0;
  $pcharcode = $pcharcode | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $charcode_039 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $char_lo_0 = 0, $pos_0 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $_sum = 0, $50 = 0, $pos_137 = 0, $charcode_136 = 0, $p_035 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $66 = 0, $67 = 0, $68 = 0, $charcode_2 = 0, $69 = 0, $70 = 0, $71 = 0, $result_0 = 0, $gindex_4 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = HEAP32[$pcharcode >> 2] | 0;
    $4 = $3 + 1 | 0;
    $5 = $4 >>> 0 < 65536;
    if ($5) {
      $charcode_039 = $4;
      label = 2;
      break;
    } else {
      $gindex_4 = 0;
      $result_0 = 0;
      label = 10;
      break;
    }
   case 2:
    $6 = _tt_cmap2_get_subheader($2, $charcode_039) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      $charcode_2 = $charcode_039;
      label = 9;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = HEAP8[$6] | 0;
    $10 = $9 & 255;
    $11 = $10 << 8;
    $12 = $6 + 1 | 0;
    $13 = HEAP8[$12] | 0;
    $14 = $13 & 255;
    $15 = $11 | $14;
    $16 = $6 + 2 | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 & 255;
    $19 = $18 << 8;
    $20 = $6 + 3 | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $21 & 255;
    $23 = $19 | $22;
    $24 = $6 + 6 | 0;
    $25 = $6 + 4 | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 & 255;
    $28 = $27 << 8;
    $29 = $6 + 5 | 0;
    $30 = HEAP8[$29] | 0;
    $31 = $30 & 255;
    $32 = $28 | $31;
    $33 = HEAP8[$24] | 0;
    $34 = $33 & 255;
    $35 = $34 << 8;
    $36 = $6 + 7 | 0;
    $37 = HEAP8[$36] | 0;
    $38 = $37 & 255;
    $39 = $35 | $38;
    $40 = $charcode_039 & 255;
    $41 = ($39 | 0) == 0;
    if ($41) {
      $charcode_2 = $charcode_039;
      label = 9;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $43 = $40 >>> 0 < $15 >>> 0;
    $44 = $40 - $15 | 0;
    $char_lo_0 = $43 ? $15 : $40;
    $pos_0 = $43 ? 0 : $44;
    $45 = $charcode_039 & -256;
    $46 = $char_lo_0 + $45 | 0;
    $47 = $pos_0 >>> 0 < $23 >>> 0;
    if ($47) {
      label = 5;
      break;
    } else {
      $charcode_2 = $46;
      label = 9;
      break;
    }
   case 5:
    $48 = $pos_0 << 1;
    $49 = $48 + 6 | 0;
    $_sum = $49 + $39 | 0;
    $50 = $6 + $_sum | 0;
    $p_035 = $50;
    $charcode_136 = $46;
    $pos_137 = $pos_0;
    label = 6;
    break;
   case 6:
    $52 = $p_035 + 2 | 0;
    $53 = HEAP8[$p_035] | 0;
    $54 = $53 & 255;
    $55 = $54 << 8;
    $56 = $p_035 + 1 | 0;
    $57 = HEAP8[$56] | 0;
    $58 = $57 & 255;
    $59 = $55 | $58;
    $60 = ($59 | 0) == 0;
    if ($60) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $62 = $59 + $32 | 0;
    $63 = $62 & 65535;
    $64 = ($63 | 0) == 0;
    if ($64) {
      label = 8;
      break;
    } else {
      $gindex_4 = $63;
      $result_0 = $charcode_136;
      label = 10;
      break;
    }
   case 8:
    $66 = $pos_137 + 1 | 0;
    $67 = $charcode_136 + 1 | 0;
    $68 = $66 >>> 0 < $23 >>> 0;
    if ($68) {
      $p_035 = $52;
      $charcode_136 = $67;
      $pos_137 = $66;
      label = 6;
      break;
    } else {
      $charcode_2 = $67;
      label = 9;
      break;
    }
   case 9:
    $69 = $charcode_2 + 256 | 0;
    $70 = $69 & -256;
    $71 = $70 >>> 0 < 65536;
    if ($71) {
      $charcode_039 = $70;
      label = 2;
      break;
    } else {
      $gindex_4 = 0;
      $result_0 = 0;
      label = 10;
      break;
    }
   case 10:
    HEAP32[$pcharcode >> 2] = $result_0;
    return $gindex_4 | 0;
  }
  return 0;
}
function _tt_cmap0_validate($table, $valid) {
  $table = $table | 0;
  $valid = $valid | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $or_cond = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $p_015 = 0, $n_014 = 0, $25 = 0, $26 = 0, $27 = 0, $30 = 0, $31 = 0, $32 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table + 2 | 0;
    $2 = HEAP8[$1] | 0;
    $3 = $2 & 255;
    $4 = $3 << 8;
    $5 = $table + 3 | 0;
    $6 = HEAP8[$5] | 0;
    $7 = $6 & 255;
    $8 = $4 | $7;
    $9 = $table + $8 | 0;
    $10 = $valid + 4 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $9 >>> 0 > $11 >>> 0;
    $13 = $8 >>> 0 < 262;
    $or_cond = $12 | $13;
    if ($or_cond) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    _ft_validator_error($valid, 8);
    return 0;
   case 3:
    $16 = $valid + 8 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 8;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $20 = $table + 6 | 0;
    $21 = $valid + 56 | 0;
    $22 = $21;
    $23 = HEAP32[$22 >> 2] | 0;
    $n_014 = 0;
    $p_015 = $20;
    label = 5;
    break;
   case 5:
    $25 = HEAP8[$p_015] | 0;
    $26 = $25 & 255;
    $27 = $26 >>> 0 < $23 >>> 0;
    if ($27) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    _ft_validator_error($valid, 16);
    return 0;
   case 7:
    $30 = $p_015 + 1 | 0;
    $31 = $n_014 + 1 | 0;
    $32 = $31 >>> 0 < 256;
    if ($32) {
      $n_014 = $31;
      $p_015 = $30;
      label = 5;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    return 0;
  }
  return 0;
}
function _tt_cmap2_get_info($cmap, $cmap_info) {
  $cmap = $cmap | 0;
  $cmap_info = $cmap_info | 0;
  var $2 = 0;
  $2 = HEAP32[$cmap + 16 >> 2] | 0;
  HEAP32[$cmap_info + 4 >> 2] = 2;
  HEAP32[$cmap_info >> 2] = (HEAPU8[$2 + 4 | 0] | 0) << 8 | (HEAPU8[$2 + 5 | 0] | 0);
  return 0;
}
function _tt_cmap4_init($cmap, $table) {
  $cmap = $cmap | 0;
  $table = $table | 0;
  HEAP32[$cmap + 16 >> 2] = $table;
  HEAP32[$cmap + 32 >> 2] = ((HEAPU8[$table + 6 | 0] | 0) << 8 | (HEAPU8[$table + 7 | 0] | 0)) >>> 1;
  HEAP32[$cmap + 24 >> 2] = -1;
  HEAP32[$cmap + 28 >> 2] = 0;
  return 0;
}
function _tt_cmap4_get_info($cmap, $cmap_info) {
  $cmap = $cmap | 0;
  $cmap_info = $cmap_info | 0;
  var $2 = 0;
  $2 = HEAP32[$cmap + 16 >> 2] | 0;
  HEAP32[$cmap_info + 4 >> 2] = 4;
  HEAP32[$cmap_info >> 2] = (HEAPU8[$2 + 4 | 0] | 0) << 8 | (HEAPU8[$2 + 5 | 0] | 0);
  return 0;
}
function _tt_cmap6_char_index($cmap, $char_code) {
  $cmap = $cmap | 0;
  $char_code = $char_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $_sum = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $_sum11 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 6 | 0;
    $4 = HEAP8[$3] | 0;
    $5 = $4 & 255;
    $6 = $5 << 8;
    $7 = $2 + 7 | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 & 255;
    $10 = $6 | $9;
    $11 = $2 + 8 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $12 & 255;
    $14 = $13 << 8;
    $15 = $2 + 9 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 & 255;
    $18 = $14 | $17;
    $19 = $char_code - $10 | 0;
    $20 = $19 >>> 0 < $18 >>> 0;
    if ($20) {
      label = 2;
      break;
    } else {
      $result_0 = 0;
      label = 3;
      break;
    }
   case 2:
    $22 = $19 << 1;
    $_sum = $22 + 10 | 0;
    $23 = $2 + $_sum | 0;
    $24 = HEAP8[$23] | 0;
    $25 = $24 & 255;
    $26 = $25 << 8;
    $_sum11 = $22 + 11 | 0;
    $27 = $2 + $_sum11 | 0;
    $28 = HEAP8[$27] | 0;
    $29 = $28 & 255;
    $30 = $26 | $29;
    $result_0 = $30;
    label = 3;
    break;
   case 3:
    return $result_0 | 0;
  }
  return 0;
}
function _tt_cmap6_char_next($cmap, $pchar_code) {
  $cmap = $cmap | 0;
  $pchar_code = $pchar_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $_ = 0, $24 = 0, $25 = 0, $26 = 0, $_sum = 0, $27 = 0, $idx_022 = 0, $char_code_121 = 0, $p_020 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $gindex_1 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = HEAP32[$pchar_code >> 2] | 0;
    $4 = $3 + 1 | 0;
    $5 = $2 + 6 | 0;
    $6 = HEAP8[$5] | 0;
    $7 = $6 & 255;
    $8 = $7 << 8;
    $9 = $2 + 7 | 0;
    $10 = HEAP8[$9] | 0;
    $11 = $10 & 255;
    $12 = $8 | $11;
    $13 = $2 + 8 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 & 255;
    $16 = $15 << 8;
    $17 = $2 + 9 | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $18 & 255;
    $20 = $16 | $19;
    $21 = $4 >>> 0 > 65535;
    if ($21) {
      $result_0 = 0;
      $gindex_1 = 0;
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $23 = $4 >>> 0 < $12 >>> 0;
    $_ = $23 ? $12 : $4;
    $24 = $_ - $12 | 0;
    $25 = $24 >>> 0 < $20 >>> 0;
    if ($25) {
      label = 3;
      break;
    } else {
      $result_0 = 0;
      $gindex_1 = 0;
      label = 6;
      break;
    }
   case 3:
    $26 = $24 << 1;
    $_sum = $26 + 10 | 0;
    $27 = $2 + $_sum | 0;
    $p_020 = $27;
    $char_code_121 = $_;
    $idx_022 = $24;
    label = 4;
    break;
   case 4:
    $29 = HEAP8[$p_020] | 0;
    $30 = $29 & 255;
    $31 = $30 << 8;
    $32 = $p_020 + 1 | 0;
    $33 = HEAP8[$32] | 0;
    $34 = $33 & 255;
    $35 = $31 | $34;
    $36 = ($35 | 0) == 0;
    if ($36) {
      label = 5;
      break;
    } else {
      $result_0 = $char_code_121;
      $gindex_1 = $35;
      label = 6;
      break;
    }
   case 5:
    $38 = $p_020 + 2 | 0;
    $39 = $char_code_121 + 1 | 0;
    $40 = $idx_022 + 1 | 0;
    $41 = $40 >>> 0 < $20 >>> 0;
    if ($41) {
      $p_020 = $38;
      $char_code_121 = $39;
      $idx_022 = $40;
      label = 4;
      break;
    } else {
      $result_0 = 0;
      $gindex_1 = 0;
      label = 6;
      break;
    }
   case 6:
    HEAP32[$pchar_code >> 2] = $result_0;
    return $gindex_1 | 0;
  }
  return 0;
}
function _tt_cmap6_get_info($cmap, $cmap_info) {
  $cmap = $cmap | 0;
  $cmap_info = $cmap_info | 0;
  var $2 = 0;
  $2 = HEAP32[$cmap + 16 >> 2] | 0;
  HEAP32[$cmap_info + 4 >> 2] = 6;
  HEAP32[$cmap_info >> 2] = (HEAPU8[$2 + 4 | 0] | 0) << 8 | (HEAPU8[$2 + 5 | 0] | 0);
  return 0;
}
function _tt_cmap4_char_index($cmap, $char_code) {
  $cmap = $cmap | 0;
  $char_code = $char_code | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $11 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = __stackBase__ | 0;
    HEAP32[$1 >> 2] = $char_code;
    $2 = $char_code >>> 0 > 65535;
    if ($2) {
      $_0 = 0;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $cmap + 20 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 & 1;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = _tt_cmap4_char_map_linear($cmap, $1, 0) | 0;
    $_0 = $9;
    label = 5;
    break;
   case 4:
    $11 = _tt_cmap4_char_map_binary($cmap, $1, 0) | 0;
    $_0 = $11;
    label = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap4_char_next($cmap, $pchar_code) {
  $cmap = $cmap | 0;
  $pchar_code = $pchar_code | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $23 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$pchar_code >> 2] | 0;
    $2 = $1 >>> 0 > 65534;
    if ($2) {
      $_0 = 0;
      label = 8;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $cmap + 20 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 & 1;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = _tt_cmap4_char_map_linear($cmap, $pchar_code, 1) | 0;
    $_0 = $9;
    label = 8;
    break;
   case 4:
    $11 = $cmap + 24 | 0;
    $12 = $11;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = ($1 | 0) == ($13 | 0);
    if ($14) {
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    $16 = $cmap;
    _tt_cmap4_next($16);
    $17 = $cmap + 28 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      $_0 = 0;
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $21 = HEAP32[$12 >> 2] | 0;
    HEAP32[$pchar_code >> 2] = $21;
    $_0 = $18;
    label = 8;
    break;
   case 7:
    $23 = _tt_cmap4_char_map_binary($cmap, $pchar_code, 1) | 0;
    $_0 = $23;
    label = 8;
    break;
   case 8:
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap2_validate($table, $valid) {
  $table = $table | 0;
  $valid = $valid | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $or_cond = 0, $16 = 0, $17 = 0, $p_068 = 0, $n_067 = 0, $max_subs_066 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $34 = 0, $35 = 0, $_max_subs_0 = 0, $36 = 0, $37 = 0, $39 = 0, $_sum69 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $p_163 = 0, $n_162 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $82 = 0, $83 = 0, $85 = 0, $87 = 0, $88 = 0, $91 = 0, $_sum = 0, $93 = 0, $94 = 0, $96 = 0, $_sum58 = 0, $97 = 0, $98 = 0, $101 = 0, $102 = 0, $_sum59 = 0, $104 = 0, $105 = 0, $p_261 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $p_3 = 0, $122 = 0, $123 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table + 2 | 0;
    $2 = HEAP8[$1] | 0;
    $3 = $2 & 255;
    $4 = $3 << 8;
    $5 = $table + 3 | 0;
    $6 = HEAP8[$5] | 0;
    $7 = $6 & 255;
    $8 = $4 | $7;
    $9 = $table + $8 | 0;
    $10 = $valid + 4 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $9 >>> 0 > $11 >>> 0;
    $13 = $8 >>> 0 < 518;
    $or_cond = $12 | $13;
    if ($or_cond) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    _ft_validator_error($valid, 8);
    return 0;
   case 3:
    $16 = $table + 6 | 0;
    $17 = $valid + 8 | 0;
    $max_subs_066 = 0;
    $n_067 = 0;
    $p_068 = $16;
    label = 4;
    break;
   case 4:
    $19 = $p_068 + 2 | 0;
    $20 = HEAP8[$p_068] | 0;
    $21 = $20 & 255;
    $22 = $21 << 8;
    $23 = $p_068 + 1 | 0;
    $24 = HEAP8[$23] | 0;
    $25 = $24 & 255;
    $26 = $22 | $25;
    $27 = HEAP32[$17 >> 2] | 0;
    $28 = $27 >>> 0 > 1;
    if ($28) {
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    $30 = $25 & 7;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    _ft_validator_error($valid, 8);
    return 0;
   case 7:
    $34 = $26 >>> 3;
    $35 = $34 >>> 0 > $max_subs_066 >>> 0;
    $_max_subs_0 = $35 ? $34 : $max_subs_066;
    $36 = $n_067 + 1 | 0;
    $37 = $36 >>> 0 < 256;
    if ($37) {
      $max_subs_066 = $_max_subs_0;
      $n_067 = $36;
      $p_068 = $19;
      label = 4;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $39 = $_max_subs_0 << 3;
    $_sum69 = $39 + 10 | 0;
    $40 = $p_068 + $_sum69 | 0;
    $41 = HEAP32[$10 >> 2] | 0;
    $42 = $40 >>> 0 > $41 >>> 0;
    if ($42) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $43 = $valid + 8 | 0;
    $44 = $valid + 56 | 0;
    $45 = $44;
    $n_162 = 0;
    $p_163 = $19;
    label = 11;
    break;
   case 10:
    _ft_validator_error($valid, 8);
    return 0;
   case 11:
    $48 = HEAP8[$p_163] | 0;
    $49 = $48 & 255;
    $50 = $49 << 8;
    $51 = $p_163 + 1 | 0;
    $52 = HEAP8[$51] | 0;
    $53 = $52 & 255;
    $54 = $50 | $53;
    $55 = $p_163 + 2 | 0;
    $56 = HEAP8[$55] | 0;
    $57 = $56 & 255;
    $58 = $57 << 8;
    $59 = $p_163 + 3 | 0;
    $60 = HEAP8[$59] | 0;
    $61 = $60 & 255;
    $62 = $58 | $61;
    $63 = $p_163 + 4 | 0;
    $64 = HEAP8[$63] | 0;
    $65 = $64 & 255;
    $66 = $65 << 8;
    $67 = $p_163 + 5 | 0;
    $68 = HEAP8[$67] | 0;
    $69 = $68 & 255;
    $70 = $66 | $69;
    $71 = $p_163 + 8 | 0;
    $72 = $p_163 + 6 | 0;
    $73 = HEAP8[$72] | 0;
    $74 = $73 & 255;
    $75 = $74 << 8;
    $76 = $p_163 + 7 | 0;
    $77 = HEAP8[$76] | 0;
    $78 = $77 & 255;
    $79 = $75 | $78;
    $80 = ($62 | 0) == 0;
    if ($80) {
      $p_3 = $71;
      label = 26;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $82 = HEAP32[$43 >> 2] | 0;
    $83 = $82 >>> 0 > 1;
    if ($83) {
      label = 13;
      break;
    } else {
      label = 16;
      break;
    }
   case 13:
    $85 = $54 >>> 0 > 255;
    if ($85) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $87 = $62 + $54 | 0;
    $88 = $87 >>> 0 > 256;
    if ($88) {
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 15:
    _ft_validator_error($valid, 8);
    return 0;
   case 16:
    $91 = ($79 | 0) == 0;
    if ($91) {
      $p_3 = $71;
      label = 26;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $_sum = $79 + 6 | 0;
    $93 = $p_163 + $_sum | 0;
    $94 = $93 >>> 0 < $40 >>> 0;
    if ($94) {
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $96 = $62 << 1;
    $_sum58 = $_sum + $96 | 0;
    $97 = $p_163 + $_sum58 | 0;
    $98 = $97 >>> 0 > $9 >>> 0;
    if ($98) {
      label = 19;
      break;
    } else {
      label = 20;
      break;
    }
   case 19:
    _ft_validator_error($valid, 9);
    return 0;
   case 20:
    $101 = HEAP32[$43 >> 2] | 0;
    $102 = ($101 | 0) == 0;
    if ($102) {
      $p_3 = $71;
      label = 26;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $_sum59 = $96 + 8 | 0;
    $104 = $p_163 + $_sum59 | 0;
    $105 = $_sum59 >>> 0 > 8;
    if ($105) {
      $p_261 = $71;
      label = 22;
      break;
    } else {
      $p_3 = $71;
      label = 26;
      break;
    }
   case 22:
    $106 = $p_261 + 2 | 0;
    $107 = HEAP8[$p_261] | 0;
    $108 = $107 & 255;
    $109 = $108 << 8;
    $110 = $p_261 + 1 | 0;
    $111 = HEAP8[$110] | 0;
    $112 = $111 & 255;
    $113 = $109 | $112;
    $114 = ($113 | 0) == 0;
    if ($114) {
      label = 23;
      break;
    } else {
      label = 24;
      break;
    }
   case 23:
    $115 = $106 >>> 0 < $104 >>> 0;
    if ($115) {
      $p_261 = $106;
      label = 22;
      break;
    } else {
      $p_3 = $106;
      label = 26;
      break;
    }
   case 24:
    $117 = $113 + $70 | 0;
    $118 = $117 & 65535;
    $119 = HEAP32[$45 >> 2] | 0;
    $120 = $118 >>> 0 < $119 >>> 0;
    if ($120) {
      label = 23;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    _ft_validator_error($valid, 16);
    return 0;
   case 26:
    $122 = $n_162 + 1 | 0;
    $123 = $122 >>> 0 > $_max_subs_0 >>> 0;
    if ($123) {
      label = 27;
      break;
    } else {
      $n_162 = $122;
      $p_163 = $p_3;
      label = 11;
      break;
    }
   case 27:
    return 0;
  }
  return 0;
}
function _tt_cmap4_validate($table, $valid) {
  $table = $table | 0;
  $valid = $valid | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $length_0 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $or_cond129 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $95 = 0, $_sum = 0, $96 = 0, $_sum121 = 0, $97 = 0, $_sum122 = 0, $98 = 0, $_sum123 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $_sum126 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $_sum127 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $p_offset_0151 = 0, $p_delta_0150 = 0, $p_end_0149 = 0, $p_start_0148 = 0, $last_end_0147 = 0, $last_start_0146 = 0, $n_0145 = 0, $error_0144 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $155 = 0, $156 = 0, $or_cond130 = 0, $158 = 0, $159 = 0, $162 = 0, $163 = 0, $or_cond131 = 0, $165 = 0, $167 = 0, $error_1 = 0, $170 = 0, $171 = 0, $172 = 0, $174 = 0, $176 = 0, $177 = 0, $178 = 0, $_sum125 = 0, $179 = 0, $180 = 0, $183 = 0, $184 = 0, $or_cond = 0, $185 = 0, $or_cond132 = 0, $187 = 0, $189 = 0, $190 = 0, $191 = 0, $_sum124 = 0, $192 = 0, $193 = 0, $194 = 0, $197 = 0, $198 = 0, $199 = 0, $or_cond157 = 0, $i_0136 = 0, $p_0135 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $216 = 0, $217 = 0, $219 = 0, $220 = 0, $222 = 0, $223 = 0, $or_cond133 = 0, $224 = 0, $or_cond134 = 0, $226 = 0, $227 = 0, $error_0_lcssa = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table + 2 | 0;
    $2 = HEAP8[$1] | 0;
    $3 = $2 & 255;
    $4 = $3 << 8;
    $5 = $table + 3 | 0;
    $6 = HEAP8[$5] | 0;
    $7 = $6 & 255;
    $8 = $4 | $7;
    $9 = $8 >>> 0 < 16;
    if ($9) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    _ft_validator_error($valid, 8);
    return 0;
   case 3:
    $12 = $table + $8 | 0;
    $13 = $valid + 4 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $12 >>> 0 > $14 >>> 0;
    if ($15) {
      label = 4;
      break;
    } else {
      $length_0 = $8;
      label = 7;
      break;
    }
   case 4:
    $17 = $valid + 8 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    _ft_validator_error($valid, 8);
    return 0;
   case 6:
    $22 = HEAP32[$13 >> 2] | 0;
    $23 = $22;
    $24 = $table;
    $25 = $23 - $24 | 0;
    $length_0 = $25;
    label = 7;
    break;
   case 7:
    $27 = $table + 6 | 0;
    $28 = HEAP8[$27] | 0;
    $29 = $28 & 255;
    $30 = $29 << 8;
    $31 = $table + 7 | 0;
    $32 = HEAP8[$31] | 0;
    $33 = $32 & 255;
    $34 = $30 | $33;
    $35 = $valid + 8 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $36 >>> 0 > 1;
    if ($37) {
      label = 8;
      break;
    } else {
      label = 10;
      break;
    }
   case 8:
    $39 = $33 & 1;
    $40 = ($39 | 0) == 0;
    if ($40) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    _ft_validator_error($valid, 8);
    return 0;
   case 10:
    $43 = $34 >>> 1;
    $44 = $43 << 1;
    $45 = $43 << 3;
    $46 = $45 + 16 | 0;
    $47 = $length_0 >>> 0 < $46 >>> 0;
    if ($47) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    _ft_validator_error($valid, 8);
    return 0;
   case 12:
    $50 = HEAP32[$35 >> 2] | 0;
    $51 = $50 >>> 0 > 1;
    if ($51) {
      label = 13;
      break;
    } else {
      label = 19;
      break;
    }
   case 13:
    $53 = $table + 9 | 0;
    $54 = HEAP8[$53] | 0;
    $55 = $table + 10 | 0;
    $56 = HEAP8[$55] | 0;
    $57 = $56 & 255;
    $58 = $57 << 8;
    $59 = $table + 11 | 0;
    $60 = HEAP8[$59] | 0;
    $61 = $60 & 255;
    $62 = $58 | $61;
    $63 = $table + 13 | 0;
    $64 = HEAP8[$63] | 0;
    $65 = $64 | $54;
    $66 = $65 & 1;
    $67 = $66 << 24 >> 24 == 0;
    if ($67) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    _ft_validator_error($valid, 8);
    return 0;
   case 15:
    $70 = $table + 8 | 0;
    $71 = HEAP8[$70] | 0;
    $72 = $71 & 255;
    $73 = $54 & 255;
    $74 = $72 << 8;
    $75 = $74 | $73;
    $76 = $75 >>> 1;
    $77 = $76 >>> 0 > $43 >>> 0;
    $78 = $76 << 1;
    $79 = $78 >>> 0 < $43 >>> 0;
    $or_cond129 = $77 | $79;
    if ($or_cond129) {
      label = 18;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $81 = $table + 12 | 0;
    $82 = HEAP8[$81] | 0;
    $83 = $82 & 255;
    $84 = $83 << 8;
    $85 = $64 & 255;
    $86 = $84 | $85;
    $87 = $86 >>> 1;
    $88 = $87 + $76 | 0;
    $89 = ($88 | 0) == ($43 | 0);
    if ($89) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    $91 = 1 << $62;
    $92 = ($76 | 0) == ($91 | 0);
    if ($92) {
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    _ft_validator_error($valid, 8);
    return 0;
   case 19:
    $95 = $table + 14 | 0;
    $_sum = $44 + 16 | 0;
    $96 = $table + $_sum | 0;
    $_sum121 = $_sum + $44 | 0;
    $97 = $table + $_sum121 | 0;
    $_sum122 = $_sum121 + $44 | 0;
    $98 = $table + $_sum122 | 0;
    $_sum123 = $_sum122 + $44 | 0;
    $99 = $table + $_sum123 | 0;
    $100 = HEAP32[$35 >> 2] | 0;
    $101 = $100 >>> 0 > 1;
    if ($101) {
      label = 22;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $102 = ($43 | 0) == 0;
    if ($102) {
      $error_0_lcssa = 0;
      label = 50;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $103 = $43 - 1 | 0;
    $104 = $valid + 56 | 0;
    $105 = $104;
    $106 = $table + $length_0 | 0;
    $107 = $43 - 1 | 0;
    $error_0144 = 0;
    $n_0145 = 0;
    $last_start_0146 = 0;
    $last_end_0147 = 0;
    $p_start_0148 = $96;
    $p_end_0149 = $95;
    $p_delta_0150 = $97;
    $p_offset_0151 = $98;
    label = 24;
    break;
   case 22:
    $_sum126 = $44 + 12 | 0;
    $109 = $table + $_sum126 | 0;
    $110 = HEAP8[$109] | 0;
    $111 = $110 & 255;
    $112 = $111 << 8;
    $_sum127 = $44 + 13 | 0;
    $113 = $table + $_sum127 | 0;
    $114 = HEAP8[$113] | 0;
    $115 = $114 & 255;
    $116 = $112 | $115;
    $117 = ($116 | 0) == 65535;
    if ($117) {
      label = 20;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    _ft_validator_error($valid, 8);
    return 0;
   case 24:
    $120 = $p_start_0148 + 2 | 0;
    $121 = HEAP8[$p_start_0148] | 0;
    $122 = $121 & 255;
    $123 = $122 << 8;
    $124 = $p_start_0148 + 1 | 0;
    $125 = HEAP8[$124] | 0;
    $126 = $125 & 255;
    $127 = $123 | $126;
    $128 = $p_end_0149 + 2 | 0;
    $129 = HEAP8[$p_end_0149] | 0;
    $130 = $129 & 255;
    $131 = $130 << 8;
    $132 = $p_end_0149 + 1 | 0;
    $133 = HEAP8[$132] | 0;
    $134 = $133 & 255;
    $135 = $131 | $134;
    $136 = $p_delta_0150 + 2 | 0;
    $137 = HEAP8[$p_delta_0150] | 0;
    $138 = $137 & 255;
    $139 = $138 << 8;
    $140 = $p_delta_0150 + 1 | 0;
    $141 = HEAP8[$140] | 0;
    $142 = $141 & 255;
    $143 = $139 | $142;
    $144 = $p_offset_0151 + 2 | 0;
    $145 = HEAP8[$p_offset_0151] | 0;
    $146 = $145 & 255;
    $147 = $146 << 8;
    asmPrintInt($p_offset_0151|0);
    $148 = ($p_offset_0151 + 1) | 0;
    asmPrintInt($148|0);
    $149 = HEAP8[$148] | 0;
    $150 = $149 & 255;
    $151 = $147 | $150;
    $152 = $127 >>> 0 > $135 >>> 0;
    if ($152) {
      label = 25;
      break;
    } else {
      label = 26;
      break;
    }
   case 25:
    _ft_validator_error($valid, 8);
    return 0;
   case 26:
    $155 = $127 >>> 0 > $last_end_0147 >>> 0;
    $156 = ($n_0145 | 0) == 0;
    $or_cond130 = $155 | $156;
    if ($or_cond130) {
      $error_1 = $error_0144;
      label = 32;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $158 = HEAP32[$35 >> 2] | 0;
    $159 = ($158 | 0) == 0;
    if ($159) {
      label = 29;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    _ft_validator_error($valid, 8);
    return 0;
   case 29:
    $162 = $last_start_0146 >>> 0 > $127 >>> 0;
    $163 = $last_end_0147 >>> 0 > $135 >>> 0;
    $or_cond131 = $162 | $163;
    if ($or_cond131) {
      label = 30;
      break;
    } else {
      label = 31;
      break;
    }
   case 30:
    $165 = $error_0144 | 1;
    $error_1 = $165;
    label = 32;
    break;
   case 31:
    $167 = $error_0144 | 2;
    $error_1 = $167;
    label = 32;
    break;
   case 32:
    if (($151 | 0) == 65535) {
      label = 46;
      break;
    } else if (($151 | 0) == 0) {
      label = 49;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    $170 = $p_offset_0151 + $151 | 0;
    $171 = HEAP32[$35 >> 2] | 0;
    $172 = ($171 | 0) == 0;
    if ($172) {
      label = 37;
      break;
    } else {
      label = 34;
      break;
    }
   case 34:
    $174 = $170 >>> 0 < $99 >>> 0;
    if ($174) {
      label = 36;
      break;
    } else {
      label = 35;
      break;
    }
   case 35:
    $176 = $135 - $127 | 0;
    $177 = $176 << 1;
    $178 = $177 + 2 | 0;
    $_sum125 = $178 + $151 | 0;
    $179 = $p_offset_0151 + $_sum125 | 0;
    $180 = $179 >>> 0 > $106 >>> 0;
    if ($180) {
      label = 36;
      break;
    } else {
      label = 41;
      break;
    }
   case 36:
    _ft_validator_error($valid, 8);
    return 0;
   case 37:
    $183 = ($n_0145 | 0) == ($103 | 0);
    $184 = ($127 | 0) == 65535;
    $or_cond = $183 & $184;
    $185 = ($135 | 0) == 65535;
    $or_cond132 = $or_cond & $185;
    if ($or_cond132) {
      label = 41;
      break;
    } else {
      label = 38;
      break;
    }
   case 38:
    $187 = $170 >>> 0 < $99 >>> 0;
    if ($187) {
      label = 40;
      break;
    } else {
      label = 39;
      break;
    }
   case 39:
    $189 = $135 - $127 | 0;
    $190 = $189 << 1;
    $191 = $190 + 2 | 0;
    $_sum124 = $191 + $151 | 0;
    $192 = $p_offset_0151 + $_sum124 | 0;
    $193 = HEAP32[$13 >> 2] | 0;
    $194 = $192 >>> 0 > $193 >>> 0;
    if ($194) {
      label = 40;
      break;
    } else {
      label = 41;
      break;
    }
   case 40:
    _ft_validator_error($valid, 8);
    return 0;
   case 41:
    $197 = HEAP32[$35 >> 2] | 0;
    $198 = ($197 | 0) != 0;
    $199 = $127 >>> 0 < $135 >>> 0;
    $or_cond157 = $198 & $199;
    if ($or_cond157) {
      $p_0135 = $170;
      $i_0136 = $127;
      label = 42;
      break;
    } else {
      label = 49;
      break;
    }
   case 42:
    $200 = $p_0135 + 2 | 0;
    $201 = HEAP8[$p_0135] | 0;
    $202 = $201 & 255;
    $203 = $202 << 8;
    $204 = $p_0135 + 1 | 0;
    $205 = HEAP8[$204] | 0;
    $206 = $205 & 255;
    $207 = $203 | $206;
    $208 = ($207 | 0) == 0;
    if ($208) {
      label = 45;
      break;
    } else {
      label = 43;
      break;
    }
   case 43:
    $210 = $207 + $143 | 0;
    $211 = $210 & 65535;
    $212 = HEAP32[$105 >> 2] | 0;
    $213 = $211 >>> 0 < $212 >>> 0;
    if ($213) {
      label = 45;
      break;
    } else {
      label = 44;
      break;
    }
   case 44:
    _ft_validator_error($valid, 16);
    return 0;
   case 45:
    $216 = $i_0136 + 1 | 0;
    $217 = $216 >>> 0 < $135 >>> 0;
    if ($217) {
      $p_0135 = $200;
      $i_0136 = $216;
      label = 42;
      break;
    } else {
      label = 49;
      break;
    }
   case 46:
    $219 = HEAP32[$35 >> 2] | 0;
    $220 = $219 >>> 0 > 1;
    if ($220) {
      label = 48;
      break;
    } else {
      label = 47;
      break;
    }
   case 47:
    $222 = ($n_0145 | 0) == ($107 | 0);
    $223 = ($127 | 0) == 65535;
    $or_cond133 = $222 & $223;
    $224 = ($135 | 0) == 65535;
    $or_cond134 = $or_cond133 & $224;
    if ($or_cond134) {
      label = 49;
      break;
    } else {
      label = 48;
      break;
    }
   case 48:
    _ft_validator_error($valid, 8);
    return 0;
   case 49:
    $226 = $n_0145 + 1 | 0;
    $227 = $226 >>> 0 < $43 >>> 0;
    if ($227) {
      $error_0144 = $error_1;
      $n_0145 = $226;
      $last_start_0146 = $127;
      $last_end_0147 = $135;
      $p_start_0148 = $120;
      $p_end_0149 = $128;
      $p_delta_0150 = $136;
      $p_offset_0151 = $144;
      label = 24;
      break;
    } else {
      $error_0_lcssa = $error_1;
      label = 50;
      break;
    }
   case 50:
    return $error_0_lcssa | 0;
  }
  return 0;
}
function _tt_cmap6_validate($table, $valid) {
  $table = $table | 0;
  $valid = $valid | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $or_cond = 0, $36 = 0, $37 = 0, $38 = 0, $p_023 = 0, $count_022 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $50 = 0, $51 = 0, $52 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table + 10 | 0;
    $2 = $valid + 4 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $1 >>> 0 > $3 >>> 0;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    _ft_validator_error($valid, 8);
    return 0;
   case 3:
    $7 = $table + 2 | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 & 255;
    $10 = $9 << 8;
    $11 = $table + 3 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $12 & 255;
    $14 = $10 | $13;
    $15 = $table + 8 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 & 255;
    $18 = $17 << 8;
    $19 = $table + 9 | 0;
    $20 = HEAP8[$19] | 0;
    $21 = $20 & 255;
    $22 = $18 | $21;
    $23 = $table + $14 | 0;
    $24 = HEAP32[$2 >> 2] | 0;
    $25 = $23 >>> 0 > $24 >>> 0;
    if ($25) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $27 = $22 << 1;
    $28 = $27 + 10 | 0;
    $29 = $14 >>> 0 < $28 >>> 0;
    if ($29) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    _ft_validator_error($valid, 8);
    return 0;
   case 6:
    $32 = $valid + 8 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = ($33 | 0) == 0;
    $35 = ($22 | 0) == 0;
    $or_cond = $34 | $35;
    if ($or_cond) {
      label = 11;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $36 = $valid + 56 | 0;
    $37 = $36;
    $38 = HEAP32[$37 >> 2] | 0;
    $count_022 = $22;
    $p_023 = $1;
    label = 8;
    break;
   case 8:
    $40 = HEAP8[$p_023] | 0;
    $41 = $40 & 255;
    $42 = $41 << 8;
    $43 = $p_023 + 1 | 0;
    $44 = HEAP8[$43] | 0;
    $45 = $44 & 255;
    $46 = $42 | $45;
    $47 = $46 >>> 0 < $38 >>> 0;
    if ($47) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    _ft_validator_error($valid, 16);
    return 0;
   case 10:
    $50 = $p_023 + 2 | 0;
    $51 = $count_022 - 1 | 0;
    $52 = ($51 | 0) == 0;
    if ($52) {
      label = 11;
      break;
    } else {
      $count_022 = $51;
      $p_023 = $50;
      label = 8;
      break;
    }
   case 11:
    return 0;
  }
  return 0;
}
function _tt_cmap8_char_index($cmap, $char_code) {
  $cmap = $cmap | 0;
  $char_code = $char_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $num_groups_0 = 0, $p_0 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 8208 | 0;
    $4 = $2 + 8204 | 0;
    $5 = HEAP8[$4] | 0;
    $6 = $5 & 255;
    $7 = $6 << 24;
    $8 = $2 + 8205 | 0;
    $9 = HEAP8[$8] | 0;
    $10 = $9 & 255;
    $11 = $10 << 16;
    $12 = $11 | $7;
    $13 = $2 + 8206 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 & 255;
    $16 = $15 << 8;
    $17 = $12 | $16;
    $18 = $2 + 8207 | 0;
    $19 = HEAP8[$18] | 0;
    $20 = $19 & 255;
    $21 = $17 | $20;
    $p_0 = $3;
    $num_groups_0 = $21;
    label = 2;
    break;
   case 2:
    $23 = ($num_groups_0 | 0) == 0;
    if ($23) {
      $result_0 = 0;
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $25 = HEAP8[$p_0] | 0;
    $26 = $25 & 255;
    $27 = $26 << 24;
    $28 = $p_0 + 1 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $29 & 255;
    $31 = $30 << 16;
    $32 = $31 | $27;
    $33 = $p_0 + 2 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $35 << 8;
    $37 = $32 | $36;
    $38 = $p_0 + 3 | 0;
    $39 = HEAP8[$38] | 0;
    $40 = $39 & 255;
    $41 = $37 | $40;
    $42 = $p_0 + 8 | 0;
    $43 = HEAP8[$42] | 0;
    $44 = $43 & 255;
    $45 = $44 << 24;
    $46 = $p_0 + 9 | 0;
    $47 = HEAP8[$46] | 0;
    $48 = $47 & 255;
    $49 = $48 << 16;
    $50 = $49 | $45;
    $51 = $p_0 + 10 | 0;
    $52 = HEAP8[$51] | 0;
    $53 = $52 & 255;
    $54 = $53 << 8;
    $55 = $p_0 + 11 | 0;
    $56 = HEAP8[$55] | 0;
    $57 = $41 >>> 0 > $char_code >>> 0;
    if ($57) {
      $result_0 = 0;
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $59 = $p_0 + 12 | 0;
    $60 = $p_0 + 5 | 0;
    $61 = $p_0 + 4 | 0;
    $62 = $p_0 + 6 | 0;
    $63 = HEAP8[$60] | 0;
    $64 = HEAP8[$61] | 0;
    $65 = HEAP8[$62] | 0;
    $66 = $63 & 255;
    $67 = $64 & 255;
    $68 = $p_0 + 7 | 0;
    $69 = $65 & 255;
    $70 = $66 << 16;
    $71 = $67 << 24;
    $72 = HEAP8[$68] | 0;
    $73 = $69 << 8;
    $74 = $71 | $70;
    $75 = $72 & 255;
    $76 = $74 | $73;
    $77 = $76 | $75;
    $78 = $77 >>> 0 < $char_code >>> 0;
    $79 = $num_groups_0 - 1 | 0;
    if ($78) {
      $p_0 = $59;
      $num_groups_0 = $79;
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $81 = $50 | $54;
    $82 = $56 & 255;
    $83 = $81 | $82;
    $84 = $char_code - $41 | 0;
    $85 = $84 + $83 | 0;
    $result_0 = $85;
    label = 6;
    break;
   case 6:
    return $result_0 | 0;
  }
  return 0;
}
function _tt_cmap8_char_next($cmap, $pchar_code) {
  $cmap = $cmap | 0;
  $pchar_code = $pchar_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $char_code_032 = 0, $num_groups_031 = 0, $p_030 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $_char_code_0 = 0, $63 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $87 = 0, $88 = 0, $gindex_2 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 8204 | 0;
    $4 = HEAP8[$3] | 0;
    $5 = $4 & 255;
    $6 = $5 << 24;
    $7 = $2 + 8205 | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 & 255;
    $10 = $9 << 16;
    $11 = $10 | $6;
    $12 = $2 + 8206 | 0;
    $13 = HEAP8[$12] | 0;
    $14 = $13 & 255;
    $15 = $14 << 8;
    $16 = $11 | $15;
    $17 = $2 + 8207 | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $18 & 255;
    $20 = $16 | $19;
    $21 = ($20 | 0) == 0;
    if ($21) {
      $result_0 = 0;
      $gindex_2 = 0;
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $22 = HEAP32[$pchar_code >> 2] | 0;
    $23 = $2 + 8208 | 0;
    $24 = $22 + 1 | 0;
    $p_030 = $23;
    $num_groups_031 = $20;
    $char_code_032 = $24;
    label = 3;
    break;
   case 3:
    $26 = HEAP8[$p_030] | 0;
    $27 = $26 & 255;
    $28 = $27 << 24;
    $29 = $p_030 + 1 | 0;
    $30 = HEAP8[$29] | 0;
    $31 = $30 & 255;
    $32 = $31 << 16;
    $33 = $32 | $28;
    $34 = $p_030 + 2 | 0;
    $35 = HEAP8[$34] | 0;
    $36 = $35 & 255;
    $37 = $36 << 8;
    $38 = $33 | $37;
    $39 = $p_030 + 3 | 0;
    $40 = HEAP8[$39] | 0;
    $41 = $40 & 255;
    $42 = $38 | $41;
    $43 = $p_030 + 4 | 0;
    $44 = HEAP8[$43] | 0;
    $45 = $44 & 255;
    $46 = $45 << 24;
    $47 = $p_030 + 5 | 0;
    $48 = HEAP8[$47] | 0;
    $49 = $48 & 255;
    $50 = $49 << 16;
    $51 = $50 | $46;
    $52 = $p_030 + 6 | 0;
    $53 = HEAP8[$52] | 0;
    $54 = $53 & 255;
    $55 = $54 << 8;
    $56 = $51 | $55;
    $57 = $p_030 + 7 | 0;
    $58 = HEAP8[$57] | 0;
    $59 = $58 & 255;
    $60 = $56 | $59;
    $61 = $p_030 + 12 | 0;
    $62 = $char_code_032 >>> 0 < $42 >>> 0;
    $_char_code_0 = $62 ? $42 : $char_code_032;
    $63 = $_char_code_0 >>> 0 > $60 >>> 0;
    if ($63) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $65 = $p_030 + 9 | 0;
    $66 = $p_030 + 8 | 0;
    $67 = $p_030 + 10 | 0;
    $68 = HEAP8[$65] | 0;
    $69 = HEAP8[$66] | 0;
    $70 = HEAP8[$67] | 0;
    $71 = $68 & 255;
    $72 = $69 & 255;
    $73 = $p_030 + 11 | 0;
    $74 = $70 & 255;
    $75 = $71 << 16;
    $76 = $72 << 24;
    $77 = HEAP8[$73] | 0;
    $78 = $74 << 8;
    $79 = $76 | $75;
    $80 = $77 & 255;
    $81 = $79 | $78;
    $82 = $81 | $80;
    $83 = $_char_code_0 - $42 | 0;
    $84 = $82 + $83 | 0;
    $85 = ($84 | 0) == 0;
    if ($85) {
      label = 5;
      break;
    } else {
      $result_0 = $_char_code_0;
      $gindex_2 = $84;
      label = 6;
      break;
    }
   case 5:
    $87 = $num_groups_031 - 1 | 0;
    $88 = ($87 | 0) == 0;
    if ($88) {
      $result_0 = 0;
      $gindex_2 = 0;
      label = 6;
      break;
    } else {
      $p_030 = $61;
      $num_groups_031 = $87;
      $char_code_032 = $_char_code_0;
      label = 3;
      break;
    }
   case 6:
    HEAP32[$pchar_code >> 2] = $result_0;
    return $gindex_2 | 0;
  }
  return 0;
}
function _tt_cmap8_get_info($cmap, $cmap_info) {
  $cmap = $cmap | 0;
  $cmap_info = $cmap_info | 0;
  var $2 = 0;
  $2 = HEAP32[$cmap + 16 >> 2] | 0;
  HEAP32[$cmap_info + 4 >> 2] = 8;
  HEAP32[$cmap_info >> 2] = (HEAPU8[$2 + 9 | 0] | 0) << 16 | (HEAPU8[$2 + 8 | 0] | 0) << 24 | (HEAPU8[$2 + 10 | 0] | 0) << 8 | (HEAPU8[$2 + 11 | 0] | 0);
  return 0;
}
function _tt_cmap10_char_index($cmap, $char_code) {
  $cmap = $cmap | 0;
  $char_code = $char_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $_sum = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $_sum15 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 12 | 0;
    $4 = HEAP8[$3] | 0;
    $5 = $4 & 255;
    $6 = $5 << 24;
    $7 = $2 + 13 | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 & 255;
    $10 = $9 << 16;
    $11 = $10 | $6;
    $12 = $2 + 14 | 0;
    $13 = HEAP8[$12] | 0;
    $14 = $13 & 255;
    $15 = $14 << 8;
    $16 = $11 | $15;
    $17 = $2 + 15 | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $18 & 255;
    $20 = $16 | $19;
    $21 = $2 + 16 | 0;
    $22 = HEAP8[$21] | 0;
    $23 = $22 & 255;
    $24 = $23 << 24;
    $25 = $2 + 17 | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 & 255;
    $28 = $27 << 16;
    $29 = $28 | $24;
    $30 = $2 + 18 | 0;
    $31 = HEAP8[$30] | 0;
    $32 = $31 & 255;
    $33 = $32 << 8;
    $34 = $29 | $33;
    $35 = $2 + 19 | 0;
    $36 = HEAP8[$35] | 0;
    $37 = $36 & 255;
    $38 = $34 | $37;
    $39 = $char_code - $20 | 0;
    $40 = $39 >>> 0 < $38 >>> 0;
    if ($40) {
      label = 2;
      break;
    } else {
      $result_0 = 0;
      label = 3;
      break;
    }
   case 2:
    $42 = $39 << 1;
    $_sum = $42 + 20 | 0;
    $43 = $2 + $_sum | 0;
    $44 = HEAP8[$43] | 0;
    $45 = $44 & 255;
    $46 = $45 << 8;
    $_sum15 = $42 + 21 | 0;
    $47 = $2 + $_sum15 | 0;
    $48 = HEAP8[$47] | 0;
    $49 = $48 & 255;
    $50 = $46 | $49;
    $result_0 = $50;
    label = 3;
    break;
   case 3:
    return $result_0 | 0;
  }
  return 0;
}
function _tt_cmap10_char_next($cmap, $pchar_code) {
  $cmap = $cmap | 0;
  $pchar_code = $pchar_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $_ = 0, $42 = 0, $43 = 0, $44 = 0, $_sum = 0, $45 = 0, $idx_026 = 0, $char_code_125 = 0, $p_024 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $char_code_1_lcssa = 0, $gindex_1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = HEAP32[$pchar_code >> 2] | 0;
    $4 = $3 + 1 | 0;
    $5 = $2 + 12 | 0;
    $6 = HEAP8[$5] | 0;
    $7 = $6 & 255;
    $8 = $7 << 24;
    $9 = $2 + 13 | 0;
    $10 = HEAP8[$9] | 0;
    $11 = $10 & 255;
    $12 = $11 << 16;
    $13 = $12 | $8;
    $14 = $2 + 14 | 0;
    $15 = HEAP8[$14] | 0;
    $16 = $15 & 255;
    $17 = $16 << 8;
    $18 = $13 | $17;
    $19 = $2 + 15 | 0;
    $20 = HEAP8[$19] | 0;
    $21 = $20 & 255;
    $22 = $18 | $21;
    $23 = $2 + 16 | 0;
    $24 = HEAP8[$23] | 0;
    $25 = $24 & 255;
    $26 = $25 << 24;
    $27 = $2 + 17 | 0;
    $28 = HEAP8[$27] | 0;
    $29 = $28 & 255;
    $30 = $29 << 16;
    $31 = $30 | $26;
    $32 = $2 + 18 | 0;
    $33 = HEAP8[$32] | 0;
    $34 = $33 & 255;
    $35 = $34 << 8;
    $36 = $31 | $35;
    $37 = $2 + 19 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 & 255;
    $40 = $36 | $39;
    $41 = $4 >>> 0 < $22 >>> 0;
    $_ = $41 ? $22 : $4;
    $42 = $_ - $22 | 0;
    $43 = $42 >>> 0 < $40 >>> 0;
    if ($43) {
      label = 2;
      break;
    } else {
      $gindex_1 = 0;
      $char_code_1_lcssa = $_;
      label = 5;
      break;
    }
   case 2:
    $44 = $42 << 1;
    $_sum = $44 + 20 | 0;
    $45 = $2 + $_sum | 0;
    $p_024 = $45;
    $char_code_125 = $_;
    $idx_026 = $42;
    label = 3;
    break;
   case 3:
    $47 = HEAP8[$p_024] | 0;
    $48 = $47 & 255;
    $49 = $48 << 8;
    $50 = $p_024 + 1 | 0;
    $51 = HEAP8[$50] | 0;
    $52 = $51 & 255;
    $53 = $49 | $52;
    $54 = ($53 | 0) == 0;
    if ($54) {
      label = 4;
      break;
    } else {
      $gindex_1 = $53;
      $char_code_1_lcssa = $char_code_125;
      label = 5;
      break;
    }
   case 4:
    $56 = $p_024 + 2 | 0;
    $57 = $char_code_125 + 1 | 0;
    $58 = $idx_026 + 1 | 0;
    $59 = $58 >>> 0 < $40 >>> 0;
    if ($59) {
      $p_024 = $56;
      $char_code_125 = $57;
      $idx_026 = $58;
      label = 3;
      break;
    } else {
      $gindex_1 = 0;
      $char_code_1_lcssa = $57;
      label = 5;
      break;
    }
   case 5:
    HEAP32[$pchar_code >> 2] = $char_code_1_lcssa;
    return $gindex_1 | 0;
  }
  return 0;
}
function _tt_cmap10_get_info($cmap, $cmap_info) {
  $cmap = $cmap | 0;
  $cmap_info = $cmap_info | 0;
  var $2 = 0;
  $2 = HEAP32[$cmap + 16 >> 2] | 0;
  HEAP32[$cmap_info + 4 >> 2] = 10;
  HEAP32[$cmap_info >> 2] = (HEAPU8[$2 + 9 | 0] | 0) << 16 | (HEAPU8[$2 + 8 | 0] | 0) << 24 | (HEAPU8[$2 + 10 | 0] | 0) << 8 | (HEAPU8[$2 + 11 | 0] | 0);
  return 0;
}
function _tt_cmap12_init($cmap, $table) {
  $cmap = $cmap | 0;
  $table = $table | 0;
  HEAP32[$cmap + 16 >> 2] = $table;
  HEAP32[$cmap + 40 >> 2] = (HEAPU8[$table + 13 | 0] | 0) << 16 | (HEAPU8[$table + 12 | 0] | 0) << 24 | (HEAPU8[$table + 14 | 0] | 0) << 8 | (HEAPU8[$table + 15 | 0] | 0);
  HEAP8[$cmap + 24 | 0] = 0;
  return 0;
}
function _tt_cmap12_char_index($cmap, $char_code) {
  $cmap = $cmap | 0;
  $char_code = $char_code | 0;
  var $1 = 0, $2 = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  $1 = __stackBase__ | 0;
  HEAP32[$1 >> 2] = $char_code;
  $2 = _tt_cmap12_char_map_binary($cmap, $1, 0) | 0;
  STACKTOP = __stackBase__;
  return $2 | 0;
}
function _tt_cmap12_char_next($cmap, $pchar_code) {
  $cmap = $cmap | 0;
  $pchar_code = $pchar_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $24 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap;
    $2 = $cmap + 28 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = ($3 | 0) == -1;
    if ($4) {
      $_0 = 0;
      label = 8;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $cmap + 24 | 0;
    $7 = $6;
    $8 = HEAP8[$7] | 0;
    $9 = $8 << 24 >> 24 == 0;
    if ($9) {
      label = 7;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = HEAP32[$pchar_code >> 2] | 0;
    $12 = ($3 | 0) == ($11 | 0);
    if ($12) {
      label = 4;
      break;
    } else {
      label = 7;
      break;
    }
   case 4:
    _tt_cmap12_next($1);
    $14 = HEAP8[$7] | 0;
    $15 = $14 << 24 >> 24 == 0;
    if ($15) {
      $_0 = 0;
      label = 8;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = $cmap + 32 | 0;
    $18 = $17;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      $_0 = 0;
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $22 = HEAP32[$2 >> 2] | 0;
    HEAP32[$pchar_code >> 2] = $22;
    $_0 = $19;
    label = 8;
    break;
   case 7:
    $24 = _tt_cmap12_char_map_binary($cmap, $pchar_code, 1) | 0;
    $_0 = $24;
    label = 8;
    break;
   case 8:
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap8_validate($table, $valid) {
  $table = $table | 0;
  $valid = $valid | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $or_cond = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $_sum = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $p_086 = 0, $last_085 = 0, $n_084 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $118 = 0, $119 = 0, $or_cond75 = 0, $122 = 0, $123 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $count_077 = 0, $start_076 = 0, $135 = 0, $136 = 0, $_sum73 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $146 = 0, $147 = 0, $_sum74 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $157 = 0, $158 = 0, $159 = 0, $161 = 0, $162 = 0, $count_181 = 0, $start_180 = 0, $164 = 0, $165 = 0, $_sum72 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table + 8208 | 0;
    $2 = $valid + 4 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $1 >>> 0 > $3 >>> 0;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    _ft_validator_error($valid, 8);
    return 0;
   case 3:
    $7 = $table + 4 | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 & 255;
    $10 = $9 << 24;
    $11 = $table + 5 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $12 & 255;
    $14 = $13 << 16;
    $15 = $14 | $10;
    $16 = $table + 6 | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 & 255;
    $19 = $18 << 8;
    $20 = $15 | $19;
    $21 = $table + 7 | 0;
    $22 = HEAP8[$21] | 0;
    $23 = $22 & 255;
    $24 = $20 | $23;
    $25 = HEAP32[$2 >> 2] | 0;
    $26 = $25;
    $27 = $table;
    $28 = $26 - $27 | 0;
    $29 = $24 >>> 0 > $28 >>> 0;
    $30 = $24 >>> 0 < 8208;
    $or_cond = $29 | $30;
    if ($or_cond) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    _ft_validator_error($valid, 8);
    return 0;
   case 5:
    $33 = $table + 8204 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $35 << 24;
    $37 = $table + 8205 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 & 255;
    $40 = $39 << 16;
    $41 = $40 | $36;
    $42 = $table + 8206 | 0;
    $43 = HEAP8[$42] | 0;
    $44 = $43 & 255;
    $45 = $44 << 8;
    $46 = $41 | $45;
    $47 = $table + 8207 | 0;
    $48 = HEAP8[$47] | 0;
    $49 = $48 & 255;
    $50 = $46 | $49;
    $51 = $50 * 12 & -1;
    $_sum = $51 + 8208 | 0;
    $52 = $table + $_sum | 0;
    $53 = HEAP32[$2 >> 2] | 0;
    $54 = $52 >>> 0 > $53 >>> 0;
    if ($54) {
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $55 = ($50 | 0) == 0;
    if ($55) {
      label = 30;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $56 = $valid + 8 | 0;
    $57 = $valid + 56 | 0;
    $58 = $57;
    $n_084 = 0;
    $last_085 = 0;
    $p_086 = $1;
    label = 9;
    break;
   case 8:
    _ft_validator_error($valid, 8);
    return 0;
   case 9:
    $61 = HEAP8[$p_086] | 0;
    $62 = $61 & 255;
    $63 = $62 << 24;
    $64 = $p_086 + 1 | 0;
    $65 = HEAP8[$64] | 0;
    $66 = $65 & 255;
    $67 = $66 << 16;
    $68 = $67 | $63;
    $69 = $p_086 + 2 | 0;
    $70 = HEAP8[$69] | 0;
    $71 = $70 & 255;
    $72 = $71 << 8;
    $73 = $68 | $72;
    $74 = $p_086 + 3 | 0;
    $75 = HEAP8[$74] | 0;
    $76 = $75 & 255;
    $77 = $73 | $76;
    $78 = $p_086 + 4 | 0;
    $79 = HEAP8[$78] | 0;
    $80 = $79 & 255;
    $81 = $80 << 24;
    $82 = $p_086 + 5 | 0;
    $83 = HEAP8[$82] | 0;
    $84 = $83 & 255;
    $85 = $84 << 16;
    $86 = $85 | $81;
    $87 = $p_086 + 6 | 0;
    $88 = HEAP8[$87] | 0;
    $89 = $88 & 255;
    $90 = $89 << 8;
    $91 = $86 | $90;
    $92 = $p_086 + 7 | 0;
    $93 = HEAP8[$92] | 0;
    $94 = $93 & 255;
    $95 = $91 | $94;
    $96 = $p_086 + 12 | 0;
    $97 = $p_086 + 8 | 0;
    $98 = HEAP8[$97] | 0;
    $99 = $98 & 255;
    $100 = $99 << 24;
    $101 = $p_086 + 9 | 0;
    $102 = HEAP8[$101] | 0;
    $103 = $102 & 255;
    $104 = $103 << 16;
    $105 = $104 | $100;
    $106 = $p_086 + 10 | 0;
    $107 = HEAP8[$106] | 0;
    $108 = $107 & 255;
    $109 = $108 << 8;
    $110 = $105 | $109;
    $111 = $p_086 + 11 | 0;
    $112 = HEAP8[$111] | 0;
    $113 = $112 & 255;
    $114 = $110 | $113;
    $115 = $77 >>> 0 > $95 >>> 0;
    if ($115) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    _ft_validator_error($valid, 8);
    return 0;
   case 11:
    $118 = ($n_084 | 0) == 0;
    $119 = $77 >>> 0 > $last_085 >>> 0;
    $or_cond75 = $118 | $119;
    if ($or_cond75) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    _ft_validator_error($valid, 8);
    return 0;
   case 13:
    $122 = HEAP32[$56 >> 2] | 0;
    $123 = ($122 | 0) == 0;
    if ($123) {
      label = 29;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $125 = $95 - $77 | 0;
    $126 = $125 + $114 | 0;
    $127 = HEAP32[$58 >> 2] | 0;
    $128 = $126 >>> 0 < $127 >>> 0;
    if ($128) {
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    _ft_validator_error($valid, 16);
    return 0;
   case 16:
    $131 = $95 - $77 | 0;
    $132 = $131 + 1 | 0;
    $133 = ($68 | 0) == 0;
    if ($133) {
      label = 23;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $134 = ($132 | 0) == 0;
    if ($134) {
      label = 29;
      break;
    } else {
      $start_076 = $77;
      $count_077 = $132;
      label = 18;
      break;
    }
   case 18:
    $135 = $start_076 >>> 16;
    $136 = $start_076 >>> 19;
    $_sum73 = $136 + 12 | 0;
    $137 = $table + $_sum73 | 0;
    $138 = HEAP8[$137] | 0;
    $139 = $138 & 255;
    $140 = $135 & 7;
    $141 = 128 >>> ($140 >>> 0);
    $142 = $139 & $141;
    $143 = ($142 | 0) == 0;
    if ($143) {
      label = 19;
      break;
    } else {
      label = 20;
      break;
    }
   case 19:
    _ft_validator_error($valid, 8);
    return 0;
   case 20:
    $146 = $start_076 >>> 3;
    $147 = $146 & 8191;
    $_sum74 = $147 + 12 | 0;
    $148 = $table + $_sum74 | 0;
    $149 = HEAP8[$148] | 0;
    $150 = $149 & 255;
    $151 = $start_076 & 7;
    $152 = 128 >>> ($151 >>> 0);
    $153 = $150 & $152;
    $154 = ($153 | 0) == 0;
    if ($154) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    _ft_validator_error($valid, 8);
    return 0;
   case 22:
    $157 = $count_077 - 1 | 0;
    $158 = $start_076 + 1 | 0;
    $159 = ($157 | 0) == 0;
    if ($159) {
      label = 29;
      break;
    } else {
      $start_076 = $158;
      $count_077 = $157;
      label = 18;
      break;
    }
   case 23:
    $161 = ($86 | 0) == 0;
    if ($161) {
      label = 24;
      break;
    } else {
      label = 25;
      break;
    }
   case 24:
    $162 = ($132 | 0) == 0;
    if ($162) {
      label = 29;
      break;
    } else {
      $start_180 = $77;
      $count_181 = $132;
      label = 26;
      break;
    }
   case 25:
    _ft_validator_error($valid, 8);
    return 0;
   case 26:
    $164 = $start_180 >>> 3;
    $165 = $164 & 8191;
    $_sum72 = $165 + 12 | 0;
    $166 = $table + $_sum72 | 0;
    $167 = HEAP8[$166] | 0;
    $168 = $167 & 255;
    $169 = $start_180 & 7;
    $170 = 128 >>> ($169 >>> 0);
    $171 = $168 & $170;
    $172 = ($171 | 0) == 0;
    if ($172) {
      label = 28;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    _ft_validator_error($valid, 8);
    return 0;
   case 28:
    $175 = $count_181 - 1 | 0;
    $176 = $start_180 + 1 | 0;
    $177 = ($175 | 0) == 0;
    if ($177) {
      label = 29;
      break;
    } else {
      $start_180 = $176;
      $count_181 = $175;
      label = 26;
      break;
    }
   case 29:
    $178 = $n_084 + 1 | 0;
    $179 = $178 >>> 0 < $50 >>> 0;
    if ($179) {
      $n_084 = $178;
      $last_085 = $95;
      $p_086 = $96;
      label = 9;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    return 0;
  }
  return 0;
}
function _tt_cmap10_validate($table, $valid) {
  $table = $table | 0;
  $valid = $valid | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $or_cond = 0, $58 = 0, $59 = 0, $60 = 0, $p_027 = 0, $count_026 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $72 = 0, $73 = 0, $74 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table + 20 | 0;
    $2 = $valid + 4 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $1 >>> 0 > $3 >>> 0;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    _ft_validator_error($valid, 8);
    return 0;
   case 3:
    $7 = $table + 4 | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 & 255;
    $10 = $9 << 24;
    $11 = $table + 5 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $12 & 255;
    $14 = $13 << 16;
    $15 = $14 | $10;
    $16 = $table + 6 | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 & 255;
    $19 = $18 << 8;
    $20 = $15 | $19;
    $21 = $table + 7 | 0;
    $22 = HEAP8[$21] | 0;
    $23 = $22 & 255;
    $24 = $20 | $23;
    $25 = $table + 16 | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 & 255;
    $28 = $27 << 24;
    $29 = $table + 17 | 0;
    $30 = HEAP8[$29] | 0;
    $31 = $30 & 255;
    $32 = $31 << 16;
    $33 = $32 | $28;
    $34 = $table + 18 | 0;
    $35 = HEAP8[$34] | 0;
    $36 = $35 & 255;
    $37 = $36 << 8;
    $38 = $33 | $37;
    $39 = $table + 19 | 0;
    $40 = HEAP8[$39] | 0;
    $41 = $40 & 255;
    $42 = $38 | $41;
    $43 = HEAP32[$2 >> 2] | 0;
    $44 = $43;
    $45 = $table;
    $46 = $44 - $45 | 0;
    $47 = $24 >>> 0 > $46 >>> 0;
    if ($47) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $49 = $42 << 1;
    $50 = $49 + 20 | 0;
    $51 = $24 >>> 0 < $50 >>> 0;
    if ($51) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    _ft_validator_error($valid, 8);
    return 0;
   case 6:
    $54 = $valid + 8 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = ($55 | 0) == 0;
    $57 = ($42 | 0) == 0;
    $or_cond = $56 | $57;
    if ($or_cond) {
      label = 11;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $58 = $valid + 56 | 0;
    $59 = $58;
    $60 = HEAP32[$59 >> 2] | 0;
    $count_026 = $42;
    $p_027 = $1;
    label = 8;
    break;
   case 8:
    $62 = HEAP8[$p_027] | 0;
    $63 = $62 & 255;
    $64 = $63 << 8;
    $65 = $p_027 + 1 | 0;
    $66 = HEAP8[$65] | 0;
    $67 = $66 & 255;
    $68 = $64 | $67;
    $69 = $68 >>> 0 < $60 >>> 0;
    if ($69) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    _ft_validator_error($valid, 16);
    return 0;
   case 10:
    $72 = $p_027 + 2 | 0;
    $73 = $count_026 - 1 | 0;
    $74 = ($73 | 0) == 0;
    if ($74) {
      label = 11;
      break;
    } else {
      $count_026 = $73;
      $p_027 = $72;
      label = 8;
      break;
    }
   case 11:
    return 0;
  }
  return 0;
}
function _tt_cmap14_char_index($cmap, $char_code) {
  $cmap = $cmap | 0;
  $char_code = $char_code | 0;
  return 0;
}
function _tt_cmap14_char_next($cmap, $pchar_code) {
  $cmap = $cmap | 0;
  $pchar_code = $pchar_code | 0;
  HEAP32[$pchar_code >> 2] = 0;
  return 0;
}
function _tt_cmap12_get_info($cmap, $cmap_info) {
  $cmap = $cmap | 0;
  $cmap_info = $cmap_info | 0;
  var $2 = 0;
  $2 = HEAP32[$cmap + 16 >> 2] | 0;
  HEAP32[$cmap_info + 4 >> 2] = 12;
  HEAP32[$cmap_info >> 2] = (HEAPU8[$2 + 9 | 0] | 0) << 16 | (HEAPU8[$2 + 8 | 0] | 0) << 24 | (HEAPU8[$2 + 10 | 0] | 0) << 8 | (HEAPU8[$2 + 11 | 0] | 0);
  return 0;
}
function _tt_cmap13_init($cmap, $table) {
  $cmap = $cmap | 0;
  $table = $table | 0;
  HEAP32[$cmap + 16 >> 2] = $table;
  HEAP32[$cmap + 40 >> 2] = (HEAPU8[$table + 13 | 0] | 0) << 16 | (HEAPU8[$table + 12 | 0] | 0) << 24 | (HEAPU8[$table + 14 | 0] | 0) << 8 | (HEAPU8[$table + 15 | 0] | 0);
  HEAP8[$cmap + 24 | 0] = 0;
  return 0;
}
function _tt_cmap13_get_info($cmap, $cmap_info) {
  $cmap = $cmap | 0;
  $cmap_info = $cmap_info | 0;
  var $2 = 0;
  $2 = HEAP32[$cmap + 16 >> 2] | 0;
  HEAP32[$cmap_info + 4 >> 2] = 13;
  HEAP32[$cmap_info >> 2] = (HEAPU8[$2 + 9 | 0] | 0) << 16 | (HEAPU8[$2 + 8 | 0] | 0) << 24 | (HEAPU8[$2 + 10 | 0] | 0) << 8 | (HEAPU8[$2 + 11 | 0] | 0);
  return 0;
}
function _tt_cmap14_init($cmap, $table) {
  $cmap = $cmap | 0;
  $table = $table | 0;
  HEAP32[$cmap + 16 >> 2] = $table;
  HEAP32[$cmap + 24 >> 2] = (HEAPU8[$table + 7 | 0] | 0) << 16 | (HEAPU8[$table + 6 | 0] | 0) << 24 | (HEAPU8[$table + 8 | 0] | 0) << 8 | (HEAPU8[$table + 9 | 0] | 0);
  HEAP32[$cmap + 28 >> 2] = 0;
  HEAP32[$cmap + 32 >> 2] = 0;
  return 0;
}
function _tt_cmap13_char_index($cmap, $char_code) {
  $cmap = $cmap | 0;
  $char_code = $char_code | 0;
  var $1 = 0, $2 = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  $1 = __stackBase__ | 0;
  HEAP32[$1 >> 2] = $char_code;
  $2 = _tt_cmap13_char_map_binary($cmap, $1, 0) | 0;
  STACKTOP = __stackBase__;
  return $2 | 0;
}
function _tt_cmap13_char_next($cmap, $pchar_code) {
  $cmap = $cmap | 0;
  $pchar_code = $pchar_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $24 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap;
    $2 = $cmap + 28 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = ($3 | 0) == -1;
    if ($4) {
      $_0 = 0;
      label = 8;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $cmap + 24 | 0;
    $7 = $6;
    $8 = HEAP8[$7] | 0;
    $9 = $8 << 24 >> 24 == 0;
    if ($9) {
      label = 7;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = HEAP32[$pchar_code >> 2] | 0;
    $12 = ($3 | 0) == ($11 | 0);
    if ($12) {
      label = 4;
      break;
    } else {
      label = 7;
      break;
    }
   case 4:
    _tt_cmap13_next($1);
    $14 = HEAP8[$7] | 0;
    $15 = $14 << 24 >> 24 == 0;
    if ($15) {
      $_0 = 0;
      label = 8;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = $cmap + 32 | 0;
    $18 = $17;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      $_0 = 0;
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $22 = HEAP32[$2 >> 2] | 0;
    HEAP32[$pchar_code >> 2] = $22;
    $_0 = $19;
    label = 8;
    break;
   case 7:
    $24 = _tt_cmap13_char_map_binary($cmap, $pchar_code, 1) | 0;
    $_0 = $24;
    label = 8;
    break;
   case 8:
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap14_done($cmap) {
  $cmap = $cmap | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 36 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $cmap + 28 | 0;
    HEAP32[$3 >> 2] = 0;
    $4 = ($2 | 0) == 0;
    if ($4) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $cmap + 32 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $10 = $7;
    _ft_mem_free($2, $10);
    HEAP32[$6 >> 2] = 0;
    label = 4;
    break;
   case 4:
    return;
  }
}
function _tt_cmap14_char_var_index($cmap, $ucmap, $charcode, $variantSelector) {
  $cmap = $cmap | 0;
  $ucmap = $ucmap | 0;
  $charcode = $charcode | 0;
  $variantSelector = $variantSelector | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 6 | 0;
    $4 = _tt_cmap14_find_variant($3, $variantSelector) | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $_0 = 0;
      label = 7;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $4 + 4 | 0;
    $8 = HEAP8[$4] | 0;
    $9 = $8 & 255;
    $10 = $9 << 24;
    $11 = $4 + 1 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $12 & 255;
    $14 = $13 << 16;
    $15 = $14 | $10;
    $16 = $4 + 2 | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 & 255;
    $19 = $18 << 8;
    $20 = $15 | $19;
    $21 = $4 + 3 | 0;
    $22 = HEAP8[$21] | 0;
    $23 = $22 & 255;
    $24 = $20 | $23;
    $25 = HEAP8[$7] | 0;
    $26 = $25 & 255;
    $27 = $26 << 24;
    $28 = $4 + 5 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $29 & 255;
    $31 = $30 << 16;
    $32 = $31 | $27;
    $33 = $4 + 6 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $35 << 8;
    $37 = $32 | $36;
    $38 = $4 + 7 | 0;
    $39 = HEAP8[$38] | 0;
    $40 = $39 & 255;
    $41 = $37 | $40;
    $42 = ($24 | 0) == 0;
    if ($42) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $44 = $2 + $24 | 0;
    $45 = _tt_cmap14_char_map_def_binary($44, $charcode) | 0;
    $46 = ($45 | 0) == 0;
    if ($46) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $48 = $ucmap | 0;
    $49 = $ucmap + 12 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $50 + 12 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = FUNCTION_TABLE_iii[$52 & 1023]($48, $charcode) | 0;
    $_0 = $53;
    label = 7;
    break;
   case 5:
    $55 = ($41 | 0) == 0;
    if ($55) {
      $_0 = 0;
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $57 = HEAP32[$1 >> 2] | 0;
    $58 = $57 + $41 | 0;
    $59 = _tt_cmap14_char_map_nondef_binary($58, $charcode) | 0;
    $_0 = $59;
    label = 7;
    break;
   case 7:
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap14_char_var_isdefault($cmap, $charcode, $variantSelector) {
  $cmap = $cmap | 0;
  $charcode = $charcode | 0;
  $variantSelector = $variantSelector | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 6 | 0;
    $4 = _tt_cmap14_find_variant($3, $variantSelector) | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $_0 = -1;
      label = 7;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = HEAP8[$4] | 0;
    $8 = $7 & 255;
    $9 = $8 << 24;
    $10 = $4 + 1 | 0;
    $11 = HEAP8[$10] | 0;
    $12 = $11 & 255;
    $13 = $12 << 16;
    $14 = $13 | $9;
    $15 = $4 + 2 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 & 255;
    $18 = $17 << 8;
    $19 = $14 | $18;
    $20 = $4 + 3 | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $21 & 255;
    $23 = $19 | $22;
    $24 = $4 + 4 | 0;
    $25 = HEAP8[$24] | 0;
    $26 = $25 & 255;
    $27 = $26 << 24;
    $28 = $4 + 5 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $29 & 255;
    $31 = $30 << 16;
    $32 = $31 | $27;
    $33 = $4 + 6 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $35 << 8;
    $37 = $32 | $36;
    $38 = $4 + 7 | 0;
    $39 = HEAP8[$38] | 0;
    $40 = $39 & 255;
    $41 = $37 | $40;
    $42 = ($23 | 0) == 0;
    if ($42) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $44 = $2 + $23 | 0;
    $45 = _tt_cmap14_char_map_def_binary($44, $charcode) | 0;
    $46 = ($45 | 0) == 0;
    if ($46) {
      label = 4;
      break;
    } else {
      $_0 = 1;
      label = 7;
      break;
    }
   case 4:
    $48 = ($41 | 0) == 0;
    if ($48) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $50 = HEAP32[$1 >> 2] | 0;
    $51 = $50 + $41 | 0;
    $52 = _tt_cmap14_char_map_nondef_binary($51, $charcode) | 0;
    $53 = ($52 | 0) == 0;
    if ($53) {
      label = 6;
      break;
    } else {
      $_0 = 0;
      label = 7;
      break;
    }
   case 6:
    $_0 = -1;
    label = 7;
    break;
   case 7:
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap14_variants($cmap, $memory) {
  $cmap = $cmap | 0;
  $memory = $memory | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $i_017 = 0, $p_016 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $exitcond = 0, $i_0_lcssa = 0, $32 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap;
    $2 = $cmap + 24 | 0;
    $3 = $2;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $cmap + 16 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $4 + 1 | 0;
    $8 = _tt_cmap14_ensure($1, $7, $memory) | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 6;
      break;
    }
   case 2:
    $11 = $cmap + 32 | 0;
    $12 = $11;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = ($4 | 0) == 0;
    if ($14) {
      $i_0_lcssa = 0;
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $15 = $6 + 10 | 0;
    $p_016 = $15;
    $i_017 = 0;
    label = 4;
    break;
   case 4:
    $17 = HEAP8[$p_016] | 0;
    $18 = $17 & 255;
    $19 = $18 << 16;
    $20 = $p_016 + 1 | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $21 & 255;
    $23 = $22 << 8;
    $24 = $23 | $19;
    $25 = $p_016 + 2 | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 & 255;
    $28 = $24 | $27;
    $29 = $13 + ($i_017 << 2) | 0;
    HEAP32[$29 >> 2] = $28;
    $30 = $p_016 + 11 | 0;
    $31 = $i_017 + 1 | 0;
    $exitcond = ($31 | 0) == ($4 | 0);
    if ($exitcond) {
      $i_0_lcssa = $4;
      label = 5;
      break;
    } else {
      $p_016 = $30;
      $i_017 = $31;
      label = 4;
      break;
    }
   case 5:
    $32 = $13 + ($i_0_lcssa << 2) | 0;
    HEAP32[$32 >> 2] = 0;
    $_0 = $13;
    label = 6;
    break;
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap14_char_variants($cmap, $memory, $charCode) {
  $cmap = $cmap | 0;
  $memory = $memory | 0;
  $charCode = $charCode | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $count_032 = 0, $p_031 = 0, $q_030 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $73 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $q_1 = 0, $82 = 0, $83 = 0, $q_0_lcssa = 0, $84 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap;
    $2 = $cmap + 24 | 0;
    $3 = $2;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $cmap + 16 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $4 + 1 | 0;
    $8 = _tt_cmap14_ensure($1, $7, $memory) | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 11;
      break;
    }
   case 2:
    $11 = $cmap + 32 | 0;
    $12 = $11;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = ($4 | 0) == 0;
    if ($14) {
      $q_0_lcssa = $13;
      label = 10;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $15 = $6 + 10 | 0;
    $q_030 = $13;
    $p_031 = $15;
    $count_032 = $4;
    label = 4;
    break;
   case 4:
    $17 = HEAP8[$p_031] | 0;
    $18 = $17 & 255;
    $19 = $18 << 16;
    $20 = $p_031 + 1 | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $21 & 255;
    $23 = $22 << 8;
    $24 = $23 | $19;
    $25 = $p_031 + 2 | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 & 255;
    $28 = $24 | $27;
    $29 = $p_031 + 3 | 0;
    $30 = HEAP8[$29] | 0;
    $31 = $30 & 255;
    $32 = $31 << 24;
    $33 = $p_031 + 4 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $35 << 16;
    $37 = $36 | $32;
    $38 = $p_031 + 5 | 0;
    $39 = HEAP8[$38] | 0;
    $40 = $39 & 255;
    $41 = $40 << 8;
    $42 = $37 | $41;
    $43 = $p_031 + 6 | 0;
    $44 = HEAP8[$43] | 0;
    $45 = $44 & 255;
    $46 = $42 | $45;
    $47 = $p_031 + 11 | 0;
    $48 = $p_031 + 7 | 0;
    $49 = HEAP8[$48] | 0;
    $50 = $49 & 255;
    $51 = $50 << 24;
    $52 = $p_031 + 8 | 0;
    $53 = HEAP8[$52] | 0;
    $54 = $53 & 255;
    $55 = $54 << 16;
    $56 = $55 | $51;
    $57 = $p_031 + 9 | 0;
    $58 = HEAP8[$57] | 0;
    $59 = $58 & 255;
    $60 = $59 << 8;
    $61 = $56 | $60;
    $62 = $p_031 + 10 | 0;
    $63 = HEAP8[$62] | 0;
    $64 = $63 & 255;
    $65 = $61 | $64;
    $66 = ($46 | 0) == 0;
    if ($66) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $68 = HEAP32[$5 >> 2] | 0;
    $69 = $68 + $46 | 0;
    $70 = _tt_cmap14_char_map_def_binary($69, $charCode) | 0;
    $71 = ($70 | 0) == 0;
    if ($71) {
      label = 6;
      break;
    } else {
      label = 8;
      break;
    }
   case 6:
    $73 = ($65 | 0) == 0;
    if ($73) {
      $q_1 = $q_030;
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $75 = HEAP32[$5 >> 2] | 0;
    $76 = $75 + $65 | 0;
    $77 = _tt_cmap14_char_map_nondef_binary($76, $charCode) | 0;
    $78 = ($77 | 0) == 0;
    if ($78) {
      $q_1 = $q_030;
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    HEAP32[$q_030 >> 2] = $28;
    $80 = $q_030 + 4 | 0;
    $q_1 = $80;
    label = 9;
    break;
   case 9:
    $82 = $count_032 - 1 | 0;
    $83 = ($82 | 0) == 0;
    if ($83) {
      $q_0_lcssa = $q_1;
      label = 10;
      break;
    } else {
      $q_030 = $q_1;
      $p_031 = $47;
      $count_032 = $82;
      label = 4;
      break;
    }
   case 10:
    HEAP32[$q_0_lcssa >> 2] = 0;
    $84 = HEAP32[$12 >> 2] | 0;
    $_0 = $84;
    label = 11;
    break;
   case 11:
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap12_validate($table, $valid) {
  $table = $table | 0;
  $valid = $valid | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $last_047 = 0, $p_046 = 0, $n_045 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $115 = 0, $116 = 0, $or_cond = 0, $119 = 0, $120 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $128 = 0, $129 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table + 16 | 0;
    $2 = $valid + 4 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $1 >>> 0 > $3 >>> 0;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    _ft_validator_error($valid, 8);
    return 0;
   case 3:
    $7 = $table + 4 | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 & 255;
    $10 = $9 << 24;
    $11 = $table + 5 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $12 & 255;
    $14 = $13 << 16;
    $15 = $14 | $10;
    $16 = $table + 6 | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 & 255;
    $19 = $18 << 8;
    $20 = $15 | $19;
    $21 = $table + 7 | 0;
    $22 = HEAP8[$21] | 0;
    $23 = $22 & 255;
    $24 = $20 | $23;
    $25 = $table + 12 | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 & 255;
    $28 = $27 << 24;
    $29 = $table + 13 | 0;
    $30 = HEAP8[$29] | 0;
    $31 = $30 & 255;
    $32 = $31 << 16;
    $33 = $32 | $28;
    $34 = $table + 14 | 0;
    $35 = HEAP8[$34] | 0;
    $36 = $35 & 255;
    $37 = $36 << 8;
    $38 = $33 | $37;
    $39 = $table + 15 | 0;
    $40 = HEAP8[$39] | 0;
    $41 = $40 & 255;
    $42 = $38 | $41;
    $43 = HEAP32[$2 >> 2] | 0;
    $44 = $43;
    $45 = $table;
    $46 = $44 - $45 | 0;
    $47 = $24 >>> 0 > $46 >>> 0;
    if ($47) {
      label = 7;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $49 = $42 * 12 & -1;
    $50 = $49 + 16 | 0;
    $51 = $24 >>> 0 < $50 >>> 0;
    if ($51) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $52 = ($42 | 0) == 0;
    if ($52) {
      label = 16;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $53 = $valid + 8 | 0;
    $54 = $valid + 56 | 0;
    $55 = $54;
    $n_045 = 0;
    $p_046 = $1;
    $last_047 = 0;
    label = 8;
    break;
   case 7:
    _ft_validator_error($valid, 8);
    return 0;
   case 8:
    $58 = HEAP8[$p_046] | 0;
    $59 = $58 & 255;
    $60 = $59 << 24;
    $61 = $p_046 + 1 | 0;
    $62 = HEAP8[$61] | 0;
    $63 = $62 & 255;
    $64 = $63 << 16;
    $65 = $64 | $60;
    $66 = $p_046 + 2 | 0;
    $67 = HEAP8[$66] | 0;
    $68 = $67 & 255;
    $69 = $68 << 8;
    $70 = $65 | $69;
    $71 = $p_046 + 3 | 0;
    $72 = HEAP8[$71] | 0;
    $73 = $72 & 255;
    $74 = $70 | $73;
    $75 = $p_046 + 4 | 0;
    $76 = HEAP8[$75] | 0;
    $77 = $76 & 255;
    $78 = $77 << 24;
    $79 = $p_046 + 5 | 0;
    $80 = HEAP8[$79] | 0;
    $81 = $80 & 255;
    $82 = $81 << 16;
    $83 = $82 | $78;
    $84 = $p_046 + 6 | 0;
    $85 = HEAP8[$84] | 0;
    $86 = $85 & 255;
    $87 = $86 << 8;
    $88 = $83 | $87;
    $89 = $p_046 + 7 | 0;
    $90 = HEAP8[$89] | 0;
    $91 = $90 & 255;
    $92 = $88 | $91;
    $93 = $p_046 + 12 | 0;
    $94 = $p_046 + 8 | 0;
    $95 = HEAP8[$94] | 0;
    $96 = $95 & 255;
    $97 = $96 << 24;
    $98 = $p_046 + 9 | 0;
    $99 = HEAP8[$98] | 0;
    $100 = $99 & 255;
    $101 = $100 << 16;
    $102 = $101 | $97;
    $103 = $p_046 + 10 | 0;
    $104 = HEAP8[$103] | 0;
    $105 = $104 & 255;
    $106 = $105 << 8;
    $107 = $102 | $106;
    $108 = $p_046 + 11 | 0;
    $109 = HEAP8[$108] | 0;
    $110 = $109 & 255;
    $111 = $107 | $110;
    $112 = $74 >>> 0 > $92 >>> 0;
    if ($112) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    _ft_validator_error($valid, 8);
    return 0;
   case 10:
    $115 = ($n_045 | 0) == 0;
    $116 = $74 >>> 0 > $last_047 >>> 0;
    $or_cond = $115 | $116;
    if ($or_cond) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    _ft_validator_error($valid, 8);
    return 0;
   case 12:
    $119 = HEAP32[$53 >> 2] | 0;
    $120 = ($119 | 0) == 0;
    if ($120) {
      label = 15;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $122 = $92 - $74 | 0;
    $123 = $122 + $111 | 0;
    $124 = HEAP32[$55 >> 2] | 0;
    $125 = $123 >>> 0 < $124 >>> 0;
    if ($125) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    _ft_validator_error($valid, 16);
    return 0;
   case 15:
    $128 = $n_045 + 1 | 0;
    $129 = $128 >>> 0 < $42 >>> 0;
    if ($129) {
      $n_045 = $128;
      $p_046 = $93;
      $last_047 = $92;
      label = 8;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    return 0;
  }
  return 0;
}
function _tt_cmap13_validate($table, $valid) {
  $table = $table | 0;
  $valid = $valid | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $last_045 = 0, $p_044 = 0, $n_043 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $115 = 0, $116 = 0, $or_cond = 0, $119 = 0, $120 = 0, $122 = 0, $123 = 0, $126 = 0, $127 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table + 16 | 0;
    $2 = $valid + 4 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $1 >>> 0 > $3 >>> 0;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    _ft_validator_error($valid, 8);
    return 0;
   case 3:
    $7 = $table + 4 | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 & 255;
    $10 = $9 << 24;
    $11 = $table + 5 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $12 & 255;
    $14 = $13 << 16;
    $15 = $14 | $10;
    $16 = $table + 6 | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 & 255;
    $19 = $18 << 8;
    $20 = $15 | $19;
    $21 = $table + 7 | 0;
    $22 = HEAP8[$21] | 0;
    $23 = $22 & 255;
    $24 = $20 | $23;
    $25 = $table + 12 | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 & 255;
    $28 = $27 << 24;
    $29 = $table + 13 | 0;
    $30 = HEAP8[$29] | 0;
    $31 = $30 & 255;
    $32 = $31 << 16;
    $33 = $32 | $28;
    $34 = $table + 14 | 0;
    $35 = HEAP8[$34] | 0;
    $36 = $35 & 255;
    $37 = $36 << 8;
    $38 = $33 | $37;
    $39 = $table + 15 | 0;
    $40 = HEAP8[$39] | 0;
    $41 = $40 & 255;
    $42 = $38 | $41;
    $43 = HEAP32[$2 >> 2] | 0;
    $44 = $43;
    $45 = $table;
    $46 = $44 - $45 | 0;
    $47 = $24 >>> 0 > $46 >>> 0;
    if ($47) {
      label = 7;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $49 = $42 * 12 & -1;
    $50 = $49 + 16 | 0;
    $51 = $24 >>> 0 < $50 >>> 0;
    if ($51) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $52 = ($42 | 0) == 0;
    if ($52) {
      label = 16;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $53 = $valid + 8 | 0;
    $54 = $valid + 56 | 0;
    $55 = $54;
    $n_043 = 0;
    $p_044 = $1;
    $last_045 = 0;
    label = 8;
    break;
   case 7:
    _ft_validator_error($valid, 8);
    return 0;
   case 8:
    $58 = HEAP8[$p_044] | 0;
    $59 = $58 & 255;
    $60 = $59 << 24;
    $61 = $p_044 + 1 | 0;
    $62 = HEAP8[$61] | 0;
    $63 = $62 & 255;
    $64 = $63 << 16;
    $65 = $64 | $60;
    $66 = $p_044 + 2 | 0;
    $67 = HEAP8[$66] | 0;
    $68 = $67 & 255;
    $69 = $68 << 8;
    $70 = $65 | $69;
    $71 = $p_044 + 3 | 0;
    $72 = HEAP8[$71] | 0;
    $73 = $72 & 255;
    $74 = $70 | $73;
    $75 = $p_044 + 4 | 0;
    $76 = HEAP8[$75] | 0;
    $77 = $76 & 255;
    $78 = $77 << 24;
    $79 = $p_044 + 5 | 0;
    $80 = HEAP8[$79] | 0;
    $81 = $80 & 255;
    $82 = $81 << 16;
    $83 = $82 | $78;
    $84 = $p_044 + 6 | 0;
    $85 = HEAP8[$84] | 0;
    $86 = $85 & 255;
    $87 = $86 << 8;
    $88 = $83 | $87;
    $89 = $p_044 + 7 | 0;
    $90 = HEAP8[$89] | 0;
    $91 = $90 & 255;
    $92 = $88 | $91;
    $93 = $p_044 + 12 | 0;
    $94 = $p_044 + 8 | 0;
    $95 = HEAP8[$94] | 0;
    $96 = $95 & 255;
    $97 = $96 << 24;
    $98 = $p_044 + 9 | 0;
    $99 = HEAP8[$98] | 0;
    $100 = $99 & 255;
    $101 = $100 << 16;
    $102 = $101 | $97;
    $103 = $p_044 + 10 | 0;
    $104 = HEAP8[$103] | 0;
    $105 = $104 & 255;
    $106 = $105 << 8;
    $107 = $102 | $106;
    $108 = $p_044 + 11 | 0;
    $109 = HEAP8[$108] | 0;
    $110 = $109 & 255;
    $111 = $107 | $110;
    $112 = $74 >>> 0 > $92 >>> 0;
    if ($112) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    _ft_validator_error($valid, 8);
    return 0;
   case 10:
    $115 = ($n_043 | 0) == 0;
    $116 = $74 >>> 0 > $last_045 >>> 0;
    $or_cond = $115 | $116;
    if ($or_cond) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    _ft_validator_error($valid, 8);
    return 0;
   case 12:
    $119 = HEAP32[$53 >> 2] | 0;
    $120 = ($119 | 0) == 0;
    if ($120) {
      label = 15;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $122 = HEAP32[$55 >> 2] | 0;
    $123 = $111 >>> 0 < $122 >>> 0;
    if ($123) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    _ft_validator_error($valid, 16);
    return 0;
   case 15:
    $126 = $n_043 + 1 | 0;
    $127 = $126 >>> 0 < $42 >>> 0;
    if ($127) {
      $n_043 = $126;
      $p_044 = $93;
      $last_045 = $92;
      label = 8;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    return 0;
  }
  return 0;
}
function _tt_cmap14_get_info($cmap, $cmap_info) {
  $cmap = $cmap | 0;
  $cmap_info = $cmap_info | 0;
  HEAP32[$cmap_info + 4 >> 2] = 14;
  HEAP32[$cmap_info >> 2] = -1;
  return 0;
}
function _tt_cmap14_variant_chars($cmap, $memory, $variantSelector) {
  $cmap = $cmap | 0;
  $memory = $memory | 0;
  $variantSelector = $variantSelector | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $48 = 0, $49 = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $_sum125 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $_sum126 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $_sum127 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $_sum130 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $_sum131 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $_sum132 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $95 = 0, $97 = 0, $99 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $106 = 0, $107 = 0, $108 = 0, $_sum133 = 0, $109 = 0, $_sum134 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $_sum135 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $_sum136 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $_sum137 = 0, $123 = 0, $124 = 0, $125 = 0, $_sum139 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $_sum140 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $_sum141 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $_sum142 = 0, $139 = 0, $i_0_ph = 0, $p_0_ph = 0, $duni_0_ph = 0, $dcnt_0_ph = 0, $nuni_0_ph = 0, $dp_0_ph = 0, $di_0_ph = 0, $ni_0_ph = 0, $140 = 0, $141 = 0, $di_0174 = 0, $dp_0173 = 0, $dcnt_0172 = 0, $duni_0171 = 0, $i_0170 = 0, $k_0160 = 0, $i_1159 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $149 = 0, $150 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $di_0_lcssa = 0, $dp_0_lcssa = 0, $dcnt_0_lcssa = 0, $duni_0_lcssa = 0, $i_0_lcssa = 0, $170 = 0, $172 = 0, $173 = 0, $i_2 = 0, $175 = 0, $176 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $dp_0168 = 0, $dcnt_0166 = 0, $duni_0164 = 0, $i_3 = 0, $di_1 = 0, $ni_1 = 0, $191 = 0, $193 = 0, $i_4152 = 0, $194 = 0, $195 = 0, $196 = 0, $i_4155 = 0, $ni_2154 = 0, $p_1153 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $210 = 0, $211 = 0, $212 = 0, $i_4 = 0, $exitcond190 = 0, $214 = 0, $215 = 0, $k_1150 = 0, $i_5149 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $220 = 0, $di_2147 = 0, $dp_1146 = 0, $i_6145 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $k_2144 = 0, $i_7143 = 0, $238 = 0, $239 = 0, $240 = 0, $241 = 0, $exitcond = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $exitcond187 = 0, $247 = 0, $i_8 = 0, $248 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 6 | 0;
    $4 = _tt_cmap14_find_variant($3, $variantSelector) | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $_0 = 0;
      label = 34;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = HEAP8[$4] | 0;
    $8 = $7 & 255;
    $9 = $8 << 24;
    $10 = $4 + 1 | 0;
    $11 = HEAP8[$10] | 0;
    $12 = $11 & 255;
    $13 = $12 << 16;
    $14 = $13 | $9;
    $15 = $4 + 2 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 & 255;
    $18 = $17 << 8;
    $19 = $14 | $18;
    $20 = $4 + 3 | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $21 & 255;
    $23 = $19 | $22;
    $24 = $4 + 4 | 0;
    $25 = HEAP8[$24] | 0;
    $26 = $25 & 255;
    $27 = $26 << 24;
    $28 = $4 + 5 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $29 & 255;
    $31 = $30 << 16;
    $32 = $31 | $27;
    $33 = $4 + 6 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $35 << 8;
    $37 = $32 | $36;
    $38 = $4 + 7 | 0;
    $39 = HEAP8[$38] | 0;
    $40 = $39 & 255;
    $41 = $37 | $40;
    $42 = ($41 | 0) == 0;
    $43 = $41 | $23;
    $44 = ($43 | 0) == 0;
    if ($44) {
      $_0 = 0;
      label = 34;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $46 = ($23 | 0) == 0;
    if ($46) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $48 = $2 + $41 | 0;
    $49 = _tt_cmap14_get_nondef_chars($cmap, $48, $memory) | 0;
    $_0 = $49;
    label = 34;
    break;
   case 5:
    if ($42) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $52 = $2 + $23 | 0;
    $53 = _tt_cmap14_get_def_chars($cmap, $52, $memory) | 0;
    $_0 = $53;
    label = 34;
    break;
   case 7:
    $55 = $cmap;
    $56 = $2 + $23 | 0;
    $57 = $2 + $41 | 0;
    $58 = HEAP8[$57] | 0;
    $59 = $58 & 255;
    $60 = $59 << 24;
    $_sum125 = $41 + 1 | 0;
    $61 = $2 + $_sum125 | 0;
    $62 = HEAP8[$61] | 0;
    $63 = $62 & 255;
    $64 = $63 << 16;
    $65 = $64 | $60;
    $_sum126 = $41 + 2 | 0;
    $66 = $2 + $_sum126 | 0;
    $67 = HEAP8[$66] | 0;
    $68 = $67 & 255;
    $69 = $68 << 8;
    $70 = $65 | $69;
    $_sum127 = $41 + 3 | 0;
    $71 = $2 + $_sum127 | 0;
    $72 = HEAP8[$71] | 0;
    $73 = $72 & 255;
    $74 = $70 | $73;
    $75 = _tt_cmap14_def_char_count($56) | 0;
    $76 = HEAP8[$56] | 0;
    $77 = $76 & 255;
    $78 = $77 << 24;
    $_sum130 = $23 + 1 | 0;
    $79 = $2 + $_sum130 | 0;
    $80 = HEAP8[$79] | 0;
    $81 = $80 & 255;
    $82 = $81 << 16;
    $83 = $82 | $78;
    $_sum131 = $23 + 2 | 0;
    $84 = $2 + $_sum131 | 0;
    $85 = HEAP8[$84] | 0;
    $86 = $85 & 255;
    $87 = $86 << 8;
    $88 = $83 | $87;
    $_sum132 = $23 + 3 | 0;
    $89 = $2 + $_sum132 | 0;
    $90 = HEAP8[$89] | 0;
    $91 = $90 & 255;
    $92 = $88 | $91;
    $93 = ($74 | 0) == 0;
    if ($93) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $95 = _tt_cmap14_get_def_chars($cmap, $56, $memory) | 0;
    $_0 = $95;
    label = 34;
    break;
   case 9:
    $97 = ($75 | 0) == 0;
    if ($97) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $99 = _tt_cmap14_get_nondef_chars($cmap, $57, $memory) | 0;
    $_0 = $99;
    label = 34;
    break;
   case 11:
    $101 = $75 + 1 | 0;
    $102 = $101 + $74 | 0;
    $103 = _tt_cmap14_ensure($55, $102, $memory) | 0;
    $104 = ($103 | 0) == 0;
    if ($104) {
      label = 12;
      break;
    } else {
      $_0 = 0;
      label = 34;
      break;
    }
   case 12:
    $106 = $cmap + 32 | 0;
    $107 = $106;
    $108 = HEAP32[$107 >> 2] | 0;
    $_sum133 = $23 + 7 | 0;
    $109 = $2 + $_sum133 | 0;
    $_sum134 = $23 + 4 | 0;
    $110 = $2 + $_sum134 | 0;
    $111 = HEAP8[$110] | 0;
    $112 = $111 & 255;
    $113 = $112 << 16;
    $_sum135 = $23 + 5 | 0;
    $114 = $2 + $_sum135 | 0;
    $115 = HEAP8[$114] | 0;
    $116 = $115 & 255;
    $117 = $116 << 8;
    $118 = $117 | $113;
    $_sum136 = $23 + 6 | 0;
    $119 = $2 + $_sum136 | 0;
    $120 = HEAP8[$119] | 0;
    $121 = $120 & 255;
    $122 = $118 | $121;
    $_sum137 = $23 + 8 | 0;
    $123 = $2 + $_sum137 | 0;
    $124 = HEAP8[$109] | 0;
    $125 = $124 & 255;
    $_sum139 = $41 + 4 | 0;
    $126 = $2 + $_sum139 | 0;
    $127 = HEAP8[$126] | 0;
    $128 = $127 & 255;
    $129 = $128 << 16;
    $_sum140 = $41 + 5 | 0;
    $130 = $2 + $_sum140 | 0;
    $131 = HEAP8[$130] | 0;
    $132 = $131 & 255;
    $133 = $132 << 8;
    $134 = $133 | $129;
    $_sum141 = $41 + 6 | 0;
    $135 = $2 + $_sum141 | 0;
    $136 = HEAP8[$135] | 0;
    $137 = $136 & 255;
    $138 = $134 | $137;
    $_sum142 = $41 + 9 | 0;
    $139 = $2 + $_sum142 | 0;
    $ni_0_ph = 1;
    $di_0_ph = 1;
    $dp_0_ph = $123;
    $nuni_0_ph = $138;
    $dcnt_0_ph = $125;
    $duni_0_ph = $122;
    $p_0_ph = $139;
    $i_0_ph = 0;
    label = 13;
    break;
   case 13:
    $140 = $dcnt_0_ph + $duni_0_ph | 0;
    $141 = $nuni_0_ph >>> 0 > $140 >>> 0;
    if ($141) {
      $i_0170 = $i_0_ph;
      $duni_0171 = $duni_0_ph;
      $dcnt_0172 = $dcnt_0_ph;
      $dp_0173 = $dp_0_ph;
      $di_0174 = $di_0_ph;
      label = 14;
      break;
    } else {
      $i_0_lcssa = $i_0_ph;
      $duni_0_lcssa = $duni_0_ph;
      $dcnt_0_lcssa = $dcnt_0_ph;
      $dp_0_lcssa = $dp_0_ph;
      $di_0_lcssa = $di_0_ph;
      label = 18;
      break;
    }
   case 14:
    $i_1159 = $i_0170;
    $k_0160 = 0;
    label = 15;
    break;
   case 15:
    $143 = $k_0160 + $duni_0171 | 0;
    $144 = $i_1159 + 1 | 0;
    $145 = $108 + ($i_1159 << 2) | 0;
    HEAP32[$145 >> 2] = $143;
    $146 = $k_0160 + 1 | 0;
    $147 = $146 >>> 0 > $dcnt_0172 >>> 0;
    if ($147) {
      label = 16;
      break;
    } else {
      $i_1159 = $144;
      $k_0160 = $146;
      label = 15;
      break;
    }
   case 16:
    $149 = $di_0174 + 1 | 0;
    $150 = $149 >>> 0 > $92 >>> 0;
    if ($150) {
      $ni_1 = $ni_0_ph;
      $di_1 = $149;
      $i_3 = $144;
      $duni_0164 = $duni_0171;
      $dcnt_0166 = $dcnt_0172;
      $dp_0168 = $dp_0173;
      label = 22;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $152 = $dp_0173 + 3 | 0;
    $153 = HEAP8[$dp_0173] | 0;
    $154 = $153 & 255;
    $155 = $154 << 16;
    $156 = $dp_0173 + 1 | 0;
    $157 = HEAP8[$156] | 0;
    $158 = $157 & 255;
    $159 = $158 << 8;
    $160 = $159 | $155;
    $161 = $dp_0173 + 2 | 0;
    $162 = HEAP8[$161] | 0;
    $163 = $162 & 255;
    $164 = $160 | $163;
    $165 = $dp_0173 + 4 | 0;
    $166 = HEAP8[$152] | 0;
    $167 = $166 & 255;
    $168 = $167 + $164 | 0;
    $169 = $nuni_0_ph >>> 0 > $168 >>> 0;
    if ($169) {
      $i_0170 = $144;
      $duni_0171 = $164;
      $dcnt_0172 = $167;
      $dp_0173 = $165;
      $di_0174 = $149;
      label = 14;
      break;
    } else {
      $i_0_lcssa = $144;
      $duni_0_lcssa = $164;
      $dcnt_0_lcssa = $167;
      $dp_0_lcssa = $165;
      $di_0_lcssa = $149;
      label = 18;
      break;
    }
   case 18:
    $170 = $nuni_0_ph >>> 0 < $duni_0_lcssa >>> 0;
    if ($170) {
      label = 19;
      break;
    } else {
      $i_2 = $i_0_lcssa;
      label = 20;
      break;
    }
   case 19:
    $172 = $i_0_lcssa + 1 | 0;
    $173 = $108 + ($i_0_lcssa << 2) | 0;
    HEAP32[$173 >> 2] = $nuni_0_ph;
    $i_2 = $172;
    label = 20;
    break;
   case 20:
    $175 = $ni_0_ph + 1 | 0;
    $176 = $175 >>> 0 > $74 >>> 0;
    if ($176) {
      $ni_1 = $175;
      $di_1 = $di_0_lcssa;
      $i_3 = $i_2;
      $duni_0164 = $duni_0_lcssa;
      $dcnt_0166 = $dcnt_0_lcssa;
      $dp_0168 = $dp_0_lcssa;
      label = 22;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $178 = HEAP8[$p_0_ph] | 0;
    $179 = $178 & 255;
    $180 = $179 << 16;
    $181 = $p_0_ph + 1 | 0;
    $182 = HEAP8[$181] | 0;
    $183 = $182 & 255;
    $184 = $183 << 8;
    $185 = $184 | $180;
    $186 = $p_0_ph + 2 | 0;
    $187 = HEAP8[$186] | 0;
    $188 = $187 & 255;
    $189 = $185 | $188;
    $190 = $p_0_ph + 5 | 0;
    $ni_0_ph = $175;
    $di_0_ph = $di_0_lcssa;
    $dp_0_ph = $dp_0_lcssa;
    $nuni_0_ph = $189;
    $dcnt_0_ph = $dcnt_0_lcssa;
    $duni_0_ph = $duni_0_lcssa;
    $p_0_ph = $190;
    $i_0_ph = $i_2;
    label = 13;
    break;
   case 22:
    $191 = $ni_1 >>> 0 > $74 >>> 0;
    if ($191) {
      label = 26;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $193 = $108 + ($i_3 << 2) | 0;
    HEAP32[$193 >> 2] = $nuni_0_ph;
    $i_4152 = $i_3 + 1 | 0;
    $194 = $ni_1 >>> 0 < $74 >>> 0;
    if ($194) {
      label = 24;
      break;
    } else {
      $i_8 = $i_4152;
      label = 33;
      break;
    }
   case 24:
    $195 = $i_3 + $74 | 0;
    $196 = $195 + 1 | 0;
    $p_1153 = $p_0_ph;
    $ni_2154 = $ni_1;
    $i_4155 = $i_4152;
    label = 25;
    break;
   case 25:
    $198 = HEAP8[$p_1153] | 0;
    $199 = $198 & 255;
    $200 = $199 << 16;
    $201 = $p_1153 + 1 | 0;
    $202 = HEAP8[$201] | 0;
    $203 = $202 & 255;
    $204 = $203 << 8;
    $205 = $204 | $200;
    $206 = $p_1153 + 2 | 0;
    $207 = HEAP8[$206] | 0;
    $208 = $207 & 255;
    $209 = $205 | $208;
    $210 = $108 + ($i_4155 << 2) | 0;
    HEAP32[$210 >> 2] = $209;
    $211 = $p_1153 + 5 | 0;
    $212 = $ni_2154 + 1 | 0;
    $i_4 = $i_4155 + 1 | 0;
    $exitcond190 = ($212 | 0) == ($74 | 0);
    if ($exitcond190) {
      label = 32;
      break;
    } else {
      $p_1153 = $211;
      $ni_2154 = $212;
      $i_4155 = $i_4;
      label = 25;
      break;
    }
   case 26:
    $214 = $di_1 >>> 0 > $92 >>> 0;
    if ($214) {
      $i_8 = $i_3;
      label = 33;
      break;
    } else {
      $i_5149 = $i_3;
      $k_1150 = 0;
      label = 28;
      break;
    }
   case 27:
    $215 = $di_1 >>> 0 < $92 >>> 0;
    if ($215) {
      $i_6145 = $217;
      $dp_1146 = $dp_0168;
      $di_2147 = $di_1;
      label = 29;
      break;
    } else {
      $i_8 = $217;
      label = 33;
      break;
    }
   case 28:
    $216 = $k_1150 + $duni_0164 | 0;
    $217 = $i_5149 + 1 | 0;
    $218 = $108 + ($i_5149 << 2) | 0;
    HEAP32[$218 >> 2] = $216;
    $219 = $k_1150 + 1 | 0;
    $220 = $219 >>> 0 > $dcnt_0166 >>> 0;
    if ($220) {
      label = 27;
      break;
    } else {
      $i_5149 = $217;
      $k_1150 = $219;
      label = 28;
      break;
    }
   case 29:
    $221 = $dp_1146 + 3 | 0;
    $222 = HEAP8[$dp_1146] | 0;
    $223 = $222 & 255;
    $224 = $223 << 16;
    $225 = $dp_1146 + 1 | 0;
    $226 = HEAP8[$225] | 0;
    $227 = $226 & 255;
    $228 = $227 << 8;
    $229 = $228 | $224;
    $230 = $dp_1146 + 2 | 0;
    $231 = HEAP8[$230] | 0;
    $232 = $231 & 255;
    $233 = $229 | $232;
    $234 = HEAP8[$221] | 0;
    $235 = $234 & 255;
    $236 = $235 + 1 | 0;
    $i_7143 = $i_6145;
    $k_2144 = 0;
    label = 30;
    break;
   case 30:
    $238 = $k_2144 + $233 | 0;
    $239 = $i_7143 + 1 | 0;
    $240 = $108 + ($i_7143 << 2) | 0;
    HEAP32[$240 >> 2] = $238;
    $241 = $k_2144 + 1 | 0;
    $exitcond = ($241 | 0) == ($236 | 0);
    if ($exitcond) {
      label = 31;
      break;
    } else {
      $i_7143 = $239;
      $k_2144 = $241;
      label = 30;
      break;
    }
   case 31:
    $243 = $dp_1146 + 4 | 0;
    $244 = $i_6145 + 1 | 0;
    $245 = $244 + $235 | 0;
    $246 = $di_2147 + 1 | 0;
    $exitcond187 = ($246 | 0) == ($92 | 0);
    if ($exitcond187) {
      $i_8 = $245;
      label = 33;
      break;
    } else {
      $i_6145 = $245;
      $dp_1146 = $243;
      $di_2147 = $246;
      label = 29;
      break;
    }
   case 32:
    $247 = $196 - $ni_1 | 0;
    $i_8 = $247;
    label = 33;
    break;
   case 33:
    $248 = $108 + ($i_8 << 2) | 0;
    HEAP32[$248 >> 2] = 0;
    $_0 = $108;
    label = 34;
    break;
   case 34:
    return $_0 | 0;
  }
  return 0;
}
function _sfnt_get_interface($module, $module_interface) {
  $module = $module | 0;
  $module_interface = $module_interface | 0;
  return _ft_service_list_lookup(5249388, $module_interface) | 0;
}
function _tt_get_cmap_info($charmap, $cmap_info) {
  $charmap = $charmap | 0;
  $cmap_info = $cmap_info | 0;
  return FUNCTION_TABLE_iii[HEAP32[(HEAP32[$charmap + 12 >> 2] | 0) + 48 >> 2] & 1023]($charmap, $cmap_info) | 0;
}
function _sfnt_get_charset_id($face, $acharset_encoding, $acharset_registry) {
  $face = $face | 0;
  $acharset_encoding = $acharset_encoding | 0;
  $acharset_registry = $acharset_registry | 0;
  var $encoding = 0, $registry = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $encoding = __stackBase__ | 0;
    $registry = __stackBase__ + 8 | 0;
    $1 = _tt_face_find_bdf_prop($face, 5320688, $registry) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $error_0 = $1;
      label = 6;
      break;
    }
   case 2:
    $4 = _tt_face_find_bdf_prop($face, 5320132, $encoding) | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 3;
      break;
    } else {
      $error_0 = $4;
      label = 6;
      break;
    }
   case 3:
    $7 = $registry | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 1;
    if ($9) {
      label = 4;
      break;
    } else {
      $error_0 = 6;
      label = 6;
      break;
    }
   case 4:
    $11 = $encoding | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($12 | 0) == 1;
    if ($13) {
      label = 5;
      break;
    } else {
      $error_0 = 6;
      label = 6;
      break;
    }
   case 5:
    $15 = $encoding + 4 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    HEAP32[$acharset_encoding >> 2] = $16;
    $17 = $registry + 4 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    HEAP32[$acharset_registry >> 2] = $18;
    $error_0 = $4;
    label = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _tt_face_find_bdf_prop($face, $property_name, $aprop) {
  $face = $face | 0;
  $property_name = $property_name | 0;
  $aprop = $aprop | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $or_cond = 0, $20 = 0, $21 = 0, $22 = 0, $or_cond78 = 0, $23 = 0, $_sum = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $p_071 = 0, $count_070 = 0, $strike_069 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $p_164 = 0, $count_163 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $100 = 0, $101 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $108 = 0, $110 = 0, $111 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $118 = 0, $119 = 0, $120 = 0, $122 = 0, $_c57 = 0, $124 = 0, $_c = 0, $126 = 0, $127 = 0, $128 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 88 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $aprop | 0;
    HEAP32[$3 >> 2] = 0;
    $4 = $face + 812 | 0;
    $5 = HEAP8[$4] | 0;
    $6 = $5 << 24 >> 24 == 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $8 = $face + 104 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = _tt_face_load_bdf_props($face, $9) | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 3;
      break;
    } else {
      $error_0 = $10;
      label = 21;
      break;
    }
   case 3:
    $13 = $face + 808 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $face + 792 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($2 | 0) == 0;
    $18 = ($property_name | 0) == 0;
    $or_cond = $17 | $18;
    if ($or_cond) {
      $error_0 = 6;
      label = 21;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $20 = _strlen($property_name | 0) | 0;
    $21 = ($20 | 0) == 0;
    $22 = ($14 | 0) == 0;
    $or_cond78 = $21 | $22;
    if ($or_cond78) {
      $error_0 = 6;
      label = 21;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $23 = $14 << 2;
    $_sum = $23 + 8 | 0;
    $24 = $16 + 8 | 0;
    $25 = $16 + $_sum | 0;
    $26 = $2 + 14 | 0;
    $27 = HEAP16[$26 >> 1] | 0;
    $28 = $27 & 65535;
    $strike_069 = $25;
    $count_070 = $14;
    $p_071 = $24;
    label = 6;
    break;
   case 6:
    $30 = HEAP8[$p_071] | 0;
    $31 = $30 & 255;
    $32 = $31 << 8;
    $33 = $p_071 + 1 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $32 | $35;
    $37 = $p_071 + 2 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 & 255;
    $40 = $39 << 8;
    $41 = $p_071 + 3 | 0;
    $42 = HEAP8[$41] | 0;
    $43 = $42 & 255;
    $44 = $40 | $43;
    $45 = ($36 | 0) == ($28 | 0);
    if ($45) {
      label = 7;
      break;
    } else {
      label = 9;
      break;
    }
   case 7:
    $46 = ($44 | 0) == 0;
    if ($46) {
      $error_0 = 6;
      label = 21;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $47 = $face + 804 | 0;
    $48 = $face + 800 | 0;
    $count_163 = $44;
    $p_164 = $strike_069;
    label = 10;
    break;
   case 9:
    $50 = $p_071 + 4 | 0;
    $51 = $44 * 10 & -1;
    $52 = $strike_069 + $51 | 0;
    $53 = $count_070 - 1 | 0;
    $54 = ($53 | 0) == 0;
    if ($54) {
      $error_0 = 6;
      label = 21;
      break;
    } else {
      $strike_069 = $52;
      $count_070 = $53;
      $p_071 = $50;
      label = 6;
      break;
    }
   case 10:
    $56 = $p_164 + 5 | 0;
    $57 = HEAP8[$56] | 0;
    $58 = $57 & 255;
    $59 = $58 & 16;
    $60 = ($59 | 0) == 0;
    if ($60) {
      label = 20;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $62 = HEAP8[$p_164] | 0;
    $63 = $62 & 255;
    $64 = $63 << 24;
    $65 = $p_164 + 1 | 0;
    $66 = HEAP8[$65] | 0;
    $67 = $66 & 255;
    $68 = $67 << 16;
    $69 = $68 | $64;
    $70 = $p_164 + 2 | 0;
    $71 = HEAP8[$70] | 0;
    $72 = $71 & 255;
    $73 = $72 << 8;
    $74 = $69 | $73;
    $75 = $p_164 + 3 | 0;
    $76 = HEAP8[$75] | 0;
    $77 = $76 & 255;
    $78 = $74 | $77;
    $79 = $p_164 + 6 | 0;
    $80 = HEAP8[$79] | 0;
    $81 = $80 & 255;
    $82 = $81 << 24;
    $83 = $p_164 + 7 | 0;
    $84 = HEAP8[$83] | 0;
    $85 = $84 & 255;
    $86 = $85 << 16;
    $87 = $86 | $82;
    $88 = $p_164 + 8 | 0;
    $89 = HEAP8[$88] | 0;
    $90 = $89 & 255;
    $91 = $90 << 8;
    $92 = $87 | $91;
    $93 = $p_164 + 9 | 0;
    $94 = HEAP8[$93] | 0;
    $95 = $94 & 255;
    $96 = $92 | $95;
    $97 = HEAP32[$47 >> 2] | 0;
    $98 = $78 >>> 0 < $97 >>> 0;
    if ($98) {
      label = 12;
      break;
    } else {
      label = 20;
      break;
    }
   case 12:
    $100 = $97 - $78 | 0;
    $101 = $20 >>> 0 < $100 >>> 0;
    if ($101) {
      label = 13;
      break;
    } else {
      label = 20;
      break;
    }
   case 13:
    $103 = HEAP32[$48 >> 2] | 0;
    $104 = $103 + $78 | 0;
    $105 = _strncmp($property_name | 0, $104 | 0, $100 | 0) | 0;
    $106 = ($105 | 0) == 0;
    if ($106) {
      label = 14;
      break;
    } else {
      label = 20;
      break;
    }
   case 14:
    $108 = $58 & 15;
    if (($108 | 0) == 0 | ($108 | 0) == 1) {
      label = 15;
      break;
    } else if (($108 | 0) == 2) {
      label = 18;
      break;
    } else if (($108 | 0) == 3) {
      label = 19;
      break;
    } else {
      label = 20;
      break;
    }
   case 15:
    $110 = HEAP32[$47 >> 2] | 0;
    $111 = $96 >>> 0 < $110 >>> 0;
    if ($111) {
      label = 16;
      break;
    } else {
      label = 20;
      break;
    }
   case 16:
    $113 = HEAP32[$48 >> 2] | 0;
    $114 = $113 + $96 | 0;
    $115 = _memchr($114 | 0, 0, $110 | 0) | 0;
    $116 = ($115 | 0) == 0;
    if ($116) {
      label = 20;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    HEAP32[$3 >> 2] = 1;
    $118 = HEAP32[$48 >> 2] | 0;
    $119 = $118 + $96 | 0;
    $120 = $aprop + 4 | 0;
    HEAP32[$120 >> 2] = $119;
    $error_0 = 0;
    label = 21;
    break;
   case 18:
    HEAP32[$3 >> 2] = 2;
    $122 = $aprop + 4 | 0;
    $_c57 = $96;
    HEAP32[$122 >> 2] = $_c57;
    $error_0 = 0;
    label = 21;
    break;
   case 19:
    HEAP32[$3 >> 2] = 3;
    $124 = $aprop + 4 | 0;
    $_c = $96;
    HEAP32[$124 >> 2] = $_c;
    $error_0 = 0;
    label = 21;
    break;
   case 20:
    $126 = $p_164 + 10 | 0;
    $127 = $count_163 - 1 | 0;
    $128 = ($127 | 0) == 0;
    if ($128) {
      $error_0 = 6;
      label = 21;
      break;
    } else {
      $count_163 = $127;
      $p_164 = $126;
      label = 10;
      break;
    }
   case 21:
    return $error_0 | 0;
  }
  return 0;
}
function _tt_cmap14_validate($table, $valid) {
  $table = $table | 0;
  $valid = $valid | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $p_0105 = 0, $n_0104 = 0, $lastVarSel_0103 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $or_cond = 0, $107 = 0, $110 = 0, $111 = 0, $_sum87 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $_sum89 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $_sum90 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $_sum91 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $_sum92 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $defp_095 = 0, $i_094 = 0, $lastBase_093 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $158 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $_sum = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $_sum84 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $_sum85 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $_sum86 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $lastUni_0100 = 0, $i1_099 = 0, $ndp_098 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $217 = 0, $220 = 0, $221 = 0, $222 = 0, $224 = 0, $225 = 0, $228 = 0, $229 = 0, $230 = 0, $231 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $table + 2 | 0;
    $2 = HEAP8[$1] | 0;
    $3 = $2 & 255;
    $4 = $3 << 24;
    $5 = $table + 3 | 0;
    $6 = HEAP8[$5] | 0;
    $7 = $6 & 255;
    $8 = $7 << 16;
    $9 = $8 | $4;
    $10 = $table + 4 | 0;
    $11 = HEAP8[$10] | 0;
    $12 = $11 & 255;
    $13 = $12 << 8;
    $14 = $9 | $13;
    $15 = $table + 5 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 & 255;
    $18 = $14 | $17;
    $19 = $table + 6 | 0;
    $20 = HEAP8[$19] | 0;
    $21 = $20 & 255;
    $22 = $21 << 24;
    $23 = $table + 7 | 0;
    $24 = HEAP8[$23] | 0;
    $25 = $24 & 255;
    $26 = $25 << 16;
    $27 = $26 | $22;
    $28 = $table + 8 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $29 & 255;
    $31 = $30 << 8;
    $32 = $27 | $31;
    $33 = $table + 9 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $32 | $35;
    $37 = $valid + 4 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $38;
    $40 = $table;
    $41 = $39 - $40 | 0;
    $42 = $18 >>> 0 > $41 >>> 0;
    if ($42) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $44 = $table + 10 | 0;
    $45 = $36 * 11 & -1;
    $46 = $45 + 10 | 0;
    $47 = $18 >>> 0 < $46 >>> 0;
    if ($47) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $48 = ($36 | 0) == 0;
    if ($48) {
      label = 32;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $49 = $valid + 8 | 0;
    $50 = $valid + 56 | 0;
    $51 = $50;
    $lastVarSel_0103 = 1;
    $n_0104 = 0;
    $p_0105 = $44;
    label = 6;
    break;
   case 5:
    _ft_validator_error($valid, 8);
    return 0;
   case 6:
    $54 = HEAP8[$p_0105] | 0;
    $55 = $54 & 255;
    $56 = $55 << 16;
    $57 = $p_0105 + 1 | 0;
    $58 = HEAP8[$57] | 0;
    $59 = $58 & 255;
    $60 = $59 << 8;
    $61 = $60 | $56;
    $62 = $p_0105 + 2 | 0;
    $63 = HEAP8[$62] | 0;
    $64 = $63 & 255;
    $65 = $61 | $64;
    $66 = $p_0105 + 3 | 0;
    $67 = HEAP8[$66] | 0;
    $68 = $67 & 255;
    $69 = $68 << 24;
    $70 = $p_0105 + 4 | 0;
    $71 = HEAP8[$70] | 0;
    $72 = $71 & 255;
    $73 = $72 << 16;
    $74 = $73 | $69;
    $75 = $p_0105 + 5 | 0;
    $76 = HEAP8[$75] | 0;
    $77 = $76 & 255;
    $78 = $77 << 8;
    $79 = $74 | $78;
    $80 = $p_0105 + 6 | 0;
    $81 = HEAP8[$80] | 0;
    $82 = $81 & 255;
    $83 = $79 | $82;
    $84 = $p_0105 + 11 | 0;
    $85 = $p_0105 + 7 | 0;
    $86 = HEAP8[$85] | 0;
    $87 = $86 & 255;
    $88 = $87 << 24;
    $89 = $p_0105 + 8 | 0;
    $90 = HEAP8[$89] | 0;
    $91 = $90 & 255;
    $92 = $91 << 16;
    $93 = $92 | $88;
    $94 = $p_0105 + 9 | 0;
    $95 = HEAP8[$94] | 0;
    $96 = $95 & 255;
    $97 = $96 << 8;
    $98 = $93 | $97;
    $99 = $p_0105 + 10 | 0;
    $100 = HEAP8[$99] | 0;
    $101 = $100 & 255;
    $102 = $98 | $101;
    $103 = $83 >>> 0 < $18 >>> 0;
    $104 = $102 >>> 0 < $18 >>> 0;
    $or_cond = $103 & $104;
    if ($or_cond) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    _ft_validator_error($valid, 8);
    return 0;
   case 8:
    $107 = $65 >>> 0 < $lastVarSel_0103 >>> 0;
    if ($107) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    _ft_validator_error($valid, 8);
    return 0;
   case 10:
    $110 = $65 + 1 | 0;
    $111 = ($83 | 0) == 0;
    if ($111) {
      label = 19;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $_sum87 = $83 + 4 | 0;
    $113 = $table + $83 | 0;
    $114 = HEAP8[$113] | 0;
    $115 = $114 & 255;
    $116 = $115 << 24;
    $_sum89 = $83 + 1 | 0;
    $117 = $table + $_sum89 | 0;
    $118 = HEAP8[$117] | 0;
    $119 = $118 & 255;
    $120 = $119 << 16;
    $121 = $120 | $116;
    $_sum90 = $83 + 2 | 0;
    $122 = $table + $_sum90 | 0;
    $123 = HEAP8[$122] | 0;
    $124 = $123 & 255;
    $125 = $124 << 8;
    $126 = $121 | $125;
    $_sum91 = $83 + 3 | 0;
    $127 = $table + $_sum91 | 0;
    $128 = HEAP8[$127] | 0;
    $129 = $128 & 255;
    $130 = $126 | $129;
    $131 = $130 << 2;
    $_sum92 = $131 + $_sum87 | 0;
    $132 = $table + $_sum92 | 0;
    $133 = HEAP32[$37 >> 2] | 0;
    $134 = $132 >>> 0 > $133 >>> 0;
    if ($134) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $135 = $table + $_sum87 | 0;
    $136 = ($130 | 0) == 0;
    if ($136) {
      label = 19;
      break;
    } else {
      $lastBase_093 = 0;
      $i_094 = 0;
      $defp_095 = $135;
      label = 14;
      break;
    }
   case 13:
    _ft_validator_error($valid, 8);
    return 0;
   case 14:
    $138 = $defp_095 + 3 | 0;
    $139 = HEAP8[$defp_095] | 0;
    $140 = $139 & 255;
    $141 = $140 << 16;
    $142 = $defp_095 + 1 | 0;
    $143 = HEAP8[$142] | 0;
    $144 = $143 & 255;
    $145 = $144 << 8;
    $146 = $145 | $141;
    $147 = $defp_095 + 2 | 0;
    $148 = HEAP8[$147] | 0;
    $149 = $148 & 255;
    $150 = $146 | $149;
    $151 = $defp_095 + 4 | 0;
    $152 = HEAP8[$138] | 0;
    $153 = $152 & 255;
    $154 = $150 + $153 | 0;
    $155 = $154 >>> 0 > 1114111;
    if ($155) {
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 15:
    _ft_validator_error($valid, 8);
    return 0;
   case 16:
    $158 = $150 >>> 0 < $lastBase_093 >>> 0;
    if ($158) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    _ft_validator_error($valid, 8);
    return 0;
   case 18:
    $161 = $154 + 1 | 0;
    $162 = $i_094 + 1 | 0;
    $163 = $162 >>> 0 < $130 >>> 0;
    if ($163) {
      $lastBase_093 = $161;
      $i_094 = $162;
      $defp_095 = $151;
      label = 14;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $164 = ($102 | 0) == 0;
    if ($164) {
      label = 31;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $_sum = $102 + 4 | 0;
    $166 = $table + $_sum | 0;
    $167 = $table + $102 | 0;
    $168 = HEAP8[$167] | 0;
    $169 = $168 & 255;
    $170 = $169 << 24;
    $_sum84 = $102 + 1 | 0;
    $171 = $table + $_sum84 | 0;
    $172 = HEAP8[$171] | 0;
    $173 = $172 & 255;
    $174 = $173 << 16;
    $175 = $174 | $170;
    $_sum85 = $102 + 2 | 0;
    $176 = $table + $_sum85 | 0;
    $177 = HEAP8[$176] | 0;
    $178 = $177 & 255;
    $179 = $178 << 8;
    $180 = $175 | $179;
    $_sum86 = $102 + 3 | 0;
    $181 = $table + $_sum86 | 0;
    $182 = HEAP8[$181] | 0;
    $183 = $182 & 255;
    $184 = $180 | $183;
    $185 = $184 << 2;
    $186 = HEAP32[$37 >> 2] | 0;
    $187 = $186;
    $188 = $166;
    $189 = $187 - $188 | 0;
    $190 = $185 >>> 0 > $189 >>> 0;
    if ($190) {
      label = 22;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $191 = ($184 | 0) == 0;
    if ($191) {
      label = 31;
      break;
    } else {
      $ndp_098 = $166;
      $i1_099 = 0;
      $lastUni_0100 = 0;
      label = 23;
      break;
    }
   case 22:
    _ft_validator_error($valid, 8);
    return 0;
   case 23:
    $193 = HEAP8[$ndp_098] | 0;
    $194 = $193 & 255;
    $195 = $194 << 16;
    $196 = $ndp_098 + 1 | 0;
    $197 = HEAP8[$196] | 0;
    $198 = $197 & 255;
    $199 = $198 << 8;
    $200 = $199 | $195;
    $201 = $ndp_098 + 2 | 0;
    $202 = HEAP8[$201] | 0;
    $203 = $202 & 255;
    $204 = $200 | $203;
    $205 = $ndp_098 + 5 | 0;
    $206 = $ndp_098 + 3 | 0;
    $207 = HEAP8[$206] | 0;
    $208 = $207 & 255;
    $209 = $208 << 8;
    $210 = $ndp_098 + 4 | 0;
    $211 = HEAP8[$210] | 0;
    $212 = $211 & 255;
    $213 = $209 | $212;
    $214 = $204 >>> 0 > 1114111;
    if ($214) {
      label = 24;
      break;
    } else {
      label = 25;
      break;
    }
   case 24:
    _ft_validator_error($valid, 8);
    return 0;
   case 25:
    $217 = $204 >>> 0 < $lastUni_0100 >>> 0;
    if ($217) {
      label = 26;
      break;
    } else {
      label = 27;
      break;
    }
   case 26:
    _ft_validator_error($valid, 8);
    return 0;
   case 27:
    $220 = $204 + 1 | 0;
    $221 = HEAP32[$49 >> 2] | 0;
    $222 = ($221 | 0) == 0;
    if ($222) {
      label = 30;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $224 = HEAP32[$51 >> 2] | 0;
    $225 = $213 >>> 0 < $224 >>> 0;
    if ($225) {
      label = 30;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    _ft_validator_error($valid, 16);
    return 0;
   case 30:
    $228 = $i1_099 + 1 | 0;
    $229 = $228 >>> 0 < $184 >>> 0;
    if ($229) {
      $ndp_098 = $205;
      $i1_099 = $228;
      $lastUni_0100 = $220;
      label = 23;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    $230 = $n_0104 + 1 | 0;
    $231 = $230 >>> 0 < $36 >>> 0;
    if ($231) {
      $lastVarSel_0103 = $110;
      $n_0104 = $230;
      $p_0105 = $84;
      label = 6;
      break;
    } else {
      label = 32;
      break;
    }
   case 32:
    return 0;
  }
  return 0;
}
function _tt_face_lookup_table($face, $tag) {
  $face = $face | 0;
  $tag = $tag | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $entry_09 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 156 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 152 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 & 65535;
    $6 = $2 + ($5 << 4) | 0;
    $7 = $4 << 16 >> 16 == 0;
    if ($7) {
      $_0 = 0;
      label = 5;
      break;
    } else {
      $entry_09 = $2;
      label = 2;
      break;
    }
   case 2:
    $8 = $entry_09 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == ($tag | 0);
    if ($10) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $12 = $entry_09 + 12 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 4;
      break;
    } else {
      $_0 = $entry_09;
      label = 5;
      break;
    }
   case 4:
    $16 = $entry_09 + 16 | 0;
    $17 = $16 >>> 0 < $6 >>> 0;
    if ($17) {
      $entry_09 = $16;
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 5;
      break;
    }
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function _tt_face_load_bdf_props($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $length = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $or_cond = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $_sum = 0, $72 = 0, $73 = 0, $74 = 0, $strike_044 = 0, $count_043 = 0, $p_042 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $strike_0_lcssa = 0, $89 = 0, $90 = 0, $92 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $length = __stackBase__ | 0;
    $1 = $face + 792 | 0;
    $2 = $1;
    _memset($2 | 0, 0, 24);
    $3 = _tt_face_goto_table($face, 1111770656, $stream, $length) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 2;
      break;
    } else {
      $error_0 = 8;
      label = 12;
      break;
    }
   case 2:
    $6 = HEAP32[$length >> 2] | 0;
    $7 = $6 >>> 0 < 8;
    if ($7) {
      $error_0 = 8;
      label = 12;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = $1 | 0;
    $10 = _FT_Stream_ExtractFrame($stream, $6, $9) | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 4;
      break;
    } else {
      $error_0 = 8;
      label = 12;
      break;
    }
   case 4:
    $13 = HEAP32[$9 >> 2] | 0;
    $14 = HEAP32[$length >> 2] | 0;
    $15 = $13 + $14 | 0;
    $16 = $face + 796 | 0;
    HEAP32[$16 >> 2] = $15;
    $17 = HEAP32[$9 >> 2] | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $18 & 255;
    $20 = $19 << 8;
    $21 = $17 + 1 | 0;
    $22 = HEAP8[$21] | 0;
    $23 = $22 & 255;
    $24 = $20 | $23;
    $25 = $17 + 2 | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 & 255;
    $28 = $27 << 8;
    $29 = $17 + 3 | 0;
    $30 = HEAP8[$29] | 0;
    $31 = $30 & 255;
    $32 = $28 | $31;
    $33 = $17 + 4 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $35 << 24;
    $37 = $17 + 5 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 & 255;
    $40 = $39 << 16;
    $41 = $40 | $36;
    $42 = $17 + 6 | 0;
    $43 = HEAP8[$42] | 0;
    $44 = $43 & 255;
    $45 = $44 << 8;
    $46 = $41 | $45;
    $47 = $17 + 7 | 0;
    $48 = HEAP8[$47] | 0;
    $49 = $48 & 255;
    $50 = $46 | $49;
    $51 = ($24 | 0) != 1;
    $52 = $50 >>> 0 < 8;
    $or_cond = $51 | $52;
    if ($or_cond) {
      label = 13;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $54 = $50 - 8 | 0;
    $55 = $54 >>> 2;
    $56 = $55 >>> 0 < $32 >>> 0;
    if ($56) {
      label = 13;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $58 = $50 + 1 | 0;
    $59 = HEAP32[$length >> 2] | 0;
    $60 = $58 >>> 0 > $59 >>> 0;
    if ($60) {
      label = 13;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $62 = $face + 808 | 0;
    HEAP32[$62 >> 2] = $32;
    $63 = HEAP32[$9 >> 2] | 0;
    $64 = $63 + $50 | 0;
    $65 = $face + 800 | 0;
    HEAP32[$65 >> 2] = $64;
    $66 = HEAP32[$length >> 2] | 0;
    $67 = $66 - $50 | 0;
    $68 = $face + 804 | 0;
    HEAP32[$68 >> 2] = $67;
    $69 = HEAP32[$62 >> 2] | 0;
    $70 = HEAP32[$9 >> 2] | 0;
    $71 = $69 << 2;
    $_sum = $71 + 8 | 0;
    $72 = $70 + $_sum | 0;
    $73 = ($69 | 0) == 0;
    if ($73) {
      $strike_0_lcssa = $72;
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $74 = $70 + 8 | 0;
    $p_042 = $74;
    $count_043 = $69;
    $strike_044 = $72;
    label = 9;
    break;
   case 9:
    $76 = $p_042 + 2 | 0;
    $77 = HEAP8[$76] | 0;
    $78 = $77 & 255;
    $79 = $78 << 8;
    $80 = $p_042 + 3 | 0;
    $81 = HEAP8[$80] | 0;
    $82 = $81 & 255;
    $83 = $79 | $82;
    $84 = $83 * 10 & -1;
    $85 = $strike_044 + $84 | 0;
    $86 = $p_042 + 4 | 0;
    $87 = $count_043 - 1 | 0;
    $88 = ($87 | 0) == 0;
    if ($88) {
      $strike_0_lcssa = $85;
      label = 10;
      break;
    } else {
      $p_042 = $86;
      $count_043 = $87;
      $strike_044 = $85;
      label = 9;
      break;
    }
   case 10:
    $89 = HEAP32[$65 >> 2] | 0;
    $90 = $strike_0_lcssa >>> 0 > $89 >>> 0;
    if ($90) {
      label = 13;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $92 = $face + 812 | 0;
    HEAP8[$92] = 1;
    $error_0 = $10;
    label = 12;
    break;
   case 12:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
   case 13:
    _FT_Stream_ReleaseFrame($stream, $9);
    _memset($2 | 0, 0, 24);
    $error_0 = 8;
    label = 12;
    break;
  }
  return 0;
}
function _tt_face_goto_table($face, $tag, $stream, $length) {
  $face = $face | 0;
  $tag = $tag | 0;
  $stream = $stream | 0;
  $length = $length | 0;
  var $1 = 0, $2 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _tt_face_lookup_table($face, $tag) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      $error_0 = 142;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = ($length | 0) == 0;
    if ($4) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $6 = $1 + 12 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    HEAP32[$length >> 2] = $7;
    label = 4;
    break;
   case 4:
    $9 = $1 + 8 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = _FT_Stream_Seek($stream, $10) | 0;
    $error_0 = $11;
    label = 5;
    break;
   case 5:
    return $error_0 | 0;
  }
  return 0;
}
function _sfnt_get_glyph_name($face, $glyph_index, $buffer, $buffer_max) {
  $face = $face | 0;
  $glyph_index = $glyph_index | 0;
  $buffer = $buffer | 0;
  $buffer_max = $buffer_max | 0;
  var $gname = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $gname = __stackBase__ | 0;
    $1 = _tt_face_get_ps_name($face, $glyph_index, $gname) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $4 = HEAP32[$gname >> 2] | 0;
    $5 = _ft_mem_strcpyn($buffer, $4, $buffer_max) | 0;
    label = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return $1 | 0;
  }
  return 0;
}
function _sfnt_get_name_index($face, $glyph_name) {
  $face = $face | 0;
  $glyph_name = $glyph_name | 0;
  var $gname = 0, $1 = 0, $2 = 0, $3 = 0, $i_09 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $gname = __stackBase__ | 0;
    $1 = $face + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) < 1;
    if ($3) {
      $_0 = 0;
      label = 5;
      break;
    } else {
      $i_09 = 0;
      label = 2;
      break;
    }
   case 2:
    $4 = _tt_face_get_ps_name($face, $i_09, $gname) | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $7 = HEAP32[$gname >> 2] | 0;
    $8 = _strcmp($glyph_name | 0, $7 | 0) | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      $_0 = $i_09;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $11 = $i_09 + 1 | 0;
    $12 = $11 >>> 0 < $2 >>> 0;
    if ($12) {
      $i_09 = $11;
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 5;
      break;
    }
   case 5:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _tt_face_get_ps_name($face, $idx, $PSname) {
  $face = $face | 0;
  $idx = $idx | 0;
  $PSname = $PSname | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($face | 0) == 0;
    if ($1) {
      $_0 = 35;
      label = 17;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 264 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 & 65535;
    $6 = $5 >>> 0 > $idx >>> 0;
    if ($6) {
      label = 3;
      break;
    } else {
      $_0 = 16;
      label = 17;
      break;
    }
   case 3:
    $8 = $face + 536 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      $_0 = 7;
      label = 17;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $12 = $face + 628 | 0;
    $13 = $9 + 16 | 0;
    $14 = $13;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = FUNCTION_TABLE_ii[$15 & 1023](0) | 0;
    HEAP32[$PSname >> 2] = $16;
    $17 = $face + 468 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    if (($18 | 0) == 65536) {
      label = 5;
      break;
    } else if (($18 | 0) == 131072) {
      label = 7;
      break;
    } else if (($18 | 0) == 163840) {
      label = 13;
      break;
    } else {
      $_0 = 0;
      label = 17;
      break;
    }
   case 5:
    $20 = $idx >>> 0 < 258;
    if ($20) {
      label = 6;
      break;
    } else {
      $_0 = 0;
      label = 17;
      break;
    }
   case 6:
    $22 = HEAP32[$14 >> 2] | 0;
    $23 = FUNCTION_TABLE_ii[$22 & 1023]($idx) | 0;
    HEAP32[$PSname >> 2] = $23;
    $_0 = 0;
    label = 17;
    break;
   case 7:
    $25 = $12 | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 << 24 >> 24 == 0;
    if ($27) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $29 = _load_post_names($face) | 0;
    $30 = ($29 | 0) == 0;
    if ($30) {
      label = 9;
      break;
    } else {
      $_0 = 0;
      label = 17;
      break;
    }
   case 9:
    $32 = $face + 632 | 0;
    $33 = HEAP16[$32 >> 1] | 0;
    $34 = $33 & 65535;
    $35 = $34 >>> 0 > $idx >>> 0;
    if ($35) {
      label = 10;
      break;
    } else {
      $_0 = 0;
      label = 17;
      break;
    }
   case 10:
    $37 = $face + 636 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $38 + ($idx << 1) | 0;
    $40 = HEAP16[$39 >> 1] | 0;
    $41 = $40 & 65535;
    $42 = ($40 & 65535) < 258;
    if ($42) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $44 = HEAP32[$14 >> 2] | 0;
    $45 = FUNCTION_TABLE_ii[$44 & 1023]($41) | 0;
    HEAP32[$PSname >> 2] = $45;
    $_0 = 0;
    label = 17;
    break;
   case 12:
    $47 = $41 - 258 | 0;
    $48 = $face + 640 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = $49 + ($47 << 2) | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    HEAP32[$PSname >> 2] = $51;
    $_0 = 0;
    label = 17;
    break;
   case 13:
    $53 = $12 | 0;
    $54 = HEAP8[$53] | 0;
    $55 = $54 << 24 >> 24 == 0;
    if ($55) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $57 = _load_post_names($face) | 0;
    $58 = ($57 | 0) == 0;
    if ($58) {
      label = 15;
      break;
    } else {
      $_0 = 0;
      label = 17;
      break;
    }
   case 15:
    $60 = $face + 632 | 0;
    $61 = HEAP16[$60 >> 1] | 0;
    $62 = $61 & 65535;
    $63 = $62 >>> 0 > $idx >>> 0;
    if ($63) {
      label = 16;
      break;
    } else {
      $_0 = 0;
      label = 17;
      break;
    }
   case 16:
    $65 = $face + 636 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = $66;
    $68 = $67 + $idx | 0;
    $69 = HEAP8[$68] | 0;
    $70 = $69 << 24 >> 24;
    $71 = $70 + $idx | 0;
    $72 = HEAP32[$14 >> 2] | 0;
    $73 = FUNCTION_TABLE_ii[$72 & 1023]($71) | 0;
    HEAP32[$PSname >> 2] = $73;
    $_0 = 0;
    label = 17;
    break;
   case 17:
    return $_0 | 0;
  }
  return 0;
}
function _load_post_names($face) {
  $face = $face | 0;
  var $post_len = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $18 = 0, $20 = 0, $error_0 = 0, $22 = 0, $error_1 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $post_len = __stackBase__ | 0;
    $1 = $face + 104 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 508 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4;
    $6 = FUNCTION_TABLE_iiiii[$5 & 1023]($face, 1886352244, $2, $post_len) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 2;
      break;
    } else {
      $error_1 = $6;
      label = 7;
      break;
    }
   case 2:
    $9 = _FT_Stream_Pos($2) | 0;
    $10 = HEAP32[$post_len >> 2] | 0;
    $11 = $10 + $9 | 0;
    $12 = $face + 468 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = _FT_Stream_Skip($2, 32) | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 3;
      break;
    } else {
      $error_1 = $14;
      label = 7;
      break;
    }
   case 3:
    if (($13 | 0) == 131072) {
      label = 4;
      break;
    } else if (($13 | 0) == 163840) {
      label = 5;
      break;
    } else {
      $error_0 = 3;
      label = 6;
      break;
    }
   case 4:
    $18 = _load_format_20($face, $2, $11) | 0;
    $error_0 = $18;
    label = 6;
    break;
   case 5:
    $20 = _load_format_25($face, $2) | 0;
    $error_0 = $20;
    label = 6;
    break;
   case 6:
    $22 = $face + 628 | 0;
    HEAP8[$22] = 1;
    $error_1 = $error_0;
    label = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return $error_1 | 0;
  }
  return 0;
}
function _load_format_20($face, $stream, $post_limit) {
  $face = $face | 0;
  $stream = $stream | 0;
  $post_limit = $post_limit | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $n_091 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $n1_088 = 0, $num_names_087 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $_num_names_0 = 0, $num_names_1 = 0, $37 = 0, $38 = 0, $num_names_0_lcssa = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $indvars_iv102 = 0, $n2_080 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $56 = 0, $57 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $_ = 0, $len_0 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $73 = 0, $74 = 0, $indvars_iv_next103 = 0, $75 = 0, $76 = 0, $77 = 0, $indvars_iv96 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $indvars_iv_next97 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $indvars_iv = 0, $89 = 0, $90 = 0, $indvars_iv_next = 0, $lftr_wideiv = 0, $exitcond = 0, $name_strings_0 = 0, $91 = 0, $93 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _FT_Stream_ReadShort($stream, $error) | 0;
    $4 = $3 & 65535;
    $5 = HEAP32[$error >> 2] | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 30;
      break;
    }
   case 2:
    $8 = $face + 264 | 0;
    $9 = HEAP16[$8 >> 1] | 0;
    $10 = ($3 & 65535) > ($9 & 65535);
    if ($10) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    HEAP32[$error >> 2] = 3;
    label = 30;
    break;
   case 4:
    $13 = _ft_mem_realloc($2, 2, 0, $4, 0, $error) | 0;
    $14 = $13;
    $15 = HEAP32[$error >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 5;
      break;
    } else {
      $name_strings_0 = 0;
      label = 29;
      break;
    }
   case 5:
    $18 = $4 << 1;
    $19 = _FT_Stream_EnterFrame($stream, $18) | 0;
    HEAP32[$error >> 2] = $19;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 6;
      break;
    } else {
      $name_strings_0 = 0;
      label = 29;
      break;
    }
   case 6:
    $21 = $3 << 16 >> 16 == 0;
    if ($21) {
      label = 7;
      break;
    } else {
      $n_091 = 0;
      label = 8;
      break;
    }
   case 7:
    _FT_Stream_ExitFrame($stream);
    $num_names_0_lcssa = 0;
    label = 13;
    break;
   case 8:
    $22 = _FT_Stream_GetShort($stream) | 0;
    $23 = $14 + ($n_091 << 1) | 0;
    HEAP16[$23 >> 1] = $22;
    $24 = $n_091 + 1 | 0;
    $25 = ($24 | 0) < ($4 | 0);
    if ($25) {
      $n_091 = $24;
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    _FT_Stream_ExitFrame($stream);
    $26 = $3 << 16 >> 16 == 0;
    if ($26) {
      $num_names_0_lcssa = 0;
      label = 13;
      break;
    } else {
      $num_names_087 = 0;
      $n1_088 = 0;
      label = 10;
      break;
    }
   case 10:
    $27 = $14 + ($n1_088 << 1) | 0;
    $28 = HEAP16[$27 >> 1] | 0;
    $29 = ($28 & 65535) > 257;
    if ($29) {
      label = 11;
      break;
    } else {
      $num_names_1 = $num_names_087;
      label = 12;
      break;
    }
   case 11:
    $31 = $28 & 65535;
    $32 = $31 - 257 | 0;
    $33 = $num_names_087 & 65535;
    $34 = ($32 | 0) > ($33 | 0);
    $35 = $32 & 65535;
    $_num_names_0 = $34 ? $35 : $num_names_087;
    $num_names_1 = $_num_names_0;
    label = 12;
    break;
   case 12:
    $37 = $n1_088 + 1 | 0;
    $38 = ($37 | 0) < ($4 | 0);
    if ($38) {
      $num_names_087 = $num_names_1;
      $n1_088 = $37;
      label = 10;
      break;
    } else {
      $num_names_0_lcssa = $num_names_1;
      label = 13;
      break;
    }
   case 13:
    $39 = $num_names_0_lcssa & 65535;
    $40 = _ft_mem_realloc($2, 4, 0, $39, 0, $error) | 0;
    $41 = $40;
    $42 = HEAP32[$error >> 2] | 0;
    $43 = ($42 | 0) == 0;
    if ($43) {
      label = 14;
      break;
    } else {
      $name_strings_0 = $41;
      label = 29;
      break;
    }
   case 14:
    $44 = $num_names_0_lcssa << 16 >> 16 == 0;
    if ($44) {
      label = 27;
      break;
    } else {
      $n2_080 = 0;
      $indvars_iv102 = 0;
      label = 15;
      break;
    }
   case 15:
    $45 = _FT_Stream_Pos($stream) | 0;
    $46 = ($45 | 0) < ($post_limit | 0);
    if ($46) {
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $47 = ($n2_080 & 65535) < ($num_names_0_lcssa & 65535);
    if ($47) {
      $indvars_iv96 = $indvars_iv102;
      label = 24;
      break;
    } else {
      label = 27;
      break;
    }
   case 17:
    $49 = _FT_Stream_ReadChar($stream, $error) | 0;
    $50 = $49 & 255;
    $51 = HEAP32[$error >> 2] | 0;
    $52 = ($51 | 0) == 0;
    if ($52) {
      label = 18;
      break;
    } else {
      label = 25;
      break;
    }
   case 18:
    $54 = ($50 | 0) > ($post_limit | 0);
    if ($54) {
      label = 20;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $56 = _FT_Stream_Pos($stream) | 0;
    $57 = $post_limit - $50 | 0;
    $58 = ($56 | 0) > ($57 | 0);
    if ($58) {
      label = 20;
      break;
    } else {
      $len_0 = $50;
      label = 21;
      break;
    }
   case 20:
    $60 = _FT_Stream_Pos($stream) | 0;
    $61 = $post_limit - $60 | 0;
    $62 = ($61 | 0) < 0;
    $_ = $62 ? 0 : $61;
    $len_0 = $_;
    label = 21;
    break;
   case 21:
    $64 = $len_0 + 1 | 0;
    $65 = _ft_mem_realloc($2, 1, 0, $64, 0, $error) | 0;
    $66 = $41 + ($indvars_iv102 << 2) | 0;
    HEAP32[$66 >> 2] = $65;
    $67 = HEAP32[$error >> 2] | 0;
    $68 = ($67 | 0) == 0;
    if ($68) {
      label = 22;
      break;
    } else {
      label = 25;
      break;
    }
   case 22:
    $70 = _FT_Stream_Read($stream, $65, $len_0) | 0;
    HEAP32[$error >> 2] = $70;
    $71 = ($70 | 0) == 0;
    if ($71) {
      label = 23;
      break;
    } else {
      label = 25;
      break;
    }
   case 23:
    $73 = HEAP32[$66 >> 2] | 0;
    $74 = $73 + $len_0 | 0;
    HEAP8[$74] = 0;
    $indvars_iv_next103 = $indvars_iv102 + 1 | 0;
    $75 = $n2_080 + 1 & 65535;
    $76 = $indvars_iv_next103 & 65535;
    $77 = ($76 & 65535) < ($num_names_0_lcssa & 65535);
    if ($77) {
      $n2_080 = $75;
      $indvars_iv102 = $indvars_iv_next103;
      label = 15;
      break;
    } else {
      label = 27;
      break;
    }
   case 24:
    $78 = _ft_mem_realloc($2, 1, 0, 1, 0, $error) | 0;
    $79 = $41 + ($indvars_iv96 << 2) | 0;
    HEAP32[$79 >> 2] = $78;
    $80 = HEAP32[$error >> 2] | 0;
    $81 = ($80 | 0) == 0;
    if ($81) {
      label = 26;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $82 = $num_names_0_lcssa << 16 >> 16 == 0;
    if ($82) {
      $name_strings_0 = $41;
      label = 29;
      break;
    } else {
      $indvars_iv = 0;
      label = 28;
      break;
    }
   case 26:
    HEAP8[$78] = 0;
    $indvars_iv_next97 = $indvars_iv96 + 1 | 0;
    $83 = $indvars_iv_next97 & 65535;
    $84 = ($83 & 65535) < ($num_names_0_lcssa & 65535);
    if ($84) {
      $indvars_iv96 = $indvars_iv_next97;
      label = 24;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $85 = $face + 632 | 0;
    HEAP16[$85 >> 1] = $3;
    $86 = $face + 634 | 0;
    HEAP16[$86 >> 1] = $num_names_0_lcssa;
    $87 = $face + 636 | 0;
    HEAP32[$87 >> 2] = $14;
    $88 = $face + 640 | 0;
    HEAP32[$88 >> 2] = $41;
    $_0 = 0;
    label = 31;
    break;
   case 28:
    $89 = $41 + ($indvars_iv << 2) | 0;
    $90 = HEAP32[$89 >> 2] | 0;
    _ft_mem_free($2, $90);
    HEAP32[$89 >> 2] = 0;
    $indvars_iv_next = $indvars_iv + 1 | 0;
    $lftr_wideiv = $indvars_iv_next & 65535;
    $exitcond = $lftr_wideiv << 16 >> 16 == $num_names_0_lcssa << 16 >> 16;
    if ($exitcond) {
      $name_strings_0 = $41;
      label = 29;
      break;
    } else {
      $indvars_iv = $indvars_iv_next;
      label = 28;
      break;
    }
   case 29:
    $91 = $name_strings_0;
    _ft_mem_free($2, $91);
    _ft_mem_free($2, $13);
    label = 30;
    break;
   case 30:
    $93 = HEAP32[$error >> 2] | 0;
    $_0 = $93;
    label = 31;
    break;
   case 31:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _load_format_25($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $or_cond = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $n_0 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $or_cond1 = 0, $28 = 0, $31 = 0, $32 = 0, $_c = 0, $35 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _FT_Stream_ReadShort($stream, $error) | 0;
    $4 = $3 & 65535;
    $5 = HEAP32[$error >> 2] | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 11;
      break;
    }
   case 2:
    $8 = $face + 264 | 0;
    $9 = HEAP16[$8 >> 1] | 0;
    $10 = ($3 & 65535) > ($9 & 65535);
    $11 = ($3 & 65535) > 258;
    $or_cond = $10 | $11;
    if ($or_cond) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    HEAP32[$error >> 2] = 3;
    label = 11;
    break;
   case 4:
    $14 = _ft_mem_realloc($2, 1, 0, $4, 0, $error) | 0;
    $15 = HEAP32[$error >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 5;
      break;
    } else {
      label = 10;
      break;
    }
   case 5:
    $18 = _FT_Stream_Read($stream, $14, $4) | 0;
    HEAP32[$error >> 2] = $18;
    $19 = ($18 | 0) == 0;
    if ($19) {
      $n_0 = 0;
      label = 6;
      break;
    } else {
      label = 10;
      break;
    }
   case 6:
    $20 = ($n_0 | 0) < ($4 | 0);
    if ($20) {
      label = 7;
      break;
    } else {
      label = 9;
      break;
    }
   case 7:
    $22 = $14 + $n_0 | 0;
    $23 = HEAP8[$22] | 0;
    $24 = $23 << 24 >> 24;
    $25 = $24 + $n_0 | 0;
    $26 = ($25 | 0) < 0;
    $27 = ($25 | 0) > ($4 | 0);
    $or_cond1 = $26 | $27;
    $28 = $n_0 + 1 | 0;
    if ($or_cond1) {
      label = 8;
      break;
    } else {
      $n_0 = $28;
      label = 6;
      break;
    }
   case 8:
    HEAP32[$error >> 2] = 3;
    label = 10;
    break;
   case 9:
    $31 = $face + 632 | 0;
    HEAP16[$31 >> 1] = $3;
    $32 = $face + 636 | 0;
    $_c = $14;
    HEAP32[$32 >> 2] = $_c;
    $_0 = 0;
    label = 12;
    break;
   case 10:
    _ft_mem_free($2, $14);
    label = 11;
    break;
   case 11:
    $35 = HEAP32[$error >> 2] | 0;
    $_0 = $35;
    label = 12;
    break;
   case 12:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _sfnt_get_ps_name($face) {
  $face = $face | 0;
  var $error = 0, $error5 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $n_065 = 0, $found_win_064 = 0, $found_apple_063 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $n_0_found_win_0 = 0, $found_win_1_ph = 0, $_pr = 0, $32 = 0, $found_win_1 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $n_0_found_apple_0 = 0, $found_apple_1 = 0, $found_win_2 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $75 = 0, $77 = 0, $78 = 0, $79 = 0, $p_062 = 0, $r_061 = 0, $len_060 = 0, $81 = 0, $82 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $or_cond = 0, $89 = 0, $r_1 = 0, $91 = 0, $92 = 0, $93 = 0, $r_0_lcssa = 0, $95 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $116 = 0, $117 = 0, $119 = 0, $120 = 0, $122 = 0, $result_0 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $error5 = __stackBase__ + 4 | 0;
    $1 = $face + 700 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $_0 = $2;
      label = 33;
      break;
    }
   case 2:
    $4 = $face + 344 | 0;
    $5 = HEAP16[$4 >> 1] | 0;
    $6 = $5 << 16 >> 16 == 0;
    if ($6) {
      $result_0 = 0;
      label = 32;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $face + 360 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = HEAP16[$4 >> 1] | 0;
    $10 = $9 & 65535;
    $found_apple_063 = -1;
    $found_win_064 = -1;
    $n_065 = 0;
    label = 4;
    break;
   case 4:
    $12 = $8 + ($n_065 * 20 & -1) + 6 | 0;
    $13 = HEAP16[$12 >> 1] | 0;
    $14 = $13 << 16 >> 16 == 6;
    if ($14) {
      label = 5;
      break;
    } else {
      $found_win_2 = $found_win_064;
      $found_apple_1 = $found_apple_063;
      label = 13;
      break;
    }
   case 5:
    $16 = $8 + ($n_065 * 20 & -1) + 8 | 0;
    $17 = HEAP16[$16 >> 1] | 0;
    $18 = $17 << 16 >> 16 == 0;
    if ($18) {
      $found_win_2 = $found_win_064;
      $found_apple_1 = $found_apple_063;
      label = 13;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $20 = $8 + ($n_065 * 20 & -1) | 0;
    $21 = HEAP16[$20 >> 1] | 0;
    $22 = $21 << 16 >> 16 == 3;
    if ($22) {
      label = 7;
      break;
    } else {
      $found_win_1 = $found_win_064;
      $32 = $21;
      label = 10;
      break;
    }
   case 7:
    $24 = $8 + ($n_065 * 20 & -1) + 2 | 0;
    $25 = HEAP16[$24 >> 1] | 0;
    $26 = $25 << 16 >> 16 == 1;
    if ($26) {
      label = 8;
      break;
    } else {
      $found_win_1_ph = $found_win_064;
      label = 9;
      break;
    }
   case 8:
    $28 = $8 + ($n_065 * 20 & -1) + 4 | 0;
    $29 = HEAP16[$28 >> 1] | 0;
    $30 = $29 << 16 >> 16 == 1033;
    $n_0_found_win_0 = $30 ? $n_065 : $found_win_064;
    $found_win_1_ph = $n_0_found_win_0;
    label = 9;
    break;
   case 9:
    $_pr = HEAP16[$20 >> 1] | 0;
    $found_win_1 = $found_win_1_ph;
    $32 = $_pr;
    label = 10;
    break;
   case 10:
    $33 = $32 << 16 >> 16 == 1;
    if ($33) {
      label = 11;
      break;
    } else {
      $found_win_2 = $found_win_1;
      $found_apple_1 = $found_apple_063;
      label = 13;
      break;
    }
   case 11:
    $35 = $8 + ($n_065 * 20 & -1) + 2 | 0;
    $36 = HEAP16[$35 >> 1] | 0;
    $37 = $36 << 16 >> 16 == 0;
    if ($37) {
      label = 12;
      break;
    } else {
      $found_win_2 = $found_win_1;
      $found_apple_1 = $found_apple_063;
      label = 13;
      break;
    }
   case 12:
    $39 = $8 + ($n_065 * 20 & -1) + 4 | 0;
    $40 = HEAP16[$39 >> 1] | 0;
    $41 = $40 << 16 >> 16 == 0;
    $n_0_found_apple_0 = $41 ? $n_065 : $found_apple_063;
    $found_win_2 = $found_win_1;
    $found_apple_1 = $n_0_found_apple_0;
    label = 13;
    break;
   case 13:
    $43 = $n_065 + 1 | 0;
    $44 = ($43 | 0) < ($10 | 0);
    if ($44) {
      $found_apple_063 = $found_apple_1;
      $found_win_064 = $found_win_2;
      $n_065 = $43;
      label = 4;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $45 = ($found_win_2 | 0) == -1;
    if ($45) {
      label = 26;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $47 = $face + 100 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $face + 360 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $50 + ($found_win_2 * 20 & -1) + 8 | 0;
    $52 = HEAP16[$51 >> 1] | 0;
    $53 = $52 & 65535;
    $54 = $53 >>> 1;
    HEAP32[$error >> 2] = 0;
    $55 = HEAP16[$51 >> 1] | 0;
    $56 = $55 & 65535;
    $57 = $56 + 1 | 0;
    $58 = _ft_mem_alloc($48, $57, $error) | 0;
    $59 = HEAP32[$error >> 2] | 0;
    $60 = ($59 | 0) == 0;
    if ($60) {
      label = 16;
      break;
    } else {
      $result_0 = $58;
      label = 32;
      break;
    }
   case 16:
    $62 = $face + 364 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = $50 + ($found_win_2 * 20 & -1) + 16 | 0;
    $65 = $50 + ($found_win_2 * 20 & -1) + 12 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = _FT_Stream_Seek($63, $66) | 0;
    HEAP32[$error >> 2] = $67;
    $68 = ($67 | 0) == 0;
    if ($68) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    $70 = HEAP16[$51 >> 1] | 0;
    $71 = $70 & 65535;
    $72 = _FT_Stream_EnterFrame($63, $71) | 0;
    HEAP32[$error >> 2] = $72;
    $73 = ($72 | 0) == 0;
    if ($73) {
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    _ft_mem_free($48, $58);
    HEAP16[$51 >> 1] = 0;
    HEAP32[$65 >> 2] = 0;
    $75 = HEAP32[$64 >> 2] | 0;
    _ft_mem_free($48, $75);
    HEAP32[$64 >> 2] = 0;
    $result_0 = 0;
    label = 32;
    break;
   case 19:
    $77 = ($54 | 0) == 0;
    if ($77) {
      $r_0_lcssa = $58;
      label = 25;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $78 = $63 + 32 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $len_060 = $54;
    $r_061 = $58;
    $p_062 = $79;
    label = 21;
    break;
   case 21:
    $81 = HEAP8[$p_062] | 0;
    $82 = $81 << 24 >> 24 == 0;
    if ($82) {
      label = 22;
      break;
    } else {
      $r_1 = $r_061;
      label = 24;
      break;
    }
   case 22:
    $84 = $p_062 + 1 | 0;
    $85 = HEAP8[$84] | 0;
    $86 = ($85 & 255) > 31;
    $87 = $85 << 24 >> 24 > -1;
    $or_cond = $86 & $87;
    if ($or_cond) {
      label = 23;
      break;
    } else {
      $r_1 = $r_061;
      label = 24;
      break;
    }
   case 23:
    $89 = $r_061 + 1 | 0;
    HEAP8[$r_061] = $85;
    $r_1 = $89;
    label = 24;
    break;
   case 24:
    $91 = $len_060 - 1 | 0;
    $92 = $p_062 + 2 | 0;
    $93 = ($91 | 0) == 0;
    if ($93) {
      $r_0_lcssa = $r_1;
      label = 25;
      break;
    } else {
      $len_060 = $91;
      $r_061 = $r_1;
      $p_062 = $92;
      label = 21;
      break;
    }
   case 25:
    HEAP8[$r_0_lcssa] = 0;
    _FT_Stream_ExitFrame($63);
    $result_0 = $58;
    label = 32;
    break;
   case 26:
    $95 = ($found_apple_1 | 0) == -1;
    if ($95) {
      $result_0 = 0;
      label = 32;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $97 = $face + 100 | 0;
    $98 = HEAP32[$97 >> 2] | 0;
    $99 = $face + 360 | 0;
    $100 = HEAP32[$99 >> 2] | 0;
    $101 = $100 + ($found_apple_1 * 20 & -1) + 8 | 0;
    $102 = HEAP16[$101 >> 1] | 0;
    $103 = $102 & 65535;
    HEAP32[$error5 >> 2] = 0;
    $104 = $103 + 1 | 0;
    $105 = _ft_mem_alloc($98, $104, $error5) | 0;
    $106 = HEAP32[$error5 >> 2] | 0;
    $107 = ($106 | 0) == 0;
    if ($107) {
      label = 28;
      break;
    } else {
      $result_0 = $105;
      label = 32;
      break;
    }
   case 28:
    $109 = $face + 364 | 0;
    $110 = HEAP32[$109 >> 2] | 0;
    $111 = $100 + ($found_apple_1 * 20 & -1) + 12 | 0;
    $112 = HEAP32[$111 >> 2] | 0;
    $113 = _FT_Stream_Seek($110, $112) | 0;
    HEAP32[$error5 >> 2] = $113;
    $114 = ($113 | 0) == 0;
    if ($114) {
      label = 29;
      break;
    } else {
      label = 30;
      break;
    }
   case 29:
    $116 = _FT_Stream_Read($110, $105, $103) | 0;
    HEAP32[$error5 >> 2] = $116;
    $117 = ($116 | 0) == 0;
    if ($117) {
      label = 31;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    HEAP32[$111 >> 2] = 0;
    HEAP16[$101 >> 1] = 0;
    $119 = $100 + ($found_apple_1 * 20 & -1) + 16 | 0;
    $120 = HEAP32[$119 >> 2] | 0;
    _ft_mem_free($98, $120);
    HEAP32[$119 >> 2] = 0;
    _ft_mem_free($98, $105);
    $result_0 = 0;
    label = 32;
    break;
   case 31:
    $122 = $105 + $103 | 0;
    HEAP8[$122] = 0;
    $result_0 = $105;
    label = 32;
    break;
   case 32:
    HEAP32[$1 >> 2] = $result_0;
    $_0 = $result_0;
    label = 33;
    break;
   case 33:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _tt_face_load_any($face, $tag, $offset, $buffer, $length) {
  $face = $face | 0;
  $tag = $tag | 0;
  $offset = $offset | 0;
  $buffer = $buffer | 0;
  $length = $length | 0;
  var $1 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $_016 = 0, $size_0_in = 0, $size_0 = 0, $15 = 0, $17 = 0, $18 = 0, $size_1 = 0, $20 = 0, $21 = 0, $22 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($tag | 0) == 0;
    if ($1) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = _tt_face_lookup_table($face, $tag) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      $_0 = 142;
      label = 9;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $6 = $3 + 8 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 + $offset | 0;
    $9 = $3 + 12 | 0;
    $size_0_in = $9;
    $_016 = $8;
    label = 5;
    break;
   case 4:
    $11 = $face + 104 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + 4 | 0;
    $size_0_in = $13;
    $_016 = $offset;
    label = 5;
    break;
   case 5:
    $size_0 = HEAP32[$size_0_in >> 2] | 0;
    $15 = ($length | 0) == 0;
    if ($15) {
      $size_1 = $size_0;
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $17 = HEAP32[$length >> 2] | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 7;
      break;
    } else {
      $size_1 = $17;
      label = 8;
      break;
    }
   case 7:
    HEAP32[$length >> 2] = $size_0;
    $_0 = 0;
    label = 9;
    break;
   case 8:
    $20 = $face + 104 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = _FT_Stream_ReadAt($21, $_016, $buffer, $size_1) | 0;
    $_0 = $22;
    label = 9;
    break;
   case 9:
    return $_0 | 0;
  }
  return 0;
}
function _get_sfnt_table($face, $tag) {
  $face = $face | 0;
  $tag = $tag | 0;
  var $2 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $phitmp12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $phitmp11 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $phitmp = 0, $table_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    if (($tag | 0) == 0) {
      label = 2;
      break;
    } else if (($tag | 0) == 3) {
      label = 3;
      break;
    } else if (($tag | 0) == 4) {
      label = 4;
      break;
    } else if (($tag | 0) == 2) {
      label = 6;
      break;
    } else if (($tag | 0) == 5) {
      label = 8;
      break;
    } else if (($tag | 0) == 1) {
      label = 9;
      break;
    } else if (($tag | 0) == 6) {
      label = 10;
      break;
    } else {
      $table_0 = 0;
      label = 12;
      break;
    }
   case 2:
    $2 = $face + 160 | 0;
    $3 = $2;
    $table_0 = $3;
    label = 12;
    break;
   case 3:
    $5 = $face + 216 | 0;
    $6 = $5;
    $table_0 = $6;
    label = 12;
    break;
   case 4:
    $8 = $face + 296 | 0;
    $9 = HEAP8[$8] | 0;
    $10 = $9 << 24 >> 24 == 0;
    if ($10) {
      $table_0 = 0;
      label = 12;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $12 = $face + 300 | 0;
    $phitmp12 = $12;
    $table_0 = $phitmp12;
    label = 12;
    break;
   case 6:
    $14 = $face + 368 | 0;
    $15 = $14 | 0;
    $16 = HEAP16[$15 >> 1] | 0;
    $17 = $16 << 16 >> 16 == -1;
    if ($17) {
      $table_0 = 0;
      label = 12;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $phitmp11 = $14;
    $table_0 = $phitmp11;
    label = 12;
    break;
   case 8:
    $20 = $face + 468 | 0;
    $21 = $20;
    $table_0 = $21;
    label = 12;
    break;
   case 9:
    $23 = $face + 260 | 0;
    $24 = $23;
    $table_0 = $24;
    label = 12;
    break;
   case 10:
    $26 = $face + 556 | 0;
    $27 = $26 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = ($28 | 0) == 0;
    if ($29) {
      $table_0 = 0;
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $phitmp = $26;
    $table_0 = $phitmp;
    label = 12;
    break;
   case 12:
    return $table_0 | 0;
  }
  return 0;
}
function _sfnt_table_info($face, $idx, $tag, $offset, $length) {
  $face = $face | 0;
  $idx = $idx | 0;
  $tag = $tag | 0;
  $offset = $offset | 0;
  $length = $length | 0;
  var $1 = 0, $2 = 0, $or_cond = 0, $3 = 0, $or_cond15 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($tag | 0) == 0;
    $2 = ($offset | 0) == 0;
    $or_cond = $1 | $2;
    $3 = ($length | 0) == 0;
    $or_cond15 = $or_cond | $3;
    if ($or_cond15) {
      $_0 = 6;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $face + 152 | 0;
    $6 = HEAP16[$5 >> 1] | 0;
    $7 = $6 & 65535;
    $8 = $7 >>> 0 > $idx >>> 0;
    if ($8) {
      label = 3;
      break;
    } else {
      $_0 = 142;
      label = 4;
      break;
    }
   case 3:
    $10 = $face + 156 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 + ($idx << 4) | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    HEAP32[$tag >> 2] = $13;
    $14 = HEAP32[$10 >> 2] | 0;
    $15 = $14 + ($idx << 4) + 8 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    HEAP32[$offset >> 2] = $16;
    $17 = HEAP32[$10 >> 2] | 0;
    $18 = $17 + ($idx << 4) + 12 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    HEAP32[$length >> 2] = $19;
    $_0 = 0;
    label = 4;
    break;
   case 4:
    return $_0 | 0;
  }
  return 0;
}
function _sfnt_init_face($stream, $face, $face_index, $num_params, $params) {
  $stream = $stream | 0;
  $face = $face | 0;
  $face_index = $face_index | 0;
  $num_params = $num_params | 0;
  $params = $params | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $_c = 0, $sfnt_0_in = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $_face_index = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 532 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $sfnt_0_in = $2;
      label = 4;
      break;
    }
   case 2:
    $5 = $face + 96 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + 4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = _FT_Get_Module_Interface($8, 5324776) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      $_0 = 3;
      label = 9;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    HEAP32[$1 >> 2] = $9;
    $12 = $9;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $face + 508 | 0;
    $_c = $13;
    HEAP32[$14 >> 2] = $_c;
    $sfnt_0_in = $9;
    label = 4;
    break;
   case 4:
    $16 = $face + 96 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $17 | 0;
    $19 = _ft_module_get_service($18, 5319724) | 0;
    $20 = $face + 536 | 0;
    HEAP32[$20 >> 2] = $19;
    $21 = _sfnt_open_font($stream, $face) | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 5;
      break;
    } else {
      $_0 = $21;
      label = 9;
      break;
    }
   case 5:
    $24 = ($face_index | 0) < 0;
    $_face_index = $24 ? 0 : $face_index;
    $25 = $face + 140 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = ($_face_index | 0) < ($26 | 0);
    if ($27) {
      label = 6;
      break;
    } else {
      $_0 = 6;
      label = 9;
      break;
    }
   case 6:
    $29 = $face + 144 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $30 + ($_face_index << 2) | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = _FT_Stream_Seek($stream, $32) | 0;
    $34 = ($33 | 0) == 0;
    if ($34) {
      label = 7;
      break;
    } else {
      $_0 = $33;
      label = 9;
      break;
    }
   case 7:
    $36 = $sfnt_0_in + 132 | 0;
    $37 = $36;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = FUNCTION_TABLE_iii[$38 & 1023]($face, $stream) | 0;
    $40 = ($39 | 0) == 0;
    if ($40) {
      label = 8;
      break;
    } else {
      $_0 = $39;
      label = 9;
      break;
    }
   case 8:
    $42 = HEAP32[$25 >> 2] | 0;
    $43 = $face | 0;
    HEAP32[$43 >> 2] = $42;
    $44 = $face + 4 | 0;
    HEAP32[$44 >> 2] = $_face_index;
    $_0 = 0;
    label = 9;
    break;
   case 9:
    return $_0 | 0;
  }
  return 0;
}
function _sfnt_load_face($stream, $face, $face_index, $num_params, $params) {
  $stream = $stream | 0;
  $face = $face | 0;
  $face_index = $face_index | 0;
  $num_params = $num_params | 0;
  $params = $params | 0;
  var $error = 0, $metrics = 0, $1 = 0, $2 = 0, $3 = 0, $ignore_preferred_family_0225 = 0, $ignore_preferred_subfamily_0224 = 0, $i_0223 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $_ignore_preferred_subfamily_0 = 0, $ignore_preferred_subfamily_1 = 0, $ignore_preferred_family_1 = 0, $10 = 0, $exitcond = 0, $ignore_preferred_family_0_lcssa = 0, $ignore_preferred_subfamily_0_lcssa = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $is_apple_sbit_0205 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $83 = 0, $85 = 0, $86 = 0, $87 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $101 = 0, $_pr = 0, $103 = 0, $104 = 0, $has_outline_0208 = 0, $105 = 0, $106 = 0, $107 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $115 = 0, $_pr212 = 0, $117 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $125 = 0, $has_outline_1 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $132 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $140 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $165 = 0, $167 = 0, $168 = 0, $170 = 0, $171 = 0, $173 = 0, $174 = 0, $176 = 0, $178 = 0, $179 = 0, $181 = 0, $182 = 0, $184 = 0, $185 = 0, $187 = 0, $188 = 0, $190 = 0, $191 = 0, $192 = 0, $or_cond = 0, $194 = 0, $195 = 0, $_pr214 = 0, $197 = 0, $198 = 0, $200 = 0, $201 = 0, $203 = 0, $204 = 0, $206 = 0, $207 = 0, $208 = 0, $or_cond197 = 0, $210 = 0, $211 = 0, $_pr216 = 0, $213 = 0, $214 = 0, $216 = 0, $217 = 0, $219 = 0, $220 = 0, $221 = 0, $222 = 0, $flags_0 = 0, $223 = 0, $224 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $_ = 0, $flags_1 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $flags_2 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $flags_2_ = 0, $239 = 0, $240 = 0, $241 = 0, $242 = 0, $flags_4 = 0, $243 = 0, $244 = 0, $246 = 0, $247 = 0, $249 = 0, $250 = 0, $251 = 0, $flags_4_ = 0, $flags_5 = 0, $254 = 0, $255 = 0, $257 = 0, $258 = 0, $259 = 0, $260 = 0, $261 = 0, $262 = 0, $_217 = 0, $263 = 0, $264 = 0, $266 = 0, $268 = 0, $269 = 0, $270 = 0, $271 = 0, $_199 = 0, $272 = 0, $273 = 0, $275 = 0, $flags_8 = 0, $277 = 0, $278 = 0, $279 = 0, $280 = 0, $281 = 0, $m_0219 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $308 = 0, $309 = 0, $310 = 0, $311 = 0, $em_size_0 = 0, $avgwidth_0 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $i1_0218 = 0, $329 = 0, $330 = 0, $331 = 0, $332 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $360 = 0, $361 = 0, $363 = 0, $364 = 0, $365 = 0, $367 = 0, $369 = 0, $370 = 0, $371 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $_in = 0, $409 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 32 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $metrics = __stackBase__ + 4 | 0;
    $1 = $face + 532 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($num_params | 0) > 0;
    if ($3) {
      $i_0223 = 0;
      $ignore_preferred_subfamily_0224 = 0;
      $ignore_preferred_family_0225 = 0;
      label = 2;
      break;
    } else {
      $ignore_preferred_subfamily_0_lcssa = 0;
      $ignore_preferred_family_0_lcssa = 0;
      label = 5;
      break;
    }
   case 2:
    $4 = $params + ($i_0223 << 3) | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($5 | 0) == 1768386662;
    if ($6) {
      $ignore_preferred_family_1 = 1;
      $ignore_preferred_subfamily_1 = $ignore_preferred_subfamily_0224;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $8 = ($5 | 0) == 1768386675;
    $_ignore_preferred_subfamily_0 = $8 ? 1 : $ignore_preferred_subfamily_0224;
    $ignore_preferred_family_1 = $ignore_preferred_family_0225;
    $ignore_preferred_subfamily_1 = $_ignore_preferred_subfamily_0;
    label = 4;
    break;
   case 4:
    $10 = $i_0223 + 1 | 0;
    $exitcond = ($10 | 0) == ($num_params | 0);
    if ($exitcond) {
      $ignore_preferred_subfamily_0_lcssa = $ignore_preferred_subfamily_1;
      $ignore_preferred_family_0_lcssa = $ignore_preferred_family_1;
      label = 5;
      break;
    } else {
      $i_0223 = $10;
      $ignore_preferred_subfamily_0224 = $ignore_preferred_subfamily_1;
      $ignore_preferred_family_0225 = $ignore_preferred_family_1;
      label = 2;
      break;
    }
   case 5:
    $11 = $face + 128 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + 52 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 6;
      break;
    } else {
      $31 = 1;
      label = 10;
      break;
    }
   case 6:
    $17 = _tt_face_lookup_table($face, 1735162214) | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 7;
      break;
    } else {
      $31 = 1;
      label = 10;
      break;
    }
   case 7:
    $20 = _tt_face_lookup_table($face, 1128678944) | 0;
    $21 = ($20 | 0) != 0;
    $22 = $21 & 1;
    if ($21) {
      $31 = $22;
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $24 = $2 + 84 | 0;
    $25 = $24;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = ($26 | 0) == 0;
    if ($27) {
      $31 = $22;
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $29 = FUNCTION_TABLE_iii[$26 & 1023]($face, $stream) | 0;
    HEAP32[$error >> 2] = $29;
    $30 = ($29 | 0) == 0;
    if ($30) {
      $38 = $22;
      $is_apple_sbit_0205 = 1;
      label = 11;
      break;
    } else {
      $31 = $22;
      label = 10;
      break;
    }
   case 10:
    $32 = $2 + 32 | 0;
    $33 = $32;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = FUNCTION_TABLE_iii[$34 & 1023]($face, $stream) | 0;
    HEAP32[$error >> 2] = $35;
    $36 = ($35 | 0) == 0;
    if ($36) {
      $38 = $31;
      $is_apple_sbit_0205 = 0;
      label = 11;
      break;
    } else {
      label = 87;
      break;
    }
   case 11:
    $39 = $face + 178 | 0;
    $40 = HEAP16[$39 >> 1] | 0;
    $41 = $40 << 16 >> 16 == 0;
    if ($41) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    HEAP32[$error >> 2] = 8;
    label = 87;
    break;
   case 13:
    $44 = $2 + 44 | 0;
    $45 = $44;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = FUNCTION_TABLE_iii[$46 & 1023]($face, $stream) | 0;
    HEAP32[$error >> 2] = $47;
    $48 = $2 + 40 | 0;
    $49 = $48;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = FUNCTION_TABLE_iii[$50 & 1023]($face, $stream) | 0;
    HEAP32[$error >> 2] = $51;
    $52 = $2 + 56 | 0;
    $53 = $52;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = FUNCTION_TABLE_iii[$54 & 1023]($face, $stream) | 0;
    HEAP32[$error >> 2] = $55;
    $56 = $2 + 52 | 0;
    $57 = $56;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = FUNCTION_TABLE_iii[$58 & 1023]($face, $stream) | 0;
    HEAP32[$error >> 2] = $59;
    if ($is_apple_sbit_0205) {
      $has_outline_1 = $38;
      label = 32;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $61 = $2 + 36 | 0;
    $62 = $61;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = FUNCTION_TABLE_iiii[$63 & 1023]($face, $stream, 0) | 0;
    HEAP32[$error >> 2] = $64;
    if (($64 | 0) == 0) {
      label = 15;
      break;
    } else if (($64 | 0) == 142) {
      label = 19;
      break;
    } else {
      $103 = $64;
      label = 25;
      break;
    }
   case 15:
    $66 = $2 + 136 | 0;
    $67 = $66;
    $68 = HEAP32[$67 >> 2] | 0;
    $69 = FUNCTION_TABLE_iiii[$68 & 1023]($face, $stream, 0) | 0;
    HEAP32[$error >> 2] = $69;
    $70 = ($69 | 0) == 142;
    if ($70) {
      label = 16;
      break;
    } else {
      $103 = $69;
      label = 25;
      break;
    }
   case 16:
    HEAP32[$error >> 2] = 147;
    $72 = HEAP32[$11 >> 2] | 0;
    $73 = $72 + 52 | 0;
    $74 = HEAP32[$73 >> 2] | 0;
    $75 = ($74 | 0) == 0;
    if ($75) {
      label = 87;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $77 = $74 | 0;
    $78 = HEAP32[$77 >> 2] | 0;
    $79 = $78 + 8 | 0;
    $80 = HEAP32[$79 >> 2] | 0;
    $81 = ($80 | 0) == 0;
    if ($81) {
      label = 24;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $83 = $face + 250 | 0;
    HEAP16[$83 >> 1] = 0;
    HEAP32[$error >> 2] = 0;
    $has_outline_0208 = $38;
    label = 26;
    break;
   case 19:
    $85 = $face + 148 | 0;
    $86 = HEAP32[$85 >> 2] | 0;
    $87 = ($86 | 0) == 1953658213;
    if ($87) {
      label = 20;
      break;
    } else {
      label = 21;
      break;
    }
   case 20:
    HEAP32[$error >> 2] = 0;
    $has_outline_0208 = 0;
    label = 26;
    break;
   case 21:
    HEAP32[$error >> 2] = 143;
    $90 = HEAP32[$11 >> 2] | 0;
    $91 = $90 + 52 | 0;
    $92 = HEAP32[$91 >> 2] | 0;
    $93 = ($92 | 0) == 0;
    if ($93) {
      label = 87;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $95 = $92 | 0;
    $96 = HEAP32[$95 >> 2] | 0;
    $97 = $96 + 8 | 0;
    $98 = HEAP32[$97 >> 2] | 0;
    $99 = ($98 | 0) == 0;
    if ($99) {
      label = 24;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $101 = $face + 250 | 0;
    HEAP16[$101 >> 1] = 0;
    HEAP32[$error >> 2] = 0;
    $has_outline_0208 = $38;
    label = 26;
    break;
   case 24:
    $_pr = HEAP32[$error >> 2] | 0;
    $103 = $_pr;
    label = 25;
    break;
   case 25:
    $104 = ($103 | 0) == 0;
    if ($104) {
      $has_outline_0208 = $38;
      label = 26;
      break;
    } else {
      label = 87;
      break;
    }
   case 26:
    $105 = HEAP32[$62 >> 2] | 0;
    $106 = FUNCTION_TABLE_iiii[$105 & 1023]($face, $stream, 1) | 0;
    HEAP32[$error >> 2] = $106;
    $107 = ($106 | 0) == 0;
    if ($107) {
      label = 27;
      break;
    } else {
      $117 = $106;
      label = 29;
      break;
    }
   case 27:
    $109 = $2 + 136 | 0;
    $110 = $109;
    $111 = HEAP32[$110 >> 2] | 0;
    $112 = FUNCTION_TABLE_iiii[$111 & 1023]($face, $stream, 1) | 0;
    HEAP32[$error >> 2] = $112;
    $113 = ($112 | 0) == 0;
    if ($113) {
      label = 28;
      break;
    } else {
      $117 = $112;
      label = 29;
      break;
    }
   case 28:
    $115 = $face + 296 | 0;
    HEAP8[$115] = 1;
    $_pr212 = HEAP32[$error >> 2] | 0;
    $117 = $_pr212;
    label = 29;
    break;
   case 29:
    if (($117 | 0) == 142 | ($117 | 0) == 0) {
      label = 30;
      break;
    } else {
      label = 87;
      break;
    }
   case 30:
    $119 = $2 + 48 | 0;
    $120 = $119;
    $121 = HEAP32[$120 >> 2] | 0;
    $122 = FUNCTION_TABLE_iii[$121 & 1023]($face, $stream) | 0;
    HEAP32[$error >> 2] = $122;
    $123 = ($122 | 0) == 0;
    if ($123) {
      $has_outline_1 = $has_outline_0208;
      label = 32;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    $125 = $face + 368 | 0;
    HEAP16[$125 >> 1] = -1;
    $has_outline_1 = $has_outline_0208;
    label = 32;
    break;
   case 32:
    $127 = $2 + 140 | 0;
    $128 = $127;
    $129 = HEAP32[$128 >> 2] | 0;
    $130 = ($129 | 0) == 0;
    if ($130) {
      label = 35;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    $132 = FUNCTION_TABLE_iii[$129 & 1023]($face, $stream) | 0;
    HEAP32[$error >> 2] = $132;
    if (($132 | 0) == 142) {
      label = 34;
      break;
    } else if (($132 | 0) == 0) {
      label = 35;
      break;
    } else {
      label = 87;
      break;
    }
   case 34:
    HEAP32[$error >> 2] = 0;
    label = 35;
    break;
   case 35:
    $135 = $2 + 80 | 0;
    $136 = $135;
    $137 = HEAP32[$136 >> 2] | 0;
    $138 = FUNCTION_TABLE_iii[$137 & 1023]($face, $stream) | 0;
    HEAP32[$error >> 2] = $138;
    if (($138 | 0) == 142) {
      label = 36;
      break;
    } else if (($138 | 0) == 0) {
      label = 37;
      break;
    } else {
      label = 87;
      break;
    }
   case 36:
    $140 = $face + 556 | 0;
    HEAP32[$140 >> 2] = 0;
    label = 37;
    break;
   case 37:
    $142 = $2 + 76 | 0;
    $143 = $142;
    $144 = HEAP32[$143 >> 2] | 0;
    $145 = FUNCTION_TABLE_iii[$144 & 1023]($face, $stream) | 0;
    HEAP32[$error >> 2] = $145;
    $146 = $2 + 72 | 0;
    $147 = $146;
    $148 = HEAP32[$147 >> 2] | 0;
    $149 = FUNCTION_TABLE_iii[$148 & 1023]($face, $stream) | 0;
    HEAP32[$error >> 2] = $149;
    $150 = $face + 264 | 0;
    $151 = HEAP16[$150 >> 1] | 0;
    $152 = $151 & 65535;
    $153 = $face + 16 | 0;
    HEAP32[$153 >> 2] = $152;
    $154 = $face + 20 | 0;
    HEAP32[$154 >> 2] = 0;
    $155 = $face + 24 | 0;
    HEAP32[$155 >> 2] = 0;
    $156 = $face + 368 | 0;
    $157 = HEAP16[$156 >> 1] | 0;
    $158 = $157 << 16 >> 16 == -1;
    if ($158) {
      label = 47;
      break;
    } else {
      label = 38;
      break;
    }
   case 38:
    $160 = $face + 432 | 0;
    $161 = HEAP16[$160 >> 1] | 0;
    $162 = $161 & 256;
    $163 = $162 << 16 >> 16 == 0;
    if ($163) {
      label = 47;
      break;
    } else {
      label = 39;
      break;
    }
   case 39:
    $165 = $ignore_preferred_family_0_lcssa << 24 >> 24 == 0;
    if ($165) {
      label = 40;
      break;
    } else {
      label = 41;
      break;
    }
   case 40:
    $167 = _tt_face_get_name($face, 16, $154) | 0;
    HEAP32[$error >> 2] = $167;
    $168 = ($167 | 0) == 0;
    if ($168) {
      label = 41;
      break;
    } else {
      label = 87;
      break;
    }
   case 41:
    $170 = HEAP32[$154 >> 2] | 0;
    $171 = ($170 | 0) == 0;
    if ($171) {
      label = 42;
      break;
    } else {
      label = 43;
      break;
    }
   case 42:
    $173 = _tt_face_get_name($face, 1, $154) | 0;
    HEAP32[$error >> 2] = $173;
    $174 = ($173 | 0) == 0;
    if ($174) {
      label = 43;
      break;
    } else {
      label = 87;
      break;
    }
   case 43:
    $176 = $ignore_preferred_subfamily_0_lcssa << 24 >> 24 == 0;
    if ($176) {
      label = 44;
      break;
    } else {
      label = 45;
      break;
    }
   case 44:
    $178 = _tt_face_get_name($face, 17, $155) | 0;
    HEAP32[$error >> 2] = $178;
    $179 = ($178 | 0) == 0;
    if ($179) {
      label = 45;
      break;
    } else {
      label = 87;
      break;
    }
   case 45:
    $181 = HEAP32[$155 >> 2] | 0;
    $182 = ($181 | 0) == 0;
    if ($182) {
      label = 46;
      break;
    } else {
      label = 59;
      break;
    }
   case 46:
    $184 = _tt_face_get_name($face, 2, $155) | 0;
    HEAP32[$error >> 2] = $184;
    $185 = ($184 | 0) == 0;
    if ($185) {
      label = 59;
      break;
    } else {
      label = 87;
      break;
    }
   case 47:
    $187 = _tt_face_get_name($face, 21, $154) | 0;
    HEAP32[$error >> 2] = $187;
    $188 = ($187 | 0) == 0;
    if ($188) {
      label = 48;
      break;
    } else {
      label = 87;
      break;
    }
   case 48:
    $190 = HEAP32[$154 >> 2] | 0;
    $191 = ($190 | 0) == 0;
    $192 = $ignore_preferred_family_0_lcssa << 24 >> 24 == 0;
    $or_cond = $191 & $192;
    if ($or_cond) {
      label = 49;
      break;
    } else {
      $197 = $190;
      label = 51;
      break;
    }
   case 49:
    $194 = _tt_face_get_name($face, 16, $154) | 0;
    HEAP32[$error >> 2] = $194;
    $195 = ($194 | 0) == 0;
    if ($195) {
      label = 50;
      break;
    } else {
      label = 87;
      break;
    }
   case 50:
    $_pr214 = HEAP32[$154 >> 2] | 0;
    $197 = $_pr214;
    label = 51;
    break;
   case 51:
    $198 = ($197 | 0) == 0;
    if ($198) {
      label = 52;
      break;
    } else {
      label = 53;
      break;
    }
   case 52:
    $200 = _tt_face_get_name($face, 1, $154) | 0;
    HEAP32[$error >> 2] = $200;
    $201 = ($200 | 0) == 0;
    if ($201) {
      label = 53;
      break;
    } else {
      label = 87;
      break;
    }
   case 53:
    $203 = _tt_face_get_name($face, 22, $155) | 0;
    HEAP32[$error >> 2] = $203;
    $204 = ($203 | 0) == 0;
    if ($204) {
      label = 54;
      break;
    } else {
      label = 87;
      break;
    }
   case 54:
    $206 = HEAP32[$155 >> 2] | 0;
    $207 = ($206 | 0) == 0;
    $208 = $ignore_preferred_subfamily_0_lcssa << 24 >> 24 == 0;
    $or_cond197 = $207 & $208;
    if ($or_cond197) {
      label = 55;
      break;
    } else {
      $213 = $206;
      label = 57;
      break;
    }
   case 55:
    $210 = _tt_face_get_name($face, 17, $155) | 0;
    HEAP32[$error >> 2] = $210;
    $211 = ($210 | 0) == 0;
    if ($211) {
      label = 56;
      break;
    } else {
      label = 87;
      break;
    }
   case 56:
    $_pr216 = HEAP32[$155 >> 2] | 0;
    $213 = $_pr216;
    label = 57;
    break;
   case 57:
    $214 = ($213 | 0) == 0;
    if ($214) {
      label = 58;
      break;
    } else {
      label = 59;
      break;
    }
   case 58:
    $216 = _tt_face_get_name($face, 2, $155) | 0;
    HEAP32[$error >> 2] = $216;
    $217 = ($216 | 0) == 0;
    if ($217) {
      label = 59;
      break;
    } else {
      label = 87;
      break;
    }
   case 59:
    $219 = $face + 8 | 0;
    $220 = HEAP32[$219 >> 2] | 0;
    $221 = $has_outline_1 << 24 >> 24 == 1;
    $222 = $221 & 1;
    $flags_0 = $220 | $222;
    $223 = $flags_0 | 24;
    $224 = ($59 | 0) == 0;
    if ($224) {
      label = 60;
      break;
    } else {
      $flags_1 = $223;
      label = 61;
      break;
    }
   case 60:
    $226 = $face + 468 | 0;
    $227 = HEAP32[$226 >> 2] | 0;
    $228 = ($227 | 0) == 196608;
    $229 = $flags_0 | 536;
    $_ = $228 ? $223 : $229;
    $flags_1 = $_;
    label = 61;
    break;
   case 61:
    $231 = $face + 480 | 0;
    $232 = HEAP32[$231 >> 2] | 0;
    $233 = ($232 | 0) == 0;
    $234 = $flags_1 | 4;
    $flags_2 = $233 ? $flags_1 : $234;
    $235 = $face + 296 | 0;
    $236 = HEAP8[$235] | 0;
    $237 = $236 << 24 >> 24 == 0;
    $238 = $flags_2 | 32;
    $flags_2_ = $237 ? $flags_2 : $238;
    $239 = $face + 784 | 0;
    $240 = HEAP32[$239 >> 2] | 0;
    $241 = ($240 | 0) == 0;
    $242 = $flags_2_ | 64;
    $flags_4 = $241 ? $flags_2_ : $242;
    $243 = _tt_face_lookup_table($face, 1735162214) | 0;
    $244 = ($243 | 0) == 0;
    if ($244) {
      $flags_5 = $flags_4;
      label = 64;
      break;
    } else {
      label = 62;
      break;
    }
   case 62:
    $246 = _tt_face_lookup_table($face, 1719034226) | 0;
    $247 = ($246 | 0) == 0;
    if ($247) {
      $flags_5 = $flags_4;
      label = 64;
      break;
    } else {
      label = 63;
      break;
    }
   case 63:
    $249 = _tt_face_lookup_table($face, 1735811442) | 0;
    $250 = ($249 | 0) == 0;
    $251 = $flags_4 | 256;
    $flags_4_ = $250 ? $flags_4 : $251;
    $flags_5 = $flags_4_;
    label = 64;
    break;
   case 64:
    HEAP32[$219 >> 2] = $flags_5;
    if ($221) {
      label = 65;
      break;
    } else {
      label = 68;
      break;
    }
   case 65:
    $254 = HEAP16[$156 >> 1] | 0;
    $255 = $254 << 16 >> 16 == -1;
    if ($255) {
      label = 68;
      break;
    } else {
      label = 66;
      break;
    }
   case 66:
    $257 = $face + 432 | 0;
    $258 = HEAP16[$257 >> 1] | 0;
    $259 = $258 & 65535;
    $260 = $259 & 512;
    $261 = ($260 | 0) == 0;
    $262 = $259 & 1;
    $_217 = $261 ? $262 : 1;
    $263 = $258 & 32;
    $264 = $263 << 16 >> 16 == 0;
    if ($264) {
      $flags_8 = $_217;
      label = 70;
      break;
    } else {
      label = 67;
      break;
    }
   case 67:
    $266 = $_217 | 2;
    $flags_8 = $266;
    label = 70;
    break;
   case 68:
    $268 = $face + 204 | 0;
    $269 = HEAP16[$268 >> 1] | 0;
    $270 = $269 & 1;
    $271 = $270 << 16 >> 16 == 0;
    $_199 = $271 ? 0 : 2;
    $272 = $269 & 2;
    $273 = $272 << 16 >> 16 == 0;
    if ($273) {
      $flags_8 = $_199;
      label = 70;
      break;
    } else {
      label = 69;
      break;
    }
   case 69:
    $275 = $_199 | 1;
    $flags_8 = $275;
    label = 70;
    break;
   case 70:
    $277 = $face + 12 | 0;
    HEAP32[$277 >> 2] = $flags_8;
    _tt_face_build_cmaps($face);
    $278 = $face + 36 | 0;
    $279 = HEAP32[$278 >> 2] | 0;
    $280 = ($279 | 0) > 0;
    if ($280) {
      label = 71;
      break;
    } else {
      label = 73;
      break;
    }
   case 71:
    $281 = $face + 40 | 0;
    $m_0219 = 0;
    label = 72;
    break;
   case 72:
    $283 = HEAP32[$281 >> 2] | 0;
    $284 = $283 + ($m_0219 << 2) | 0;
    $285 = HEAP32[$284 >> 2] | 0;
    $286 = $285 + 8 | 0;
    $287 = HEAP16[$286 >> 1] | 0;
    $288 = $287 & 65535;
    $289 = $285 + 10 | 0;
    $290 = HEAP16[$289 >> 1] | 0;
    $291 = $290 & 65535;
    $292 = _sfnt_find_encoding($288, $291) | 0;
    $293 = $285 + 4 | 0;
    HEAP32[$293 >> 2] = $292;
    $294 = $m_0219 + 1 | 0;
    $295 = HEAP32[$278 >> 2] | 0;
    $296 = ($294 | 0) < ($295 | 0);
    if ($296) {
      $m_0219 = $294;
      label = 72;
      break;
    } else {
      label = 73;
      break;
    }
   case 73:
    $297 = $face + 612 | 0;
    $298 = HEAP32[$297 >> 2] | 0;
    $299 = ($298 | 0) == 0;
    if ($299) {
      label = 83;
      break;
    } else {
      label = 74;
      break;
    }
   case 74:
    $301 = $face + 104 | 0;
    $302 = HEAP32[$301 >> 2] | 0;
    $303 = $302 + 28 | 0;
    $304 = HEAP32[$303 >> 2] | 0;
    $305 = HEAP16[$39 >> 1] | 0;
    $306 = $305 << 16 >> 16 == 0;
    if ($306) {
      label = 76;
      break;
    } else {
      label = 75;
      break;
    }
   case 75:
    $308 = $face + 370 | 0;
    $309 = HEAP16[$308 >> 1] | 0;
    $310 = HEAP16[$156 >> 1] | 0;
    $311 = $310 << 16 >> 16 == -1;
    if ($311) {
      label = 76;
      break;
    } else {
      $avgwidth_0 = $309;
      $em_size_0 = $305;
      label = 77;
      break;
    }
   case 76:
    $avgwidth_0 = 0;
    $em_size_0 = 1;
    label = 77;
    break;
   case 77:
    $314 = _ft_mem_realloc($304, 16, 0, $298, 0, $error) | 0;
    $315 = $314;
    $316 = $face + 32 | 0;
    HEAP32[$316 >> 2] = $315;
    $317 = HEAP32[$error >> 2] | 0;
    $318 = ($317 | 0) == 0;
    if ($318) {
      label = 78;
      break;
    } else {
      label = 87;
      break;
    }
   case 78:
    $319 = ($298 | 0) == 0;
    if ($319) {
      label = 82;
      break;
    } else {
      label = 79;
      break;
    }
   case 79:
    $320 = $2 + 152 | 0;
    $321 = $320;
    $322 = $metrics + 20 | 0;
    $323 = $avgwidth_0 << 16 >> 16;
    $324 = $metrics | 0;
    $325 = $em_size_0 & 65535;
    $326 = $325 >>> 1;
    $327 = $metrics + 2 | 0;
    $i1_0218 = 0;
    label = 80;
    break;
   case 80:
    $329 = HEAP32[$316 >> 2] | 0;
    $330 = HEAP32[$321 >> 2] | 0;
    $331 = FUNCTION_TABLE_iiii[$330 & 1023]($face, $i1_0218, $metrics) | 0;
    HEAP32[$error >> 2] = $331;
    $332 = ($331 | 0) == 0;
    if ($332) {
      label = 81;
      break;
    } else {
      label = 87;
      break;
    }
   case 81:
    $334 = HEAP32[$322 >> 2] | 0;
    $335 = $334 >>> 6;
    $336 = $335 & 65535;
    $337 = $329 + ($i1_0218 << 4) | 0;
    HEAP16[$337 >> 1] = $336;
    $338 = HEAP16[$324 >> 1] | 0;
    $339 = $338 & 65535;
    $340 = Math_imul($339, $323);
    $341 = $340 + $326 | 0;
    $342 = ($341 | 0) / ($325 | 0) & -1;
    $343 = $342 & 65535;
    $344 = $329 + ($i1_0218 << 4) + 2 | 0;
    HEAP16[$344 >> 1] = $343;
    $345 = HEAP16[$324 >> 1] | 0;
    $346 = $345 & 65535;
    $347 = $346 << 6;
    $348 = $329 + ($i1_0218 << 4) + 8 | 0;
    HEAP32[$348 >> 2] = $347;
    $349 = HEAP16[$327 >> 1] | 0;
    $350 = $349 & 65535;
    $351 = $350 << 6;
    $352 = $329 + ($i1_0218 << 4) + 12 | 0;
    HEAP32[$352 >> 2] = $351;
    $353 = HEAP16[$327 >> 1] | 0;
    $354 = $353 & 65535;
    $355 = $354 << 6;
    $356 = $329 + ($i1_0218 << 4) + 4 | 0;
    HEAP32[$356 >> 2] = $355;
    $357 = $i1_0218 + 1 | 0;
    $358 = $357 >>> 0 < $298 >>> 0;
    if ($358) {
      $i1_0218 = $357;
      label = 80;
      break;
    } else {
      label = 82;
      break;
    }
   case 82:
    $359 = HEAP32[$219 >> 2] | 0;
    $360 = $359 | 2;
    HEAP32[$219 >> 2] = $360;
    $361 = $face + 28 | 0;
    HEAP32[$361 >> 2] = $298;
    label = 83;
    break;
   case 83:
    $363 = HEAP32[$219 >> 2] | 0;
    $364 = $363 & 3;
    $365 = ($364 | 0) == 0;
    if ($365) {
      label = 84;
      break;
    } else {
      label = 85;
      break;
    }
   case 84:
    $367 = $363 | 1;
    HEAP32[$219 >> 2] = $367;
    label = 85;
    break;
   case 85:
    $369 = HEAP32[$219 >> 2] | 0;
    $370 = $369 & 1;
    $371 = ($370 | 0) == 0;
    if ($371) {
      label = 87;
      break;
    } else {
      label = 86;
      break;
    }
   case 86:
    $373 = $face + 196 | 0;
    $374 = HEAP16[$373 >> 1] | 0;
    $375 = $374 << 16 >> 16;
    $376 = $face + 52 | 0;
    HEAP32[$376 >> 2] = $375;
    $377 = $face + 198 | 0;
    $378 = HEAP16[$377 >> 1] | 0;
    $379 = $378 << 16 >> 16;
    $380 = $face + 56 | 0;
    HEAP32[$380 >> 2] = $379;
    $381 = $face + 200 | 0;
    $382 = HEAP16[$381 >> 1] | 0;
    $383 = $382 << 16 >> 16;
    $384 = $face + 60 | 0;
    HEAP32[$384 >> 2] = $383;
    $385 = $face + 202 | 0;
    $386 = HEAP16[$385 >> 1] | 0;
    $387 = $386 << 16 >> 16;
    $388 = $face + 64 | 0;
    HEAP32[$388 >> 2] = $387;
    $389 = HEAP16[$39 >> 1] | 0;
    $390 = $face + 68 | 0;
    HEAP16[$390 >> 1] = $389;
    $391 = $face + 220 | 0;
    $392 = HEAP16[$391 >> 1] | 0;
    $393 = $face + 70 | 0;
    HEAP16[$393 >> 1] = $392;
    $394 = $face + 222 | 0;
    $395 = HEAP16[$394 >> 1] | 0;
    $396 = $face + 72 | 0;
    HEAP16[$396 >> 1] = $395;
    $397 = HEAP16[$393 >> 1] | 0;
    $398 = $397 - $395 & 65535;
    $399 = $face + 224 | 0;
    $400 = HEAP16[$399 >> 1] | 0;
    $401 = $398 + $400 & 65535;
    $402 = $face + 74 | 0;
    HEAP16[$402 >> 1] = $401;
    $403 = $face + 226 | 0;
    $404 = HEAP16[$403 >> 1] | 0;
    $405 = $face + 76 | 0;
    HEAP16[$405 >> 1] = $404;
    $406 = HEAP8[$235] | 0;
    $407 = $406 << 24 >> 24 == 0;
    $408 = $face + 310 | 0;
    $_in = $407 ? $402 : $408;
    $409 = HEAP16[$_in >> 1] | 0;
    $410 = $face + 78 | 0;
    HEAP16[$410 >> 1] = $409;
    $411 = $face + 476 | 0;
    $412 = HEAP16[$411 >> 1] | 0;
    $413 = $412 & 65535;
    $414 = $face + 478 | 0;
    $415 = HEAP16[$414 >> 1] | 0;
    $416 = $415 << 16 >> 16;
    $417 = ($416 | 0) / 2 & -1;
    $418 = $413 - $417 | 0;
    $419 = $418 & 65535;
    $420 = $face + 80 | 0;
    HEAP16[$420 >> 1] = $419;
    $421 = HEAP16[$414 >> 1] | 0;
    $422 = $face + 82 | 0;
    HEAP16[$422 >> 1] = $421;
    label = 87;
    break;
   case 87:
    $423 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $423 | 0;
  }
  return 0;
}
function _tt_face_load_sfnt_header_stub($face, $stream, $face_index, $header) {
  $face = $face | 0;
  $stream = $stream | 0;
  $face_index = $face_index | 0;
  $header = $header | 0;
  return 7;
}
function _tt_face_load_directory_stub($face, $stream, $header) {
  $face = $face | 0;
  $stream = $stream | 0;
  $header = $header | 0;
  return 7;
}
function _tt_face_load_hdmx_stub($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  return 7;
}
function _tt_face_free_hdmx_stub($face) {
  $face = $face | 0;
  return;
}
function _tt_face_load_sbit_stub($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  return 7;
}
function _sfnt_done_face($face) {
  $face = $face | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($face | 0) == 0;
    if ($1) {
      label = 12;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 100 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $face + 532 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) != 0;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 7;
      break;
    }
   case 3:
    $9 = $6 + 116 | 0;
    $10 = $9;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    FUNCTION_TABLE_vi[$11 & 1023]($face);
    label = 5;
    break;
   case 5:
    $15 = $6 + 144 | 0;
    $16 = $15;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    FUNCTION_TABLE_vi[$17 & 1023]($face);
    label = 7;
    break;
   case 7:
    _tt_face_free_bdf_props($face);
    _tt_face_done_kern($face);
    $21 = $face + 144 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22;
    _ft_mem_free($4, $23);
    HEAP32[$21 >> 2] = 0;
    $24 = $face + 140 | 0;
    HEAP32[$24 >> 2] = 0;
    $25 = $face + 156 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $26;
    _ft_mem_free($4, $27);
    HEAP32[$25 >> 2] = 0;
    $28 = $face + 152 | 0;
    HEAP16[$28 >> 1] = 0;
    $29 = $face + 104 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $face + 500 | 0;
    _FT_Stream_ReleaseFrame($30, $31);
    $32 = $face + 504 | 0;
    HEAP32[$32 >> 2] = 0;
    $33 = $face + 252 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    _ft_mem_free($4, $34);
    HEAP32[$33 >> 2] = 0;
    $35 = $face + 256 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    _ft_mem_free($4, $36);
    HEAP32[$35 >> 2] = 0;
    $37 = $face + 296 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 << 24 >> 24 == 0;
    if ($39) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $41 = $face + 336 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    _ft_mem_free($4, $42);
    HEAP32[$41 >> 2] = 0;
    $43 = $face + 340 | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    _ft_mem_free($4, $44);
    HEAP32[$43 >> 2] = 0;
    HEAP8[$37] = 0;
    label = 9;
    break;
   case 9:
    $46 = $face + 552 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $47;
    _ft_mem_free($4, $48);
    HEAP32[$46 >> 2] = 0;
    $49 = $face + 550 | 0;
    HEAP16[$49 >> 1] = 0;
    if ($7) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $51 = $6 + 60 | 0;
    $52 = $51;
    $53 = HEAP32[$52 >> 2] | 0;
    FUNCTION_TABLE_vi[$53 & 1023]($face);
    label = 11;
    break;
   case 11:
    $55 = $face + 20 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    _ft_mem_free($4, $56);
    HEAP32[$55 >> 2] = 0;
    $57 = $face + 24 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    _ft_mem_free($4, $58);
    HEAP32[$57 >> 2] = 0;
    $59 = $face + 32 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = $60;
    _ft_mem_free($4, $61);
    HEAP32[$59 >> 2] = 0;
    $62 = $face + 28 | 0;
    HEAP32[$62 >> 2] = 0;
    $63 = $face + 700 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    _ft_mem_free($4, $64);
    HEAP32[$63 >> 2] = 0;
    HEAP32[$5 >> 2] = 0;
    label = 12;
    break;
   case 12:
    return;
  }
}
function _tt_face_load_head($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  return _tt_face_load_generic_header($face, $stream, 1751474532) | 0;
}
function _tt_face_load_hhea($face, $stream, $vertical) {
  $face = $face | 0;
  $stream = $stream | 0;
  $vertical = $vertical | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $15 = 0, $header_0 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $vertical << 24 >> 24 == 0;
    $2 = $face + 508 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3;
    if ($1) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = FUNCTION_TABLE_iiiii[$4 & 1023]($face, 1986553185, $stream, 0) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 3;
      break;
    } else {
      $error_0 = $6;
      label = 8;
      break;
    }
   case 3:
    $9 = $face + 300 | 0;
    $10 = $9;
    $header_0 = $10;
    label = 6;
    break;
   case 4:
    $12 = FUNCTION_TABLE_iiiii[$4 & 1023]($face, 1751672161, $stream, 0) | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 5;
      break;
    } else {
      $error_0 = $12;
      label = 8;
      break;
    }
   case 5:
    $15 = $face + 216 | 0;
    $header_0 = $15;
    label = 6;
    break;
   case 6:
    $17 = $header_0;
    $18 = _FT_Stream_ReadFields($stream, 5243916, $17) | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 7;
      break;
    } else {
      $error_0 = $18;
      label = 8;
      break;
    }
   case 7:
    $21 = $header_0 + 36 | 0;
    HEAP32[$21 >> 2] = 0;
    $22 = $header_0 + 40 | 0;
    HEAP32[$22 >> 2] = 0;
    $error_0 = 0;
    label = 8;
    break;
   case 8:
    return $error_0 | 0;
  }
  return 0;
}
function _tt_face_load_cmap($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 508 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    $4 = $face + 504 | 0;
    $5 = FUNCTION_TABLE_iiiii[$3 & 1023]($face, 1668112752, $stream, $4) | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 2;
      break;
    } else {
      $error_0 = $5;
      label = 4;
      break;
    }
   case 2:
    $8 = HEAP32[$4 >> 2] | 0;
    $9 = $face + 500 | 0;
    $10 = _FT_Stream_ExtractFrame($stream, $8, $9) | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      $error_0 = 0;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    HEAP32[$4 >> 2] = 0;
    $error_0 = $10;
    label = 4;
    break;
   case 4:
    return $error_0 | 0;
  }
  return 0;
}
function _tt_face_load_maxp($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $28 = 0, $29 = 0, $32 = 0, $33 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 260 | 0;
    $2 = $face + 508 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3;
    $5 = FUNCTION_TABLE_iiiii[$4 & 1023]($face, 1835104368, $stream, 0) | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 2;
      break;
    } else {
      $error_0 = $5;
      label = 11;
      break;
    }
   case 2:
    $8 = $1;
    $9 = _FT_Stream_ReadFields($stream, 5243900, $8) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 3;
      break;
    } else {
      $error_0 = $9;
      label = 11;
      break;
    }
   case 3:
    $12 = $face + 266 | 0;
    $13 = $face + 276 | 0;
    $14 = $face + 280 | 0;
    $15 = $face + 290 | 0;
    $16 = $1 | 0;
    $17 = $12;
    _memset($17 | 0, 0, 26);
    $18 = HEAP32[$16 >> 2] | 0;
    $19 = ($18 | 0) > 65535;
    if ($19) {
      label = 4;
      break;
    } else {
      $error_0 = 0;
      label = 11;
      break;
    }
   case 4:
    $21 = _FT_Stream_ReadFields($stream, 5243840, $8) | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 5;
      break;
    } else {
      $error_0 = $21;
      label = 11;
      break;
    }
   case 5:
    $24 = HEAP16[$14 >> 1] | 0;
    $25 = ($24 & 65535) < 64;
    if ($25) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    HEAP16[$14 >> 1] = 64;
    label = 7;
    break;
   case 7:
    $28 = HEAP16[$13 >> 1] | 0;
    $29 = ($28 & 65535) > 65531;
    if ($29) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    HEAP16[$13 >> 1] = -5;
    label = 9;
    break;
   case 9:
    $32 = HEAP16[$15 >> 1] | 0;
    $33 = ($32 & 65535) > 100;
    if ($33) {
      label = 10;
      break;
    } else {
      $error_0 = $21;
      label = 11;
      break;
    }
   case 10:
    HEAP16[$15 >> 1] = 100;
    $error_0 = $21;
    label = 11;
    break;
   case 11:
    return $error_0 | 0;
  }
  return 0;
}
function _tt_face_load_os2($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $24 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 508 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    $4 = FUNCTION_TABLE_iiiii[$3 & 1023]($face, 1330851634, $stream, 0) | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $error_0 = $4;
      label = 7;
      break;
    }
   case 2:
    $7 = $face + 368 | 0;
    $8 = $7;
    $9 = _FT_Stream_ReadFields($stream, 5243616, $8) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 3;
      break;
    } else {
      $error_0 = $9;
      label = 7;
      break;
    }
   case 3:
    $12 = $face + 448 | 0;
    $13 = $7 | 0;
    $14 = $12;
    _memset($14 | 0, 0, 18);
    $15 = HEAP16[$13 >> 1] | 0;
    $16 = $15 << 16 >> 16 == 0;
    if ($16) {
      $error_0 = 0;
      label = 7;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $18 = _FT_Stream_ReadFields($stream, 5243600, $8) | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 5;
      break;
    } else {
      $error_0 = $18;
      label = 7;
      break;
    }
   case 5:
    $21 = HEAP16[$13 >> 1] | 0;
    $22 = ($21 & 65535) > 1;
    if ($22) {
      label = 6;
      break;
    } else {
      $error_0 = 0;
      label = 7;
      break;
    }
   case 6:
    $24 = _FT_Stream_ReadFields($stream, 5243572, $8) | 0;
    $error_0 = $24;
    label = 7;
    break;
   case 7:
    return $error_0 | 0;
  }
  return 0;
}
function _tt_face_load_post($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 508 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    $4 = FUNCTION_TABLE_iiiii[$3 & 1023]($face, 1886352244, $stream, 0) | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $_0 = $4;
      label = 3;
      break;
    }
   case 2:
    $7 = $face + 468 | 0;
    $8 = $7;
    $9 = _FT_Stream_ReadFields($stream, 5243464, $8) | 0;
    $_0 = $9;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _tt_face_load_name($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $error = 0, $table_len = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $entry_039 = 0, $count_038 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $60 = 0, $entry_1 = 0, $62 = 0, $63 = 0, $entry_0_lcssa = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $73 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $table_len = __stackBase__ + 4 | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 364 | 0;
    HEAP32[$3 >> 2] = $stream;
    $4 = $face + 508 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5;
    $7 = FUNCTION_TABLE_iiiii[$6 & 1023]($face, 1851878757, $stream, $table_len) | 0;
    HEAP32[$error >> 2] = $7;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 17;
      break;
    }
   case 2:
    $10 = $face + 348 | 0;
    $11 = _FT_Stream_Pos($stream) | 0;
    $12 = $10;
    $13 = _FT_Stream_ReadFields($stream, 5243792, $12) | 0;
    HEAP32[$error >> 2] = $13;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 3;
      break;
    } else {
      label = 17;
      break;
    }
   case 3:
    $16 = $11 + 6 | 0;
    $17 = $face + 352 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $18 * 12 & -1;
    $20 = $16 + $19 | 0;
    $21 = HEAP32[$table_len >> 2] | 0;
    $22 = $21 + $11 | 0;
    $23 = $20 >>> 0 > $22 >>> 0;
    if ($23) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    HEAP32[$error >> 2] = 145;
    label = 17;
    break;
   case 5:
    HEAP32[$17 >> 2] = 0;
    $26 = _ft_mem_realloc($2, 20, 0, $18, 0, $error) | 0;
    $27 = $26;
    $28 = $face + 360 | 0;
    HEAP32[$28 >> 2] = $27;
    $29 = HEAP32[$error >> 2] | 0;
    $30 = ($29 | 0) == 0;
    if ($30) {
      label = 6;
      break;
    } else {
      label = 17;
      break;
    }
   case 6:
    $32 = _FT_Stream_EnterFrame($stream, $19) | 0;
    HEAP32[$error >> 2] = $32;
    $33 = ($32 | 0) == 0;
    if ($33) {
      label = 7;
      break;
    } else {
      label = 17;
      break;
    }
   case 7:
    $35 = HEAP32[$28 >> 2] | 0;
    $36 = ($18 | 0) == 0;
    if ($36) {
      $entry_0_lcssa = $35;
      label = 16;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $37 = $face + 356 | 0;
    $count_038 = $18;
    $entry_039 = $35;
    label = 9;
    break;
   case 9:
    $39 = $entry_039;
    $40 = _FT_Stream_ReadFields($stream, 5243812, $39) | 0;
    HEAP32[$error >> 2] = $40;
    $41 = ($40 | 0) == 0;
    if ($41) {
      label = 10;
      break;
    } else {
      $entry_1 = $entry_039;
      label = 15;
      break;
    }
   case 10:
    $43 = $entry_039 + 8 | 0;
    $44 = HEAP16[$43 >> 1] | 0;
    $45 = $44 << 16 >> 16 == 0;
    if ($45) {
      $entry_1 = $entry_039;
      label = 15;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $47 = HEAP32[$37 >> 2] | 0;
    $48 = $47 + $11 | 0;
    $49 = $entry_039 + 12 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $48 + $50 | 0;
    HEAP32[$49 >> 2] = $51;
    $52 = $51 >>> 0 < $20 >>> 0;
    if ($52) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $54 = HEAP16[$43 >> 1] | 0;
    $55 = $54 & 65535;
    $56 = $55 + $51 | 0;
    $57 = $56 >>> 0 > $22 >>> 0;
    if ($57) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    HEAP32[$49 >> 2] = 0;
    HEAP16[$43 >> 1] = 0;
    $entry_1 = $entry_039;
    label = 15;
    break;
   case 14:
    $60 = $entry_039 + 20 | 0;
    $entry_1 = $60;
    label = 15;
    break;
   case 15:
    $62 = $count_038 - 1 | 0;
    $63 = ($62 | 0) == 0;
    if ($63) {
      $entry_0_lcssa = $entry_1;
      label = 16;
      break;
    } else {
      $count_038 = $62;
      $entry_039 = $entry_1;
      label = 9;
      break;
    }
   case 16:
    $64 = HEAP32[$28 >> 2] | 0;
    $65 = $entry_0_lcssa;
    $66 = $64;
    $67 = $65 - $66 | 0;
    $68 = ($67 | 0) / 20 & -1;
    HEAP32[$17 >> 2] = $68;
    _FT_Stream_ExitFrame($stream);
    $69 = HEAP32[$17 >> 2] | 0;
    $70 = $69 & 65535;
    $71 = $face + 344 | 0;
    HEAP16[$71 >> 1] = $70;
    label = 17;
    break;
   case 17:
    $73 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $73 | 0;
  }
  return 0;
}
function _tt_face_free_name($face) {
  $face = $face | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $count_014 = 0, $entry_013 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 96 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 8 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $face + 360 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $face + 352 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($6 | 0) == 0;
    if ($9) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = ($8 | 0) == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      $entry_013 = $6;
      $count_014 = $8;
      label = 3;
      break;
    }
   case 3:
    $11 = $entry_013 + 16 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    _ft_mem_free($4, $12);
    HEAP32[$11 >> 2] = 0;
    $13 = $entry_013 + 8 | 0;
    HEAP16[$13 >> 1] = 0;
    $14 = $count_014 - 1 | 0;
    $15 = $entry_013 + 20 | 0;
    $16 = ($14 | 0) == 0;
    if ($16) {
      label = 4;
      break;
    } else {
      $entry_013 = $15;
      $count_014 = $14;
      label = 3;
      break;
    }
   case 4:
    $17 = HEAP32[$5 >> 2] | 0;
    $18 = $17;
    _ft_mem_free($4, $18);
    HEAP32[$5 >> 2] = 0;
    label = 5;
    break;
   case 5:
    HEAP32[$7 >> 2] = 0;
    $20 = $face + 348 | 0;
    HEAP16[$20 >> 1] = 0;
    $21 = $face + 356 | 0;
    HEAP32[$21 >> 2] = 0;
    return;
  }
}
function _tt_face_load_kern($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $table_size = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $_ = 0, $28 = 0, $29 = 0, $p_067 = 0, $nn_066 = 0, $ordered_065 = 0, $avail_064 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $_63 = 0, $_masked = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $73 = 0, $num_pairs_0 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $p_1 = 0, $count_0_in = 0, $old_pair_0 = 0, $count_0 = 0, $cond = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $118 = 0, $avail_1 = 0, $ordered_1 = 0, $119 = 0, $120 = 0, $nn_0_lcssa = 0, $ordered_0_lcssa = 0, $avail_0_lcssa = 0, $121 = 0, $122 = 0, $123 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $table_size = __stackBase__ | 0;
    $1 = $face + 508 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    $4 = FUNCTION_TABLE_iiiii[$3 & 1023]($face, 1801810542, $stream, $table_size) | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $error_0 = $4;
      label = 19;
      break;
    }
   case 2:
    $7 = HEAP32[$table_size >> 2] | 0;
    $8 = $7 >>> 0 < 4;
    if ($8) {
      $error_0 = 142;
      label = 19;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $10 = $face + 772 | 0;
    $11 = _FT_Stream_ExtractFrame($stream, $7, $10) | 0;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 4;
      break;
    } else {
      $error_0 = $11;
      label = 19;
      break;
    }
   case 4:
    $14 = HEAP32[$table_size >> 2] | 0;
    $15 = $face + 776 | 0;
    HEAP32[$15 >> 2] = $14;
    $16 = HEAP32[$10 >> 2] | 0;
    $17 = HEAP32[$table_size >> 2] | 0;
    $18 = $16 + $17 | 0;
    $19 = $16 + 2 | 0;
    $20 = HEAP8[$19] | 0;
    $21 = $20 & 255;
    $22 = $21 << 8;
    $23 = $16 + 3 | 0;
    $24 = HEAP8[$23] | 0;
    $25 = $24 & 255;
    $26 = $22 | $25;
    $27 = $26 >>> 0 > 32;
    $_ = $27 ? 32 : $26;
    $28 = ($_ | 0) == 0;
    if ($28) {
      $avail_0_lcssa = 0;
      $ordered_0_lcssa = 0;
      $nn_0_lcssa = 0;
      label = 18;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $29 = $16 + 4 | 0;
    $avail_064 = 0;
    $ordered_065 = 0;
    $nn_066 = 0;
    $p_067 = $29;
    label = 6;
    break;
   case 6:
    $31 = 1 << $nn_066;
    $32 = $p_067 + 6 | 0;
    $33 = $32 >>> 0 > $18 >>> 0;
    if ($33) {
      $avail_0_lcssa = $avail_064;
      $ordered_0_lcssa = $ordered_065;
      $nn_0_lcssa = $nn_066;
      label = 18;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $35 = $p_067 + 2 | 0;
    $36 = HEAP8[$35] | 0;
    $37 = $36 & 255;
    $38 = $37 << 8;
    $39 = $p_067 + 3 | 0;
    $40 = HEAP8[$39] | 0;
    $41 = $40 & 255;
    $42 = $38 | $41;
    $43 = $42 >>> 0 < 7;
    if ($43) {
      $avail_0_lcssa = $avail_064;
      $ordered_0_lcssa = $ordered_065;
      $nn_0_lcssa = $nn_066;
      label = 18;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $45 = $p_067 + 4 | 0;
    $46 = $p_067 + 5 | 0;
    $47 = HEAP8[$45] | 0;
    $48 = HEAP8[$46] | 0;
    $49 = $47 & 255;
    $50 = $48 & 255;
    $51 = $49 << 8;
    $52 = $p_067 + $42 | 0;
    $53 = $52 >>> 0 > $18 >>> 0;
    $_63 = $53 ? $18 : $52;
    $_masked = $50 & 247;
    $54 = $_masked | $51;
    $55 = ($54 | 0) == 1;
    if ($55) {
      label = 9;
      break;
    } else {
      $ordered_1 = $ordered_065;
      $avail_1 = $avail_064;
      label = 17;
      break;
    }
   case 9:
    $57 = $p_067 + 14 | 0;
    $58 = $57 >>> 0 > $18 >>> 0;
    if ($58) {
      $ordered_1 = $ordered_065;
      $avail_1 = $avail_064;
      label = 17;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $60 = HEAP8[$32] | 0;
    $61 = $60 & 255;
    $62 = $61 << 8;
    $63 = $p_067 + 7 | 0;
    $64 = HEAP8[$63] | 0;
    $65 = $64 & 255;
    $66 = $62 | $65;
    $67 = $_63;
    $68 = $57;
    $69 = $67 - $68 | 0;
    $70 = $66 * 6 & -1;
    $71 = ($69 | 0) < ($70 | 0);
    if ($71) {
      label = 11;
      break;
    } else {
      $num_pairs_0 = $66;
      label = 12;
      break;
    }
   case 11:
    $73 = ($69 | 0) / 6 & -1;
    $num_pairs_0 = $73;
    label = 12;
    break;
   case 12:
    $75 = $31 | $avail_064;
    $76 = ($num_pairs_0 | 0) == 0;
    if ($76) {
      $ordered_1 = $ordered_065;
      $avail_1 = $75;
      label = 17;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $78 = HEAP8[$57] | 0;
    $79 = $78 & 255;
    $80 = $79 << 24;
    $81 = $p_067 + 15 | 0;
    $82 = HEAP8[$81] | 0;
    $83 = $82 & 255;
    $84 = $83 << 16;
    $85 = $84 | $80;
    $86 = $p_067 + 16 | 0;
    $87 = HEAP8[$86] | 0;
    $88 = $87 & 255;
    $89 = $88 << 8;
    $90 = $85 | $89;
    $91 = $p_067 + 17 | 0;
    $92 = HEAP8[$91] | 0;
    $93 = $92 & 255;
    $94 = $90 | $93;
    $95 = $p_067 + 20 | 0;
    $old_pair_0 = $94;
    $count_0_in = $num_pairs_0;
    $p_1 = $95;
    label = 14;
    break;
   case 14:
    $count_0 = $count_0_in - 1 | 0;
    $cond = ($count_0 | 0) == 0;
    if ($cond) {
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $98 = HEAP8[$p_1] | 0;
    $99 = $98 & 255;
    $100 = $99 << 24;
    $101 = $p_1 + 1 | 0;
    $102 = HEAP8[$101] | 0;
    $103 = $102 & 255;
    $104 = $103 << 16;
    $105 = $104 | $100;
    $106 = $p_1 + 2 | 0;
    $107 = HEAP8[$106] | 0;
    $108 = $107 & 255;
    $109 = $108 << 8;
    $110 = $105 | $109;
    $111 = $p_1 + 3 | 0;
    $112 = HEAP8[$111] | 0;
    $113 = $112 & 255;
    $114 = $110 | $113;
    $115 = $114 >>> 0 > $old_pair_0 >>> 0;
    $116 = $p_1 + 6 | 0;
    if ($115) {
      $old_pair_0 = $114;
      $count_0_in = $count_0;
      $p_1 = $116;
      label = 14;
      break;
    } else {
      $ordered_1 = $ordered_065;
      $avail_1 = $75;
      label = 17;
      break;
    }
   case 16:
    $118 = $31 | $ordered_065;
    $ordered_1 = $118;
    $avail_1 = $75;
    label = 17;
    break;
   case 17:
    $119 = $nn_066 + 1 | 0;
    $120 = $119 >>> 0 < $_ >>> 0;
    if ($120) {
      $avail_064 = $avail_1;
      $ordered_065 = $ordered_1;
      $nn_066 = $119;
      $p_067 = $_63;
      label = 6;
      break;
    } else {
      $avail_0_lcssa = $avail_1;
      $ordered_0_lcssa = $ordered_1;
      $nn_0_lcssa = $119;
      label = 18;
      break;
    }
   case 18:
    $121 = $face + 780 | 0;
    HEAP32[$121 >> 2] = $nn_0_lcssa;
    $122 = $face + 784 | 0;
    HEAP32[$122 >> 2] = $avail_0_lcssa;
    $123 = $face + 788 | 0;
    HEAP32[$123 >> 2] = $ordered_0_lcssa;
    $error_0 = $11;
    label = 19;
    break;
   case 19:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _tt_face_load_gasp($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $j_023 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $exitcond = 0, $41 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 508 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4;
    $6 = FUNCTION_TABLE_iiiii[$5 & 1023]($face, 1734439792, $stream, 0) | 0;
    HEAP32[$error >> 2] = $6;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 2;
      break;
    } else {
      label = 11;
      break;
    }
   case 2:
    $9 = _FT_Stream_EnterFrame($stream, 4) | 0;
    HEAP32[$error >> 2] = $9;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 3;
      break;
    } else {
      label = 11;
      break;
    }
   case 3:
    $12 = _FT_Stream_GetShort($stream) | 0;
    $13 = $face + 548 | 0;
    HEAP16[$13 >> 1] = $12;
    $14 = _FT_Stream_GetShort($stream) | 0;
    $15 = $face + 550 | 0;
    HEAP16[$15 >> 1] = $14;
    _FT_Stream_ExitFrame($stream);
    $16 = HEAP16[$13 >> 1] | 0;
    $17 = ($16 & 65535) > 1;
    if ($17) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    HEAP16[$15 >> 1] = 0;
    HEAP32[$error >> 2] = 8;
    label = 11;
    break;
   case 5:
    $20 = HEAP16[$15 >> 1] | 0;
    $21 = $20 & 65535;
    $22 = _ft_mem_realloc($2, 4, 0, $21, 0, $error) | 0;
    $23 = $22;
    $24 = HEAP32[$error >> 2] | 0;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 6;
      break;
    } else {
      label = 11;
      break;
    }
   case 6:
    $27 = $21 << 2;
    $28 = _FT_Stream_EnterFrame($stream, $27) | 0;
    HEAP32[$error >> 2] = $28;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 7;
      break;
    } else {
      label = 11;
      break;
    }
   case 7:
    $31 = $face + 552 | 0;
    HEAP32[$31 >> 2] = $23;
    $32 = $20 << 16 >> 16 == 0;
    if ($32) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $33 = $20 & 65535;
    $j_023 = 0;
    label = 9;
    break;
   case 9:
    $35 = _FT_Stream_GetShort($stream) | 0;
    $36 = $23 + ($j_023 << 2) | 0;
    HEAP16[$36 >> 1] = $35;
    $37 = _FT_Stream_GetShort($stream) | 0;
    $38 = $23 + ($j_023 << 2) + 2 | 0;
    HEAP16[$38 >> 1] = $37;
    $39 = $j_023 + 1 | 0;
    $exitcond = ($39 | 0) == ($33 | 0);
    if ($exitcond) {
      label = 10;
      break;
    } else {
      $j_023 = $39;
      label = 9;
      break;
    }
   case 10:
    _FT_Stream_ExitFrame($stream);
    label = 11;
    break;
   case 11:
    $41 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $41 | 0;
  }
  return 0;
}
function _tt_face_load_pclt($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 508 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    $4 = FUNCTION_TABLE_iiiii[$3 & 1023]($face, 1346587732, $stream, 0) | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $error_0 = $4;
      label = 3;
      break;
    }
   case 2:
    $7 = $face + 556 | 0;
    $8 = $7;
    $9 = _FT_Stream_ReadFields($stream, 5243508, $8) | 0;
    $error_0 = $9;
    label = 3;
    break;
   case 3:
    return $error_0 | 0;
  }
  return 0;
}
function _tt_face_load_bhed($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  return _tt_face_load_generic_header($face, $stream, 1651008868) | 0;
}
function _tt_face_set_sbit_strike_stub($face, $x_ppem, $y_ppem, $astrike_index) {
  $face = $face | 0;
  $x_ppem = $x_ppem | 0;
  $y_ppem = $y_ppem | 0;
  $astrike_index = $astrike_index | 0;
  var $req = 0, $6 = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 20 | 0;
  $req = __stackBase__ | 0;
  HEAP32[$req >> 2] = 0;
  HEAP32[$req + 4 >> 2] = $x_ppem;
  HEAP32[$req + 8 >> 2] = $y_ppem;
  HEAP32[$req + 12 >> 2] = 0;
  HEAP32[$req + 16 >> 2] = 0;
  HEAP32[$astrike_index >> 2] = 2147483647;
  $6 = _tt_face_set_sbit_strike($face, $req, $astrike_index) | 0;
  STACKTOP = __stackBase__;
  return $6 | 0;
}
function _tt_find_sbit_image($face, $glyph_index, $strike_index, $arange, $astrike, $aglyph_offset) {
  $face = $face | 0;
  $glyph_index = $glyph_index | 0;
  $strike_index = $strike_index | 0;
  $arange = $arange | 0;
  $astrike = $astrike | 0;
  $aglyph_offset = $aglyph_offset | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 616 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $face + 612 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 >>> 0 > $strike_index >>> 0;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $9 = $2 + ($strike_index * 48 & -1) | 0;
    $10 = _find_sbit_range($glyph_index, $9, $arange, $aglyph_offset) | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    HEAP32[$astrike >> 2] = $9;
    $_0 = 0;
    label = 6;
    break;
   case 5:
    HEAP32[$arange >> 2] = 0;
    HEAP32[$astrike >> 2] = 0;
    HEAP32[$aglyph_offset >> 2] = 0;
    $_0 = 6;
    label = 6;
    break;
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _tt_load_sbit_metrics($stream, $range, $metrics) {
  $stream = $stream | 0;
  $range = $range | 0;
  $metrics = $metrics | 0;
  var $smetrics = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $ld$0$0 = 0, $36$0 = 0, $ld$1$1 = 0, $36$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $smetrics = __stackBase__ | 0;
    $1 = $range + 6 | 0;
    $2 = HEAP16[$1 >> 1] | 0;
    $3 = $2 & 65535;
    if (($3 | 0) == 1 | ($3 | 0) == 2 | ($3 | 0) == 8) {
      label = 2;
      break;
    } else if (($3 | 0) == 6 | ($3 | 0) == 7 | ($3 | 0) == 9) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 2:
    $5 = $smetrics | 0;
    $6 = _FT_Stream_ReadFields($stream, 5243436, $5) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 3;
      break;
    } else {
      $_0 = $6;
      label = 7;
      break;
    }
   case 3:
    $9 = HEAP8[$5] | 0;
    $10 = $metrics | 0;
    HEAP8[$10] = $9;
    $11 = $smetrics + 1 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $metrics + 1 | 0;
    HEAP8[$13] = $12;
    $14 = $smetrics + 2 | 0;
    $15 = HEAP8[$14] | 0;
    $16 = $metrics + 2 | 0;
    HEAP8[$16] = $15;
    $17 = $smetrics + 3 | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $metrics + 3 | 0;
    HEAP8[$19] = $18;
    $20 = $smetrics + 4 | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $metrics + 4 | 0;
    HEAP8[$22] = $21;
    $23 = $metrics + 5 | 0;
    HEAP8[$23] = 0;
    $24 = $metrics + 6 | 0;
    HEAP8[$24] = 0;
    $25 = $metrics + 7 | 0;
    HEAP8[$25] = 0;
    $_0 = 0;
    label = 7;
    break;
   case 4:
    $27 = $metrics | 0;
    $28 = _FT_Stream_ReadFields($stream, 5249812, $27) | 0;
    $_0 = $28;
    label = 7;
    break;
   case 5:
    $30 = $range + 4 | 0;
    $31 = HEAP16[$30 >> 1] | 0;
    if (($31 << 16 >> 16 | 0) == 2 | ($31 << 16 >> 16 | 0) == 5) {
      label = 6;
      break;
    } else {
      $_0 = 3;
      label = 7;
      break;
    }
   case 6:
    $33 = $range + 16 | 0;
    $34 = $33;
    $35 = $metrics;
    $ld$0$0 = $34 | 0;
    $36$0 = HEAPU8[$ld$0$0] | HEAPU8[$ld$0$0 + 1 | 0] << 8 | HEAPU8[$ld$0$0 + 2 | 0] << 16 | HEAPU8[$ld$0$0 + 3 | 0] << 24 | 0;
    $ld$1$1 = $34 + 4 | 0;
    $36$1 = HEAPU8[$ld$1$1] | HEAPU8[$ld$1$1 + 1 | 0] << 8 | HEAPU8[$ld$1$1 + 2 | 0] << 16 | HEAPU8[$ld$1$1 + 3 | 0] << 24 | 0;
    $st$2$0 = $35 | 0;
    tempBigInt = $36$0;
    HEAP8[$st$2$0] = tempBigInt & 255;
    tempBigInt = tempBigInt >> 8;
    HEAP8[$st$2$0 + 1 | 0] = tempBigInt & 255;
    tempBigInt = tempBigInt >> 8;
    HEAP8[$st$2$0 + 2 | 0] = tempBigInt & 255;
    tempBigInt = tempBigInt >> 8;
    HEAP8[$st$2$0 + 3 | 0] = tempBigInt & 255;
    $st$3$1 = $35 + 4 | 0;
    tempBigInt = $36$1;
    HEAP8[$st$3$1] = tempBigInt & 255;
    tempBigInt = tempBigInt >> 8;
    HEAP8[$st$3$1 + 1 | 0] = tempBigInt & 255;
    tempBigInt = tempBigInt >> 8;
    HEAP8[$st$3$1 + 2 | 0] = tempBigInt & 255;
    tempBigInt = tempBigInt >> 8;
    HEAP8[$st$3$1 + 3 | 0] = tempBigInt & 255;
    $_0 = 0;
    label = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _tt_face_free_sbit_stub($face) {
  $face = $face | 0;
  return;
}
function _tt_face_load_charmap_stub($face, $cmap, $input) {
  $face = $face | 0;
  $cmap = $cmap | 0;
  $input = $input | 0;
  return 7;
}
function _tt_face_free_charmap_stub($face, $cmap) {
  $face = $face | 0;
  $cmap = $cmap | 0;
  return 0;
}
function _tt_face_get_kerning($face, $left_glyph, $right_glyph) {
  $face = $face | 0;
  $left_glyph = $left_glyph | 0;
  $right_glyph = $right_glyph | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $result_079 = 0, $count_078 = 0, $mask_076 = 0, $p_075 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $_ = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $num_pairs_0 = 0, $cond = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $max_068 = 0, $min_067 = 0, $59 = 0, $60 = 0, $61 = 0, $_sum62 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $_sum63 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $_sum64 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $_sum65 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $_sum61 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $_sum66 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $_min_0 = 0, $max_0_ = 0, $93 = 0, $count2_073 = 0, $p_172 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $122 = 0, $123 = 0, $124 = 0, $value_0_in = 0, $value_0 = 0, $126 = 0, $127 = 0, $129 = 0, $result_1 = 0, $130 = 0, $131 = 0, $132 = 0, $result_0_lcssa = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 772 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 776 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + $4 | 0;
    $6 = $face + 780 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      $result_0_lcssa = 0;
      label = 21;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = $2 + 4 | 0;
    $10 = $face + 784 | 0;
    $11 = $left_glyph << 16;
    $12 = $11 | $right_glyph;
    $13 = $face + 788 | 0;
    $p_075 = $9;
    $mask_076 = 1;
    $count_078 = $7;
    $result_079 = 0;
    label = 3;
    break;
   case 3:
    $15 = $p_075 + 6 | 0;
    $16 = $15 >>> 0 > $5 >>> 0;
    if ($16) {
      $result_0_lcssa = $result_079;
      label = 21;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $18 = $p_075 + 2 | 0;
    $19 = HEAP8[$18] | 0;
    $20 = $19 & 255;
    $21 = $20 << 8;
    $22 = $p_075 + 3 | 0;
    $23 = HEAP8[$22] | 0;
    $24 = $23 & 255;
    $25 = $21 | $24;
    $26 = $p_075 + 4 | 0;
    $27 = HEAP8[$26] | 0;
    $28 = $p_075 + 5 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $p_075 + $25 | 0;
    $31 = $30 >>> 0 > $5 >>> 0;
    $_ = $31 ? $5 : $30;
    $32 = HEAP32[$10 >> 2] | 0;
    $33 = $32 & $mask_076;
    $34 = ($33 | 0) == 0;
    if ($34) {
      $result_1 = $result_079;
      label = 20;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $36 = $p_075 + 14 | 0;
    $37 = $36 >>> 0 > $_ >>> 0;
    if ($37) {
      $result_1 = $result_079;
      label = 20;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $39 = HEAP8[$15] | 0;
    $40 = $39 & 255;
    $41 = $40 << 8;
    $42 = $p_075 + 7 | 0;
    $43 = HEAP8[$42] | 0;
    $44 = $43 & 255;
    $45 = $41 | $44;
    $46 = $_;
    $47 = $36;
    $48 = $46 - $47 | 0;
    $49 = $45 * 6 & -1;
    $50 = ($48 | 0) < ($49 | 0);
    if ($50) {
      label = 7;
      break;
    } else {
      $num_pairs_0 = $45;
      label = 8;
      break;
    }
   case 7:
    $52 = ($48 | 0) / 6 & -1;
    $num_pairs_0 = $52;
    label = 8;
    break;
   case 8:
    $cond = $27 << 24 >> 24 == 0;
    if ($cond) {
      label = 9;
      break;
    } else {
      $result_1 = $result_079;
      label = 20;
      break;
    }
   case 9:
    $55 = HEAP32[$13 >> 2] | 0;
    $56 = $55 & $mask_076;
    $57 = ($56 | 0) == 0;
    $58 = ($num_pairs_0 | 0) == 0;
    if ($57) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    if ($58) {
      $result_1 = $result_079;
      label = 20;
      break;
    } else {
      $p_172 = $36;
      $count2_073 = $num_pairs_0;
      label = 15;
      break;
    }
   case 11:
    if ($58) {
      $result_1 = $result_079;
      label = 20;
      break;
    } else {
      $min_067 = 0;
      $max_068 = $num_pairs_0;
      label = 12;
      break;
    }
   case 12:
    $59 = $max_068 + $min_067 | 0;
    $60 = $59 >>> 1;
    $61 = $60 * 6 & -1;
    $_sum62 = $61 + 14 | 0;
    $62 = $p_075 + $_sum62 | 0;
    $63 = HEAP8[$62] | 0;
    $64 = $63 & 255;
    $65 = $64 << 24;
    $_sum63 = $61 + 15 | 0;
    $66 = $p_075 + $_sum63 | 0;
    $67 = HEAP8[$66] | 0;
    $68 = $67 & 255;
    $69 = $68 << 16;
    $70 = $69 | $65;
    $_sum64 = $61 + 16 | 0;
    $71 = $p_075 + $_sum64 | 0;
    $72 = HEAP8[$71] | 0;
    $73 = $72 & 255;
    $74 = $73 << 8;
    $75 = $70 | $74;
    $_sum65 = $61 + 17 | 0;
    $76 = $p_075 + $_sum65 | 0;
    $77 = HEAP8[$76] | 0;
    $78 = $77 & 255;
    $79 = $75 | $78;
    $80 = ($79 | 0) == ($12 | 0);
    if ($80) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    $_sum61 = $61 + 18 | 0;
    $82 = $p_075 + $_sum61 | 0;
    $83 = HEAP8[$82] | 0;
    $84 = $83 & 255;
    $85 = $84 << 8;
    $_sum66 = $61 + 19 | 0;
    $86 = $p_075 + $_sum66 | 0;
    $87 = HEAP8[$86] | 0;
    $88 = $87 & 255;
    $89 = $85 | $88;
    $value_0_in = $89;
    label = 18;
    break;
   case 14:
    $91 = $79 >>> 0 < $12 >>> 0;
    $92 = $60 + 1 | 0;
    $_min_0 = $91 ? $92 : $min_067;
    $max_0_ = $91 ? $max_068 : $60;
    $93 = $_min_0 >>> 0 < $max_0_ >>> 0;
    if ($93) {
      $min_067 = $_min_0;
      $max_068 = $max_0_;
      label = 12;
      break;
    } else {
      $result_1 = $result_079;
      label = 20;
      break;
    }
   case 15:
    $94 = HEAP8[$p_172] | 0;
    $95 = $94 & 255;
    $96 = $95 << 24;
    $97 = $p_172 + 1 | 0;
    $98 = HEAP8[$97] | 0;
    $99 = $98 & 255;
    $100 = $99 << 16;
    $101 = $100 | $96;
    $102 = $p_172 + 2 | 0;
    $103 = HEAP8[$102] | 0;
    $104 = $103 & 255;
    $105 = $104 << 8;
    $106 = $101 | $105;
    $107 = $p_172 + 3 | 0;
    $108 = HEAP8[$107] | 0;
    $109 = $108 & 255;
    $110 = $106 | $109;
    $111 = ($110 | 0) == ($12 | 0);
    if ($111) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    $113 = $p_172 + 4 | 0;
    $114 = HEAP8[$113] | 0;
    $115 = $114 & 255;
    $116 = $115 << 8;
    $117 = $p_172 + 5 | 0;
    $118 = HEAP8[$117] | 0;
    $119 = $118 & 255;
    $120 = $116 | $119;
    $value_0_in = $120;
    label = 18;
    break;
   case 17:
    $122 = $p_172 + 6 | 0;
    $123 = $count2_073 - 1 | 0;
    $124 = ($123 | 0) == 0;
    if ($124) {
      $result_1 = $result_079;
      label = 20;
      break;
    } else {
      $p_172 = $122;
      $count2_073 = $123;
      label = 15;
      break;
    }
   case 18:
    $value_0 = $value_0_in << 16 >> 16;
    $126 = $29 & 8;
    $127 = $126 << 24 >> 24 == 0;
    if ($127) {
      label = 19;
      break;
    } else {
      $result_1 = $value_0;
      label = 20;
      break;
    }
   case 19:
    $129 = $value_0 + $result_079 | 0;
    $result_1 = $129;
    label = 20;
    break;
   case 20:
    $130 = $count_078 - 1 | 0;
    $131 = $mask_076 << 1;
    $132 = ($130 | 0) == 0;
    if ($132) {
      $result_0_lcssa = $result_1;
      label = 21;
      break;
    } else {
      $p_075 = $_;
      $mask_076 = $131;
      $count_078 = $130;
      $result_079 = $result_1;
      label = 3;
      break;
    }
   case 21:
    return $result_0_lcssa | 0;
  }
  return 0;
}
function _tt_face_load_sbit_image($face, $strike_index, $glyph_index, $load_flags, $stream, $map, $metrics) {
  $face = $face | 0;
  $strike_index = $strike_index | 0;
  $glyph_index = $glyph_index | 0;
  $load_flags = $load_flags | 0;
  $stream = $stream | 0;
  $map = $map | 0;
  $metrics = $metrics | 0;
  var $glyph_offset = 0, $strike = 0, $range = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $error_1 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $glyph_offset = __stackBase__ | 0;
    $strike = __stackBase__ + 4 | 0;
    $range = __stackBase__ + 8 | 0;
    $1 = _tt_find_sbit_image($face, $glyph_index, $strike_index, $range, $strike, $glyph_offset) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $error_1 = $1;
      label = 9;
      break;
    }
   case 2:
    $4 = $face + 508 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5;
    $7 = FUNCTION_TABLE_iiiii[$6 & 1023]($face, 1161970772, $stream, 0) | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $10 = HEAP32[$4 >> 2] | 0;
    $11 = $10;
    $12 = FUNCTION_TABLE_iiiii[$11 & 1023]($face, 1650745716, $stream, 0) | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 4;
      break;
    } else {
      $error_1 = $12;
      label = 9;
      break;
    }
   case 4:
    $14 = _FT_Stream_Pos($stream) | 0;
    $15 = HEAP32[$strike >> 2] | 0;
    $16 = HEAP32[$range >> 2] | 0;
    $17 = HEAP32[$glyph_offset >> 2] | 0;
    $18 = $face + 84 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = _Load_SBit_Image($15, $16, $14, $17, $19, 0, 0, $stream, $metrics, 0) | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 5;
      break;
    } else {
      $error_1 = $20;
      label = 9;
      break;
    }
   case 5:
    $23 = HEAP32[$strike >> 2] | 0;
    $24 = $23 + 47 | 0;
    $25 = HEAP8[$24] | 0;
    $26 = $25 & 1;
    $27 = $26 << 24 >> 24 == 0;
    if ($27) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $29 = $23 + 16 | 0;
    $30 = HEAP8[$29] | 0;
    $31 = $30 << 24 >> 24;
    $32 = $23 + 17 | 0;
    $33 = HEAP8[$32] | 0;
    $34 = $33 << 24 >> 24;
    $35 = $31 - $34 | 0;
    $36 = $metrics + 1 | 0;
    $37 = HEAP8[$36] | 0;
    $38 = $37 & 255;
    $39 = ($38 | 0) / -2 & -1;
    $40 = $39 & 255;
    $41 = $metrics + 5 | 0;
    HEAP8[$41] = $40;
    $42 = $metrics | 0;
    $43 = HEAP8[$42] | 0;
    $44 = $43 & 255;
    $45 = $35 - $44 | 0;
    $46 = ($45 | 0) / 2 & -1;
    $47 = $46 & 255;
    $48 = $metrics + 6 | 0;
    HEAP8[$48] = $47;
    $49 = $35 * 12 & -1;
    $50 = ($49 | 0) / 10 & -1;
    $51 = $50 & 255;
    $52 = $metrics + 7 | 0;
    HEAP8[$52] = $51;
    label = 7;
    break;
   case 7:
    $54 = $load_flags & 64;
    $55 = ($54 | 0) == 0;
    if ($55) {
      $error_1 = $20;
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    _crop_bitmap($map, $metrics);
    $error_1 = $20;
    label = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return $error_1 | 0;
  }
  return 0;
}
function _tt_face_free_ps_names($face) {
  $face = $face | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $n_024 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $_lcssa23 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 628 | 0;
    $4 = HEAP8[$3] | 0;
    $5 = $4 << 24 >> 24 == 0;
    if ($5) {
      label = 7;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $face + 468 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    if (($8 | 0) == 131072) {
      label = 3;
      break;
    } else if (($8 | 0) == 163840) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 3:
    $10 = $face + 636 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11;
    _ft_mem_free($2, $12);
    HEAP32[$10 >> 2] = 0;
    $13 = $face + 632 | 0;
    HEAP16[$13 >> 1] = 0;
    $14 = $face + 634 | 0;
    $15 = HEAP16[$14 >> 1] | 0;
    $16 = $15 << 16 >> 16 == 0;
    $17 = $face + 640 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    if ($16) {
      $_lcssa23 = $18;
      label = 5;
      break;
    } else {
      $n_024 = 0;
      $20 = 0;
      $19 = $18;
      label = 4;
      break;
    }
   case 4:
    $21 = $19 + ($20 << 2) | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    _ft_mem_free($2, $22);
    $23 = HEAP32[$17 >> 2] | 0;
    $24 = $23 + ($20 << 2) | 0;
    HEAP32[$24 >> 2] = 0;
    $25 = $n_024 + 1 & 65535;
    $26 = $25 & 65535;
    $27 = HEAP16[$14 >> 1] | 0;
    $28 = ($25 & 65535) < ($27 & 65535);
    $29 = HEAP32[$17 >> 2] | 0;
    if ($28) {
      $n_024 = $25;
      $20 = $26;
      $19 = $29;
      label = 4;
      break;
    } else {
      $_lcssa23 = $29;
      label = 5;
      break;
    }
   case 5:
    $30 = $_lcssa23;
    _ft_mem_free($2, $30);
    HEAP32[$17 >> 2] = 0;
    HEAP16[$14 >> 1] = 0;
    label = 7;
    break;
   case 6:
    $32 = $face + 636 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $33;
    _ft_mem_free($2, $34);
    HEAP32[$32 >> 2] = 0;
    $35 = $face + 632 | 0;
    HEAP16[$35 >> 1] = 0;
    label = 7;
    break;
   case 7:
    HEAP8[$3] = 0;
    return;
  }
}
function _tt_face_load_font_dir($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $sfnt = 0, $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $nn_026 = 0, $entry_025 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $entry_0_ = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $64 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 20 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $sfnt = __stackBase__ | 0;
    $error = __stackBase__ + 16 | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _FT_Stream_Pos($stream) | 0;
    $4 = $sfnt + 12 | 0;
    HEAP32[$4 >> 2] = $3;
    $5 = _FT_Stream_ReadLong($stream, $error) | 0;
    $6 = $sfnt | 0;
    HEAP32[$6 >> 2] = $5;
    $7 = HEAP32[$error >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 11;
      break;
    }
   case 2:
    $10 = $sfnt;
    $11 = _FT_Stream_ReadFields($stream, 5244076, $10) | 0;
    HEAP32[$error >> 2] = $11;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 3;
      break;
    } else {
      label = 11;
      break;
    }
   case 3:
    $14 = _check_table_dir($sfnt, $stream) | 0;
    HEAP32[$error >> 2] = $14;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 4;
      break;
    } else {
      label = 11;
      break;
    }
   case 4:
    $17 = $sfnt + 4 | 0;
    $18 = HEAP16[$17 >> 1] | 0;
    $19 = $face + 152 | 0;
    HEAP16[$19 >> 1] = $18;
    $20 = HEAP32[$6 >> 2] | 0;
    $21 = $face + 148 | 0;
    HEAP32[$21 >> 2] = $20;
    $22 = HEAP16[$19 >> 1] | 0;
    $23 = $22 & 65535;
    $24 = _ft_mem_realloc($2, 16, 0, $23, 0, $error) | 0;
    $25 = $24;
    $26 = $face + 156 | 0;
    HEAP32[$26 >> 2] = $25;
    $27 = HEAP32[$error >> 2] | 0;
    $28 = ($27 | 0) == 0;
    if ($28) {
      label = 5;
      break;
    } else {
      label = 11;
      break;
    }
   case 5:
    $30 = HEAP32[$4 >> 2] | 0;
    $31 = $30 + 12 | 0;
    $32 = _FT_Stream_Seek($stream, $31) | 0;
    HEAP32[$error >> 2] = $32;
    $33 = ($32 | 0) == 0;
    if ($33) {
      label = 6;
      break;
    } else {
      label = 11;
      break;
    }
   case 6:
    $35 = HEAP16[$19 >> 1] | 0;
    $36 = $35 & 65535;
    $37 = $36 << 4;
    $38 = _FT_Stream_EnterFrame($stream, $37) | 0;
    HEAP32[$error >> 2] = $38;
    $39 = ($38 | 0) == 0;
    if ($39) {
      label = 7;
      break;
    } else {
      label = 11;
      break;
    }
   case 7:
    $41 = HEAP16[$17 >> 1] | 0;
    $42 = $41 << 16 >> 16 == 0;
    if ($42) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $43 = HEAP32[$26 >> 2] | 0;
    $44 = $stream + 4 | 0;
    $entry_025 = $43;
    $nn_026 = 0;
    label = 9;
    break;
   case 9:
    $46 = _FT_Stream_GetLong($stream) | 0;
    $47 = $entry_025 | 0;
    HEAP32[$47 >> 2] = $46;
    $48 = _FT_Stream_GetLong($stream) | 0;
    $49 = $entry_025 + 4 | 0;
    HEAP32[$49 >> 2] = $48;
    $50 = _FT_Stream_GetLong($stream) | 0;
    $51 = $entry_025 + 8 | 0;
    HEAP32[$51 >> 2] = $50;
    $52 = _FT_Stream_GetLong($stream) | 0;
    $53 = $entry_025 + 12 | 0;
    HEAP32[$53 >> 2] = $52;
    $54 = HEAP32[$51 >> 2] | 0;
    $55 = $54 + $52 | 0;
    $56 = HEAP32[$44 >> 2] | 0;
    $57 = $55 >>> 0 > $56 >>> 0;
    $58 = $entry_025 + 16 | 0;
    $entry_0_ = $57 ? $entry_025 : $58;
    $59 = $nn_026 + 1 | 0;
    $60 = HEAP16[$17 >> 1] | 0;
    $61 = $60 & 65535;
    $62 = ($59 | 0) < ($61 | 0);
    if ($62) {
      $entry_025 = $entry_0_;
      $nn_026 = $59;
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    _FT_Stream_ExitFrame($stream);
    label = 11;
    break;
   case 11:
    $64 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $64 | 0;
  }
  return 0;
}
function _tt_face_load_hmtx($face, $stream, $vertical) {
  $face = $face | 0;
  $stream = $stream | 0;
  $vertical = $vertical | 0;
  var $error = 0, $table_len = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $_ = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $_64 = 0, $shorts_0_in = 0, $longs_0_in = 0, $num_longs_2 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $_65 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $longs_063 = 0, $55 = 0, $56 = 0, $57 = 0, $cur_071 = 0, $p_070 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $p_0_lcssa = 0, $shorts_061 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $cur3_068 = 0, $p_167 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $cur3_0_lcssa = 0, $93 = 0, $94 = 0, $or_cond = 0, $96 = 0, $shorts_062 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $cur3_166 = 0, $102 = 0, $103 = 0, $104 = 0, $106 = 0, $108 = 0, $110 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $table_len = __stackBase__ + 4 | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $vertical << 24 >> 24 != 0;
    $4 = $face + 508 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $8 = FUNCTION_TABLE_iiiii[$6 & 1023]($face, 1986884728, $stream, $table_len) | 0;
    HEAP32[$error >> 2] = $8;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 3;
      break;
    } else {
      label = 19;
      break;
    }
   case 3:
    $11 = $face + 340 | 0;
    $12 = $face + 336 | 0;
    $13 = $face + 334 | 0;
    $14 = HEAP16[$13 >> 1] | 0;
    $15 = $14 & 65535;
    $16 = HEAP32[$table_len >> 2] | 0;
    $17 = $16 >>> 2;
    $18 = $15 >>> 0 > $17 >>> 0;
    $_ = $18 ? $17 : $15;
    HEAP16[$13 >> 1] = 0;
    $num_longs_2 = $_;
    $longs_0_in = $12;
    $shorts_0_in = $11;
    label = 6;
    break;
   case 4:
    $20 = FUNCTION_TABLE_iiiii[$6 & 1023]($face, 1752003704, $stream, $table_len) | 0;
    HEAP32[$error >> 2] = $20;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 5;
      break;
    } else {
      label = 19;
      break;
    }
   case 5:
    $23 = $face + 256 | 0;
    $24 = $face + 252 | 0;
    $25 = $face + 250 | 0;
    $26 = HEAP16[$25 >> 1] | 0;
    $27 = $26 & 65535;
    $28 = HEAP32[$table_len >> 2] | 0;
    $29 = $28 >>> 2;
    $30 = $27 >>> 0 > $29 >>> 0;
    $_64 = $30 ? $29 : $27;
    HEAP16[$25 >> 1] = 0;
    $num_longs_2 = $_64;
    $longs_0_in = $24;
    $shorts_0_in = $23;
    label = 6;
    break;
   case 6:
    $32 = $face + 264 | 0;
    $33 = HEAP16[$32 >> 1] | 0;
    $34 = $33 & 65535;
    $35 = $34 - $num_longs_2 | 0;
    $36 = HEAP32[$table_len >> 2] | 0;
    $37 = $num_longs_2 << 2;
    $38 = $36 - $37 | 0;
    $39 = $38 >>> 1;
    $40 = ($35 | 0) < 0;
    $_65 = $40 ? 0 : $35;
    $41 = _ft_mem_realloc($2, 4, 0, $num_longs_2, 0, $error) | 0;
    HEAP32[$longs_0_in >> 2] = $41;
    $42 = HEAP32[$error >> 2] | 0;
    $43 = ($42 | 0) == 0;
    if ($43) {
      label = 7;
      break;
    } else {
      label = 19;
      break;
    }
   case 7:
    $45 = _ft_mem_realloc($2, 2, 0, $_65, 0, $error) | 0;
    HEAP32[$shorts_0_in >> 2] = $45;
    $46 = HEAP32[$error >> 2] | 0;
    $47 = ($46 | 0) == 0;
    if ($47) {
      label = 8;
      break;
    } else {
      label = 19;
      break;
    }
   case 8:
    $49 = HEAP32[$table_len >> 2] | 0;
    $50 = _FT_Stream_EnterFrame($stream, $49) | 0;
    HEAP32[$error >> 2] = $50;
    $51 = ($50 | 0) == 0;
    if ($51) {
      label = 9;
      break;
    } else {
      label = 19;
      break;
    }
   case 9:
    $53 = $stream + 32 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $longs_063 = HEAP32[$longs_0_in >> 2] | 0;
    $55 = $longs_063;
    $56 = $55 + ($num_longs_2 << 2) | 0;
    $57 = $55 >>> 0 < $56 >>> 0;
    if ($57) {
      $p_070 = $54;
      $cur_071 = $55;
      label = 10;
      break;
    } else {
      $p_0_lcssa = $54;
      label = 11;
      break;
    }
   case 10:
    $58 = HEAP8[$p_070] | 0;
    $59 = $58 & 255;
    $60 = $59 << 8;
    $61 = $p_070 + 1 | 0;
    $62 = HEAP8[$61] | 0;
    $63 = $62 & 255;
    $64 = $60 | $63;
    $65 = $cur_071 | 0;
    HEAP16[$65 >> 1] = $64;
    $66 = $p_070 + 4 | 0;
    $67 = $p_070 + 2 | 0;
    $68 = HEAP8[$67] | 0;
    $69 = $68 & 255;
    $70 = $69 << 8;
    $71 = $p_070 + 3 | 0;
    $72 = HEAP8[$71] | 0;
    $73 = $72 & 255;
    $74 = $70 | $73;
    $75 = $cur_071 + 2 | 0;
    HEAP16[$75 >> 1] = $74;
    $76 = $cur_071 + 4 | 0;
    $77 = $76 >>> 0 < $56 >>> 0;
    if ($77) {
      $p_070 = $66;
      $cur_071 = $76;
      label = 10;
      break;
    } else {
      $p_0_lcssa = $66;
      label = 11;
      break;
    }
   case 11:
    $shorts_061 = HEAP32[$shorts_0_in >> 2] | 0;
    $78 = $shorts_061;
    $79 = ($_65 | 0) < ($39 | 0);
    $80 = $79 ? $_65 : $39;
    $81 = $78 + ($80 << 1) | 0;
    $82 = $78 >>> 0 < $81 >>> 0;
    if ($82) {
      $p_167 = $p_0_lcssa;
      $cur3_068 = $78;
      label = 12;
      break;
    } else {
      $cur3_0_lcssa = $78;
      label = 13;
      break;
    }
   case 12:
    $83 = $p_167 + 2 | 0;
    $84 = HEAP8[$p_167] | 0;
    $85 = $84 & 255;
    $86 = $85 << 8;
    $87 = $p_167 + 1 | 0;
    $88 = HEAP8[$87] | 0;
    $89 = $88 & 255;
    $90 = $86 | $89;
    HEAP16[$cur3_068 >> 1] = $90;
    $91 = $cur3_068 + 2 | 0;
    $92 = $91 >>> 0 < $81 >>> 0;
    if ($92) {
      $p_167 = $83;
      $cur3_068 = $91;
      label = 12;
      break;
    } else {
      $cur3_0_lcssa = $91;
      label = 13;
      break;
    }
   case 13:
    $93 = ($_65 | 0) > ($39 | 0);
    $94 = ($39 | 0) != 0;
    $or_cond = $93 & $94;
    if ($or_cond) {
      label = 14;
      break;
    } else {
      label = 16;
      break;
    }
   case 14:
    $96 = $39 - 1 | 0;
    $shorts_062 = HEAP32[$shorts_0_in >> 2] | 0;
    $97 = $shorts_062;
    $98 = $97 + ($96 << 1) | 0;
    $99 = HEAP16[$98 >> 1] | 0;
    $100 = $97 + ($_65 << 1) | 0;
    $101 = $cur3_0_lcssa >>> 0 < $100 >>> 0;
    if ($101) {
      $cur3_166 = $cur3_0_lcssa;
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 15:
    HEAP16[$cur3_166 >> 1] = $99;
    $102 = $cur3_166 + 2 | 0;
    $103 = $102 >>> 0 < $100 >>> 0;
    if ($103) {
      $cur3_166 = $102;
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    _FT_Stream_ExitFrame($stream);
    $104 = $num_longs_2 & 65535;
    if ($3) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    $106 = $face + 334 | 0;
    HEAP16[$106 >> 1] = $104;
    label = 19;
    break;
   case 18:
    $108 = $face + 250 | 0;
    HEAP16[$108 >> 1] = $104;
    label = 19;
    break;
   case 19:
    $110 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $110 | 0;
  }
  return 0;
}
function _tt_face_load_eblc($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $or_cond = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $count_083 = 0, $strike_082 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $count2_078 = 0, $strike1_077 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $count23_070 = 0, $range_069 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $count23_172 = 0, $range_171 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $97 = 0, $98 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 612 | 0;
    HEAP32[$3 >> 2] = 0;
    $4 = $face + 508 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5;
    $7 = FUNCTION_TABLE_iiiii[$6 & 1023]($face, 1161972803, $stream, 0) | 0;
    HEAP32[$error >> 2] = $7;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = HEAP32[$4 >> 2] | 0;
    $11 = $10;
    $12 = FUNCTION_TABLE_iiiii[$11 & 1023]($face, 1651273571, $stream, 0) | 0;
    HEAP32[$error >> 2] = $12;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 3;
      break;
    } else {
      label = 29;
      break;
    }
   case 3:
    $14 = _FT_Stream_Pos($stream) | 0;
    $15 = _FT_Stream_EnterFrame($stream, 8) | 0;
    HEAP32[$error >> 2] = $15;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 4;
      break;
    } else {
      label = 29;
      break;
    }
   case 4:
    $18 = _FT_Stream_GetLong($stream) | 0;
    $19 = _FT_Stream_GetLong($stream) | 0;
    _FT_Stream_ExitFrame($stream);
    $20 = ($18 | 0) != 131072;
    $21 = $19 >>> 0 > 65535;
    $or_cond = $20 | $21;
    if ($or_cond) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    HEAP32[$error >> 2] = 3;
    label = 29;
    break;
   case 6:
    $24 = _ft_mem_realloc($2, 48, 0, $19, 0, $error) | 0;
    $25 = $24;
    $26 = $face + 616 | 0;
    HEAP32[$26 >> 2] = $25;
    $27 = HEAP32[$error >> 2] | 0;
    $28 = ($27 | 0) == 0;
    if ($28) {
      label = 7;
      break;
    } else {
      label = 29;
      break;
    }
   case 7:
    HEAP32[$3 >> 2] = $19;
    $30 = HEAP32[$26 >> 2] | 0;
    $31 = $19 * 48 & -1;
    $32 = _FT_Stream_EnterFrame($stream, $31) | 0;
    HEAP32[$error >> 2] = $32;
    $33 = ($32 | 0) == 0;
    if ($33) {
      label = 8;
      break;
    } else {
      label = 29;
      break;
    }
   case 8:
    $34 = ($19 | 0) == 0;
    if ($34) {
      label = 9;
      break;
    } else {
      $strike_082 = $30;
      $count_083 = $19;
      label = 10;
      break;
    }
   case 9:
    _FT_Stream_ExitFrame($stream);
    label = 29;
    break;
   case 10:
    $35 = $strike_082;
    $36 = _FT_Stream_ReadFields($stream, 5244100, $35) | 0;
    HEAP32[$error >> 2] = $36;
    $37 = ($36 | 0) == 0;
    if ($37) {
      label = 11;
      break;
    } else {
      label = 15;
      break;
    }
   case 11:
    $39 = $strike_082 + 16 | 0;
    $40 = _FT_Stream_ReadFields($stream, 5244148, $39) | 0;
    HEAP32[$error >> 2] = $40;
    $41 = ($40 | 0) == 0;
    if ($41) {
      label = 12;
      break;
    } else {
      label = 15;
      break;
    }
   case 12:
    $43 = $strike_082 + 28 | 0;
    $44 = _FT_Stream_ReadFields($stream, 5244148, $43) | 0;
    HEAP32[$error >> 2] = $44;
    $45 = ($44 | 0) == 0;
    if ($45) {
      label = 13;
      break;
    } else {
      label = 15;
      break;
    }
   case 13:
    $47 = _FT_Stream_ReadFields($stream, 5244120, $35) | 0;
    HEAP32[$error >> 2] = $47;
    $48 = ($47 | 0) == 0;
    if ($48) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $50 = $count_083 - 1 | 0;
    $51 = $strike_082 + 48 | 0;
    $52 = ($50 | 0) == 0;
    if ($52) {
      label = 15;
      break;
    } else {
      $strike_082 = $51;
      $count_083 = $50;
      label = 10;
      break;
    }
   case 15:
    _FT_Stream_ExitFrame($stream);
    $53 = ($19 | 0) == 0;
    if ($53) {
      label = 29;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $54 = HEAP32[$26 >> 2] | 0;
    $strike1_077 = $54;
    $count2_078 = $19;
    label = 17;
    break;
   case 17:
    $56 = $strike1_077 | 0;
    $57 = HEAP32[$56 >> 2] | 0;
    $58 = $strike1_077 + 8 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = $59 + $14 | 0;
    $61 = _FT_Stream_Seek($stream, $60) | 0;
    HEAP32[$error >> 2] = $61;
    $62 = ($61 | 0) == 0;
    if ($62) {
      label = 18;
      break;
    } else {
      label = 29;
      break;
    }
   case 18:
    $64 = HEAP32[$56 >> 2] | 0;
    $65 = $64 << 3;
    $66 = _FT_Stream_EnterFrame($stream, $65) | 0;
    HEAP32[$error >> 2] = $66;
    $67 = ($66 | 0) == 0;
    if ($67) {
      label = 19;
      break;
    } else {
      label = 29;
      break;
    }
   case 19:
    $69 = HEAP32[$56 >> 2] | 0;
    $70 = _ft_mem_realloc($2, 40, 0, $69, 0, $error) | 0;
    $71 = $70;
    $72 = $strike1_077 + 4 | 0;
    HEAP32[$72 >> 2] = $71;
    $73 = HEAP32[$error >> 2] | 0;
    $74 = ($73 | 0) == 0;
    if ($74) {
      label = 20;
      break;
    } else {
      label = 29;
      break;
    }
   case 20:
    $75 = ($57 | 0) == 0;
    if ($75) {
      label = 22;
      break;
    } else {
      $range_069 = $71;
      $count23_070 = $57;
      label = 21;
      break;
    }
   case 21:
    $76 = _FT_Stream_GetShort($stream) | 0;
    $77 = $range_069 | 0;
    HEAP16[$77 >> 1] = $76;
    $78 = _FT_Stream_GetShort($stream) | 0;
    $79 = $range_069 + 2 | 0;
    HEAP16[$79 >> 1] = $78;
    $80 = HEAP32[$58 >> 2] | 0;
    $81 = $80 + $14 | 0;
    $82 = _FT_Stream_GetLong($stream) | 0;
    $83 = $81 + $82 | 0;
    $84 = $range_069 + 36 | 0;
    HEAP32[$84 >> 2] = $83;
    $85 = $count23_070 - 1 | 0;
    $86 = $range_069 + 40 | 0;
    $87 = ($85 | 0) == 0;
    if ($87) {
      label = 22;
      break;
    } else {
      $range_069 = $86;
      $count23_070 = $85;
      label = 21;
      break;
    }
   case 22:
    _FT_Stream_ExitFrame($stream);
    $88 = HEAP32[$56 >> 2] | 0;
    $89 = ($88 | 0) == 0;
    if ($89) {
      label = 28;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $90 = HEAP32[$72 >> 2] | 0;
    $range_171 = $90;
    $count23_172 = $88;
    label = 24;
    break;
   case 24:
    $92 = $range_171 + 36 | 0;
    $93 = HEAP32[$92 >> 2] | 0;
    $94 = _FT_Stream_Seek($stream, $93) | 0;
    HEAP32[$error >> 2] = $94;
    $95 = ($94 | 0) == 0;
    if ($95) {
      label = 25;
      break;
    } else {
      label = 29;
      break;
    }
   case 25:
    $97 = _FT_Stream_EnterFrame($stream, 8) | 0;
    HEAP32[$error >> 2] = $97;
    $98 = ($97 | 0) == 0;
    if ($98) {
      label = 26;
      break;
    } else {
      label = 29;
      break;
    }
   case 26:
    $100 = _FT_Stream_GetShort($stream) | 0;
    $101 = $range_171 + 4 | 0;
    HEAP16[$101 >> 1] = $100;
    $102 = _FT_Stream_GetShort($stream) | 0;
    $103 = $range_171 + 6 | 0;
    HEAP16[$103 >> 1] = $102;
    $104 = _FT_Stream_GetLong($stream) | 0;
    $105 = $range_171 + 8 | 0;
    HEAP32[$105 >> 2] = $104;
    _FT_Stream_ExitFrame($stream);
    $106 = _Load_SBit_Range($range_171, $stream) | 0;
    HEAP32[$error >> 2] = $106;
    $107 = ($106 | 0) == 0;
    if ($107) {
      label = 27;
      break;
    } else {
      label = 29;
      break;
    }
   case 27:
    $109 = $count23_172 - 1 | 0;
    $110 = $range_171 + 40 | 0;
    $111 = ($109 | 0) == 0;
    if ($111) {
      label = 28;
      break;
    } else {
      $range_171 = $110;
      $count23_172 = $109;
      label = 24;
      break;
    }
   case 28:
    $112 = $count2_078 - 1 | 0;
    $113 = $strike1_077 + 48 | 0;
    $114 = ($112 | 0) == 0;
    if ($114) {
      label = 29;
      break;
    } else {
      $strike1_077 = $113;
      $count2_078 = $112;
      label = 17;
      break;
    }
   case 29:
    $115 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $115 | 0;
  }
  return 0;
}
function _tt_face_free_eblc($face) {
  $face = $face | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $strike_026 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $or_cond = 0, $range_024 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 616 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $face + 612 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $4 + ($6 * 48 & -1) | 0;
    $8 = ($4 | 0) == 0;
    if ($8) {
      label = 7;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = ($6 | 0) > 0;
    if ($9) {
      $strike_026 = $4;
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 3:
    $10 = $strike_026 + 4 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $strike_026 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $11 + ($13 * 40 & -1) | 0;
    $15 = ($11 | 0) != 0;
    $16 = ($13 | 0) > 0;
    $or_cond = $15 & $16;
    if ($or_cond) {
      $range_024 = $11;
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $17 = $range_024 + 28 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $18;
    _ft_mem_free($2, $19);
    HEAP32[$17 >> 2] = 0;
    $20 = $range_024 + 32 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $21;
    _ft_mem_free($2, $22);
    HEAP32[$20 >> 2] = 0;
    $23 = $range_024 + 40 | 0;
    $24 = $23 >>> 0 < $14 >>> 0;
    if ($24) {
      $range_024 = $23;
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $25 = HEAP32[$10 >> 2] | 0;
    $26 = $25;
    _ft_mem_free($2, $26);
    HEAP32[$10 >> 2] = 0;
    HEAP32[$12 >> 2] = 0;
    $27 = $strike_026 + 48 | 0;
    $28 = $27 >>> 0 < $7 >>> 0;
    if ($28) {
      $strike_026 = $27;
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $29 = HEAP32[$3 >> 2] | 0;
    $30 = $29;
    _ft_mem_free($2, $30);
    HEAP32[$3 >> 2] = 0;
    label = 7;
    break;
   case 7:
    HEAP32[$5 >> 2] = 0;
    return;
  }
}
function _tt_face_set_sbit_strike($face, $req, $astrike_index) {
  $face = $face | 0;
  $req = $req | 0;
  $astrike_index = $astrike_index | 0;
  return _FT_Match_Size($face | 0, $req, 0, $astrike_index) | 0;
}
function _tt_face_load_strike_metrics($face, $strike_index, $metrics) {
  $face = $face | 0;
  $strike_index = $strike_index | 0;
  $metrics = $metrics | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 612 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 >>> 0 > $strike_index >>> 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $_0 = 6;
      label = 3;
      break;
    }
   case 2:
    $5 = $face + 616 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + ($strike_index * 48 & -1) + 44 | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 & 255;
    $10 = $metrics | 0;
    HEAP16[$10 >> 1] = $9;
    $11 = $6 + ($strike_index * 48 & -1) + 45 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $12 & 255;
    $14 = $metrics + 2 | 0;
    HEAP16[$14 >> 1] = $13;
    $15 = $6 + ($strike_index * 48 & -1) + 16 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 << 24 >> 24;
    $18 = $17 << 6;
    $19 = $metrics + 12 | 0;
    HEAP32[$19 >> 2] = $18;
    $20 = $6 + ($strike_index * 48 & -1) + 17 | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $21 << 24 >> 24;
    $23 = $22 << 6;
    $24 = $metrics + 16 | 0;
    HEAP32[$24 >> 2] = $23;
    $25 = $6 + ($strike_index * 48 & -1) + 22 | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 << 24 >> 24;
    $28 = $6 + ($strike_index * 48 & -1) + 18 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $29 & 255;
    $31 = $30 + $27 | 0;
    $32 = $6 + ($strike_index * 48 & -1) + 23 | 0;
    $33 = HEAP8[$32] | 0;
    $34 = $33 << 24 >> 24;
    $35 = $31 + $34 | 0;
    $36 = $35 << 6;
    $37 = $metrics + 24 | 0;
    HEAP32[$37 >> 2] = $36;
    $38 = HEAP32[$19 >> 2] | 0;
    $39 = HEAP32[$24 >> 2] | 0;
    $40 = $38 - $39 | 0;
    $41 = $metrics + 20 | 0;
    HEAP32[$41 >> 2] = $40;
    $_0 = 0;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _tt_face_get_metrics($face, $vertical, $gindex, $abearing, $aadvance) {
  $face = $face | 0;
  $vertical = $vertical | 0;
  $gindex = $gindex | 0;
  $abearing = $abearing | 0;
  $aadvance = $aadvance | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_sink = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $storemerge_in = 0, $storemerge = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 300 | 0;
    $2 = $1;
    $3 = $face + 216 | 0;
    $4 = $3;
    $5 = $vertical << 24 >> 24 != 0;
    $_sink = $5 ? $2 : $4;
    $6 = $_sink + 34 | 0;
    $7 = $6;
    $8 = HEAP16[$7 >> 1] | 0;
    $9 = $8 & 65535;
    $10 = $8 << 16 >> 16 == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $12 = $_sink + 36 | 0;
    $13 = $12;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $17 = $face + 264 | 0;
    $18 = HEAP16[$17 >> 1] | 0;
    $19 = $18 & 65535;
    $20 = $19 >>> 0 > $gindex >>> 0;
    if ($20) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    HEAP16[$aadvance >> 1] = 0;
    HEAP16[$abearing >> 1] = 0;
    label = 9;
    break;
   case 5:
    $23 = $9 >>> 0 > $gindex >>> 0;
    if ($23) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $25 = $14;
    $26 = $25 + ($gindex << 2) + 2 | 0;
    $27 = HEAP16[$26 >> 1] | 0;
    HEAP16[$abearing >> 1] = $27;
    $28 = $25 + ($gindex << 2) | 0;
    $storemerge_in = $28;
    label = 8;
    break;
   case 7:
    $30 = $gindex - $9 | 0;
    $31 = $_sink + 40 | 0;
    $32 = $31;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $33;
    $35 = $34 + ($30 << 1) | 0;
    $36 = HEAP16[$35 >> 1] | 0;
    HEAP16[$abearing >> 1] = $36;
    $37 = $9 - 1 | 0;
    $38 = HEAP32[$13 >> 2] | 0;
    $39 = $38;
    $40 = $39 + ($37 << 2) | 0;
    $storemerge_in = $40;
    label = 8;
    break;
   case 8:
    $storemerge = HEAP16[$storemerge_in >> 1] | 0;
    HEAP16[$aadvance >> 1] = $storemerge;
    label = 9;
    break;
   case 9:
    return 0;
  }
  return 0;
}
function _Load_SBit_Range($range, $stream) {
  $range = $range | 0;
  $stream = $stream | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $n_029 = 0, $39 = 0, $41 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $exitcond = 0, $52 = 0, $54 = 0, $56 = 0, $57 = 0, $59 = 0, $62 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $range + 4 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 & 65535;
    if (($5 | 0) == 1 | ($5 | 0) == 3) {
      label = 2;
      break;
    } else if (($5 | 0) == 2) {
      label = 13;
      break;
    } else if (($5 | 0) == 4) {
      label = 14;
      break;
    } else if (($5 | 0) == 5) {
      label = 15;
      break;
    } else {
      label = 17;
      break;
    }
   case 2:
    $7 = $range + 2 | 0;
    $8 = HEAP16[$7 >> 1] | 0;
    $9 = $range | 0;
    $10 = HEAP16[$9 >> 1] | 0;
    $11 = ($8 & 65535) < ($10 & 65535);
    if ($11) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    HEAP32[$error >> 2] = 3;
    label = 18;
    break;
   case 4:
    $14 = HEAP16[$3 >> 1] | 0;
    $15 = $8 & 65535;
    $16 = $10 & 65535;
    $17 = $14 << 16 >> 16 == 1;
    $18 = $15 - $16 | 0;
    $19 = $18 + 1 | 0;
    $20 = $range + 24 | 0;
    HEAP32[$20 >> 2] = $19;
    $21 = $18 + 2 | 0;
    $22 = _ft_mem_realloc($2, 4, 0, $21, 0, $error) | 0;
    $23 = $22;
    $24 = $range + 28 | 0;
    HEAP32[$24 >> 2] = $23;
    $25 = HEAP32[$error >> 2] | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 5;
      break;
    } else {
      label = 18;
      break;
    }
   case 5:
    $28 = $17 ? 4 : 2;
    $29 = Math_imul($28, $21);
    $30 = _FT_Stream_EnterFrame($stream, $29) | 0;
    HEAP32[$error >> 2] = $30;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 6;
      break;
    } else {
      label = 18;
      break;
    }
   case 6:
    $32 = ($21 | 0) == 0;
    if ($32) {
      label = 12;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $33 = $range + 8 | 0;
    $34 = $8 & 65535;
    $35 = $34 + 2 | 0;
    $36 = $10 & 65535;
    $37 = $35 - $36 | 0;
    $n_029 = 0;
    label = 8;
    break;
   case 8:
    $39 = HEAP32[$33 >> 2] | 0;
    if ($17) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $41 = _FT_Stream_GetLong($stream) | 0;
    $46 = $41;
    label = 11;
    break;
   case 10:
    $43 = _FT_Stream_GetShort($stream) | 0;
    $44 = $43 & 65535;
    $46 = $44;
    label = 11;
    break;
   case 11:
    $47 = $46 + $39 | 0;
    $48 = HEAP32[$24 >> 2] | 0;
    $49 = $48 + ($n_029 << 2) | 0;
    HEAP32[$49 >> 2] = $47;
    $50 = $n_029 + 1 | 0;
    $exitcond = ($50 | 0) == ($37 | 0);
    if ($exitcond) {
      label = 12;
      break;
    } else {
      $n_029 = $50;
      label = 8;
      break;
    }
   case 12:
    _FT_Stream_ExitFrame($stream);
    label = 18;
    break;
   case 13:
    $52 = _Load_SBit_Const_Metrics($range, $stream) | 0;
    HEAP32[$error >> 2] = $52;
    label = 18;
    break;
   case 14:
    $54 = _Load_SBit_Range_Codes($range, $stream, 1) | 0;
    HEAP32[$error >> 2] = $54;
    label = 18;
    break;
   case 15:
    $56 = _Load_SBit_Const_Metrics($range, $stream) | 0;
    HEAP32[$error >> 2] = $56;
    $57 = ($56 | 0) == 0;
    if ($57) {
      label = 16;
      break;
    } else {
      label = 18;
      break;
    }
   case 16:
    $59 = _Load_SBit_Range_Codes($range, $stream, 0) | 0;
    HEAP32[$error >> 2] = $59;
    label = 18;
    break;
   case 17:
    HEAP32[$error >> 2] = 3;
    label = 18;
    break;
   case 18:
    $62 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $62 | 0;
  }
  return 0;
}
function _Load_SBit_Const_Metrics($range, $stream) {
  $range = $range | 0;
  $stream = $stream | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = _FT_Stream_ReadLong($stream, $error) | 0;
    $2 = $range + 12 | 0;
    HEAP32[$2 >> 2] = $1;
    $3 = HEAP32[$error >> 2] | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 2;
      break;
    } else {
      $_0 = $3;
      label = 3;
      break;
    }
   case 2:
    $6 = $range + 16 | 0;
    $7 = _FT_Stream_ReadFields($stream, 5249812, $6) | 0;
    HEAP32[$error >> 2] = $7;
    $8 = ($7 | 0) != 0;
    $9 = $8 & 1;
    $_0 = $9;
    label = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _Load_SBit_Range_Codes($range, $stream, $load_offsets) {
  $range = $range | 0;
  $stream = $stream | 0;
  $load_offsets = $load_offsets | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $18 = 0, $size_0 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $n_022 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $exitcond = 0, $45 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _FT_Stream_ReadLong($stream, $error) | 0;
    $4 = HEAP32[$error >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      label = 14;
      break;
    }
   case 2:
    $7 = $range + 24 | 0;
    HEAP32[$7 >> 2] = $3;
    $8 = $load_offsets << 24 >> 24 != 0;
    if ($8) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $10 = _ft_mem_realloc($2, 4, 0, $3, 0, $error) | 0;
    $11 = $10;
    $12 = $range + 28 | 0;
    HEAP32[$12 >> 2] = $11;
    $13 = HEAP32[$error >> 2] | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 4;
      break;
    } else {
      label = 14;
      break;
    }
   case 4:
    $16 = $3 << 2;
    $size_0 = $16;
    label = 6;
    break;
   case 5:
    $18 = $3 << 1;
    $size_0 = $18;
    label = 6;
    break;
   case 6:
    $20 = _ft_mem_realloc($2, 2, 0, $3, 0, $error) | 0;
    $21 = $20;
    $22 = $range + 32 | 0;
    HEAP32[$22 >> 2] = $21;
    $23 = HEAP32[$error >> 2] | 0;
    $24 = ($23 | 0) == 0;
    if ($24) {
      label = 7;
      break;
    } else {
      label = 14;
      break;
    }
   case 7:
    $26 = _FT_Stream_EnterFrame($stream, $size_0) | 0;
    HEAP32[$error >> 2] = $26;
    $27 = ($26 | 0) == 0;
    if ($27) {
      label = 8;
      break;
    } else {
      label = 14;
      break;
    }
   case 8:
    $28 = ($3 | 0) == 0;
    if ($28) {
      label = 13;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $29 = $range + 8 | 0;
    $30 = $range + 28 | 0;
    $n_022 = 0;
    label = 10;
    break;
   case 10:
    $32 = _FT_Stream_GetShort($stream) | 0;
    $33 = HEAP32[$22 >> 2] | 0;
    $34 = $33 + ($n_022 << 1) | 0;
    HEAP16[$34 >> 1] = $32;
    if ($8) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $36 = HEAP32[$29 >> 2] | 0;
    $37 = _FT_Stream_GetShort($stream) | 0;
    $38 = $37 & 65535;
    $39 = $38 + $36 | 0;
    $40 = HEAP32[$30 >> 2] | 0;
    $41 = $40 + ($n_022 << 2) | 0;
    HEAP32[$41 >> 2] = $39;
    label = 12;
    break;
   case 12:
    $43 = $n_022 + 1 | 0;
    $exitcond = ($43 | 0) == ($3 | 0);
    if ($exitcond) {
      label = 13;
      break;
    } else {
      $n_022 = $43;
      label = 10;
      break;
    }
   case 13:
    _FT_Stream_ExitFrame($stream);
    label = 14;
    break;
   case 14:
    $45 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $45 | 0;
  }
  return 0;
}
function _check_table_dir($sfnt, $stream) {
  $sfnt = $sfnt | 0;
  $stream = $stream | 0;
  var $error = 0, $table = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $nn_050 = 0, $valid_entries_049 = 0, $has_meta_048 = 0, $has_sing_047 = 0, $has_head_046 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $_has_meta_0 = 0, $has_head_1 = 0, $has_sing_1 = 0, $has_meta_1 = 0, $valid_entries_1 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $valid_entries_037 = 0, $has_meta_032 = 0, $has_sing_027 = 0, $has_head_022 = 0, $58 = 0, $61 = 0, $63 = 0, $64 = 0, $or_cond = 0, $67 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 20 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $table = __stackBase__ + 4 | 0;
    $1 = $sfnt + 12 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 12 | 0;
    $4 = _FT_Stream_Seek($stream, $3) | 0;
    HEAP32[$error >> 2] = $4;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      label = 24;
      break;
    }
   case 2:
    $6 = $sfnt + 4 | 0;
    $7 = HEAP16[$6 >> 1] | 0;
    $8 = $7 << 16 >> 16 == 0;
    if ($8) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    HEAP16[$6 >> 1] = 0;
    label = 19;
    break;
   case 4:
    $9 = $table;
    $10 = $table + 8 | 0;
    $11 = $table + 12 | 0;
    $12 = $stream + 4 | 0;
    $13 = $table | 0;
    $14 = $2 + 28 | 0;
    $has_head_046 = 0;
    $has_sing_047 = 0;
    $has_meta_048 = 0;
    $valid_entries_049 = 0;
    $nn_050 = 0;
    $16 = 0;
    label = 5;
    break;
   case 5:
    $17 = _FT_Stream_ReadFields($stream, 5313996, $9) | 0;
    HEAP32[$error >> 2] = $17;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $20 = $nn_050 - 1 & 65535;
    HEAP16[$6 >> 1] = $20;
    $has_head_022 = $has_head_046;
    $has_sing_027 = $has_sing_047;
    $has_meta_032 = $has_meta_048;
    $valid_entries_037 = $valid_entries_049;
    label = 18;
    break;
   case 7:
    $22 = HEAP32[$10 >> 2] | 0;
    $23 = HEAP32[$11 >> 2] | 0;
    $24 = $23 + $22 | 0;
    $25 = HEAP32[$12 >> 2] | 0;
    $26 = $24 >>> 0 > $25 >>> 0;
    if ($26) {
      $valid_entries_1 = $valid_entries_049;
      $has_meta_1 = $has_meta_048;
      $has_sing_1 = $has_sing_047;
      $has_head_1 = $has_head_046;
      label = 17;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $28 = $valid_entries_049 + 1 & 65535;
    $29 = HEAP32[$13 >> 2] | 0;
    if (($29 | 0) == 1751474532 | ($29 | 0) == 1651008868) {
      label = 9;
      break;
    } else if (($29 | 0) == 1397313095) {
      $valid_entries_1 = $28;
      $has_meta_1 = $has_meta_048;
      $has_sing_1 = 1;
      $has_head_1 = $has_head_046;
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 9:
    $31 = HEAP32[$11 >> 2] | 0;
    $32 = $31 >>> 0 < 54;
    if ($32) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    HEAP32[$error >> 2] = 142;
    label = 24;
    break;
   case 11:
    $35 = HEAP32[$10 >> 2] | 0;
    $36 = $35 + 12 | 0;
    $37 = _FT_Stream_Seek($stream, $36) | 0;
    HEAP32[$error >> 2] = $37;
    $38 = ($37 | 0) == 0;
    if ($38) {
      label = 12;
      break;
    } else {
      label = 24;
      break;
    }
   case 12:
    $40 = _FT_Stream_ReadLong($stream, $error) | 0;
    $41 = HEAP32[$error >> 2] | 0;
    $42 = ($41 | 0) == 0;
    if ($42) {
      label = 13;
      break;
    } else {
      label = 24;
      break;
    }
   case 13:
    $44 = ($40 | 0) == 1594834165;
    if ($44) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    HEAP32[$error >> 2] = 142;
    label = 24;
    break;
   case 15:
    $47 = $16 << 4;
    $48 = $14 + $47 | 0;
    $49 = _FT_Stream_Seek($stream, $48) | 0;
    HEAP32[$error >> 2] = $49;
    $50 = ($49 | 0) == 0;
    if ($50) {
      $valid_entries_1 = $28;
      $has_meta_1 = $has_meta_048;
      $has_sing_1 = $has_sing_047;
      $has_head_1 = 1;
      label = 17;
      break;
    } else {
      label = 24;
      break;
    }
   case 16:
    $52 = ($29 | 0) == 1296389185;
    $_has_meta_0 = $52 ? 1 : $has_meta_048;
    $valid_entries_1 = $28;
    $has_meta_1 = $_has_meta_0;
    $has_sing_1 = $has_sing_047;
    $has_head_1 = $has_head_046;
    label = 17;
    break;
   case 17:
    $54 = $nn_050 + 1 & 65535;
    $55 = $54 & 65535;
    $56 = HEAP16[$6 >> 1] | 0;
    $57 = ($54 & 65535) < ($56 & 65535);
    if ($57) {
      $has_head_046 = $has_head_1;
      $has_sing_047 = $has_sing_1;
      $has_meta_048 = $has_meta_1;
      $valid_entries_049 = $valid_entries_1;
      $nn_050 = $54;
      $16 = $55;
      label = 5;
      break;
    } else {
      $has_head_022 = $has_head_1;
      $has_sing_027 = $has_sing_1;
      $has_meta_032 = $has_meta_1;
      $valid_entries_037 = $valid_entries_1;
      label = 18;
      break;
    }
   case 18:
    HEAP16[$6 >> 1] = $valid_entries_037;
    $58 = $valid_entries_037 << 16 >> 16 == 0;
    if ($58) {
      label = 19;
      break;
    } else {
      label = 20;
      break;
    }
   case 19:
    HEAP32[$error >> 2] = 2;
    label = 24;
    break;
   case 20:
    $61 = ($has_head_022 | 0) == 0;
    if ($61) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    $63 = ($has_sing_027 | 0) == 0;
    $64 = ($has_meta_032 | 0) == 0;
    $or_cond = $63 | $64;
    if ($or_cond) {
      label = 23;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    HEAP32[$error >> 2] = 0;
    label = 24;
    break;
   case 23:
    HEAP32[$error >> 2] = 142;
    label = 24;
    break;
   case 24:
    $67 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $67 | 0;
  }
  return 0;
}
function _Load_SBit_Image($strike, $range, $ebdt_pos, $glyph_offset, $slot, $x_offset, $y_offset, $stream, $metrics, $depth) {
  $strike = $strike | 0;
  $range = $range | 0;
  $ebdt_pos = $ebdt_pos | 0;
  $glyph_offset = $glyph_offset | 0;
  $slot = $slot | 0;
  $x_offset = $x_offset | 0;
  $y_offset = $y_offset | 0;
  $stream = $stream | 0;
  $metrics = $metrics | 0;
  $depth = $depth | 0;
  var $error = 0, $elem_range = 0, $elem_metrics = 0, $elem_offset = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $56 = 0, $57 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $66 = 0, $67 = 0, $70 = 0, $71 = 0, $72 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $count_071 = 0, $comp_070 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $count_169 = 0, $comp_168 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $115 = 0, $116 = 0, $117 = 0, $119 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 20 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $elem_range = __stackBase__ + 4 | 0;
    $elem_metrics = __stackBase__ + 8 | 0;
    $elem_offset = __stackBase__ + 16 | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $slot + 76 | 0;
    $4 = $glyph_offset + $ebdt_pos | 0;
    $5 = _FT_Stream_Seek($stream, $4) | 0;
    HEAP32[$error >> 2] = $5;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 27;
      break;
    }
   case 2:
    $8 = _tt_load_sbit_metrics($stream, $range, $metrics) | 0;
    HEAP32[$error >> 2] = $8;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 3;
      break;
    } else {
      label = 27;
      break;
    }
   case 3:
    $11 = ($depth | 0) == 0;
    if ($11) {
      label = 4;
      break;
    } else {
      label = 11;
      break;
    }
   case 4:
    $13 = $metrics + 1 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 & 255;
    $16 = $slot + 80 | 0;
    HEAP32[$16 >> 2] = $15;
    $17 = $metrics | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $18 & 255;
    $20 = $3 | 0;
    HEAP32[$20 >> 2] = $19;
    $21 = $strike + 46 | 0;
    $22 = HEAP8[$21] | 0;
    $23 = $22 & 255;
    if (($23 | 0) == 1) {
      label = 5;
      break;
    } else if (($23 | 0) == 2) {
      label = 6;
      break;
    } else if (($23 | 0) == 4) {
      label = 7;
      break;
    } else if (($23 | 0) == 8) {
      label = 8;
      break;
    } else {
      $_0 = 3;
      label = 28;
      break;
    }
   case 5:
    $25 = $slot + 94 | 0;
    HEAP8[$25] = 1;
    $26 = HEAP32[$16 >> 2] | 0;
    $27 = $26 + 7 | 0;
    $28 = $27 >> 3;
    $29 = $slot + 84 | 0;
    HEAP32[$29 >> 2] = $28;
    label = 9;
    break;
   case 6:
    $31 = $slot + 94 | 0;
    HEAP8[$31] = 3;
    $32 = HEAP32[$16 >> 2] | 0;
    $33 = $32 + 3 | 0;
    $34 = $33 >> 2;
    $35 = $slot + 84 | 0;
    HEAP32[$35 >> 2] = $34;
    label = 9;
    break;
   case 7:
    $37 = $slot + 94 | 0;
    HEAP8[$37] = 4;
    $38 = HEAP32[$16 >> 2] | 0;
    $39 = $38 + 1 | 0;
    $40 = $39 >> 1;
    $41 = $slot + 84 | 0;
    HEAP32[$41 >> 2] = $40;
    label = 9;
    break;
   case 8:
    $43 = $slot + 94 | 0;
    HEAP8[$43] = 2;
    $44 = HEAP32[$16 >> 2] | 0;
    $45 = $slot + 84 | 0;
    HEAP32[$45 >> 2] = $44;
    label = 9;
    break;
   case 9:
    $47 = HEAP32[$20 >> 2] | 0;
    $48 = $slot + 84 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = Math_imul($49, $47);
    $51 = ($50 | 0) == 0;
    if ($51) {
      label = 27;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $53 = _ft_glyphslot_alloc_bitmap($slot, $50) | 0;
    HEAP32[$error >> 2] = $53;
    $54 = ($53 | 0) == 0;
    if ($54) {
      label = 11;
      break;
    } else {
      label = 27;
      break;
    }
   case 11:
    $56 = $range + 6 | 0;
    $57 = HEAP16[$56 >> 1] | 0;
    $58 = $57 & 65535;
    if (($58 | 0) == 1 | ($58 | 0) == 2 | ($58 | 0) == 5 | ($58 | 0) == 6 | ($58 | 0) == 7) {
      label = 12;
      break;
    } else if (($58 | 0) == 8) {
      label = 13;
      break;
    } else if (($58 | 0) == 9) {
      label = 15;
      break;
    } else {
      $_0 = 3;
      label = 28;
      break;
    }
   case 12:
    $60 = $strike + 46 | 0;
    $61 = HEAP8[$60] | 0;
    $62 = $61 & 255;
    $63 = HEAP16[$56 >> 1] | 0;
    $64 = _Load_SBit_Single($3, $x_offset, $y_offset, $62, $63, $metrics, $stream) | 0;
    $_0 = $64;
    label = 28;
    break;
   case 13:
    $66 = _FT_Stream_Skip($stream, 1) | 0;
    HEAP32[$error >> 2] = $66;
    $67 = ($66 | 0) == 0;
    if ($67) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    HEAP32[$error >> 2] = 83;
    label = 27;
    break;
   case 15:
    $70 = _FT_Stream_ReadShort($stream, $error) | 0;
    $71 = HEAP32[$error >> 2] | 0;
    $72 = ($71 | 0) == 0;
    if ($72) {
      label = 16;
      break;
    } else {
      label = 27;
      break;
    }
   case 16:
    $74 = $70 & 65535;
    $75 = _ft_mem_realloc($2, 4, 0, $74, 0, $error) | 0;
    $76 = $75;
    $77 = HEAP32[$error >> 2] | 0;
    $78 = ($77 | 0) == 0;
    if ($78) {
      label = 17;
      break;
    } else {
      label = 27;
      break;
    }
   case 17:
    $80 = $74 << 2;
    $81 = _FT_Stream_EnterFrame($stream, $80) | 0;
    HEAP32[$error >> 2] = $81;
    $82 = ($81 | 0) == 0;
    if ($82) {
      label = 18;
      break;
    } else {
      label = 26;
      break;
    }
   case 18:
    $83 = $70 << 16 >> 16 == 0;
    if ($83) {
      label = 19;
      break;
    } else {
      $comp_070 = $76;
      $count_071 = $70;
      label = 20;
      break;
    }
   case 19:
    _FT_Stream_ExitFrame($stream);
    label = 26;
    break;
   case 20:
    $84 = _FT_Stream_GetShort($stream) | 0;
    $85 = $comp_070 | 0;
    HEAP16[$85 >> 1] = $84;
    $86 = _FT_Stream_GetChar($stream) | 0;
    $87 = $comp_070 + 2 | 0;
    HEAP8[$87] = $86;
    $88 = _FT_Stream_GetChar($stream) | 0;
    $89 = $comp_070 + 3 | 0;
    HEAP8[$89] = $88;
    $90 = $count_071 - 1 & 65535;
    $91 = $comp_070 + 4 | 0;
    $92 = $90 << 16 >> 16 == 0;
    if ($92) {
      label = 21;
      break;
    } else {
      $comp_070 = $91;
      $count_071 = $90;
      label = 20;
      break;
    }
   case 21:
    _FT_Stream_ExitFrame($stream);
    $93 = $70 << 16 >> 16 == 0;
    if ($93) {
      label = 26;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $94 = $depth + 1 | 0;
    $comp_168 = $76;
    $count_169 = $70;
    label = 23;
    break;
   case 23:
    $96 = $comp_168 | 0;
    $97 = HEAP16[$96 >> 1] | 0;
    $98 = $97 & 65535;
    $99 = _find_sbit_range($98, $strike, $elem_range, $elem_offset) | 0;
    HEAP32[$error >> 2] = $99;
    $100 = ($99 | 0) == 0;
    if ($100) {
      label = 24;
      break;
    } else {
      label = 26;
      break;
    }
   case 24:
    $102 = HEAP32[$elem_range >> 2] | 0;
    $103 = HEAP32[$elem_offset >> 2] | 0;
    $104 = $comp_168 + 2 | 0;
    $105 = HEAP8[$104] | 0;
    $106 = $105 << 24 >> 24;
    $107 = $106 + $x_offset | 0;
    $108 = $comp_168 + 3 | 0;
    $109 = HEAP8[$108] | 0;
    $110 = $109 << 24 >> 24;
    $111 = $110 + $y_offset | 0;
    $112 = _Load_SBit_Image($strike, $102, $ebdt_pos, $103, $slot, $107, $111, $stream, $elem_metrics, $94) | 0;
    HEAP32[$error >> 2] = $112;
    $113 = ($112 | 0) == 0;
    if ($113) {
      label = 25;
      break;
    } else {
      label = 26;
      break;
    }
   case 25:
    $115 = $count_169 - 1 & 65535;
    $116 = $comp_168 + 4 | 0;
    $117 = $115 << 16 >> 16 == 0;
    if ($117) {
      label = 26;
      break;
    } else {
      $comp_168 = $116;
      $count_169 = $115;
      label = 23;
      break;
    }
   case 26:
    _ft_mem_free($2, $75);
    label = 27;
    break;
   case 27:
    $119 = HEAP32[$error >> 2] | 0;
    $_0 = $119;
    label = 28;
    break;
   case 28:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _find_sbit_range($glyph_index, $strike, $arange, $aglyph_offset) {
  $glyph_index = $glyph_index | 0;
  $strike = $strike | 0;
  $arange = $arange | 0;
  $aglyph_offset = $aglyph_offset | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $or_cond = 0, $range_045 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $n_0 = 0, $50 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $75 = 0, $76 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $strike + 40 | 0;
    $2 = HEAP16[$1 >> 1] | 0;
    $3 = $2 & 65535;
    $4 = $3 >>> 0 > $glyph_index >>> 0;
    if ($4) {
      label = 17;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $strike + 42 | 0;
    $7 = HEAP16[$6 >> 1] | 0;
    $8 = $7 & 65535;
    $9 = $8 >>> 0 < $glyph_index >>> 0;
    if ($9) {
      label = 17;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = $strike + 4 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $strike | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $12 + ($14 * 40 & -1) | 0;
    $16 = ($12 | 0) != 0;
    $17 = ($14 | 0) > 0;
    $or_cond = $16 & $17;
    if ($or_cond) {
      $range_045 = $12;
      label = 4;
      break;
    } else {
      label = 17;
      break;
    }
   case 4:
    $18 = $range_045 | 0;
    $19 = HEAP16[$18 >> 1] | 0;
    $20 = $19 & 65535;
    $21 = $20 >>> 0 > $glyph_index >>> 0;
    if ($21) {
      label = 16;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $23 = $range_045 + 2 | 0;
    $24 = HEAP16[$23 >> 1] | 0;
    $25 = $24 & 65535;
    $26 = $25 >>> 0 < $glyph_index >>> 0;
    if ($26) {
      label = 16;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $28 = $glyph_index - $20 | 0;
    $29 = $range_045 + 4 | 0;
    $30 = HEAP16[$29 >> 1] | 0;
    $31 = $30 & 65535;
    if (($31 | 0) == 4 | ($31 | 0) == 5) {
      label = 7;
      break;
    } else if (($31 | 0) == 1 | ($31 | 0) == 3) {
      label = 8;
      break;
    } else if (($31 | 0) == 2) {
      label = 9;
      break;
    } else {
      label = 17;
      break;
    }
   case 7:
    $32 = $range_045 + 24 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $range_045 + 32 | 0;
    $n_0 = 0;
    label = 10;
    break;
   case 8:
    $36 = $28 & 65535;
    $37 = $range_045 + 28 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $38 + ($36 << 2) | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    HEAP32[$aglyph_offset >> 2] = $40;
    label = 15;
    break;
   case 9:
    $42 = $range_045 + 8 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $range_045 + 12 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = $28 & 65535;
    $47 = Math_imul($45, $46);
    $48 = $47 + $43 | 0;
    HEAP32[$aglyph_offset >> 2] = $48;
    label = 15;
    break;
   case 10:
    $50 = $n_0 >>> 0 < $33 >>> 0;
    if ($50) {
      label = 11;
      break;
    } else {
      label = 17;
      break;
    }
   case 11:
    $52 = HEAP32[$34 >> 2] | 0;
    $53 = $52 + ($n_0 << 1) | 0;
    $54 = HEAP16[$53 >> 1] | 0;
    $55 = $54 & 65535;
    $56 = ($55 | 0) == ($glyph_index | 0);
    $57 = $n_0 + 1 | 0;
    if ($56) {
      label = 12;
      break;
    } else {
      $n_0 = $57;
      label = 10;
      break;
    }
   case 12:
    $59 = HEAP16[$29 >> 1] | 0;
    $60 = $59 << 16 >> 16 == 4;
    if ($60) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    $62 = $range_045 + 28 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = $63 + ($n_0 << 2) | 0;
    $65 = HEAP32[$64 >> 2] | 0;
    HEAP32[$aglyph_offset >> 2] = $65;
    label = 15;
    break;
   case 14:
    $67 = $range_045 + 8 | 0;
    $68 = HEAP32[$67 >> 2] | 0;
    $69 = $range_045 + 12 | 0;
    $70 = HEAP32[$69 >> 2] | 0;
    $71 = Math_imul($70, $n_0);
    $72 = $71 + $68 | 0;
    HEAP32[$aglyph_offset >> 2] = $72;
    label = 15;
    break;
   case 15:
    HEAP32[$arange >> 2] = $range_045;
    $_0 = 0;
    label = 18;
    break;
   case 16:
    $75 = $range_045 + 40 | 0;
    $76 = $75 >>> 0 < $15 >>> 0;
    if ($76) {
      $range_045 = $75;
      label = 4;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    HEAP32[$arange >> 2] = 0;
    HEAP32[$aglyph_offset >> 2] = 0;
    $_0 = 6;
    label = 18;
    break;
   case 18:
    return $_0 | 0;
  }
  return 0;
}
function _blit_sbit($target, $source, $line_bits, $byte_padded, $x_offset, $y_offset, $source_height) {
  $target = $target | 0;
  $source = $source | 0;
  $line_bits = $line_bits | 0;
  $byte_padded = $byte_padded | 0;
  $x_offset = $x_offset | 0;
  $y_offset = $y_offset | 0;
  $source_height = $source_height | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $line_buff_0 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $x_offset_tr = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $line_bits_op = 0, $line_bits_op_op = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $scevgep = 0, $35 = 0, $36 = 0, $37 = 0, $indvars_iv = 0, $_058 = 0, $line_buff_157 = 0, $height_056 = 0, $acc_055 = 0, $loaded_054 = 0, $loaded_1 = 0, $cur_0 = 0, $count_0 = 0, $acc_1 = 0, $_1 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $loaded_2 = 0, $acc_2 = 0, $_2 = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $loaded_3 = 0, $cur_1 = 0, $count_1 = 0, $acc_3 = 0, $_3 = 0, $77 = 0, $79 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $loaded_4 = 0, $acc_4 = 0, $_4 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $111 = 0, $112 = 0, $113 = 0, $loaded_5 = 0, $acc_5 = 0, $_5 = 0, $loaded_5_ = 0, $acc_5_ = 0, $115 = 0, $116 = 0, $117 = 0, $scevgep6263 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $target + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $target + 12 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) < 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $line_buff_0 = $4;
      label = 3;
      break;
    }
   case 2:
    $7 = $target | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 - 1 | 0;
    $10 = -$2 | 0;
    $11 = Math_imul($9, $10);
    $12 = $4 + $11 | 0;
    $line_buff_0 = $12;
    label = 3;
    break;
   case 3:
    $14 = ($source_height | 0) > 0;
    if ($14) {
      label = 4;
      break;
    } else {
      label = 19;
      break;
    }
   case 4:
    $15 = Math_imul($2, $y_offset);
    $16 = $x_offset >> 3;
    $17 = $15 + $16 | 0;
    $18 = $line_buff_0 + $17 | 0;
    $x_offset_tr = $x_offset & 255;
    $19 = $x_offset_tr & 7;
    $20 = $19 & 255;
    $21 = 8 - $19 & 255;
    $22 = ($line_bits | 0) > 7;
    $23 = $line_bits - 8 | 0;
    $24 = $19 << 24 >> 24 == 0;
    $25 = $21 & 255;
    $26 = $21 & 255;
    $27 = $byte_padded << 24 >> 24 == 0;
    $28 = 15 - $line_bits | 0;
    $29 = ($28 | 0) > 0;
    $line_bits_op = $line_bits - 8 | 0;
    $line_bits_op_op = $line_bits_op >>> 3;
    $30 = $29 ? 0 : $line_bits_op_op;
    $31 = $16 + $30 | 0;
    $32 = Math_imul($2, $y_offset);
    $33 = $31 + $32 | 0;
    $34 = $33 + 1 | 0;
    $scevgep = $line_buff_0 + $34 | 0;
    $35 = $line_bits - 8 | 0;
    $36 = $30 << 3;
    $37 = $35 - $36 | 0;
    $loaded_054 = 0;
    $acc_055 = 0;
    $height_056 = $source_height;
    $line_buff_157 = $18;
    $_058 = $source;
    $indvars_iv = $scevgep;
    label = 5;
    break;
   case 5:
    if ($22) {
      $_1 = $_058;
      $acc_1 = $acc_055;
      $count_0 = $23;
      $cur_0 = $line_buff_157;
      $loaded_1 = $loaded_054;
      label = 6;
      break;
    } else {
      $_3 = $_058;
      $acc_3 = $acc_055;
      $count_1 = $line_bits;
      $cur_1 = $line_buff_157;
      $loaded_3 = $loaded_054;
      label = 12;
      break;
    }
   case 6:
    $40 = $loaded_1 >>> 0 < 8;
    if ($40) {
      label = 7;
      break;
    } else {
      $_2 = $_1;
      $acc_2 = $acc_1;
      $loaded_2 = $loaded_1;
      label = 8;
      break;
    }
   case 7:
    $42 = $_1 + 1 | 0;
    $43 = HEAP8[$_1] | 0;
    $44 = $43 & 255;
    $45 = 8 - $loaded_1 | 0;
    $46 = $44 << $45;
    $47 = $acc_1 & 65535;
    $48 = $46 | $47;
    $49 = $48 & 65535;
    $50 = $loaded_1 + 8 | 0;
    $_2 = $42;
    $acc_2 = $49;
    $loaded_2 = $50;
    label = 8;
    break;
   case 8:
    $52 = ($acc_2 & 65535) >>> 8;
    $53 = $52 & 65535;
    if ($24) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $55 = $53 >>> ($20 >>> 0);
    $56 = HEAP8[$cur_0] | 0;
    $57 = $56 & 255;
    $58 = $57 | $55;
    $59 = $58 & 255;
    HEAP8[$cur_0] = $59;
    $60 = $53 << $25;
    $61 = $cur_0 + 1 | 0;
    $62 = HEAP8[$61] | 0;
    $63 = $62 & 255;
    $64 = $63 | $60;
    $65 = $64 & 255;
    HEAP8[$61] = $65;
    label = 11;
    break;
   case 10:
    $67 = HEAP8[$cur_0] | 0;
    $68 = $67 & 255;
    $69 = $68 | $53;
    $70 = $69 & 255;
    HEAP8[$cur_0] = $70;
    label = 11;
    break;
   case 11:
    $72 = $cur_0 + 1 | 0;
    $73 = $acc_2 << 8;
    $74 = $loaded_2 - 8 | 0;
    $75 = $count_0 - 8 | 0;
    $76 = ($75 | 0) > -1;
    if ($76) {
      $_1 = $_2;
      $acc_1 = $73;
      $count_0 = $75;
      $cur_0 = $72;
      $loaded_1 = $74;
      label = 6;
      break;
    } else {
      $_3 = $_2;
      $acc_3 = $73;
      $count_1 = $37;
      $cur_1 = $indvars_iv;
      $loaded_3 = $74;
      label = 12;
      break;
    }
   case 12:
    $77 = ($count_1 | 0) > 0;
    if ($77) {
      label = 13;
      break;
    } else {
      $_5 = $_3;
      $acc_5 = $acc_3;
      $loaded_5 = $loaded_3;
      label = 18;
      break;
    }
   case 13:
    $79 = ($loaded_3 | 0) < ($count_1 | 0);
    if ($79) {
      label = 14;
      break;
    } else {
      $_4 = $_3;
      $acc_4 = $acc_3;
      $loaded_4 = $loaded_3;
      label = 15;
      break;
    }
   case 14:
    $81 = $_3 + 1 | 0;
    $82 = HEAP8[$_3] | 0;
    $83 = $82 & 255;
    $84 = 8 - $loaded_3 | 0;
    $85 = $83 << $84;
    $86 = $acc_3 & 65535;
    $87 = $85 | $86;
    $88 = $87 & 65535;
    $89 = $loaded_3 + 8 | 0;
    $_4 = $81;
    $acc_4 = $88;
    $loaded_4 = $89;
    label = 15;
    break;
   case 15:
    $91 = $acc_4 & 65535;
    $92 = ($acc_4 & 65535) >>> 8;
    $93 = $92 & 65535;
    $94 = 255 >>> ($count_1 >>> 0);
    $95 = $94 ^ 255;
    $96 = $93 & $95;
    $97 = $96 >>> ($20 >>> 0);
    $98 = HEAP8[$cur_1] | 0;
    $99 = $98 & 255;
    $100 = $97 | $99;
    $101 = $100 & 255;
    HEAP8[$cur_1] = $101;
    $102 = ($count_1 | 0) > ($26 | 0);
    if ($102) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    $104 = $96 << $26;
    $105 = $cur_1 + 1 | 0;
    $106 = HEAP8[$105] | 0;
    $107 = $106 & 255;
    $108 = $107 | $104;
    $109 = $108 & 255;
    HEAP8[$105] = $109;
    label = 17;
    break;
   case 17:
    $111 = $91 << $count_1;
    $112 = $111 & 65535;
    $113 = $loaded_4 - $count_1 | 0;
    $_5 = $_4;
    $acc_5 = $112;
    $loaded_5 = $113;
    label = 18;
    break;
   case 18:
    $loaded_5_ = $27 ? $loaded_5 : 0;
    $acc_5_ = $27 ? $acc_5 : 0;
    $115 = $line_buff_157 + $2 | 0;
    $116 = $height_056 - 1 | 0;
    $117 = ($116 | 0) > 0;
    $scevgep6263 = $indvars_iv + $2 | 0;
    if ($117) {
      $loaded_054 = $loaded_5_;
      $acc_055 = $acc_5_;
      $height_056 = $116;
      $line_buff_157 = $115;
      $_058 = $_5;
      $indvars_iv = $scevgep6263;
      label = 5;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    return;
  }
}
function _crop_bitmap($map, $metrics) {
  $map = $map | 0;
  $metrics = $metrics | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $count_0137 = 0, $line_0136 = 0, $9 = 0, $cur_0 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $rows_0 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $count_1129 = 0, $line_1128 = 0, $52 = 0, $cur1_0 = 0, $54 = 0, $56 = 0, $57 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $count_1127 = 0, $63 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $rows_1_ph = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $line_2101 = 0, $83 = 0, $84 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $line_3114 = 0, $93 = 0, $old_0105 = 0, $94 = 0, $old_0108 = 0, $cur4_0107 = 0, $n_0106 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $old_0 = 0, $100 = 0, $old_0_lcssa = 0, $cur4_0_lcssa = 0, $101 = 0, $102 = 0, $103 = 0, $_lcssa113 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $_sum = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $line_499 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $map + 12 | 0;
    $2 = $map | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $map + 8 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($3 | 0) > 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 33;
      break;
    }
   case 2:
    $7 = HEAP32[$1 >> 2] | 0;
    $line_0136 = $7;
    $count_0137 = 0;
    label = 3;
    break;
   case 3:
    $9 = $line_0136 + $5 | 0;
    $cur_0 = $line_0136;
    label = 4;
    break;
   case 4:
    $11 = $cur_0 >>> 0 < $9 >>> 0;
    if ($11) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $13 = HEAP8[$cur_0] | 0;
    $14 = $13 << 24 >> 24 == 0;
    $15 = $cur_0 + 1 | 0;
    if ($14) {
      $cur_0 = $15;
      label = 4;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $17 = $count_0137 + 1 | 0;
    $18 = ($17 | 0) < ($3 | 0);
    if ($18) {
      $line_0136 = $9;
      $count_0137 = $17;
      label = 3;
      break;
    } else {
      label = 33;
      break;
    }
   case 7:
    $20 = ($count_0137 | 0) > 0;
    if ($20) {
      label = 8;
      break;
    } else {
      $rows_0 = $3;
      label = 9;
      break;
    }
   case 8:
    $22 = HEAP32[$1 >> 2] | 0;
    $23 = Math_imul($count_0137, $5);
    $24 = $22 + $23 | 0;
    $25 = $3 - $count_0137 | 0;
    $26 = Math_imul($25, $5);
    _memmove($22 | 0, $24 | 0, $26 | 0);
    $27 = $metrics | 0;
    $28 = HEAP8[$27] | 0;
    $29 = $28 & 255;
    $30 = $29 - $count_0137 | 0;
    $31 = $30 & 255;
    HEAP8[$27] = $31;
    $32 = $metrics + 3 | 0;
    $33 = HEAP8[$32] | 0;
    $34 = $33 & 255;
    $35 = $34 - $count_0137 | 0;
    $36 = $35 & 255;
    HEAP8[$32] = $36;
    $37 = $metrics + 6 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 & 255;
    $40 = $39 - $count_0137 | 0;
    $41 = $40 & 255;
    HEAP8[$37] = $41;
    $42 = HEAP32[$2 >> 2] | 0;
    $43 = $42 - $count_0137 | 0;
    HEAP32[$2 >> 2] = $43;
    $rows_0 = $25;
    label = 9;
    break;
   case 9:
    $45 = ($rows_0 | 0) > 0;
    if ($45) {
      label = 10;
      break;
    } else {
      $rows_1_ph = $rows_0;
      label = 17;
      break;
    }
   case 10:
    $46 = $rows_0 - 1 | 0;
    $47 = Math_imul($46, $5);
    $48 = HEAP32[$1 >> 2] | 0;
    $49 = $48 + $47 | 0;
    $50 = -$5 | 0;
    $line_1128 = $49;
    $count_1129 = 0;
    label = 11;
    break;
   case 11:
    $52 = $line_1128 + $5 | 0;
    $cur1_0 = $line_1128;
    label = 12;
    break;
   case 12:
    $54 = $cur1_0 >>> 0 < $52 >>> 0;
    if ($54) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    $56 = HEAP8[$cur1_0] | 0;
    $57 = $56 << 24 >> 24 == 0;
    $58 = $cur1_0 + 1 | 0;
    if ($57) {
      $cur1_0 = $58;
      label = 12;
      break;
    } else {
      $count_1127 = $count_1129;
      label = 15;
      break;
    }
   case 14:
    $60 = $line_1128 + $50 | 0;
    $61 = $count_1129 + 1 | 0;
    $62 = ($61 | 0) < ($rows_0 | 0);
    if ($62) {
      $line_1128 = $60;
      $count_1129 = $61;
      label = 11;
      break;
    } else {
      $count_1127 = $61;
      label = 15;
      break;
    }
   case 15:
    $63 = ($count_1127 | 0) > 0;
    if ($63) {
      label = 16;
      break;
    } else {
      $rows_1_ph = $rows_0;
      label = 17;
      break;
    }
   case 16:
    $65 = $metrics | 0;
    $66 = HEAP8[$65] | 0;
    $67 = $66 & 255;
    $68 = $67 - $count_1127 | 0;
    $69 = $68 & 255;
    HEAP8[$65] = $69;
    $70 = $rows_0 - $count_1127 | 0;
    $71 = HEAP32[$2 >> 2] | 0;
    $72 = $71 - $count_1127 | 0;
    HEAP32[$2 >> 2] = $72;
    $rows_1_ph = $70;
    label = 17;
    break;
   case 17:
    $73 = Math_imul($rows_1_ph, $5);
    $74 = $map + 4 | 0;
    $75 = $metrics + 2 | 0;
    $76 = $metrics + 5 | 0;
    $77 = $metrics + 1 | 0;
    label = 18;
    break;
   case 18:
    $79 = HEAP32[$1 >> 2] | 0;
    $80 = $79 + $73 | 0;
    $81 = ($73 | 0) > 0;
    if ($81) {
      $line_2101 = $79;
      label = 20;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $82 = HEAP32[$74 >> 2] | 0;
    $_lcssa113 = $82;
    label = 26;
    break;
   case 20:
    $83 = HEAP8[$line_2101] | 0;
    $84 = $83 << 24 >> 24 < 0;
    if ($84) {
      label = 27;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $86 = $line_2101 + $5 | 0;
    $87 = $86 >>> 0 < $80 >>> 0;
    if ($87) {
      $line_2101 = $86;
      label = 20;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $88 = HEAP32[$1 >> 2] | 0;
    $89 = $88 + $73 | 0;
    $90 = ($73 | 0) > 0;
    $91 = HEAP32[$74 >> 2] | 0;
    if ($90) {
      $line_3114 = $88;
      $92 = $91;
      label = 23;
      break;
    } else {
      $_lcssa113 = $91;
      label = 26;
      break;
    }
   case 23:
    $93 = HEAP8[$line_3114] | 0;
    $old_0105 = $93 << 1;
    $94 = ($92 | 0) > 8;
    if ($94) {
      $n_0106 = 8;
      $cur4_0107 = $line_3114;
      $old_0108 = $old_0105;
      label = 24;
      break;
    } else {
      $cur4_0_lcssa = $line_3114;
      $old_0_lcssa = $old_0105;
      label = 25;
      break;
    }
   case 24:
    $95 = $cur4_0107 + 1 | 0;
    $96 = HEAP8[$95] | 0;
    $97 = ($96 & 255) >>> 7;
    $98 = $97 | $old_0108;
    HEAP8[$cur4_0107] = $98;
    $99 = $n_0106 + 8 | 0;
    $old_0 = $96 << 1;
    $100 = ($99 | 0) < ($92 | 0);
    if ($100) {
      $n_0106 = $99;
      $cur4_0107 = $95;
      $old_0108 = $old_0;
      label = 24;
      break;
    } else {
      $cur4_0_lcssa = $95;
      $old_0_lcssa = $old_0;
      label = 25;
      break;
    }
   case 25:
    HEAP8[$cur4_0_lcssa] = $old_0_lcssa;
    $101 = $line_3114 + $5 | 0;
    $102 = $101 >>> 0 < $89 >>> 0;
    $103 = HEAP32[$74 >> 2] | 0;
    if ($102) {
      $line_3114 = $101;
      $92 = $103;
      label = 23;
      break;
    } else {
      $_lcssa113 = $103;
      label = 26;
      break;
    }
   case 26:
    $104 = $_lcssa113 - 1 | 0;
    HEAP32[$74 >> 2] = $104;
    $105 = HEAP8[$75] | 0;
    $106 = $105 + 1 & 255;
    HEAP8[$75] = $106;
    $107 = HEAP8[$76] | 0;
    $108 = $107 + 1 & 255;
    HEAP8[$76] = $108;
    $109 = HEAP8[$77] | 0;
    $110 = $109 - 1 & 255;
    HEAP8[$77] = $110;
    $111 = HEAP32[$74 >> 2] | 0;
    $112 = ($111 | 0) > 0;
    if ($112) {
      label = 18;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $113 = $map + 4 | 0;
    $114 = $metrics + 1 | 0;
    label = 28;
    break;
   case 28:
    $116 = HEAP32[$113 >> 2] | 0;
    $117 = $116 - 1 | 0;
    $118 = HEAP32[$1 >> 2] | 0;
    $119 = $117 >> 3;
    $_sum = $119 + $73 | 0;
    $120 = $118 + $_sum | 0;
    $121 = ($119 | 0) < ($_sum | 0);
    if ($121) {
      label = 29;
      break;
    } else {
      label = 32;
      break;
    }
   case 29:
    $122 = $117 & 7;
    $123 = $118 + $119 | 0;
    $124 = 128 >>> ($122 >>> 0);
    $line_499 = $123;
    label = 30;
    break;
   case 30:
    $126 = HEAP8[$line_499] | 0;
    $127 = $126 & 255;
    $128 = $124 & $127;
    $129 = ($128 | 0) == 0;
    if ($129) {
      label = 31;
      break;
    } else {
      label = 34;
      break;
    }
   case 31:
    $131 = $line_499 + $5 | 0;
    $132 = $131 >>> 0 < $120 >>> 0;
    if ($132) {
      $line_499 = $131;
      label = 30;
      break;
    } else {
      label = 32;
      break;
    }
   case 32:
    $133 = HEAP32[$113 >> 2] | 0;
    $134 = $133 - 1 | 0;
    HEAP32[$113 >> 2] = $134;
    $135 = HEAP8[$114] | 0;
    $136 = $135 - 1 & 255;
    HEAP8[$114] = $136;
    $137 = HEAP32[$113 >> 2] | 0;
    $138 = ($137 | 0) > 0;
    if ($138) {
      label = 28;
      break;
    } else {
      label = 34;
      break;
    }
   case 33:
    $139 = $map + 4 | 0;
    HEAP32[$139 >> 2] = 0;
    HEAP32[$2 >> 2] = 0;
    HEAP32[$4 >> 2] = 0;
    $140 = $map + 18 | 0;
    HEAP8[$140] = 1;
    label = 34;
    break;
   case 34:
    return;
  }
}
function _Load_SBit_Single($map, $x_offset, $y_offset, $pix_bits, $image_format, $metrics, $stream) {
  $map = $map | 0;
  $x_offset = $x_offset | 0;
  $y_offset = $y_offset | 0;
  $pix_bits = $pix_bits | 0;
  $image_format = $image_format | 0;
  $metrics = $metrics | 0;
  $stream = $stream | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $or_cond = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $line_length_0 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $glyph_size_0 = 0, $pad_bytes_0 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($x_offset | 0) < 0;
    if ($1) {
      $_0 = 6;
      label = 13;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $metrics + 1 | 0;
    $4 = HEAP8[$3] | 0;
    $5 = $4 & 255;
    $6 = $5 + $x_offset | 0;
    $7 = $map + 4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($6 | 0) > ($8 | 0);
    $10 = ($y_offset | 0) < 0;
    $or_cond = $9 | $10;
    if ($or_cond) {
      $_0 = 6;
      label = 13;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = $metrics | 0;
    $13 = HEAP8[$12] | 0;
    $14 = $13 & 255;
    $15 = $14 + $y_offset | 0;
    $16 = $map | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($15 | 0) > ($17 | 0);
    if ($18) {
      $_0 = 6;
      label = 13;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $20 = Math_imul($5, $pix_bits);
    $21 = $image_format & 65535;
    if (($21 | 0) == 1 | ($21 | 0) == 6) {
      label = 5;
      break;
    } else if (($21 | 0) == 2 | ($21 | 0) == 5 | ($21 | 0) == 7) {
      label = 10;
      break;
    } else {
      $_0 = 3;
      label = 13;
      break;
    }
   case 5:
    if (($pix_bits | 0) == 1) {
      label = 6;
      break;
    } else if (($pix_bits | 0) == 2) {
      label = 7;
      break;
    } else if (($pix_bits | 0) == 4) {
      label = 8;
      break;
    } else {
      $line_length_0 = $5;
      label = 9;
      break;
    }
   case 6:
    $24 = $5 + 7 | 0;
    $25 = $24 >>> 3;
    $line_length_0 = $25;
    label = 9;
    break;
   case 7:
    $27 = $5 + 3 | 0;
    $28 = $27 >>> 2;
    $line_length_0 = $28;
    label = 9;
    break;
   case 8:
    $30 = $5 + 1 | 0;
    $31 = $30 >>> 1;
    $line_length_0 = $31;
    label = 9;
    break;
   case 9:
    $33 = Math_imul($line_length_0, $14);
    $pad_bytes_0 = 1;
    $glyph_size_0 = $33;
    label = 11;
    break;
   case 10:
    $35 = Math_imul($14, $20);
    $36 = $35 + 7 | 0;
    $37 = $36 >> 3;
    $pad_bytes_0 = 0;
    $glyph_size_0 = $37;
    label = 11;
    break;
   case 11:
    $39 = _FT_Stream_EnterFrame($stream, $glyph_size_0) | 0;
    $40 = ($39 | 0) == 0;
    if ($40) {
      label = 12;
      break;
    } else {
      $_0 = $39;
      label = 13;
      break;
    }
   case 12:
    $42 = $stream + 32 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = Math_imul($pix_bits, $x_offset);
    $45 = HEAP8[$12] | 0;
    $46 = $45 & 255;
    _blit_sbit($map, $43, $20, $pad_bytes_0, $44, $y_offset, $46);
    _FT_Stream_ExitFrame($stream);
    $_0 = 0;
    label = 13;
    break;
   case 13:
    return $_0 | 0;
  }
  return 0;
}
function _tt_face_load_generic_header($face, $stream, $tag) {
  $face = $face | 0;
  $stream = $stream | 0;
  $tag = $tag | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 508 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    $4 = FUNCTION_TABLE_iiiii[$3 & 1023]($face, $tag, $stream, 0) | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $error_0 = $4;
      label = 3;
      break;
    }
   case 2:
    $7 = $face + 160 | 0;
    $8 = $7;
    $9 = _FT_Stream_ReadFields($stream, 5243992, $8) | 0;
    $error_0 = $9;
    label = 3;
    break;
   case 3:
    return $error_0 | 0;
  }
  return 0;
}
function _tt_face_free_bdf_props($face) {
  $face = $face | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 812 | 0;
    $2 = HEAP8[$1] | 0;
    $3 = $2 << 24 >> 24 == 0;
    if ($3) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $face + 792 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = $face + 104 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    _FT_Stream_ReleaseFrame($10, $5);
    label = 4;
    break;
   case 4:
    $12 = $face + 796 | 0;
    HEAP32[$12 >> 2] = 0;
    $13 = $face + 800 | 0;
    HEAP32[$13 >> 2] = 0;
    $14 = $face + 804 | 0;
    HEAP32[$14 >> 2] = 0;
    label = 5;
    break;
   case 5:
    return;
  }
}
function _tt_face_done_kern($face) {
  $face = $face | 0;
  _FT_Stream_ReleaseFrame(HEAP32[$face + 104 >> 2] | 0, $face + 772 | 0);
  _memset($face + 776 | 0, 0, 16);
  return;
}
function _tt_face_get_name($face, $nameid, $name) {
  $face = $face | 0;
  $nameid = $nameid | 0;
  $name = $name | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $indvars_iv = 0, $is_english_053 = 0, $found_unicode_052 = 0, $found_win_051 = 0, $found_apple_english_050 = 0, $found_apple_roman_049 = 0, $rec_047 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $_found_apple_roman_0 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $found_apple_roman_1 = 0, $found_apple_english_1 = 0, $found_win_1 = 0, $found_unicode_1 = 0, $is_english_1 = 0, $indvars_iv_next = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $found_apple_english_0_found_apple_roman_0 = 0, $52 = 0, $54 = 0, $55 = 0, $or_cond = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $65 = 0, $66 = 0, $68 = 0, $70 = 0, $71 = 0, $rec_1 = 0, $convert_0 = 0, $73 = 0, $75 = 0, $76 = 0, $77 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $99 = 0, $101 = 0, $result_0 = 0, $102 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $3 = $face + 360 | 0;
    $4 = $face + 344 | 0;
    $5 = HEAP16[$4 >> 1] | 0;
    $6 = $5 << 16 >> 16 == 0;
    if ($6) {
      $result_0 = 0;
      label = 28;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = HEAP32[$3 >> 2] | 0;
    $8 = HEAP16[$4 >> 1] | 0;
    $rec_047 = $7;
    $found_apple_roman_049 = -1;
    $found_apple_english_050 = -1;
    $found_win_051 = -1;
    $found_unicode_052 = -1;
    $is_english_053 = 0;
    $indvars_iv = 0;
    label = 3;
    break;
   case 3:
    $10 = $rec_047 + 6 | 0;
    $11 = HEAP16[$10 >> 1] | 0;
    $12 = $11 << 16 >> 16 == $nameid << 16 >> 16;
    if ($12) {
      label = 4;
      break;
    } else {
      $is_english_1 = $is_english_053;
      $found_unicode_1 = $found_unicode_052;
      $found_win_1 = $found_win_051;
      $found_apple_english_1 = $found_apple_english_050;
      $found_apple_roman_1 = $found_apple_roman_049;
      label = 13;
      break;
    }
   case 4:
    $14 = $rec_047 + 8 | 0;
    $15 = HEAP16[$14 >> 1] | 0;
    $16 = $15 << 16 >> 16 == 0;
    if ($16) {
      $is_english_1 = $is_english_053;
      $found_unicode_1 = $found_unicode_052;
      $found_win_1 = $found_win_051;
      $found_apple_english_1 = $found_apple_english_050;
      $found_apple_roman_1 = $found_apple_roman_049;
      label = 13;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $18 = $rec_047 | 0;
    $19 = HEAP16[$18 >> 1] | 0;
    $20 = $19 & 65535;
    if (($20 | 0) == 0 | ($20 | 0) == 2) {
      label = 6;
      break;
    } else if (($20 | 0) == 1) {
      label = 7;
      break;
    } else if (($20 | 0) == 3) {
      label = 9;
      break;
    } else {
      $is_english_1 = $is_english_053;
      $found_unicode_1 = $found_unicode_052;
      $found_win_1 = $found_win_051;
      $found_apple_english_1 = $found_apple_english_050;
      $found_apple_roman_1 = $found_apple_roman_049;
      label = 13;
      break;
    }
   case 6:
    $is_english_1 = $is_english_053;
    $found_unicode_1 = $indvars_iv;
    $found_win_1 = $found_win_051;
    $found_apple_english_1 = $found_apple_english_050;
    $found_apple_roman_1 = $found_apple_roman_049;
    label = 13;
    break;
   case 7:
    $23 = $rec_047 + 4 | 0;
    $24 = HEAP16[$23 >> 1] | 0;
    $25 = $24 << 16 >> 16 == 0;
    if ($25) {
      $is_english_1 = $is_english_053;
      $found_unicode_1 = $found_unicode_052;
      $found_win_1 = $found_win_051;
      $found_apple_english_1 = $indvars_iv;
      $found_apple_roman_1 = $found_apple_roman_049;
      label = 13;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $27 = $rec_047 + 2 | 0;
    $28 = HEAP16[$27 >> 1] | 0;
    $29 = $28 << 16 >> 16 == 0;
    $_found_apple_roman_0 = $29 ? $indvars_iv : $found_apple_roman_049;
    $is_english_1 = $is_english_053;
    $found_unicode_1 = $found_unicode_052;
    $found_win_1 = $found_win_051;
    $found_apple_english_1 = $found_apple_english_050;
    $found_apple_roman_1 = $_found_apple_roman_0;
    label = 13;
    break;
   case 9:
    $31 = ($found_win_051 | 0) == -1;
    if ($31) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $33 = $rec_047 + 4 | 0;
    $34 = HEAP16[$33 >> 1] | 0;
    $35 = $34 & 1023;
    $36 = $35 << 16 >> 16 == 9;
    if ($36) {
      label = 11;
      break;
    } else {
      $is_english_1 = $is_english_053;
      $found_unicode_1 = $found_unicode_052;
      $found_win_1 = $found_win_051;
      $found_apple_english_1 = $found_apple_english_050;
      $found_apple_roman_1 = $found_apple_roman_049;
      label = 13;
      break;
    }
   case 11:
    $38 = $rec_047 + 2 | 0;
    $39 = HEAP16[$38 >> 1] | 0;
    $40 = $39 & 65535;
    if (($40 | 0) == 0 | ($40 | 0) == 1 | ($40 | 0) == 10) {
      label = 12;
      break;
    } else {
      $is_english_1 = $is_english_053;
      $found_unicode_1 = $found_unicode_052;
      $found_win_1 = $found_win_051;
      $found_apple_english_1 = $found_apple_english_050;
      $found_apple_roman_1 = $found_apple_roman_049;
      label = 13;
      break;
    }
   case 12:
    $42 = $rec_047 + 4 | 0;
    $43 = HEAP16[$42 >> 1] | 0;
    $44 = $43 & 1023;
    $45 = $44 << 16 >> 16 == 9;
    $46 = $45 & 1;
    $is_english_1 = $46;
    $found_unicode_1 = $found_unicode_052;
    $found_win_1 = $indvars_iv;
    $found_apple_english_1 = $found_apple_english_050;
    $found_apple_roman_1 = $found_apple_roman_049;
    label = 13;
    break;
   case 13:
    $indvars_iv_next = $indvars_iv + 1 | 0;
    $48 = $rec_047 + 20 | 0;
    $49 = $indvars_iv_next & 65535;
    $50 = ($49 & 65535) < ($8 & 65535);
    if ($50) {
      $rec_047 = $48;
      $found_apple_roman_049 = $found_apple_roman_1;
      $found_apple_english_050 = $found_apple_english_1;
      $found_win_051 = $found_win_1;
      $found_unicode_052 = $found_unicode_1;
      $is_english_053 = $is_english_1;
      $indvars_iv = $indvars_iv_next;
      label = 3;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $51 = ($found_apple_english_1 | 0) > -1;
    $found_apple_english_0_found_apple_roman_0 = $51 ? $found_apple_english_1 : $found_apple_roman_1;
    $52 = ($found_win_1 | 0) > -1;
    if ($52) {
      label = 15;
      break;
    } else {
      label = 17;
      break;
    }
   case 15:
    $54 = ($found_apple_english_0_found_apple_roman_0 | 0) > -1;
    $55 = $is_english_1 << 24 >> 24 == 0;
    $or_cond = $54 & $55;
    if ($or_cond) {
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $57 = HEAP32[$3 >> 2] | 0;
    $58 = $57 + ($found_win_1 * 20 & -1) | 0;
    $59 = $57 + ($found_win_1 * 20 & -1) + 2 | 0;
    $60 = HEAP16[$59 >> 1] | 0;
    $61 = $60 & 65535;
    if (($61 | 0) == 1 | ($61 | 0) == 0 | ($61 | 0) == 10) {
      $convert_0 = 890;
      $rec_1 = $58;
      label = 21;
      break;
    } else {
      $result_0 = 0;
      label = 28;
      break;
    }
   case 17:
    $63 = ($found_apple_english_0_found_apple_roman_0 | 0) > -1;
    if ($63) {
      label = 18;
      break;
    } else {
      label = 19;
      break;
    }
   case 18:
    $65 = HEAP32[$3 >> 2] | 0;
    $66 = $65 + ($found_apple_english_0_found_apple_roman_0 * 20 & -1) | 0;
    $convert_0 = 178;
    $rec_1 = $66;
    label = 21;
    break;
   case 19:
    $68 = ($found_unicode_1 | 0) > -1;
    if ($68) {
      label = 20;
      break;
    } else {
      $result_0 = 0;
      label = 28;
      break;
    }
   case 20:
    $70 = HEAP32[$3 >> 2] | 0;
    $71 = $70 + ($found_unicode_1 * 20 & -1) | 0;
    $convert_0 = 890;
    $rec_1 = $71;
    label = 21;
    break;
   case 21:
    $73 = ($rec_1 | 0) == 0;
    if ($73) {
      $result_0 = 0;
      label = 28;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $75 = $rec_1 + 16 | 0;
    $76 = HEAP32[$75 >> 2] | 0;
    $77 = ($76 | 0) == 0;
    if ($77) {
      label = 23;
      break;
    } else {
      label = 27;
      break;
    }
   case 23:
    $79 = $face + 364 | 0;
    $80 = HEAP32[$79 >> 2] | 0;
    $81 = $rec_1 + 8 | 0;
    $82 = HEAP16[$81 >> 1] | 0;
    $83 = $82 & 65535;
    $84 = _ft_mem_realloc($2, 1, 0, $83, 0, $error) | 0;
    HEAP32[$75 >> 2] = $84;
    $85 = HEAP32[$error >> 2] | 0;
    $86 = ($85 | 0) == 0;
    if ($86) {
      label = 24;
      break;
    } else {
      label = 26;
      break;
    }
   case 24:
    $88 = $rec_1 + 12 | 0;
    $89 = HEAP32[$88 >> 2] | 0;
    $90 = _FT_Stream_Seek($80, $89) | 0;
    HEAP32[$error >> 2] = $90;
    $91 = ($90 | 0) == 0;
    if ($91) {
      label = 25;
      break;
    } else {
      label = 26;
      break;
    }
   case 25:
    $93 = HEAP32[$75 >> 2] | 0;
    $94 = HEAP16[$81 >> 1] | 0;
    $95 = $94 & 65535;
    $96 = _FT_Stream_Read($80, $93, $95) | 0;
    HEAP32[$error >> 2] = $96;
    $97 = ($96 | 0) == 0;
    if ($97) {
      label = 27;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $99 = HEAP32[$75 >> 2] | 0;
    _ft_mem_free($2, $99);
    HEAP32[$75 >> 2] = 0;
    HEAP16[$81 >> 1] = 0;
    $result_0 = 0;
    label = 28;
    break;
   case 27:
    $101 = FUNCTION_TABLE_iii[$convert_0 & 1023]($rec_1, $2) | 0;
    $result_0 = $101;
    label = 28;
    break;
   case 28:
    HEAP32[$name >> 2] = $result_0;
    $102 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $102 | 0;
  }
  return 0;
}
function _sfnt_find_encoding($platform_id, $encoding_id) {
  $platform_id = $platform_id | 0;
  $encoding_id = $encoding_id | 0;
  var $1 = 0, $cur_010_lcssa = 0, $3 = 0, $4 = 0, $_0 = 0, $7 = 0, $9 = 0, $11 = 0, $13 = 0, $15 = 0, $17 = 0, $19 = 0, $21 = 0, $23 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($platform_id | 0) == 2;
    if ($1) {
      $cur_010_lcssa = 5249680;
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = $cur_010_lcssa + 8 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $_0 = $4;
    label = 4;
    break;
   case 3:
    if (($platform_id | 0) == 0) {
      $cur_010_lcssa = 5249692;
      label = 2;
      break;
    } else if (($platform_id | 0) == 1) {
      label = 5;
      break;
    } else if (($platform_id | 0) == 3) {
      label = 6;
      break;
    } else {
      $_0 = 0;
      label = 4;
      break;
    }
   case 4:
    return $_0 | 0;
   case 5:
    $7 = ($encoding_id | 0) == 0;
    if ($7) {
      $cur_010_lcssa = 5249704;
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 4;
      break;
    }
   case 6:
    $9 = ($encoding_id | 0) == 0;
    if ($9) {
      $cur_010_lcssa = 5249716;
      label = 2;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $11 = ($encoding_id | 0) == 10;
    if ($11) {
      $cur_010_lcssa = 5249728;
      label = 2;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $13 = ($encoding_id | 0) == 1;
    if ($13) {
      $cur_010_lcssa = 5249740;
      label = 2;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $15 = ($encoding_id | 0) == 2;
    if ($15) {
      $cur_010_lcssa = 5249752;
      label = 2;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $17 = ($encoding_id | 0) == 3;
    if ($17) {
      $cur_010_lcssa = 5249764;
      label = 2;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $19 = ($encoding_id | 0) == 4;
    if ($19) {
      $cur_010_lcssa = 5249776;
      label = 2;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $21 = ($encoding_id | 0) == 5;
    if ($21) {
      $cur_010_lcssa = 5249788;
      label = 2;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $23 = ($encoding_id | 0) == 6;
    if ($23) {
      $cur_010_lcssa = 5249800;
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 4;
      break;
    }
  }
  return 0;
}
function _tt_cmap14_find_variant($base, $variantCode) {
  $base = $base | 0;
  $variantCode = $variantCode | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $max_0_ph = 0, $min_0_ph = 0, $min_0 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $_sum19 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $_sum20 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $_sum21 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $_sum18 = 0, $39 = 0, $40 = 0, $41 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP8[$base] | 0;
    $2 = $1 & 255;
    $3 = $2 << 24;
    $4 = $base + 1 | 0;
    $5 = HEAP8[$4] | 0;
    $6 = $5 & 255;
    $7 = $6 << 16;
    $8 = $7 | $3;
    $9 = $base + 2 | 0;
    $10 = HEAP8[$9] | 0;
    $11 = $10 & 255;
    $12 = $11 << 8;
    $13 = $8 | $12;
    $14 = $base + 3 | 0;
    $15 = HEAP8[$14] | 0;
    $16 = $15 & 255;
    $17 = $13 | $16;
    $min_0_ph = 0;
    $max_0_ph = $17;
    label = 2;
    break;
   case 2:
    $min_0 = $min_0_ph;
    label = 3;
    break;
   case 3:
    $19 = $min_0 >>> 0 < $max_0_ph >>> 0;
    if ($19) {
      label = 4;
      break;
    } else {
      $_0 = 0;
      label = 6;
      break;
    }
   case 4:
    $21 = $min_0 + $max_0_ph | 0;
    $22 = $21 >>> 1;
    $23 = $22 * 11 & -1;
    $_sum19 = $23 + 4 | 0;
    $24 = $base + $_sum19 | 0;
    $25 = HEAP8[$24] | 0;
    $26 = $25 & 255;
    $27 = $26 << 16;
    $_sum20 = $23 + 5 | 0;
    $28 = $base + $_sum20 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $29 & 255;
    $31 = $30 << 8;
    $32 = $31 | $27;
    $_sum21 = $23 + 6 | 0;
    $33 = $base + $_sum21 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $32 | $35;
    $37 = $36 >>> 0 > $variantCode >>> 0;
    if ($37) {
      $min_0_ph = $min_0;
      $max_0_ph = $22;
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $_sum18 = $23 + 7 | 0;
    $39 = $base + $_sum18 | 0;
    $40 = $36 >>> 0 < $variantCode >>> 0;
    $41 = $22 + 1 | 0;
    if ($40) {
      $min_0 = $41;
      label = 3;
      break;
    } else {
      $_0 = $39;
      label = 6;
      break;
    }
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap14_def_char_count($p) {
  $p = $p | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $tot_012 = 0, $numRanges_011 = 0, $_010 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $tot_0_lcssa = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP8[$p] | 0;
    $2 = $1 & 255;
    $3 = $2 << 24;
    $4 = $p + 1 | 0;
    $5 = HEAP8[$4] | 0;
    $6 = $5 & 255;
    $7 = $6 << 16;
    $8 = $7 | $3;
    $9 = $p + 2 | 0;
    $10 = HEAP8[$9] | 0;
    $11 = $10 & 255;
    $12 = $11 << 8;
    $13 = $8 | $12;
    $14 = $p + 3 | 0;
    $15 = HEAP8[$14] | 0;
    $16 = $15 & 255;
    $17 = $13 | $16;
    $18 = ($17 | 0) == 0;
    if ($18) {
      $tot_0_lcssa = 0;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $19 = $p + 7 | 0;
    $_010 = $19;
    $numRanges_011 = $17;
    $tot_012 = 0;
    label = 3;
    break;
   case 3:
    $21 = HEAP8[$_010] | 0;
    $22 = $21 & 255;
    $23 = $tot_012 + 1 | 0;
    $24 = $23 + $22 | 0;
    $25 = $_010 + 4 | 0;
    $26 = $numRanges_011 - 1 | 0;
    $27 = ($26 | 0) == 0;
    if ($27) {
      $tot_0_lcssa = $24;
      label = 4;
      break;
    } else {
      $_010 = $25;
      $numRanges_011 = $26;
      $tot_012 = $24;
      label = 3;
      break;
    }
   case 4:
    return $tot_0_lcssa | 0;
  }
  return 0;
}
function _tt_cmap14_char_map_def_binary($base, $char_code) {
  $base = $base | 0;
  $char_code = $char_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $min_0_ph = 0, $max_0_ph = 0, $max_0 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $_sum19 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $_sum20 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $_sum21 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $_sum18 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP8[$base] | 0;
    $2 = $1 & 255;
    $3 = $2 << 24;
    $4 = $base + 1 | 0;
    $5 = HEAP8[$4] | 0;
    $6 = $5 & 255;
    $7 = $6 << 16;
    $8 = $7 | $3;
    $9 = $base + 2 | 0;
    $10 = HEAP8[$9] | 0;
    $11 = $10 & 255;
    $12 = $11 << 8;
    $13 = $8 | $12;
    $14 = $base + 3 | 0;
    $15 = HEAP8[$14] | 0;
    $16 = $15 & 255;
    $17 = $13 | $16;
    $max_0_ph = $17;
    $min_0_ph = 0;
    label = 2;
    break;
   case 2:
    $max_0 = $max_0_ph;
    label = 3;
    break;
   case 3:
    $19 = $min_0_ph >>> 0 < $max_0 >>> 0;
    if ($19) {
      label = 4;
      break;
    } else {
      $_0 = 0;
      label = 6;
      break;
    }
   case 4:
    $21 = $max_0 + $min_0_ph | 0;
    $22 = $21 >>> 1;
    $23 = $22 << 2;
    $_sum19 = $23 + 4 | 0;
    $24 = $base + $_sum19 | 0;
    $25 = HEAP8[$24] | 0;
    $26 = $25 & 255;
    $27 = $26 << 16;
    $_sum20 = $23 + 5 | 0;
    $28 = $base + $_sum20 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $29 & 255;
    $31 = $30 << 8;
    $32 = $31 | $27;
    $_sum21 = $23 + 6 | 0;
    $33 = $base + $_sum21 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $32 | $35;
    $37 = $36 >>> 0 > $char_code >>> 0;
    if ($37) {
      $max_0 = $22;
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $_sum18 = $23 + 7 | 0;
    $39 = $base + $_sum18 | 0;
    $40 = HEAP8[$39] | 0;
    $41 = $40 & 255;
    $42 = $41 + $36 | 0;
    $43 = $42 >>> 0 < $char_code >>> 0;
    $44 = $22 + 1 | 0;
    if ($43) {
      $max_0_ph = $max_0;
      $min_0_ph = $44;
      label = 2;
      break;
    } else {
      $_0 = 1;
      label = 6;
      break;
    }
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap14_char_map_nondef_binary($base, $char_code) {
  $base = $base | 0;
  $char_code = $char_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $max_0_ph = 0, $min_0_ph = 0, $min_0 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $_sum20 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $_sum21 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $_sum22 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $_sum19 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $_sum23 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP8[$base] | 0;
    $2 = $1 & 255;
    $3 = $2 << 24;
    $4 = $base + 1 | 0;
    $5 = HEAP8[$4] | 0;
    $6 = $5 & 255;
    $7 = $6 << 16;
    $8 = $7 | $3;
    $9 = $base + 2 | 0;
    $10 = HEAP8[$9] | 0;
    $11 = $10 & 255;
    $12 = $11 << 8;
    $13 = $8 | $12;
    $14 = $base + 3 | 0;
    $15 = HEAP8[$14] | 0;
    $16 = $15 & 255;
    $17 = $13 | $16;
    $min_0_ph = 0;
    $max_0_ph = $17;
    label = 2;
    break;
   case 2:
    $min_0 = $min_0_ph;
    label = 3;
    break;
   case 3:
    $19 = $min_0 >>> 0 < $max_0_ph >>> 0;
    if ($19) {
      label = 4;
      break;
    } else {
      $_0 = 0;
      label = 7;
      break;
    }
   case 4:
    $21 = $min_0 + $max_0_ph | 0;
    $22 = $21 >>> 1;
    $23 = $22 * 5 & -1;
    $_sum20 = $23 + 4 | 0;
    $24 = $base + $_sum20 | 0;
    $25 = HEAP8[$24] | 0;
    $26 = $25 & 255;
    $27 = $26 << 16;
    $_sum21 = $23 + 5 | 0;
    $28 = $base + $_sum21 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $29 & 255;
    $31 = $30 << 8;
    $32 = $31 | $27;
    $_sum22 = $23 + 6 | 0;
    $33 = $base + $_sum22 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $32 | $35;
    $37 = $36 >>> 0 > $char_code >>> 0;
    if ($37) {
      $min_0_ph = $min_0;
      $max_0_ph = $22;
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $39 = $36 >>> 0 < $char_code >>> 0;
    $40 = $22 + 1 | 0;
    if ($39) {
      $min_0 = $40;
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $_sum19 = $23 + 7 | 0;
    $42 = $base + $_sum19 | 0;
    $43 = HEAP8[$42] | 0;
    $44 = $43 & 255;
    $45 = $44 << 8;
    $_sum23 = $23 + 8 | 0;
    $46 = $base + $_sum23 | 0;
    $47 = HEAP8[$46] | 0;
    $48 = $47 & 255;
    $49 = $45 | $48;
    $_0 = $49;
    label = 7;
    break;
   case 7:
    return $_0 | 0;
  }
  return 0;
}
function _tt_face_build_cmaps($face) {
  $face = $face | 0;
  var $num_cmaps = 0, $p = 0, $charmap = 0, $cmap = 0, $format = 0, $pclazz = 0, $clazz = 0, $valid = 0, $error = 0, $ttcmap = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $p_0_load31 = 0, $7 = 0, $p_0_load32 = 0, $9 = 0, $10 = 0, $p_0_load33 = 0, $12 = 0, $p_0_load34 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $p_0_load35 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $p_0_load36 = 0, $23 = 0, $25 = 0, $p_0_load37 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $p_0_load38 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $num_cmaps_0_load51 = 0, $num_cmaps_0_load5255 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $p_0_load39 = 0, $46 = 0, $47 = 0, $p_0_load40 = 0, $49 = 0, $p_0_load41 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $p_0_load42 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $p_0_load43 = 0, $58 = 0, $p_0_load44 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $p_0_load45 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $p_0_load46 = 0, $67 = 0, $p_0_load47 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $p_0_load48 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $p_0_load49 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $p_0_load50 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $88 = 0, $89 = 0, $90 = 0, $92 = 0, $cmap_0_load11 = 0, $93 = 0, $94 = 0, $95 = 0, $cmap_0_load12 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $pclazz_0_load654 = 0, $100 = 0, $101 = 0, $pclazz_0_load7 = 0, $102 = 0, $clazz_0_load3 = 0, $103 = 0, $104 = 0, $format_0_load10 = 0, $105 = 0, $cmap_0_load13 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $clazz_0_load4 = 0, $112 = 0, $113 = 0, $cmap_0_load14 = 0, $114 = 0, $116 = 0, $117 = 0, $clazz_0_load5 = 0, $cmap_0_load15 = 0, $119 = 0, $120 = 0, $121 = 0, $error_0_load1 = 0, $123 = 0, $124 = 0, $pclazz_0_load8 = 0, $126 = 0, $pclazz_0_load6 = 0, $127 = 0, $128 = 0, $pclazz_0_load9 = 0, $num_cmaps_0_load53 = 0, $130 = 0, $num_cmaps_0_load52 = 0, $131 = 0, label = 0, __stackBase__ = 0, setjmpLabel = 0, setjmpTable = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 76 | 0;
  label = 1;
  setjmpLabel = 0;
  setjmpTable = STACKTOP;
  STACKTOP = STACKTOP + 88 | 0;
  while (1) switch (label | 0) {
   case 1:
    $charmap = __stackBase__ | 0;
    $valid = __stackBase__ + 12 | 0;
    $ttcmap = __stackBase__ + 72 | 0;
    $1 = $face + 500 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 504 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + $4 | 0;
    $p = $2;
    $6 = $face | 0;
    $p_0_load31 = $p;
    $7 = ($p_0_load31 | 0) == 0;
    if ($7) {
      label = 20;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $p_0_load32 = $p;
    $9 = $p_0_load32 + 4 | 0;
    $10 = $9 >>> 0 > $5 >>> 0;
    if ($10) {
      label = 20;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $p_0_load33 = $p;
    $12 = $p_0_load33 + 2 | 0;
    $p = $12;
    $p_0_load34 = $p;
    $13 = $p_0_load34 - 2 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 & 255;
    $16 = $15 << 8;
    $p_0_load35 = $p;
    $17 = $p_0_load35 - 1 | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $18 & 255;
    $20 = $19 | $16;
    $21 = ($20 | 0) == 0;
    $p_0_load36 = $p;
    if ($21) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $23 = $p_0_load36 - 2 | 0;
    $p = $23;
    label = 20;
    break;
   case 5:
    $25 = $p_0_load36 + 2 | 0;
    $p = $25;
    $p_0_load37 = $p;
    $26 = $p_0_load37 - 2 | 0;
    $27 = HEAP8[$26] | 0;
    $28 = $27 & 255;
    $29 = $28 << 8;
    $p_0_load38 = $p;
    $30 = $p_0_load38 - 1 | 0;
    $31 = HEAP8[$30] | 0;
    $32 = $31 & 255;
    $33 = $32 | $29;
    $num_cmaps = $33;
    $num_cmaps_0_load51 = $num_cmaps;
    $num_cmaps_0_load5255 = $num_cmaps;
    $34 = ($num_cmaps_0_load5255 | 0) == 0;
    if ($34) {
      label = 20;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $35 = $charmap + 8 | 0;
    $36 = $charmap + 10 | 0;
    $37 = $charmap | 0;
    $38 = $charmap + 4 | 0;
    $39 = $valid | 0;
    $40 = $face + 264 | 0;
    $41 = $valid + 56 | 0;
    $42 = $valid + 16 | 0;
    $43 = $valid + 12 | 0;
    $44 = $ttcmap;
    label = 7;
    break;
   case 7:
    $p_0_load39 = $p;
    $46 = $p_0_load39 + 8 | 0;
    $47 = $46 >>> 0 > $5 >>> 0;
    if ($47) {
      label = 20;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $p_0_load40 = $p;
    $49 = $p_0_load40 + 2 | 0;
    $p = $49;
    $p_0_load41 = $p;
    $50 = $p_0_load41 - 2 | 0;
    $51 = HEAP8[$50] | 0;
    $52 = $51 & 255;
    $53 = $52 << 8;
    $p_0_load42 = $p;
    $54 = $p_0_load42 - 1 | 0;
    $55 = HEAP8[$54] | 0;
    $56 = $55 & 255;
    $57 = $56 | $53;
    HEAP16[$35 >> 1] = $57;
    $p_0_load43 = $p;
    $58 = $p_0_load43 + 2 | 0;
    $p = $58;
    $p_0_load44 = $p;
    $59 = $p_0_load44 - 2 | 0;
    $60 = HEAP8[$59] | 0;
    $61 = $60 & 255;
    $62 = $61 << 8;
    $p_0_load45 = $p;
    $63 = $p_0_load45 - 1 | 0;
    $64 = HEAP8[$63] | 0;
    $65 = $64 & 255;
    $66 = $65 | $62;
    HEAP16[$36 >> 1] = $66;
    HEAP32[$37 >> 2] = $6;
    HEAP32[$38 >> 2] = 0;
    $p_0_load46 = $p;
    $67 = $p_0_load46 + 4 | 0;
    $p = $67;
    $p_0_load47 = $p;
    $68 = $p_0_load47 - 4 | 0;
    $69 = HEAP8[$68] | 0;
    $70 = $69 & 255;
    $71 = $70 << 24;
    $p_0_load48 = $p;
    $72 = $p_0_load48 - 3 | 0;
    $73 = HEAP8[$72] | 0;
    $74 = $73 & 255;
    $75 = $74 << 16;
    $76 = $75 | $71;
    $p_0_load49 = $p;
    $77 = $p_0_load49 - 2 | 0;
    $78 = HEAP8[$77] | 0;
    $79 = $78 & 255;
    $80 = $79 << 8;
    $81 = $76 | $80;
    $p_0_load50 = $p;
    $82 = $p_0_load50 - 1 | 0;
    $83 = HEAP8[$82] | 0;
    $84 = $83 & 255;
    $85 = $81 | $84;
    $86 = ($85 | 0) == 0;
    if ($86) {
      label = 19;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $88 = HEAP32[$3 >> 2] | 0;
    $89 = $88 - 2 | 0;
    $90 = $85 >>> 0 > $89 >>> 0;
    if ($90) {
      label = 19;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $92 = $2 + $85 | 0;
    $cmap = $92;
    $cmap_0_load11 = $cmap;
    $93 = HEAP8[$cmap_0_load11] | 0;
    $94 = $93 & 255;
    $95 = $94 << 8;
    $cmap_0_load12 = $cmap;
    $96 = $cmap_0_load12 + 1 | 0;
    $97 = HEAP8[$96] | 0;
    $98 = $97 & 255;
    $99 = $98 | $95;
    $format = $99;
    $pclazz = 5244372;
    $pclazz_0_load654 = $pclazz;
    $100 = HEAP32[$pclazz_0_load654 >> 2] | 0;
    $101 = ($100 | 0) == 0;
    if ($101) {
      label = 18;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $pclazz_0_load7 = $pclazz;
    $102 = HEAP32[$pclazz_0_load7 >> 2] | 0;
    $clazz = $102;
    $clazz_0_load3 = $clazz;
    $103 = $clazz_0_load3 + 40 | 0;
    $104 = HEAP32[$103 >> 2] | 0;
    $format_0_load10 = $format;
    $105 = ($104 | 0) == ($format_0_load10 | 0);
    if ($105) {
      label = 12;
      break;
    } else {
      label = 17;
      break;
    }
   case 12:
    $error = 0;
    $cmap_0_load13 = $cmap;
    invoke_viiii(40, $39 | 0, $cmap_0_load13 | 0, $5 | 0, 0);
    if ((__THREW__ | 0) != 0 & (threwValue | 0) > 0) {
      setjmpLabel = _testSetjmp(HEAP32[__THREW__ >> 2] | 0, setjmpTable);
      if ((setjmpLabel | 0) > 0) {
        label = -1111;
        break;
      } else return;
    }
    __THREW__ = threwValue = 0;
    $107 = HEAP16[$40 >> 1] | 0;
    $108 = $107 & 65535;
    HEAP32[$41 >> 2] = $108;
    $109 = _saveSetjmp($42 | 0, label, setjmpTable);
    label = 21;
    break;
   case 21:
    $110 = ($109 | 0) == 0;
    if ($110) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    $clazz_0_load4 = $clazz;
    $112 = $clazz_0_load4 + 44 | 0;
    $113 = HEAP32[$112 >> 2] | 0;
    $cmap_0_load14 = $cmap;
    $114 = FUNCTION_TABLE_iii[$113 & 1023]($cmap_0_load14, $39) | 0;
    if ((__THREW__ | 0) != 0 & (threwValue | 0) > 0) {
      setjmpLabel = _testSetjmp(HEAP32[__THREW__ >> 2] | 0, setjmpTable);
      if ((setjmpLabel | 0) > 0) {
        label = -1111;
        break;
      } else return;
    }
    __THREW__ = threwValue = 0;
    $error = $114;
    label = 14;
    break;
   case 14:
    $116 = HEAP32[$43 >> 2] | 0;
    $117 = ($116 | 0) == 0;
    if ($117) {
      label = 15;
      break;
    } else {
      label = 18;
      break;
    }
   case 15:
    $clazz_0_load5 = $clazz;
    $cmap_0_load15 = $cmap;
    $119 = $clazz_0_load5;
    $120 = invoke_iiiii(564, $119 | 0, $cmap_0_load15 | 0, $charmap | 0, $44 | 0) | 0;
    if ((__THREW__ | 0) != 0 & (threwValue | 0) > 0) {
      setjmpLabel = _testSetjmp(HEAP32[__THREW__ >> 2] | 0, setjmpTable);
      if ((setjmpLabel | 0) > 0) {
        label = -1111;
        break;
      } else return;
    }
    __THREW__ = threwValue = 0;
    $121 = ($120 | 0) == 0;
    if ($121) {
      label = 16;
      break;
    } else {
      label = 18;
      break;
    }
   case 16:
    $error_0_load1 = $error;
    $123 = HEAP32[$ttcmap >> 2] | 0;
    $124 = $123 + 20 | 0;
    HEAP32[$124 >> 2] = $error_0_load1;
    label = 18;
    break;
   case 17:
    $pclazz_0_load8 = $pclazz;
    $126 = $pclazz_0_load8 + 4 | 0;
    $pclazz = $126;
    $pclazz_0_load6 = $pclazz;
    $127 = HEAP32[$pclazz_0_load6 >> 2] | 0;
    $128 = ($127 | 0) == 0;
    if ($128) {
      label = 18;
      break;
    } else {
      label = 11;
      break;
    }
   case 18:
    $pclazz_0_load9 = $pclazz;
    label = 19;
    break;
   case 19:
    $num_cmaps_0_load53 = $num_cmaps;
    $130 = $num_cmaps_0_load53 - 1 | 0;
    $num_cmaps = $130;
    $num_cmaps_0_load52 = $num_cmaps;
    $131 = ($num_cmaps_0_load52 | 0) == 0;
    if ($131) {
      label = 20;
      break;
    } else {
      label = 7;
      break;
    }
   case 20:
    STACKTOP = __stackBase__;
    return;
   case -1111:
    if ((setjmpLabel | 0) == 12) {
      $109 = threwValue;
      label = 21;
    }
    __THREW__ = threwValue = 0;
    break;
  }
}
function _tt_name_entry_ascii_from_utf16($entry, $memory) {
  $entry = $entry | 0;
  $memory = $memory | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $read_016 = 0, $n_015 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $_off = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $entry + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $entry + 8 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 & 65535;
    $6 = $5 >>> 1;
    $7 = $6 + 1 | 0;
    $8 = _ft_mem_realloc($memory, 1, 0, $7, 0, $error) | 0;
    $9 = HEAP32[$error >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 5;
      break;
    }
   case 2:
    $11 = ($6 | 0) == 0;
    if ($11) {
      label = 4;
      break;
    } else {
      $n_015 = 0;
      $read_016 = $2;
      label = 3;
      break;
    }
   case 3:
    $12 = $read_016 + 2 | 0;
    $13 = HEAP8[$read_016] | 0;
    $14 = $13 & 255;
    $15 = $14 << 8;
    $16 = $read_016 + 1 | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 & 255;
    $19 = $15 | $18;
    $_off = $19 - 32 | 0;
    $20 = $_off >>> 0 > 95;
    $21 = $20 ? 63 : $17;
    $22 = $8 + $n_015 | 0;
    HEAP8[$22] = $21;
    $23 = $n_015 + 1 | 0;
    $24 = $23 >>> 0 < $6 >>> 0;
    if ($24) {
      $n_015 = $23;
      $read_016 = $12;
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $25 = $8 + $6 | 0;
    HEAP8[$25] = 0;
    $_0 = $8;
    label = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _tt_name_entry_ascii_from_other($entry, $memory) {
  $entry = $entry | 0;
  $memory = $memory | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $read_014 = 0, $n_013 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $or_cond = 0, $_ = 0, $17 = 0, $18 = 0, $exitcond = 0, $19 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $entry + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $entry + 8 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 & 65535;
    $6 = $5 + 1 | 0;
    $7 = _ft_mem_realloc($memory, 1, 0, $6, 0, $error) | 0;
    $8 = HEAP32[$error >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 6;
      break;
    }
   case 2:
    $10 = $4 << 16 >> 16 == 0;
    if ($10) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = $4 & 65535;
    $n_013 = 0;
    $read_014 = $2;
    label = 4;
    break;
   case 4:
    $13 = $read_014 + 1 | 0;
    $14 = HEAP8[$read_014] | 0;
    $15 = ($14 & 255) < 32;
    $16 = $14 << 24 >> 24 < 0;
    $or_cond = $15 | $16;
    $_ = $or_cond ? 63 : $14;
    $17 = $7 + $n_013 | 0;
    HEAP8[$17] = $_;
    $18 = $n_013 + 1 | 0;
    $exitcond = ($18 | 0) == ($11 | 0);
    if ($exitcond) {
      label = 5;
      break;
    } else {
      $n_013 = $18;
      $read_014 = $13;
      label = 4;
      break;
    }
   case 5:
    $19 = $7 + $5 | 0;
    HEAP8[$19] = 0;
    $_0 = $7;
    label = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _sfnt_open_font($stream, $face) {
  $stream = $stream | 0;
  $face = $face | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $n_039 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $46 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 132 | 0;
    $4 = $3 | 0;
    HEAP32[$4 >> 2] = 0;
    $5 = $face + 136 | 0;
    HEAP32[$5 >> 2] = 0;
    $6 = $face + 140 | 0;
    HEAP32[$6 >> 2] = 0;
    $7 = _FT_Stream_Pos($stream) | 0;
    $8 = _FT_Stream_ReadLong($stream, $error) | 0;
    $9 = HEAP32[$error >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 2;
      break;
    } else {
      $_0 = $9;
      label = 13;
      break;
    }
   case 2:
    if (($8 | 0) == 1954115633 | ($8 | 0) == 1953784678 | ($8 | 0) == 1953658213 | ($8 | 0) == 1330926671 | ($8 | 0) == 131072 | ($8 | 0) == 65536) {
      label = 3;
      break;
    } else {
      $_0 = 2;
      label = 13;
      break;
    }
   case 3:
    HEAP32[$4 >> 2] = 1953784678;
    $13 = ($8 | 0) == 1953784678;
    if ($13) {
      label = 4;
      break;
    } else {
      label = 10;
      break;
    }
   case 4:
    $15 = $3;
    $16 = _FT_Stream_ReadFields($stream, 5249468, $15) | 0;
    HEAP32[$error >> 2] = $16;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 5;
      break;
    } else {
      $_0 = $16;
      label = 13;
      break;
    }
   case 5:
    $19 = HEAP32[$6 >> 2] | 0;
    $20 = _ft_mem_realloc($2, 4, 0, $19, 0, $error) | 0;
    $21 = $20;
    $22 = $face + 144 | 0;
    HEAP32[$22 >> 2] = $21;
    $23 = HEAP32[$error >> 2] | 0;
    $24 = ($23 | 0) == 0;
    if ($24) {
      label = 6;
      break;
    } else {
      $_0 = $23;
      label = 13;
      break;
    }
   case 6:
    $26 = HEAP32[$6 >> 2] | 0;
    $27 = $26 << 2;
    $28 = _FT_Stream_EnterFrame($stream, $27) | 0;
    HEAP32[$error >> 2] = $28;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 7;
      break;
    } else {
      $_0 = $28;
      label = 13;
      break;
    }
   case 7:
    $30 = HEAP32[$6 >> 2] | 0;
    $31 = ($30 | 0) > 0;
    if ($31) {
      $n_039 = 0;
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $32 = _FT_Stream_GetLong($stream) | 0;
    $33 = HEAP32[$22 >> 2] | 0;
    $34 = $33 + ($n_039 << 2) | 0;
    HEAP32[$34 >> 2] = $32;
    $35 = $n_039 + 1 | 0;
    $36 = HEAP32[$6 >> 2] | 0;
    $37 = ($35 | 0) < ($36 | 0);
    if ($37) {
      $n_039 = $35;
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    _FT_Stream_ExitFrame($stream);
    label = 12;
    break;
   case 10:
    HEAP32[$5 >> 2] = 65536;
    HEAP32[$6 >> 2] = 1;
    $39 = _ft_mem_alloc($2, 4, $error) | 0;
    $40 = $39;
    $41 = $face + 144 | 0;
    HEAP32[$41 >> 2] = $40;
    $42 = HEAP32[$error >> 2] | 0;
    $43 = ($42 | 0) == 0;
    if ($43) {
      label = 11;
      break;
    } else {
      $_0 = $42;
      label = 13;
      break;
    }
   case 11:
    HEAP32[$40 >> 2] = $7;
    label = 12;
    break;
   case 12:
    $46 = HEAP32[$error >> 2] | 0;
    $_0 = $46;
    label = 13;
    break;
   case 13:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap14_get_nondef_chars($cmap, $p, $memory) {
  $cmap = $cmap | 0;
  $p = $p | 0;
  $memory = $memory | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $i_022 = 0, $_02021 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $exitcond = 0, $i_0_lcssa = 0, $44 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap;
    $2 = HEAP8[$p] | 0;
    $3 = $2 & 255;
    $4 = $3 << 24;
    $5 = $p + 1 | 0;
    $6 = HEAP8[$5] | 0;
    $7 = $6 & 255;
    $8 = $7 << 16;
    $9 = $8 | $4;
    $10 = $p + 2 | 0;
    $11 = HEAP8[$10] | 0;
    $12 = $11 & 255;
    $13 = $12 << 8;
    $14 = $9 | $13;
    $15 = $p + 3 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 & 255;
    $18 = $14 | $17;
    $19 = $18 + 1 | 0;
    $20 = _tt_cmap14_ensure($1, $19, $memory) | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 6;
      break;
    }
   case 2:
    $23 = $cmap + 32 | 0;
    $24 = $23;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = ($18 | 0) == 0;
    if ($26) {
      $i_0_lcssa = 0;
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $27 = $p + 4 | 0;
    $_02021 = $27;
    $i_022 = 0;
    label = 4;
    break;
   case 4:
    $29 = HEAP8[$_02021] | 0;
    $30 = $29 & 255;
    $31 = $30 << 16;
    $32 = $_02021 + 1 | 0;
    $33 = HEAP8[$32] | 0;
    $34 = $33 & 255;
    $35 = $34 << 8;
    $36 = $35 | $31;
    $37 = $_02021 + 2 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 & 255;
    $40 = $36 | $39;
    $41 = $25 + ($i_022 << 2) | 0;
    HEAP32[$41 >> 2] = $40;
    $42 = $_02021 + 5 | 0;
    $43 = $i_022 + 1 | 0;
    $exitcond = ($43 | 0) == ($18 | 0);
    if ($exitcond) {
      $i_0_lcssa = $18;
      label = 5;
      break;
    } else {
      $_02021 = $42;
      $i_022 = $43;
      label = 4;
      break;
    }
   case 5:
    $44 = $25 + ($i_0_lcssa << 2) | 0;
    HEAP32[$44 >> 2] = 0;
    $_0 = $25;
    label = 6;
    break;
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap14_get_def_chars($cmap, $p, $memory) {
  $cmap = $cmap | 0;
  $p = $p | 0;
  $memory = $memory | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $p_pn = 0, $q_025 = 0, $numRanges_024 = 0, $_02126 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $cnt_0 = 0, $q_1 = 0, $uni_0 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $scevgep_sum = 0, $scevgep27 = 0, $51 = 0, $52 = 0, $q_0_lcssa = 0, $53 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap;
    $2 = _tt_cmap14_def_char_count($p) | 0;
    $3 = HEAP8[$p] | 0;
    $4 = $p + 1 | 0;
    $5 = HEAP8[$4] | 0;
    $6 = $p + 2 | 0;
    $7 = HEAP8[$6] | 0;
    $8 = $p + 3 | 0;
    $9 = HEAP8[$8] | 0;
    $10 = $2 + 1 | 0;
    $11 = _tt_cmap14_ensure($1, $10, $memory) | 0;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 7;
      break;
    }
   case 2:
    $14 = $5 & 255;
    $15 = $3 & 255;
    $16 = $7 & 255;
    $17 = $14 << 16;
    $18 = $15 << 24;
    $19 = $16 << 8;
    $20 = $17 | $18;
    $21 = $9 & 255;
    $22 = $20 | $19;
    $23 = $22 | $21;
    $24 = $cmap + 32 | 0;
    $25 = $24;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = ($23 | 0) == 0;
    if ($27) {
      $q_0_lcssa = $26;
      label = 6;
      break;
    } else {
      $numRanges_024 = $23;
      $q_025 = $26;
      $p_pn = $p;
      label = 3;
      break;
    }
   case 3:
    $_02126 = $p_pn + 4 | 0;
    $28 = $p_pn + 7 | 0;
    $29 = HEAP8[$_02126] | 0;
    $30 = $29 & 255;
    $31 = $30 << 16;
    $32 = $p_pn + 5 | 0;
    $33 = HEAP8[$32] | 0;
    $34 = $33 & 255;
    $35 = $34 << 8;
    $36 = $35 | $31;
    $37 = $p_pn + 6 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 & 255;
    $40 = $36 | $39;
    $41 = HEAP8[$28] | 0;
    $42 = $41 & 255;
    $43 = $42 + 1 | 0;
    $44 = $41 & 255;
    $uni_0 = $40;
    $q_1 = $q_025;
    $cnt_0 = $43;
    label = 4;
    break;
   case 4:
    HEAP32[$q_1 >> 2] = $uni_0;
    $46 = $uni_0 + 1 | 0;
    $47 = $q_1 + 4 | 0;
    $48 = $cnt_0 - 1 | 0;
    $49 = ($48 | 0) == 0;
    if ($49) {
      label = 5;
      break;
    } else {
      $uni_0 = $46;
      $q_1 = $47;
      $cnt_0 = $48;
      label = 4;
      break;
    }
   case 5:
    $scevgep_sum = $44 + 1 | 0;
    $scevgep27 = $q_025 + ($scevgep_sum << 2) | 0;
    $51 = $numRanges_024 - 1 | 0;
    $52 = ($51 | 0) == 0;
    if ($52) {
      $q_0_lcssa = $scevgep27;
      label = 6;
      break;
    } else {
      $numRanges_024 = $51;
      $q_025 = $scevgep27;
      $p_pn = $_02126;
      label = 3;
      break;
    }
   case 6:
    HEAP32[$q_0_lcssa >> 2] = 0;
    $53 = HEAP32[$25 >> 2] | 0;
    $_0 = $53;
    label = 7;
    break;
   case 7:
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap14_ensure($cmap, $num_results, $memory) {
  $cmap = $cmap | 0;
  $num_results = $num_results | 0;
  $memory = $memory | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $16 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $cmap + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $3 = HEAP32[$1 >> 2] | 0;
    $4 = $3 >>> 0 < $num_results >>> 0;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $6 = $cmap + 36 | 0;
    HEAP32[$6 >> 2] = $memory;
    $7 = $cmap + 32 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8;
    $10 = _ft_mem_realloc($memory, 4, $2, $num_results, $9, $error) | 0;
    $11 = $10;
    HEAP32[$7 >> 2] = $11;
    $12 = HEAP32[$error >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 3;
      break;
    } else {
      $_0 = $12;
      label = 5;
      break;
    }
   case 3:
    HEAP32[$1 >> 2] = $num_results;
    label = 4;
    break;
   case 4:
    $16 = HEAP32[$error >> 2] | 0;
    $_0 = $16;
    label = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap13_next($cmap) {
  $cmap = $cmap | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $n_0 = 0, $char_code_0 = 0, $12 = 0, $14 = 0, $15 = 0, $_sum31 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $_sum32 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $_sum33 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $_sum34 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $_sum35 = 0, $34 = 0, $_sum36 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $_sum37 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $_sum38 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $_sum39 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $_sum40 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $_sum41 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $_sum42 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $_char_code_0 = 0, $71 = 0, $72 = 0, $or_cond = 0, $73 = 0, $75 = 0, $76 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == -1;
    if ($3) {
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 + 1 | 0;
    $6 = $cmap + 36 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $cmap + 40 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $cmap + 16 | 0;
    $char_code_0 = $5;
    $n_0 = $7;
    label = 3;
    break;
   case 3:
    $12 = $n_0 >>> 0 < $9 >>> 0;
    if ($12) {
      label = 4;
      break;
    } else {
      label = 6;
      break;
    }
   case 4:
    $14 = HEAP32[$10 >> 2] | 0;
    $15 = $n_0 * 12 & -1;
    $_sum31 = $15 + 16 | 0;
    $16 = $14 + $_sum31 | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 & 255;
    $19 = $18 << 24;
    $_sum32 = $15 + 17 | 0;
    $20 = $14 + $_sum32 | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $21 & 255;
    $23 = $22 << 16;
    $24 = $23 | $19;
    $_sum33 = $15 + 18 | 0;
    $25 = $14 + $_sum33 | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 & 255;
    $28 = $27 << 8;
    $29 = $24 | $28;
    $_sum34 = $15 + 19 | 0;
    $30 = $14 + $_sum34 | 0;
    $31 = HEAP8[$30] | 0;
    $32 = $31 & 255;
    $33 = $29 | $32;
    $_sum35 = $15 + 24 | 0;
    $34 = $14 + $_sum35 | 0;
    $_sum36 = $15 + 20 | 0;
    $35 = $14 + $_sum36 | 0;
    $36 = HEAP8[$35] | 0;
    $37 = $36 & 255;
    $38 = $37 << 24;
    $_sum37 = $15 + 21 | 0;
    $39 = $14 + $_sum37 | 0;
    $40 = HEAP8[$39] | 0;
    $41 = $40 & 255;
    $42 = $41 << 16;
    $43 = $42 | $38;
    $_sum38 = $15 + 22 | 0;
    $44 = $14 + $_sum38 | 0;
    $45 = HEAP8[$44] | 0;
    $46 = $45 & 255;
    $47 = $46 << 8;
    $48 = $43 | $47;
    $_sum39 = $15 + 23 | 0;
    $49 = $14 + $_sum39 | 0;
    $50 = HEAP8[$49] | 0;
    $51 = $50 & 255;
    $52 = $48 | $51;
    $53 = HEAP8[$34] | 0;
    $54 = $53 & 255;
    $55 = $54 << 24;
    $_sum40 = $15 + 25 | 0;
    $56 = $14 + $_sum40 | 0;
    $57 = HEAP8[$56] | 0;
    $58 = $57 & 255;
    $59 = $58 << 16;
    $60 = $59 | $55;
    $_sum41 = $15 + 26 | 0;
    $61 = $14 + $_sum41 | 0;
    $62 = HEAP8[$61] | 0;
    $63 = $62 & 255;
    $64 = $63 << 8;
    $65 = $60 | $64;
    $_sum42 = $15 + 27 | 0;
    $66 = $14 + $_sum42 | 0;
    $67 = HEAP8[$66] | 0;
    $68 = $67 & 255;
    $69 = $65 | $68;
    $70 = $char_code_0 >>> 0 < $33 >>> 0;
    $_char_code_0 = $70 ? $33 : $char_code_0;
    $71 = $_char_code_0 >>> 0 > $52 >>> 0;
    $72 = ($69 | 0) == 0;
    $or_cond = $71 | $72;
    $73 = $n_0 + 1 | 0;
    if ($or_cond) {
      $char_code_0 = $_char_code_0;
      $n_0 = $73;
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    HEAP32[$1 >> 2] = $_char_code_0;
    $75 = $cmap + 32 | 0;
    HEAP32[$75 >> 2] = $69;
    HEAP32[$6 >> 2] = $n_0;
    label = 7;
    break;
   case 6:
    $76 = $cmap + 24 | 0;
    HEAP8[$76] = 0;
    label = 7;
    break;
   case 7:
    return;
  }
}
function _tt_cmap12_next($cmap) {
  $cmap = $cmap | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $char_code_049 = 0, $n_048 = 0, $14 = 0, $_sum33 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $_sum34 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $_sum35 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $_sum36 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $_sum37 = 0, $33 = 0, $_sum38 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $_sum39 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $_sum40 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $_sum41 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $_sum42 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $_sum43 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $_sum44 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $_char_code_0 = 0, $char_code_1 = 0, $71 = 0, $73 = 0, $74 = 0, $75 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == -1;
    if ($3) {
      label = 9;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $cmap + 36 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $cmap + 40 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $6 >>> 0 < $8 >>> 0;
    if ($9) {
      label = 3;
      break;
    } else {
      label = 9;
      break;
    }
   case 3:
    $10 = $2 + 1 | 0;
    $11 = $cmap + 16 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $n_048 = $6;
    $char_code_049 = $10;
    label = 4;
    break;
   case 4:
    $14 = $n_048 * 12 & -1;
    $_sum33 = $14 + 16 | 0;
    $15 = $12 + $_sum33 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 & 255;
    $18 = $17 << 24;
    $_sum34 = $14 + 17 | 0;
    $19 = $12 + $_sum34 | 0;
    $20 = HEAP8[$19] | 0;
    $21 = $20 & 255;
    $22 = $21 << 16;
    $23 = $22 | $18;
    $_sum35 = $14 + 18 | 0;
    $24 = $12 + $_sum35 | 0;
    $25 = HEAP8[$24] | 0;
    $26 = $25 & 255;
    $27 = $26 << 8;
    $28 = $23 | $27;
    $_sum36 = $14 + 19 | 0;
    $29 = $12 + $_sum36 | 0;
    $30 = HEAP8[$29] | 0;
    $31 = $30 & 255;
    $32 = $28 | $31;
    $_sum37 = $14 + 24 | 0;
    $33 = $12 + $_sum37 | 0;
    $_sum38 = $14 + 20 | 0;
    $34 = $12 + $_sum38 | 0;
    $35 = HEAP8[$34] | 0;
    $36 = $35 & 255;
    $37 = $36 << 24;
    $_sum39 = $14 + 21 | 0;
    $38 = $12 + $_sum39 | 0;
    $39 = HEAP8[$38] | 0;
    $40 = $39 & 255;
    $41 = $40 << 16;
    $42 = $41 | $37;
    $_sum40 = $14 + 22 | 0;
    $43 = $12 + $_sum40 | 0;
    $44 = HEAP8[$43] | 0;
    $45 = $44 & 255;
    $46 = $45 << 8;
    $47 = $42 | $46;
    $_sum41 = $14 + 23 | 0;
    $48 = $12 + $_sum41 | 0;
    $49 = HEAP8[$48] | 0;
    $50 = $49 & 255;
    $51 = $47 | $50;
    $52 = HEAP8[$33] | 0;
    $53 = $52 & 255;
    $54 = $53 << 24;
    $_sum42 = $14 + 25 | 0;
    $55 = $12 + $_sum42 | 0;
    $56 = HEAP8[$55] | 0;
    $57 = $56 & 255;
    $58 = $57 << 16;
    $59 = $58 | $54;
    $_sum43 = $14 + 26 | 0;
    $60 = $12 + $_sum43 | 0;
    $61 = HEAP8[$60] | 0;
    $62 = $61 & 255;
    $63 = $62 << 8;
    $64 = $59 | $63;
    $_sum44 = $14 + 27 | 0;
    $65 = $12 + $_sum44 | 0;
    $66 = HEAP8[$65] | 0;
    $67 = $66 & 255;
    $68 = $64 | $67;
    $69 = $char_code_049 >>> 0 < $32 >>> 0;
    $_char_code_0 = $69 ? $32 : $char_code_049;
    $char_code_1 = $_char_code_0;
    label = 5;
    break;
   case 5:
    $71 = $char_code_1 >>> 0 > $51 >>> 0;
    if ($71) {
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $73 = $char_code_1 + $68 | 0;
    $74 = ($73 | 0) == ($32 | 0);
    $75 = $char_code_1 + 1 | 0;
    if ($74) {
      $char_code_1 = $75;
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $77 = $73 - $32 | 0;
    HEAP32[$1 >> 2] = $char_code_1;
    $78 = $cmap + 32 | 0;
    HEAP32[$78 >> 2] = $77;
    HEAP32[$5 >> 2] = $n_048;
    label = 10;
    break;
   case 8:
    $80 = $n_048 + 1 | 0;
    $81 = HEAP32[$7 >> 2] | 0;
    $82 = $80 >>> 0 < $81 >>> 0;
    if ($82) {
      $n_048 = $80;
      $char_code_049 = $char_code_1;
      label = 4;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $83 = $cmap + 24 | 0;
    HEAP8[$83] = 0;
    label = 10;
    break;
   case 10:
    return;
  }
}
function _tt_cmap4_char_map_linear($cmap, $pcharcode, $next) {
  $cmap = $cmap | 0;
  $pcharcode = $pcharcode | 0;
  $next = $next | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_masked = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $_ = 0, $_sum = 0, $_sum5354 = 0, $_sum55 = 0, $_sum5657 = 0, $17 = 0, $18 = 0, $_sum6076 = 0, $charcode_0 = 0, $gindex_0 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $q_075 = 0, $p_074 = 0, $i_073 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $or_cond = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $or_cond62 = 0, $63 = 0, $or_cond63 = 0, $65 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $_sum61 = 0, $75 = 0, $76 = 0, $_64 = 0, $_65 = 0, $delta_0 = 0, $offset_0 = 0, $79 = 0, $80 = 0, $81 = 0, $_sum58 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $_sum59 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $92 = 0, $93 = 0, $delta_068 = 0, $94 = 0, $95 = 0, $p_1 = 0, $97 = 0, $98 = 0, $gindex_1 = 0, $99 = 0, $or_cond66 = 0, $100 = 0, $gindex_2 = 0, $102 = 0, $103 = 0, $or_cond67 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 6 | 0;
    $4 = HEAP8[$3] | 0;
    $5 = $4 & 255;
    $6 = $5 << 8;
    $7 = $2 + 7 | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 & 255;
    $_masked = $9 & 254;
    $10 = $_masked | $6;
    $11 = $10 >>> 1;
    $12 = ($11 | 0) == 0;
    if ($12) {
      $_0 = 0;
      label = 17;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $14 = HEAP32[$pcharcode >> 2] | 0;
    $15 = $next << 24 >> 24 != 0;
    $16 = $15 & 1;
    $_ = $14 + $16 | 0;
    $_sum = $10 + 16 | 0;
    $_sum5354 = $10 | 1;
    $_sum55 = $10 << 1;
    $_sum5657 = $_sum55 | 1;
    $17 = $11 - 1 | 0;
    $18 = $cmap | 0;
    $_sum6076 = $_sum55 | 2;
    $gindex_0 = 0;
    $charcode_0 = $_;
    label = 3;
    break;
   case 3:
    $20 = $charcode_0 >>> 0 < 65536;
    if ($20) {
      label = 4;
      break;
    } else {
      $gindex_2 = $gindex_0;
      label = 15;
      break;
    }
   case 4:
    $21 = HEAP32[$1 >> 2] | 0;
    $22 = $21 + $_sum | 0;
    $23 = $21 + 14 | 0;
    $i_073 = 0;
    $p_074 = $23;
    $q_075 = $22;
    label = 5;
    break;
   case 5:
    $25 = $p_074 + 2 | 0;
    $26 = HEAP8[$p_074] | 0;
    $27 = $26 & 255;
    $28 = $27 << 8;
    $29 = $p_074 + 1 | 0;
    $30 = HEAP8[$29] | 0;
    $31 = $30 & 255;
    $32 = $28 | $31;
    $33 = $q_075 + 2 | 0;
    $34 = HEAP8[$q_075] | 0;
    $35 = $34 & 255;
    $36 = $35 << 8;
    $37 = $q_075 + 1 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 & 255;
    $40 = $36 | $39;
    $41 = $charcode_0 >>> 0 < $40 >>> 0;
    $42 = $charcode_0 >>> 0 > $32 >>> 0;
    $or_cond = $41 | $42;
    if ($or_cond) {
      $p_1 = $25;
      label = 13;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $44 = $q_075 + $10 | 0;
    $45 = HEAP8[$44] | 0;
    $46 = $45 & 255;
    $47 = $46 << 8;
    $48 = $q_075 + $_sum5354 | 0;
    $49 = HEAP8[$48] | 0;
    $50 = $49 & 255;
    $51 = $47 | $50;
    $52 = $51 << 16 >> 16;
    $53 = $q_075 + $_sum55 | 0;
    $54 = HEAP8[$53] | 0;
    $55 = $54 & 255;
    $56 = $55 << 8;
    $57 = $q_075 + $_sum5657 | 0;
    $58 = HEAP8[$57] | 0;
    $59 = $58 & 255;
    $60 = $56 | $59;
    $61 = $i_073 >>> 0 >= $17 >>> 0;
    $62 = ($40 | 0) == 65535;
    $or_cond62 = $61 & $62;
    $63 = ($32 | 0) == 65535;
    $or_cond63 = $or_cond62 & $63;
    if ($or_cond63) {
      label = 7;
      break;
    } else {
      $offset_0 = $60;
      $delta_0 = $52;
      label = 9;
      break;
    }
   case 7:
    $65 = HEAP32[$18 >> 2] | 0;
    $66 = ($60 | 0) == 0;
    if ($66) {
      $delta_068 = $52;
      label = 12;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $68 = $65 + 504 | 0;
    $69 = $65 + 500 | 0;
    $70 = $68;
    $71 = HEAP32[$69 >> 2] | 0;
    $72 = HEAP32[$70 >> 2] | 0;
    $73 = $71;
    $74 = $73 + $72 | 0;
    $_sum61 = $_sum6076 + $60 | 0;
    $75 = $q_075 + $_sum61 | 0;
    $76 = $75 >>> 0 > $74 >>> 0;
    $_64 = $76 ? 1 : $52;
    $_65 = $76 ? 0 : $60;
    $offset_0 = $_65;
    $delta_0 = $_64;
    label = 9;
    break;
   case 9:
    if (($offset_0 | 0) == 0) {
      $delta_068 = $delta_0;
      label = 12;
      break;
    } else if (($offset_0 | 0) == 65535) {
      $p_1 = $53;
      label = 13;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $79 = $charcode_0 - $40 | 0;
    $80 = $79 << 1;
    $81 = $80 + $_sum55 | 0;
    $_sum58 = $81 + $offset_0 | 0;
    $82 = $q_075 + $_sum58 | 0;
    $83 = HEAP8[$82] | 0;
    $84 = $83 & 255;
    $85 = $84 << 8;
    $_sum59 = $_sum58 + 1 | 0;
    $86 = $q_075 + $_sum59 | 0;
    $87 = HEAP8[$86] | 0;
    $88 = $87 & 255;
    $89 = $85 | $88;
    $90 = ($89 | 0) == 0;
    if ($90) {
      $gindex_1 = 0;
      label = 14;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $92 = $89 + $delta_0 | 0;
    $93 = $92 & 65535;
    $gindex_1 = $93;
    label = 14;
    break;
   case 12:
    $94 = $delta_068 + $charcode_0 | 0;
    $95 = $94 & 65535;
    $gindex_1 = $95;
    label = 14;
    break;
   case 13:
    $97 = $i_073 + 1 | 0;
    $98 = $97 >>> 0 < $11 >>> 0;
    if ($98) {
      $i_073 = $97;
      $p_074 = $p_1;
      $q_075 = $33;
      label = 5;
      break;
    } else {
      $gindex_1 = $gindex_0;
      label = 14;
      break;
    }
   case 14:
    $99 = ($gindex_1 | 0) == 0;
    $or_cond66 = $15 & $99;
    $100 = $charcode_0 + 1 | 0;
    if ($or_cond66) {
      $gindex_0 = $gindex_1;
      $charcode_0 = $100;
      label = 3;
      break;
    } else {
      $gindex_2 = $gindex_1;
      label = 15;
      break;
    }
   case 15:
    $102 = $next << 24 >> 24 == 0;
    $103 = ($gindex_2 | 0) == 0;
    $or_cond67 = $102 | $103;
    if ($or_cond67) {
      $_0 = $gindex_2;
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    HEAP32[$pcharcode >> 2] = $charcode_0;
    $_0 = $gindex_2;
    label = 17;
    break;
   case 17:
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap13_char_map_binary($cmap, $pchar_code, $next) {
  $cmap = $cmap | 0;
  $pchar_code = $pchar_code | 0;
  $next = $next | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $_ = 0, $end_0_ph = 0, $max_0_ph = 0, $min_0_ph = 0, $end_0 = 0, $min_0 = 0, $mid_0 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $_sum51 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $_sum52 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $_sum53 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $_sum54 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $_sum56 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $_sum57 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $_sum58 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $_sum59 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $71 = 0, $72 = 0, $_sum55 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $_sum60 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $_sum61 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $_sum62 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $gindex_0 = 0, $end_1 = 0, $mid_1 = 0, $93 = 0, $94 = 0, $96 = 0, $97 = 0, $mid_2 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $mid_2_c = 0, $103 = 0, $105 = 0, $106 = 0, $108 = 0, $109 = 0, $110 = 0, $112 = 0, $113 = 0, $gindex_1 = 0, $115 = 0, $117 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 12 | 0;
    $4 = HEAP8[$3] | 0;
    $5 = $4 & 255;
    $6 = $5 << 24;
    $7 = $2 + 13 | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 & 255;
    $10 = $9 << 16;
    $11 = $10 | $6;
    $12 = $2 + 14 | 0;
    $13 = HEAP8[$12] | 0;
    $14 = $13 & 255;
    $15 = $14 << 8;
    $16 = $11 | $15;
    $17 = $2 + 15 | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $18 & 255;
    $20 = $16 | $19;
    $21 = ($20 | 0) == 0;
    if ($21) {
      $_0 = 0;
      label = 17;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $23 = HEAP32[$pchar_code >> 2] | 0;
    $24 = $next << 24 >> 24 != 0;
    $25 = $24 & 1;
    $_ = $23 + $25 | 0;
    $min_0_ph = 0;
    $max_0_ph = $20;
    $end_0_ph = -1;
    label = 3;
    break;
   case 3:
    $mid_0 = $max_0_ph;
    $min_0 = $min_0_ph;
    $end_0 = $end_0_ph;
    label = 4;
    break;
   case 4:
    $27 = $min_0 >>> 0 < $max_0_ph >>> 0;
    if ($27) {
      label = 5;
      break;
    } else {
      $mid_1 = $mid_0;
      $end_1 = $end_0;
      $gindex_0 = 0;
      label = 8;
      break;
    }
   case 5:
    $29 = $min_0 + $max_0_ph | 0;
    $30 = $29 >>> 1;
    $31 = HEAP32[$1 >> 2] | 0;
    $32 = $30 * 12 & -1;
    $_sum51 = $32 + 16 | 0;
    $33 = $31 + $_sum51 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $35 << 24;
    $_sum52 = $32 + 17 | 0;
    $37 = $31 + $_sum52 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 & 255;
    $40 = $39 << 16;
    $41 = $40 | $36;
    $_sum53 = $32 + 18 | 0;
    $42 = $31 + $_sum53 | 0;
    $43 = HEAP8[$42] | 0;
    $44 = $43 & 255;
    $45 = $44 << 8;
    $46 = $41 | $45;
    $_sum54 = $32 + 19 | 0;
    $47 = $31 + $_sum54 | 0;
    $48 = HEAP8[$47] | 0;
    $49 = $48 & 255;
    $50 = $46 | $49;
    $_sum56 = $32 + 20 | 0;
    $51 = $31 + $_sum56 | 0;
    $52 = HEAP8[$51] | 0;
    $53 = $52 & 255;
    $54 = $53 << 24;
    $_sum57 = $32 + 21 | 0;
    $55 = $31 + $_sum57 | 0;
    $56 = HEAP8[$55] | 0;
    $57 = $56 & 255;
    $58 = $57 << 16;
    $59 = $58 | $54;
    $_sum58 = $32 + 22 | 0;
    $60 = $31 + $_sum58 | 0;
    $61 = HEAP8[$60] | 0;
    $62 = $61 & 255;
    $63 = $62 << 8;
    $64 = $59 | $63;
    $_sum59 = $32 + 23 | 0;
    $65 = $31 + $_sum59 | 0;
    $66 = HEAP8[$65] | 0;
    $67 = $66 & 255;
    $68 = $64 | $67;
    $69 = $_ >>> 0 < $50 >>> 0;
    if ($69) {
      $min_0_ph = $min_0;
      $max_0_ph = $30;
      $end_0_ph = $68;
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $71 = $_ >>> 0 > $68 >>> 0;
    $72 = $30 + 1 | 0;
    if ($71) {
      $mid_0 = $30;
      $min_0 = $72;
      $end_0 = $68;
      label = 4;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $_sum55 = $32 + 24 | 0;
    $74 = $31 + $_sum55 | 0;
    $75 = HEAP8[$74] | 0;
    $76 = $75 & 255;
    $77 = $76 << 24;
    $_sum60 = $32 + 25 | 0;
    $78 = $31 + $_sum60 | 0;
    $79 = HEAP8[$78] | 0;
    $80 = $79 & 255;
    $81 = $80 << 16;
    $82 = $81 | $77;
    $_sum61 = $32 + 26 | 0;
    $83 = $31 + $_sum61 | 0;
    $84 = HEAP8[$83] | 0;
    $85 = $84 & 255;
    $86 = $85 << 8;
    $87 = $82 | $86;
    $_sum62 = $32 + 27 | 0;
    $88 = $31 + $_sum62 | 0;
    $89 = HEAP8[$88] | 0;
    $90 = $89 & 255;
    $91 = $87 | $90;
    $mid_1 = $30;
    $end_1 = $68;
    $gindex_0 = $91;
    label = 8;
    break;
   case 8:
    if ($24) {
      label = 9;
      break;
    } else {
      $_0 = $gindex_0;
      label = 17;
      break;
    }
   case 9:
    $93 = $cmap;
    $94 = $_ >>> 0 > $end_1 >>> 0;
    if ($94) {
      label = 10;
      break;
    } else {
      $mid_2 = $mid_1;
      label = 11;
      break;
    }
   case 10:
    $96 = $mid_1 + 1 | 0;
    $97 = ($96 | 0) == ($20 | 0);
    if ($97) {
      $_0 = 0;
      label = 17;
      break;
    } else {
      $mid_2 = $96;
      label = 11;
      break;
    }
   case 11:
    $99 = $cmap + 24 | 0;
    $100 = $99;
    HEAP8[$100] = 1;
    $101 = $cmap + 28 | 0;
    HEAP32[$101 >> 2] = $_;
    $102 = $cmap + 36 | 0;
    $mid_2_c = $mid_2;
    HEAP32[$102 >> 2] = $mid_2_c;
    $103 = ($gindex_0 | 0) == 0;
    if ($103) {
      label = 12;
      break;
    } else {
      label = 14;
      break;
    }
   case 12:
    _tt_cmap13_next($93);
    $105 = HEAP8[$100] | 0;
    $106 = $105 << 24 >> 24 == 0;
    if ($106) {
      $_0 = 0;
      label = 17;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $108 = $cmap + 32 | 0;
    $109 = $108;
    $110 = HEAP32[$109 >> 2] | 0;
    $gindex_1 = $110;
    label = 15;
    break;
   case 14:
    $112 = $cmap + 32 | 0;
    $113 = $112;
    HEAP32[$113 >> 2] = $gindex_0;
    $gindex_1 = $gindex_0;
    label = 15;
    break;
   case 15:
    $115 = ($gindex_1 | 0) == 0;
    if ($115) {
      $_0 = 0;
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $117 = HEAP32[$101 >> 2] | 0;
    HEAP32[$pchar_code >> 2] = $117;
    $_0 = $gindex_1;
    label = 17;
    break;
   case 17:
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap12_char_map_binary($cmap, $pchar_code, $next) {
  $cmap = $cmap | 0;
  $pchar_code = $pchar_code | 0;
  $next = $next | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $_ = 0, $end_0_ph = 0, $max_0_ph = 0, $min_0_ph = 0, $end_0 = 0, $min_0 = 0, $mid_0 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $_sum53 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $_sum54 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $_sum55 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $_sum56 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $_sum58 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $_sum59 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $_sum60 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $_sum61 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $71 = 0, $72 = 0, $_sum57 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $_sum62 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $_sum63 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $_sum64 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $end_1 = 0, $gindex_0 = 0, $mid_1 = 0, $95 = 0, $96 = 0, $98 = 0, $99 = 0, $mid_2 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $mid_2_c = 0, $105 = 0, $107 = 0, $108 = 0, $110 = 0, $111 = 0, $112 = 0, $114 = 0, $115 = 0, $gindex_1 = 0, $117 = 0, $119 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 12 | 0;
    $4 = HEAP8[$3] | 0;
    $5 = $4 & 255;
    $6 = $5 << 24;
    $7 = $2 + 13 | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 & 255;
    $10 = $9 << 16;
    $11 = $10 | $6;
    $12 = $2 + 14 | 0;
    $13 = HEAP8[$12] | 0;
    $14 = $13 & 255;
    $15 = $14 << 8;
    $16 = $11 | $15;
    $17 = $2 + 15 | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $18 & 255;
    $20 = $16 | $19;
    $21 = ($20 | 0) == 0;
    if ($21) {
      $_0 = 0;
      label = 17;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $23 = HEAP32[$pchar_code >> 2] | 0;
    $24 = $next << 24 >> 24 != 0;
    $25 = $24 & 1;
    $_ = $23 + $25 | 0;
    $min_0_ph = 0;
    $max_0_ph = $20;
    $end_0_ph = -1;
    label = 3;
    break;
   case 3:
    $mid_0 = $max_0_ph;
    $min_0 = $min_0_ph;
    $end_0 = $end_0_ph;
    label = 4;
    break;
   case 4:
    $27 = $min_0 >>> 0 < $max_0_ph >>> 0;
    if ($27) {
      label = 5;
      break;
    } else {
      $mid_1 = $mid_0;
      $gindex_0 = 0;
      $end_1 = $end_0;
      label = 8;
      break;
    }
   case 5:
    $29 = $min_0 + $max_0_ph | 0;
    $30 = $29 >>> 1;
    $31 = HEAP32[$1 >> 2] | 0;
    $32 = $30 * 12 & -1;
    $_sum53 = $32 + 16 | 0;
    $33 = $31 + $_sum53 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $35 << 24;
    $_sum54 = $32 + 17 | 0;
    $37 = $31 + $_sum54 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 & 255;
    $40 = $39 << 16;
    $41 = $40 | $36;
    $_sum55 = $32 + 18 | 0;
    $42 = $31 + $_sum55 | 0;
    $43 = HEAP8[$42] | 0;
    $44 = $43 & 255;
    $45 = $44 << 8;
    $46 = $41 | $45;
    $_sum56 = $32 + 19 | 0;
    $47 = $31 + $_sum56 | 0;
    $48 = HEAP8[$47] | 0;
    $49 = $48 & 255;
    $50 = $46 | $49;
    $_sum58 = $32 + 20 | 0;
    $51 = $31 + $_sum58 | 0;
    $52 = HEAP8[$51] | 0;
    $53 = $52 & 255;
    $54 = $53 << 24;
    $_sum59 = $32 + 21 | 0;
    $55 = $31 + $_sum59 | 0;
    $56 = HEAP8[$55] | 0;
    $57 = $56 & 255;
    $58 = $57 << 16;
    $59 = $58 | $54;
    $_sum60 = $32 + 22 | 0;
    $60 = $31 + $_sum60 | 0;
    $61 = HEAP8[$60] | 0;
    $62 = $61 & 255;
    $63 = $62 << 8;
    $64 = $59 | $63;
    $_sum61 = $32 + 23 | 0;
    $65 = $31 + $_sum61 | 0;
    $66 = HEAP8[$65] | 0;
    $67 = $66 & 255;
    $68 = $64 | $67;
    $69 = $_ >>> 0 < $50 >>> 0;
    if ($69) {
      $min_0_ph = $min_0;
      $max_0_ph = $30;
      $end_0_ph = $68;
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $71 = $_ >>> 0 > $68 >>> 0;
    $72 = $30 + 1 | 0;
    if ($71) {
      $mid_0 = $30;
      $min_0 = $72;
      $end_0 = $68;
      label = 4;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $_sum57 = $32 + 24 | 0;
    $74 = $31 + $_sum57 | 0;
    $75 = HEAP8[$74] | 0;
    $76 = $75 & 255;
    $77 = $76 << 24;
    $_sum62 = $32 + 25 | 0;
    $78 = $31 + $_sum62 | 0;
    $79 = HEAP8[$78] | 0;
    $80 = $79 & 255;
    $81 = $80 << 16;
    $82 = $81 | $77;
    $_sum63 = $32 + 26 | 0;
    $83 = $31 + $_sum63 | 0;
    $84 = HEAP8[$83] | 0;
    $85 = $84 & 255;
    $86 = $85 << 8;
    $87 = $82 | $86;
    $_sum64 = $32 + 27 | 0;
    $88 = $31 + $_sum64 | 0;
    $89 = HEAP8[$88] | 0;
    $90 = $89 & 255;
    $91 = $87 | $90;
    $92 = $_ - $50 | 0;
    $93 = $92 + $91 | 0;
    $mid_1 = $30;
    $gindex_0 = $93;
    $end_1 = $68;
    label = 8;
    break;
   case 8:
    if ($24) {
      label = 9;
      break;
    } else {
      $_0 = $gindex_0;
      label = 17;
      break;
    }
   case 9:
    $95 = $cmap;
    $96 = $_ >>> 0 > $end_1 >>> 0;
    if ($96) {
      label = 10;
      break;
    } else {
      $mid_2 = $mid_1;
      label = 11;
      break;
    }
   case 10:
    $98 = $mid_1 + 1 | 0;
    $99 = ($98 | 0) == ($20 | 0);
    if ($99) {
      $_0 = 0;
      label = 17;
      break;
    } else {
      $mid_2 = $98;
      label = 11;
      break;
    }
   case 11:
    $101 = $cmap + 24 | 0;
    $102 = $101;
    HEAP8[$102] = 1;
    $103 = $cmap + 28 | 0;
    HEAP32[$103 >> 2] = $_;
    $104 = $cmap + 36 | 0;
    $mid_2_c = $mid_2;
    HEAP32[$104 >> 2] = $mid_2_c;
    $105 = ($gindex_0 | 0) == 0;
    if ($105) {
      label = 12;
      break;
    } else {
      label = 14;
      break;
    }
   case 12:
    _tt_cmap12_next($95);
    $107 = HEAP8[$102] | 0;
    $108 = $107 << 24 >> 24 == 0;
    if ($108) {
      $_0 = 0;
      label = 17;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $110 = $cmap + 32 | 0;
    $111 = $110;
    $112 = HEAP32[$111 >> 2] | 0;
    $gindex_1 = $112;
    label = 15;
    break;
   case 14:
    $114 = $cmap + 32 | 0;
    $115 = $114;
    HEAP32[$115 >> 2] = $gindex_0;
    $gindex_1 = $gindex_0;
    label = 15;
    break;
   case 15:
    $117 = ($gindex_1 | 0) == 0;
    if ($117) {
      $_0 = 0;
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $119 = HEAP32[$103 >> 2] | 0;
    HEAP32[$pchar_code >> 2] = $119;
    $_0 = $gindex_1;
    label = 17;
    break;
   case 17:
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap4_next($cmap) {
  $cmap = $cmap | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_ = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $charcode_0 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $p_0 = 0, $charcode_1 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $42 = 0, $43 = 0, $charcode_2 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $50 = 0, $51 = 0, $charcode_3 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $_charcode_3 = 0, $59 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 24 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 >>> 0 > 65534;
    if ($3) {
      label = 15;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 + 1 | 0;
    $6 = $cmap + 40 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $5 >>> 0 < $7 >>> 0;
    $_ = $8 ? $7 : $5;
    $9 = $cmap + 52 | 0;
    $10 = $cmap + 44 | 0;
    $11 = $cmap + 48 | 0;
    $12 = $cmap + 36 | 0;
    $charcode_0 = $_;
    label = 3;
    break;
   case 3:
    $14 = HEAP32[$9 >> 2] | 0;
    $15 = HEAP32[$10 >> 2] | 0;
    $16 = HEAP32[$11 >> 2] | 0;
    $17 = $charcode_0 >>> 0 > $15 >>> 0;
    if ($17) {
      $charcode_3 = $charcode_0;
      label = 13;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $19 = ($14 | 0) == 0;
    if ($19) {
      $charcode_2 = $charcode_0;
      label = 10;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $21 = HEAP32[$6 >> 2] | 0;
    $22 = $charcode_0 - $21 | 0;
    $23 = $22 << 1;
    $24 = $14 + $23 | 0;
    $charcode_1 = $charcode_0;
    $p_0 = $24;
    label = 6;
    break;
   case 6:
    $26 = $p_0 + 2 | 0;
    $27 = HEAP8[$p_0] | 0;
    $28 = $27 & 255;
    $29 = $28 << 8;
    $30 = $p_0 + 1 | 0;
    $31 = HEAP8[$30] | 0;
    $32 = $31 & 255;
    $33 = $29 | $32;
    $34 = ($33 | 0) == 0;
    if ($34) {
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $36 = $33 + $16 | 0;
    $37 = $36 & 65535;
    $38 = ($37 | 0) == 0;
    if ($38) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    HEAP32[$1 >> 2] = $charcode_1;
    $40 = $cmap + 28 | 0;
    HEAP32[$40 >> 2] = $37;
    label = 16;
    break;
   case 9:
    $42 = $charcode_1 + 1 | 0;
    $43 = $42 >>> 0 > $15 >>> 0;
    if ($43) {
      $charcode_3 = $42;
      label = 13;
      break;
    } else {
      $charcode_1 = $42;
      $p_0 = $26;
      label = 6;
      break;
    }
   case 10:
    $44 = $charcode_2 + $16 | 0;
    $45 = $44 & 65535;
    $46 = ($45 | 0) == 0;
    if ($46) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    HEAP32[$1 >> 2] = $charcode_2;
    $48 = $cmap + 28 | 0;
    HEAP32[$48 >> 2] = $45;
    label = 16;
    break;
   case 12:
    $50 = $charcode_2 + 1 | 0;
    $51 = $50 >>> 0 > $15 >>> 0;
    if ($51) {
      $charcode_3 = $50;
      label = 13;
      break;
    } else {
      $charcode_2 = $50;
      label = 10;
      break;
    }
   case 13:
    $52 = HEAP32[$12 >> 2] | 0;
    $53 = $52 + 1 | 0;
    $54 = _tt_cmap4_set_range($cmap, $53) | 0;
    $55 = ($54 | 0) < 0;
    if ($55) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $57 = HEAP32[$6 >> 2] | 0;
    $58 = $charcode_3 >>> 0 < $57 >>> 0;
    $_charcode_3 = $58 ? $57 : $charcode_3;
    $charcode_0 = $_charcode_3;
    label = 3;
    break;
   case 15:
    HEAP32[$1 >> 2] = -1;
    $59 = $cmap + 28 | 0;
    HEAP32[$59 >> 2] = 0;
    label = 16;
    break;
   case 16:
    return;
  }
}
function _tt_cmap4_set_range($cmap, $range_index) {
  $cmap = $cmap | 0;
  $range_index = $range_index | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $_03862 = 0, $14 = 0, $_sum = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $_sum39 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $_sum40 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $_sum4142 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $_sum43 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $_sum4445 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $_sum46 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $_sum4748 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $_sum50 = 0, $_sum51 = 0, $66 = 0, $67 = 0, $_sum49 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $76 = 0, $77 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $cmap + 32 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 >>> 0 > $range_index >>> 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $_0 = -1;
      label = 13;
      break;
    }
   case 2:
    $6 = $cmap + 44 | 0;
    $7 = $4 << 1;
    $8 = $7 + 2 | 0;
    $9 = $cmap + 40 | 0;
    $10 = $cmap + 48 | 0;
    $11 = $4 - 1 | 0;
    $12 = $cmap | 0;
    $_03862 = $range_index;
    label = 3;
    break;
   case 3:
    $14 = $_03862 << 1;
    $_sum = $14 + 14 | 0;
    $15 = $2 + $_sum | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 & 255;
    $18 = $17 << 8;
    $_sum39 = $14 + 15 | 0;
    $19 = $2 + $_sum39 | 0;
    $20 = HEAP8[$19] | 0;
    $21 = $20 & 255;
    $22 = $18 | $21;
    HEAP32[$6 >> 2] = $22;
    $_sum40 = $8 + $_sum | 0;
    $23 = $2 + $_sum40 | 0;
    $24 = HEAP8[$23] | 0;
    $25 = $24 & 255;
    $26 = $25 << 8;
    $_sum4142 = $_sum40 | 1;
    $27 = $2 + $_sum4142 | 0;
    $28 = HEAP8[$27] | 0;
    $29 = $28 & 255;
    $30 = $26 | $29;
    HEAP32[$9 >> 2] = $30;
    $_sum43 = $_sum40 + $7 | 0;
    $31 = $2 + $_sum43 | 0;
    $32 = HEAP8[$31] | 0;
    $33 = $32 & 255;
    $34 = $33 << 8;
    $_sum4445 = $_sum43 | 1;
    $35 = $2 + $_sum4445 | 0;
    $36 = HEAP8[$35] | 0;
    $37 = $36 & 255;
    $38 = $34 | $37;
    $39 = $38 << 16 >> 16;
    HEAP32[$10 >> 2] = $39;
    $_sum46 = $_sum43 + $7 | 0;
    $40 = $2 + $_sum46 | 0;
    $41 = HEAP8[$40] | 0;
    $42 = $41 & 255;
    $43 = $42 << 8;
    $_sum4748 = $_sum46 | 1;
    $44 = $2 + $_sum4748 | 0;
    $45 = HEAP8[$44] | 0;
    $46 = $45 & 255;
    $47 = $43 | $46;
    $48 = $_03862 >>> 0 < $11 >>> 0;
    if ($48) {
      label = 9;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $50 = HEAP32[$9 >> 2] | 0;
    $51 = ($50 | 0) == 65535;
    if ($51) {
      label = 5;
      break;
    } else {
      label = 9;
      break;
    }
   case 5:
    $53 = HEAP32[$6 >> 2] | 0;
    $54 = ($53 | 0) == 65535;
    if ($54) {
      label = 6;
      break;
    } else {
      label = 9;
      break;
    }
   case 6:
    $56 = HEAP32[$12 >> 2] | 0;
    $57 = ($47 | 0) == 0;
    if ($57) {
      $72 = 0;
      label = 11;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $59 = $56 + 504 | 0;
    $60 = $56 + 500 | 0;
    $61 = $59;
    $62 = HEAP32[$60 >> 2] | 0;
    $63 = HEAP32[$61 >> 2] | 0;
    $64 = $62;
    $65 = $64 + $63 | 0;
    $_sum50 = $_sum46 + 2 | 0;
    $_sum51 = $_sum50 + $47 | 0;
    $66 = $2 + $_sum51 | 0;
    $67 = $66 >>> 0 > $65 >>> 0;
    if ($67) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    HEAP32[$10 >> 2] = 1;
    $72 = 0;
    label = 11;
    break;
   case 9:
    if (($47 | 0) == 0) {
      $72 = 0;
      label = 11;
      break;
    } else if (($47 | 0) == 65535) {
      label = 12;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $_sum49 = $47 + $_sum46 | 0;
    $71 = $2 + $_sum49 | 0;
    $72 = $71;
    label = 11;
    break;
   case 11:
    $73 = $cmap + 52 | 0;
    HEAP32[$73 >> 2] = $72;
    $74 = $cmap + 36 | 0;
    HEAP32[$74 >> 2] = $_03862;
    $_0 = 0;
    label = 13;
    break;
   case 12:
    $76 = $_03862 + 1 | 0;
    $77 = $76 >>> 0 < $4 >>> 0;
    if ($77) {
      $_03862 = $76;
      label = 3;
      break;
    } else {
      $_0 = -1;
      label = 13;
      break;
    }
   case 13:
    return $_0 | 0;
  }
  return 0;
}
function _tt_cmap2_get_subheader($table, $char_code) {
  $table = $table | 0;
  $char_code = $char_code | 0;
  var $1 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $_sum16 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $_sum17 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $_sum = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $_sum14 = 0, $24 = 0, $25 = 0, $26 = 0, $_masked = 0, $27 = 0, $_sum15 = 0, $28 = 0, $29 = 0, $sub_0 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $char_code >>> 0 < 65536;
    if ($1) {
      label = 2;
      break;
    } else {
      $result_0 = 0;
      label = 6;
      break;
    }
   case 2:
    $3 = $char_code >>> 8;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $6 = $table + 518 | 0;
    $7 = $char_code << 1;
    $8 = $7 & 510;
    $_sum16 = $8 + 6 | 0;
    $9 = $table + $_sum16 | 0;
    $10 = HEAP8[$9] | 0;
    $11 = $10 & 255;
    $12 = $11 << 8;
    $_sum17 = $8 + 7 | 0;
    $13 = $table + $_sum17 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 & 255;
    $16 = $12 | $15;
    $17 = ($16 | 0) == 0;
    if ($17) {
      $sub_0 = $6;
      label = 5;
      break;
    } else {
      $result_0 = 0;
      label = 6;
      break;
    }
   case 4:
    $19 = $3 << 1;
    $_sum = $19 + 6 | 0;
    $20 = $table + $_sum | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $21 & 255;
    $23 = $22 << 8;
    $_sum14 = $19 + 7 | 0;
    $24 = $table + $_sum14 | 0;
    $25 = HEAP8[$24] | 0;
    $26 = $25 & 255;
    $_masked = $26 & 248;
    $27 = $_masked | $23;
    $_sum15 = $27 + 518 | 0;
    $28 = $table + $_sum15 | 0;
    $29 = ($27 | 0) == 0;
    if ($29) {
      $result_0 = 0;
      label = 6;
      break;
    } else {
      $sub_0 = $28;
      label = 5;
      break;
    }
   case 5:
    $result_0 = $sub_0;
    label = 6;
    break;
   case 6:
    return $result_0 | 0;
  }
  return 0;
}
function _gray_raster_reset($raster, $pool_base, $pool_size) {
  $raster = $raster | 0;
  $pool_base = $pool_base | 0;
  $pool_size = $pool_size | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $or_cond = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $raster;
    $2 = ($raster | 0) == 0;
    if ($2) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = ($pool_base | 0) != 0;
    $5 = ($pool_size | 0) > 3359;
    $or_cond = $4 & $5;
    if ($or_cond) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $7 = $pool_base;
    $8 = $1 + 16 | 0;
    HEAP32[$8 >> 2] = $7;
    $9 = $pool_base + 1312 | 0;
    $10 = $raster;
    HEAP32[$10 >> 2] = $9;
    $11 = $pool_size - 1312 | 0;
    $12 = $11 & -16;
    $13 = $1 + 4 | 0;
    HEAP32[$13 >> 2] = $12;
    $14 = $11 >>> 7;
    $15 = $1 + 8 | 0;
    HEAP32[$15 >> 2] = $14;
    label = 5;
    break;
   case 4:
    $17 = $raster;
    HEAP32[$17 >> 2] = 0;
    $18 = $1 + 4 | 0;
    HEAP32[$18 >> 2] = 0;
    $19 = $1 + 16 | 0;
    HEAP32[$19 >> 2] = 0;
    label = 5;
    break;
   case 5:
    return;
  }
}
function _tt_cmap4_char_map_binary($cmap, $pcharcode, $next) {
  $cmap = $cmap | 0;
  $pcharcode = $pcharcode | 0;
  $next = $next | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_masked = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $_ = 0, $17 = 0, $mid_0_ph = 0, $min_0_ph = 0, $max_0_ph = 0, $end_0_ph = 0, $mid_0 = 0, $max_0 = 0, $end_0 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $_sum = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $_sum166 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $_sum167 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $_sum168169 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $_sum170 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $_sum171172 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $_sum173 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $_sum174 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $or_cond = 0, $66 = 0, $or_cond218 = 0, $68 = 0, $69 = 0, $70 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $_sum216 = 0, $_sum217 = 0, $79 = 0, $80 = 0, $_219 = 0, $_220 = 0, $delta_0 = 0, $offset_0 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $88 = 0, $_221 = 0, $89 = 0, $90 = 0, $start_0241 = 0, $end_1240 = 0, $offset_1239 = 0, $delta_1238 = 0, $i_0237 = 0, $p_0236 = 0, $mid_2235 = 0, $92 = 0, $93 = 0, $_sum206 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $_sum207 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $_sum208 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $_sum209210 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $_sum211 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $_sum212213 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $_sum214 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $_sum215 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $mid_2_ = 0, $130 = 0, $start_0_lcssa = 0, $end_1_lcssa = 0, $offset_1_lcssa = 0, $delta_1_lcssa = 0, $i_0_lcssa = 0, $p_0_lcssa = 0, $mid_2_lcssa = 0, $131 = 0, $133 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $delta_3_ph = 0, $offset_3_ph = 0, $end_3_ph = 0, $start_2_ph = 0, $169 = 0, $170 = 0, $start_2227 = 0, $end_3226 = 0, $offset_3225 = 0, $delta_3224 = 0, $i_1223 = 0, $mid_4222 = 0, $172 = 0, $_sum186 = 0, $_sum188 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $_sum189190 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $_sum187 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $_sum191 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $_sum192193 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $_sum194 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $_sum195 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $mid_4_i_1 = 0, $209 = 0, $210 = 0, $start_2_lcssa = 0, $end_3_lcssa = 0, $offset_3_lcssa = 0, $delta_3_lcssa = 0, $i_1_lcssa = 0, $mid_4_lcssa = 0, $p_4 = 0, $211 = 0, $212 = 0, $mid_6 = 0, $p_5 = 0, $i_2 = 0, $delta_4 = 0, $offset_4 = 0, $end_4 = 0, $start_3 = 0, $214 = 0, $216 = 0, $217 = 0, $_sum176 = 0, $218 = 0, $219 = 0, $220 = 0, $221 = 0, $_sum177 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $_sum178 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $_sum179180 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $_sum181 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $_sum182183 = 0, $238 = 0, $239 = 0, $240 = 0, $241 = 0, $242 = 0, $_sum184 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $_sum185 = 0, $247 = 0, $248 = 0, $249 = 0, $250 = 0, $mid_7 = 0, $p_6 = 0, $delta_5 = 0, $offset_5 = 0, $end_5 = 0, $start_4 = 0, $253 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $260 = 0, $261 = 0, $_sum175 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $268 = 0, $269 = 0, $271 = 0, $272 = 0, $mid_8 = 0, $gindex_0 = 0, $end_6 = 0, $274 = 0, $275 = 0, $277 = 0, $278 = 0, $mid_9 = 0, $280 = 0, $281 = 0, $283 = 0, $286 = 0, $287 = 0, $288 = 0, $charcode_0_c = 0, $289 = 0, $291 = 0, $293 = 0, $294 = 0, $gindex_1 = 0, $296 = 0, $298 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cmap + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 6 | 0;
    $4 = HEAP8[$3] | 0;
    $5 = $4 & 255;
    $6 = $5 << 8;
    $7 = $2 + 7 | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 & 255;
    $_masked = $9 & 254;
    $10 = $_masked | $6;
    $11 = ($10 | 0) == 0;
    if ($11) {
      $_0 = 0;
      label = 41;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $13 = HEAP32[$pcharcode >> 2] | 0;
    $14 = $10 >>> 1;
    $15 = $next << 24 >> 24 != 0;
    $16 = $15 & 1;
    $_ = $13 + $16 | 0;
    $17 = $10 + 2 | 0;
    $end_0_ph = 65535;
    $max_0_ph = $14;
    $min_0_ph = 0;
    $mid_0_ph = $14;
    label = 3;
    break;
   case 3:
    $end_0 = $end_0_ph;
    $max_0 = $max_0_ph;
    $mid_0 = $mid_0_ph;
    label = 4;
    break;
   case 4:
    $19 = $min_0_ph >>> 0 < $max_0 >>> 0;
    if ($19) {
      label = 5;
      break;
    } else {
      $end_6 = $end_0;
      $gindex_0 = 0;
      $mid_8 = $mid_0;
      label = 30;
      break;
    }
   case 5:
    $21 = $max_0 + $min_0_ph | 0;
    $22 = $21 >>> 1;
    $23 = HEAP32[$1 >> 2] | 0;
    $24 = $22 << 1;
    $_sum = $24 + 14 | 0;
    $25 = $23 + $_sum | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 & 255;
    $28 = $27 << 8;
    $_sum166 = $24 + 15 | 0;
    $29 = $23 + $_sum166 | 0;
    $30 = HEAP8[$29] | 0;
    $31 = $30 & 255;
    $32 = $28 | $31;
    $_sum167 = $_sum + $17 | 0;
    $33 = $23 + $_sum167 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $35 << 8;
    $_sum168169 = $_sum167 | 1;
    $37 = $23 + $_sum168169 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 & 255;
    $40 = $36 | $39;
    $41 = $_ >>> 0 < $40 >>> 0;
    if ($41) {
      $end_0 = $32;
      $max_0 = $22;
      $mid_0 = $22;
      label = 4;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $43 = $_ >>> 0 > $32 >>> 0;
    $44 = $22 + 1 | 0;
    if ($43) {
      $end_0_ph = $32;
      $max_0_ph = $max_0;
      $min_0_ph = $44;
      $mid_0_ph = $22;
      label = 3;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $_sum170 = $_sum167 + $10 | 0;
    $46 = $23 + $_sum170 | 0;
    $47 = HEAP8[$46] | 0;
    $48 = $47 & 255;
    $49 = $48 << 8;
    $_sum171172 = $_sum170 | 1;
    $50 = $23 + $_sum171172 | 0;
    $51 = HEAP8[$50] | 0;
    $52 = $51 & 255;
    $53 = $49 | $52;
    $54 = $53 << 16 >> 16;
    $_sum173 = $_sum170 + $10 | 0;
    $55 = $23 + $_sum173 | 0;
    $56 = HEAP8[$55] | 0;
    $57 = $56 & 255;
    $58 = $57 << 8;
    $_sum174 = $_sum173 | 1;
    $59 = $23 + $_sum174 | 0;
    $60 = HEAP8[$59] | 0;
    $61 = $60 & 255;
    $62 = $58 | $61;
    $63 = $14 - 1 | 0;
    $64 = $22 >>> 0 >= $63 >>> 0;
    $65 = ($40 | 0) == 65535;
    $or_cond = $64 & $65;
    $66 = ($32 | 0) == 65535;
    $or_cond218 = $or_cond & $66;
    if ($or_cond218) {
      label = 8;
      break;
    } else {
      $offset_0 = $62;
      $delta_0 = $54;
      label = 10;
      break;
    }
   case 8:
    $68 = $cmap | 0;
    $69 = HEAP32[$68 >> 2] | 0;
    $70 = ($62 | 0) == 0;
    if ($70) {
      $offset_0 = 0;
      $delta_0 = $54;
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $72 = $69 + 504 | 0;
    $73 = $69 + 500 | 0;
    $74 = $72;
    $75 = HEAP32[$73 >> 2] | 0;
    $76 = HEAP32[$74 >> 2] | 0;
    $77 = $75;
    $78 = $77 + $76 | 0;
    $_sum216 = $_sum173 + 2 | 0;
    $_sum217 = $_sum216 + $62 | 0;
    $79 = $23 + $_sum217 | 0;
    $80 = $79 >>> 0 > $78 >>> 0;
    $_219 = $80 ? 1 : $54;
    $_220 = $80 ? 0 : $62;
    $offset_0 = $_220;
    $delta_0 = $_219;
    label = 10;
    break;
   case 10:
    $82 = $cmap + 20 | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = $83 & 2;
    $85 = ($84 | 0) == 0;
    $86 = ($offset_0 | 0) == 65535;
    if ($85) {
      label = 25;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $88 = $22 + 1 | 0;
    $_221 = $86 ? $88 : $22;
    $89 = ($22 | 0) == 0;
    if ($89) {
      $mid_2_lcssa = $_221;
      $p_0_lcssa = $55;
      $i_0_lcssa = 0;
      $delta_1_lcssa = $delta_0;
      $offset_1_lcssa = $offset_0;
      $end_1_lcssa = $32;
      $start_0_lcssa = $40;
      label = 15;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $90 = HEAP32[$1 >> 2] | 0;
    $mid_2235 = $_221;
    $p_0236 = $55;
    $i_0237 = $22;
    $delta_1238 = $delta_0;
    $offset_1239 = $offset_0;
    $end_1240 = $32;
    $start_0241 = $40;
    label = 13;
    break;
   case 13:
    $92 = $i_0237 - 1 | 0;
    $93 = $92 << 1;
    $_sum206 = $93 + 14 | 0;
    $94 = $90 + $_sum206 | 0;
    $95 = HEAP8[$94] | 0;
    $96 = $95 & 255;
    $97 = $96 << 8;
    $_sum207 = $93 + 15 | 0;
    $98 = $90 + $_sum207 | 0;
    $99 = HEAP8[$98] | 0;
    $100 = $99 & 255;
    $101 = $97 | $100;
    $102 = $_ >>> 0 > $101 >>> 0;
    if ($102) {
      $mid_2_lcssa = $mid_2235;
      $p_0_lcssa = $p_0236;
      $i_0_lcssa = $i_0237;
      $delta_1_lcssa = $delta_1238;
      $offset_1_lcssa = $offset_1239;
      $end_1_lcssa = $end_1240;
      $start_0_lcssa = $start_0241;
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $_sum208 = $_sum206 + $17 | 0;
    $104 = $90 + $_sum208 | 0;
    $105 = HEAP8[$104] | 0;
    $106 = $105 & 255;
    $107 = $106 << 8;
    $_sum209210 = $_sum208 | 1;
    $108 = $90 + $_sum209210 | 0;
    $109 = HEAP8[$108] | 0;
    $110 = $109 & 255;
    $111 = $107 | $110;
    $_sum211 = $_sum208 + $10 | 0;
    $112 = $90 + $_sum211 | 0;
    $113 = HEAP8[$112] | 0;
    $114 = $113 & 255;
    $115 = $114 << 8;
    $_sum212213 = $_sum211 | 1;
    $116 = $90 + $_sum212213 | 0;
    $117 = HEAP8[$116] | 0;
    $118 = $117 & 255;
    $119 = $115 | $118;
    $120 = $119 << 16 >> 16;
    $_sum214 = $_sum211 + $10 | 0;
    $121 = $90 + $_sum214 | 0;
    $122 = HEAP8[$121] | 0;
    $123 = $122 & 255;
    $124 = $123 << 8;
    $_sum215 = $_sum214 | 1;
    $125 = $90 + $_sum215 | 0;
    $126 = HEAP8[$125] | 0;
    $127 = $126 & 255;
    $128 = $124 | $127;
    $129 = ($128 | 0) == 65535;
    $mid_2_ = $129 ? $mid_2235 : $92;
    $130 = ($92 | 0) == 0;
    if ($130) {
      $mid_2_lcssa = $mid_2_;
      $p_0_lcssa = $121;
      $i_0_lcssa = 0;
      $delta_1_lcssa = $120;
      $offset_1_lcssa = $128;
      $end_1_lcssa = $101;
      $start_0_lcssa = $111;
      label = 15;
      break;
    } else {
      $mid_2235 = $mid_2_;
      $p_0236 = $121;
      $i_0237 = $92;
      $delta_1238 = $120;
      $offset_1239 = $128;
      $end_1240 = $101;
      $start_0241 = $111;
      label = 13;
      break;
    }
   case 15:
    $131 = ($mid_2_lcssa | 0) == ($88 | 0);
    if ($131) {
      label = 16;
      break;
    } else {
      $start_3 = $start_0_lcssa;
      $end_4 = $end_1_lcssa;
      $offset_4 = $offset_1_lcssa;
      $delta_4 = $delta_1_lcssa;
      $i_2 = $i_0_lcssa;
      $p_5 = $p_0_lcssa;
      $mid_6 = $mid_2_lcssa;
      label = 23;
      break;
    }
   case 16:
    $133 = ($i_0_lcssa | 0) == ($22 | 0);
    if ($133) {
      $start_2_ph = $start_0_lcssa;
      $end_3_ph = $end_1_lcssa;
      $offset_3_ph = $offset_1_lcssa;
      $delta_3_ph = $delta_1_lcssa;
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $135 = HEAP32[$1 >> 2] | 0;
    $136 = $135 + $_sum | 0;
    $137 = HEAP8[$136] | 0;
    $138 = $137 & 255;
    $139 = $138 << 8;
    $140 = $135 + $_sum166 | 0;
    $141 = HEAP8[$140] | 0;
    $142 = $141 & 255;
    $143 = $139 | $142;
    $144 = $135 + $_sum167 | 0;
    $145 = HEAP8[$144] | 0;
    $146 = $145 & 255;
    $147 = $146 << 8;
    $148 = $135 + $_sum168169 | 0;
    $149 = HEAP8[$148] | 0;
    $150 = $149 & 255;
    $151 = $147 | $150;
    $152 = $135 + $_sum170 | 0;
    $153 = HEAP8[$152] | 0;
    $154 = $153 & 255;
    $155 = $154 << 8;
    $156 = $135 + $_sum171172 | 0;
    $157 = HEAP8[$156] | 0;
    $158 = $157 & 255;
    $159 = $155 | $158;
    $160 = $159 << 16 >> 16;
    $161 = $135 + $_sum173 | 0;
    $162 = HEAP8[$161] | 0;
    $163 = $162 & 255;
    $164 = $163 << 8;
    $165 = $135 + $_sum174 | 0;
    $166 = HEAP8[$165] | 0;
    $167 = $166 & 255;
    $168 = $164 | $167;
    $start_2_ph = $151;
    $end_3_ph = $143;
    $offset_3_ph = $168;
    $delta_3_ph = $160;
    label = 18;
    break;
   case 18:
    $169 = $88 >>> 0 < $14 >>> 0;
    if ($169) {
      label = 19;
      break;
    } else {
      $end_6 = $end_3_ph;
      $gindex_0 = 0;
      $mid_8 = $22;
      label = 30;
      break;
    }
   case 19:
    $170 = HEAP32[$1 >> 2] | 0;
    $mid_4222 = $22;
    $i_1223 = $88;
    $delta_3224 = $delta_3_ph;
    $offset_3225 = $offset_3_ph;
    $end_3226 = $end_3_ph;
    $start_2227 = $start_2_ph;
    label = 20;
    break;
   case 20:
    $172 = $i_1223 << 1;
    $_sum186 = $172 + 14 | 0;
    $_sum188 = $_sum186 + $17 | 0;
    $173 = $170 + $_sum188 | 0;
    $174 = HEAP8[$173] | 0;
    $175 = $174 & 255;
    $176 = $175 << 8;
    $_sum189190 = $_sum188 | 1;
    $177 = $170 + $_sum189190 | 0;
    $178 = HEAP8[$177] | 0;
    $179 = $178 & 255;
    $180 = $176 | $179;
    $181 = $_ >>> 0 < $180 >>> 0;
    if ($181) {
      $p_4 = $173;
      $mid_4_lcssa = $mid_4222;
      $i_1_lcssa = $i_1223;
      $delta_3_lcssa = $delta_3224;
      $offset_3_lcssa = $offset_3225;
      $end_3_lcssa = $end_3226;
      $start_2_lcssa = $start_2227;
      label = 22;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $_sum187 = $172 + 15 | 0;
    $183 = $170 + $_sum186 | 0;
    $184 = $170 + $_sum187 | 0;
    $185 = HEAP8[$183] | 0;
    $186 = HEAP8[$184] | 0;
    $187 = $185 & 255;
    $188 = $186 & 255;
    $189 = $187 << 8;
    $190 = $189 | $188;
    $_sum191 = $_sum188 + $10 | 0;
    $191 = $170 + $_sum191 | 0;
    $192 = HEAP8[$191] | 0;
    $193 = $192 & 255;
    $194 = $193 << 8;
    $_sum192193 = $_sum191 | 1;
    $195 = $170 + $_sum192193 | 0;
    $196 = HEAP8[$195] | 0;
    $197 = $196 & 255;
    $198 = $194 | $197;
    $199 = $198 << 16 >> 16;
    $_sum194 = $_sum191 + $10 | 0;
    $200 = $170 + $_sum194 | 0;
    $201 = HEAP8[$200] | 0;
    $202 = $201 & 255;
    $203 = $202 << 8;
    $_sum195 = $_sum194 | 1;
    $204 = $170 + $_sum195 | 0;
    $205 = HEAP8[$204] | 0;
    $206 = $205 & 255;
    $207 = $203 | $206;
    $208 = ($207 | 0) == 65535;
    $mid_4_i_1 = $208 ? $mid_4222 : $i_1223;
    $209 = $i_1223 + 1 | 0;
    $210 = $209 >>> 0 < $14 >>> 0;
    if ($210) {
      $mid_4222 = $mid_4_i_1;
      $i_1223 = $209;
      $delta_3224 = $199;
      $offset_3225 = $207;
      $end_3226 = $190;
      $start_2227 = $180;
      label = 20;
      break;
    } else {
      $p_4 = $200;
      $mid_4_lcssa = $mid_4_i_1;
      $i_1_lcssa = $209;
      $delta_3_lcssa = $199;
      $offset_3_lcssa = $207;
      $end_3_lcssa = $190;
      $start_2_lcssa = $180;
      label = 22;
      break;
    }
   case 22:
    $211 = $i_1_lcssa - 1 | 0;
    $212 = ($mid_4_lcssa | 0) == ($22 | 0);
    if ($212) {
      $end_6 = $end_3_lcssa;
      $gindex_0 = 0;
      $mid_8 = $211;
      label = 30;
      break;
    } else {
      $start_3 = $start_2_lcssa;
      $end_4 = $end_3_lcssa;
      $offset_4 = $offset_3_lcssa;
      $delta_4 = $delta_3_lcssa;
      $i_2 = $211;
      $p_5 = $p_4;
      $mid_6 = $mid_4_lcssa;
      label = 23;
      break;
    }
   case 23:
    $214 = ($mid_6 | 0) == ($i_2 | 0);
    if ($214) {
      $start_4 = $start_3;
      $end_5 = $end_4;
      $offset_5 = $offset_4;
      $delta_5 = $delta_4;
      $p_6 = $p_5;
      $mid_7 = $mid_6;
      label = 26;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $216 = HEAP32[$1 >> 2] | 0;
    $217 = $mid_6 << 1;
    $_sum176 = $217 + 14 | 0;
    $218 = $216 + $_sum176 | 0;
    $219 = HEAP8[$218] | 0;
    $220 = $219 & 255;
    $221 = $220 << 8;
    $_sum177 = $217 + 15 | 0;
    $222 = $216 + $_sum177 | 0;
    $223 = HEAP8[$222] | 0;
    $224 = $223 & 255;
    $225 = $221 | $224;
    $_sum178 = $_sum176 + $17 | 0;
    $226 = $216 + $_sum178 | 0;
    $227 = HEAP8[$226] | 0;
    $228 = $227 & 255;
    $229 = $228 << 8;
    $_sum179180 = $_sum178 | 1;
    $230 = $216 + $_sum179180 | 0;
    $231 = HEAP8[$230] | 0;
    $232 = $231 & 255;
    $233 = $229 | $232;
    $_sum181 = $_sum178 + $10 | 0;
    $234 = $216 + $_sum181 | 0;
    $235 = HEAP8[$234] | 0;
    $236 = $235 & 255;
    $237 = $236 << 8;
    $_sum182183 = $_sum181 | 1;
    $238 = $216 + $_sum182183 | 0;
    $239 = HEAP8[$238] | 0;
    $240 = $239 & 255;
    $241 = $237 | $240;
    $242 = $241 << 16 >> 16;
    $_sum184 = $_sum181 + $10 | 0;
    $243 = $216 + $_sum184 | 0;
    $244 = HEAP8[$243] | 0;
    $245 = $244 & 255;
    $246 = $245 << 8;
    $_sum185 = $_sum184 | 1;
    $247 = $216 + $_sum185 | 0;
    $248 = HEAP8[$247] | 0;
    $249 = $248 & 255;
    $250 = $246 | $249;
    $start_4 = $233;
    $end_5 = $225;
    $offset_5 = $250;
    $delta_5 = $242;
    $p_6 = $243;
    $mid_7 = $mid_6;
    label = 26;
    break;
   case 25:
    if ($86) {
      $end_6 = $32;
      $gindex_0 = 0;
      $mid_8 = $22;
      label = 30;
      break;
    } else {
      $start_4 = $40;
      $end_5 = $32;
      $offset_5 = $offset_0;
      $delta_5 = $delta_0;
      $p_6 = $55;
      $mid_7 = $22;
      label = 26;
      break;
    }
   case 26:
    $253 = ($offset_5 | 0) == 0;
    if ($253) {
      label = 29;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $255 = $_ - $start_4 | 0;
    $256 = $255 << 1;
    $257 = $256 + $offset_5 | 0;
    $258 = $p_6 + $257 | 0;
    $259 = HEAP8[$258] | 0;
    $260 = $259 & 255;
    $261 = $260 << 8;
    $_sum175 = $257 + 1 | 0;
    $262 = $p_6 + $_sum175 | 0;
    $263 = HEAP8[$262] | 0;
    $264 = $263 & 255;
    $265 = $261 | $264;
    $266 = ($265 | 0) == 0;
    if ($266) {
      $end_6 = $end_5;
      $gindex_0 = 0;
      $mid_8 = $mid_7;
      label = 30;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $268 = $265 + $delta_5 | 0;
    $269 = $268 & 65535;
    $end_6 = $end_5;
    $gindex_0 = $269;
    $mid_8 = $mid_7;
    label = 30;
    break;
   case 29:
    $271 = $delta_5 + $_ | 0;
    $272 = $271 & 65535;
    $end_6 = $end_5;
    $gindex_0 = $272;
    $mid_8 = $mid_7;
    label = 30;
    break;
   case 30:
    if ($15) {
      label = 31;
      break;
    } else {
      $_0 = $gindex_0;
      label = 41;
      break;
    }
   case 31:
    $274 = $cmap;
    $275 = $_ >>> 0 > $end_6 >>> 0;
    if ($275) {
      label = 32;
      break;
    } else {
      $mid_9 = $mid_8;
      label = 33;
      break;
    }
   case 32:
    $277 = $mid_8 + 1 | 0;
    $278 = ($277 | 0) == ($14 | 0);
    if ($278) {
      $_0 = 0;
      label = 41;
      break;
    } else {
      $mid_9 = $277;
      label = 33;
      break;
    }
   case 33:
    $280 = _tt_cmap4_set_range($274, $mid_9) | 0;
    $281 = ($280 | 0) == 0;
    if ($281) {
      label = 36;
      break;
    } else {
      label = 34;
      break;
    }
   case 34:
    $283 = ($gindex_0 | 0) == 0;
    if ($283) {
      $_0 = 0;
      label = 41;
      break;
    } else {
      label = 35;
      break;
    }
   case 35:
    HEAP32[$pcharcode >> 2] = $_;
    $_0 = $gindex_0;
    label = 41;
    break;
   case 36:
    $286 = $cmap + 24 | 0;
    $287 = $286;
    $288 = $286 | 0;
    $charcode_0_c = $_;
    HEAP32[$288 >> 2] = $charcode_0_c;
    $289 = ($gindex_0 | 0) == 0;
    if ($289) {
      label = 38;
      break;
    } else {
      label = 37;
      break;
    }
   case 37:
    $291 = $cmap + 28 | 0;
    HEAP32[$291 >> 2] = $gindex_0;
    $gindex_1 = $gindex_0;
    label = 39;
    break;
   case 38:
    HEAP32[$288 >> 2] = $charcode_0_c;
    _tt_cmap4_next($274);
    $293 = $cmap + 28 | 0;
    $294 = HEAP32[$293 >> 2] | 0;
    $gindex_1 = $294;
    label = 39;
    break;
   case 39:
    $296 = ($gindex_1 | 0) == 0;
    if ($296) {
      $_0 = 0;
      label = 41;
      break;
    } else {
      label = 40;
      break;
    }
   case 40:
    $298 = HEAP32[$287 >> 2] | 0;
    HEAP32[$pcharcode >> 2] = $298;
    $_0 = $gindex_1;
    label = 41;
    break;
   case 41:
    return $_0 | 0;
  }
  return 0;
}
function _gray_raster_new($memory, $araster) {
  $memory = $memory | 0;
  $araster = $araster | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$araster >> 2] = 0;
    $1 = _ft_mem_alloc($memory, 20, $error) | 0;
    $2 = HEAP32[$error >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $5 = $memory;
    $6 = $1 + 12 | 0;
    $7 = $6;
    HEAP32[$7 >> 2] = $5;
    $8 = $1;
    HEAP32[$araster >> 2] = $8;
    label = 3;
    break;
   case 3:
    $10 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $10 | 0;
  }
  return 0;
}
function _gray_raster_render($raster, $params) {
  $raster = $raster | 0;
  $params = $params | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $82 = 0, $83 = 0, $84 = 0, $86 = 0, $87 = 0, $88 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $123 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $params + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $params | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($raster | 0) == 0;
    if ($5) {
      $_0 = 6;
      label = 25;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $raster | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      $_0 = 6;
      label = 25;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = $raster + 4 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      $_0 = 6;
      label = 25;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $15 = ($2 | 0) == 0;
    if ($15) {
      $_0 = 20;
      label = 25;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = $2 + 2 | 0;
    $18 = $17;
    $19 = HEAP16[$18 >> 1] | 0;
    $20 = $19 << 16 >> 16;
    $21 = $19 << 16 >> 16 == 0;
    if ($21) {
      $_0 = 0;
      label = 25;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $23 = $2;
    $24 = HEAP16[$23 >> 1] | 0;
    $25 = $24 << 16 >> 16;
    $26 = $24 << 16 >> 16 < 1;
    if ($26) {
      $_0 = 0;
      label = 25;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $28 = $2 + 12 | 0;
    $29 = $28;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = ($30 | 0) == 0;
    if ($31) {
      $_0 = 20;
      label = 25;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $33 = $2 + 4 | 0;
    $34 = $33;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = ($35 | 0) == 0;
    if ($36) {
      $_0 = 20;
      label = 25;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $38 = $25 - 1 | 0;
    $39 = $30 + ($38 << 1) | 0;
    $40 = HEAP16[$39 >> 1] | 0;
    $41 = $40 << 16 >> 16;
    $42 = $41 + 1 | 0;
    $43 = ($20 | 0) == ($42 | 0);
    if ($43) {
      label = 10;
      break;
    } else {
      $_0 = 20;
      label = 25;
      break;
    }
   case 10:
    $45 = $raster + 16 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $params + 8 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $48 & 2;
    $50 = ($49 | 0) == 0;
    if ($50) {
      label = 11;
      break;
    } else {
      label = 15;
      break;
    }
   case 11:
    $52 = ($4 | 0) == 0;
    if ($52) {
      $_0 = 6;
      label = 25;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $54 = $4 + 4 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = ($55 | 0) == 0;
    if ($56) {
      $_0 = 0;
      label = 25;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $58 = $4 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = ($59 | 0) == 0;
    if ($60) {
      $_0 = 0;
      label = 25;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $62 = $4 + 12 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = ($63 | 0) == 0;
    if ($64) {
      $_0 = 6;
      label = 25;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $66 = HEAP32[$47 >> 2] | 0;
    $67 = $66 & 1;
    $68 = ($67 | 0) == 0;
    if ($68) {
      $_0 = 19;
      label = 25;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $70 = $66 & 2;
    $71 = ($70 | 0) == 0;
    if ($71) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    $73 = $46 + 1024 | 0;
    HEAP32[$73 >> 2] = 0;
    $74 = $46 + 1028 | 0;
    HEAP32[$74 >> 2] = 0;
    $75 = $4 + 4 | 0;
    $76 = HEAP32[$75 >> 2] | 0;
    $77 = $46 + 1032 | 0;
    HEAP32[$77 >> 2] = $76;
    $78 = $4 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = $46 + 1036 | 0;
    HEAP32[$80 >> 2] = $79;
    label = 21;
    break;
   case 18:
    $82 = $66 & 4;
    $83 = ($82 | 0) == 0;
    $84 = $46 + 1024 | 0;
    if ($83) {
      label = 20;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $86 = $params + 32 | 0;
    $87 = $84;
    $88 = $86;
    _memcpy($87 | 0, $88 | 0, 16);
    label = 21;
    break;
   case 20:
    $90 = $84 | 0;
    HEAP32[$90 >> 2] = -32768;
    $91 = $46 + 1028 | 0;
    HEAP32[$91 >> 2] = -32768;
    $92 = $46 + 1032 | 0;
    HEAP32[$92 >> 2] = 32767;
    $93 = $46 + 1036 | 0;
    HEAP32[$93 >> 2] = 32767;
    label = 21;
    break;
   case 21:
    $95 = HEAP32[$7 >> 2] | 0;
    $96 = HEAP32[$11 >> 2] | 0;
    _gray_init_cells($46, $95, $96);
    $97 = $46 + 980 | 0;
    $98 = $97;
    _memcpy($98 | 0, $2 | 0, 20);
    $99 = $46 + 52 | 0;
    HEAP32[$99 >> 2] = 0;
    $100 = $46 + 40 | 0;
    HEAP32[$100 >> 2] = 1;
    $101 = $raster + 8 | 0;
    $102 = HEAP32[$101 >> 2] | 0;
    $103 = $46 + 1248 | 0;
    HEAP32[$103 >> 2] = $102;
    $104 = $46 + 1232 | 0;
    HEAP32[$104 >> 2] = 0;
    $105 = HEAP32[$47 >> 2] | 0;
    $106 = $105 & 2;
    $107 = ($106 | 0) == 0;
    if ($107) {
      label = 23;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $109 = $params + 12 | 0;
    $110 = HEAP32[$109 >> 2] | 0;
    $111 = $46 + 1236 | 0;
    HEAP32[$111 >> 2] = $110;
    $112 = $params + 28 | 0;
    $113 = HEAP32[$112 >> 2] | 0;
    $114 = $46 + 1240 | 0;
    HEAP32[$114 >> 2] = $113;
    label = 24;
    break;
   case 23:
    $116 = $46 + 1e3 | 0;
    $117 = $116;
    $118 = $4;
    _memcpy($117 | 0, $118 | 0, 24);
    $119 = $46 + 1236 | 0;
    HEAP32[$119 >> 2] = 204;
    $120 = $46;
    $121 = $46 + 1240 | 0;
    HEAP32[$121 >> 2] = $120;
    label = 24;
    break;
   case 24:
    $123 = _gray_convert_glyph($46) | 0;
    $_0 = $123;
    label = 25;
    break;
   case 25:
    return $_0 | 0;
  }
  return 0;
}
function _gray_raster_done($raster) {
  $raster = $raster | 0;
  _ft_mem_free(HEAP32[$raster + 12 >> 2] | 0, $raster);
  return;
}
function _ft_smooth_init($render) {
  $render = $render | 0;
  var $2 = 0;
  $2 = HEAP32[$render + 4 >> 2] | 0;
  FUNCTION_TABLE_viii[HEAP32[(HEAP32[(HEAP32[$render + 20 >> 2] | 0) + 56 >> 2] | 0) + 8 >> 2] & 1023](HEAP32[$render + 60 >> 2] | 0, HEAP32[$2 + 172 >> 2] | 0, HEAP32[$2 + 176 >> 2] | 0);
  return 0;
}
function _ft_smooth_render($render, $slot, $mode, $origin) {
  $render = $render | 0;
  $slot = $slot | 0;
  $mode = $mode | 0;
  $origin = $origin | 0;
  return _ft_smooth_render_generic($render, $slot, ($mode | 0) == 1 ? 0 : $mode, $origin, 0) | 0;
}
function _gray_init_cells($worker, $buffer, $byte_size) {
  $worker = $worker | 0;
  $buffer = $buffer | 0;
  $byte_size = $byte_size | 0;
  HEAP32[$worker + 1296 >> 2] = $buffer;
  HEAP32[$worker + 1300 >> 2] = $byte_size;
  HEAP32[$worker + 1304 >> 2] = $buffer;
  HEAP32[$worker + 44 >> 2] = 0;
  HEAP32[$worker + 48 >> 2] = 0;
  HEAP32[$worker + 52 >> 2] = 0;
  HEAP32[$worker + 32 >> 2] = 0;
  HEAP32[$worker + 36 >> 2] = 0;
  HEAP32[$worker + 40 >> 2] = 1;
  return;
}
function _ft_smooth_transform($render, $slot, $matrix, $delta) {
  $render = $render | 0;
  $slot = $slot | 0;
  $matrix = $matrix | 0;
  $delta = $delta | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $9 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $slot + 72 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $render + 24 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) == ($4 | 0);
    if ($5) {
      label = 2;
      break;
    } else {
      $error_0 = 6;
      label = 6;
      break;
    }
   case 2:
    $7 = ($matrix | 0) == 0;
    if ($7) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = $slot + 108 | 0;
    _FT_Outline_Transform($9, $matrix);
    label = 4;
    break;
   case 4:
    $11 = ($delta | 0) == 0;
    if ($11) {
      $error_0 = 0;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $13 = $slot + 108 | 0;
    $14 = $delta | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $delta + 4 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    _FT_Outline_Translate($13, $15, $17);
    $error_0 = 0;
    label = 6;
    break;
   case 6:
    return $error_0 | 0;
  }
  return 0;
}
function _ft_smooth_get_cbox($render, $slot, $cbox) {
  $render = $render | 0;
  $slot = $slot | 0;
  $cbox = $cbox | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cbox;
    _memset($1 | 0, 0, 16);
    $2 = $slot + 72 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $render + 24 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($3 | 0) == ($5 | 0);
    if ($6) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $8 = $slot + 108 | 0;
    _FT_Outline_Get_CBox($8, $cbox);
    label = 3;
    break;
   case 3:
    return;
  }
}
function _ft_smooth_set_mode($render, $mode_tag, $data) {
  $render = $render | 0;
  $mode_tag = $mode_tag | 0;
  $data = $data | 0;
  return FUNCTION_TABLE_iiii[HEAP32[(HEAP32[(HEAP32[$render + 20 >> 2] | 0) + 56 >> 2] | 0) + 12 >> 2] & 1023](HEAP32[$render + 60 >> 2] | 0, $mode_tag, $data) | 0;
}
function _ft_smooth_render_lcd($render, $slot, $mode, $origin) {
  $render = $render | 0;
  $slot = $slot | 0;
  $mode = $mode | 0;
  $origin = $origin | 0;
  var $1 = 0, $2 = 0, $4 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _ft_smooth_render_generic($render, $slot, $mode, $origin, 3) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $4 = $slot + 94 | 0;
    HEAP8[$4] = 5;
    label = 3;
    break;
   case 3:
    return $1 | 0;
  }
  return 0;
}
function _ft_smooth_render_lcd_v($render, $slot, $mode, $origin) {
  $render = $render | 0;
  $slot = $slot | 0;
  $mode = $mode | 0;
  $origin = $origin | 0;
  var $1 = 0, $2 = 0, $4 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _ft_smooth_render_generic($render, $slot, $mode, $origin, 4) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $4 = $slot + 94 | 0;
    HEAP8[$4] = 6;
    label = 3;
    break;
   case 3:
    return $1 | 0;
  }
  return 0;
}
function _ft_smooth_render_generic($render, $slot, $mode, $origin, $required_mode) {
  $render = $render | 0;
  $slot = $slot | 0;
  $mode = $mode | 0;
  $origin = $origin | 0;
  $required_mode = $required_mode | 0;
  var $error = 0, $cbox = 0, $params = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $73 = 0, $74 = 0, $75 = 0, $pitch_0 = 0, $width_0 = 0, $78 = 0, $height_0 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $or_cond = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $_not = 0, $114 = 0, $or_cond104 = 0, $115 = 0, $116 = 0, $hh_0101 = 0, $line_0100 = 0, $118 = 0, $end_097 = 0, $xx_096 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $_sum = 0, $_sum90 = 0, $hh1_095 = 0, $write_094 = 0, $read_093 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $146 = 0, $147 = 0, $149 = 0, $150 = 0, $or_cond91 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $159 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 68 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $cbox = __stackBase__ + 4 | 0;
    $params = __stackBase__ + 20 | 0;
    $1 = ($mode | 0) == 3;
    $2 = ($mode | 0) == 4;
    $3 = $slot + 72 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $render + 24 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($4 | 0) == ($6 | 0);
    if ($7) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    HEAP32[$error >> 2] = 6;
    label = 32;
    break;
   case 3:
    $9 = ($mode | 0) == ($required_mode | 0);
    if ($9) {
      label = 4;
      break;
    } else {
      $_0 = 19;
      label = 33;
      break;
    }
   case 4:
    $11 = $slot + 108 | 0;
    $12 = ($origin | 0) == 0;
    if ($12) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $14 = $origin | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $origin + 4 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    _FT_Outline_Translate($11, $15, $17);
    label = 6;
    break;
   case 6:
    _FT_Outline_Get_CBox($11, $cbox);
    $19 = $cbox | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $20 & -64;
    HEAP32[$19 >> 2] = $21;
    $22 = $cbox + 4 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $23 & -64;
    HEAP32[$22 >> 2] = $24;
    $25 = $cbox + 8 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $26 + 63 | 0;
    $28 = $27 & -64;
    HEAP32[$25 >> 2] = $28;
    $29 = $cbox + 12 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $30 + 63 | 0;
    $32 = $31 & -64;
    HEAP32[$29 >> 2] = $32;
    $33 = HEAP32[$19 >> 2] | 0;
    $34 = ($33 | 0) < 0;
    if ($34) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $36 = HEAP32[$25 >> 2] | 0;
    $37 = $33 + 2147483647 | 0;
    $38 = ($36 | 0) > ($37 | 0);
    if ($38) {
      $_0 = 98;
      label = 33;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $40 = HEAP32[$25 >> 2] | 0;
    $41 = HEAP32[$19 >> 2] | 0;
    $42 = $40 - $41 | 0;
    $43 = $42 >> 6;
    $44 = HEAP32[$22 >> 2] | 0;
    $45 = ($44 | 0) < 0;
    if ($45) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $47 = HEAP32[$29 >> 2] | 0;
    $48 = $44 + 2147483647 | 0;
    $49 = ($47 | 0) > ($48 | 0);
    if ($49) {
      $_0 = 98;
      label = 33;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $51 = HEAP32[$29 >> 2] | 0;
    $52 = HEAP32[$22 >> 2] | 0;
    $53 = $51 - $52 | 0;
    $54 = $53 >> 6;
    $55 = $slot + 76 | 0;
    $56 = $render + 8 | 0;
    $57 = HEAP32[$56 >> 2] | 0;
    $58 = $slot + 156 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = $59 + 4 | 0;
    $61 = HEAP32[$60 >> 2] | 0;
    $62 = $61 & 1;
    $63 = ($62 | 0) == 0;
    if ($63) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $65 = $slot + 88 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    _ft_mem_free($57, $66);
    HEAP32[$65 >> 2] = 0;
    $67 = HEAP32[$58 >> 2] | 0;
    $68 = $67 + 4 | 0;
    $69 = HEAP32[$68 >> 2] | 0;
    $70 = $69 & -2;
    HEAP32[$68 >> 2] = $70;
    label = 12;
    break;
   case 12:
    if ($1) {
      label = 13;
      break;
    } else {
      $width_0 = $43;
      $pitch_0 = $43;
      label = 14;
      break;
    }
   case 13:
    $73 = $43 * 3 & -1;
    $74 = $73 + 3 | 0;
    $75 = $74 & -4;
    $width_0 = $73;
    $pitch_0 = $75;
    label = 14;
    break;
   case 14:
    if ($2) {
      label = 15;
      break;
    } else {
      $height_0 = $54;
      label = 16;
      break;
    }
   case 15:
    $78 = $54 * 3 & -1;
    $height_0 = $78;
    label = 16;
    break;
   case 16:
    $80 = HEAP32[$19 >> 2] | 0;
    $81 = HEAP32[$22 >> 2] | 0;
    $82 = $80 >> 6;
    $83 = HEAP32[$29 >> 2] | 0;
    $84 = $83 >> 6;
    $85 = $width_0 >>> 0 > 32767;
    $86 = $height_0 >>> 0 > 32767;
    $or_cond = $85 | $86;
    if ($or_cond) {
      $_0 = 98;
      label = 33;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $88 = $slot + 94 | 0;
    HEAP8[$88] = 2;
    $89 = $slot + 92 | 0;
    HEAP16[$89 >> 1] = 256;
    $90 = $slot + 80 | 0;
    HEAP32[$90 >> 2] = $width_0;
    $91 = $55 | 0;
    HEAP32[$91 >> 2] = $height_0;
    $92 = $slot + 84 | 0;
    HEAP32[$92 >> 2] = $pitch_0;
    $93 = -$80 | 0;
    $94 = -$81 | 0;
    _FT_Outline_Translate($11, $93, $94);
    $95 = Math_imul($height_0, $pitch_0);
    $96 = _ft_mem_alloc($57, $95, $error) | 0;
    $97 = $slot + 88 | 0;
    HEAP32[$97 >> 2] = $96;
    $98 = HEAP32[$error >> 2] | 0;
    $99 = ($98 | 0) == 0;
    if ($99) {
      label = 18;
      break;
    } else {
      label = 30;
      break;
    }
   case 18:
    $101 = HEAP32[$58 >> 2] | 0;
    $102 = $101 + 4 | 0;
    $103 = HEAP32[$102 >> 2] | 0;
    $104 = $103 | 1;
    HEAP32[$102 >> 2] = $104;
    $105 = $params | 0;
    HEAP32[$105 >> 2] = $55;
    $106 = $11;
    $107 = $params + 4 | 0;
    HEAP32[$107 >> 2] = $106;
    $108 = $params + 8 | 0;
    HEAP32[$108 >> 2] = 1;
    $109 = $render + 64 | 0;
    $110 = HEAP32[$109 >> 2] | 0;
    $111 = $render + 60 | 0;
    $112 = HEAP32[$111 >> 2] | 0;
    $113 = FUNCTION_TABLE_iii[$110 & 1023]($112, $params) | 0;
    HEAP32[$error >> 2] = $113;
    $_not = $1 ^ 1;
    $114 = ($54 | 0) == 0;
    $or_cond104 = $114 | $_not;
    if ($or_cond104) {
      label = 24;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $115 = HEAP32[$97 >> 2] | 0;
    $116 = ($43 | 0) == 0;
    $line_0100 = $115;
    $hh_0101 = $54;
    label = 20;
    break;
   case 20:
    if ($116) {
      label = 23;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $118 = $line_0100 + $width_0 | 0;
    $xx_096 = $43;
    $end_097 = $118;
    label = 22;
    break;
   case 22:
    $120 = $xx_096 - 1 | 0;
    $121 = $line_0100 + $120 | 0;
    $122 = HEAP8[$121] | 0;
    $123 = $end_097 - 3 | 0;
    HEAP8[$123] = $122;
    $124 = $end_097 - 2 | 0;
    HEAP8[$124] = $122;
    $125 = $end_097 - 1 | 0;
    HEAP8[$125] = $122;
    $126 = ($120 | 0) == 0;
    if ($126) {
      label = 23;
      break;
    } else {
      $xx_096 = $120;
      $end_097 = $123;
      label = 22;
      break;
    }
   case 23:
    $127 = $hh_0101 - 1 | 0;
    $128 = $line_0100 + $pitch_0 | 0;
    $129 = ($127 | 0) == 0;
    if ($129) {
      label = 24;
      break;
    } else {
      $line_0100 = $128;
      $hh_0101 = $127;
      label = 20;
      break;
    }
   case 24:
    if ($2) {
      label = 25;
      break;
    } else {
      label = 28;
      break;
    }
   case 25:
    $131 = HEAP32[$97 >> 2] | 0;
    $132 = ($54 | 0) == 0;
    if ($132) {
      label = 28;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $133 = $height_0 - $54 | 0;
    $134 = Math_imul($133, $pitch_0);
    $135 = $131 + $134 | 0;
    $_sum = $pitch_0 << 1;
    $_sum90 = $_sum + $pitch_0 | 0;
    $read_093 = $135;
    $write_094 = $131;
    $hh1_095 = $54;
    label = 27;
    break;
   case 27:
    _memcpy($write_094 | 0, $read_093 | 0, $pitch_0 | 0);
    $137 = $write_094 + $pitch_0 | 0;
    _memcpy($137 | 0, $read_093 | 0, $pitch_0 | 0);
    $138 = $write_094 + $_sum | 0;
    _memcpy($138 | 0, $read_093 | 0, $pitch_0 | 0);
    $139 = $write_094 + $_sum90 | 0;
    $140 = $read_093 + $pitch_0 | 0;
    $141 = $hh1_095 - 1 | 0;
    $142 = ($141 | 0) == 0;
    if ($142) {
      label = 28;
      break;
    } else {
      $read_093 = $140;
      $write_094 = $139;
      $hh1_095 = $141;
      label = 27;
      break;
    }
   case 28:
    _FT_Outline_Translate($11, $80, $81);
    $143 = HEAP32[$error >> 2] | 0;
    $144 = ($143 | 0) == 0;
    if ($144) {
      label = 29;
      break;
    } else {
      label = 30;
      break;
    }
   case 29:
    HEAP32[$3 >> 2] = 1651078259;
    $146 = $slot + 100 | 0;
    HEAP32[$146 >> 2] = $82;
    $147 = $slot + 104 | 0;
    HEAP32[$147 >> 2] = $84;
    label = 30;
    break;
   case 30:
    $149 = ($11 | 0) == 0;
    $150 = ($origin | 0) == 0;
    $or_cond91 = $149 | $150;
    if ($or_cond91) {
      label = 32;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    $152 = $origin | 0;
    $153 = HEAP32[$152 >> 2] | 0;
    $154 = -$153 | 0;
    $155 = $origin + 4 | 0;
    $156 = HEAP32[$155 >> 2] | 0;
    $157 = -$156 | 0;
    _FT_Outline_Translate($11, $154, $157);
    label = 32;
    break;
   case 32:
    $159 = HEAP32[$error >> 2] | 0;
    $_0 = $159;
    label = 33;
    break;
   case 33:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _gray_render_span($y, $count, $spans, $worker) {
  $y = $y | 0;
  $count = $count | 0;
  $spans = $spans | 0;
  $worker = $worker | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $_pn34 = 0, $_pn = 0, $12 = 0, $_032 = 0, $_02931 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $p_0_ph_sum = 0, $24 = 0, $_sum = 0, $p_0_ph_sum33 = 0, $28 = 0, $q_0 = 0, $30 = 0, $q_1 = 0, $32 = 0, $q_2 = 0, $34 = 0, $q_3 = 0, $36 = 0, $q_4 = 0, $38 = 0, $q_5 = 0, $41 = 0, $42 = 0, $43 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 1012 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $worker + 1008 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = Math_imul($4, $y);
    $6 = ($4 | 0) > -1;
    if ($6) {
      label = 2;
      break;
    } else {
      $_pn34 = 0;
      label = 3;
      break;
    }
   case 2:
    $8 = $worker + 1e3 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 - 1 | 0;
    $11 = Math_imul($10, $4);
    $_pn34 = $11;
    label = 3;
    break;
   case 3:
    $_pn = $_pn34 - $5 | 0;
    $12 = ($count | 0) > 0;
    if ($12) {
      $_02931 = $spans;
      $_032 = $count;
      label = 4;
      break;
    } else {
      label = 16;
      break;
    }
   case 4:
    $13 = $_02931 + 4 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 << 24 >> 24 == 0;
    if ($15) {
      label = 15;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = $_02931 + 2 | 0;
    $18 = HEAP16[$17 >> 1] | 0;
    $19 = $18 & 65535;
    $20 = ($18 & 65535) > 7;
    $21 = $_02931 | 0;
    $22 = HEAP16[$21 >> 1] | 0;
    $23 = $22 << 16 >> 16;
    $p_0_ph_sum = $_pn + $23 | 0;
    $24 = $2 + $p_0_ph_sum | 0;
    if ($20) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    _memset($24 | 0, $14 | 0, $19 | 0);
    label = 15;
    break;
   case 7:
    if (($19 | 0) == 7) {
      label = 8;
      break;
    } else if (($19 | 0) == 6) {
      $q_0 = $24;
      label = 9;
      break;
    } else if (($19 | 0) == 5) {
      $q_1 = $24;
      label = 10;
      break;
    } else if (($19 | 0) == 4) {
      $q_2 = $24;
      label = 11;
      break;
    } else if (($19 | 0) == 3) {
      $q_3 = $24;
      label = 12;
      break;
    } else if (($19 | 0) == 2) {
      $q_4 = $24;
      label = 13;
      break;
    } else if (($19 | 0) == 1) {
      $q_5 = $24;
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 8:
    $_sum = $23 + 1 | 0;
    $p_0_ph_sum33 = $_pn + $_sum | 0;
    $28 = $2 + $p_0_ph_sum33 | 0;
    HEAP8[$24] = $14;
    $q_0 = $28;
    label = 9;
    break;
   case 9:
    $30 = $q_0 + 1 | 0;
    HEAP8[$q_0] = $14;
    $q_1 = $30;
    label = 10;
    break;
   case 10:
    $32 = $q_1 + 1 | 0;
    HEAP8[$q_1] = $14;
    $q_2 = $32;
    label = 11;
    break;
   case 11:
    $34 = $q_2 + 1 | 0;
    HEAP8[$q_2] = $14;
    $q_3 = $34;
    label = 12;
    break;
   case 12:
    $36 = $q_3 + 1 | 0;
    HEAP8[$q_3] = $14;
    $q_4 = $36;
    label = 13;
    break;
   case 13:
    $38 = $q_4 + 1 | 0;
    HEAP8[$q_4] = $14;
    $q_5 = $38;
    label = 14;
    break;
   case 14:
    HEAP8[$q_5] = $14;
    label = 15;
    break;
   case 15:
    $41 = $_032 - 1 | 0;
    $42 = $_02931 + 6 | 0;
    $43 = ($41 | 0) > 0;
    if ($43) {
      $_02931 = $42;
      $_032 = $41;
      label = 4;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    return;
  }
}
function _gray_convert_glyph($worker) {
  $worker = $worker | 0;
  var $bands = 0, $band = 0, $n = 0, $num_bands = 0, $min = 0, $max = 0, $max_y = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $28 = 0, $29 = 0, $30 = 0, $33 = 0, $34 = 0, $35 = 0, $38 = 0, $39 = 0, $40 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $num_bands_0_load115 = 0, $57 = 0, $num_bands_0_load116 = 0, $60 = 0, $63 = 0, $64 = 0, $65 = 0, $n_0_load119142 = 0, $num_bands_0_load117143 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $min_0_load113 = 0, $79 = 0, $80 = 0, $n_0_load120 = 0, $num_bands_0_load118 = 0, $81 = 0, $82 = 0, $max_0_load110 = 0, $max_y_0_load108 = 0, $84 = 0, $max_y_0_load109 = 0, $min_0_load114 = 0, $max_0_load111 = 0, $band_0_load122138 = 0, $87 = 0, $88 = 0, $89 = 0, $band_0_load123 = 0, $90 = 0, $91 = 0, $band_0_load124 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $99 = 0, $100 = 0, $cell_start_0 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $yindex_0137 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $band_0_load125 = 0, $119 = 0, $120 = 0, $band_0_load126 = 0, $121 = 0, $122 = 0, $band_0_load127 = 0, $123 = 0, $124 = 0, $band_0_load128 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $band_0_load129 = 0, $130 = 0, $band_0_load122 = 0, $131 = 0, $band_0_load130 = 0, $133 = 0, $134 = 0, $band_0_load131 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $142 = 0, $143 = 0, $144 = 0, $146 = 0, $147 = 0, $band_0_load132 = 0, $149 = 0, $band_0_load133 = 0, $150 = 0, $band_0_load134 = 0, $151 = 0, $band_0_load135 = 0, $152 = 0, $band_0_load136 = 0, $153 = 0, $n_0_load121 = 0, $154 = 0, $max_0_load112 = 0, $n_0_load119 = 0, $num_bands_0_load117 = 0, $155 = 0, $156 = 0, $157 = 0, $159 = 0, $160 = 0, $162 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 320 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $bands = __stackBase__ | 0;
    _gray_compute_cbox($worker);
    $1 = $worker + 12 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $worker + 1024 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) > ($4 | 0);
    if ($5) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 40;
      break;
    }
   case 2:
    $7 = $worker + 8 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $worker + 1032 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($8 | 0) < ($10 | 0);
    if ($11) {
      label = 3;
      break;
    } else {
      $_0 = 0;
      label = 40;
      break;
    }
   case 3:
    $13 = $worker + 20 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $worker + 1028 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($14 | 0) > ($16 | 0);
    if ($17) {
      label = 4;
      break;
    } else {
      $_0 = 0;
      label = 40;
      break;
    }
   case 4:
    $19 = $worker + 16 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $worker + 1036 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = ($20 | 0) < ($22 | 0);
    if ($23) {
      label = 5;
      break;
    } else {
      $_0 = 0;
      label = 40;
      break;
    }
   case 5:
    $25 = ($8 | 0) < ($4 | 0);
    if ($25) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    HEAP32[$7 >> 2] = $4;
    label = 7;
    break;
   case 7:
    $28 = HEAP32[$19 >> 2] | 0;
    $29 = HEAP32[$15 >> 2] | 0;
    $30 = ($28 | 0) < ($29 | 0);
    if ($30) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    HEAP32[$19 >> 2] = $29;
    label = 9;
    break;
   case 9:
    $33 = HEAP32[$1 >> 2] | 0;
    $34 = HEAP32[$9 >> 2] | 0;
    $35 = ($33 | 0) > ($34 | 0);
    if ($35) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    HEAP32[$1 >> 2] = $34;
    label = 11;
    break;
   case 11:
    $38 = HEAP32[$13 >> 2] | 0;
    $39 = HEAP32[$21 >> 2] | 0;
    $40 = ($38 | 0) > ($39 | 0);
    if ($40) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    HEAP32[$13 >> 2] = $39;
    label = 13;
    break;
   case 13:
    $43 = HEAP32[$1 >> 2] | 0;
    $44 = HEAP32[$7 >> 2] | 0;
    $45 = $43 - $44 | 0;
    $46 = $worker + 24 | 0;
    HEAP32[$46 >> 2] = $45;
    $47 = HEAP32[$13 >> 2] | 0;
    $48 = HEAP32[$19 >> 2] | 0;
    $49 = $47 - $48 | 0;
    $50 = $worker + 28 | 0;
    HEAP32[$50 >> 2] = $49;
    $51 = HEAP32[$13 >> 2] | 0;
    $52 = HEAP32[$19 >> 2] | 0;
    $53 = $51 - $52 | 0;
    $54 = $worker + 1248 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = ($53 | 0) / ($55 | 0) & -1;
    $num_bands = $56;
    $num_bands_0_load115 = $num_bands;
    $57 = ($num_bands_0_load115 | 0) == 0;
    if ($57) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $num_bands = 1;
    label = 15;
    break;
   case 15:
    $num_bands_0_load116 = $num_bands;
    $60 = ($num_bands_0_load116 | 0) > 38;
    if ($60) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    $num_bands = 39;
    label = 17;
    break;
   case 17:
    $63 = $worker + 1252 | 0;
    HEAP32[$63 >> 2] = 0;
    $64 = HEAP32[$19 >> 2] | 0;
    $min = $64;
    $65 = HEAP32[$13 >> 2] | 0;
    $max_y = $65;
    $n = 0;
    $n_0_load119142 = $n;
    $num_bands_0_load117143 = $num_bands;
    $66 = ($n_0_load119142 | 0) < ($num_bands_0_load117143 | 0);
    if ($66) {
      label = 18;
      break;
    } else {
      label = 37;
      break;
    }
   case 18:
    $67 = $bands | 0;
    $68 = $bands | 0;
    $69 = $bands + 4 | 0;
    $70 = $worker + 1296 | 0;
    $71 = $worker + 1304 | 0;
    $72 = $worker + 1308 | 0;
    $73 = $worker + 1300 | 0;
    $74 = $worker + 44 | 0;
    $75 = $worker + 48 | 0;
    $76 = $worker + 52 | 0;
    $77 = $worker + 40 | 0;
    label = 19;
    break;
   case 19:
    $min_0_load113 = $min;
    $79 = HEAP32[$54 >> 2] | 0;
    $80 = $79 + $min_0_load113 | 0;
    $max = $80;
    $n_0_load120 = $n;
    $num_bands_0_load118 = $num_bands;
    $81 = $num_bands_0_load118 - 1 | 0;
    $82 = ($n_0_load120 | 0) == ($81 | 0);
    if ($82) {
      label = 21;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $max_0_load110 = $max;
    $max_y_0_load108 = $max_y;
    $84 = ($max_0_load110 | 0) > ($max_y_0_load108 | 0);
    if ($84) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    $max_y_0_load109 = $max_y;
    $max = $max_y_0_load109;
    label = 22;
    break;
   case 22:
    $min_0_load114 = $min;
    HEAP32[$68 >> 2] = $min_0_load114;
    $max_0_load111 = $max;
    HEAP32[$69 >> 2] = $max_0_load111;
    $band = $67;
    $band_0_load122138 = $band;
    $87 = $band_0_load122138 >>> 0 < $67 >>> 0;
    if ($87) {
      label = 36;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $88 = HEAP32[$70 >> 2] | 0;
    $89 = $88;
    HEAP32[$71 >> 2] = $89;
    $band_0_load123 = $band;
    $90 = $band_0_load123 + 4 | 0;
    $91 = HEAP32[$90 >> 2] | 0;
    $band_0_load124 = $band;
    $92 = $band_0_load124 | 0;
    $93 = HEAP32[$92 >> 2] | 0;
    $94 = $91 - $93 | 0;
    HEAP32[$72 >> 2] = $94;
    $95 = $94 << 2;
    $96 = $95 & 12;
    $97 = ($96 | 0) == 0;
    if ($97) {
      $cell_start_0 = $95;
      label = 25;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $99 = $95 + 16 | 0;
    $100 = $99 - $96 | 0;
    $cell_start_0 = $100;
    label = 25;
    break;
   case 25:
    $102 = HEAP32[$73 >> 2] | 0;
    $103 = $102 & -16;
    $104 = HEAP32[$70 >> 2] | 0;
    $105 = $104 + $cell_start_0 | 0;
    $106 = $105;
    HEAP32[$74 >> 2] = $106;
    $107 = ($cell_start_0 | 0) < ($103 | 0);
    if ($107) {
      label = 26;
      break;
    } else {
      label = 32;
      break;
    }
   case 26:
    $109 = $103 - $cell_start_0 | 0;
    $110 = $109 >> 4;
    HEAP32[$75 >> 2] = $110;
    $111 = ($109 | 0) < 32;
    if ($111) {
      label = 32;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $112 = HEAP32[$72 >> 2] | 0;
    $113 = ($112 | 0) > 0;
    if ($113) {
      $yindex_0137 = 0;
      label = 28;
      break;
    } else {
      label = 29;
      break;
    }
   case 28:
    $114 = HEAP32[$71 >> 2] | 0;
    $115 = $114 + ($yindex_0137 << 2) | 0;
    HEAP32[$115 >> 2] = 0;
    $116 = $yindex_0137 + 1 | 0;
    $117 = HEAP32[$72 >> 2] | 0;
    $118 = ($116 | 0) < ($117 | 0);
    if ($118) {
      $yindex_0137 = $116;
      label = 28;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    HEAP32[$76 >> 2] = 0;
    HEAP32[$77 >> 2] = 1;
    $band_0_load125 = $band;
    $119 = $band_0_load125 | 0;
    $120 = HEAP32[$119 >> 2] | 0;
    HEAP32[$19 >> 2] = $120;
    $band_0_load126 = $band;
    $121 = $band_0_load126 + 4 | 0;
    $122 = HEAP32[$121 >> 2] | 0;
    HEAP32[$13 >> 2] = $122;
    $band_0_load127 = $band;
    $123 = $band_0_load127 + 4 | 0;
    $124 = HEAP32[$123 >> 2] | 0;
    $band_0_load128 = $band;
    $125 = $band_0_load128 | 0;
    $126 = HEAP32[$125 >> 2] | 0;
    $127 = $124 - $126 | 0;
    HEAP32[$50 >> 2] = $127;
    $128 = _gray_convert_glyph_inner($worker) | 0;
    if (($128 | 0) == 0) {
      label = 30;
      break;
    } else if (($128 | 0) == 64) {
      label = 32;
      break;
    } else {
      $_0 = 1;
      label = 40;
      break;
    }
   case 30:
    _gray_sweep($worker);
    $band_0_load129 = $band;
    $130 = $band_0_load129 - 8 | 0;
    $band = $130;
    label = 31;
    break;
   case 31:
    $band_0_load122 = $band;
    $131 = $band_0_load122 >>> 0 < $67 >>> 0;
    if ($131) {
      label = 36;
      break;
    } else {
      label = 23;
      break;
    }
   case 32:
    $band_0_load130 = $band;
    $133 = $band_0_load130 | 0;
    $134 = HEAP32[$133 >> 2] | 0;
    $band_0_load131 = $band;
    $135 = $band_0_load131 + 4 | 0;
    $136 = HEAP32[$135 >> 2] | 0;
    $137 = $136 - $134 | 0;
    $138 = $137 >> 1;
    $139 = $138 + $134 | 0;
    $140 = ($138 | 0) == 0;
    if ($140) {
      $_0 = 1;
      label = 40;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    $142 = $134 - $136 | 0;
    $143 = HEAP32[$54 >> 2] | 0;
    $144 = ($142 | 0) < ($143 | 0);
    if ($144) {
      label = 35;
      break;
    } else {
      label = 34;
      break;
    }
   case 34:
    $146 = HEAP32[$63 >> 2] | 0;
    $147 = $146 + 1 | 0;
    HEAP32[$63 >> 2] = $147;
    label = 35;
    break;
   case 35:
    $band_0_load132 = $band;
    $149 = $band_0_load132 + 8 | 0;
    HEAP32[$149 >> 2] = $134;
    $band_0_load133 = $band;
    $150 = $band_0_load133 + 12 | 0;
    HEAP32[$150 >> 2] = $139;
    $band_0_load134 = $band;
    $151 = $band_0_load134 | 0;
    HEAP32[$151 >> 2] = $139;
    $band_0_load135 = $band;
    $152 = $band_0_load135 + 4 | 0;
    HEAP32[$152 >> 2] = $136;
    $band_0_load136 = $band;
    $153 = $band_0_load136 + 8 | 0;
    $band = $153;
    label = 31;
    break;
   case 36:
    $n_0_load121 = $n;
    $154 = $n_0_load121 + 1 | 0;
    $n = $154;
    $max_0_load112 = $max;
    $min = $max_0_load112;
    $n_0_load119 = $n;
    $num_bands_0_load117 = $num_bands;
    $155 = ($n_0_load119 | 0) < ($num_bands_0_load117 | 0);
    if ($155) {
      label = 19;
      break;
    } else {
      label = 37;
      break;
    }
   case 37:
    $156 = HEAP32[$63 >> 2] | 0;
    $157 = ($156 | 0) > 8;
    if ($157) {
      label = 38;
      break;
    } else {
      $_0 = 0;
      label = 40;
      break;
    }
   case 38:
    $159 = HEAP32[$54 >> 2] | 0;
    $160 = ($159 | 0) > 16;
    if ($160) {
      label = 39;
      break;
    } else {
      $_0 = 0;
      label = 40;
      break;
    }
   case 39:
    $162 = ($159 | 0) / 2 & -1;
    HEAP32[$54 >> 2] = $162;
    $_0 = 0;
    label = 40;
    break;
   case 40:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _gray_compute_cbox($worker) {
  $worker = $worker | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $vec_040 = 0, $vec_042 = 0, $_pn41 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $30 = 0, $31 = 0, $34 = 0, $35 = 0, $38 = 0, $39 = 0, $vec_0 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 984 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $worker + 982 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 << 16 >> 16;
    $6 = $2 + ($5 << 3) | 0;
    $7 = $4 << 16 >> 16 < 1;
    if ($7) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $9 = $worker + 8 | 0;
    $10 = $9;
    _memset($10 | 0, 0, 16);
    label = 15;
    break;
   case 3:
    $12 = $2 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $worker + 12 | 0;
    HEAP32[$14 >> 2] = $13;
    $15 = $worker + 8 | 0;
    HEAP32[$15 >> 2] = $13;
    $16 = $2 + 4 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $worker + 20 | 0;
    HEAP32[$18 >> 2] = $17;
    $19 = $worker + 16 | 0;
    HEAP32[$19 >> 2] = $17;
    $20 = $4 << 16 >> 16 > 1;
    if ($20) {
      label = 4;
      break;
    } else {
      label = 14;
      break;
    }
   case 4:
    $vec_040 = $2 + 8 | 0;
    $_pn41 = $2;
    $vec_042 = $vec_040;
    label = 5;
    break;
   case 5:
    $22 = $vec_042 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $_pn41 + 12 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = HEAP32[$15 >> 2] | 0;
    $27 = ($23 | 0) < ($26 | 0);
    if ($27) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    HEAP32[$15 >> 2] = $23;
    label = 7;
    break;
   case 7:
    $30 = HEAP32[$14 >> 2] | 0;
    $31 = ($23 | 0) > ($30 | 0);
    if ($31) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    HEAP32[$14 >> 2] = $23;
    label = 9;
    break;
   case 9:
    $34 = HEAP32[$19 >> 2] | 0;
    $35 = ($25 | 0) < ($34 | 0);
    if ($35) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    HEAP32[$19 >> 2] = $25;
    label = 11;
    break;
   case 11:
    $38 = HEAP32[$18 >> 2] | 0;
    $39 = ($25 | 0) > ($38 | 0);
    if ($39) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $vec_0 = $vec_042 + 8 | 0;
    $40 = $vec_0 >>> 0 < $6 >>> 0;
    if ($40) {
      $_pn41 = $vec_042;
      $vec_042 = $vec_0;
      label = 5;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    HEAP32[$18 >> 2] = $25;
    label = 12;
    break;
   case 14:
    $42 = HEAP32[$15 >> 2] | 0;
    $43 = $42 >> 6;
    HEAP32[$15 >> 2] = $43;
    $44 = HEAP32[$19 >> 2] | 0;
    $45 = $44 >> 6;
    HEAP32[$19 >> 2] = $45;
    $46 = HEAP32[$14 >> 2] | 0;
    $47 = $46 + 63 | 0;
    $48 = $47 >> 6;
    HEAP32[$14 >> 2] = $48;
    $49 = HEAP32[$18 >> 2] | 0;
    $50 = $49 + 63 | 0;
    $51 = $50 >> 6;
    HEAP32[$18 >> 2] = $51;
    label = 15;
    break;
   case 15:
    return;
  }
}
function _gray_convert_glyph_inner($worker) {
  $worker = $worker | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $error_0_load4 = 0, label = 0, setjmpLabel = 0, setjmpTable = 0;
  label = 1;
  setjmpLabel = 0;
  setjmpTable = STACKTOP;
  STACKTOP = STACKTOP + 88 | 0;
  while (1) switch (label | 0) {
   case 1:
    $error = 0;
    $1 = $worker + 1256 | 0;
    $2 = _saveSetjmp($1 | 0, label, setjmpTable);
    label = 5;
    break;
   case 5:
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $5 = $worker + 980 | 0;
    $6 = $worker;
    $7 = invoke_iiii(640, $5 | 0, 5251348, $6 | 0) | 0;
    if ((__THREW__ | 0) != 0 & (threwValue | 0) > 0) {
      setjmpLabel = _testSetjmp(HEAP32[__THREW__ >> 2] | 0, setjmpTable);
      if ((setjmpLabel | 0) > 0) {
        label = -1111;
        break;
      } else return 0;
    }
    __THREW__ = threwValue = 0;
    $error = $7;
    invoke_vi(108, $worker | 0);
    if ((__THREW__ | 0) != 0 & (threwValue | 0) > 0) {
      setjmpLabel = _testSetjmp(HEAP32[__THREW__ >> 2] | 0, setjmpTable);
      if ((setjmpLabel | 0) > 0) {
        label = -1111;
        break;
      } else return 0;
    }
    __THREW__ = threwValue = 0;
    label = 4;
    break;
   case 3:
    $error = 64;
    label = 4;
    break;
   case 4:
    $error_0_load4 = $error;
    return $error_0_load4 | 0;
   case -1111:
    if ((setjmpLabel | 0) == 1) {
      $2 = threwValue;
      label = 5;
    }
    __THREW__ = threwValue = 0;
    break;
  }
  return 0;
}
function _gray_split_cubic($base) {
  $base = $base | 0;
  var $1 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $11 = 0, $14 = 0, $17 = 0, $19 = 0, $21 = 0, $25 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $35 = 0, $38 = 0, $41 = 0, $43 = 0, $45 = 0;
  $1 = $base + 24 | 0;
  HEAP32[$base + 48 >> 2] = HEAP32[$1 >> 2] | 0;
  $4 = $base + 8 | 0;
  $5 = HEAP32[$4 >> 2] | 0;
  $6 = $base + 16 | 0;
  $7 = HEAP32[$6 >> 2] | 0;
  $11 = ((HEAP32[$base >> 2] | 0) + $5 | 0) / 2 & -1;
  HEAP32[$4 >> 2] = $11;
  $14 = ((HEAP32[$1 >> 2] | 0) + $7 | 0) / 2 & -1;
  HEAP32[$base + 40 >> 2] = $14;
  $17 = ($7 + $5 | 0) / 2 & -1;
  $19 = ($17 + $11 | 0) / 2 & -1;
  HEAP32[$6 >> 2] = $19;
  $21 = ($17 + $14 | 0) / 2 & -1;
  HEAP32[$base + 32 >> 2] = $21;
  HEAP32[$1 >> 2] = ($21 + $19 | 0) / 2 & -1;
  $25 = $base + 28 | 0;
  HEAP32[$base + 52 >> 2] = HEAP32[$25 >> 2] | 0;
  $28 = $base + 12 | 0;
  $29 = HEAP32[$28 >> 2] | 0;
  $30 = $base + 20 | 0;
  $31 = HEAP32[$30 >> 2] | 0;
  $35 = ((HEAP32[$base + 4 >> 2] | 0) + $29 | 0) / 2 & -1;
  HEAP32[$28 >> 2] = $35;
  $38 = ((HEAP32[$25 >> 2] | 0) + $31 | 0) / 2 & -1;
  HEAP32[$base + 44 >> 2] = $38;
  $41 = ($31 + $29 | 0) / 2 & -1;
  $43 = ($41 + $35 | 0) / 2 & -1;
  HEAP32[$30 >> 2] = $43;
  $45 = ($41 + $38 | 0) / 2 & -1;
  HEAP32[$base + 36 >> 2] = $45;
  HEAP32[$25 >> 2] = ($45 + $43 | 0) / 2 & -1;
  return;
}
function _gray_sweep($worker) {
  $worker = $worker | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $yindex_06 = 0, $12 = 0, $13 = 0, $cell_01 = 0, $14 = 0, $cell_04 = 0, $x_03 = 0, $cover_02 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $or_cond = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $36 = 0, $37 = 0, $38 = 0, $cell_0 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 52 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 17;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $worker + 1232 | 0;
    HEAP32[$5 >> 2] = 0;
    $6 = $worker + 1308 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = ($7 | 0) > 0;
    if ($8) {
      label = 3;
      break;
    } else {
      label = 14;
      break;
    }
   case 3:
    $9 = $worker + 1304 | 0;
    $10 = $worker + 24 | 0;
    $yindex_06 = 0;
    label = 4;
    break;
   case 4:
    $12 = HEAP32[$9 >> 2] | 0;
    $13 = $12 + ($yindex_06 << 2) | 0;
    $cell_01 = HEAP32[$13 >> 2] | 0;
    $14 = ($cell_01 | 0) == 0;
    if ($14) {
      label = 13;
      break;
    } else {
      $cover_02 = 0;
      $x_03 = 0;
      $cell_04 = $cell_01;
      label = 5;
      break;
    }
   case 5:
    $15 = $cell_04 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($16 | 0) <= ($x_03 | 0);
    $18 = ($cover_02 | 0) == 0;
    $or_cond = $17 | $18;
    if ($or_cond) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $20 = $cover_02 << 9;
    $21 = $16 - $x_03 | 0;
    _gray_hline($worker, $x_03, $yindex_06, $20, $21);
    label = 7;
    break;
   case 7:
    $23 = $cell_04 + 4 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24 + $cover_02 | 0;
    $26 = $25 << 9;
    $27 = $cell_04 + 8 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $26 - $28 | 0;
    $30 = ($26 | 0) == ($28 | 0);
    if ($30) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $32 = HEAP32[$15 >> 2] | 0;
    $33 = ($32 | 0) > -1;
    if ($33) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    _gray_hline($worker, $32, $yindex_06, $29, 1);
    label = 10;
    break;
   case 10:
    $36 = HEAP32[$15 >> 2] | 0;
    $37 = $36 + 1 | 0;
    $38 = $cell_04 + 12 | 0;
    $cell_0 = HEAP32[$38 >> 2] | 0;
    $39 = ($cell_0 | 0) == 0;
    if ($39) {
      label = 11;
      break;
    } else {
      $cover_02 = $25;
      $x_03 = $37;
      $cell_04 = $cell_0;
      label = 5;
      break;
    }
   case 11:
    $40 = ($25 | 0) == 0;
    if ($40) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $42 = $25 << 9;
    $43 = HEAP32[$10 >> 2] | 0;
    $44 = $43 - $37 | 0;
    _gray_hline($worker, $37, $yindex_06, $42, $44);
    label = 13;
    break;
   case 13:
    $45 = $yindex_06 + 1 | 0;
    $46 = HEAP32[$6 >> 2] | 0;
    $47 = ($45 | 0) < ($46 | 0);
    if ($47) {
      $yindex_06 = $45;
      label = 4;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $48 = $worker + 1236 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = ($49 | 0) == 0;
    if ($50) {
      label = 17;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $52 = HEAP32[$5 >> 2] | 0;
    $53 = ($52 | 0) > 0;
    if ($53) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    $55 = $worker + 1244 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = $worker + 1040 | 0;
    $58 = $worker + 1240 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    FUNCTION_TABLE_viiii[$49 & 1023]($56, $52, $57, $59);
    label = 17;
    break;
   case 17:
    return;
  }
}
function _gray_hline($worker, $x, $y, $area, $acount) {
  $worker = $worker | 0;
  $x = $x | 0;
  $y = $y | 0;
  $area = $area | 0;
  $acount = $acount | 0;
  var $1 = 0, $2 = 0, $3 = 0, $_ = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $14 = 0, $_49 = 0, $16 = 0, $__ = 0, $coverage_1 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $_50 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $_sum = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $or_cond = 0, $58 = 0, $59 = 0, $60 = 0, $_not = 0, $brmerge = 0, $62 = 0, $63 = 0, $66 = 0, $span_0 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $area >> 9;
    $2 = ($1 | 0) < 0;
    $3 = -$1 | 0;
    $_ = $2 ? $3 : $1;
    $4 = $worker + 996 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 & 2;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = $_ & 511;
    $10 = $9 >>> 0 > 256;
    if ($10) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $12 = 512 - $9 | 0;
    $coverage_1 = $12;
    label = 6;
    break;
   case 4:
    $14 = ($9 | 0) == 256;
    $_49 = $14 ? 255 : $9;
    $coverage_1 = $_49;
    label = 6;
    break;
   case 5:
    $16 = ($_ | 0) > 255;
    $__ = $16 ? 255 : $_;
    $coverage_1 = $__;
    label = 6;
    break;
   case 6:
    $18 = $worker + 16 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $19 + $y | 0;
    $21 = $worker + 8 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22 + $x | 0;
    $24 = ($23 | 0) < 32767;
    $_50 = $24 ? $23 : 32767;
    $25 = ($coverage_1 | 0) == 0;
    if ($25) {
      label = 18;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $27 = $worker + 1232 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $worker + 1040 | 0;
    $_sum = $28 - 1 | 0;
    $30 = ($28 | 0) > 0;
    if ($30) {
      label = 8;
      break;
    } else {
      label = 12;
      break;
    }
   case 8:
    $32 = $worker + 1244 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = ($33 | 0) == ($20 | 0);
    if ($34) {
      label = 9;
      break;
    } else {
      label = 12;
      break;
    }
   case 9:
    $36 = $worker + 1040 + ($_sum * 6 & -1) | 0;
    $37 = HEAP16[$36 >> 1] | 0;
    $38 = $37 << 16 >> 16;
    $39 = $worker + 1040 + ($_sum * 6 & -1) + 2 | 0;
    $40 = HEAP16[$39 >> 1] | 0;
    $41 = $40 & 65535;
    $42 = $41 + $38 | 0;
    $43 = ($42 | 0) == ($_50 | 0);
    if ($43) {
      label = 10;
      break;
    } else {
      label = 12;
      break;
    }
   case 10:
    $45 = $worker + 1040 + ($_sum * 6 & -1) + 4 | 0;
    $46 = HEAP8[$45] | 0;
    $47 = $46 & 255;
    $48 = ($47 | 0) == ($coverage_1 | 0);
    if ($48) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $50 = $41 + $acount | 0;
    $51 = $50 & 65535;
    HEAP16[$39 >> 1] = $51;
    label = 18;
    break;
   case 12:
    $53 = $worker + 1244 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = ($54 | 0) != ($20 | 0);
    $56 = ($28 | 0) > 31;
    $or_cond = $55 | $56;
    if ($or_cond) {
      label = 13;
      break;
    } else {
      label = 16;
      break;
    }
   case 13:
    $58 = $worker + 1236 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = ($59 | 0) == 0;
    $_not = $30 ^ 1;
    $brmerge = $60 | $_not;
    if ($brmerge) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $62 = $worker + 1240 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    FUNCTION_TABLE_viiii[$59 & 1023]($54, $28, $29, $63);
    label = 15;
    break;
   case 15:
    HEAP32[$27 >> 2] = 0;
    HEAP32[$53 >> 2] = $20;
    $span_0 = $29;
    label = 17;
    break;
   case 16:
    $66 = $worker + 1040 + ($28 * 6 & -1) | 0;
    $span_0 = $66;
    label = 17;
    break;
   case 17:
    $68 = $_50 & 65535;
    $69 = $span_0 | 0;
    HEAP16[$69 >> 1] = $68;
    $70 = $acount & 65535;
    $71 = $span_0 + 2 | 0;
    HEAP16[$71 >> 1] = $70;
    $72 = $coverage_1 & 255;
    $73 = $span_0 + 4 | 0;
    HEAP8[$73] = $72;
    $74 = HEAP32[$27 >> 2] | 0;
    $75 = $74 + 1 | 0;
    HEAP32[$27 >> 2] = $75;
    label = 18;
    break;
   case 18:
    return;
  }
}
function _gray_record_cell($worker) {
  $worker = $worker | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 40 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $5 = $worker + 32 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $worker + 36 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 | $6;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = _gray_find_cell($worker) | 0;
    $13 = HEAP32[$5 >> 2] | 0;
    $14 = $12 + 8 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15 + $13 | 0;
    HEAP32[$14 >> 2] = $16;
    $17 = HEAP32[$7 >> 2] | 0;
    $18 = $12 + 4 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $19 + $17 | 0;
    HEAP32[$18 >> 2] = $20;
    label = 4;
    break;
   case 4:
    return;
  }
}
function _gray_move_to($to, $worker) {
  $to = $to | 0;
  $worker = $worker | 0;
  var $3 = 0, $6 = 0;
  _gray_record_cell($worker);
  $3 = HEAP32[$to >> 2] << 2;
  $6 = HEAP32[$to + 4 >> 2] << 2;
  _gray_start_cell($worker, $3 >> 8, $6 >> 8);
  HEAP32[$worker + 64 >> 2] = $3;
  HEAP32[$worker + 68 >> 2] = $6;
  return 0;
}
function _gray_line_to($to, $worker) {
  $to = $to | 0;
  $worker = $worker | 0;
  _gray_render_line($worker, HEAP32[$to >> 2] << 2, HEAP32[$to + 4 >> 2] << 2);
  return 0;
}
function _gray_conic_to($control, $to, $worker) {
  $control = $control | 0;
  $to = $to | 0;
  $worker = $worker | 0;
  _gray_render_conic($worker, $control, $to);
  return 0;
}
function _gray_cubic_to($control1, $control2, $to, $worker) {
  $control1 = $control1 | 0;
  $control2 = $control2 | 0;
  $to = $to | 0;
  $worker = $worker | 0;
  _gray_render_cubic($worker, $control1, $control2, $to);
  return 0;
}
function _gray_render_cubic($worker, $control1, $control2, $to) {
  $worker = $worker | 0;
  $control1 = $control1 | 0;
  $control2 = $control2 | 0;
  $to = $to | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $arc_0 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $_ = 0, $39 = 0, $max_0 = 0, $40 = 0, $41 = 0, $42 = 0, $__ = 0, $43 = 0, $max_1 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $___ = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $max_2 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $71 = 0, $72 = 0, $73 = 0, $75 = 0, $76 = 0, $77 = 0, $79 = 0, $80 = 0, $81 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $145 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 76 | 0;
    $2 = $to | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 << 2;
    $5 = $1 | 0;
    HEAP32[$5 >> 2] = $4;
    $6 = $to + 4 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 << 2;
    $9 = $worker + 80 | 0;
    HEAP32[$9 >> 2] = $8;
    $10 = $control2 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 << 2;
    $13 = $worker + 84 | 0;
    HEAP32[$13 >> 2] = $12;
    $14 = $control2 + 4 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15 << 2;
    $17 = $worker + 88 | 0;
    HEAP32[$17 >> 2] = $16;
    $18 = $control1 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $19 << 2;
    $21 = $worker + 92 | 0;
    HEAP32[$21 >> 2] = $20;
    $22 = $control1 + 4 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $23 << 2;
    $25 = $worker + 96 | 0;
    HEAP32[$25 >> 2] = $24;
    $26 = $worker + 64 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $worker + 100 | 0;
    HEAP32[$28 >> 2] = $27;
    $29 = $worker + 68 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $worker + 104 | 0;
    HEAP32[$31 >> 2] = $30;
    $32 = $worker + 20 | 0;
    $33 = $worker + 16 | 0;
    $arc_0 = $1;
    label = 2;
    break;
   case 2:
    $34 = $arc_0 + 4 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $arc_0 + 12 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = ($37 | 0) < ($35 | 0);
    $_ = $38 ? $37 : $35;
    $39 = ($37 | 0) > ($35 | 0);
    $max_0 = $39 ? $37 : $35;
    $40 = $arc_0 + 20 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = ($41 | 0) < ($_ | 0);
    $__ = $42 ? $41 : $_;
    $43 = ($41 | 0) > ($max_0 | 0);
    $max_1 = $43 ? $41 : $max_0;
    $44 = $arc_0 + 24 | 0;
    $45 = $arc_0 + 28 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = ($46 | 0) < ($__ | 0);
    $___ = $47 ? $46 : $__;
    $48 = $___ >> 8;
    $49 = HEAP32[$32 >> 2] | 0;
    $50 = ($48 | 0) < ($49 | 0);
    if ($50) {
      label = 3;
      break;
    } else {
      label = 15;
      break;
    }
   case 3:
    $52 = ($46 | 0) > ($max_1 | 0);
    $max_2 = $52 ? $46 : $max_1;
    $53 = $max_2 >> 8;
    $54 = HEAP32[$33 >> 2] | 0;
    $55 = ($53 | 0) < ($54 | 0);
    if ($55) {
      label = 15;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $57 = $44 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = $arc_0 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = $58 - $60 | 0;
    $62 = $46 - $35 | 0;
    $63 = ($61 | 0) < 0;
    $64 = -$61 | 0;
    $65 = $63 ? $64 : $61;
    $66 = ($62 | 0) < 0;
    $67 = -$62 | 0;
    $68 = $66 ? $67 : $62;
    $69 = ($65 | 0) > ($68 | 0);
    if ($69) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $71 = $65 * 236 & -1;
    $72 = $68 * 97 & -1;
    $73 = $71 + $72 | 0;
    $79 = $73;
    label = 7;
    break;
   case 6:
    $75 = $65 * 97 & -1;
    $76 = $68 * 236 & -1;
    $77 = $75 + $76 | 0;
    $79 = $77;
    label = 7;
    break;
   case 7:
    $80 = $79 >> 8;
    $81 = ($80 | 0) > 32767;
    if ($81) {
      label = 14;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $83 = $80 * 42 & -1;
    $84 = $arc_0 + 8 | 0;
    $85 = HEAP32[$84 >> 2] | 0;
    $86 = HEAP32[$59 >> 2] | 0;
    $87 = $85 - $86 | 0;
    $88 = HEAP32[$36 >> 2] | 0;
    $89 = HEAP32[$34 >> 2] | 0;
    $90 = $88 - $89 | 0;
    $91 = Math_imul($87, $62);
    $92 = Math_imul($90, $61);
    $93 = $91 - $92 | 0;
    $94 = ($93 | 0) < 0;
    $95 = -$93 | 0;
    $96 = $94 ? $95 : $93;
    $97 = ($96 | 0) > ($83 | 0);
    if ($97) {
      label = 14;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $99 = $arc_0 + 16 | 0;
    $100 = HEAP32[$99 >> 2] | 0;
    $101 = $100 - $86 | 0;
    $102 = HEAP32[$40 >> 2] | 0;
    $103 = $102 - $89 | 0;
    $104 = Math_imul($101, $62);
    $105 = Math_imul($103, $61);
    $106 = $104 - $105 | 0;
    $107 = ($106 | 0) < 0;
    $108 = -$106 | 0;
    $109 = $107 ? $108 : $106;
    $110 = ($109 | 0) > ($83 | 0);
    if ($110) {
      label = 14;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $112 = Math_imul($90, $62);
    $113 = Math_imul($87, $61);
    $114 = $112 + $113 | 0;
    $115 = ($114 | 0) < 0;
    if ($115) {
      label = 14;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $117 = Math_imul($103, $62);
    $118 = Math_imul($101, $61);
    $119 = $117 + $118 | 0;
    $120 = ($119 | 0) < 0;
    if ($120) {
      label = 14;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $122 = HEAP32[$45 >> 2] | 0;
    $123 = $122 - $88 | 0;
    $124 = Math_imul($123, $62);
    $125 = HEAP32[$57 >> 2] | 0;
    $126 = $125 - $85 | 0;
    $127 = Math_imul($126, $61);
    $128 = $127 + $124 | 0;
    $129 = ($128 | 0) < 0;
    if ($129) {
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $131 = $122 - $102 | 0;
    $132 = Math_imul($131, $62);
    $133 = $125 - $100 | 0;
    $134 = Math_imul($133, $61);
    $135 = $134 + $132 | 0;
    $136 = ($135 | 0) < 0;
    if ($136) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    _gray_split_cubic($arc_0);
    $arc_0 = $44;
    label = 2;
    break;
   case 15:
    $139 = $arc_0 | 0;
    $140 = HEAP32[$139 >> 2] | 0;
    $141 = HEAP32[$34 >> 2] | 0;
    _gray_render_line($worker, $140, $141);
    $142 = ($arc_0 | 0) == ($1 | 0);
    if ($142) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    return;
   case 17:
    $145 = $arc_0 - 24 | 0;
    $arc_0 = $145;
    label = 2;
    break;
  }
}
function _gray_render_line($worker, $to_x, $to_y) {
  $worker = $worker | 0;
  $to_x = $to_x | 0;
  $to_y = $to_y | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $_ = 0, $15 = 0, $16 = 0, $17 = 0, $_122 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $ey1_0129 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $66 = 0, $_125 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $_128 = 0, $p_0 = 0, $72 = 0, $73 = 0, $74 = 0, $76 = 0, $77 = 0, $delta_0 = 0, $mod_0 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $90 = 0, $91 = 0, $rem_0 = 0, $lift_0 = 0, $93 = 0, $94 = 0, $95 = 0, $ey1_1132 = 0, $mod_1131 = 0, $x_0130 = 0, $97 = 0, $98 = 0, $_lobit = 0, $_lobit_not = 0, $delta_1 = 0, $99 = 0, $mod_2 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $x_1 = 0, $ey1_2 = 0, $104 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 72 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 >> 8;
    $4 = $to_y >> 8;
    $5 = $worker + 68 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 - $2 | 0;
    $8 = $4 << 8;
    $9 = $to_y - $8 | 0;
    $10 = $worker + 64 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $to_x - $11 | 0;
    $13 = $to_y - $6 | 0;
    $14 = ($3 | 0) > ($4 | 0);
    $_ = $14 ? $4 : $3;
    $15 = $worker + 20 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($_ | 0) < ($16 | 0);
    if ($17) {
      label = 2;
      break;
    } else {
      label = 18;
      break;
    }
   case 2:
    $_122 = $14 ? $3 : $4;
    $19 = $worker + 16 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = ($_122 | 0) < ($20 | 0);
    if ($21) {
      label = 18;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $23 = ($3 | 0) == ($4 | 0);
    if ($23) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    _gray_render_scanline($worker, $3, $11, $7, $to_x, $9);
    label = 18;
    break;
   case 5:
    $26 = ($11 | 0) == ($to_x | 0);
    if ($26) {
      label = 6;
      break;
    } else {
      label = 9;
      break;
    }
   case 6:
    $28 = $11 >> 8;
    $29 = $28 << 8;
    $30 = $11 - $29 | 0;
    $31 = $30 << 1;
    $32 = $13 >> 31;
    $33 = $32 + 256 | 0;
    $34 = $33 & -256;
    $35 = $13 >> 31;
    $36 = $35 | 1;
    $37 = $34 - $7 | 0;
    $38 = Math_imul($31, $37);
    $39 = $worker + 32 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $40 + $38 | 0;
    HEAP32[$39 >> 2] = $41;
    $42 = $worker + 36 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $43 + $37 | 0;
    HEAP32[$42 >> 2] = $44;
    $45 = $36 + $3 | 0;
    _gray_set_cell($worker, $28, $45);
    $46 = $34 << 1;
    $47 = $46 - 256 | 0;
    $48 = Math_imul($47, $31);
    $49 = ($45 | 0) == ($4 | 0);
    if ($49) {
      label = 8;
      break;
    } else {
      $ey1_0129 = $45;
      label = 7;
      break;
    }
   case 7:
    $50 = HEAP32[$39 >> 2] | 0;
    $51 = $50 + $48 | 0;
    HEAP32[$39 >> 2] = $51;
    $52 = HEAP32[$42 >> 2] | 0;
    $53 = $52 + $47 | 0;
    HEAP32[$42 >> 2] = $53;
    $54 = $ey1_0129 + $36 | 0;
    _gray_set_cell($worker, $28, $54);
    $55 = ($54 | 0) == ($4 | 0);
    if ($55) {
      label = 8;
      break;
    } else {
      $ey1_0129 = $54;
      label = 7;
      break;
    }
   case 8:
    $56 = $9 - 256 | 0;
    $57 = $56 + $34 | 0;
    $58 = Math_imul($31, $57);
    $59 = HEAP32[$39 >> 2] | 0;
    $60 = $59 + $58 | 0;
    HEAP32[$39 >> 2] = $60;
    $61 = HEAP32[$42 >> 2] | 0;
    $62 = $61 + $57 | 0;
    HEAP32[$42 >> 2] = $62;
    label = 18;
    break;
   case 9:
    $64 = 256 - $7 | 0;
    $65 = ($13 | 0) < 0;
    $66 = -$13 | 0;
    $_125 = $65 ? $7 : $64;
    $67 = $13 >> 31;
    $68 = $67 + 256 | 0;
    $69 = $68 & -256;
    $70 = $13 >> 31;
    $71 = $70 | 1;
    $_128 = $65 ? $66 : $13;
    $p_0 = Math_imul($_125, $12);
    $72 = ($p_0 | 0) / ($_128 | 0) & -1;
    $73 = ($p_0 | 0) % ($_128 | 0);
    $74 = ($73 | 0) < 0;
    if ($74) {
      label = 10;
      break;
    } else {
      $mod_0 = $73;
      $delta_0 = $72;
      label = 11;
      break;
    }
   case 10:
    $76 = $72 - 1 | 0;
    $77 = $73 + $_128 | 0;
    $mod_0 = $77;
    $delta_0 = $76;
    label = 11;
    break;
   case 11:
    $79 = HEAP32[$10 >> 2] | 0;
    $80 = $79 + $delta_0 | 0;
    _gray_render_scanline($worker, $3, $79, $7, $80, $69);
    $81 = $71 + $3 | 0;
    $82 = $80 >> 8;
    _gray_set_cell($worker, $82, $81);
    $83 = ($81 | 0) == ($4 | 0);
    if ($83) {
      $ey1_2 = $81;
      $x_1 = $80;
      label = 17;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $85 = $12 << 8;
    $86 = ($85 | 0) / ($_128 | 0) & -1;
    $87 = ($85 | 0) % ($_128 | 0);
    $88 = ($87 | 0) < 0;
    if ($88) {
      label = 13;
      break;
    } else {
      $lift_0 = $86;
      $rem_0 = $87;
      label = 14;
      break;
    }
   case 13:
    $90 = $86 - 1 | 0;
    $91 = $87 + $_128 | 0;
    $lift_0 = $90;
    $rem_0 = $91;
    label = 14;
    break;
   case 14:
    $93 = ($81 | 0) == ($4 | 0);
    if ($93) {
      $ey1_2 = $81;
      $x_1 = $80;
      label = 17;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $94 = $mod_0 - $_128 | 0;
    $95 = 256 - $69 | 0;
    $x_0130 = $80;
    $mod_1131 = $94;
    $ey1_1132 = $81;
    label = 16;
    break;
   case 16:
    $97 = $mod_1131 + $rem_0 | 0;
    $98 = ($97 | 0) > -1;
    $_lobit = $97 >>> 31;
    $_lobit_not = $_lobit ^ 1;
    $delta_1 = $lift_0 + $_lobit_not | 0;
    $99 = $98 ? $_128 : 0;
    $mod_2 = $97 - $99 | 0;
    $100 = $delta_1 + $x_0130 | 0;
    _gray_render_scanline($worker, $ey1_1132, $x_0130, $95, $100, $69);
    $101 = $ey1_1132 + $71 | 0;
    $102 = $100 >> 8;
    _gray_set_cell($worker, $102, $101);
    $103 = ($101 | 0) == ($4 | 0);
    if ($103) {
      $ey1_2 = $101;
      $x_1 = $100;
      label = 17;
      break;
    } else {
      $x_0130 = $100;
      $mod_1131 = $mod_2;
      $ey1_1132 = $101;
      label = 16;
      break;
    }
   case 17:
    $104 = 256 - $69 | 0;
    _gray_render_scanline($worker, $ey1_2, $x_1, $104, $to_x, $9);
    label = 18;
    break;
   case 18:
    HEAP32[$10 >> 2] = $to_x;
    HEAP32[$5 >> 2] = $to_y;
    HEAP32[$1 >> 2] = $8;
    return;
  }
}
function _gray_render_scanline($worker, $ey, $x1, $y1, $x2, $y2) {
  $worker = $worker | 0;
  $ey = $ey | 0;
  $x1 = $x1 | 0;
  $y1 = $y1 | 0;
  $x2 = $x2 | 0;
  $y2 = $y2 | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $_ = 0, $27 = 0, $28 = 0, $29 = 0, $_84 = 0, $30 = 0, $31 = 0, $p_0 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $delta_0 = 0, $mod_0 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $lift_0 = 0, $rem_0 = 0, $61 = 0, $62 = 0, $mod_189 = 0, $_088 = 0, $ex1_087 = 0, $64 = 0, $65 = 0, $_lobit = 0, $_lobit_not = 0, $delta_1 = 0, $66 = 0, $mod_2 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $_1 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $x2 - $x1 | 0;
    $2 = $x1 >> 8;
    $3 = $x2 >> 8;
    $4 = $2 << 8;
    $5 = $x1 - $4 | 0;
    $6 = $3 << 8;
    $7 = $x2 - $6 | 0;
    $8 = ($y1 | 0) == ($y2 | 0);
    if ($8) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    _gray_set_cell($worker, $3, $ey);
    label = 14;
    break;
   case 3:
    $11 = ($2 | 0) == ($3 | 0);
    if ($11) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $13 = $y2 - $y1 | 0;
    $14 = $7 + $5 | 0;
    $15 = Math_imul($14, $13);
    $16 = $worker + 32 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $17 + $15 | 0;
    HEAP32[$16 >> 2] = $18;
    $19 = $worker + 36 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $20 + $13 | 0;
    HEAP32[$19 >> 2] = $21;
    label = 14;
    break;
   case 5:
    $23 = 256 - $5 | 0;
    $24 = $y2 - $y1 | 0;
    $25 = ($1 | 0) < 0;
    $26 = -$1 | 0;
    $_ = $25 ? $5 : $23;
    $27 = $1 >> 31;
    $28 = $27 + 256 | 0;
    $29 = $28 & -256;
    $_84 = $25 ? $26 : $1;
    $30 = $1 >> 31;
    $31 = $30 | 1;
    $p_0 = Math_imul($_, $24);
    $32 = ($p_0 | 0) / ($_84 | 0) & -1;
    $33 = ($p_0 | 0) % ($_84 | 0);
    $34 = ($33 | 0) < 0;
    if ($34) {
      label = 6;
      break;
    } else {
      $mod_0 = $33;
      $delta_0 = $32;
      label = 7;
      break;
    }
   case 6:
    $36 = $32 - 1 | 0;
    $37 = $33 + $_84 | 0;
    $mod_0 = $37;
    $delta_0 = $36;
    label = 7;
    break;
   case 7:
    $39 = $29 + $5 | 0;
    $40 = Math_imul($delta_0, $39);
    $41 = $worker + 32 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = $42 + $40 | 0;
    HEAP32[$41 >> 2] = $43;
    $44 = $worker + 36 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = $45 + $delta_0 | 0;
    HEAP32[$44 >> 2] = $46;
    $47 = $31 + $2 | 0;
    _gray_set_cell($worker, $47, $ey);
    $48 = $delta_0 + $y1 | 0;
    $49 = ($47 | 0) == ($3 | 0);
    if ($49) {
      $_1 = $48;
      label = 13;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $51 = $delta_0 + $y2 | 0;
    $52 = $51 - $48 | 0;
    $53 = $52 << 8;
    $54 = ($53 | 0) / ($_84 | 0) & -1;
    $55 = ($53 | 0) % ($_84 | 0);
    $56 = ($55 | 0) < 0;
    if ($56) {
      label = 9;
      break;
    } else {
      $rem_0 = $55;
      $lift_0 = $54;
      label = 10;
      break;
    }
   case 9:
    $58 = $54 - 1 | 0;
    $59 = $55 + $_84 | 0;
    $rem_0 = $59;
    $lift_0 = $58;
    label = 10;
    break;
   case 10:
    $61 = ($47 | 0) == ($3 | 0);
    if ($61) {
      $_1 = $48;
      label = 13;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $62 = $mod_0 - $_84 | 0;
    $ex1_087 = $47;
    $_088 = $48;
    $mod_189 = $62;
    label = 12;
    break;
   case 12:
    $64 = $mod_189 + $rem_0 | 0;
    $65 = ($64 | 0) > -1;
    $_lobit = $64 >>> 31;
    $_lobit_not = $_lobit ^ 1;
    $delta_1 = $lift_0 + $_lobit_not | 0;
    $66 = $65 ? $_84 : 0;
    $mod_2 = $64 - $66 | 0;
    $67 = $delta_1 << 8;
    $68 = HEAP32[$41 >> 2] | 0;
    $69 = $68 + $67 | 0;
    HEAP32[$41 >> 2] = $69;
    $70 = HEAP32[$44 >> 2] | 0;
    $71 = $70 + $delta_1 | 0;
    HEAP32[$44 >> 2] = $71;
    $72 = $delta_1 + $_088 | 0;
    $73 = $ex1_087 + $31 | 0;
    _gray_set_cell($worker, $73, $ey);
    $74 = ($73 | 0) == ($3 | 0);
    if ($74) {
      $_1 = $72;
      label = 13;
      break;
    } else {
      $ex1_087 = $73;
      $_088 = $72;
      $mod_189 = $mod_2;
      label = 12;
      break;
    }
   case 13:
    $75 = $y2 - $_1 | 0;
    $76 = $7 + 256 | 0;
    $77 = $76 - $29 | 0;
    $78 = Math_imul($75, $77);
    $79 = HEAP32[$41 >> 2] | 0;
    $80 = $78 + $79 | 0;
    HEAP32[$41 >> 2] = $80;
    $81 = HEAP32[$44 >> 2] | 0;
    $82 = $81 + $75 | 0;
    HEAP32[$44 >> 2] = $82;
    label = 14;
    break;
   case 14:
    return;
  }
}
function _gray_find_cell($worker) {
  $worker = $worker | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_ = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $pcell_0 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $cell_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $worker + 24 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) > ($4 | 0);
    $_ = $5 ? $4 : $2;
    $6 = $worker + 4 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $worker + 1304 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 + ($7 << 2) | 0;
    $pcell_0 = $10;
    label = 2;
    break;
   case 2:
    $12 = HEAP32[$pcell_0 >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $15 = $12 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($16 | 0) > ($_ | 0);
    if ($17) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $19 = ($16 | 0) == ($_ | 0);
    $20 = $12 + 12 | 0;
    if ($19) {
      $cell_0 = $12;
      label = 8;
      break;
    } else {
      $pcell_0 = $20;
      label = 2;
      break;
    }
   case 5:
    $22 = $worker + 52 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $worker + 48 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = ($23 | 0) < ($25 | 0);
    if ($26) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $28 = $worker + 1256 | 0;
    _longjmp($28 | 0, 1);
    return 0;
   case 7:
    $30 = $worker + 44 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $23 + 1 | 0;
    HEAP32[$22 >> 2] = $32;
    $33 = $31 + ($23 << 4) | 0;
    $34 = $33 | 0;
    HEAP32[$34 >> 2] = $_;
    $35 = $31 + ($23 << 4) + 8 | 0;
    HEAP32[$35 >> 2] = 0;
    $36 = $31 + ($23 << 4) + 4 | 0;
    HEAP32[$36 >> 2] = 0;
    $37 = HEAP32[$pcell_0 >> 2] | 0;
    $38 = $31 + ($23 << 4) + 12 | 0;
    HEAP32[$38 >> 2] = $37;
    HEAP32[$pcell_0 >> 2] = $33;
    $cell_0 = $33;
    label = 8;
    break;
   case 8:
    return $cell_0 | 0;
  }
  return 0;
}
function _gray_split_conic($base) {
  $base = $base | 0;
  var $1 = 0, $4 = 0, $5 = 0, $8 = 0, $13 = 0, $16 = 0, $19 = 0, $20 = 0, $23 = 0, $28 = 0;
  $1 = $base + 16 | 0;
  HEAP32[$base + 32 >> 2] = HEAP32[$1 >> 2] | 0;
  $4 = $base + 8 | 0;
  $5 = HEAP32[$4 >> 2] | 0;
  $8 = ((HEAP32[$1 >> 2] | 0) + $5 | 0) / 2 & -1;
  HEAP32[$base + 24 >> 2] = $8;
  $13 = ((HEAP32[$base >> 2] | 0) + $5 | 0) / 2 & -1;
  HEAP32[$4 >> 2] = $13;
  HEAP32[$1 >> 2] = ($13 + $8 | 0) / 2 & -1;
  $16 = $base + 20 | 0;
  HEAP32[$base + 36 >> 2] = HEAP32[$16 >> 2] | 0;
  $19 = $base + 12 | 0;
  $20 = HEAP32[$19 >> 2] | 0;
  $23 = ((HEAP32[$16 >> 2] | 0) + $20 | 0) / 2 & -1;
  HEAP32[$base + 28 >> 2] = $23;
  $28 = ((HEAP32[$base + 4 >> 2] | 0) + $20 | 0) / 2 & -1;
  HEAP32[$19 >> 2] = $28;
  HEAP32[$16 >> 2] = ($28 + $23 | 0) / 2 & -1;
  return;
}
function _tt_size_init($ttsize) {
  $ttsize = $ttsize | 0;
  HEAP8[$ttsize + 300 | 0] = 0;
  HEAP8[$ttsize + 301 | 0] = 0;
  HEAP8[($ttsize + 72 | 0) + 36 | 0] = 0;
  HEAP32[$ttsize + 112 >> 2] = -1;
  return 0;
}
function _gray_set_cell($worker, $ex, $ey) {
  $worker = $worker | 0;
  $ex = $ex | 0;
  $ey = $ey | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_ex = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $_1 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $ey - $2 | 0;
    $4 = $worker + 12 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($5 | 0) < ($ex | 0);
    $_ex = $6 ? $5 : $ex;
    $7 = $worker + 8 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $_ex - $8 | 0;
    $10 = ($9 | 0) > -1;
    $_1 = $10 ? $9 : -1;
    $11 = $worker | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($_1 | 0) == ($12 | 0);
    if ($13) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $15 = $worker + 4 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($3 | 0) == ($16 | 0);
    if ($17) {
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $19 = $worker + 40 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    _gray_record_cell($worker);
    label = 5;
    break;
   case 5:
    $24 = $worker + 32 | 0;
    HEAP32[$24 >> 2] = 0;
    $25 = $worker + 36 | 0;
    HEAP32[$25 >> 2] = 0;
    label = 6;
    break;
   case 6:
    HEAP32[$11 >> 2] = $_1;
    $27 = $worker + 4 | 0;
    HEAP32[$27 >> 2] = $3;
    $28 = $worker + 28 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $3 >>> 0 < $29 >>> 0;
    if ($30) {
      label = 7;
      break;
    } else {
      $36 = 1;
      label = 8;
      break;
    }
   case 7:
    $32 = $worker + 24 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = ($_1 | 0) >= ($33 | 0);
    $36 = $34;
    label = 8;
    break;
   case 8:
    $37 = $36 & 1;
    $38 = $worker + 40 | 0;
    HEAP32[$38 >> 2] = $37;
    return;
  }
}
function _gray_render_conic($worker, $control, $to) {
  $worker = $worker | 0;
  $control = $control | 0;
  $to = $to | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $_ = 0, $42 = 0, $dx_170 = 0, $level_069 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $arc_068 = 0, $top_067 = 0, $51 = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $_65 = 0, $60 = 0, $max_0 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $__65 = 0, $65 = 0, $66 = 0, $67 = 0, $69 = 0, $max_1 = 0, $70 = 0, $71 = 0, $72 = 0, $74 = 0, $75 = 0, $76 = 0, $top_0_be = 0, $arc_0_be = 0, $77 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 76 | 0;
    $2 = $to | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 << 2;
    $5 = $1 | 0;
    HEAP32[$5 >> 2] = $4;
    $6 = $to + 4 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 << 2;
    $9 = $worker + 80 | 0;
    HEAP32[$9 >> 2] = $8;
    $10 = $control | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 << 2;
    $13 = $worker + 84 | 0;
    HEAP32[$13 >> 2] = $12;
    $14 = $control + 4 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15 << 2;
    $17 = $worker + 88 | 0;
    HEAP32[$17 >> 2] = $16;
    $18 = $worker + 64 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $worker + 92 | 0;
    HEAP32[$20 >> 2] = $19;
    $21 = $worker + 68 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $worker + 96 | 0;
    HEAP32[$23 >> 2] = $22;
    $24 = HEAP32[$20 >> 2] | 0;
    $25 = HEAP32[$5 >> 2] | 0;
    $26 = $25 + $24 | 0;
    $27 = HEAP32[$13 >> 2] | 0;
    $28 = $27 << 1;
    $29 = $26 - $28 | 0;
    $30 = ($29 | 0) < 0;
    $31 = -$29 | 0;
    $32 = $30 ? $31 : $29;
    $33 = HEAP32[$9 >> 2] | 0;
    $34 = $33 + $22 | 0;
    $35 = HEAP32[$17 >> 2] | 0;
    $36 = $35 << 1;
    $37 = $34 - $36 | 0;
    $38 = ($37 | 0) < 0;
    $39 = -$37 | 0;
    $40 = $38 ? $39 : $37;
    $41 = ($32 | 0) < ($40 | 0);
    $_ = $41 ? $40 : $32;
    $42 = ($_ | 0) < 65;
    if ($42) {
      label = 2;
      break;
    } else {
      $level_069 = 0;
      $dx_170 = $_;
      label = 3;
      break;
    }
   case 2:
    _gray_render_line($worker, $25, $33);
    label = 11;
    break;
   case 3:
    $44 = $dx_170 >> 2;
    $45 = $level_069 + 1 | 0;
    $46 = ($44 | 0) > 64;
    if ($46) {
      $level_069 = $45;
      $dx_170 = $44;
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $47 = $worker + 852 | 0;
    HEAP32[$47 >> 2] = $45;
    $48 = $worker + 20 | 0;
    $49 = $worker + 16 | 0;
    $top_067 = 0;
    $arc_068 = $1;
    label = 5;
    break;
   case 5:
    $51 = $worker + 852 + ($top_067 << 2) | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = ($52 | 0) > 1;
    if ($53) {
      label = 6;
      break;
    } else {
      label = 10;
      break;
    }
   case 6:
    $55 = $arc_068 + 4 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = $arc_068 + 12 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = ($58 | 0) < ($56 | 0);
    $_65 = $59 ? $58 : $56;
    $60 = ($58 | 0) > ($56 | 0);
    $max_0 = $60 ? $58 : $56;
    $61 = $arc_068 + 16 | 0;
    $62 = $arc_068 + 20 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = ($63 | 0) < ($_65 | 0);
    $__65 = $64 ? $63 : $_65;
    $65 = $__65 >> 8;
    $66 = HEAP32[$48 >> 2] | 0;
    $67 = ($65 | 0) < ($66 | 0);
    if ($67) {
      label = 7;
      break;
    } else {
      label = 10;
      break;
    }
   case 7:
    $69 = ($63 | 0) > ($max_0 | 0);
    $max_1 = $69 ? $63 : $max_0;
    $70 = $max_1 >> 8;
    $71 = HEAP32[$49 >> 2] | 0;
    $72 = ($70 | 0) < ($71 | 0);
    if ($72) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    _gray_split_conic($arc_068);
    $74 = $top_067 + 1 | 0;
    $75 = $52 - 1 | 0;
    HEAP32[$51 >> 2] = $75;
    $76 = $worker + 852 + ($74 << 2) | 0;
    HEAP32[$76 >> 2] = $75;
    $arc_0_be = $61;
    $top_0_be = $74;
    label = 9;
    break;
   case 9:
    $77 = ($top_0_be | 0) > -1;
    if ($77) {
      $top_067 = $top_0_be;
      $arc_068 = $arc_0_be;
      label = 5;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $79 = $arc_068 | 0;
    $80 = HEAP32[$79 >> 2] | 0;
    $81 = $arc_068 + 4 | 0;
    $82 = HEAP32[$81 >> 2] | 0;
    _gray_render_line($worker, $80, $82);
    $83 = $top_067 - 1 | 0;
    $84 = $arc_068 - 16 | 0;
    $arc_0_be = $84;
    $top_0_be = $83;
    label = 9;
    break;
   case 11:
    return;
  }
}
function _gray_start_cell($worker, $ex, $ey) {
  $worker = $worker | 0;
  $ex = $ex | 0;
  $ey = $ey | 0;
  var $2 = 0, $_ex = 0, $4 = 0, $5 = 0, $_1 = 0;
  $2 = HEAP32[$worker + 12 >> 2] | 0;
  $_ex = ($2 | 0) < ($ex | 0) ? $2 : $ex;
  $4 = $worker + 8 | 0;
  $5 = HEAP32[$4 >> 2] | 0;
  $_1 = ($_ex | 0) < ($5 | 0) ? $5 - 1 | 0 : $_ex;
  HEAP32[$worker + 32 >> 2] = 0;
  HEAP32[$worker + 36 >> 2] = 0;
  HEAP32[$worker >> 2] = $_1 - (HEAP32[$4 >> 2] | 0) | 0;
  HEAP32[$worker + 4 >> 2] = $ey - (HEAP32[$worker + 16 >> 2] | 0) | 0;
  HEAP32[$worker + 72 >> 2] = $ey << 8;
  HEAP32[$worker + 40 >> 2] = 0;
  _gray_set_cell($worker, $_1, $ey);
  return;
}
function _tt_driver_init($ttdriver) {
  $ttdriver = $ttdriver | 0;
  return ((_TT_New_Context($ttdriver) | 0) == 0 ? 153 : 0) | 0;
}
function _tt_driver_done($ttdriver) {
  $ttdriver = $ttdriver | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $ttdriver + 40 | 0;
    $2 = $1;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    _TT_Done_Context($3);
    $6 = $1 | 0;
    HEAP32[$6 >> 2] = 0;
    label = 3;
    break;
   case 3:
    return;
  }
}
function _tt_get_interface($driver, $tt_interface) {
  $driver = $driver | 0;
  $tt_interface = $tt_interface | 0;
  var $1 = 0, $2 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _ft_service_list_lookup(5243364, $tt_interface) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $_0 = $1;
      label = 6;
      break;
    }
   case 2:
    $4 = ($driver | 0) == 0;
    if ($4) {
      $_0 = 0;
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $6 = $driver + 4 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7;
    $9 = _FT_Get_Module($8, 5324508) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      $_0 = 0;
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $12 = $9;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 + 20 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      $_0 = 0;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $18 = $15 + 16 | 0;
    $19 = $18;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = FUNCTION_TABLE_iii[$20 & 1023]($driver, $tt_interface) | 0;
    $_0 = $21;
    label = 6;
    break;
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _tt_face_init($stream, $ttface, $face_index, $num_params, $params) {
  $stream = $stream | 0;
  $ttface = $ttface | 0;
  $face_index = $face_index | 0;
  $num_params = $num_params | 0;
  $params = $params | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $error_0 = 0, $54 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $62 = 0, $error_3 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $ttface;
    $2 = $ttface + 96 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5;
    $7 = _FT_Get_Module_Interface($6, 5324508) | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      $_0 = 2;
      label = 18;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = _FT_Stream_Seek($stream, 0) | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 3;
      break;
    } else {
      $_0 = $10;
      label = 18;
      break;
    }
   case 3:
    $13 = $7 + 4 | 0;
    $14 = $13;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = FUNCTION_TABLE_iiiiii[$15 & 1023]($stream, $1, $face_index, $num_params, $params) | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 4;
      break;
    } else {
      $_0 = $16;
      label = 18;
      break;
    }
   case 4:
    $19 = $ttface + 148 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    if (($20 | 0) == 65536 | ($20 | 0) == 131072 | ($20 | 0) == 1953658213) {
      label = 5;
      break;
    } else {
      $_0 = 2;
      label = 18;
      break;
    }
   case 5:
    $22 = $ttface + 8 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $23 | 2048;
    HEAP32[$22 >> 2] = $24;
    $25 = ($face_index | 0) < 0;
    if ($25) {
      $_0 = 0;
      label = 18;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $27 = $7 + 8 | 0;
    $28 = $27;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = FUNCTION_TABLE_iiiiii[$29 & 1023]($stream, $1, $face_index, $num_params, $params) | 0;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 7;
      break;
    } else {
      $_0 = $30;
      label = 18;
      break;
    }
   case 7:
    $33 = _tt_check_trickyness($ttface) | 0;
    $34 = $33 << 24 >> 24 == 0;
    if ($34) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $36 = HEAP32[$22 >> 2] | 0;
    $37 = $36 | 8192;
    HEAP32[$22 >> 2] = $37;
    label = 9;
    break;
   case 9:
    $39 = _tt_face_load_hdmx($1, $stream) | 0;
    $40 = ($39 | 0) == 0;
    if ($40) {
      label = 10;
      break;
    } else {
      $_0 = $39;
      label = 18;
      break;
    }
   case 10:
    $42 = HEAP32[$22 >> 2] | 0;
    $43 = $42 & 1;
    $44 = ($43 | 0) == 0;
    if ($44) {
      $error_3 = 0;
      label = 17;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $46 = $ttface + 128 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $47 + 52 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = ($49 | 0) == 0;
    if ($50) {
      label = 12;
      break;
    } else {
      $error_0 = $39;
      label = 13;
      break;
    }
   case 12:
    $52 = _tt_face_load_loca($1, $stream) | 0;
    $error_0 = $52;
    label = 13;
    break;
   case 13:
    $54 = ($error_0 | 0) == 0;
    if ($54) {
      label = 14;
      break;
    } else {
      $error_3 = $error_0;
      label = 17;
      break;
    }
   case 14:
    $56 = _tt_face_load_cvt($1, $stream) | 0;
    $57 = ($56 | 0) == 0;
    if ($57) {
      label = 15;
      break;
    } else {
      $error_3 = $56;
      label = 17;
      break;
    }
   case 15:
    $59 = _tt_face_load_fpgm($1, $stream) | 0;
    $60 = ($59 | 0) == 0;
    if ($60) {
      label = 16;
      break;
    } else {
      $error_3 = $59;
      label = 17;
      break;
    }
   case 16:
    $62 = _tt_face_load_prep($1, $stream) | 0;
    $error_3 = $62;
    label = 17;
    break;
   case 17:
    _TT_Init_Glyph_Loading($1);
    $_0 = $error_3;
    label = 18;
    break;
   case 18:
    return $_0 | 0;
  }
  return 0;
}
function _tt_face_done($ttface) {
  $ttface = $ttface | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $ttface;
    $2 = ($ttface | 0) == 0;
    if ($2) {
      label = 7;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $ttface + 100 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $ttface + 104 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $ttface + 532 | 0;
    $9 = $8;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $ttface + 692 | 0;
    $12 = $11 + 4 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $16 = $13;
    $17 = HEAP32[$11 >> 2] | 0;
    $18 = $17;
    FUNCTION_TABLE_vi[$16 & 1023]($18);
    label = 4;
    break;
   case 4:
    $20 = ($10 | 0) == 0;
    if ($20) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $22 = $10 + 12 | 0;
    $23 = $22;
    $24 = HEAP32[$23 >> 2] | 0;
    FUNCTION_TABLE_vi[$24 & 1023]($1);
    label = 6;
    break;
   case 6:
    _tt_face_done_loca($1);
    _tt_face_free_hdmx($1);
    $26 = $ttface + 672 | 0;
    $27 = $26;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $28;
    _ft_mem_free($5, $29);
    HEAP32[$26 >> 2] = 0;
    $30 = $ttface + 668 | 0;
    HEAP32[$30 >> 2] = 0;
    $31 = $ttface + 656 | 0;
    $32 = $31;
    _FT_Stream_ReleaseFrame($7, $32);
    $33 = $ttface + 664 | 0;
    $34 = $33;
    _FT_Stream_ReleaseFrame($7, $34);
    $35 = $ttface + 652 | 0;
    HEAP32[$35 >> 2] = 0;
    $36 = $ttface + 660 | 0;
    HEAP32[$36 >> 2] = 0;
    $37 = $ttface + 712 | 0;
    $38 = $37;
    $39 = HEAP32[$38 >> 2] | 0;
    _tt_done_blend($5, $39);
    $40 = $37 | 0;
    HEAP32[$40 >> 2] = 0;
    label = 7;
    break;
   case 7:
    return;
  }
}
function _tt_size_done($ttsize) {
  $ttsize = $ttsize | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $ttsize + 300 | 0;
    $2 = $1;
    $3 = HEAP8[$2] | 0;
    $4 = $3 << 24 >> 24 == 0;
    if ($4) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    _tt_size_done_bytecode($ttsize);
    label = 3;
    break;
   case 3:
    $7 = $ttsize + 72 | 0;
    $8 = $7 + 36 | 0;
    $9 = $8;
    HEAP8[$9] = 0;
    return;
  }
}
function _tt_slot_init($slot) {
  $slot = $slot | 0;
  return _FT_GlyphLoader_CreateExtra(HEAP32[HEAP32[$slot + 156 >> 2] >> 2] | 0) | 0;
}
function _Load_Glyph($ttslot, $ttsize, $glyph_index, $load_flags) {
  $ttslot = $ttslot | 0;
  $ttsize = $ttsize | 0;
  $glyph_index = $glyph_index | 0;
  $load_flags = $load_flags | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $load_flags_ = 0, $28 = 0, $29 = 0, $31 = 0, $_1 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $_ = 0, $_2 = 0, $42 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $ttsize;
    $2 = $ttslot + 4 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = ($ttslot | 0) == 0;
    if ($4) {
      $_0 = 37;
      label = 12;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = ($ttsize | 0) == 0;
    if ($6) {
      $_0 = 36;
      label = 12;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $8 = ($3 | 0) == 0;
    if ($8) {
      $_0 = 6;
      label = 12;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $10 = $3 + 16 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 >>> 0 > $glyph_index >>> 0;
    if ($12) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $14 = $3 + 128 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15 + 52 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      $_0 = 6;
      label = 12;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $20 = $load_flags & 2;
    $21 = ($20 | 0) == 0;
    if ($21) {
      $_1 = $load_flags;
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $23 = $3 + 8 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24 & 8192;
    $26 = ($25 | 0) == 0;
    $27 = $load_flags & -3;
    $load_flags_ = $26 ? $load_flags : $27;
    $28 = $load_flags_ & 32768;
    $29 = ($28 | 0) == 0;
    if ($29) {
      $_1 = $load_flags_;
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $31 = $load_flags_ | 2;
    $_1 = $31;
    label = 9;
    break;
   case 9:
    $33 = $_1 & 1025;
    $34 = ($33 | 0) == 0;
    if ($34) {
      $_2 = $_1;
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $36 = $3 + 8 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $37 >>> 12;
    $39 = $38 & 2;
    $40 = $39 ^ 11;
    $_ = $40 | $_1;
    $_2 = $_;
    label = 11;
    break;
   case 11:
    $42 = _TT_Load_Glyph($1, $ttslot, $glyph_index, $_2) | 0;
    $_0 = $42;
    label = 12;
    break;
   case 12:
    return $_0 | 0;
  }
  return 0;
}
function _tt_get_kerning($ttface, $left_glyph, $right_glyph, $kerning) {
  $ttface = $ttface | 0;
  $left_glyph = $left_glyph | 0;
  $right_glyph = $right_glyph | 0;
  $kerning = $kerning | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $ttface + 532 | 0;
    $2 = $1;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $kerning | 0;
    HEAP32[$4 >> 2] = 0;
    $5 = $kerning + 4 | 0;
    HEAP32[$5 >> 2] = 0;
    $6 = ($3 | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $ttface;
    $9 = $3 + 128 | 0;
    $10 = $9;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = FUNCTION_TABLE_iiii[$11 & 1023]($8, $left_glyph, $right_glyph) | 0;
    HEAP32[$4 >> 2] = $12;
    label = 3;
    break;
   case 3:
    return 0;
  }
  return 0;
}
function _tt_get_advances($ttface, $start, $count, $flags, $advances) {
  $ttface = $ttface | 0;
  $start = $start | 0;
  $count = $count | 0;
  $flags = $flags | 0;
  $advances = $advances | 0;
  var $tsb = 0, $ah = 0, $lsb = 0, $aw = 0, $1 = 0, $2 = 0, $_lobit = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $nn_021 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $exitcond23 = 0, $nn_118 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $exitcond = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $tsb = __stackBase__ | 0;
    $ah = __stackBase__ + 4 | 0;
    $lsb = __stackBase__ + 8 | 0;
    $aw = __stackBase__ + 12 | 0;
    $1 = $ttface;
    $2 = $flags >>> 9;
    $_lobit = $2 & 1;
    $3 = $_lobit ^ 1;
    $4 = $3 & 255;
    $5 = $flags & 16;
    $6 = ($5 | 0) == 0;
    $7 = ($count | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    if ($7) {
      label = 6;
      break;
    } else {
      $nn_021 = 0;
      label = 4;
      break;
    }
   case 3:
    if ($7) {
      label = 6;
      break;
    } else {
      $nn_118 = 0;
      label = 5;
      break;
    }
   case 4:
    $8 = $nn_021 + $start | 0;
    _TT_Get_VMetrics($1, $8, $tsb, $ah);
    $9 = HEAP16[$ah >> 1] | 0;
    $10 = $9 & 65535;
    $11 = $advances + ($nn_021 << 2) | 0;
    HEAP32[$11 >> 2] = $10;
    $12 = $nn_021 + 1 | 0;
    $exitcond23 = ($12 | 0) == ($count | 0);
    if ($exitcond23) {
      label = 6;
      break;
    } else {
      $nn_021 = $12;
      label = 4;
      break;
    }
   case 5:
    $13 = $nn_118 + $start | 0;
    _TT_Get_HMetrics($1, $13, $4, $lsb, $aw);
    $14 = HEAP16[$aw >> 1] | 0;
    $15 = $14 & 65535;
    $16 = $advances + ($nn_118 << 2) | 0;
    HEAP32[$16 >> 2] = $15;
    $17 = $nn_118 + 1 | 0;
    $exitcond = ($17 | 0) == ($count | 0);
    if ($exitcond) {
      label = 6;
      break;
    } else {
      $nn_118 = $17;
      label = 5;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return 0;
  }
  return 0;
}
function _tt_size_request($size, $req) {
  $size = $size | 0;
  $req = $req | 0;
  var $strike_index = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $21 = 0, $22 = 0, $error_0 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $strike_index = __stackBase__ | 0;
    $1 = $size;
    $2 = $size | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 + 8 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 & 2;
    $7 = ($6 | 0) == 0;
    if ($7) {
      $error_0 = 0;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = $3;
    $10 = $3 + 532 | 0;
    $11 = $10;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + 148 | 0;
    $14 = $13;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = FUNCTION_TABLE_iiii[$15 & 1023]($9, $req, $strike_index) | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $19 = $size + 112 | 0;
    HEAP32[$19 >> 2] = -1;
    $error_0 = $16;
    label = 5;
    break;
   case 4:
    $21 = HEAP32[$strike_index >> 2] | 0;
    $22 = _tt_size_select($size, $21) | 0;
    $_0 = $22;
    label = 7;
    break;
   case 5:
    $24 = HEAP32[$2 >> 2] | 0;
    $25 = $24;
    _FT_Request_Metrics($25, $req);
    $26 = HEAP32[$2 >> 2] | 0;
    $27 = $26 + 8 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $28 & 1;
    $30 = ($29 | 0) == 0;
    if ($30) {
      $_0 = $error_0;
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $32 = _tt_size_reset($1) | 0;
    $_0 = $32;
    label = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _tt_size_select($size, $strike_index) {
  $size = $size | 0;
  $strike_index = $strike_index | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $size + 112 | 0;
    HEAP32[$3 >> 2] = $strike_index;
    $4 = HEAP32[$1 >> 2] | 0;
    $5 = $4 + 8 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 & 1;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = $size;
    $11 = $4;
    _FT_Select_Metrics($11, $strike_index);
    $12 = _tt_size_reset($10) | 0;
    $error_0 = 0;
    label = 5;
    break;
   case 3:
    $14 = $2;
    $15 = $2 + 532 | 0;
    $16 = $15;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $size + 12 | 0;
    $19 = $17 + 152 | 0;
    $20 = $19;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = FUNCTION_TABLE_iiii[$21 & 1023]($14, $strike_index, $18) | 0;
    $23 = ($22 | 0) == 0;
    if ($23) {
      $error_0 = 0;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    HEAP32[$3 >> 2] = -1;
    $error_0 = $22;
    label = 5;
    break;
   case 5:
    return $error_0 | 0;
  }
  return 0;
}
function _TT_New_Context($driver) {
  $driver = $driver | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $16 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $driver + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $driver + 40 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 2:
    $7 = _ft_mem_alloc($2, 608, $error) | 0;
    $8 = $7;
    $9 = HEAP32[$error >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 3;
      break;
    } else {
      $_0 = 0;
      label = 6;
      break;
    }
   case 3:
    $12 = _Init_Context($8, $2) | 0;
    HEAP32[$error >> 2] = $12;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 4;
      break;
    } else {
      $_0 = 0;
      label = 6;
      break;
    }
   case 4:
    HEAP32[$3 >> 2] = $8;
    label = 5;
    break;
   case 5:
    $16 = HEAP32[$3 >> 2] | 0;
    $_0 = $16;
    label = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _Init_Context($exec, $memory) {
  $exec = $exec | 0;
  $memory = $memory | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $exec + 8 | 0;
    HEAP32[$1 >> 2] = $memory;
    $2 = $exec + 432 | 0;
    HEAP32[$2 >> 2] = 32;
    $3 = _ft_mem_realloc($memory, 16, 0, 32, 0, $error) | 0;
    $4 = $3;
    $5 = $exec + 436 | 0;
    HEAP32[$5 >> 2] = $4;
    $6 = HEAP32[$error >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $9 = $exec + 440 | 0;
    HEAP16[$9 >> 1] = 0;
    $10 = $exec + 442 | 0;
    HEAP16[$10 >> 1] = 0;
    $11 = $exec + 20 | 0;
    HEAP32[$11 >> 2] = 0;
    $12 = $exec + 388 | 0;
    HEAP32[$12 >> 2] = 0;
    $13 = $exec + 24 | 0;
    HEAP32[$13 >> 2] = 0;
    $14 = $exec + 392 | 0;
    HEAP32[$14 >> 2] = 0;
    $15 = $exec | 0;
    HEAP32[$15 >> 2] = 0;
    $16 = $exec + 4 | 0;
    HEAP32[$16 >> 2] = 0;
    $_0 = 0;
    label = 4;
    break;
   case 3:
    _TT_Done_Context($exec);
    $18 = HEAP32[$error >> 2] | 0;
    $_0 = $18;
    label = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _TT_RunIns($exc) {
  $exc = $exc | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ins_counter_0 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $_off = 0, $109 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $139 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $151 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $159 = 0, $_tr = 0, $160 = 0, $161 = 0, $162 = 0, $165 = 0, $166 = 0, $_sum452 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $180 = 0, $_sum451 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $_sum448 = 0, $193 = 0, $194 = 0, $sext449 = 0, $195 = 0, $196 = 0, $sext450 = 0, $197 = 0, $198 = 0, $_sum446 = 0, $200 = 0, $201 = 0, $sext = 0, $202 = 0, $203 = 0, $sext447 = 0, $204 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $_sum445 = 0, $210 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $_sum444 = 0, $216 = 0, $218 = 0, $221 = 0, $222 = 0, $224 = 0, $225 = 0, $227 = 0, $228 = 0, $234 = 0, $235 = 0, $241 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $251 = 0, $253 = 0, $255 = 0, $256 = 0, $258 = 0, $_sum443 = 0, $259 = 0, $262 = 0, $_sum442 = 0, $263 = 0, $264 = 0, $266 = 0, $268 = 0, $269 = 0, $270 = 0, $or_cond = 0, $273 = 0, $274 = 0, $275 = 0, $298 = 0, $299 = 0, $300 = 0, $301 = 0, $303 = 0, $304 = 0, $_sum441 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $317 = 0, $318 = 0, $321 = 0, $322 = 0, $323 = 0, $325 = 0, $326 = 0, $327 = 0, $329 = 0, $330 = 0, $332 = 0, $_sum440 = 0, $333 = 0, $334 = 0, $336 = 0, $337 = 0, $338 = 0, $340 = 0, $341 = 0, $344 = 0, $345 = 0, $350 = 0, $352 = 0, $357 = 0, $_sum439 = 0, $358 = 0, $359 = 0, $360 = 0, $361 = 0, $363 = 0, $_sum438 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $369 = 0, $_sum437 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $375 = 0, $_sum436 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $381 = 0, $_sum435 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $387 = 0, $_sum434 = 0, $388 = 0, $389 = 0, $390 = 0, $391 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $408 = 0, $409 = 0, $_sum433 = 0, $411 = 0, $412 = 0, $413 = 0, $415 = 0, $416 = 0, $418 = 0, $419 = 0, $_sum432 = 0, $421 = 0, $422 = 0, $423 = 0, $425 = 0, $426 = 0, $428 = 0, $429 = 0, $430 = 0, $433 = 0, $434 = 0, $436 = 0, $437 = 0, $_sum431 = 0, $439 = 0, $440 = 0, $441 = 0, $442 = 0, $_sum430 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $_sum429 = 0, $449 = 0, $450 = 0, $451 = 0, $454 = 0, $455 = 0, $457 = 0, $_sum428 = 0, $458 = 0, $459 = 0, $460 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $467 = 0, $468 = 0, $470 = 0, $471 = 0, $473 = 0, $474 = 0, $475 = 0, $477 = 0, $478 = 0, $479 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $490 = 0, $491 = 0, $492 = 0, $494 = 0, $495 = 0, $496 = 0, $498 = 0, $499 = 0, $_sum427 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $510 = 0, $512 = 0, $_sum426 = 0, $514 = 0, $515 = 0, $516 = 0, $518 = 0, $519 = 0, $520 = 0, $521 = 0, $_sum425 = 0, $525 = 0, $526 = 0, $527 = 0, $529 = 0, $530 = 0, $531 = 0, $532 = 0, $_sum424 = 0, $549 = 0, $550 = 0, $551 = 0, $552 = 0, $_sum = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $564 = 0, $567 = 0, $570 = 0, $573 = 0, $_pr = 0, $578 = 0, $579 = 0, $580 = 0, $581 = 0, $def_0454 = 0, $582 = 0, $583 = 0, $584 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $590 = 0, $592 = 0, $593 = 0, $594 = 0, $597 = 0, $598 = 0, $599 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $610 = 0, $611 = 0, $613 = 0, $614 = 0, $616 = 0, $617 = 0, $618 = 0, $620 = 0, $621 = 0, $622 = 0, $624 = 0, $625 = 0, $ins_counter_1 = 0, $627 = 0, $628 = 0, $629 = 0, $631 = 0, $632 = 0, $633 = 0, $636 = 0, $637 = 0, $639 = 0, $640 = 0, $641 = 0, $642 = 0, $644 = 0, $645 = 0, $646 = 0, $648 = 0, $649 = 0, $650 = 0, $652 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 256 | 0;
    HEAP32[$1 >> 2] = 0;
    $2 = $exc + 216 | 0;
    $3 = HEAP16[$2 >> 1] | 0;
    $4 = $exc + 218 | 0;
    $5 = HEAP16[$4 >> 1] | 0;
    $6 = $3 << 16 >> 16 == $5 << 16 >> 16;
    $7 = $exc + 592 | 0;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    HEAP32[$7 >> 2] = 870;
    $9 = $exc + 596 | 0;
    HEAP32[$9 >> 2] = 208;
    $10 = $exc + 600 | 0;
    HEAP32[$10 >> 2] = 270;
    label = 4;
    break;
   case 3:
    HEAP32[$7 >> 2] = 688;
    $12 = $exc + 596 | 0;
    HEAP32[$12 >> 2] = 90;
    $13 = $exc + 600 | 0;
    HEAP32[$13 >> 2] = 254;
    label = 4;
    break;
   case 4:
    _Compute_Funcs($exc);
    $15 = $exc + 312 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $16 & 255;
    _Compute_Round($exc, $17);
    $18 = $exc + 360 | 0;
    $19 = $exc + 356 | 0;
    $20 = $exc + 368 | 0;
    $21 = $exc + 372 | 0;
    $22 = $exc + 364 | 0;
    $23 = $exc + 364 | 0;
    $24 = $exc + 16 | 0;
    $25 = $exc + 28 | 0;
    $26 = $exc + 32 | 0;
    $27 = $exc + 20 | 0;
    $28 = $exc + 376 | 0;
    $29 = $exc + 12 | 0;
    $30 = $exc + 24 | 0;
    $31 = $exc + 488 | 0;
    $32 = $exc + 416 | 0;
    $33 = $exc + 408 | 0;
    $34 = $exc + 428 | 0;
    $35 = $exc + 432 | 0;
    $36 = $exc + 436 | 0;
    $37 = $exc + 352 | 0;
    $38 = $exc + 294 | 0;
    $39 = $exc + 296 | 0;
    $40 = $exc + 290 | 0;
    $41 = $exc + 292 | 0;
    $42 = $exc + 298 | 0;
    $43 = $exc + 300 | 0;
    $44 = $exc + 294 | 0;
    $45 = $exc + 290 | 0;
    $46 = $44;
    $47 = $45;
    $48 = $exc + 298 | 0;
    $49 = $exc + 294 | 0;
    $50 = $exc + 290 | 0;
    $51 = $49;
    $52 = $50;
    $53 = $exc + 298 | 0;
    $54 = $exc + 294 | 0;
    $55 = $exc + 296 | 0;
    $56 = $exc + 298 | 0;
    $57 = $exc + 300 | 0;
    $58 = $exc + 298 | 0;
    $59 = $exc + 294 | 0;
    $60 = $59;
    $61 = $58;
    $62 = $exc + 284 | 0;
    $63 = $exc + 286 | 0;
    $64 = $exc + 288 | 0;
    $65 = $exc + 304 | 0;
    $66 = $exc + 568 | 0;
    $67 = $exc + 568 | 0;
    $68 = $exc + 308 | 0;
    $69 = $exc + 320 | 0;
    $70 = $exc + 324 | 0;
    $71 = $exc + 328 | 0;
    $72 = $exc + 568 | 0;
    $73 = $exc + 468 | 0;
    $74 = $exc + 472 | 0;
    $75 = $exc + 561 | 0;
    $76 = $exc + 468 | 0;
    $77 = $exc + 472 | 0;
    $78 = $exc + 561 | 0;
    $79 = $exc + 380 | 0;
    $80 = $exc + 596 | 0;
    $81 = $exc + 561 | 0;
    $82 = $exc + 380 | 0;
    $83 = $exc + 561 | 0;
    $84 = $exc + 316 | 0;
    $85 = $exc + 316 | 0;
    $86 = $exc + 568 | 0;
    $87 = $exc + 568 | 0;
    $88 = $exc + 332 | 0;
    $89 = $exc + 334 | 0;
    $90 = $exc + 568 | 0;
    $91 = $exc + 380 | 0;
    $92 = $exc + 260 | 0;
    $93 = $exc + 384 | 0;
    $94 = $exc + 561 | 0;
    $95 = $exc + 568 | 0;
    $96 = $exc + 568 | 0;
    $97 = $exc + 568 | 0;
    $98 = $exc + 568 | 0;
    $99 = $exc + 568 | 0;
    $ins_counter_0 = 0;
    label = 5;
    break;
   case 5:
    $101 = HEAP32[$18 >> 2] | 0;
    $102 = HEAP32[$19 >> 2] | 0;
    $103 = $102 + $101 | 0;
    $104 = HEAP8[$103] | 0;
    HEAP8[$20] = $104;
    $105 = $104 & 255;
    $106 = $105 + 5251024 | 0;
    $107 = HEAP8[$106] | 0;
    $108 = $107 << 24 >> 24;
    HEAP32[$21 >> 2] = $108;
    $_off = $105 - 64 | 0;
    $109 = $_off >>> 0 < 2;
    if ($109) {
      label = 6;
      break;
    } else {
      label = 8;
      break;
    }
   case 6:
    $111 = HEAP32[$18 >> 2] | 0;
    $112 = $111 + 1 | 0;
    $113 = HEAP32[$22 >> 2] | 0;
    $114 = ($112 | 0) > ($113 | 0);
    if ($114) {
      label = 191;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $116 = HEAP32[$19 >> 2] | 0;
    $117 = $116 + $112 | 0;
    $118 = HEAP8[$117] | 0;
    $119 = $118 & 255;
    $120 = Math_imul($119, $108);
    $121 = 2 - $120 | 0;
    HEAP32[$21 >> 2] = $121;
    label = 8;
    break;
   case 8:
    $123 = HEAP32[$18 >> 2] | 0;
    $124 = HEAP32[$21 >> 2] | 0;
    $125 = $124 + $123 | 0;
    $126 = HEAP32[$23 >> 2] | 0;
    $127 = ($125 | 0) > ($126 | 0);
    if ($127) {
      label = 191;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $129 = HEAP32[$24 >> 2] | 0;
    $130 = HEAP8[$20] | 0;
    $131 = $130 & 255;
    $132 = $131 + 5326844 | 0;
    $133 = HEAP8[$132] | 0;
    $134 = $133 & 255;
    $135 = $134 >>> 4;
    $136 = $129 - $135 | 0;
    HEAP32[$25 >> 2] = $136;
    $137 = ($136 | 0) < 0;
    if ($137) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $139 = $exc + 12 | 0;
    HEAP32[$139 >> 2] = 129;
    label = 192;
    break;
   case 11:
    $141 = HEAP8[$20] | 0;
    $142 = $141 & 255;
    $143 = $142 + 5326844 | 0;
    $144 = HEAP8[$143] | 0;
    $145 = $144 & 255;
    $146 = $145 & 15;
    $147 = $146 + $136 | 0;
    HEAP32[$26 >> 2] = $147;
    $148 = HEAP32[$27 >> 2] | 0;
    $149 = $147 >>> 0 > $148 >>> 0;
    if ($149) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $151 = $exc + 12 | 0;
    HEAP32[$151 >> 2] = 130;
    label = 192;
    break;
   case 13:
    HEAP8[$28] = 1;
    HEAP32[$29 >> 2] = 0;
    $153 = HEAP32[$30 >> 2] | 0;
    $154 = HEAP32[$25 >> 2] | 0;
    $155 = $153 + ($154 << 2) | 0;
    $156 = HEAP8[$20] | 0;
    $157 = $156 & 255;
    if (($157 | 0) == 0 | ($157 | 0) == 1 | ($157 | 0) == 2 | ($157 | 0) == 3 | ($157 | 0) == 4 | ($157 | 0) == 5) {
      label = 14;
      break;
    } else if (($157 | 0) == 6 | ($157 | 0) == 7) {
      label = 19;
      break;
    } else if (($157 | 0) == 8 | ($157 | 0) == 9) {
      label = 21;
      break;
    } else if (($157 | 0) == 10) {
      label = 23;
      break;
    } else if (($157 | 0) == 11) {
      label = 24;
      break;
    } else if (($157 | 0) == 12) {
      label = 25;
      break;
    } else if (($157 | 0) == 13) {
      label = 26;
      break;
    } else if (($157 | 0) == 14) {
      label = 27;
      break;
    } else if (($157 | 0) == 15) {
      label = 28;
      break;
    } else if (($157 | 0) == 16) {
      label = 29;
      break;
    } else if (($157 | 0) == 17) {
      label = 30;
      break;
    } else if (($157 | 0) == 18) {
      label = 31;
      break;
    } else if (($157 | 0) == 19) {
      label = 32;
      break;
    } else if (($157 | 0) == 20) {
      label = 33;
      break;
    } else if (($157 | 0) == 21) {
      label = 34;
      break;
    } else if (($157 | 0) == 22) {
      label = 35;
      break;
    } else if (($157 | 0) == 23) {
      label = 36;
      break;
    } else if (($157 | 0) == 24) {
      label = 39;
      break;
    } else if (($157 | 0) == 25) {
      label = 40;
      break;
    } else if (($157 | 0) == 26) {
      label = 41;
      break;
    } else if (($157 | 0) == 27) {
      label = 42;
      break;
    } else if (($157 | 0) == 28) {
      label = 43;
      break;
    } else if (($157 | 0) == 29) {
      label = 46;
      break;
    } else if (($157 | 0) == 30) {
      label = 47;
      break;
    } else if (($157 | 0) == 31) {
      label = 48;
      break;
    } else if (($157 | 0) == 32) {
      label = 49;
      break;
    } else if (($157 | 0) == 34) {
      label = 50;
      break;
    } else if (($157 | 0) == 35) {
      label = 51;
      break;
    } else if (($157 | 0) == 36) {
      label = 52;
      break;
    } else if (($157 | 0) == 37) {
      label = 53;
      break;
    } else if (($157 | 0) == 38) {
      label = 56;
      break;
    } else if (($157 | 0) == 39) {
      label = 57;
      break;
    } else if (($157 | 0) == 40) {
      label = 58;
      break;
    } else if (($157 | 0) == 41) {
      label = 59;
      break;
    } else if (($157 | 0) == 42) {
      label = 60;
      break;
    } else if (($157 | 0) == 43) {
      label = 61;
      break;
    } else if (($157 | 0) == 44) {
      label = 62;
      break;
    } else if (($157 | 0) == 45) {
      label = 63;
      break;
    } else if (($157 | 0) == 46 | ($157 | 0) == 47) {
      label = 64;
      break;
    } else if (($157 | 0) == 48 | ($157 | 0) == 49) {
      label = 65;
      break;
    } else if (($157 | 0) == 50 | ($157 | 0) == 51) {
      label = 66;
      break;
    } else if (($157 | 0) == 52 | ($157 | 0) == 53) {
      label = 67;
      break;
    } else if (($157 | 0) == 54 | ($157 | 0) == 55) {
      label = 68;
      break;
    } else if (($157 | 0) == 56) {
      label = 69;
      break;
    } else if (($157 | 0) == 57) {
      label = 70;
      break;
    } else if (($157 | 0) == 58 | ($157 | 0) == 59) {
      label = 71;
      break;
    } else if (($157 | 0) == 60) {
      label = 72;
      break;
    } else if (($157 | 0) == 61) {
      label = 73;
      break;
    } else if (($157 | 0) == 62 | ($157 | 0) == 63) {
      label = 74;
      break;
    } else if (($157 | 0) == 64) {
      label = 75;
      break;
    } else if (($157 | 0) == 65) {
      label = 76;
      break;
    } else if (($157 | 0) == 66) {
      label = 77;
      break;
    } else if (($157 | 0) == 67) {
      label = 81;
      break;
    } else if (($157 | 0) == 68) {
      label = 85;
      break;
    } else if (($157 | 0) == 69) {
      label = 88;
      break;
    } else if (($157 | 0) == 70 | ($157 | 0) == 71) {
      label = 92;
      break;
    } else if (($157 | 0) == 72) {
      label = 93;
      break;
    } else if (($157 | 0) == 73 | ($157 | 0) == 74) {
      label = 94;
      break;
    } else if (($157 | 0) == 75) {
      label = 95;
      break;
    } else if (($157 | 0) == 76) {
      label = 96;
      break;
    } else if (($157 | 0) == 77) {
      label = 97;
      break;
    } else if (($157 | 0) == 78) {
      label = 98;
      break;
    } else if (($157 | 0) == 79) {
      label = 99;
      break;
    } else if (($157 | 0) == 80) {
      label = 100;
      break;
    } else if (($157 | 0) == 81) {
      label = 101;
      break;
    } else if (($157 | 0) == 82) {
      label = 102;
      break;
    } else if (($157 | 0) == 83) {
      label = 103;
      break;
    } else if (($157 | 0) == 84) {
      label = 104;
      break;
    } else if (($157 | 0) == 85) {
      label = 105;
      break;
    } else if (($157 | 0) == 86) {
      label = 106;
      break;
    } else if (($157 | 0) == 87) {
      label = 107;
      break;
    } else if (($157 | 0) == 88) {
      label = 108;
      break;
    } else if (($157 | 0) == 90) {
      label = 109;
      break;
    } else if (($157 | 0) == 91) {
      label = 112;
      break;
    } else if (($157 | 0) == 92) {
      label = 115;
      break;
    } else if (($157 | 0) == 93) {
      label = 116;
      break;
    } else if (($157 | 0) == 94) {
      label = 117;
      break;
    } else if (($157 | 0) == 95) {
      label = 118;
      break;
    } else if (($157 | 0) == 96) {
      label = 119;
      break;
    } else if (($157 | 0) == 97) {
      label = 120;
      break;
    } else if (($157 | 0) == 98) {
      label = 121;
      break;
    } else if (($157 | 0) == 99) {
      label = 124;
      break;
    } else if (($157 | 0) == 100) {
      label = 125;
      break;
    } else if (($157 | 0) == 101) {
      label = 126;
      break;
    } else if (($157 | 0) == 102) {
      label = 127;
      break;
    } else if (($157 | 0) == 103) {
      label = 128;
      break;
    } else if (($157 | 0) == 104 | ($157 | 0) == 105 | ($157 | 0) == 106 | ($157 | 0) == 107) {
      label = 129;
      break;
    } else if (($157 | 0) == 108 | ($157 | 0) == 109 | ($157 | 0) == 110 | ($157 | 0) == 111) {
      label = 130;
      break;
    } else if (($157 | 0) == 112) {
      label = 131;
      break;
    } else if (($157 | 0) == 113 | ($157 | 0) == 114) {
      label = 134;
      break;
    } else if (($157 | 0) == 115 | ($157 | 0) == 116 | ($157 | 0) == 117) {
      label = 135;
      break;
    } else if (($157 | 0) == 118) {
      label = 136;
      break;
    } else if (($157 | 0) == 119) {
      label = 137;
      break;
    } else if (($157 | 0) == 120) {
      label = 138;
      break;
    } else if (($157 | 0) == 121) {
      label = 142;
      break;
    } else if (($157 | 0) == 122) {
      label = 146;
      break;
    } else if (($157 | 0) == 123) {
      label = 147;
      break;
    } else if (($157 | 0) == 124) {
      label = 148;
      break;
    } else if (($157 | 0) == 125) {
      label = 149;
      break;
    } else if (($157 | 0) == 128) {
      label = 150;
      break;
    } else if (($157 | 0) == 129) {
      label = 151;
      break;
    } else if (($157 | 0) == 130) {
      label = 152;
      break;
    } else if (($157 | 0) == 131 | ($157 | 0) == 132) {
      label = 153;
      break;
    } else if (($157 | 0) == 133) {
      label = 154;
      break;
    } else if (($157 | 0) == 134 | ($157 | 0) == 135) {
      label = 155;
      break;
    } else if (($157 | 0) == 136) {
      label = 156;
      break;
    } else if (($157 | 0) == 137) {
      label = 157;
      break;
    } else if (($157 | 0) == 138) {
      label = 158;
      break;
    } else if (($157 | 0) == 139) {
      label = 159;
      break;
    } else if (($157 | 0) == 140) {
      label = 161;
      break;
    } else if (($157 | 0) == 141) {
      label = 163;
      break;
    } else if (($157 | 0) == 142) {
      label = 164;
      break;
    } else if (($157 | 0) == 143) {
      label = 165;
      break;
    } else if (($157 | 0) == 33 | ($157 | 0) == 89 | ($157 | 0) == 126 | ($157 | 0) == 127) {
      label = 175;
      break;
    } else {
      label = 166;
      break;
    }
   case 14:
    $159 = $157 << 14;
    $_tr = $159 & 65535;
    $160 = $_tr & 16384;
    $161 = $160 ^ 16384;
    $162 = ($156 & 255) < 4;
    if ($162) {
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 15:
    HEAP16[$38 >> 1] = $160;
    HEAP16[$39 >> 1] = $161;
    HEAP16[$40 >> 1] = $160;
    HEAP16[$41 >> 1] = $161;
    label = 16;
    break;
   case 16:
    $165 = $157 & 2;
    $166 = ($165 | 0) == 0;
    if ($166) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    HEAP16[$42 >> 1] = $160;
    HEAP16[$43 >> 1] = $161;
    label = 18;
    break;
   case 18:
    _Compute_Funcs($exc);
    label = 175;
    break;
   case 19:
    $_sum452 = $154 + 1 | 0;
    $170 = $153 + ($_sum452 << 2) | 0;
    $171 = HEAP32[$170 >> 2] | 0;
    $172 = $171 & 65535;
    $173 = HEAP32[$155 >> 2] | 0;
    $174 = $173 & 65535;
    $175 = HEAP8[$20] | 0;
    $176 = $175 & 255;
    $177 = _Ins_SxVTL($exc, $172, $174, $176, $44) | 0;
    $178 = $177 << 24 >> 24 == 0;
    if ($178) {
      label = 20;
      break;
    } else {
      label = 175;
      break;
    }
   case 20:
    $180 = HEAPU16[$46 >> 1] | HEAPU16[$46 + 2 >> 1] << 16;
    tempBigInt = $180;
    HEAP16[$47 >> 1] = tempBigInt & 65535;
    HEAP16[$47 + 2 >> 1] = tempBigInt >> 16;
    _Compute_Funcs($exc);
    label = 175;
    break;
   case 21:
    $_sum451 = $154 + 1 | 0;
    $182 = $153 + ($_sum451 << 2) | 0;
    $183 = HEAP32[$182 >> 2] | 0;
    $184 = $183 & 65535;
    $185 = HEAP32[$155 >> 2] | 0;
    $186 = $185 & 65535;
    $187 = HEAP8[$20] | 0;
    $188 = $187 & 255;
    $189 = _Ins_SxVTL($exc, $184, $186, $188, $48) | 0;
    $190 = $189 << 24 >> 24 == 0;
    if ($190) {
      label = 22;
      break;
    } else {
      label = 175;
      break;
    }
   case 22:
    _Compute_Funcs($exc);
    label = 175;
    break;
   case 23:
    $_sum448 = $154 + 1 | 0;
    $193 = $153 + ($_sum448 << 2) | 0;
    $194 = HEAP32[$193 >> 2] | 0;
    $sext449 = $194 << 16;
    $195 = $sext449 >> 16;
    $196 = HEAP32[$155 >> 2] | 0;
    $sext450 = $196 << 16;
    $197 = $sext450 >> 16;
    _Normalize($197, $195, $49);
    $198 = HEAPU16[$51 >> 1] | HEAPU16[$51 + 2 >> 1] << 16;
    tempBigInt = $198;
    HEAP16[$52 >> 1] = tempBigInt & 65535;
    HEAP16[$52 + 2 >> 1] = tempBigInt >> 16;
    _Compute_Funcs($exc);
    label = 175;
    break;
   case 24:
    $_sum446 = $154 + 1 | 0;
    $200 = $153 + ($_sum446 << 2) | 0;
    $201 = HEAP32[$200 >> 2] | 0;
    $sext = $201 << 16;
    $202 = $sext >> 16;
    $203 = HEAP32[$155 >> 2] | 0;
    $sext447 = $203 << 16;
    $204 = $sext447 >> 16;
    _Normalize($204, $202, $53);
    _Compute_Funcs($exc);
    label = 175;
    break;
   case 25:
    $206 = HEAP16[$54 >> 1] | 0;
    $207 = $206 << 16 >> 16;
    HEAP32[$155 >> 2] = $207;
    $208 = HEAP16[$55 >> 1] | 0;
    $209 = $208 << 16 >> 16;
    $_sum445 = $154 + 1 | 0;
    $210 = $153 + ($_sum445 << 2) | 0;
    HEAP32[$210 >> 2] = $209;
    label = 175;
    break;
   case 26:
    $212 = HEAP16[$56 >> 1] | 0;
    $213 = $212 << 16 >> 16;
    HEAP32[$155 >> 2] = $213;
    $214 = HEAP16[$57 >> 1] | 0;
    $215 = $214 << 16 >> 16;
    $_sum444 = $154 + 1 | 0;
    $216 = $153 + ($_sum444 << 2) | 0;
    HEAP32[$216 >> 2] = $215;
    label = 175;
    break;
   case 27:
    $218 = HEAPU16[$60 >> 1] | HEAPU16[$60 + 2 >> 1] << 16;
    tempBigInt = $218;
    HEAP16[$61 >> 1] = tempBigInt & 65535;
    HEAP16[$61 + 2 >> 1] = tempBigInt >> 16;
    _Compute_Funcs($exc);
    label = 175;
    break;
   case 28:
    _Ins_ISECT($exc, $155);
    label = 175;
    break;
   case 29:
    $221 = HEAP32[$155 >> 2] | 0;
    $222 = $221 & 65535;
    HEAP16[$62 >> 1] = $222;
    label = 175;
    break;
   case 30:
    $224 = HEAP32[$155 >> 2] | 0;
    $225 = $224 & 65535;
    HEAP16[$63 >> 1] = $225;
    label = 175;
    break;
   case 31:
    $227 = HEAP32[$155 >> 2] | 0;
    $228 = $227 & 65535;
    HEAP16[$64 >> 1] = $228;
    label = 175;
    break;
   case 32:
    _Ins_SZP0($exc, $155);
    label = 175;
    break;
   case 33:
    _Ins_SZP1($exc, $155);
    label = 175;
    break;
   case 34:
    _Ins_SZP2($exc, $155);
    label = 175;
    break;
   case 35:
    _Ins_SZPS($exc, $155);
    label = 175;
    break;
   case 36:
    $234 = HEAP32[$155 >> 2] | 0;
    $235 = ($234 | 0) < 0;
    if ($235) {
      label = 37;
      break;
    } else {
      label = 38;
      break;
    }
   case 37:
    HEAP32[$29 >> 2] = 132;
    label = 192;
    break;
   case 38:
    HEAP32[$65 >> 2] = $234;
    label = 175;
    break;
   case 39:
    HEAP32[$15 >> 2] = 1;
    HEAP32[$66 >> 2] = 164;
    label = 175;
    break;
   case 40:
    HEAP32[$15 >> 2] = 0;
    HEAP32[$67 >> 2] = 338;
    label = 175;
    break;
   case 41:
    $241 = HEAP32[$155 >> 2] | 0;
    HEAP32[$68 >> 2] = $241;
    label = 175;
    break;
   case 42:
    _Ins_ELSE($exc);
    label = 175;
    break;
   case 43:
    $244 = HEAP32[$155 >> 2] | 0;
    $245 = HEAP32[$18 >> 2] | 0;
    $246 = $245 + $244 | 0;
    HEAP32[$18 >> 2] = $246;
    $247 = ($246 | 0) < 0;
    if ($247) {
      label = 44;
      break;
    } else {
      label = 45;
      break;
    }
   case 44:
    HEAP32[$29 >> 2] = 132;
    label = 45;
    break;
   case 45:
    HEAP8[$28] = 0;
    label = 175;
    break;
   case 46:
    $251 = HEAP32[$155 >> 2] | 0;
    HEAP32[$69 >> 2] = $251;
    label = 175;
    break;
   case 47:
    $253 = HEAP32[$155 >> 2] | 0;
    HEAP32[$70 >> 2] = $253;
    label = 175;
    break;
   case 48:
    $255 = HEAP32[$155 >> 2] | 0;
    $256 = $255 >> 10;
    HEAP32[$71 >> 2] = $256;
    label = 175;
    break;
   case 49:
    $258 = HEAP32[$155 >> 2] | 0;
    $_sum443 = $154 + 1 | 0;
    $259 = $153 + ($_sum443 << 2) | 0;
    HEAP32[$259 >> 2] = $258;
    label = 175;
    break;
   case 50:
    HEAP32[$26 >> 2] = 0;
    label = 175;
    break;
   case 51:
    $262 = HEAP32[$155 >> 2] | 0;
    $_sum442 = $154 + 1 | 0;
    $263 = $153 + ($_sum442 << 2) | 0;
    $264 = HEAP32[$263 >> 2] | 0;
    HEAP32[$155 >> 2] = $264;
    HEAP32[$263 >> 2] = $262;
    label = 175;
    break;
   case 52:
    $266 = HEAP32[$24 >> 2] | 0;
    HEAP32[$155 >> 2] = $266;
    label = 175;
    break;
   case 53:
    $268 = HEAP32[$155 >> 2] | 0;
    $269 = ($268 | 0) < 1;
    $270 = ($268 | 0) > ($154 | 0);
    $or_cond = $269 | $270;
    if ($or_cond) {
      label = 54;
      break;
    } else {
      label = 55;
      break;
    }
   case 54:
    HEAP32[$29 >> 2] = 134;
    label = 192;
    break;
   case 55:
    $273 = $154 - $268 | 0;
    $274 = $153 + ($273 << 2) | 0;
    $275 = HEAP32[$274 >> 2] | 0;
    HEAP32[$155 >> 2] = $275;
    label = 175;
    break;
   case 56:
    _Ins_MINDEX($exc, $155);
    label = 175;
    break;
   case 57:
    _Ins_ALIGNPTS($exc, $155);
    label = 175;
    break;
   case 58:
    _Ins_UNKNOWN($exc);
    label = 175;
    break;
   case 59:
    _Ins_UTP($exc, $155);
    label = 175;
    break;
   case 60:
    _Ins_LOOPCALL($exc, $155);
    label = 175;
    break;
   case 61:
    _Ins_CALL($exc, $155);
    label = 175;
    break;
   case 62:
    _Ins_FDEF($exc, $155);
    label = 175;
    break;
   case 63:
    _Ins_ENDF($exc);
    label = 175;
    break;
   case 64:
    _Ins_MDAP($exc, $155);
    label = 175;
    break;
   case 65:
    _Ins_IUP($exc);
    label = 175;
    break;
   case 66:
    _Ins_SHP($exc);
    label = 175;
    break;
   case 67:
    _Ins_SHC($exc, $155);
    label = 175;
    break;
   case 68:
    _Ins_SHZ($exc, $155);
    label = 175;
    break;
   case 69:
    _Ins_SHPIX($exc, $155);
    label = 175;
    break;
   case 70:
    _Ins_IP($exc);
    label = 175;
    break;
   case 71:
    _Ins_MSIRP($exc, $155);
    label = 175;
    break;
   case 72:
    _Ins_ALIGNRP($exc);
    label = 175;
    break;
   case 73:
    HEAP32[$15 >> 2] = 2;
    HEAP32[$72 >> 2] = 264;
    label = 175;
    break;
   case 74:
    _Ins_MIAP($exc, $155);
    label = 175;
    break;
   case 75:
    _Ins_NPUSHB($exc, $155);
    label = 175;
    break;
   case 76:
    _Ins_NPUSHW($exc, $155);
    label = 175;
    break;
   case 77:
    $298 = HEAP32[$155 >> 2] | 0;
    $299 = HEAP16[$73 >> 1] | 0;
    $300 = $299 & 65535;
    $301 = $298 >>> 0 < $300 >>> 0;
    if ($301) {
      label = 79;
      break;
    } else {
      label = 78;
      break;
    }
   case 78:
    $303 = HEAP8[$75] | 0;
    $304 = $303 << 24 >> 24 == 0;
    if ($304) {
      label = 175;
      break;
    } else {
      label = 80;
      break;
    }
   case 79:
    $_sum441 = $154 + 1 | 0;
    $306 = $153 + ($_sum441 << 2) | 0;
    $307 = HEAP32[$306 >> 2] | 0;
    $308 = HEAP32[$74 >> 2] | 0;
    $309 = $308 + ($298 << 2) | 0;
    HEAP32[$309 >> 2] = $307;
    label = 175;
    break;
   case 80:
    HEAP32[$29 >> 2] = 134;
    label = 192;
    break;
   case 81:
    $312 = HEAP32[$155 >> 2] | 0;
    $313 = HEAP16[$76 >> 1] | 0;
    $314 = $313 & 65535;
    $315 = $312 >>> 0 < $314 >>> 0;
    if ($315) {
      label = 84;
      break;
    } else {
      label = 82;
      break;
    }
   case 82:
    $317 = HEAP8[$78] | 0;
    $318 = $317 << 24 >> 24 == 0;
    if ($318) {
      label = 83;
      break;
    } else {
      label = 80;
      break;
    }
   case 83:
    HEAP32[$155 >> 2] = 0;
    label = 175;
    break;
   case 84:
    $321 = HEAP32[$77 >> 2] | 0;
    $322 = $321 + ($312 << 2) | 0;
    $323 = HEAP32[$322 >> 2] | 0;
    HEAP32[$155 >> 2] = $323;
    label = 175;
    break;
   case 85:
    $325 = HEAP32[$155 >> 2] | 0;
    $326 = HEAP32[$79 >> 2] | 0;
    $327 = $325 >>> 0 < $326 >>> 0;
    if ($327) {
      label = 87;
      break;
    } else {
      label = 86;
      break;
    }
   case 86:
    $329 = HEAP8[$81] | 0;
    $330 = $329 << 24 >> 24 == 0;
    if ($330) {
      label = 175;
      break;
    } else {
      label = 80;
      break;
    }
   case 87:
    $332 = HEAP32[$80 >> 2] | 0;
    $_sum440 = $154 + 1 | 0;
    $333 = $153 + ($_sum440 << 2) | 0;
    $334 = HEAP32[$333 >> 2] | 0;
    FUNCTION_TABLE_viii[$332 & 1023]($exc, $325, $334);
    label = 175;
    break;
   case 88:
    $336 = HEAP32[$155 >> 2] | 0;
    $337 = HEAP32[$82 >> 2] | 0;
    $338 = $336 >>> 0 < $337 >>> 0;
    if ($338) {
      label = 91;
      break;
    } else {
      label = 89;
      break;
    }
   case 89:
    $340 = HEAP8[$83] | 0;
    $341 = $340 << 24 >> 24 == 0;
    if ($341) {
      label = 90;
      break;
    } else {
      label = 80;
      break;
    }
   case 90:
    HEAP32[$155 >> 2] = 0;
    label = 175;
    break;
   case 91:
    $344 = HEAP32[$7 >> 2] | 0;
    $345 = FUNCTION_TABLE_iii[$344 & 1023]($exc, $336) | 0;
    HEAP32[$155 >> 2] = $345;
    label = 175;
    break;
   case 92:
    _Ins_GC($exc, $155);
    label = 175;
    break;
   case 93:
    _Ins_SCFS($exc, $155);
    label = 175;
    break;
   case 94:
    _Ins_MD($exc, $155);
    label = 175;
    break;
   case 95:
    $350 = _Current_Ppem($exc) | 0;
    HEAP32[$155 >> 2] = $350;
    label = 175;
    break;
   case 96:
    $352 = _Current_Ppem($exc) | 0;
    HEAP32[$155 >> 2] = $352;
    label = 175;
    break;
   case 97:
    HEAP8[$84] = 1;
    label = 175;
    break;
   case 98:
    HEAP8[$85] = 0;
    label = 175;
    break;
   case 99:
    HEAP32[$29 >> 2] = 135;
    label = 192;
    break;
   case 100:
    $357 = HEAP32[$155 >> 2] | 0;
    $_sum439 = $154 + 1 | 0;
    $358 = $153 + ($_sum439 << 2) | 0;
    $359 = HEAP32[$358 >> 2] | 0;
    $360 = ($357 | 0) < ($359 | 0);
    $361 = $360 & 1;
    HEAP32[$155 >> 2] = $361;
    label = 175;
    break;
   case 101:
    $363 = HEAP32[$155 >> 2] | 0;
    $_sum438 = $154 + 1 | 0;
    $364 = $153 + ($_sum438 << 2) | 0;
    $365 = HEAP32[$364 >> 2] | 0;
    $366 = ($363 | 0) <= ($365 | 0);
    $367 = $366 & 1;
    HEAP32[$155 >> 2] = $367;
    label = 175;
    break;
   case 102:
    $369 = HEAP32[$155 >> 2] | 0;
    $_sum437 = $154 + 1 | 0;
    $370 = $153 + ($_sum437 << 2) | 0;
    $371 = HEAP32[$370 >> 2] | 0;
    $372 = ($369 | 0) > ($371 | 0);
    $373 = $372 & 1;
    HEAP32[$155 >> 2] = $373;
    label = 175;
    break;
   case 103:
    $375 = HEAP32[$155 >> 2] | 0;
    $_sum436 = $154 + 1 | 0;
    $376 = $153 + ($_sum436 << 2) | 0;
    $377 = HEAP32[$376 >> 2] | 0;
    $378 = ($375 | 0) >= ($377 | 0);
    $379 = $378 & 1;
    HEAP32[$155 >> 2] = $379;
    label = 175;
    break;
   case 104:
    $381 = HEAP32[$155 >> 2] | 0;
    $_sum435 = $154 + 1 | 0;
    $382 = $153 + ($_sum435 << 2) | 0;
    $383 = HEAP32[$382 >> 2] | 0;
    $384 = ($381 | 0) == ($383 | 0);
    $385 = $384 & 1;
    HEAP32[$155 >> 2] = $385;
    label = 175;
    break;
   case 105:
    $387 = HEAP32[$155 >> 2] | 0;
    $_sum434 = $154 + 1 | 0;
    $388 = $153 + ($_sum434 << 2) | 0;
    $389 = HEAP32[$388 >> 2] | 0;
    $390 = ($387 | 0) != ($389 | 0);
    $391 = $390 & 1;
    HEAP32[$155 >> 2] = $391;
    label = 175;
    break;
   case 106:
    $393 = HEAP32[$86 >> 2] | 0;
    $394 = HEAP32[$155 >> 2] | 0;
    $395 = FUNCTION_TABLE_iiii[$393 & 1023]($exc, $394, 0) | 0;
    $396 = $395 & 127;
    $397 = ($396 | 0) == 64;
    $398 = $397 & 1;
    HEAP32[$155 >> 2] = $398;
    label = 175;
    break;
   case 107:
    $400 = HEAP32[$87 >> 2] | 0;
    $401 = HEAP32[$155 >> 2] | 0;
    $402 = FUNCTION_TABLE_iiii[$400 & 1023]($exc, $401, 0) | 0;
    $403 = $402 & 127;
    $404 = ($403 | 0) == 0;
    $405 = $404 & 1;
    HEAP32[$155 >> 2] = $405;
    label = 175;
    break;
   case 108:
    _Ins_IF($exc, $155);
    label = 175;
    break;
   case 109:
    $408 = HEAP32[$155 >> 2] | 0;
    $409 = ($408 | 0) == 0;
    if ($409) {
      $415 = 0;
      label = 111;
      break;
    } else {
      label = 110;
      break;
    }
   case 110:
    $_sum433 = $154 + 1 | 0;
    $411 = $153 + ($_sum433 << 2) | 0;
    $412 = HEAP32[$411 >> 2] | 0;
    $413 = ($412 | 0) != 0;
    $415 = $413;
    label = 111;
    break;
   case 111:
    $416 = $415 & 1;
    HEAP32[$155 >> 2] = $416;
    label = 175;
    break;
   case 112:
    $418 = HEAP32[$155 >> 2] | 0;
    $419 = ($418 | 0) == 0;
    if ($419) {
      label = 113;
      break;
    } else {
      $425 = 1;
      label = 114;
      break;
    }
   case 113:
    $_sum432 = $154 + 1 | 0;
    $421 = $153 + ($_sum432 << 2) | 0;
    $422 = HEAP32[$421 >> 2] | 0;
    $423 = ($422 | 0) != 0;
    $425 = $423;
    label = 114;
    break;
   case 114:
    $426 = $425 & 1;
    HEAP32[$155 >> 2] = $426;
    label = 175;
    break;
   case 115:
    $428 = HEAP32[$155 >> 2] | 0;
    $429 = ($428 | 0) == 0;
    $430 = $429 & 1;
    HEAP32[$155 >> 2] = $430;
    label = 175;
    break;
   case 116:
    _Ins_DELTAP($exc, $155);
    label = 175;
    break;
   case 117:
    $433 = HEAP32[$155 >> 2] | 0;
    $434 = $433 & 65535;
    HEAP16[$88 >> 1] = $434;
    label = 175;
    break;
   case 118:
    $436 = HEAP32[$155 >> 2] | 0;
    $437 = $436 & 65535;
    HEAP16[$89 >> 1] = $437;
    label = 175;
    break;
   case 119:
    $_sum431 = $154 + 1 | 0;
    $439 = $153 + ($_sum431 << 2) | 0;
    $440 = HEAP32[$439 >> 2] | 0;
    $441 = HEAP32[$155 >> 2] | 0;
    $442 = $441 + $440 | 0;
    HEAP32[$155 >> 2] = $442;
    label = 175;
    break;
   case 120:
    $_sum430 = $154 + 1 | 0;
    $444 = $153 + ($_sum430 << 2) | 0;
    $445 = HEAP32[$444 >> 2] | 0;
    $446 = HEAP32[$155 >> 2] | 0;
    $447 = $446 - $445 | 0;
    HEAP32[$155 >> 2] = $447;
    label = 175;
    break;
   case 121:
    $_sum429 = $154 + 1 | 0;
    $449 = $153 + ($_sum429 << 2) | 0;
    $450 = HEAP32[$449 >> 2] | 0;
    $451 = ($450 | 0) == 0;
    if ($451) {
      label = 122;
      break;
    } else {
      label = 123;
      break;
    }
   case 122:
    HEAP32[$29 >> 2] = 133;
    label = 192;
    break;
   case 123:
    $454 = HEAP32[$155 >> 2] | 0;
    $455 = _FT_MulDiv_No_Round($454, 64, $450) | 0;
    HEAP32[$155 >> 2] = $455;
    label = 175;
    break;
   case 124:
    $457 = HEAP32[$155 >> 2] | 0;
    $_sum428 = $154 + 1 | 0;
    $458 = $153 + ($_sum428 << 2) | 0;
    $459 = HEAP32[$458 >> 2] | 0;
    $460 = _FT_MulDiv($457, $459, 64) | 0;
    HEAP32[$155 >> 2] = $460;
    label = 175;
    break;
   case 125:
    $462 = HEAP32[$155 >> 2] | 0;
    $463 = ($462 | 0) < 0;
    $464 = -$462 | 0;
    $465 = $463 ? $464 : $462;
    HEAP32[$155 >> 2] = $465;
    label = 175;
    break;
   case 126:
    $467 = HEAP32[$155 >> 2] | 0;
    $468 = -$467 | 0;
    HEAP32[$155 >> 2] = $468;
    label = 175;
    break;
   case 127:
    $470 = HEAP32[$155 >> 2] | 0;
    $471 = $470 & -64;
    HEAP32[$155 >> 2] = $471;
    label = 175;
    break;
   case 128:
    $473 = HEAP32[$155 >> 2] | 0;
    $474 = $473 + 63 | 0;
    $475 = $474 & -64;
    HEAP32[$155 >> 2] = $475;
    label = 175;
    break;
   case 129:
    $477 = HEAP32[$90 >> 2] | 0;
    $478 = HEAP32[$155 >> 2] | 0;
    $479 = HEAP8[$20] | 0;
    $480 = $479 & 255;
    $481 = $480 - 104 | 0;
    $482 = $exc + 264 + ($481 << 2) | 0;
    $483 = HEAP32[$482 >> 2] | 0;
    $484 = FUNCTION_TABLE_iiii[$477 & 1023]($exc, $478, $483) | 0;
    HEAP32[$155 >> 2] = $484;
    label = 175;
    break;
   case 130:
    $486 = HEAP32[$155 >> 2] | 0;
    $487 = HEAP8[$20] | 0;
    $488 = $487 & 255;
    $489 = $488 - 108 | 0;
    $490 = $exc + 264 + ($489 << 2) | 0;
    $491 = HEAP32[$490 >> 2] | 0;
    $492 = _Round_None($exc, $486, $491) | 0;
    HEAP32[$155 >> 2] = $492;
    label = 175;
    break;
   case 131:
    $494 = HEAP32[$155 >> 2] | 0;
    $495 = HEAP32[$91 >> 2] | 0;
    $496 = $494 >>> 0 < $495 >>> 0;
    if ($496) {
      label = 133;
      break;
    } else {
      label = 132;
      break;
    }
   case 132:
    $498 = HEAP8[$94] | 0;
    $499 = $498 << 24 >> 24 == 0;
    if ($499) {
      label = 175;
      break;
    } else {
      label = 80;
      break;
    }
   case 133:
    $_sum427 = $154 + 1 | 0;
    $501 = $153 + ($_sum427 << 2) | 0;
    $502 = HEAP32[$501 >> 2] | 0;
    $503 = HEAP32[$92 >> 2] | 0;
    $504 = _FT_MulFix($502, $503) | 0;
    $505 = HEAP32[$93 >> 2] | 0;
    $506 = $505 + ($494 << 2) | 0;
    HEAP32[$506 >> 2] = $504;
    label = 175;
    break;
   case 134:
    _Ins_DELTAP($exc, $155);
    label = 175;
    break;
   case 135:
    _Ins_DELTAC($exc, $155);
    label = 175;
    break;
   case 136:
    $510 = HEAP32[$155 >> 2] | 0;
    _SetSuperRound($exc, 16384, $510);
    HEAP32[$15 >> 2] = 6;
    HEAP32[$95 >> 2] = 4;
    label = 175;
    break;
   case 137:
    $512 = HEAP32[$155 >> 2] | 0;
    _SetSuperRound($exc, 11585, $512);
    HEAP32[$15 >> 2] = 7;
    HEAP32[$96 >> 2] = 938;
    label = 175;
    break;
   case 138:
    $_sum426 = $154 + 1 | 0;
    $514 = $153 + ($_sum426 << 2) | 0;
    $515 = HEAP32[$514 >> 2] | 0;
    $516 = ($515 | 0) == 0;
    if ($516) {
      label = 175;
      break;
    } else {
      label = 139;
      break;
    }
   case 139:
    $518 = HEAP32[$155 >> 2] | 0;
    $519 = HEAP32[$18 >> 2] | 0;
    $520 = $519 + $518 | 0;
    HEAP32[$18 >> 2] = $520;
    $521 = ($520 | 0) < 0;
    if ($521) {
      label = 140;
      break;
    } else {
      label = 141;
      break;
    }
   case 140:
    HEAP32[$29 >> 2] = 132;
    label = 141;
    break;
   case 141:
    HEAP8[$28] = 0;
    label = 175;
    break;
   case 142:
    $_sum425 = $154 + 1 | 0;
    $525 = $153 + ($_sum425 << 2) | 0;
    $526 = HEAP32[$525 >> 2] | 0;
    $527 = ($526 | 0) == 0;
    if ($527) {
      label = 143;
      break;
    } else {
      label = 175;
      break;
    }
   case 143:
    $529 = HEAP32[$155 >> 2] | 0;
    $530 = HEAP32[$18 >> 2] | 0;
    $531 = $530 + $529 | 0;
    HEAP32[$18 >> 2] = $531;
    $532 = ($531 | 0) < 0;
    if ($532) {
      label = 144;
      break;
    } else {
      label = 145;
      break;
    }
   case 144:
    HEAP32[$29 >> 2] = 132;
    label = 145;
    break;
   case 145:
    HEAP8[$28] = 0;
    label = 175;
    break;
   case 146:
    HEAP32[$15 >> 2] = 5;
    HEAP32[$97 >> 2] = 406;
    label = 175;
    break;
   case 147:
    _Ins_UNKNOWN($exc);
    label = 175;
    break;
   case 148:
    HEAP32[$15 >> 2] = 4;
    HEAP32[$98 >> 2] = 16;
    label = 175;
    break;
   case 149:
    HEAP32[$15 >> 2] = 3;
    HEAP32[$99 >> 2] = 572;
    label = 175;
    break;
   case 150:
    _Ins_FLIPPT($exc);
    label = 175;
    break;
   case 151:
    _Ins_FLIPRGON($exc, $155);
    label = 175;
    break;
   case 152:
    _Ins_FLIPRGOFF($exc, $155);
    label = 175;
    break;
   case 153:
    _Ins_UNKNOWN($exc);
    label = 175;
    break;
   case 154:
    _Ins_SCANCTRL($exc, $155);
    label = 175;
    break;
   case 155:
    _Ins_SDPVTL($exc, $155);
    label = 175;
    break;
   case 156:
    _Ins_GETINFO($exc, $155);
    label = 175;
    break;
   case 157:
    _Ins_IDEF($exc, $155);
    label = 175;
    break;
   case 158:
    _Ins_ROLL($155);
    label = 175;
    break;
   case 159:
    $_sum424 = $154 + 1 | 0;
    $549 = $153 + ($_sum424 << 2) | 0;
    $550 = HEAP32[$549 >> 2] | 0;
    $551 = HEAP32[$155 >> 2] | 0;
    $552 = ($550 | 0) > ($551 | 0);
    if ($552) {
      label = 160;
      break;
    } else {
      label = 175;
      break;
    }
   case 160:
    HEAP32[$155 >> 2] = $550;
    label = 175;
    break;
   case 161:
    $_sum = $154 + 1 | 0;
    $555 = $153 + ($_sum << 2) | 0;
    $556 = HEAP32[$555 >> 2] | 0;
    $557 = HEAP32[$155 >> 2] | 0;
    $558 = ($556 | 0) < ($557 | 0);
    if ($558) {
      label = 162;
      break;
    } else {
      label = 175;
      break;
    }
   case 162:
    HEAP32[$155 >> 2] = $556;
    label = 175;
    break;
   case 163:
    _Ins_SCANTYPE($exc, $155);
    label = 175;
    break;
   case 164:
    _Ins_INSTCTRL($exc, $155);
    label = 175;
    break;
   case 165:
    _Ins_UNKNOWN($exc);
    label = 175;
    break;
   case 166:
    $564 = ($156 & 255) > 223;
    if ($564) {
      label = 167;
      break;
    } else {
      label = 168;
      break;
    }
   case 167:
    _Ins_MIRP($exc, $155);
    label = 175;
    break;
   case 168:
    $567 = ($156 & 255) > 191;
    if ($567) {
      label = 169;
      break;
    } else {
      label = 170;
      break;
    }
   case 169:
    _Ins_MDRP($exc, $155);
    label = 175;
    break;
   case 170:
    $570 = ($156 & 255) > 183;
    if ($570) {
      label = 171;
      break;
    } else {
      label = 172;
      break;
    }
   case 171:
    _Ins_PUSHW($exc, $155);
    label = 175;
    break;
   case 172:
    $573 = ($156 & 255) > 175;
    if ($573) {
      label = 173;
      break;
    } else {
      label = 174;
      break;
    }
   case 173:
    _Ins_PUSHB($exc, $155);
    label = 175;
    break;
   case 174:
    _Ins_UNKNOWN($exc);
    label = 175;
    break;
   case 175:
    $_pr = HEAP32[$29 >> 2] | 0;
    if (($_pr | 0) == 128) {
      label = 176;
      break;
    } else if (($_pr | 0) == 0) {
      label = 184;
      break;
    } else {
      label = 192;
      break;
    }
   case 176:
    $578 = HEAP32[$32 >> 2] | 0;
    $579 = HEAP32[$33 >> 2] | 0;
    $580 = $578 + ($579 << 4) | 0;
    $581 = ($579 | 0) > 0;
    if ($581) {
      $def_0454 = $578;
      label = 177;
      break;
    } else {
      label = 183;
      break;
    }
   case 177:
    $582 = $def_0454 + 12 | 0;
    $583 = HEAP8[$582] | 0;
    $584 = $583 << 24 >> 24 == 0;
    if ($584) {
      label = 182;
      break;
    } else {
      label = 178;
      break;
    }
   case 178:
    $586 = HEAP8[$20] | 0;
    $587 = $def_0454 + 8 | 0;
    $588 = HEAP32[$587 >> 2] | 0;
    $589 = $588 & 255;
    $590 = $586 << 24 >> 24 == $589 << 24 >> 24;
    if ($590) {
      label = 179;
      break;
    } else {
      label = 182;
      break;
    }
   case 179:
    $592 = HEAP32[$34 >> 2] | 0;
    $593 = HEAP32[$35 >> 2] | 0;
    $594 = ($592 | 0) < ($593 | 0);
    if ($594) {
      label = 181;
      break;
    } else {
      label = 180;
      break;
    }
   case 180:
    HEAP32[$29 >> 2] = 134;
    label = 192;
    break;
   case 181:
    $597 = HEAP32[$36 >> 2] | 0;
    $598 = HEAP32[$37 >> 2] | 0;
    $599 = $597 + ($592 << 4) | 0;
    HEAP32[$599 >> 2] = $598;
    $600 = HEAP32[$18 >> 2] | 0;
    $601 = $600 + 1 | 0;
    $602 = $597 + ($592 << 4) + 4 | 0;
    HEAP32[$602 >> 2] = $601;
    $603 = $597 + ($592 << 4) + 8 | 0;
    HEAP32[$603 >> 2] = 1;
    $604 = $def_0454 + 4 | 0;
    $605 = HEAP32[$604 >> 2] | 0;
    $606 = $597 + ($592 << 4) + 12 | 0;
    HEAP32[$606 >> 2] = $605;
    $607 = $def_0454 | 0;
    $608 = HEAP32[$607 >> 2] | 0;
    $609 = HEAP32[$604 >> 2] | 0;
    $610 = _Ins_Goto_CodeRange($exc, $608, $609) | 0;
    $611 = $610 << 24 >> 24 == 1;
    if ($611) {
      label = 192;
      break;
    } else {
      $ins_counter_1 = $ins_counter_0;
      label = 187;
      break;
    }
   case 182:
    $613 = $def_0454 + 16 | 0;
    $614 = $613 >>> 0 < $580 >>> 0;
    if ($614) {
      $def_0454 = $613;
      label = 177;
      break;
    } else {
      label = 183;
      break;
    }
   case 183:
    HEAP32[$29 >> 2] = 128;
    label = 192;
    break;
   case 184:
    $616 = HEAP32[$26 >> 2] | 0;
    HEAP32[$24 >> 2] = $616;
    $617 = HEAP8[$28] | 0;
    $618 = $617 << 24 >> 24 == 0;
    if ($618) {
      label = 186;
      break;
    } else {
      label = 185;
      break;
    }
   case 185:
    $620 = HEAP32[$21 >> 2] | 0;
    $621 = HEAP32[$18 >> 2] | 0;
    $622 = $621 + $620 | 0;
    HEAP32[$18 >> 2] = $622;
    label = 186;
    break;
   case 186:
    $624 = $ins_counter_0 + 1 | 0;
    $625 = ($624 | 0) > 1e6;
    if ($625) {
      $_0 = 139;
      label = 196;
      break;
    } else {
      $ins_counter_1 = $624;
      label = 187;
      break;
    }
   case 187:
    $627 = HEAP32[$18 >> 2] | 0;
    $628 = HEAP32[$23 >> 2] | 0;
    $629 = ($627 | 0) < ($628 | 0);
    if ($629) {
      label = 190;
      break;
    } else {
      label = 188;
      break;
    }
   case 188:
    $631 = $exc + 428 | 0;
    $632 = HEAP32[$631 >> 2] | 0;
    $633 = ($632 | 0) > 0;
    if ($633) {
      label = 189;
      break;
    } else {
      $_0 = 0;
      label = 196;
      break;
    }
   case 189:
    HEAP32[$29 >> 2] = 131;
    label = 192;
    break;
   case 190:
    $636 = HEAP8[$31] | 0;
    $637 = $636 << 24 >> 24 == 0;
    if ($637) {
      $ins_counter_0 = $ins_counter_1;
      label = 5;
      break;
    } else {
      $_0 = 0;
      label = 196;
      break;
    }
   case 191:
    $639 = $exc + 12 | 0;
    HEAP32[$639 >> 2] = 131;
    label = 192;
    break;
   case 192:
    $640 = $exc + 12 | 0;
    $641 = HEAP32[$640 >> 2] | 0;
    $642 = ($641 | 0) == 0;
    if ($642) {
      label = 195;
      break;
    } else {
      label = 193;
      break;
    }
   case 193:
    $644 = $exc + 488 | 0;
    $645 = HEAP8[$644] | 0;
    $646 = $645 << 24 >> 24 == 0;
    if ($646) {
      label = 194;
      break;
    } else {
      label = 195;
      break;
    }
   case 194:
    $648 = $exc + 4 | 0;
    $649 = HEAP32[$648 >> 2] | 0;
    $650 = $649 + 301 | 0;
    HEAP8[$650] = 0;
    label = 195;
    break;
   case 195:
    $652 = HEAP32[$640 >> 2] | 0;
    $_0 = $652;
    label = 196;
    break;
   case 196:
    return $_0 | 0;
  }
  return 0;
}
function _Round_To_Grid($exc, $distance, $compensation) {
  $exc = $exc | 0;
  $distance = $distance | 0;
  $compensation = $compensation | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $or_cond = 0, $7 = 0, $_10 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $_ = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($distance | 0) > -1;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = $distance + 32 | 0;
    $4 = $3 + $compensation | 0;
    $5 = ($distance | 0) != 0;
    $6 = ($4 | 0) > 0;
    $or_cond = $5 & $6;
    $7 = $4 & -64;
    $_10 = $or_cond ? $7 : 0;
    return $_10 | 0;
   case 3:
    $9 = 32 - $distance | 0;
    $10 = $9 + $compensation | 0;
    $11 = $10 & -64;
    $12 = -$11 | 0;
    $13 = ($11 | 0) < 0;
    $_ = $13 ? 0 : $12;
    return $_ | 0;
  }
  return 0;
}
function _Round_To_Half_Grid($exc, $distance, $compensation) {
  $exc = $exc | 0;
  $distance = $distance | 0;
  $compensation = $compensation | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or_cond = 0, $_9 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $_ = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($distance | 0) > -1;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = $compensation + $distance | 0;
    $4 = $3 & -64;
    $5 = $4 | 32;
    $6 = ($distance | 0) != 0;
    $7 = ($5 | 0) < 0;
    $or_cond = $6 & $7;
    $_9 = $or_cond ? 0 : $5;
    return $_9 | 0;
   case 3:
    $9 = $compensation - $distance | 0;
    $10 = $9 & -64;
    $11 = $10 | 32;
    $12 = -$11 | 0;
    $13 = ($11 | 0) < 0;
    $_ = $13 ? 0 : $12;
    return $_ | 0;
  }
  return 0;
}
function _Read_CVT($exc, $idx) {
  $exc = $exc | 0;
  $idx = $idx | 0;
  return HEAP32[(HEAP32[$exc + 384 >> 2] | 0) + ($idx << 2) >> 2] | 0;
}
function _Write_CVT($exc, $idx, $value) {
  $exc = $exc | 0;
  $idx = $idx | 0;
  $value = $value | 0;
  HEAP32[(HEAP32[$exc + 384 >> 2] | 0) + ($idx << 2) >> 2] = $value;
  return;
}
function _Move_CVT($exc, $idx, $value) {
  $exc = $exc | 0;
  $idx = $idx | 0;
  $value = $value | 0;
  var $3 = 0;
  $3 = (HEAP32[$exc + 384 >> 2] | 0) + ($idx << 2) | 0;
  HEAP32[$3 >> 2] = (HEAP32[$3 >> 2] | 0) + $value | 0;
  return;
}
function _Compute_Funcs($exc) {
  $exc = $exc | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $tmp = 0, $tmp27 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $66 = 0, $69 = 0, $70 = 0, $71 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $81 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 298 | 0;
    $2 = HEAP16[$1 >> 1] | 0;
    $3 = $2 << 16 >> 16;
    $4 = $2 << 16 >> 16 == 16384;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $6 = $exc + 294 | 0;
    $7 = HEAP16[$6 >> 1] | 0;
    $8 = $7 << 16 >> 16;
    $9 = $8 << 16;
    $10 = $exc + 564 | 0;
    HEAP32[$10 >> 2] = $9;
    label = 6;
    break;
   case 3:
    $12 = $exc + 300 | 0;
    $13 = HEAP16[$12 >> 1] | 0;
    $14 = $13 << 16 >> 16 == 16384;
    if ($14) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $16 = $exc + 296 | 0;
    $17 = HEAP16[$16 >> 1] | 0;
    $18 = $17 << 16 >> 16;
    $19 = $18 << 16;
    $20 = $exc + 564 | 0;
    HEAP32[$20 >> 2] = $19;
    label = 6;
    break;
   case 5:
    $22 = $13 << 16 >> 16;
    $23 = $exc + 294 | 0;
    $24 = HEAP16[$23 >> 1] | 0;
    $25 = $24 << 16 >> 16;
    $26 = Math_imul($25, $3);
    $27 = $exc + 296 | 0;
    $28 = HEAP16[$27 >> 1] | 0;
    $29 = $28 << 16 >> 16;
    $30 = Math_imul($29, $22);
    $tmp = $30 + $26 | 0;
    $tmp27 = $tmp << 2;
    $31 = $exc + 564 | 0;
    HEAP32[$31 >> 2] = $tmp27;
    label = 6;
    break;
   case 6:
    $33 = $exc + 294 | 0;
    $34 = HEAP16[$33 >> 1] | 0;
    $35 = $34 << 16 >> 16 == 16384;
    if ($35) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $37 = $exc + 572 | 0;
    HEAP32[$37 >> 2] = 796;
    label = 11;
    break;
   case 8:
    $39 = $exc + 296 | 0;
    $40 = HEAP16[$39 >> 1] | 0;
    $41 = $40 << 16 >> 16 == 16384;
    $42 = $exc + 572 | 0;
    if ($41) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    HEAP32[$42 >> 2] = 794;
    label = 11;
    break;
   case 10:
    HEAP32[$42 >> 2] = 856;
    label = 11;
    break;
   case 11:
    $46 = $exc + 290 | 0;
    $47 = HEAP16[$46 >> 1] | 0;
    $48 = $47 << 16 >> 16 == 16384;
    if ($48) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $50 = $exc + 576 | 0;
    HEAP32[$50 >> 2] = 796;
    label = 16;
    break;
   case 13:
    $52 = $exc + 292 | 0;
    $53 = HEAP16[$52 >> 1] | 0;
    $54 = $53 << 16 >> 16 == 16384;
    $55 = $exc + 576 | 0;
    if ($54) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    HEAP32[$55 >> 2] = 794;
    label = 16;
    break;
   case 15:
    HEAP32[$55 >> 2] = 420;
    label = 16;
    break;
   case 16:
    $59 = $exc + 584 | 0;
    HEAP32[$59 >> 2] = 212;
    $60 = $exc + 588 | 0;
    HEAP32[$60 >> 2] = 130;
    $61 = $exc + 564 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = ($62 | 0) == 1073741824;
    if ($63) {
      label = 17;
      break;
    } else {
      label = 21;
      break;
    }
   case 17:
    $65 = HEAP16[$1 >> 1] | 0;
    $66 = $65 << 16 >> 16 == 16384;
    if ($66) {
      label = 18;
      break;
    } else {
      label = 19;
      break;
    }
   case 18:
    HEAP32[$59 >> 2] = 606;
    HEAP32[$60 >> 2] = 222;
    label = 21;
    break;
   case 19:
    $69 = $exc + 300 | 0;
    $70 = HEAP16[$69 >> 1] | 0;
    $71 = $70 << 16 >> 16 == 16384;
    if ($71) {
      label = 20;
      break;
    } else {
      label = 21;
      break;
    }
   case 20:
    HEAP32[$59 >> 2] = 604;
    HEAP32[$60 >> 2] = 224;
    label = 21;
    break;
   case 21:
    $74 = HEAP32[$61 >> 2] | 0;
    $75 = ($74 | 0) < 0;
    $76 = -$74 | 0;
    $77 = $75 ? $76 : $74;
    $78 = ($77 | 0) < 67108864;
    if ($78) {
      label = 22;
      break;
    } else {
      label = 23;
      break;
    }
   case 22:
    HEAP32[$61 >> 2] = 1073741824;
    label = 23;
    break;
   case 23:
    $81 = $exc + 256 | 0;
    HEAP32[$81 >> 2] = 0;
    return;
  }
}
function _Compute_Round($exc, $round_mode) {
  $exc = $exc | 0;
  $round_mode = $round_mode | 0;
  var $1 = 0, $3 = 0, $5 = 0, $7 = 0, $9 = 0, $11 = 0, $13 = 0, $15 = 0, $17 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $round_mode & 255;
    if (($1 | 0) == 5) {
      label = 2;
      break;
    } else if (($1 | 0) == 1) {
      label = 3;
      break;
    } else if (($1 | 0) == 4) {
      label = 4;
      break;
    } else if (($1 | 0) == 3) {
      label = 5;
      break;
    } else if (($1 | 0) == 0) {
      label = 6;
      break;
    } else if (($1 | 0) == 2) {
      label = 7;
      break;
    } else if (($1 | 0) == 6) {
      label = 8;
      break;
    } else if (($1 | 0) == 7) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 2:
    $3 = $exc + 568 | 0;
    HEAP32[$3 >> 2] = 406;
    label = 10;
    break;
   case 3:
    $5 = $exc + 568 | 0;
    HEAP32[$5 >> 2] = 164;
    label = 10;
    break;
   case 4:
    $7 = $exc + 568 | 0;
    HEAP32[$7 >> 2] = 16;
    label = 10;
    break;
   case 5:
    $9 = $exc + 568 | 0;
    HEAP32[$9 >> 2] = 572;
    label = 10;
    break;
   case 6:
    $11 = $exc + 568 | 0;
    HEAP32[$11 >> 2] = 338;
    label = 10;
    break;
   case 7:
    $13 = $exc + 568 | 0;
    HEAP32[$13 >> 2] = 264;
    label = 10;
    break;
   case 8:
    $15 = $exc + 568 | 0;
    HEAP32[$15 >> 2] = 4;
    label = 10;
    break;
   case 9:
    $17 = $exc + 568 | 0;
    HEAP32[$17 >> 2] = 938;
    label = 10;
    break;
   case 10:
    return;
  }
}
function _Read_CVT_Stretched($exc, $idx) {
  $exc = $exc | 0;
  $idx = $idx | 0;
  var $4 = 0;
  $4 = HEAP32[(HEAP32[$exc + 384 >> 2] | 0) + ($idx << 2) >> 2] | 0;
  return _FT_MulFix($4, _Current_Ratio($exc) | 0) | 0;
}
function _Write_CVT_Stretched($exc, $idx, $value) {
  $exc = $exc | 0;
  $idx = $idx | 0;
  $value = $value | 0;
  var $2 = 0;
  $2 = _FT_DivFix($value, _Current_Ratio($exc) | 0) | 0;
  HEAP32[(HEAP32[$exc + 384 >> 2] | 0) + ($idx << 2) >> 2] = $2;
  return;
}
function _Move_CVT_Stretched($exc, $idx, $value) {
  $exc = $exc | 0;
  $idx = $idx | 0;
  $value = $value | 0;
  var $2 = 0, $5 = 0;
  $2 = _FT_DivFix($value, _Current_Ratio($exc) | 0) | 0;
  $5 = (HEAP32[$exc + 384 >> 2] | 0) + ($idx << 2) | 0;
  HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + $2 | 0;
  return;
}
function _Ins_SxVTL($exc, $aIdx1, $aIdx2, $aOpc, $Vec) {
  $exc = $exc | 0;
  $aIdx1 = $aIdx1 | 0;
  $aIdx2 = $aIdx2 | 0;
  $aOpc = $aOpc | 0;
  $Vec = $Vec | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $B_0 = 0, $A_0 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $aIdx1 & 65535;
    $2 = $exc + 116 | 0;
    $3 = HEAP16[$2 >> 1] | 0;
    $4 = ($3 & 65535) > ($aIdx1 & 65535);
    if ($4) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $6 = $exc + 80 | 0;
    $7 = HEAP16[$6 >> 1] | 0;
    $8 = ($7 & 65535) > ($aIdx2 & 65535);
    if ($8) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $10 = $exc + 561 | 0;
    $11 = HEAP8[$10] | 0;
    $12 = $11 << 24 >> 24 == 0;
    if ($12) {
      $_0 = 1;
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $14 = $exc + 12 | 0;
    HEAP32[$14 >> 2] = 134;
    $_0 = 1;
    label = 6;
    break;
   case 5:
    $16 = $aIdx2 & 65535;
    $17 = $exc + 88 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $exc + 124 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $18 + ($16 << 3) | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $20 + ($1 << 3) | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $22 - $24 | 0;
    $26 = $18 + ($16 << 3) + 4 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $20 + ($1 << 3) + 4 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $27 - $29 | 0;
    $31 = $aOpc & 1;
    $32 = ($31 | 0) == 0;
    $33 = -$30 | 0;
    $B_0 = $32 ? $30 : $25;
    $A_0 = $32 ? $25 : $33;
    _Normalize($A_0, $B_0, $Vec);
    $_0 = 0;
    label = 6;
    break;
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _Normalize($Vx, $Vy, $R) {
  $Vx = $Vx | 0;
  $Vy = $Vy | 0;
  $R = $R | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $_055 = 0, $31 = 0, $32 = 0, $_ = 0, $33 = 0, $W_0_lcssa = 0, $_054_lcssa = 0, $_156_lcssa = 0, $34 = 0, $_05412 = 0, $_15611 = 0, $35 = 0, $36 = 0, $_257 = 0, $37 = 0, $38 = 0, $_1 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $_29 = 0, $_3588 = 0, $43 = 0, $44 = 0, $_459 = 0, $not_ = 0, $45 = 0, $_3 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $_2_lcssa = 0, $_358_lcssa = 0, $50 = 0, $51 = 0, $_358_ = 0, $52 = 0, $53 = 0, $_4 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($Vx | 0) < 0;
    $2 = -$Vx | 0;
    $3 = $1 ? $2 : $Vx;
    $4 = ($3 | 0) < 65536;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 2:
    $6 = ($Vy | 0) < 0;
    $7 = -$Vy | 0;
    $8 = $6 ? $7 : $Vy;
    $9 = ($8 | 0) < 65536;
    if ($9) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $11 = $Vx << 8;
    $12 = $Vy << 8;
    $13 = _TT_VecLen($11, $12) | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 10;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $16 = _FT_MulDiv($11, 16384, $13) | 0;
    $17 = $16 & 65535;
    $18 = $R | 0;
    HEAP16[$18 >> 1] = $17;
    $19 = _FT_MulDiv($12, 16384, $13) | 0;
    $20 = $19 & 65535;
    $21 = $R + 2 | 0;
    HEAP16[$21 >> 1] = $20;
    label = 10;
    break;
   case 5:
    $23 = _TT_VecLen($Vx, $Vy) | 0;
    $24 = _FT_MulDiv($Vx, 16384, $23) | 0;
    $25 = _FT_MulDiv($Vy, 16384, $23) | 0;
    $26 = Math_imul($24, $24);
    $27 = Math_imul($25, $25);
    $28 = $27 + $26 | 0;
    $29 = ($24 | 0) < 0;
    $30 = -$24 | 0;
    $_055 = $29 ? $30 : $24;
    $31 = ($25 | 0) < 0;
    $32 = -$25 | 0;
    $_ = $31 ? $32 : $25;
    $33 = ($28 | 0) < 268435456;
    if ($33) {
      $_15611 = $_055;
      $_05412 = $_;
      label = 7;
      break;
    } else {
      $_156_lcssa = $_055;
      $_054_lcssa = $_;
      $W_0_lcssa = $28;
      label = 6;
      break;
    }
   case 6:
    $34 = ($W_0_lcssa | 0) > 268451839;
    if ($34) {
      $_3588 = $_156_lcssa;
      $_29 = $_054_lcssa;
      label = 8;
      break;
    } else {
      $_358_lcssa = $_156_lcssa;
      $_2_lcssa = $_054_lcssa;
      label = 9;
      break;
    }
   case 7:
    $35 = ($_15611 | 0) < ($_05412 | 0);
    $36 = $35 & 1;
    $_257 = $36 + $_15611 | 0;
    $37 = $35 & 1;
    $38 = $37 ^ 1;
    $_1 = $38 + $_05412 | 0;
    $39 = Math_imul($_257, $_257);
    $40 = Math_imul($_1, $_1);
    $41 = $40 + $39 | 0;
    $42 = ($41 | 0) < 268435456;
    if ($42) {
      $_15611 = $_257;
      $_05412 = $_1;
      label = 7;
      break;
    } else {
      $_156_lcssa = $_257;
      $_054_lcssa = $_1;
      $W_0_lcssa = $41;
      label = 6;
      break;
    }
   case 8:
    $43 = ($_3588 | 0) < ($_29 | 0);
    $44 = $43 << 31 >> 31;
    $_459 = $44 + $_3588 | 0;
    $not_ = $43 ^ 1;
    $45 = $not_ << 31 >> 31;
    $_3 = $45 + $_29 | 0;
    $46 = Math_imul($_459, $_459);
    $47 = Math_imul($_3, $_3);
    $48 = $46 + $47 | 0;
    $49 = ($48 | 0) > 268451839;
    if ($49) {
      $_3588 = $_459;
      $_29 = $_3;
      label = 8;
      break;
    } else {
      $_358_lcssa = $_459;
      $_2_lcssa = $_3;
      label = 9;
      break;
    }
   case 9:
    $50 = ($24 | 0) > -1;
    $51 = -$_358_lcssa | 0;
    $_358_ = $50 ? $_358_lcssa : $51;
    $52 = ($25 | 0) > -1;
    $53 = -$_2_lcssa | 0;
    $_4 = $52 ? $_2_lcssa : $53;
    $54 = $_358_ & 65535;
    $55 = $R | 0;
    HEAP16[$55 >> 1] = $54;
    $56 = $_4 & 65535;
    $57 = $R + 2 | 0;
    HEAP16[$57 >> 1] = $56;
    label = 10;
    break;
   case 10:
    return;
  }
}
function _Ins_ISECT($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = $args + 4 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $args + 8 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $args + 12 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 & 65535;
    $9 = $exc + 44 | 0;
    $10 = HEAP16[$9 >> 1] | 0;
    $11 = $10 & 65535;
    $12 = $8 >>> 0 < $11 >>> 0;
    if ($12) {
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $14 = $args + 16 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15 & 65535;
    $17 = $16 >>> 0 < $11 >>> 0;
    if ($17) {
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 3:
    $19 = $3 & 65535;
    $20 = $exc + 80 | 0;
    $21 = HEAP16[$20 >> 1] | 0;
    $22 = $21 & 65535;
    $23 = $19 >>> 0 < $22 >>> 0;
    if ($23) {
      label = 4;
      break;
    } else {
      label = 6;
      break;
    }
   case 4:
    $25 = $5 & 65535;
    $26 = $25 >>> 0 < $22 >>> 0;
    if ($26) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $28 = $1 & 65535;
    $29 = $exc + 116 | 0;
    $30 = HEAP16[$29 >> 1] | 0;
    $31 = $30 & 65535;
    $32 = $28 >>> 0 < $31 >>> 0;
    if ($32) {
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $34 = $exc + 561 | 0;
    $35 = HEAP8[$34] | 0;
    $36 = $35 << 24 >> 24 == 0;
    if ($36) {
      label = 11;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $38 = $exc + 12 | 0;
    HEAP32[$38 >> 2] = 134;
    label = 11;
    break;
   case 8:
    $40 = $exc + 52 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = $41 + ($16 << 3) | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $41 + ($8 << 3) | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = $43 - $45 | 0;
    $47 = $41 + ($16 << 3) + 4 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $41 + ($8 << 3) + 4 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $exc + 88 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = $52 + ($25 << 3) | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = $52 + ($19 << 3) | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = $54 - $56 | 0;
    $58 = $52 + ($25 << 3) + 4 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = $52 + ($19 << 3) + 4 | 0;
    $61 = HEAP32[$60 >> 2] | 0;
    $62 = $59 - $61 | 0;
    $63 = $exc + 132 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = $64 + $28 | 0;
    $66 = HEAP8[$65] | 0;
    $67 = $66 | 24;
    HEAP8[$65] = $67;
    $68 = $50 - $48 | 0;
    $69 = _FT_MulDiv($57, $68, 64) | 0;
    $70 = _FT_MulDiv($62, $46, 64) | 0;
    $71 = $70 + $69 | 0;
    $72 = ($71 | 0) < 0;
    $73 = -$71 | 0;
    $74 = $72 ? $73 : $71;
    $75 = ($74 | 0) > 63;
    if ($75) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $77 = $50 - $61 | 0;
    $78 = $45 - $56 | 0;
    $79 = _FT_MulDiv($78, $68, 64) | 0;
    $80 = _FT_MulDiv($77, $46, 64) | 0;
    $81 = $80 + $79 | 0;
    $82 = _FT_MulDiv($81, $57, $71) | 0;
    $83 = _FT_MulDiv($81, $62, $71) | 0;
    $84 = HEAP32[$51 >> 2] | 0;
    $85 = $84 + ($19 << 3) | 0;
    $86 = HEAP32[$85 >> 2] | 0;
    $87 = $86 + $82 | 0;
    $88 = $exc + 124 | 0;
    $89 = HEAP32[$88 >> 2] | 0;
    $90 = $89 + ($28 << 3) | 0;
    HEAP32[$90 >> 2] = $87;
    $91 = HEAP32[$51 >> 2] | 0;
    $92 = $91 + ($19 << 3) + 4 | 0;
    $93 = HEAP32[$92 >> 2] | 0;
    $94 = $93 + $83 | 0;
    $95 = HEAP32[$88 >> 2] | 0;
    $96 = $95 + ($28 << 3) + 4 | 0;
    HEAP32[$96 >> 2] = $94;
    label = 11;
    break;
   case 10:
    $98 = HEAP32[$51 >> 2] | 0;
    $99 = $98 + ($19 << 3) | 0;
    $100 = HEAP32[$99 >> 2] | 0;
    $101 = $98 + ($25 << 3) | 0;
    $102 = HEAP32[$101 >> 2] | 0;
    $103 = $102 + $100 | 0;
    $104 = HEAP32[$40 >> 2] | 0;
    $105 = $104 + ($8 << 3) | 0;
    $106 = HEAP32[$105 >> 2] | 0;
    $107 = $103 + $106 | 0;
    $108 = $104 + ($16 << 3) | 0;
    $109 = HEAP32[$108 >> 2] | 0;
    $110 = $107 + $109 | 0;
    $111 = ($110 | 0) / 4 & -1;
    $112 = $exc + 124 | 0;
    $113 = HEAP32[$112 >> 2] | 0;
    $114 = $113 + ($28 << 3) | 0;
    HEAP32[$114 >> 2] = $111;
    $115 = HEAP32[$51 >> 2] | 0;
    $116 = $115 + ($19 << 3) + 4 | 0;
    $117 = HEAP32[$116 >> 2] | 0;
    $118 = $115 + ($25 << 3) + 4 | 0;
    $119 = HEAP32[$118 >> 2] | 0;
    $120 = $119 + $117 | 0;
    $121 = HEAP32[$40 >> 2] | 0;
    $122 = $121 + ($8 << 3) + 4 | 0;
    $123 = HEAP32[$122 >> 2] | 0;
    $124 = $120 + $123 | 0;
    $125 = $121 + ($16 << 3) + 4 | 0;
    $126 = HEAP32[$125 >> 2] | 0;
    $127 = $124 + $126 | 0;
    $128 = ($127 | 0) / 4 & -1;
    $129 = HEAP32[$112 >> 2] | 0;
    $130 = $129 + ($28 << 3) + 4 | 0;
    HEAP32[$130 >> 2] = $128;
    label = 11;
    break;
   case 11:
    return;
  }
}
function _Ins_SZP0($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    if (($1 | 0) == 0) {
      label = 2;
      break;
    } else if (($1 | 0) == 1) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $3 = $exc + 36 | 0;
    $4 = $exc + 180 | 0;
    $5 = $3;
    $6 = $4;
    _memcpy($5 | 0, $6 | 0, 36);
    label = 6;
    break;
   case 3:
    $8 = $exc + 36 | 0;
    $9 = $exc + 144 | 0;
    $10 = $8;
    $11 = $9;
    _memcpy($10 | 0, $11 | 0, 36);
    label = 6;
    break;
   case 4:
    $13 = $exc + 561 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 << 24 >> 24 == 0;
    if ($15) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = $exc + 12 | 0;
    HEAP32[$17 >> 2] = 134;
    label = 7;
    break;
   case 6:
    $19 = HEAP32[$args >> 2] | 0;
    $20 = $19 & 65535;
    $21 = $exc + 344 | 0;
    HEAP16[$21 >> 1] = $20;
    label = 7;
    break;
   case 7:
    return;
  }
}
function _Ins_SZP1($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    if (($1 | 0) == 0) {
      label = 2;
      break;
    } else if (($1 | 0) == 1) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $3 = $exc + 72 | 0;
    $4 = $exc + 180 | 0;
    $5 = $3;
    $6 = $4;
    _memcpy($5 | 0, $6 | 0, 36);
    label = 6;
    break;
   case 3:
    $8 = $exc + 72 | 0;
    $9 = $exc + 144 | 0;
    $10 = $8;
    $11 = $9;
    _memcpy($10 | 0, $11 | 0, 36);
    label = 6;
    break;
   case 4:
    $13 = $exc + 561 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 << 24 >> 24 == 0;
    if ($15) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = $exc + 12 | 0;
    HEAP32[$17 >> 2] = 134;
    label = 7;
    break;
   case 6:
    $19 = HEAP32[$args >> 2] | 0;
    $20 = $19 & 65535;
    $21 = $exc + 346 | 0;
    HEAP16[$21 >> 1] = $20;
    label = 7;
    break;
   case 7:
    return;
  }
}
function _Ins_SZP2($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    if (($1 | 0) == 0) {
      label = 2;
      break;
    } else if (($1 | 0) == 1) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $3 = $exc + 108 | 0;
    $4 = $exc + 180 | 0;
    $5 = $3;
    $6 = $4;
    _memcpy($5 | 0, $6 | 0, 36);
    label = 6;
    break;
   case 3:
    $8 = $exc + 108 | 0;
    $9 = $exc + 144 | 0;
    $10 = $8;
    $11 = $9;
    _memcpy($10 | 0, $11 | 0, 36);
    label = 6;
    break;
   case 4:
    $13 = $exc + 561 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 << 24 >> 24 == 0;
    if ($15) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = $exc + 12 | 0;
    HEAP32[$17 >> 2] = 134;
    label = 7;
    break;
   case 6:
    $19 = HEAP32[$args >> 2] | 0;
    $20 = $19 & 65535;
    $21 = $exc + 348 | 0;
    HEAP16[$21 >> 1] = $20;
    label = 7;
    break;
   case 7:
    return;
  }
}
function _Ins_SZPS($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    if (($1 | 0) == 0) {
      label = 2;
      break;
    } else if (($1 | 0) == 1) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $3 = $exc + 36 | 0;
    $4 = $exc + 180 | 0;
    $5 = $3;
    $6 = $4;
    _memcpy($5 | 0, $6 | 0, 36);
    label = 6;
    break;
   case 3:
    $8 = $exc + 36 | 0;
    $9 = $exc + 144 | 0;
    $10 = $8;
    $11 = $9;
    _memcpy($10 | 0, $11 | 0, 36);
    label = 6;
    break;
   case 4:
    $13 = $exc + 561 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 << 24 >> 24 == 0;
    if ($15) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = $exc + 12 | 0;
    HEAP32[$17 >> 2] = 134;
    label = 7;
    break;
   case 6:
    $19 = $exc + 72 | 0;
    $20 = $exc + 36 | 0;
    $21 = $19;
    $22 = $20;
    _memcpy($21 | 0, $22 | 0, 36);
    $23 = $exc + 108 | 0;
    $24 = $23;
    _memcpy($24 | 0, $22 | 0, 36);
    $25 = HEAP32[$args >> 2] | 0;
    $26 = $25 & 65535;
    $27 = $exc + 344 | 0;
    HEAP16[$27 >> 1] = $26;
    $28 = HEAP32[$args >> 2] | 0;
    $29 = $28 & 65535;
    $30 = $exc + 346 | 0;
    HEAP16[$30 >> 1] = $29;
    $31 = HEAP32[$args >> 2] | 0;
    $32 = $31 & 65535;
    $33 = $exc + 348 | 0;
    HEAP16[$33 >> 1] = $32;
    label = 7;
    break;
   case 7:
    return;
  }
}
function _Ins_ELSE($exc) {
  $exc = $exc | 0;
  var $1 = 0, $nIfs_0 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0, $11 = 0, $nIfs_1 = 0, $13 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 368 | 0;
    $nIfs_0 = 1;
    label = 2;
    break;
   case 2:
    $3 = _SkipCode($exc) | 0;
    $4 = $3 << 24 >> 24 == 1;
    if ($4) {
      label = 7;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $6 = HEAP8[$1] | 0;
    $7 = $6 & 255;
    if (($7 | 0) == 88) {
      label = 4;
      break;
    } else if (($7 | 0) == 89) {
      label = 5;
      break;
    } else {
      $nIfs_1 = $nIfs_0;
      label = 6;
      break;
    }
   case 4:
    $9 = $nIfs_0 + 1 | 0;
    $nIfs_1 = $9;
    label = 6;
    break;
   case 5:
    $11 = $nIfs_0 - 1 | 0;
    $nIfs_1 = $11;
    label = 6;
    break;
   case 6:
    $13 = ($nIfs_1 | 0) == 0;
    if ($13) {
      label = 7;
      break;
    } else {
      $nIfs_0 = $nIfs_1;
      label = 2;
      break;
    }
   case 7:
    return;
  }
}
function _Ins_MINDEX($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = ($1 | 0) < 1;
    if ($2) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $exc + 28 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($1 | 0) > ($5 | 0);
    if ($6) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $8 = $exc + 12 | 0;
    HEAP32[$8 >> 2] = 134;
    label = 5;
    break;
   case 4:
    $10 = $5 - $1 | 0;
    $11 = $exc + 24 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + ($10 << 2) | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $13;
    $16 = $10 + 1 | 0;
    $17 = $12 + ($16 << 2) | 0;
    $18 = $17;
    $19 = $1 << 2;
    $20 = $19 - 4 | 0;
    _memmove($15 | 0, $18 | 0, $20 | 0);
    $21 = HEAP32[$4 >> 2] | 0;
    $22 = $21 - 1 | 0;
    $23 = HEAP32[$11 >> 2] | 0;
    $24 = $23 + ($22 << 2) | 0;
    HEAP32[$24 >> 2] = $14;
    label = 5;
    break;
   case 5:
    return;
  }
}
function _Ins_ALIGNPTS($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = $1 & 65535;
    $3 = $args + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 & 65535;
    $6 = $1 & 65535;
    $7 = $exc + 72 | 0;
    $8 = $exc + 80 | 0;
    $9 = HEAP16[$8 >> 1] | 0;
    $10 = $9 & 65535;
    $11 = $6 >>> 0 < $10 >>> 0;
    if ($11) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $13 = $4 & 65535;
    $14 = $exc + 44 | 0;
    $15 = HEAP16[$14 >> 1] | 0;
    $16 = $15 & 65535;
    $17 = $13 >>> 0 < $16 >>> 0;
    if ($17) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $19 = $exc + 561 | 0;
    $20 = HEAP8[$19] | 0;
    $21 = $20 << 24 >> 24 == 0;
    if ($21) {
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $23 = $exc + 12 | 0;
    HEAP32[$23 >> 2] = 134;
    label = 6;
    break;
   case 5:
    $25 = $exc + 36 | 0;
    $26 = $exc + 572 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $exc + 52 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $29 + ($13 << 3) | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $exc + 88 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $33 + ($6 << 3) | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $31 - $35 | 0;
    $37 = $29 + ($13 << 3) + 4 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $33 + ($6 << 3) + 4 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $38 - $40 | 0;
    $42 = FUNCTION_TABLE_iiii[$27 & 1023]($exc, $36, $41) | 0;
    $43 = ($42 | 0) / 2 & -1;
    $44 = $exc + 584 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    FUNCTION_TABLE_viiii[$45 & 1023]($exc, $7, $2, $43);
    $46 = HEAP32[$44 >> 2] | 0;
    $47 = -$43 | 0;
    FUNCTION_TABLE_viiii[$46 & 1023]($exc, $25, $5, $47);
    label = 6;
    break;
   case 6:
    return;
  }
}
function _Ins_UTP($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $_ = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $mask_1 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = $1 & 65535;
    $3 = $exc + 44 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 & 65535;
    $6 = $2 >>> 0 < $5 >>> 0;
    if ($6) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $exc + 561 | 0;
    $9 = HEAP8[$8] | 0;
    $10 = $9 << 24 >> 24 == 0;
    if ($10) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = $exc + 12 | 0;
    HEAP32[$12 >> 2] = 134;
    label = 5;
    break;
   case 4:
    $14 = $exc + 298 | 0;
    $15 = HEAP16[$14 >> 1] | 0;
    $16 = $15 << 16 >> 16 == 0;
    $_ = $16 ? -1 : -9;
    $17 = $exc + 300 | 0;
    $18 = HEAP16[$17 >> 1] | 0;
    $19 = $18 << 16 >> 16 == 0;
    $20 = $_ & -17;
    $mask_1 = $19 ? $_ : $20;
    $21 = $exc + 60 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22 + $2 | 0;
    $24 = HEAP8[$23] | 0;
    $25 = $mask_1 & $24;
    HEAP8[$23] = $25;
    label = 5;
    break;
   case 5:
    return;
  }
}
function _Ins_UNKNOWN($exc) {
  $exc = $exc | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $def_02 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 416 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $exc + 408 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + ($4 << 4) | 0;
    $6 = ($4 | 0) > 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 9;
      break;
    }
   case 2:
    $7 = $exc + 368 | 0;
    $8 = HEAP8[$7] | 0;
    $def_02 = $2;
    label = 3;
    break;
   case 3:
    $10 = $def_02 + 8 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 & 255;
    $13 = $8 << 24 >> 24 == $12 << 24 >> 24;
    if ($13) {
      label = 4;
      break;
    } else {
      label = 8;
      break;
    }
   case 4:
    $15 = $def_02 + 12 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 << 24 >> 24 == 0;
    if ($17) {
      label = 8;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $19 = $exc + 428 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $exc + 432 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = ($20 | 0) < ($22 | 0);
    if ($23) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $25 = $exc + 12 | 0;
    HEAP32[$25 >> 2] = 130;
    label = 10;
    break;
   case 7:
    $27 = $exc + 436 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $20 + 1 | 0;
    HEAP32[$19 >> 2] = $29;
    $30 = $exc + 352 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $28 + ($20 << 4) | 0;
    HEAP32[$32 >> 2] = $31;
    $33 = $exc + 360 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $34 + 1 | 0;
    $36 = $28 + ($20 << 4) + 4 | 0;
    HEAP32[$36 >> 2] = $35;
    $37 = $28 + ($20 << 4) + 8 | 0;
    HEAP32[$37 >> 2] = 1;
    $38 = $def_02 + 4 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = $28 + ($20 << 4) + 12 | 0;
    HEAP32[$40 >> 2] = $39;
    $41 = $def_02 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = HEAP32[$38 >> 2] | 0;
    $44 = _Ins_Goto_CodeRange($exc, $42, $43) | 0;
    $45 = $exc + 376 | 0;
    HEAP8[$45] = 0;
    label = 10;
    break;
   case 8:
    $47 = $def_02 + 16 | 0;
    $48 = $47 >>> 0 < $5 >>> 0;
    if ($48) {
      $def_02 = $47;
      label = 3;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $49 = $exc + 12 | 0;
    HEAP32[$49 >> 2] = 128;
    label = 10;
    break;
   case 10:
    return;
  }
}
function _Ins_LOOPCALL($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $def_0 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $def_1 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $68 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $args + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $exc + 420 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 1 | 0;
    $6 = $2 >>> 0 < $5 >>> 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 13;
      break;
    }
   case 2:
    $8 = $exc + 404 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $exc + 396 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($5 | 0) == ($11 | 0);
    if ($12) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $14 = $9 + ($2 << 4) | 0;
    $15 = $9 + ($2 << 4) + 8 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($16 | 0) == ($2 | 0);
    if ($17) {
      $def_1 = $14;
      label = 8;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $19 = HEAP32[$8 >> 2] | 0;
    $20 = HEAP32[$10 >> 2] | 0;
    $21 = $19 + ($20 << 4) | 0;
    $def_0 = $19;
    label = 5;
    break;
   case 5:
    $23 = $def_0 >>> 0 < $21 >>> 0;
    if ($23) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $25 = $def_0 + 8 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = ($26 | 0) == ($2 | 0);
    $28 = $def_0 + 16 | 0;
    if ($27) {
      label = 7;
      break;
    } else {
      $def_0 = $28;
      label = 5;
      break;
    }
   case 7:
    $29 = ($def_0 | 0) == ($21 | 0);
    if ($29) {
      label = 13;
      break;
    } else {
      $def_1 = $def_0;
      label = 8;
      break;
    }
   case 8:
    $31 = $def_1 + 12 | 0;
    $32 = HEAP8[$31] | 0;
    $33 = $32 << 24 >> 24 == 0;
    if ($33) {
      label = 13;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $35 = $exc + 428 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $exc + 432 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = ($36 | 0) < ($38 | 0);
    if ($39) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $41 = $exc + 12 | 0;
    HEAP32[$41 >> 2] = 130;
    label = 14;
    break;
   case 11:
    $43 = HEAP32[$args >> 2] | 0;
    $44 = ($43 | 0) > 0;
    if ($44) {
      label = 12;
      break;
    } else {
      label = 14;
      break;
    }
   case 12:
    $46 = $exc + 436 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $exc + 352 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = $47 + ($36 << 4) | 0;
    HEAP32[$50 >> 2] = $49;
    $51 = $exc + 360 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = $52 + 1 | 0;
    $54 = $47 + ($36 << 4) + 4 | 0;
    HEAP32[$54 >> 2] = $53;
    $55 = HEAP32[$args >> 2] | 0;
    $56 = $47 + ($36 << 4) + 8 | 0;
    HEAP32[$56 >> 2] = $55;
    $57 = $def_1 + 4 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = $47 + ($36 << 4) + 12 | 0;
    HEAP32[$59 >> 2] = $58;
    $60 = HEAP32[$35 >> 2] | 0;
    $61 = $60 + 1 | 0;
    HEAP32[$35 >> 2] = $61;
    $62 = $def_1 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = HEAP32[$57 >> 2] | 0;
    $65 = _Ins_Goto_CodeRange($exc, $63, $64) | 0;
    $66 = $exc + 376 | 0;
    HEAP8[$66] = 0;
    label = 14;
    break;
   case 13:
    $68 = $exc + 12 | 0;
    HEAP32[$68 >> 2] = 134;
    label = 14;
    break;
   case 14:
    return;
  }
}
function _Ins_CALL($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $def_0 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $def_1 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = $exc + 420 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 + 1 | 0;
    $5 = $1 >>> 0 < $4 >>> 0;
    if ($5) {
      label = 2;
      break;
    } else {
      label = 12;
      break;
    }
   case 2:
    $7 = $exc + 404 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $exc + 396 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($4 | 0) == ($10 | 0);
    if ($11) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $13 = $8 + ($1 << 4) | 0;
    $14 = $8 + ($1 << 4) + 8 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = ($15 | 0) == ($1 | 0);
    if ($16) {
      $def_1 = $13;
      label = 8;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $18 = HEAP32[$7 >> 2] | 0;
    $19 = HEAP32[$9 >> 2] | 0;
    $20 = $18 + ($19 << 4) | 0;
    $def_0 = $18;
    label = 5;
    break;
   case 5:
    $22 = $def_0 >>> 0 < $20 >>> 0;
    if ($22) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $24 = $def_0 + 8 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = ($25 | 0) == ($1 | 0);
    $27 = $def_0 + 16 | 0;
    if ($26) {
      label = 7;
      break;
    } else {
      $def_0 = $27;
      label = 5;
      break;
    }
   case 7:
    $28 = ($def_0 | 0) == ($20 | 0);
    if ($28) {
      label = 12;
      break;
    } else {
      $def_1 = $def_0;
      label = 8;
      break;
    }
   case 8:
    $30 = $def_1 + 12 | 0;
    $31 = HEAP8[$30] | 0;
    $32 = $31 << 24 >> 24 == 0;
    if ($32) {
      label = 12;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $34 = $exc + 428 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $exc + 432 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = ($35 | 0) < ($37 | 0);
    if ($38) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $40 = $exc + 12 | 0;
    HEAP32[$40 >> 2] = 130;
    label = 13;
    break;
   case 11:
    $42 = $exc + 436 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $exc + 352 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = $43 + ($35 << 4) | 0;
    HEAP32[$46 >> 2] = $45;
    $47 = $exc + 360 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $48 + 1 | 0;
    $50 = $43 + ($35 << 4) + 4 | 0;
    HEAP32[$50 >> 2] = $49;
    $51 = $43 + ($35 << 4) + 8 | 0;
    HEAP32[$51 >> 2] = 1;
    $52 = $def_1 + 4 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $43 + ($35 << 4) + 12 | 0;
    HEAP32[$54 >> 2] = $53;
    $55 = HEAP32[$34 >> 2] | 0;
    $56 = $55 + 1 | 0;
    HEAP32[$34 >> 2] = $56;
    $57 = $def_1 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = HEAP32[$52 >> 2] | 0;
    $60 = _Ins_Goto_CodeRange($exc, $58, $59) | 0;
    $61 = $exc + 376 | 0;
    HEAP8[$61] = 0;
    label = 13;
    break;
   case 12:
    $63 = $exc + 12 | 0;
    HEAP32[$63 >> 2] = 134;
    label = 13;
    break;
   case 13:
    return;
  }
}
function _Ins_FDEF($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $rec_0 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $24 = 0, $26 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $52 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 404 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $exc + 396 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + ($4 << 4) | 0;
    $6 = HEAP32[$args >> 2] | 0;
    $rec_0 = $2;
    label = 2;
    break;
   case 2:
    $8 = $rec_0 >>> 0 < $5 >>> 0;
    if ($8) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $10 = $rec_0 + 8 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($11 | 0) == ($6 | 0);
    $13 = $rec_0 + 16 | 0;
    if ($12) {
      label = 4;
      break;
    } else {
      $rec_0 = $13;
      label = 2;
      break;
    }
   case 4:
    $15 = ($rec_0 | 0) == ($5 | 0);
    if ($15) {
      label = 5;
      break;
    } else {
      label = 8;
      break;
    }
   case 5:
    $17 = HEAP32[$3 >> 2] | 0;
    $18 = $exc + 400 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $17 >>> 0 < $19 >>> 0;
    if ($20) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $22 = $exc + 12 | 0;
    HEAP32[$22 >> 2] = 140;
    label = 16;
    break;
   case 7:
    $24 = $17 + 1 | 0;
    HEAP32[$3 >> 2] = $24;
    label = 8;
    break;
   case 8:
    $26 = $6 >>> 0 > 65535;
    if ($26) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $28 = $exc + 12 | 0;
    HEAP32[$28 >> 2] = 140;
    label = 16;
    break;
   case 10:
    $30 = $exc + 352 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $rec_0 | 0;
    HEAP32[$32 >> 2] = $31;
    $33 = $6 & 65535;
    $34 = $rec_0 + 8 | 0;
    HEAP32[$34 >> 2] = $33;
    $35 = $exc + 360 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $36 + 1 | 0;
    $38 = $rec_0 + 4 | 0;
    HEAP32[$38 >> 2] = $37;
    $39 = $rec_0 + 12 | 0;
    HEAP8[$39] = 1;
    $40 = $exc + 420 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = $6 >>> 0 > $41 >>> 0;
    if ($42) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    HEAP32[$40 >> 2] = $33;
    label = 12;
    break;
   case 12:
    $44 = $exc + 368 | 0;
    label = 13;
    break;
   case 13:
    $46 = _SkipCode($exc) | 0;
    $47 = $46 << 24 >> 24 == 0;
    if ($47) {
      label = 14;
      break;
    } else {
      label = 16;
      break;
    }
   case 14:
    $49 = HEAP8[$44] | 0;
    $50 = $49 & 255;
    if (($50 | 0) == 137 | ($50 | 0) == 44) {
      label = 15;
      break;
    } else if (($50 | 0) == 45) {
      label = 16;
      break;
    } else {
      label = 13;
      break;
    }
   case 15:
    $52 = $exc + 12 | 0;
    HEAP32[$52 >> 2] = 137;
    label = 16;
    break;
   case 16:
    return;
  }
}
function _Ins_ENDF($exc) {
  $exc = $exc | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 428 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) < 1;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $5 = $exc + 12 | 0;
    HEAP32[$5 >> 2] = 136;
    label = 6;
    break;
   case 3:
    $7 = $2 - 1 | 0;
    HEAP32[$1 >> 2] = $7;
    $8 = $exc + 436 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 + ($7 << 4) + 8 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 - 1 | 0;
    HEAP32[$10 >> 2] = $12;
    $13 = $exc + 376 | 0;
    HEAP8[$13] = 0;
    $14 = HEAP32[$10 >> 2] | 0;
    $15 = ($14 | 0) > 0;
    if ($15) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $17 = HEAP32[$1 >> 2] | 0;
    $18 = $17 + 1 | 0;
    HEAP32[$1 >> 2] = $18;
    $19 = $9 + ($7 << 4) + 12 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $exc + 360 | 0;
    HEAP32[$21 >> 2] = $20;
    label = 6;
    break;
   case 5:
    $23 = $9 + ($7 << 4) | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $9 + ($7 << 4) + 4 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = _Ins_Goto_CodeRange($exc, $24, $26) | 0;
    label = 6;
    break;
   case 6:
    return;
  }
}
function _Ins_MDAP($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $distance_0 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = $1 & 65535;
    $3 = $1 & 65535;
    $4 = $exc + 36 | 0;
    $5 = $exc + 44 | 0;
    $6 = HEAP16[$5 >> 1] | 0;
    $7 = $6 & 65535;
    $8 = $3 >>> 0 < $7 >>> 0;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = $exc + 561 | 0;
    $11 = HEAP8[$10] | 0;
    $12 = $11 << 24 >> 24 == 0;
    if ($12) {
      label = 7;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $14 = $exc + 12 | 0;
    HEAP32[$14 >> 2] = 134;
    label = 7;
    break;
   case 4:
    $16 = $exc + 368 | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 & 1;
    $19 = $18 << 24 >> 24 == 0;
    if ($19) {
      $distance_0 = 0;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $21 = $exc + 572 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $exc + 52 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24 + ($3 << 3) | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $24 + ($3 << 3) + 4 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = FUNCTION_TABLE_iiii[$22 & 1023]($exc, $26, $28) | 0;
    $30 = $exc + 568 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $exc + 264 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = FUNCTION_TABLE_iiii[$31 & 1023]($exc, $29, $33) | 0;
    $35 = $34 - $29 | 0;
    $distance_0 = $35;
    label = 6;
    break;
   case 6:
    $37 = $exc + 584 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    FUNCTION_TABLE_viiii[$38 & 1023]($exc, $4, $2, $distance_0);
    $39 = $exc + 284 | 0;
    HEAP16[$39 >> 1] = $2;
    $40 = $exc + 286 | 0;
    HEAP16[$40 >> 1] = $2;
    label = 7;
    break;
   case 7:
    return;
  }
}
function _Ins_IUP($exc) {
  $exc = $exc | 0;
  var $V = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $mask_0 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $point_0 = 0, $contour_0 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $end_point_0_ph = 0, $point_1 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $cur_touched_0_ph = 0, $point_2_in = 0, $point_2 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $75 = 0, $77 = 0, $80 = 0, $81 = 0, $82 = 0, $84 = 0, $point_3 = 0, $85 = 0, $86 = 0, $87 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $V = __stackBase__ | 0;
    $1 = $exc + 154 | 0;
    $2 = HEAP16[$1 >> 1] | 0;
    $3 = $2 << 16 >> 16 == 0;
    if ($3) {
      label = 18;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $exc + 368 | 0;
    $6 = HEAP8[$5] | 0;
    $7 = $6 & 1;
    $8 = $7 << 24 >> 24 == 0;
    $9 = $exc + 156 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = $V | 0;
    HEAP32[$12 >> 2] = $10;
    $13 = $exc + 160 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $V + 4 | 0;
    HEAP32[$15 >> 2] = $14;
    $16 = $exc + 164 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $V + 8 | 0;
    HEAP32[$18 >> 2] = $17;
    $mask_0 = 8;
    label = 5;
    break;
   case 4:
    $20 = $10 | 0;
    $21 = $20 + 4 | 0;
    $22 = $21;
    $23 = $V | 0;
    HEAP32[$23 >> 2] = $22;
    $24 = $exc + 160 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $25 | 0;
    $27 = $26 + 4 | 0;
    $28 = $27;
    $29 = $V + 4 | 0;
    HEAP32[$29 >> 2] = $28;
    $30 = $exc + 164 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $31 | 0;
    $33 = $32 + 4 | 0;
    $34 = $33;
    $35 = $V + 8 | 0;
    HEAP32[$35 >> 2] = $34;
    $mask_0 = 16;
    label = 5;
    break;
   case 5:
    $37 = $exc + 152 | 0;
    $38 = HEAP16[$37 >> 1] | 0;
    $39 = $38 & 65535;
    $40 = $V + 12 | 0;
    HEAP32[$40 >> 2] = $39;
    $41 = $exc + 172 | 0;
    $42 = $exc + 176 | 0;
    $43 = $exc + 168 | 0;
    $contour_0 = 0;
    $point_0 = 0;
    label = 6;
    break;
   case 6:
    $45 = $contour_0 << 16 >> 16;
    $46 = HEAP32[$41 >> 2] | 0;
    $47 = $46 + ($45 << 1) | 0;
    $48 = HEAP16[$47 >> 1] | 0;
    $49 = $48 & 65535;
    $50 = HEAP16[$42 >> 1] | 0;
    $51 = $50 & 65535;
    $52 = $49 - $51 | 0;
    $53 = HEAP16[$37 >> 1] | 0;
    $54 = $53 & 65535;
    $55 = $52 >>> 0 < $54 >>> 0;
    $56 = $54 - 1 | 0;
    $end_point_0_ph = $55 ? $52 : $56;
    $point_1 = $point_0;
    label = 7;
    break;
   case 7:
    $57 = $point_1 >>> 0 > $end_point_0_ph >>> 0;
    if ($57) {
      $point_3 = $point_1;
      label = 17;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $59 = HEAP32[$43 >> 2] | 0;
    $60 = $59 + $point_1 | 0;
    $61 = HEAP8[$60] | 0;
    $62 = $61 & 255;
    $63 = $62 & $mask_0;
    $64 = ($63 | 0) == 0;
    $65 = $point_1 + 1 | 0;
    if ($64) {
      $point_1 = $65;
      label = 7;
      break;
    } else {
      $cur_touched_0_ph = $point_1;
      label = 9;
      break;
    }
   case 9:
    $point_2_in = $cur_touched_0_ph;
    label = 10;
    break;
   case 10:
    $point_2 = $point_2_in + 1 | 0;
    $66 = $point_2 >>> 0 > $end_point_0_ph >>> 0;
    if ($66) {
      label = 13;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $68 = HEAP32[$43 >> 2] | 0;
    $69 = $68 + $point_2 | 0;
    $70 = HEAP8[$69] | 0;
    $71 = $70 & 255;
    $72 = $71 & $mask_0;
    $73 = ($72 | 0) == 0;
    if ($73) {
      $point_2_in = $point_2;
      label = 10;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $75 = $cur_touched_0_ph + 1 | 0;
    __iup_worker_interpolate($V, $75, $point_2_in, $cur_touched_0_ph, $point_2);
    $cur_touched_0_ph = $point_2;
    label = 9;
    break;
   case 13:
    $77 = ($cur_touched_0_ph | 0) == ($point_1 | 0);
    if ($77) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    __iup_worker_shift($V, $point_0, $end_point_0_ph, $cur_touched_0_ph);
    $point_3 = $point_2;
    label = 17;
    break;
   case 15:
    $80 = $cur_touched_0_ph + 1 | 0;
    $81 = $80 & 65535;
    __iup_worker_interpolate($V, $81, $end_point_0_ph, $cur_touched_0_ph, $point_1);
    $82 = ($point_1 | 0) == 0;
    if ($82) {
      $point_3 = $point_2;
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $84 = $point_1 - 1 | 0;
    __iup_worker_interpolate($V, $point_0, $84, $cur_touched_0_ph, $point_1);
    $point_3 = $point_2;
    label = 17;
    break;
   case 17:
    $85 = $contour_0 + 1 & 65535;
    $86 = HEAP16[$1 >> 1] | 0;
    $87 = $85 << 16 >> 16 < $86 << 16 >> 16;
    if ($87) {
      $contour_0 = $85;
      $point_0 = $point_3;
      label = 6;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    STACKTOP = __stackBase__;
    return;
  }
}
function _Ins_SHP($exc) {
  $exc = $exc | 0;
  var $zp = 0, $refp = 0, $dx = 0, $dy = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $9 = 0, $10 = 0, $_pr = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $32 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 48 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $zp = __stackBase__ | 0;
    $refp = __stackBase__ + 36 | 0;
    $dx = __stackBase__ + 40 | 0;
    $dy = __stackBase__ + 44 | 0;
    $1 = $exc + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $exc + 304 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) < ($4 | 0);
    if ($5) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $7 = $exc + 12 | 0;
    HEAP32[$7 >> 2] = 134;
    label = 12;
    break;
   case 3:
    $9 = _Compute_Point_Displacement($exc, $dx, $dy, $zp, $refp) | 0;
    $10 = $9 << 24 >> 24 == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 12;
      break;
    }
   case 4:
    $_pr = HEAP32[$3 >> 2] | 0;
    $11 = ($_pr | 0) > 0;
    if ($11) {
      label = 5;
      break;
    } else {
      label = 11;
      break;
    }
   case 5:
    $12 = $exc + 28 | 0;
    $13 = $exc + 24 | 0;
    $14 = $exc + 116 | 0;
    $15 = HEAP32[$dx >> 2] | 0;
    $16 = HEAP32[$dy >> 2] | 0;
    $17 = $exc + 561 | 0;
    label = 6;
    break;
   case 6:
    $19 = HEAP32[$12 >> 2] | 0;
    $20 = $19 - 1 | 0;
    HEAP32[$12 >> 2] = $20;
    $21 = HEAP32[$13 >> 2] | 0;
    $22 = $21 + ($20 << 2) | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $23 & 65535;
    $25 = HEAP16[$14 >> 1] | 0;
    $26 = $25 & 65535;
    $27 = $24 >>> 0 < $26 >>> 0;
    if ($27) {
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $29 = HEAP8[$17] | 0;
    $30 = $29 << 24 >> 24 == 0;
    if ($30) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $32 = $exc + 12 | 0;
    HEAP32[$32 >> 2] = 134;
    label = 12;
    break;
   case 9:
    $34 = $23 & 65535;
    _Move_Zp2_Point($exc, $34, $15, $16, 1);
    label = 10;
    break;
   case 10:
    $36 = HEAP32[$3 >> 2] | 0;
    $37 = $36 - 1 | 0;
    HEAP32[$3 >> 2] = $37;
    $38 = ($37 | 0) > 0;
    if ($38) {
      label = 6;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    HEAP32[$3 >> 2] = 1;
    $39 = $exc + 28 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $exc + 32 | 0;
    HEAP32[$41 >> 2] = $40;
    label = 12;
    break;
   case 12:
    STACKTOP = __stackBase__;
    return;
  }
}
function _Ins_SHC($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $zp = 0, $refp = 0, $dx = 0, $dy = 0, $1 = 0, $sext = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $first_point_0 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $_ = 0, $last_point_0 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $i_020 = 0, $51 = 0, $52 = 0, $53 = 0, $or_cond = 0, $56 = 0, $57 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 48 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $zp = __stackBase__ | 0;
    $refp = __stackBase__ + 36 | 0;
    $dx = __stackBase__ + 40 | 0;
    $dy = __stackBase__ + 44 | 0;
    $1 = HEAP32[$args >> 2] | 0;
    $sext = $1 << 16;
    $2 = $sext >> 16;
    $3 = $exc + 154 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 << 16 >> 16;
    $6 = $2 >>> 0 < $5 >>> 0;
    if ($6) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $exc + 561 | 0;
    $9 = HEAP8[$8] | 0;
    $10 = $9 << 24 >> 24 == 0;
    if ($10) {
      label = 14;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = $exc + 12 | 0;
    HEAP32[$12 >> 2] = 134;
    label = 14;
    break;
   case 4:
    $14 = _Compute_Point_Displacement($exc, $dx, $dy, $zp, $refp) | 0;
    $15 = $14 << 24 >> 24 == 0;
    if ($15) {
      label = 5;
      break;
    } else {
      label = 14;
      break;
    }
   case 5:
    $17 = ($2 | 0) == 0;
    if ($17) {
      $first_point_0 = 0;
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $19 = $2 - 1 | 0;
    $20 = $exc + 172 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $21 + ($19 << 1) | 0;
    $23 = HEAP16[$22 >> 1] | 0;
    $24 = $23 + 1 & 65535;
    $25 = $exc + 176 | 0;
    $26 = HEAP16[$25 >> 1] | 0;
    $27 = $24 - $26 & 65535;
    $first_point_0 = $27;
    label = 7;
    break;
   case 7:
    $29 = $exc + 172 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $30 + ($2 << 1) | 0;
    $32 = HEAP16[$31 >> 1] | 0;
    $33 = $exc + 176 | 0;
    $34 = HEAP16[$33 >> 1] | 0;
    $35 = $32 - $34 & 65535;
    $36 = $exc + 116 | 0;
    $37 = HEAP16[$36 >> 1] | 0;
    $38 = ($35 & 65535) < ($37 & 65535);
    if ($38) {
      $last_point_0 = $35;
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $40 = $37 << 16 >> 16 == 0;
    $41 = $37 - 1 & 65535;
    $_ = $40 ? 0 : $41;
    $last_point_0 = $_;
    label = 9;
    break;
   case 9:
    $43 = ($first_point_0 & 65535) > ($last_point_0 & 65535);
    if ($43) {
      label = 14;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $44 = $zp + 16 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = $exc + 124 | 0;
    $47 = HEAP16[$refp >> 1] | 0;
    $48 = HEAP32[$dx >> 2] | 0;
    $49 = HEAP32[$dy >> 2] | 0;
    $i_020 = $first_point_0;
    label = 11;
    break;
   case 11:
    $51 = HEAP32[$46 >> 2] | 0;
    $52 = ($45 | 0) == ($51 | 0);
    $53 = $47 << 16 >> 16 == $i_020 << 16 >> 16;
    $or_cond = $52 & $53;
    if ($or_cond) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    _Move_Zp2_Point($exc, $i_020, $48, $49, 1);
    label = 13;
    break;
   case 13:
    $56 = $i_020 + 1 & 65535;
    $57 = ($56 & 65535) > ($last_point_0 & 65535);
    if ($57) {
      label = 14;
      break;
    } else {
      $i_020 = $56;
      label = 11;
      break;
    }
   case 14:
    STACKTOP = __stackBase__;
    return;
  }
}
function _Ins_SHZ($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $zp = 0, $refp = 0, $dx = 0, $dy = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $_pr = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $last_point_0 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $i_019 = 0, $53 = 0, $54 = 0, $55 = 0, $or_cond = 0, $58 = 0, $59 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 48 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $zp = __stackBase__ | 0;
    $refp = __stackBase__ + 36 | 0;
    $dx = __stackBase__ + 40 | 0;
    $dy = __stackBase__ + 44 | 0;
    $1 = HEAP32[$args >> 2] | 0;
    $2 = $1 >>> 0 > 1;
    if ($2) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $4 = $exc + 561 | 0;
    $5 = HEAP8[$4] | 0;
    $6 = $5 << 24 >> 24 == 0;
    if ($6) {
      label = 18;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $8 = $exc + 12 | 0;
    HEAP32[$8 >> 2] = 134;
    label = 18;
    break;
   case 4:
    $10 = _Compute_Point_Displacement($exc, $dx, $dy, $zp, $refp) | 0;
    $11 = $10 << 24 >> 24 == 0;
    if ($11) {
      label = 5;
      break;
    } else {
      label = 18;
      break;
    }
   case 5:
    $13 = $exc + 348 | 0;
    $14 = HEAP16[$13 >> 1] | 0;
    $15 = $14 << 16 >> 16 == 0;
    if ($15) {
      label = 6;
      break;
    } else {
      $23 = $14;
      label = 9;
      break;
    }
   case 6:
    $17 = $exc + 116 | 0;
    $18 = HEAP16[$17 >> 1] | 0;
    $19 = $18 << 16 >> 16 == 0;
    if ($19) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $21 = $18 - 1 & 65535;
    $last_point_0 = $21;
    label = 14;
    break;
   case 8:
    $_pr = HEAP16[$13 >> 1] | 0;
    $23 = $_pr;
    label = 9;
    break;
   case 9:
    $24 = $23 << 16 >> 16 == 1;
    if ($24) {
      label = 10;
      break;
    } else {
      $last_point_0 = 0;
      label = 14;
      break;
    }
   case 10:
    $26 = $exc + 118 | 0;
    $27 = HEAP16[$26 >> 1] | 0;
    $28 = $27 << 16 >> 16 > 0;
    if ($28) {
      label = 11;
      break;
    } else {
      $last_point_0 = 0;
      label = 14;
      break;
    }
   case 11:
    $30 = $27 << 16 >> 16;
    $31 = $30 - 1 | 0;
    $32 = $exc + 136 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $33 + ($31 << 1) | 0;
    $35 = HEAP16[$34 >> 1] | 0;
    $36 = $exc + 116 | 0;
    $37 = HEAP16[$36 >> 1] | 0;
    $38 = ($35 & 65535) < ($37 & 65535);
    if ($38) {
      $last_point_0 = $35;
      label = 14;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $40 = $exc + 561 | 0;
    $41 = HEAP8[$40] | 0;
    $42 = $41 << 24 >> 24 == 0;
    if ($42) {
      label = 18;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $44 = $exc + 12 | 0;
    HEAP32[$44 >> 2] = 134;
    label = 18;
    break;
   case 14:
    $46 = $zp + 16 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $exc + 124 | 0;
    $49 = HEAP16[$refp >> 1] | 0;
    $50 = HEAP32[$dx >> 2] | 0;
    $51 = HEAP32[$dy >> 2] | 0;
    $i_019 = 0;
    label = 15;
    break;
   case 15:
    $53 = HEAP32[$48 >> 2] | 0;
    $54 = ($47 | 0) == ($53 | 0);
    $55 = $49 << 16 >> 16 == $i_019 << 16 >> 16;
    $or_cond = $54 & $55;
    if ($or_cond) {
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    _Move_Zp2_Point($exc, $i_019, $50, $51, 0);
    label = 17;
    break;
   case 17:
    $58 = $i_019 + 1 & 65535;
    $59 = ($58 & 65535) > ($last_point_0 & 65535);
    if ($59) {
      label = 18;
      break;
    } else {
      $i_019 = $58;
      label = 15;
      break;
    }
   case 18:
    STACKTOP = __stackBase__;
    return;
  }
}
function _Round_To_Double_Grid($exc, $distance, $compensation) {
  $exc = $exc | 0;
  $distance = $distance | 0;
  $compensation = $compensation | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $or_cond = 0, $7 = 0, $_10 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $_ = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($distance | 0) > -1;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = $distance + 16 | 0;
    $4 = $3 + $compensation | 0;
    $5 = ($distance | 0) != 0;
    $6 = ($4 | 0) > 0;
    $or_cond = $5 & $6;
    $7 = $4 & -32;
    $_10 = $or_cond ? $7 : 0;
    return $_10 | 0;
   case 3:
    $9 = 16 - $distance | 0;
    $10 = $9 + $compensation | 0;
    $11 = $10 & -32;
    $12 = -$11 | 0;
    $13 = ($11 | 0) < 0;
    $_ = $13 ? 0 : $12;
    return $_ | 0;
  }
  return 0;
}
function _Ins_NPUSHB($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $K_014 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 360 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 1 | 0;
    $4 = $exc + 356 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 + $3 | 0;
    $7 = HEAP8[$6] | 0;
    $8 = $7 & 255;
    $9 = $exc + 20 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10 + 1 | 0;
    $12 = $exc + 16 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $11 - $13 | 0;
    $15 = $8 >>> 0 < $14 >>> 0;
    if ($15) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $16 = $7 << 24 >> 24 == 0;
    if ($16) {
      label = 5;
      break;
    } else {
      $K_014 = 1;
      $19 = 1;
      label = 4;
      break;
    }
   case 3:
    $18 = $exc + 12 | 0;
    HEAP32[$18 >> 2] = 130;
    label = 6;
    break;
   case 4:
    $20 = HEAP32[$1 >> 2] | 0;
    $21 = $19 + 1 | 0;
    $22 = $21 + $20 | 0;
    $23 = HEAP32[$4 >> 2] | 0;
    $24 = $23 + $22 | 0;
    $25 = HEAP8[$24] | 0;
    $26 = $25 & 255;
    $27 = $19 - 1 | 0;
    $28 = $args + ($27 << 2) | 0;
    HEAP32[$28 >> 2] = $26;
    $29 = $K_014 + 1 & 65535;
    $30 = $29 & 65535;
    $31 = $30 >>> 0 > $8 >>> 0;
    if ($31) {
      label = 5;
      break;
    } else {
      $K_014 = $29;
      $19 = $30;
      label = 4;
      break;
    }
   case 5:
    $32 = $exc + 32 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $33 + $8 | 0;
    HEAP32[$32 >> 2] = $34;
    label = 6;
    break;
   case 6:
    return;
  }
}
function _Ins_SHPIX($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $_pr = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $38 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $exc + 304 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 1 | 0;
    $6 = ($2 | 0) < ($5 | 0);
    if ($6) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $8 = $exc + 12 | 0;
    HEAP32[$8 >> 2] = 134;
    label = 11;
    break;
   case 3:
    $10 = HEAP32[$args >> 2] | 0;
    $11 = $exc + 298 | 0;
    $12 = HEAP16[$11 >> 1] | 0;
    $13 = $12 << 16 >> 16;
    $14 = _TT_MulFix14($10, $13) | 0;
    $15 = $exc + 300 | 0;
    $16 = HEAP16[$15 >> 1] | 0;
    $17 = $16 << 16 >> 16;
    $18 = _TT_MulFix14($10, $17) | 0;
    $_pr = HEAP32[$3 >> 2] | 0;
    $19 = ($_pr | 0) > 0;
    if ($19) {
      label = 4;
      break;
    } else {
      label = 10;
      break;
    }
   case 4:
    $20 = $exc + 28 | 0;
    $21 = $exc + 24 | 0;
    $22 = $exc + 116 | 0;
    $23 = $exc + 561 | 0;
    label = 5;
    break;
   case 5:
    $25 = HEAP32[$20 >> 2] | 0;
    $26 = $25 - 1 | 0;
    HEAP32[$20 >> 2] = $26;
    $27 = HEAP32[$21 >> 2] | 0;
    $28 = $27 + ($26 << 2) | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $29 & 65535;
    $31 = HEAP16[$22 >> 1] | 0;
    $32 = $31 & 65535;
    $33 = $30 >>> 0 < $32 >>> 0;
    if ($33) {
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $35 = HEAP8[$23] | 0;
    $36 = $35 << 24 >> 24 == 0;
    if ($36) {
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $38 = $exc + 12 | 0;
    HEAP32[$38 >> 2] = 134;
    label = 11;
    break;
   case 8:
    $40 = $29 & 65535;
    _Move_Zp2_Point($exc, $40, $14, $18, 1);
    label = 9;
    break;
   case 9:
    $42 = HEAP32[$3 >> 2] | 0;
    $43 = $42 - 1 | 0;
    HEAP32[$3 >> 2] = $43;
    $44 = ($43 | 0) > 0;
    if ($44) {
      label = 5;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    HEAP32[$3 >> 2] = 1;
    $45 = $exc + 28 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $exc + 32 | 0;
    HEAP32[$47 >> 2] = $46;
    label = 11;
    break;
   case 11:
    return;
  }
}
function _Ins_IP($exc) {
  $exc = $exc | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $35 = 0, $36 = 0, $_pn_in = 0, $_pn = 0, $orus_base_0 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $old_range_0 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $cur_range_0_ph = 0, $old_range_1_ph = 0, $_pr = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $124 = 0, $125 = 0, $127 = 0, $129 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $org_dist_0 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $brmerge = 0, $_mux = 0, $166 = 0, $new_dist_0 = 0, $168 = 0, $169 = 0, $170 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $exc + 304 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) < ($4 | 0);
    if ($5) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $7 = $exc + 12 | 0;
    HEAP32[$7 >> 2] = 134;
    label = 27;
    break;
   case 3:
    $9 = $exc + 344 | 0;
    $10 = HEAP16[$9 >> 1] | 0;
    $11 = $10 << 16 >> 16 == 0;
    if ($11) {
      $21 = 1;
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $13 = $exc + 346 | 0;
    $14 = HEAP16[$13 >> 1] | 0;
    $15 = $14 << 16 >> 16 == 0;
    if ($15) {
      $21 = 1;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = $exc + 348 | 0;
    $18 = HEAP16[$17 >> 1] | 0;
    $19 = $18 << 16 >> 16 == 0;
    $21 = $19;
    label = 6;
    break;
   case 6:
    $22 = $exc + 286 | 0;
    $23 = HEAP16[$22 >> 1] | 0;
    $24 = $23 & 65535;
    $25 = $exc + 44 | 0;
    $26 = HEAP16[$25 >> 1] | 0;
    $27 = ($23 & 65535) < ($26 & 65535);
    if ($27) {
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $29 = $exc + 561 | 0;
    $30 = HEAP8[$29] | 0;
    $31 = $30 << 24 >> 24 == 0;
    if ($31) {
      label = 27;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $33 = $exc + 12 | 0;
    HEAP32[$33 >> 2] = 134;
    label = 27;
    break;
   case 9:
    $35 = $exc + 48 | 0;
    $36 = $exc + 56 | 0;
    $_pn_in = $21 ? $35 : $36;
    $_pn = HEAP32[$_pn_in >> 2] | 0;
    $orus_base_0 = $_pn + ($24 << 3) | 0;
    $37 = $exc + 52 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $38 + ($24 << 3) | 0;
    $40 = $exc + 288 | 0;
    $41 = HEAP16[$40 >> 1] | 0;
    $42 = $41 & 65535;
    $43 = $exc + 80 | 0;
    $44 = HEAP16[$43 >> 1] | 0;
    $45 = ($41 & 65535) < ($44 & 65535);
    if ($45) {
      label = 10;
      break;
    } else {
      $old_range_1_ph = 0;
      $cur_range_0_ph = 0;
      label = 14;
      break;
    }
   case 10:
    $47 = $exc + 576 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    if ($21) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $50 = $exc + 84 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = $51 + ($42 << 3) | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $orus_base_0 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = $53 - $55 | 0;
    $57 = $51 + ($42 << 3) + 4 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = $_pn + ($24 << 3) + 4 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = $58 - $60 | 0;
    $62 = FUNCTION_TABLE_iiii[$48 & 1023]($exc, $56, $61) | 0;
    $old_range_0 = $62;
    label = 13;
    break;
   case 12:
    $64 = $exc + 92 | 0;
    $65 = HEAP32[$64 >> 2] | 0;
    $66 = $65 + ($42 << 3) | 0;
    $67 = HEAP32[$66 >> 2] | 0;
    $68 = $orus_base_0 | 0;
    $69 = HEAP32[$68 >> 2] | 0;
    $70 = $67 - $69 | 0;
    $71 = $65 + ($42 << 3) + 4 | 0;
    $72 = HEAP32[$71 >> 2] | 0;
    $73 = $_pn + ($24 << 3) + 4 | 0;
    $74 = HEAP32[$73 >> 2] | 0;
    $75 = $72 - $74 | 0;
    $76 = FUNCTION_TABLE_iiii[$48 & 1023]($exc, $70, $75) | 0;
    $old_range_0 = $76;
    label = 13;
    break;
   case 13:
    $78 = $exc + 572 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = HEAP16[$40 >> 1] | 0;
    $81 = $80 & 65535;
    $82 = $exc + 88 | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = $83 + ($81 << 3) | 0;
    $85 = HEAP32[$84 >> 2] | 0;
    $86 = $39 | 0;
    $87 = HEAP32[$86 >> 2] | 0;
    $88 = $85 - $87 | 0;
    $89 = $83 + ($81 << 3) + 4 | 0;
    $90 = HEAP32[$89 >> 2] | 0;
    $91 = $38 + ($24 << 3) + 4 | 0;
    $92 = HEAP32[$91 >> 2] | 0;
    $93 = $90 - $92 | 0;
    $94 = FUNCTION_TABLE_iiii[$79 & 1023]($exc, $88, $93) | 0;
    $old_range_1_ph = $old_range_0;
    $cur_range_0_ph = $94;
    label = 14;
    break;
   case 14:
    $_pr = HEAP32[$3 >> 2] | 0;
    $95 = ($_pr | 0) > 0;
    if ($95) {
      label = 15;
      break;
    } else {
      label = 26;
      break;
    }
   case 15:
    $96 = $exc + 28 | 0;
    $97 = $exc + 24 | 0;
    $98 = $exc + 108 | 0;
    $99 = $exc + 116 | 0;
    $100 = $exc + 576 | 0;
    $101 = $exc + 120 | 0;
    $102 = $orus_base_0 | 0;
    $103 = $_pn + ($24 << 3) + 4 | 0;
    $104 = $exc + 572 | 0;
    $105 = $exc + 124 | 0;
    $106 = $39 | 0;
    $107 = $38 + ($24 << 3) + 4 | 0;
    $108 = $exc + 584 | 0;
    $109 = ($old_range_1_ph | 0) == 0;
    $110 = $exc + 128 | 0;
    $111 = $orus_base_0 | 0;
    $112 = $_pn + ($24 << 3) + 4 | 0;
    $113 = $exc + 561 | 0;
    label = 16;
    break;
   case 16:
    $115 = HEAP32[$96 >> 2] | 0;
    $116 = $115 - 1 | 0;
    HEAP32[$96 >> 2] = $116;
    $117 = HEAP32[$97 >> 2] | 0;
    $118 = $117 + ($116 << 2) | 0;
    $119 = HEAP32[$118 >> 2] | 0;
    $120 = HEAP16[$99 >> 1] | 0;
    $121 = $120 & 65535;
    $122 = $119 >>> 0 < $121 >>> 0;
    if ($122) {
      label = 19;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $124 = HEAP8[$113] | 0;
    $125 = $124 << 24 >> 24 == 0;
    if ($125) {
      label = 25;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $127 = $exc + 12 | 0;
    HEAP32[$127 >> 2] = 134;
    label = 27;
    break;
   case 19:
    $129 = HEAP32[$100 >> 2] | 0;
    if ($21) {
      label = 20;
      break;
    } else {
      label = 21;
      break;
    }
   case 20:
    $131 = HEAP32[$101 >> 2] | 0;
    $132 = $131 + ($119 << 3) | 0;
    $133 = HEAP32[$132 >> 2] | 0;
    $134 = HEAP32[$102 >> 2] | 0;
    $135 = $133 - $134 | 0;
    $136 = $131 + ($119 << 3) + 4 | 0;
    $137 = HEAP32[$136 >> 2] | 0;
    $138 = HEAP32[$103 >> 2] | 0;
    $139 = $137 - $138 | 0;
    $140 = FUNCTION_TABLE_iiii[$129 & 1023]($exc, $135, $139) | 0;
    $org_dist_0 = $140;
    label = 22;
    break;
   case 21:
    $142 = HEAP32[$110 >> 2] | 0;
    $143 = $142 + ($119 << 3) | 0;
    $144 = HEAP32[$143 >> 2] | 0;
    $145 = HEAP32[$111 >> 2] | 0;
    $146 = $144 - $145 | 0;
    $147 = $142 + ($119 << 3) + 4 | 0;
    $148 = HEAP32[$147 >> 2] | 0;
    $149 = HEAP32[$112 >> 2] | 0;
    $150 = $148 - $149 | 0;
    $151 = FUNCTION_TABLE_iiii[$129 & 1023]($exc, $146, $150) | 0;
    $org_dist_0 = $151;
    label = 22;
    break;
   case 22:
    $153 = HEAP32[$104 >> 2] | 0;
    $154 = HEAP32[$105 >> 2] | 0;
    $155 = $154 + ($119 << 3) | 0;
    $156 = HEAP32[$155 >> 2] | 0;
    $157 = HEAP32[$106 >> 2] | 0;
    $158 = $156 - $157 | 0;
    $159 = $154 + ($119 << 3) + 4 | 0;
    $160 = HEAP32[$159 >> 2] | 0;
    $161 = HEAP32[$107 >> 2] | 0;
    $162 = $160 - $161 | 0;
    $163 = FUNCTION_TABLE_iiii[$153 & 1023]($exc, $158, $162) | 0;
    $164 = ($org_dist_0 | 0) == 0;
    $brmerge = $164 | $109;
    $_mux = $164 ? 0 : $163;
    if ($brmerge) {
      $new_dist_0 = $_mux;
      label = 24;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $166 = _FT_MulDiv($org_dist_0, $cur_range_0_ph, $old_range_1_ph) | 0;
    $new_dist_0 = $166;
    label = 24;
    break;
   case 24:
    $168 = HEAP32[$108 >> 2] | 0;
    $169 = $119 & 65535;
    $170 = $new_dist_0 - $163 | 0;
    FUNCTION_TABLE_viiii[$168 & 1023]($exc, $98, $169, $170);
    label = 25;
    break;
   case 25:
    $172 = HEAP32[$3 >> 2] | 0;
    $173 = $172 - 1 | 0;
    HEAP32[$3 >> 2] = $173;
    $174 = ($173 | 0) > 0;
    if ($174) {
      label = 16;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    HEAP32[$3 >> 2] = 1;
    $175 = $exc + 28 | 0;
    $176 = HEAP32[$175 >> 2] | 0;
    $177 = $exc + 32 | 0;
    HEAP32[$177 >> 2] = $176;
    label = 27;
    break;
   case 27:
    return;
  }
}
function _Ins_MSIRP($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $ld$0$0 = 0, $35$0 = 0, $ld$1$1 = 0, $35$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $ld$4$0 = 0, $47$0 = 0, $ld$5$1 = 0, $47$1 = 0, $st$6$0 = 0, $st$7$1 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = $1 & 65535;
    $3 = $1 & 65535;
    $4 = $exc + 72 | 0;
    $5 = $exc + 80 | 0;
    $6 = HEAP16[$5 >> 1] | 0;
    $7 = $6 & 65535;
    $8 = $3 >>> 0 < $7 >>> 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $10 = $exc + 284 | 0;
    $11 = HEAP16[$10 >> 1] | 0;
    $12 = $11 & 65535;
    $13 = $exc + 44 | 0;
    $14 = HEAP16[$13 >> 1] | 0;
    $15 = ($11 & 65535) < ($14 & 65535);
    if ($15) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $17 = $exc + 561 | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $18 << 24 >> 24 == 0;
    if ($19) {
      label = 9;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $21 = $exc + 12 | 0;
    HEAP32[$21 >> 2] = 134;
    label = 9;
    break;
   case 5:
    $23 = $exc + 346 | 0;
    $24 = HEAP16[$23 >> 1] | 0;
    $25 = $24 << 16 >> 16 == 0;
    if ($25) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $27 = $exc + 84 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $28 + ($3 << 3) | 0;
    $30 = $exc + 48 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $31 + ($12 << 3) | 0;
    $33 = $32;
    $34 = $29;
    $ld$0$0 = $33 | 0;
    $35$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $33 + 4 | 0;
    $35$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $34 | 0;
    HEAP32[$st$2$0 >> 2] = $35$0;
    $st$3$1 = $34 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $35$1;
    $36 = $exc + 588 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $args + 4 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    FUNCTION_TABLE_viiii[$37 & 1023]($exc, $4, $2, $39);
    $40 = $exc + 88 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = $41 + ($3 << 3) | 0;
    $43 = HEAP32[$27 >> 2] | 0;
    $44 = $43 + ($3 << 3) | 0;
    $45 = $44;
    $46 = $42;
    $ld$4$0 = $45 | 0;
    $47$0 = HEAP32[$ld$4$0 >> 2] | 0;
    $ld$5$1 = $45 + 4 | 0;
    $47$1 = HEAP32[$ld$5$1 >> 2] | 0;
    $st$6$0 = $46 | 0;
    HEAP32[$st$6$0 >> 2] = $47$0;
    $st$7$1 = $46 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $47$1;
    label = 7;
    break;
   case 7:
    $49 = $exc + 572 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $exc + 88 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = $52 + ($3 << 3) | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = $exc + 52 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = HEAP16[$10 >> 1] | 0;
    $58 = $57 & 65535;
    $59 = $56 + ($58 << 3) | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = $54 - $60 | 0;
    $62 = $52 + ($3 << 3) + 4 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = $56 + ($58 << 3) + 4 | 0;
    $65 = HEAP32[$64 >> 2] | 0;
    $66 = $63 - $65 | 0;
    $67 = FUNCTION_TABLE_iiii[$50 & 1023]($exc, $61, $66) | 0;
    $68 = $exc + 584 | 0;
    $69 = HEAP32[$68 >> 2] | 0;
    $70 = $args + 4 | 0;
    $71 = HEAP32[$70 >> 2] | 0;
    $72 = $71 - $67 | 0;
    FUNCTION_TABLE_viiii[$69 & 1023]($exc, $4, $2, $72);
    $73 = HEAP16[$10 >> 1] | 0;
    $74 = $exc + 286 | 0;
    HEAP16[$74 >> 1] = $73;
    $75 = $exc + 288 | 0;
    HEAP16[$75 >> 1] = $2;
    $76 = $exc + 368 | 0;
    $77 = HEAP8[$76] | 0;
    $78 = $77 & 1;
    $79 = $78 << 24 >> 24 == 0;
    if ($79) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    HEAP16[$10 >> 1] = $2;
    label = 9;
    break;
   case 9:
    return;
  }
}
function _Ins_ALIGNRP($exc) {
  $exc = $exc | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $_pr = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $exc + 304 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) < ($4 | 0);
    if ($5) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $exc + 284 | 0;
    $8 = HEAP16[$7 >> 1] | 0;
    $9 = $exc + 44 | 0;
    $10 = HEAP16[$9 >> 1] | 0;
    $11 = ($8 & 65535) < ($10 & 65535);
    if ($11) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $13 = $exc + 561 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 << 24 >> 24 == 0;
    if ($15) {
      label = 13;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $17 = $exc + 12 | 0;
    HEAP32[$17 >> 2] = 134;
    label = 13;
    break;
   case 5:
    $_pr = HEAP32[$3 >> 2] | 0;
    $18 = ($_pr | 0) > 0;
    if ($18) {
      label = 6;
      break;
    } else {
      label = 12;
      break;
    }
   case 6:
    $19 = $exc + 28 | 0;
    $20 = $exc + 24 | 0;
    $21 = $exc + 80 | 0;
    $22 = $exc + 72 | 0;
    $23 = $exc + 572 | 0;
    $24 = $exc + 88 | 0;
    $25 = $exc + 52 | 0;
    $26 = $exc + 584 | 0;
    $27 = $exc + 561 | 0;
    label = 7;
    break;
   case 7:
    $29 = HEAP32[$19 >> 2] | 0;
    $30 = $29 - 1 | 0;
    HEAP32[$19 >> 2] = $30;
    $31 = HEAP32[$20 >> 2] | 0;
    $32 = $31 + ($30 << 2) | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $33 & 65535;
    $35 = HEAP16[$21 >> 1] | 0;
    $36 = $35 & 65535;
    $37 = $34 >>> 0 < $36 >>> 0;
    if ($37) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $39 = HEAP8[$27] | 0;
    $40 = $39 << 24 >> 24 == 0;
    if ($40) {
      label = 11;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $42 = $exc + 12 | 0;
    HEAP32[$42 >> 2] = 134;
    label = 13;
    break;
   case 10:
    $44 = $33 & 65535;
    $45 = HEAP32[$23 >> 2] | 0;
    $46 = HEAP32[$24 >> 2] | 0;
    $47 = $46 + ($34 << 3) | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = HEAP32[$25 >> 2] | 0;
    $50 = HEAP16[$7 >> 1] | 0;
    $51 = $50 & 65535;
    $52 = $49 + ($51 << 3) | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $48 - $53 | 0;
    $55 = $46 + ($34 << 3) + 4 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = $49 + ($51 << 3) + 4 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = $56 - $58 | 0;
    $60 = FUNCTION_TABLE_iiii[$45 & 1023]($exc, $54, $59) | 0;
    $61 = HEAP32[$26 >> 2] | 0;
    $62 = -$60 | 0;
    FUNCTION_TABLE_viiii[$61 & 1023]($exc, $22, $44, $62);
    label = 11;
    break;
   case 11:
    $64 = HEAP32[$3 >> 2] | 0;
    $65 = $64 - 1 | 0;
    HEAP32[$3 >> 2] = $65;
    $66 = ($65 | 0) > 0;
    if ($66) {
      label = 7;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    HEAP32[$3 >> 2] = 1;
    $67 = $exc + 28 | 0;
    $68 = HEAP32[$67 >> 2] | 0;
    $69 = $exc + 32 | 0;
    HEAP32[$69 >> 2] = $68;
    label = 13;
    break;
   case 13:
    return;
  }
}
function _Ins_MIAP($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $ld$0$0 = 0, $49$0 = 0, $ld$1$1 = 0, $49$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $_ = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $distance_1 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $args + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = HEAP32[$args >> 2] | 0;
    $4 = $3 & 65535;
    $5 = $3 & 65535;
    $6 = $exc + 36 | 0;
    $7 = $exc + 44 | 0;
    $8 = HEAP16[$7 >> 1] | 0;
    $9 = $8 & 65535;
    $10 = $5 >>> 0 < $9 >>> 0;
    if ($10) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $12 = $exc + 380 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $2 >>> 0 < $13 >>> 0;
    if ($14) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $16 = $exc + 561 | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 << 24 >> 24 == 0;
    if ($18) {
      label = 10;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $20 = $exc + 12 | 0;
    HEAP32[$20 >> 2] = 134;
    label = 10;
    break;
   case 5:
    $22 = $exc + 592 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = FUNCTION_TABLE_iii[$23 & 1023]($exc, $2) | 0;
    $25 = $exc + 344 | 0;
    $26 = HEAP16[$25 >> 1] | 0;
    $27 = $26 << 16 >> 16 == 0;
    if ($27) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $29 = $exc + 298 | 0;
    $30 = HEAP16[$29 >> 1] | 0;
    $31 = $30 << 16 >> 16;
    $32 = _TT_MulFix14($24, $31) | 0;
    $33 = $exc + 48 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $34 + ($5 << 3) | 0;
    HEAP32[$35 >> 2] = $32;
    $36 = $exc + 300 | 0;
    $37 = HEAP16[$36 >> 1] | 0;
    $38 = $37 << 16 >> 16;
    $39 = _TT_MulFix14($24, $38) | 0;
    $40 = HEAP32[$33 >> 2] | 0;
    $41 = $40 + ($5 << 3) + 4 | 0;
    HEAP32[$41 >> 2] = $39;
    $42 = $exc + 52 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $43 + ($5 << 3) | 0;
    $45 = HEAP32[$33 >> 2] | 0;
    $46 = $45 + ($5 << 3) | 0;
    $47 = $46;
    $48 = $44;
    $ld$0$0 = $47 | 0;
    $49$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $47 + 4 | 0;
    $49$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $48 | 0;
    HEAP32[$st$2$0 >> 2] = $49$0;
    $st$3$1 = $48 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $49$1;
    label = 7;
    break;
   case 7:
    $51 = $exc + 572 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = $exc + 52 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = $54 + ($5 << 3) | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = $54 + ($5 << 3) + 4 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = FUNCTION_TABLE_iiii[$52 & 1023]($exc, $56, $58) | 0;
    $60 = $exc + 368 | 0;
    $61 = HEAP8[$60] | 0;
    $62 = $61 & 1;
    $63 = $62 << 24 >> 24 == 0;
    if ($63) {
      $distance_1 = $24;
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $65 = $24 - $59 | 0;
    $66 = ($65 | 0) < 0;
    $67 = -$65 | 0;
    $68 = $66 ? $67 : $65;
    $69 = $exc + 320 | 0;
    $70 = HEAP32[$69 >> 2] | 0;
    $71 = ($68 | 0) > ($70 | 0);
    $_ = $71 ? $59 : $24;
    $72 = $exc + 568 | 0;
    $73 = HEAP32[$72 >> 2] | 0;
    $74 = $exc + 264 | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    $76 = FUNCTION_TABLE_iiii[$73 & 1023]($exc, $_, $75) | 0;
    $distance_1 = $76;
    label = 9;
    break;
   case 9:
    $78 = $exc + 584 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = $distance_1 - $59 | 0;
    FUNCTION_TABLE_viiii[$79 & 1023]($exc, $6, $4, $80);
    $81 = $exc + 284 | 0;
    HEAP16[$81 >> 1] = $4;
    $82 = $exc + 286 | 0;
    HEAP16[$82 >> 1] = $4;
    label = 10;
    break;
   case 10:
    return;
  }
}
function _Ins_NPUSHW($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $K_012 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 360 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 1 | 0;
    $4 = $exc + 356 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 + $3 | 0;
    $7 = HEAP8[$6] | 0;
    $8 = $7 & 255;
    $9 = $exc + 20 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10 + 1 | 0;
    $12 = $exc + 16 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $11 - $13 | 0;
    $15 = $8 >>> 0 < $14 >>> 0;
    if ($15) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $17 = $exc + 12 | 0;
    HEAP32[$17 >> 2] = 130;
    label = 6;
    break;
   case 3:
    $19 = $2 + 2 | 0;
    HEAP32[$1 >> 2] = $19;
    $20 = $7 << 24 >> 24 == 0;
    if ($20) {
      label = 5;
      break;
    } else {
      $K_012 = 0;
      $21 = 0;
      label = 4;
      break;
    }
   case 4:
    $22 = _GetShortIns($exc) | 0;
    $23 = $22 << 16 >> 16;
    $24 = $args + ($21 << 2) | 0;
    HEAP32[$24 >> 2] = $23;
    $25 = $K_012 + 1 & 65535;
    $26 = $25 & 65535;
    $27 = $26 >>> 0 < $8 >>> 0;
    if ($27) {
      $K_012 = $25;
      $21 = $26;
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $28 = $exc + 376 | 0;
    HEAP8[$28] = 0;
    $29 = $exc + 32 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $30 + $8 | 0;
    HEAP32[$29 >> 2] = $31;
    label = 6;
    break;
   case 6:
    return;
  }
}
function _Ins_GC($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $R_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = $exc + 116 | 0;
    $3 = HEAP16[$2 >> 1] | 0;
    $4 = $3 & 65535;
    $5 = $1 >>> 0 < $4 >>> 0;
    if ($5) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $exc + 561 | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 << 24 >> 24 == 0;
    if ($9) {
      $R_0 = 0;
      label = 7;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = $exc + 12 | 0;
    HEAP32[$11 >> 2] = 134;
    label = 8;
    break;
   case 4:
    $13 = $exc + 368 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 & 1;
    $16 = $15 << 24 >> 24 == 0;
    if ($16) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $18 = $exc + 576 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $exc + 120 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $21 + ($1 << 3) | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $21 + ($1 << 3) + 4 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = FUNCTION_TABLE_iiii[$19 & 1023]($exc, $23, $25) | 0;
    $R_0 = $26;
    label = 7;
    break;
   case 6:
    $28 = $exc + 572 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $exc + 124 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $31 + ($1 << 3) | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $31 + ($1 << 3) + 4 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = FUNCTION_TABLE_iiii[$29 & 1023]($exc, $33, $35) | 0;
    $R_0 = $36;
    label = 7;
    break;
   case 7:
    HEAP32[$args >> 2] = $R_0;
    label = 8;
    break;
   case 8:
    return;
  }
}
function _Ins_SCFS($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $ld$0$0 = 0, $41$0 = 0, $ld$1$1 = 0, $41$1 = 0, $st$2$0 = 0, $st$3$1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = $1 & 65535;
    $3 = $exc + 116 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 & 65535;
    $6 = $2 >>> 0 < $5 >>> 0;
    if ($6) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $exc + 561 | 0;
    $9 = HEAP8[$8] | 0;
    $10 = $9 << 24 >> 24 == 0;
    if ($10) {
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = $exc + 12 | 0;
    HEAP32[$12 >> 2] = 134;
    label = 6;
    break;
   case 4:
    $14 = $exc + 108 | 0;
    $15 = $1 & 65535;
    $16 = $exc + 572 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $exc + 124 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $19 + ($2 << 3) | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $19 + ($2 << 3) + 4 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = FUNCTION_TABLE_iiii[$17 & 1023]($exc, $21, $23) | 0;
    $25 = $exc + 584 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $args + 4 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $28 - $24 | 0;
    FUNCTION_TABLE_viiii[$26 & 1023]($exc, $14, $15, $29);
    $30 = $exc + 348 | 0;
    $31 = HEAP16[$30 >> 1] | 0;
    $32 = $31 << 16 >> 16 == 0;
    if ($32) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $34 = $exc + 120 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $35 + ($2 << 3) | 0;
    $37 = HEAP32[$18 >> 2] | 0;
    $38 = $37 + ($2 << 3) | 0;
    $39 = $38;
    $40 = $36;
    $ld$0$0 = $39 | 0;
    $41$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $39 + 4 | 0;
    $41$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $40 | 0;
    HEAP32[$st$2$0 >> 2] = $41$0;
    $st$3$1 = $40 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $41$1;
    label = 6;
    break;
   case 6:
    return;
  }
}
function _Round_None($exc, $distance, $compensation) {
  $exc = $exc | 0;
  $distance = $distance | 0;
  $compensation = $compensation | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $or_cond = 0, $_7 = 0, $7 = 0, $8 = 0, $_ = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($distance | 0) > -1;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = $compensation + $distance | 0;
    $4 = ($distance | 0) != 0;
    $5 = ($3 | 0) < 0;
    $or_cond = $4 & $5;
    $_7 = $or_cond ? 0 : $3;
    return $_7 | 0;
   case 3:
    $7 = $distance - $compensation | 0;
    $8 = ($7 | 0) > 0;
    $_ = $8 ? 0 : $7;
    return $_ | 0;
  }
  return 0;
}
function _Round_Up_To_Grid($exc, $distance, $compensation) {
  $exc = $exc | 0;
  $distance = $distance | 0;
  $compensation = $compensation | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $or_cond = 0, $7 = 0, $_10 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $_ = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($distance | 0) > -1;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = $distance + 63 | 0;
    $4 = $3 + $compensation | 0;
    $5 = ($distance | 0) != 0;
    $6 = ($4 | 0) > 0;
    $or_cond = $5 & $6;
    $7 = $4 & -64;
    $_10 = $or_cond ? $7 : 0;
    return $_10 | 0;
   case 3:
    $9 = 63 - $distance | 0;
    $10 = $9 + $compensation | 0;
    $11 = $10 & -64;
    $12 = -$11 | 0;
    $13 = ($11 | 0) < 0;
    $_ = $13 ? 0 : $12;
    return $_ | 0;
  }
  return 0;
}
function _Round_Down_To_Grid($exc, $distance, $compensation) {
  $exc = $exc | 0;
  $distance = $distance | 0;
  $compensation = $compensation | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $or_cond = 0, $6 = 0, $_10 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $_ = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($distance | 0) > -1;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = $compensation + $distance | 0;
    $4 = ($distance | 0) != 0;
    $5 = ($3 | 0) > 0;
    $or_cond = $4 & $5;
    $6 = $3 & -64;
    $_10 = $or_cond ? $6 : 0;
    return $_10 | 0;
   case 3:
    $8 = $compensation - $distance | 0;
    $9 = $8 & -64;
    $10 = -$9 | 0;
    $11 = ($9 | 0) < 0;
    $_ = $11 ? 0 : $10;
    return $_ | 0;
  }
  return 0;
}
function _SetSuperRound($exc, $GridPeriod, $selector) {
  $exc = $exc | 0;
  $GridPeriod = $GridPeriod | 0;
  $selector = $selector | 0;
  var $1 = 0, $3 = 0, $4 = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $13 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $selector & 192;
    if (($1 | 0) == 0) {
      label = 2;
      break;
    } else if (($1 | 0) == 64) {
      label = 3;
      break;
    } else if (($1 | 0) == 128) {
      label = 4;
      break;
    } else if (($1 | 0) == 192) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $3 = ($GridPeriod | 0) / 2 & -1;
    $4 = $exc + 476 | 0;
    HEAP32[$4 >> 2] = $3;
    label = 6;
    break;
   case 3:
    $6 = $exc + 476 | 0;
    HEAP32[$6 >> 2] = $GridPeriod;
    label = 6;
    break;
   case 4:
    $8 = $GridPeriod << 1;
    $9 = $exc + 476 | 0;
    HEAP32[$9 >> 2] = $8;
    label = 6;
    break;
   case 5:
    $11 = $exc + 476 | 0;
    HEAP32[$11 >> 2] = $GridPeriod;
    label = 6;
    break;
   case 6:
    $13 = $selector & 48;
    if (($13 | 0) == 0) {
      label = 7;
      break;
    } else if (($13 | 0) == 16) {
      label = 8;
      break;
    } else if (($13 | 0) == 32) {
      label = 9;
      break;
    } else if (($13 | 0) == 48) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 7:
    $15 = $exc + 480 | 0;
    HEAP32[$15 >> 2] = 0;
    label = 11;
    break;
   case 8:
    $17 = $exc + 476 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = ($18 | 0) / 4 & -1;
    $20 = $exc + 480 | 0;
    HEAP32[$20 >> 2] = $19;
    label = 11;
    break;
   case 9:
    $22 = $exc + 476 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = ($23 | 0) / 2 & -1;
    $25 = $exc + 480 | 0;
    HEAP32[$25 >> 2] = $24;
    label = 11;
    break;
   case 10:
    $27 = $exc + 476 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $28 * 3 & -1;
    $30 = ($29 | 0) / 4 & -1;
    $31 = $exc + 480 | 0;
    HEAP32[$31 >> 2] = $30;
    label = 11;
    break;
   case 11:
    $33 = $selector & 15;
    $34 = ($33 | 0) == 0;
    if ($34) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $36 = $exc + 476 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $37 - 1 | 0;
    $39 = $exc + 484 | 0;
    HEAP32[$39 >> 2] = $38;
    label = 14;
    break;
   case 13:
    $41 = $33 - 4 | 0;
    $42 = $exc + 476 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = Math_imul($43, $41);
    $45 = ($44 | 0) / 8 & -1;
    $46 = $exc + 484 | 0;
    HEAP32[$46 >> 2] = $45;
    label = 14;
    break;
   case 14:
    $48 = $exc + 476 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = ($49 | 0) / 256 & -1;
    HEAP32[$48 >> 2] = $50;
    $51 = $exc + 480 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = ($52 | 0) / 256 & -1;
    HEAP32[$51 >> 2] = $53;
    $54 = $exc + 484 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = ($55 | 0) / 256 & -1;
    HEAP32[$54 >> 2] = $56;
    return;
  }
}
function _Round_Super($exc, $distance, $compensation) {
  $exc = $exc | 0;
  $distance = $distance | 0;
  $compensation = $compensation | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $or_cond = 0, $val_0 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $_ = 0, $31 = 0, $val_2 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($distance | 0) > -1;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = $exc + 480 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $exc + 484 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $compensation + $distance | 0;
    $8 = $7 - $4 | 0;
    $9 = $8 + $6 | 0;
    $10 = $exc + 476 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = -$11 | 0;
    $13 = $9 & $12;
    $14 = ($distance | 0) != 0;
    $15 = ($13 | 0) < 0;
    $or_cond = $14 & $15;
    $val_0 = $or_cond ? 0 : $13;
    $16 = $val_0 + $4 | 0;
    $val_2 = $16;
    label = 4;
    break;
   case 3:
    $18 = $exc + 484 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $exc + 480 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $compensation - $distance | 0;
    $23 = $22 + $19 | 0;
    $24 = $23 - $21 | 0;
    $25 = $exc + 476 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = -$26 | 0;
    $28 = $24 & $27;
    $29 = -$28 | 0;
    $30 = ($28 | 0) < 0;
    $_ = $30 ? 0 : $29;
    $31 = $_ - $21 | 0;
    $val_2 = $31;
    label = 4;
    break;
   case 4:
    return $val_2 | 0;
  }
  return 0;
}
function _Round_Super_45($exc, $distance, $compensation) {
  $exc = $exc | 0;
  $distance = $distance | 0;
  $compensation = $compensation | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $or_cond = 0, $val_0 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $_ = 0, $30 = 0, $val_2 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($distance | 0) > -1;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = $exc + 480 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $exc + 484 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $compensation + $distance | 0;
    $8 = $7 - $4 | 0;
    $9 = $8 + $6 | 0;
    $10 = $exc + 476 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($9 | 0) % ($11 | 0);
    $13 = $9 - $12 | 0;
    $14 = ($distance | 0) != 0;
    $15 = ($13 | 0) < 0;
    $or_cond = $14 & $15;
    $val_0 = $or_cond ? 0 : $13;
    $16 = $val_0 + $4 | 0;
    $val_2 = $16;
    label = 4;
    break;
   case 3:
    $18 = $exc + 484 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $exc + 480 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $compensation - $distance | 0;
    $23 = $22 + $19 | 0;
    $24 = $23 - $21 | 0;
    $25 = $exc + 476 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = ($24 | 0) % ($26 | 0);
    $28 = $27 - $24 | 0;
    $29 = ($28 | 0) > 0;
    $_ = $29 ? 0 : $28;
    $30 = $_ - $21 | 0;
    $val_2 = $30;
    label = 4;
    break;
   case 4:
    return $val_2 | 0;
  }
  return 0;
}
function _Ins_FLIPPT($exc) {
  $exc = $exc | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $exc + 304 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) < ($4 | 0);
    if ($5) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = ($4 | 0) > 0;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 10;
      break;
    }
   case 3:
    $7 = $exc + 28 | 0;
    $8 = $exc + 24 | 0;
    $9 = $exc + 152 | 0;
    $10 = $exc + 168 | 0;
    $11 = $exc + 561 | 0;
    label = 5;
    break;
   case 4:
    $13 = $exc + 12 | 0;
    HEAP32[$13 >> 2] = 129;
    label = 11;
    break;
   case 5:
    $15 = HEAP32[$7 >> 2] | 0;
    $16 = $15 - 1 | 0;
    HEAP32[$7 >> 2] = $16;
    $17 = HEAP32[$8 >> 2] | 0;
    $18 = $17 + ($16 << 2) | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $19 & 65535;
    $21 = HEAP16[$9 >> 1] | 0;
    $22 = $21 & 65535;
    $23 = $20 >>> 0 < $22 >>> 0;
    if ($23) {
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $25 = HEAP8[$11] | 0;
    $26 = $25 << 24 >> 24 == 0;
    if ($26) {
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $28 = $exc + 12 | 0;
    HEAP32[$28 >> 2] = 134;
    label = 11;
    break;
   case 8:
    $30 = HEAP32[$10 >> 2] | 0;
    $31 = $30 + $20 | 0;
    $32 = HEAP8[$31] | 0;
    $33 = $32 ^ 1;
    HEAP8[$31] = $33;
    label = 9;
    break;
   case 9:
    $35 = HEAP32[$3 >> 2] | 0;
    $36 = $35 - 1 | 0;
    HEAP32[$3 >> 2] = $36;
    $37 = ($36 | 0) > 0;
    if ($37) {
      label = 5;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    HEAP32[$3 >> 2] = 1;
    $38 = $exc + 28 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = $exc + 32 | 0;
    HEAP32[$40 >> 2] = $39;
    label = 11;
    break;
   case 11:
    return;
  }
}
function _Ins_FLIPRGON($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $23 = 0, $I_011 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $args + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = HEAP32[$args >> 2] | 0;
    $4 = $2 & 65535;
    $5 = $exc + 152 | 0;
    $6 = HEAP16[$5 >> 1] | 0;
    $7 = $6 & 65535;
    $8 = $4 >>> 0 < $7 >>> 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 2:
    $10 = $3 & 65535;
    $11 = $3 & 65535;
    $12 = $11 >>> 0 < $7 >>> 0;
    if ($12) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $13 = $3 & 65535;
    $14 = $13 >>> 0 > $4 >>> 0;
    if ($14) {
      label = 8;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $15 = $exc + 168 | 0;
    $I_011 = $10;
    $23 = $13;
    label = 7;
    break;
   case 5:
    $17 = $exc + 561 | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $18 << 24 >> 24 == 0;
    if ($19) {
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $21 = $exc + 12 | 0;
    HEAP32[$21 >> 2] = 134;
    label = 8;
    break;
   case 7:
    $24 = HEAP32[$15 >> 2] | 0;
    $25 = $24 + $23 | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 | 1;
    HEAP8[$25] = $27;
    $28 = $I_011 + 1 & 65535;
    $29 = $28 & 65535;
    $30 = $29 >>> 0 > $4 >>> 0;
    if ($30) {
      label = 8;
      break;
    } else {
      $I_011 = $28;
      $23 = $29;
      label = 7;
      break;
    }
   case 8:
    return;
  }
}
function _Ins_FLIPRGOFF($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $23 = 0, $I_011 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $args + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = HEAP32[$args >> 2] | 0;
    $4 = $2 & 65535;
    $5 = $exc + 152 | 0;
    $6 = HEAP16[$5 >> 1] | 0;
    $7 = $6 & 65535;
    $8 = $4 >>> 0 < $7 >>> 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 2:
    $10 = $3 & 65535;
    $11 = $3 & 65535;
    $12 = $11 >>> 0 < $7 >>> 0;
    if ($12) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $13 = $3 & 65535;
    $14 = $13 >>> 0 > $4 >>> 0;
    if ($14) {
      label = 8;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $15 = $exc + 168 | 0;
    $I_011 = $10;
    $23 = $13;
    label = 7;
    break;
   case 5:
    $17 = $exc + 561 | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $18 << 24 >> 24 == 0;
    if ($19) {
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $21 = $exc + 12 | 0;
    HEAP32[$21 >> 2] = 134;
    label = 8;
    break;
   case 7:
    $24 = HEAP32[$15 >> 2] | 0;
    $25 = $24 + $23 | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 & -2;
    HEAP8[$25] = $27;
    $28 = $I_011 + 1 & 65535;
    $29 = $28 & 65535;
    $30 = $29 >>> 0 > $4 >>> 0;
    if ($30) {
      label = 8;
      break;
    } else {
      $I_011 = $28;
      $23 = $29;
      label = 7;
      break;
    }
   case 8:
    return;
  }
}
function _Ins_SCANCTRL($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $4 = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = $1 & 255;
    if (($2 | 0) == 255) {
      label = 2;
      break;
    } else if (($2 | 0) == 0) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $4 = $exc + 337 | 0;
    HEAP8[$4] = 1;
    label = 22;
    break;
   case 3:
    $6 = $exc + 337 | 0;
    HEAP8[$6] = 0;
    label = 22;
    break;
   case 4:
    $8 = $1 & 256;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $11 = $exc + 252 | 0;
    $12 = HEAP16[$11 >> 1] | 0;
    $13 = $12 & 65535;
    $14 = $13 >>> 0 > $2 >>> 0;
    if ($14) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $16 = $exc + 337 | 0;
    HEAP8[$16] = 1;
    label = 7;
    break;
   case 7:
    $18 = HEAP32[$args >> 2] | 0;
    $19 = $18 & 512;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $22 = $exc + 281 | 0;
    $23 = HEAP8[$22] | 0;
    $24 = $23 << 24 >> 24 == 0;
    if ($24) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $26 = $exc + 337 | 0;
    HEAP8[$26] = 1;
    label = 10;
    break;
   case 10:
    $28 = HEAP32[$args >> 2] | 0;
    $29 = $28 & 1024;
    $30 = ($29 | 0) == 0;
    if ($30) {
      label = 13;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $32 = $exc + 282 | 0;
    $33 = HEAP8[$32] | 0;
    $34 = $33 << 24 >> 24 == 0;
    if ($34) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $36 = $exc + 337 | 0;
    HEAP8[$36] = 1;
    label = 13;
    break;
   case 13:
    $38 = HEAP32[$args >> 2] | 0;
    $39 = $38 & 2048;
    $40 = ($39 | 0) == 0;
    if ($40) {
      label = 16;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $42 = $exc + 252 | 0;
    $43 = HEAP16[$42 >> 1] | 0;
    $44 = $43 & 65535;
    $45 = $44 >>> 0 > $2 >>> 0;
    if ($45) {
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 15:
    $47 = $exc + 337 | 0;
    HEAP8[$47] = 0;
    label = 16;
    break;
   case 16:
    $49 = HEAP32[$args >> 2] | 0;
    $50 = $49 & 4096;
    $51 = ($50 | 0) == 0;
    if ($51) {
      label = 19;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $53 = $exc + 281 | 0;
    $54 = HEAP8[$53] | 0;
    $55 = $54 << 24 >> 24 == 0;
    if ($55) {
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $57 = $exc + 337 | 0;
    HEAP8[$57] = 0;
    label = 19;
    break;
   case 19:
    $59 = HEAP32[$args >> 2] | 0;
    $60 = $59 & 8192;
    $61 = ($60 | 0) == 0;
    if ($61) {
      label = 22;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $63 = $exc + 282 | 0;
    $64 = HEAP8[$63] | 0;
    $65 = $64 << 24 >> 24 == 0;
    if ($65) {
      label = 22;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $67 = $exc + 337 | 0;
    HEAP8[$67] = 0;
    label = 22;
    break;
   case 22:
    return;
  }
}
function _Ins_MD($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $D_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = $1 & 65535;
    $3 = $exc + 44 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 & 65535;
    $6 = $2 >>> 0 < $5 >>> 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $8 = $args + 4 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 & 65535;
    $11 = $exc + 80 | 0;
    $12 = HEAP16[$11 >> 1] | 0;
    $13 = $12 & 65535;
    $14 = $10 >>> 0 < $13 >>> 0;
    if ($14) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $16 = $exc + 561 | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 << 24 >> 24 == 0;
    if ($18) {
      $D_0 = 0;
      label = 10;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $20 = $exc + 12 | 0;
    HEAP32[$20 >> 2] = 134;
    label = 11;
    break;
   case 5:
    $22 = $exc + 368 | 0;
    $23 = HEAP8[$22] | 0;
    $24 = $23 & 1;
    $25 = $24 << 24 >> 24 == 0;
    if ($25) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $27 = $exc + 572 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $exc + 52 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $30 + ($2 << 3) | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $exc + 88 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $34 + ($10 << 3) | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $32 - $36 | 0;
    $38 = $30 + ($2 << 3) + 4 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = $34 + ($10 << 3) + 4 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = $39 - $41 | 0;
    $43 = FUNCTION_TABLE_iiii[$28 & 1023]($exc, $37, $42) | 0;
    $D_0 = $43;
    label = 10;
    break;
   case 7:
    $45 = $exc + 56 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $46 + ($2 << 3) | 0;
    $48 = $exc + 92 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = $49 + ($10 << 3) | 0;
    $51 = $exc + 220 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = $exc + 224 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = ($52 | 0) == ($54 | 0);
    if ($55) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $57 = $exc + 576 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = $47 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = $50 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = $60 - $62 | 0;
    $64 = $46 + ($2 << 3) + 4 | 0;
    $65 = HEAP32[$64 >> 2] | 0;
    $66 = $49 + ($10 << 3) + 4 | 0;
    $67 = HEAP32[$66 >> 2] | 0;
    $68 = $65 - $67 | 0;
    $69 = FUNCTION_TABLE_iiii[$58 & 1023]($exc, $63, $68) | 0;
    $70 = HEAP32[$51 >> 2] | 0;
    $71 = _FT_MulFix($69, $70) | 0;
    $D_0 = $71;
    label = 10;
    break;
   case 9:
    $73 = $47 | 0;
    $74 = HEAP32[$73 >> 2] | 0;
    $75 = $50 | 0;
    $76 = HEAP32[$75 >> 2] | 0;
    $77 = $74 - $76 | 0;
    $78 = _FT_MulFix($77, $52) | 0;
    $79 = $46 + ($2 << 3) + 4 | 0;
    $80 = HEAP32[$79 >> 2] | 0;
    $81 = $49 + ($10 << 3) + 4 | 0;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = $80 - $82 | 0;
    $84 = _FT_MulFix($83, $54) | 0;
    $85 = $exc + 576 | 0;
    $86 = HEAP32[$85 >> 2] | 0;
    $87 = FUNCTION_TABLE_iiii[$86 & 1023]($exc, $78, $84) | 0;
    $D_0 = $87;
    label = 10;
    break;
   case 10:
    HEAP32[$args >> 2] = $D_0;
    label = 11;
    break;
   case 11:
    return;
  }
}
function _Current_Ppem($exc) {
  $exc = $exc | 0;
  var $3 = 0;
  $3 = HEAPU16[$exc + 252 >> 1] | 0;
  return _FT_MulFix($3, _Current_Ratio($exc) | 0) | 0;
}
function _Ins_IF($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $nIfs_0 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $12 = 0, $14 = 0, $15 = 0, $_sink = 0, $nIfs_1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      label = 9;
      break;
    }
   case 2:
    $3 = $exc + 368 | 0;
    $nIfs_0 = 1;
    label = 3;
    break;
   case 3:
    $4 = _SkipCode($exc) | 0;
    $5 = $4 << 24 >> 24 == 1;
    if ($5) {
      label = 9;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $7 = HEAP8[$3] | 0;
    $8 = $7 & 255;
    if (($8 | 0) == 88) {
      label = 5;
      break;
    } else if (($8 | 0) == 27) {
      label = 6;
      break;
    } else if (($8 | 0) == 89) {
      label = 7;
      break;
    } else {
      $nIfs_0 = $nIfs_0;
      label = 3;
      break;
    }
   case 5:
    $10 = $nIfs_0 + 1 | 0;
    $nIfs_0 = $10;
    label = 3;
    break;
   case 6:
    $12 = ($nIfs_0 | 0) == 1;
    $nIfs_1 = $nIfs_0;
    $_sink = $12;
    label = 8;
    break;
   case 7:
    $14 = $nIfs_0 - 1 | 0;
    $15 = ($14 | 0) == 0;
    $nIfs_1 = $14;
    $_sink = $15;
    label = 8;
    break;
   case 8:
    if ($_sink) {
      label = 9;
      break;
    } else {
      $nIfs_0 = $nIfs_1;
      label = 3;
      break;
    }
   case 9:
    return;
  }
}
function _Ins_DELTAP($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $k_029 = 0, $16 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $40 = 0, $C_0 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $_ = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $63 = 0, $64 = 0, $65 = 0, $_lcssa = 0, $66 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = ($1 | 0) == 0;
    $3 = $exc + 28 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    if ($2) {
      $_lcssa = $4;
      label = 14;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $exc + 24 | 0;
    $6 = $exc + 36 | 0;
    $7 = $exc + 44 | 0;
    $8 = $exc + 368 | 0;
    $9 = $exc + 332 | 0;
    $10 = $exc + 334 | 0;
    $11 = $exc + 584 | 0;
    $12 = $exc + 561 | 0;
    $13 = $exc + 12 | 0;
    $k_029 = 1;
    $15 = $4;
    label = 3;
    break;
   case 3:
    $16 = ($15 | 0) < 2;
    if ($16) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $18 = $exc + 12 | 0;
    HEAP32[$18 >> 2] = 129;
    label = 15;
    break;
   case 5:
    $20 = $15 - 2 | 0;
    HEAP32[$3 >> 2] = $20;
    $21 = $15 - 1 | 0;
    $22 = HEAP32[$5 >> 2] | 0;
    $23 = $22 + ($21 << 2) | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24 & 65535;
    $26 = $22 + ($20 << 2) | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $24 & 65535;
    $29 = HEAP16[$7 >> 1] | 0;
    $30 = $29 & 65535;
    $31 = $28 >>> 0 < $30 >>> 0;
    if ($31) {
      label = 6;
      break;
    } else {
      label = 11;
      break;
    }
   case 6:
    $33 = $27 >>> 4;
    $34 = $33 & 15;
    $35 = HEAP8[$8] | 0;
    $36 = $35 & 255;
    if (($36 | 0) == 113) {
      label = 7;
      break;
    } else if (($36 | 0) == 114) {
      label = 8;
      break;
    } else {
      $C_0 = $34;
      label = 9;
      break;
    }
   case 7:
    $38 = $34 | 16;
    $C_0 = $38;
    label = 9;
    break;
   case 8:
    $40 = $34 | 32;
    $C_0 = $40;
    label = 9;
    break;
   case 9:
    $42 = HEAP16[$9 >> 1] | 0;
    $43 = $42 << 16 >> 16;
    $44 = $43 + $C_0 | 0;
    $45 = _Current_Ppem($exc) | 0;
    $46 = ($45 | 0) == ($44 | 0);
    if ($46) {
      label = 10;
      break;
    } else {
      label = 13;
      break;
    }
   case 10:
    $48 = $27 & 15;
    $49 = $48 - 8 | 0;
    $50 = ($49 | 0) > -1;
    $51 = $48 - 7 | 0;
    $_ = $50 ? $51 : $49;
    $52 = $_ << 6;
    $53 = HEAP16[$10 >> 1] | 0;
    $54 = $53 << 16 >> 16;
    $55 = 1 << $54;
    $56 = ($52 | 0) / ($55 | 0) & -1;
    $57 = HEAP32[$11 >> 2] | 0;
    FUNCTION_TABLE_viiii[$57 & 1023]($exc, $6, $25, $56);
    label = 13;
    break;
   case 11:
    $59 = HEAP8[$12] | 0;
    $60 = $59 << 24 >> 24 == 0;
    if ($60) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    HEAP32[$13 >> 2] = 134;
    label = 13;
    break;
   case 13:
    $63 = $k_029 + 1 | 0;
    $64 = $63 >>> 0 > $1 >>> 0;
    $65 = HEAP32[$3 >> 2] | 0;
    if ($64) {
      $_lcssa = $65;
      label = 14;
      break;
    } else {
      $k_029 = $63;
      $15 = $65;
      label = 3;
      break;
    }
   case 14:
    $66 = $exc + 32 | 0;
    HEAP32[$66 >> 2] = $_lcssa;
    label = 15;
    break;
   case 15:
    return;
  }
}
function _Ins_DELTAC($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $k_029 = 0, $14 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $40 = 0, $C_0 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $_ = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $_lcssa = 0, $62 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = ($1 | 0) == 0;
    $3 = $exc + 28 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    if ($2) {
      $_lcssa = $4;
      label = 14;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $exc + 24 | 0;
    $6 = $exc + 380 | 0;
    $7 = $exc + 368 | 0;
    $8 = $exc + 332 | 0;
    $9 = $exc + 334 | 0;
    $10 = $exc + 600 | 0;
    $11 = $exc + 561 | 0;
    $k_029 = 1;
    $13 = $4;
    label = 3;
    break;
   case 3:
    $14 = ($13 | 0) < 2;
    if ($14) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $16 = $exc + 12 | 0;
    HEAP32[$16 >> 2] = 129;
    label = 15;
    break;
   case 5:
    $18 = $13 - 2 | 0;
    HEAP32[$3 >> 2] = $18;
    $19 = $13 - 1 | 0;
    $20 = HEAP32[$5 >> 2] | 0;
    $21 = $20 + ($19 << 2) | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $20 + ($18 << 2) | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = HEAP32[$6 >> 2] | 0;
    $26 = $22 >>> 0 < $25 >>> 0;
    if ($26) {
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $28 = HEAP8[$11] | 0;
    $29 = $28 << 24 >> 24 == 0;
    if ($29) {
      label = 13;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $31 = $exc + 12 | 0;
    HEAP32[$31 >> 2] = 134;
    label = 15;
    break;
   case 8:
    $33 = $24 >>> 4;
    $34 = $33 & 15;
    $35 = HEAP8[$7] | 0;
    $36 = $35 & 255;
    if (($36 | 0) == 116) {
      label = 9;
      break;
    } else if (($36 | 0) == 117) {
      label = 10;
      break;
    } else {
      $C_0 = $34;
      label = 11;
      break;
    }
   case 9:
    $38 = $34 | 16;
    $C_0 = $38;
    label = 11;
    break;
   case 10:
    $40 = $34 | 32;
    $C_0 = $40;
    label = 11;
    break;
   case 11:
    $42 = HEAP16[$8 >> 1] | 0;
    $43 = $42 << 16 >> 16;
    $44 = $43 + $C_0 | 0;
    $45 = _Current_Ppem($exc) | 0;
    $46 = ($45 | 0) == ($44 | 0);
    if ($46) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $48 = $24 & 15;
    $49 = $48 - 8 | 0;
    $50 = ($49 | 0) > -1;
    $51 = $48 - 7 | 0;
    $_ = $50 ? $51 : $49;
    $52 = $_ << 6;
    $53 = HEAP16[$9 >> 1] | 0;
    $54 = $53 << 16 >> 16;
    $55 = 1 << $54;
    $56 = ($52 | 0) / ($55 | 0) & -1;
    $57 = HEAP32[$10 >> 2] | 0;
    FUNCTION_TABLE_viii[$57 & 1023]($exc, $22, $56);
    label = 13;
    break;
   case 13:
    $59 = $k_029 + 1 | 0;
    $60 = $59 >>> 0 > $1 >>> 0;
    $61 = HEAP32[$3 >> 2] | 0;
    if ($60) {
      $_lcssa = $61;
      label = 14;
      break;
    } else {
      $k_029 = $59;
      $13 = $61;
      label = 3;
      break;
    }
   case 14:
    $62 = $exc + 32 | 0;
    HEAP32[$62 >> 2] = $_lcssa;
    label = 15;
    break;
   case 15:
    return;
  }
}
function _Ins_GETINFO($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $_ = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $__ = 0, $K_1 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $K_1_ = 0, $K_2 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $K_2_ = 0, $K_3 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = $1 & 1;
    $3 = ($2 | 0) == 0;
    $_ = $3 ? 0 : 35;
    $4 = $1 & 2;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $K_1 = $_;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $exc + 281 | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 << 24 >> 24 == 0;
    $10 = $_ | 128;
    $__ = $9 ? $_ : $10;
    $K_1 = $__;
    label = 3;
    break;
   case 3:
    $12 = HEAP32[$args >> 2] | 0;
    $13 = $12 & 4;
    $14 = ($13 | 0) == 0;
    if ($14) {
      $K_2 = $K_1;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $16 = $exc + 282 | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 << 24 >> 24 == 0;
    $19 = $K_1 | 256;
    $K_1_ = $18 ? $K_1 : $19;
    $K_2 = $K_1_;
    label = 5;
    break;
   case 5:
    $21 = HEAP32[$args >> 2] | 0;
    $22 = $21 & 32;
    $23 = ($22 | 0) == 0;
    if ($23) {
      $K_3 = $K_2;
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $25 = $exc + 604 | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 << 24 >> 24 == 0;
    $28 = $K_2 | 4096;
    $K_2_ = $27 ? $K_2 : $28;
    $K_3 = $K_2_;
    label = 7;
    break;
   case 7:
    HEAP32[$args >> 2] = $K_3;
    return;
  }
}
function _Ins_ROLL($args) {
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0;
  $1 = $args + 8 | 0;
  $2 = HEAP32[$1 >> 2] | 0;
  $3 = $args + 4 | 0;
  $4 = HEAP32[$3 >> 2] | 0;
  HEAP32[$1 >> 2] = HEAP32[$args >> 2] | 0;
  HEAP32[$3 >> 2] = $2;
  HEAP32[$args >> 2] = $4;
  return;
}
function _Ins_SCANTYPE($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $4 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = ($1 | 0) > -1;
    if ($2) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $4 = $exc + 340 | 0;
    HEAP32[$4 >> 2] = $1;
    label = 3;
    break;
   case 3:
    return;
  }
}
function _Ins_INSTCTRL($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $_off = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $11 = 0, $12 = 0, $_ = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $args + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $_off = $2 - 1 | 0;
    $3 = $_off >>> 0 > 1;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $5 = $exc + 561 | 0;
    $6 = HEAP8[$5] | 0;
    $7 = $6 << 24 >> 24 == 0;
    if ($7) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = $exc + 12 | 0;
    HEAP32[$9 >> 2] = 134;
    label = 5;
    break;
   case 4:
    $11 = HEAP32[$args >> 2] | 0;
    $12 = ($11 | 0) == 0;
    $_ = $12 ? 0 : $2;
    $13 = $exc + 336 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 & 255;
    $16 = $2 ^ 255;
    $17 = $15 & $16;
    $18 = $17 | $_;
    $19 = $18 & 255;
    HEAP8[$13] = $19;
    label = 5;
    break;
   case 5:
    return;
  }
}
function _Ins_PUSHB($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, $K_011 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 368 | 0;
    $2 = HEAP8[$1] | 0;
    $3 = $2 & 255;
    $4 = $3 + 65361 | 0;
    $5 = $4 & 65535;
    $6 = $exc + 20 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 + 1 | 0;
    $9 = $exc + 16 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $8 - $10 | 0;
    $12 = $5 >>> 0 < $11 >>> 0;
    if ($12) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $13 = ($5 | 0) == 0;
    if ($13) {
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $14 = $exc + 360 | 0;
    $15 = $exc + 356 | 0;
    $K_011 = 1;
    $19 = 1;
    label = 5;
    break;
   case 4:
    $17 = $exc + 12 | 0;
    HEAP32[$17 >> 2] = 130;
    label = 6;
    break;
   case 5:
    $20 = HEAP32[$14 >> 2] | 0;
    $21 = $20 + $19 | 0;
    $22 = HEAP32[$15 >> 2] | 0;
    $23 = $22 + $21 | 0;
    $24 = HEAP8[$23] | 0;
    $25 = $24 & 255;
    $26 = $19 - 1 | 0;
    $27 = $args + ($26 << 2) | 0;
    HEAP32[$27 >> 2] = $25;
    $28 = $K_011 + 1 & 65535;
    $29 = $28 & 65535;
    $30 = $29 >>> 0 > $5 >>> 0;
    if ($30) {
      label = 6;
      break;
    } else {
      $K_011 = $28;
      $19 = $29;
      label = 5;
      break;
    }
   case 6:
    return;
  }
}
function _Ins_Goto_CodeRange($exc, $aRange, $aIP) {
  $exc = $exc | 0;
  $aRange = $aRange | 0;
  $aIP = $aIP | 0;
  var $aRange_off = 0, $1 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $aRange_off = $aRange - 1 | 0;
    $1 = $aRange_off >>> 0 > 2;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = $exc + 12 | 0;
    HEAP32[$3 >> 2] = 132;
    $_0 = 1;
    label = 8;
    break;
   case 3:
    $5 = $aRange - 1 | 0;
    $6 = $exc + 444 + ($5 << 3) | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $10 = $exc + 12 | 0;
    HEAP32[$10 >> 2] = 138;
    $_0 = 1;
    label = 8;
    break;
   case 5:
    $12 = $exc + 444 + ($5 << 3) + 4 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 >>> 0 < $aIP >>> 0;
    if ($14) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $16 = $exc + 12 | 0;
    HEAP32[$16 >> 2] = 131;
    $_0 = 1;
    label = 8;
    break;
   case 7:
    $18 = $exc + 356 | 0;
    HEAP32[$18 >> 2] = $7;
    $19 = HEAP32[$12 >> 2] | 0;
    $20 = $exc + 364 | 0;
    HEAP32[$20 >> 2] = $19;
    $21 = $exc + 360 | 0;
    HEAP32[$21 >> 2] = $aIP;
    $22 = $exc + 352 | 0;
    HEAP32[$22 >> 2] = $aRange;
    $_0 = 0;
    label = 8;
    break;
   case 8:
    return $_0 | 0;
  }
  return 0;
}
function _GetShortIns($exc) {
  $exc = $exc | 0;
  var $1 = 0, $2 = 0, $5 = 0;
  $1 = $exc + 360 | 0;
  $2 = HEAP32[$1 >> 2] | 0;
  HEAP32[$1 >> 2] = $2 + 2 | 0;
  $5 = HEAP32[$exc + 356 >> 2] | 0;
  return (HEAPU8[$5 + $2 | 0] | 0) << 8 | (HEAPU8[$5 + ($2 + 1 | 0) | 0] | 0) | 0;
}
function _Ins_SDPVTL($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $B_0 = 0, $A_0 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $B_1 = 0, $A_1 = 0, $60 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = $1 & 65535;
    $3 = $exc + 80 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 & 65535;
    $6 = $2 >>> 0 < $5 >>> 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $8 = $args + 4 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 & 65535;
    $11 = $exc + 116 | 0;
    $12 = HEAP16[$11 >> 1] | 0;
    $13 = $12 & 65535;
    $14 = $10 >>> 0 < $13 >>> 0;
    if ($14) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $16 = $exc + 561 | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 << 24 >> 24 == 0;
    if ($18) {
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $20 = $exc + 12 | 0;
    HEAP32[$20 >> 2] = 134;
    label = 6;
    break;
   case 5:
    $22 = $exc + 84 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $exc + 120 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $23 + ($2 << 3) | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $25 + ($10 << 3) | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $27 - $29 | 0;
    $31 = $23 + ($2 << 3) + 4 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $25 + ($10 << 3) + 4 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $32 - $34 | 0;
    $36 = $exc + 368 | 0;
    $37 = HEAP8[$36] | 0;
    $38 = $37 & 1;
    $39 = $38 << 24 >> 24 == 0;
    $40 = -$35 | 0;
    $B_0 = $39 ? $35 : $30;
    $A_0 = $39 ? $30 : $40;
    $41 = $exc + 290 | 0;
    _Normalize($A_0, $B_0, $41);
    $42 = $exc + 88 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $exc + 124 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = $43 + ($2 << 3) | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $45 + ($10 << 3) | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = $47 - $49 | 0;
    $51 = $43 + ($2 << 3) + 4 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = $45 + ($10 << 3) + 4 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = $52 - $54 | 0;
    $56 = HEAP8[$36] | 0;
    $57 = $56 & 1;
    $58 = $57 << 24 >> 24 == 0;
    $59 = -$55 | 0;
    $B_1 = $58 ? $55 : $50;
    $A_1 = $58 ? $50 : $59;
    $60 = $exc + 294 | 0;
    _Normalize($A_1, $B_1, $60);
    _Compute_Funcs($exc);
    label = 6;
    break;
   case 6:
    return;
  }
}
function _Ins_IDEF($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $def_0 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $24 = 0, $26 = 0, $27 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $52 = 0, $53 = 0, $55 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 416 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $exc + 408 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + ($4 << 4) | 0;
    $def_0 = $2;
    label = 2;
    break;
   case 2:
    $7 = $def_0 >>> 0 < $5 >>> 0;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $9 = $def_0 + 8 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = HEAP32[$args >> 2] | 0;
    $12 = ($10 | 0) == ($11 | 0);
    $13 = $def_0 + 16 | 0;
    if ($12) {
      label = 4;
      break;
    } else {
      $def_0 = $13;
      label = 2;
      break;
    }
   case 4:
    $15 = ($def_0 | 0) == ($5 | 0);
    if ($15) {
      label = 5;
      break;
    } else {
      label = 8;
      break;
    }
   case 5:
    $17 = HEAP32[$3 >> 2] | 0;
    $18 = $exc + 412 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $17 >>> 0 < $19 >>> 0;
    if ($20) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $22 = $exc + 12 | 0;
    HEAP32[$22 >> 2] = 141;
    label = 16;
    break;
   case 7:
    $24 = $17 + 1 | 0;
    HEAP32[$3 >> 2] = $24;
    label = 8;
    break;
   case 8:
    $26 = HEAP32[$args >> 2] | 0;
    $27 = $26 >>> 0 > 255;
    if ($27) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $29 = $exc + 12 | 0;
    HEAP32[$29 >> 2] = 141;
    label = 16;
    break;
   case 10:
    $31 = $26 & 255;
    $32 = $def_0 + 8 | 0;
    HEAP32[$32 >> 2] = $31;
    $33 = $exc + 360 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $34 + 1 | 0;
    $36 = $def_0 + 4 | 0;
    HEAP32[$36 >> 2] = $35;
    $37 = $exc + 352 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $def_0 | 0;
    HEAP32[$39 >> 2] = $38;
    $40 = $def_0 + 12 | 0;
    HEAP8[$40] = 1;
    $41 = HEAP32[$args >> 2] | 0;
    $42 = $exc + 424 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $41 >>> 0 > $43 >>> 0;
    if ($44) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $46 = $41 & 255;
    HEAP32[$42 >> 2] = $46;
    label = 12;
    break;
   case 12:
    $47 = $exc + 368 | 0;
    label = 13;
    break;
   case 13:
    $49 = _SkipCode($exc) | 0;
    $50 = $49 << 24 >> 24 == 0;
    if ($50) {
      label = 14;
      break;
    } else {
      label = 16;
      break;
    }
   case 14:
    $52 = HEAP8[$47] | 0;
    $53 = $52 & 255;
    if (($53 | 0) == 137 | ($53 | 0) == 44) {
      label = 15;
      break;
    } else if (($53 | 0) == 45) {
      label = 16;
      break;
    } else {
      label = 13;
      break;
    }
   case 15:
    $55 = $exc + 12 | 0;
    HEAP32[$55 >> 2] = 137;
    label = 16;
    break;
   case 16:
    return;
  }
}
function _Ins_MIRP($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $cvt_dist_0 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $_ = 0, $cvt_dist_1 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $ld$0$0 = 0, $87$0 = 0, $ld$1$1 = 0, $87$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $131 = 0, $132 = 0, $133 = 0, $_cvt_dist_1 = 0, $cvt_dist_2 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $cvt_dist_2_ = 0, $cvt_dist_3 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $distance_0 = 0, $168 = 0, $169 = 0, $170 = 0, $172 = 0, $173 = 0, $174 = 0, $176 = 0, $_distance_0 = 0, $178 = 0, $179 = 0, $_distance_092 = 0, $distance_1 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $191 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = $1 & 65535;
    $3 = $args + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 1 | 0;
    $6 = $1 & 65535;
    $7 = $exc + 72 | 0;
    $8 = $exc + 80 | 0;
    $9 = HEAP16[$8 >> 1] | 0;
    $10 = $9 & 65535;
    $11 = $6 >>> 0 < $10 >>> 0;
    if ($11) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $13 = $exc + 380 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 + 1 | 0;
    $16 = $5 >>> 0 < $15 >>> 0;
    if ($16) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $18 = $exc + 284 | 0;
    $19 = HEAP16[$18 >> 1] | 0;
    $20 = $exc + 44 | 0;
    $21 = HEAP16[$20 >> 1] | 0;
    $22 = ($19 & 65535) < ($21 & 65535);
    if ($22) {
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $24 = $exc + 561 | 0;
    $25 = HEAP8[$24] | 0;
    $26 = $25 << 24 >> 24 == 0;
    if ($26) {
      label = 26;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $28 = $exc + 12 | 0;
    HEAP32[$28 >> 2] = 134;
    label = 26;
    break;
   case 6:
    $30 = ($5 | 0) == 0;
    if ($30) {
      $cvt_dist_0 = 0;
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $32 = $exc + 592 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = FUNCTION_TABLE_iii[$33 & 1023]($exc, $4) | 0;
    $cvt_dist_0 = $34;
    label = 8;
    break;
   case 8:
    $36 = $exc + 328 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $cvt_dist_0 - $37 | 0;
    $39 = ($38 | 0) < 0;
    $40 = -$38 | 0;
    $41 = $39 ? $40 : $38;
    $42 = $exc + 324 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = ($41 | 0) < ($43 | 0);
    if ($44) {
      label = 9;
      break;
    } else {
      $cvt_dist_1 = $cvt_dist_0;
      label = 10;
      break;
    }
   case 9:
    $46 = ($cvt_dist_0 | 0) > -1;
    $47 = -$37 | 0;
    $_ = $46 ? $37 : $47;
    $cvt_dist_1 = $_;
    label = 10;
    break;
   case 10:
    $49 = $exc + 346 | 0;
    $50 = HEAP16[$49 >> 1] | 0;
    $51 = $50 << 16 >> 16 == 0;
    if ($51) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $53 = HEAP16[$18 >> 1] | 0;
    $54 = $53 & 65535;
    $55 = $exc + 48 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = $56 + ($54 << 3) | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = $exc + 298 | 0;
    $60 = HEAP16[$59 >> 1] | 0;
    $61 = $60 << 16 >> 16;
    $62 = _TT_MulFix14($cvt_dist_1, $61) | 0;
    $63 = $62 + $58 | 0;
    $64 = $exc + 84 | 0;
    $65 = HEAP32[$64 >> 2] | 0;
    $66 = $65 + ($6 << 3) | 0;
    HEAP32[$66 >> 2] = $63;
    $67 = HEAP16[$18 >> 1] | 0;
    $68 = $67 & 65535;
    $69 = HEAP32[$55 >> 2] | 0;
    $70 = $69 + ($68 << 3) + 4 | 0;
    $71 = HEAP32[$70 >> 2] | 0;
    $72 = $exc + 300 | 0;
    $73 = HEAP16[$72 >> 1] | 0;
    $74 = $73 << 16 >> 16;
    $75 = _TT_MulFix14($cvt_dist_1, $74) | 0;
    $76 = $75 + $71 | 0;
    $77 = HEAP32[$64 >> 2] | 0;
    $78 = $77 + ($6 << 3) + 4 | 0;
    HEAP32[$78 >> 2] = $76;
    $79 = $exc + 88 | 0;
    $80 = HEAP32[$79 >> 2] | 0;
    $81 = $80 + ($6 << 3) | 0;
    $82 = $exc + 52 | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = $83 + ($6 << 3) | 0;
    $85 = $84;
    $86 = $81;
    $ld$0$0 = $85 | 0;
    $87$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $85 + 4 | 0;
    $87$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $86 | 0;
    HEAP32[$st$2$0 >> 2] = $87$0;
    $st$3$1 = $86 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $87$1;
    label = 12;
    break;
   case 12:
    $89 = $exc + 576 | 0;
    $90 = HEAP32[$89 >> 2] | 0;
    $91 = $exc + 84 | 0;
    $92 = HEAP32[$91 >> 2] | 0;
    $93 = $92 + ($6 << 3) | 0;
    $94 = HEAP32[$93 >> 2] | 0;
    $95 = HEAP16[$18 >> 1] | 0;
    $96 = $95 & 65535;
    $97 = $exc + 48 | 0;
    $98 = HEAP32[$97 >> 2] | 0;
    $99 = $98 + ($96 << 3) | 0;
    $100 = HEAP32[$99 >> 2] | 0;
    $101 = $94 - $100 | 0;
    $102 = $92 + ($6 << 3) + 4 | 0;
    $103 = HEAP32[$102 >> 2] | 0;
    $104 = $98 + ($96 << 3) + 4 | 0;
    $105 = HEAP32[$104 >> 2] | 0;
    $106 = $103 - $105 | 0;
    $107 = FUNCTION_TABLE_iiii[$90 & 1023]($exc, $101, $106) | 0;
    $108 = $exc + 572 | 0;
    $109 = HEAP32[$108 >> 2] | 0;
    $110 = $exc + 88 | 0;
    $111 = HEAP32[$110 >> 2] | 0;
    $112 = $111 + ($6 << 3) | 0;
    $113 = HEAP32[$112 >> 2] | 0;
    $114 = HEAP16[$18 >> 1] | 0;
    $115 = $114 & 65535;
    $116 = $exc + 52 | 0;
    $117 = HEAP32[$116 >> 2] | 0;
    $118 = $117 + ($115 << 3) | 0;
    $119 = HEAP32[$118 >> 2] | 0;
    $120 = $113 - $119 | 0;
    $121 = $111 + ($6 << 3) + 4 | 0;
    $122 = HEAP32[$121 >> 2] | 0;
    $123 = $117 + ($115 << 3) + 4 | 0;
    $124 = HEAP32[$123 >> 2] | 0;
    $125 = $122 - $124 | 0;
    $126 = FUNCTION_TABLE_iiii[$109 & 1023]($exc, $120, $125) | 0;
    $127 = $exc + 316 | 0;
    $128 = HEAP8[$127] | 0;
    $129 = $128 << 24 >> 24 == 0;
    if ($129) {
      $cvt_dist_2 = $cvt_dist_1;
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $131 = $107 ^ $cvt_dist_1;
    $132 = ($131 | 0) < 0;
    $133 = -$cvt_dist_1 | 0;
    $_cvt_dist_1 = $132 ? $133 : $cvt_dist_1;
    $cvt_dist_2 = $_cvt_dist_1;
    label = 14;
    break;
   case 14:
    $135 = $exc + 368 | 0;
    $136 = HEAP8[$135] | 0;
    $137 = $136 & 255;
    $138 = $137 & 4;
    $139 = ($138 | 0) == 0;
    if ($139) {
      label = 18;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $141 = $exc + 344 | 0;
    $142 = HEAP16[$141 >> 1] | 0;
    $143 = HEAP16[$49 >> 1] | 0;
    $144 = $142 << 16 >> 16 == $143 << 16 >> 16;
    if ($144) {
      label = 16;
      break;
    } else {
      $cvt_dist_3 = $cvt_dist_2;
      label = 17;
      break;
    }
   case 16:
    $146 = $cvt_dist_2 - $107 | 0;
    $147 = ($146 | 0) < 0;
    $148 = -$146 | 0;
    $149 = $147 ? $148 : $146;
    $150 = $exc + 320 | 0;
    $151 = HEAP32[$150 >> 2] | 0;
    $152 = ($149 | 0) < ($151 | 0);
    $cvt_dist_2_ = $152 ? $cvt_dist_2 : $107;
    $cvt_dist_3 = $cvt_dist_2_;
    label = 17;
    break;
   case 17:
    $154 = $exc + 568 | 0;
    $155 = HEAP32[$154 >> 2] | 0;
    $156 = HEAP8[$135] | 0;
    $157 = $156 & 255;
    $158 = $157 & 3;
    $159 = $exc + 264 + ($158 << 2) | 0;
    $160 = HEAP32[$159 >> 2] | 0;
    $161 = FUNCTION_TABLE_iiii[$155 & 1023]($exc, $cvt_dist_3, $160) | 0;
    $distance_0 = $161;
    label = 19;
    break;
   case 18:
    $163 = $137 & 3;
    $164 = $exc + 264 + ($163 << 2) | 0;
    $165 = HEAP32[$164 >> 2] | 0;
    $166 = _Round_None($exc, $cvt_dist_2, $165) | 0;
    $distance_0 = $166;
    label = 19;
    break;
   case 19:
    $168 = HEAP8[$135] | 0;
    $169 = $168 & 8;
    $170 = $169 << 24 >> 24 == 0;
    if ($170) {
      $distance_1 = $distance_0;
      label = 23;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $172 = ($107 | 0) > -1;
    $173 = $exc + 308 | 0;
    $174 = HEAP32[$173 >> 2] | 0;
    if ($172) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    $176 = ($distance_0 | 0) < ($174 | 0);
    $_distance_0 = $176 ? $174 : $distance_0;
    $distance_1 = $_distance_0;
    label = 23;
    break;
   case 22:
    $178 = -$174 | 0;
    $179 = ($distance_0 | 0) > ($178 | 0);
    $_distance_092 = $179 ? $178 : $distance_0;
    $distance_1 = $_distance_092;
    label = 23;
    break;
   case 23:
    $181 = $exc + 584 | 0;
    $182 = HEAP32[$181 >> 2] | 0;
    $183 = $distance_1 - $126 | 0;
    FUNCTION_TABLE_viiii[$182 & 1023]($exc, $7, $2, $183);
    $184 = HEAP16[$18 >> 1] | 0;
    $185 = $exc + 286 | 0;
    HEAP16[$185 >> 1] = $184;
    $186 = HEAP8[$135] | 0;
    $187 = $186 & 16;
    $188 = $187 << 24 >> 24 == 0;
    if ($188) {
      label = 25;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    HEAP16[$18 >> 1] = $2;
    label = 25;
    break;
   case 25:
    $191 = $exc + 288 | 0;
    HEAP16[$191 >> 1] = $2;
    label = 26;
    break;
   case 26:
    return;
  }
}
function _Ins_MDRP($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $org_dist_0 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $105 = 0, $106 = 0, $_ = 0, $org_dist_1 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $distance_0 = 0, $126 = 0, $127 = 0, $128 = 0, $130 = 0, $131 = 0, $132 = 0, $134 = 0, $_distance_0 = 0, $136 = 0, $137 = 0, $_distance_079 = 0, $distance_1 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$args >> 2] | 0;
    $2 = $1 & 65535;
    $3 = $1 & 65535;
    $4 = $exc + 72 | 0;
    $5 = $exc + 80 | 0;
    $6 = HEAP16[$5 >> 1] | 0;
    $7 = $6 & 65535;
    $8 = $3 >>> 0 < $7 >>> 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $10 = $exc + 284 | 0;
    $11 = HEAP16[$10 >> 1] | 0;
    $12 = $11 & 65535;
    $13 = $exc + 44 | 0;
    $14 = HEAP16[$13 >> 1] | 0;
    $15 = ($11 & 65535) < ($14 & 65535);
    if ($15) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $17 = $exc + 561 | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $18 << 24 >> 24 == 0;
    if ($19) {
      label = 22;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $21 = $exc + 12 | 0;
    HEAP32[$21 >> 2] = 134;
    label = 22;
    break;
   case 5:
    $23 = $exc + 344 | 0;
    $24 = HEAP16[$23 >> 1] | 0;
    $25 = $24 << 16 >> 16 == 0;
    if ($25) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $27 = $exc + 346 | 0;
    $28 = HEAP16[$27 >> 1] | 0;
    $29 = $28 << 16 >> 16 == 0;
    if ($29) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $31 = $exc + 84 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = HEAP16[$10 >> 1] | 0;
    $34 = $33 & 65535;
    $35 = $exc + 48 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $exc + 576 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $32 + ($3 << 3) | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $36 + ($34 << 3) | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = $40 - $42 | 0;
    $44 = $32 + ($3 << 3) + 4 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = $36 + ($34 << 3) + 4 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $45 - $47 | 0;
    $49 = FUNCTION_TABLE_iiii[$38 & 1023]($exc, $43, $48) | 0;
    $org_dist_0 = $49;
    label = 11;
    break;
   case 8:
    $51 = $exc + 92 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = $52 + ($3 << 3) | 0;
    $54 = $exc + 56 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = $55 + ($12 << 3) | 0;
    $57 = $exc + 220 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = $exc + 224 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = ($58 | 0) == ($60 | 0);
    if ($61) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $63 = $exc + 576 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = $53 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = $56 | 0;
    $68 = HEAP32[$67 >> 2] | 0;
    $69 = $66 - $68 | 0;
    $70 = $52 + ($3 << 3) + 4 | 0;
    $71 = HEAP32[$70 >> 2] | 0;
    $72 = $55 + ($12 << 3) + 4 | 0;
    $73 = HEAP32[$72 >> 2] | 0;
    $74 = $71 - $73 | 0;
    $75 = FUNCTION_TABLE_iiii[$64 & 1023]($exc, $69, $74) | 0;
    $76 = HEAP32[$57 >> 2] | 0;
    $77 = _FT_MulFix($75, $76) | 0;
    $org_dist_0 = $77;
    label = 11;
    break;
   case 10:
    $79 = $53 | 0;
    $80 = HEAP32[$79 >> 2] | 0;
    $81 = $56 | 0;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = $80 - $82 | 0;
    $84 = _FT_MulFix($83, $58) | 0;
    $85 = $52 + ($3 << 3) + 4 | 0;
    $86 = HEAP32[$85 >> 2] | 0;
    $87 = $55 + ($12 << 3) + 4 | 0;
    $88 = HEAP32[$87 >> 2] | 0;
    $89 = $86 - $88 | 0;
    $90 = _FT_MulFix($89, $60) | 0;
    $91 = $exc + 576 | 0;
    $92 = HEAP32[$91 >> 2] | 0;
    $93 = FUNCTION_TABLE_iiii[$92 & 1023]($exc, $84, $90) | 0;
    $org_dist_0 = $93;
    label = 11;
    break;
   case 11:
    $95 = $exc + 328 | 0;
    $96 = HEAP32[$95 >> 2] | 0;
    $97 = $org_dist_0 - $96 | 0;
    $98 = ($97 | 0) < 0;
    $99 = -$97 | 0;
    $100 = $98 ? $99 : $97;
    $101 = $exc + 324 | 0;
    $102 = HEAP32[$101 >> 2] | 0;
    $103 = ($100 | 0) < ($102 | 0);
    if ($103) {
      label = 12;
      break;
    } else {
      $org_dist_1 = $org_dist_0;
      label = 13;
      break;
    }
   case 12:
    $105 = ($org_dist_0 | 0) > -1;
    $106 = -$96 | 0;
    $_ = $105 ? $96 : $106;
    $org_dist_1 = $_;
    label = 13;
    break;
   case 13:
    $108 = $exc + 368 | 0;
    $109 = HEAP8[$108] | 0;
    $110 = $109 & 255;
    $111 = $110 & 4;
    $112 = ($111 | 0) == 0;
    if ($112) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $114 = $exc + 568 | 0;
    $115 = HEAP32[$114 >> 2] | 0;
    $116 = $110 & 3;
    $117 = $exc + 264 + ($116 << 2) | 0;
    $118 = HEAP32[$117 >> 2] | 0;
    $119 = FUNCTION_TABLE_iiii[$115 & 1023]($exc, $org_dist_1, $118) | 0;
    $distance_0 = $119;
    label = 16;
    break;
   case 15:
    $121 = $110 & 3;
    $122 = $exc + 264 + ($121 << 2) | 0;
    $123 = HEAP32[$122 >> 2] | 0;
    $124 = _Round_None($exc, $org_dist_1, $123) | 0;
    $distance_0 = $124;
    label = 16;
    break;
   case 16:
    $126 = HEAP8[$108] | 0;
    $127 = $126 & 8;
    $128 = $127 << 24 >> 24 == 0;
    if ($128) {
      $distance_1 = $distance_0;
      label = 20;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $130 = ($org_dist_1 | 0) > -1;
    $131 = $exc + 308 | 0;
    $132 = HEAP32[$131 >> 2] | 0;
    if ($130) {
      label = 18;
      break;
    } else {
      label = 19;
      break;
    }
   case 18:
    $134 = ($distance_0 | 0) < ($132 | 0);
    $_distance_0 = $134 ? $132 : $distance_0;
    $distance_1 = $_distance_0;
    label = 20;
    break;
   case 19:
    $136 = -$132 | 0;
    $137 = ($distance_0 | 0) > ($136 | 0);
    $_distance_079 = $137 ? $136 : $distance_0;
    $distance_1 = $_distance_079;
    label = 20;
    break;
   case 20:
    $139 = $exc + 572 | 0;
    $140 = HEAP32[$139 >> 2] | 0;
    $141 = $exc + 88 | 0;
    $142 = HEAP32[$141 >> 2] | 0;
    $143 = $142 + ($3 << 3) | 0;
    $144 = HEAP32[$143 >> 2] | 0;
    $145 = $exc + 52 | 0;
    $146 = HEAP32[$145 >> 2] | 0;
    $147 = HEAP16[$10 >> 1] | 0;
    $148 = $147 & 65535;
    $149 = $146 + ($148 << 3) | 0;
    $150 = HEAP32[$149 >> 2] | 0;
    $151 = $144 - $150 | 0;
    $152 = $142 + ($3 << 3) + 4 | 0;
    $153 = HEAP32[$152 >> 2] | 0;
    $154 = $146 + ($148 << 3) + 4 | 0;
    $155 = HEAP32[$154 >> 2] | 0;
    $156 = $153 - $155 | 0;
    $157 = FUNCTION_TABLE_iiii[$140 & 1023]($exc, $151, $156) | 0;
    $158 = $exc + 584 | 0;
    $159 = HEAP32[$158 >> 2] | 0;
    $160 = $distance_1 - $157 | 0;
    FUNCTION_TABLE_viiii[$159 & 1023]($exc, $4, $2, $160);
    $161 = HEAP16[$10 >> 1] | 0;
    $162 = $exc + 286 | 0;
    HEAP16[$162 >> 1] = $161;
    $163 = $exc + 288 | 0;
    HEAP16[$163 >> 1] = $2;
    $164 = HEAP8[$108] | 0;
    $165 = $164 & 16;
    $166 = $165 << 24 >> 24 == 0;
    if ($166) {
      label = 22;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    HEAP16[$10 >> 1] = $2;
    label = 22;
    break;
   case 22:
    return;
  }
}
function _Ins_PUSHW($exc, $args) {
  $exc = $exc | 0;
  $args = $args | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $K_09 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 368 | 0;
    $2 = HEAP8[$1] | 0;
    $3 = $2 & 255;
    $4 = $3 + 65353 | 0;
    $5 = $4 & 65535;
    $6 = $exc + 20 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 + 1 | 0;
    $9 = $exc + 16 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $8 - $10 | 0;
    $12 = $5 >>> 0 < $11 >>> 0;
    if ($12) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $14 = $exc + 12 | 0;
    HEAP32[$14 >> 2] = 130;
    label = 6;
    break;
   case 3:
    $16 = $exc + 360 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $17 + 1 | 0;
    HEAP32[$16 >> 2] = $18;
    $19 = ($5 | 0) == 0;
    if ($19) {
      label = 5;
      break;
    } else {
      $K_09 = 0;
      $20 = 0;
      label = 4;
      break;
    }
   case 4:
    $21 = _GetShortIns($exc) | 0;
    $22 = $21 << 16 >> 16;
    $23 = $args + ($20 << 2) | 0;
    HEAP32[$23 >> 2] = $22;
    $24 = $K_09 + 1 & 65535;
    $25 = $24 & 65535;
    $26 = $25 >>> 0 < $5 >>> 0;
    if ($26) {
      $K_09 = $24;
      $20 = $25;
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $27 = $exc + 376 | 0;
    HEAP8[$27] = 0;
    label = 6;
    break;
   case 6:
    return;
  }
}
function _TT_MulFix14($a, $b) {
  $a = $a | 0;
  $b = $b | 0;
  var $_a = 0, $_017 = 0, $8 = 0, $9 = 0, $uadd$0 = 0, $18 = 0;
  $_a = ($a | 0) < 0 ? -$a | 0 : $a;
  $_017 = ($b | 0) < 0 ? -$b | 0 : $b;
  $8 = Math_imul($_a & 65535, $_017);
  $9 = Math_imul($_a >>> 16, $_017);
  $uadd$0 = _llvm_uadd_with_overflow_i32($8 | 0, $9 << 16 | 8192 | 0) | 0;
  $18 = (tempRet0 & 1) + ($9 >>> 16) << 18 | $uadd$0 >>> 14;
  return (($b ^ $a | 0) > -1 ? $18 : -$18 | 0) | 0;
}
function _Project_x($exc, $dx, $dy) {
  $exc = $exc | 0;
  $dx = $dx | 0;
  $dy = $dy | 0;
  return $dx | 0;
}
function _Project_y($exc, $dx, $dy) {
  $exc = $exc | 0;
  $dx = $dx | 0;
  $dy = $dy | 0;
  return $dy | 0;
}
function _SkipCode($exc) {
  $exc = $exc | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $_off = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 372 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $exc + 360 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + $2 | 0;
    HEAP32[$3 >> 2] = $5;
    $6 = $exc + 364 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = ($5 | 0) < ($7 | 0);
    if ($8) {
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $10 = $exc + 356 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 + $5 | 0;
    $13 = HEAP8[$12] | 0;
    $14 = $exc + 368 | 0;
    HEAP8[$14] = $13;
    $15 = $13 & 255;
    $16 = $15 + 5251024 | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 << 24 >> 24;
    HEAP32[$1 >> 2] = $18;
    $_off = $15 - 64 | 0;
    $19 = $_off >>> 0 < 2;
    if ($19) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $21 = HEAP32[$3 >> 2] | 0;
    $22 = $21 + 1 | 0;
    $23 = HEAP32[$6 >> 2] | 0;
    $24 = ($22 | 0) > ($23 | 0);
    if ($24) {
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $26 = HEAP32[$10 >> 2] | 0;
    $27 = $26 + $22 | 0;
    $28 = HEAP8[$27] | 0;
    $29 = $28 & 255;
    $30 = Math_imul($29, $18);
    $31 = 2 - $30 | 0;
    HEAP32[$1 >> 2] = $31;
    label = 5;
    break;
   case 5:
    $33 = HEAP32[$3 >> 2] | 0;
    $34 = HEAP32[$1 >> 2] | 0;
    $35 = $34 + $33 | 0;
    $36 = HEAP32[$6 >> 2] | 0;
    $37 = ($35 | 0) > ($36 | 0);
    if ($37) {
      label = 6;
      break;
    } else {
      $_0 = 0;
      label = 7;
      break;
    }
   case 6:
    $39 = $exc + 12 | 0;
    HEAP32[$39 >> 2] = 131;
    $_0 = 1;
    label = 7;
    break;
   case 7:
    return $_0 | 0;
  }
  return 0;
}
function _Move_Zp2_Point($exc, $point, $dx, $dy, $touch) {
  $exc = $exc | 0;
  $point = $point | 0;
  $dx = $dx | 0;
  $dy = $dy | 0;
  $touch = $touch | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 298 | 0;
    $2 = HEAP16[$1 >> 1] | 0;
    $3 = $2 << 16 >> 16 == 0;
    if ($3) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $point & 65535;
    $6 = $exc + 124 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 + ($5 << 3) | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 + $dx | 0;
    HEAP32[$8 >> 2] = $10;
    $11 = $touch << 24 >> 24 == 0;
    if ($11) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $13 = $exc + 132 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 + $5 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 | 8;
    HEAP8[$15] = $17;
    label = 4;
    break;
   case 4:
    $19 = $exc + 300 | 0;
    $20 = HEAP16[$19 >> 1] | 0;
    $21 = $20 << 16 >> 16 == 0;
    if ($21) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $23 = $point & 65535;
    $24 = $exc + 124 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $25 + ($23 << 3) + 4 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $27 + $dy | 0;
    HEAP32[$26 >> 2] = $28;
    $29 = $touch << 24 >> 24 == 0;
    if ($29) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $31 = $exc + 132 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $32 + $23 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 | 16;
    HEAP8[$33] = $35;
    label = 7;
    break;
   case 7:
    return;
  }
}
function __iup_worker_shift($worker, $p1, $p2, $p) {
  $worker = $worker | 0;
  $p1 = $p1 | 0;
  $p2 = $p2 | 0;
  $p = $p | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $i_117 = 0, $12 = 0, $i_020 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $exitcond = 0, $i_118 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $i_1 = 0, $22 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $worker + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + ($p << 3) | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $worker | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + ($p << 3) | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $4 - $8 | 0;
    $10 = ($4 | 0) == ($8 | 0);
    if ($10) {
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $11 = $p1 >>> 0 < $p >>> 0;
    if ($11) {
      $i_020 = $p1;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $i_117 = $p + 1 | 0;
    $12 = $i_117 >>> 0 > $p2 >>> 0;
    if ($12) {
      label = 6;
      break;
    } else {
      $i_118 = $i_117;
      label = 5;
      break;
    }
   case 4:
    $13 = HEAP32[$1 >> 2] | 0;
    $14 = $13 + ($i_020 << 3) | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15 + $9 | 0;
    HEAP32[$14 >> 2] = $16;
    $17 = $i_020 + 1 | 0;
    $exitcond = ($17 | 0) == ($p | 0);
    if ($exitcond) {
      label = 3;
      break;
    } else {
      $i_020 = $17;
      label = 4;
      break;
    }
   case 5:
    $18 = HEAP32[$1 >> 2] | 0;
    $19 = $18 + ($i_118 << 3) | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $20 + $9 | 0;
    HEAP32[$19 >> 2] = $21;
    $i_1 = $i_118 + 1 | 0;
    $22 = $i_1 >>> 0 > $p2 >>> 0;
    if ($22) {
      label = 6;
      break;
    } else {
      $i_118 = $i_1;
      label = 5;
      break;
    }
   case 6:
    return;
  }
}
function _Direct_Move_X($exc, $zone, $point, $distance) {
  $exc = $exc | 0;
  $zone = $zone | 0;
  $point = $point | 0;
  $distance = $distance | 0;
  var $1 = 0, $4 = 0, $9 = 0;
  $1 = $point & 65535;
  $4 = (HEAP32[$zone + 16 >> 2] | 0) + ($1 << 3) | 0;
  HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + $distance | 0;
  $9 = (HEAP32[$zone + 24 >> 2] | 0) + $1 | 0;
  HEAP8[$9] = HEAP8[$9] | 8;
  return;
}
function _Direct_Move_Orig_X($exc, $zone, $point, $distance) {
  $exc = $exc | 0;
  $zone = $zone | 0;
  $point = $point | 0;
  $distance = $distance | 0;
  var $4 = 0;
  $4 = (HEAP32[$zone + 12 >> 2] | 0) + (($point & 65535) << 3) | 0;
  HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + $distance | 0;
  return;
}
function _Direct_Move_Y($exc, $zone, $point, $distance) {
  $exc = $exc | 0;
  $zone = $zone | 0;
  $point = $point | 0;
  $distance = $distance | 0;
  var $1 = 0, $4 = 0, $9 = 0;
  $1 = $point & 65535;
  $4 = (HEAP32[$zone + 16 >> 2] | 0) + ($1 << 3) + 4 | 0;
  HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + $distance | 0;
  $9 = (HEAP32[$zone + 24 >> 2] | 0) + $1 | 0;
  HEAP8[$9] = HEAP8[$9] | 16;
  return;
}
function _Direct_Move_Orig_Y($exc, $zone, $point, $distance) {
  $exc = $exc | 0;
  $zone = $zone | 0;
  $point = $point | 0;
  $distance = $distance | 0;
  var $4 = 0;
  $4 = (HEAP32[$zone + 12 >> 2] | 0) + (($point & 65535) << 3) + 4 | 0;
  HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + $distance | 0;
  return;
}
function _Current_Ratio($exc) {
  $exc = $exc | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 244 | 0;
    $2 = $exc + 256 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 7;
      break;
    }
   case 2:
    $6 = $exc + 296 | 0;
    $7 = HEAP16[$6 >> 1] | 0;
    $8 = $7 << 16 >> 16 == 0;
    if ($8) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $10 = $1 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    HEAP32[$2 >> 2] = $11;
    label = 7;
    break;
   case 4:
    $13 = $exc + 294 | 0;
    $14 = HEAP16[$13 >> 1] | 0;
    $15 = $14 << 16 >> 16 == 0;
    if ($15) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $17 = $exc + 248 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    HEAP32[$2 >> 2] = $18;
    label = 7;
    break;
   case 6:
    $20 = $14 << 16 >> 16;
    $21 = $1 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = _FT_MulDiv($20, $22, 16384) | 0;
    $24 = HEAP16[$6 >> 1] | 0;
    $25 = $24 << 16 >> 16;
    $26 = $exc + 248 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = _FT_MulDiv($25, $27, 16384) | 0;
    $29 = _TT_VecLen($23, $28) | 0;
    HEAP32[$2 >> 2] = $29;
    label = 7;
    break;
   case 7:
    $31 = HEAP32[$2 >> 2] | 0;
    return $31 | 0;
  }
  return 0;
}
function _TT_VecLen($X, $Y) {
  $X = $X | 0;
  $Y = $Y | 0;
  var $v = 0, $3 = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  $v = __stackBase__ | 0;
  HEAP32[$v >> 2] = $X;
  HEAP32[$v + 4 >> 2] = $Y;
  $3 = _FT_Vector_Length($v) | 0;
  STACKTOP = __stackBase__;
  return $3 | 0;
}
function _Compute_Point_Displacement($exc, $x, $y, $zone, $refp) {
  $exc = $exc | 0;
  $x = $x | 0;
  $y = $y | 0;
  $zone = $zone | 0;
  $refp = $refp | 0;
  var $zp_sroa_5 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $zp_sroa_0_0__idx9 = 0, $6 = 0, $ld$0$0 = 0, $7$0 = 0, $ld$1$1 = 0, $7$1 = 0, $zp_sroa_1_8__idx15 = 0, $zp_sroa_1_8_copyload16 = 0, $zp_sroa_2_10__idx20 = 0, $zp_sroa_2_10_copyload21 = 0, $zp_sroa_3_12__idx26 = 0, $zp_sroa_3_12_copyload27 = 0, $zp_sroa_4_16__idx32 = 0, $zp_sroa_4_16_copyload33 = 0, $zp_sroa_5_20__idx37 = 0, $zp_sroa_5_20__cast38 = 0, $zp_sroa_5_20_cast39 = 0, $8 = 0, $zp_sroa_0_0__idx = 0, $10 = 0, $ld$2$0 = 0, $11$0 = 0, $ld$3$1 = 0, $11$1 = 0, $zp_sroa_1_8__idx13 = 0, $zp_sroa_1_8_copyload14 = 0, $zp_sroa_2_10__idx18 = 0, $zp_sroa_2_10_copyload19 = 0, $zp_sroa_3_12__idx24 = 0, $zp_sroa_3_12_copyload25 = 0, $zp_sroa_4_16__idx30 = 0, $zp_sroa_4_16_copyload31 = 0, $zp_sroa_5_20__idx34 = 0, $zp_sroa_5_20__cast35 = 0, $zp_sroa_5_20_cast36 = 0, $12 = 0, $14$0 = 0, $14$1 = 0, $zp_sroa_4_0 = 0, $zp_sroa_3_0 = 0, $zp_sroa_2_0 = 0, $zp_sroa_1_0 = 0, $p_0_in = 0, $p_0 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $25 = 0, $st$4$0 = 0, $st$5$1 = 0, $zp_sroa_1_8__idx12 = 0, $zp_sroa_2_10__idx17 = 0, $zp_sroa_3_12__idx23 = 0, $zp_sroa_4_16__idx29 = 0, $zp_sroa_5_20__idx = 0, $zp_sroa_5_20__cast = 0, $zp_sroa_5_20_cast = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $zp_sroa_5 = __stackBase__ | 0;
    $1 = $exc + 368 | 0;
    $2 = HEAP8[$1] | 0;
    $3 = $2 & 1;
    $4 = $3 << 24 >> 24 == 0;
    if ($4) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $zp_sroa_0_0__idx9 = $exc + 36 | 0;
    $6 = $zp_sroa_0_0__idx9;
    $ld$0$0 = $6 | 0;
    $7$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $6 + 4 | 0;
    $7$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $zp_sroa_1_8__idx15 = $exc + 44 | 0;
    $zp_sroa_1_8_copyload16 = HEAP16[$zp_sroa_1_8__idx15 >> 1] | 0;
    $zp_sroa_2_10__idx20 = $exc + 46 | 0;
    $zp_sroa_2_10_copyload21 = HEAP16[$zp_sroa_2_10__idx20 >> 1] | 0;
    $zp_sroa_3_12__idx26 = $exc + 48 | 0;
    $zp_sroa_3_12_copyload27 = HEAP32[$zp_sroa_3_12__idx26 >> 2] | 0;
    $zp_sroa_4_16__idx32 = $exc + 52 | 0;
    $zp_sroa_4_16_copyload33 = HEAP32[$zp_sroa_4_16__idx32 >> 2] | 0;
    $zp_sroa_5_20__idx37 = $exc + 56 | 0;
    $zp_sroa_5_20__cast38 = $zp_sroa_5_20__idx37;
    $zp_sroa_5_20_cast39 = $zp_sroa_5;
    _memcpy($zp_sroa_5_20_cast39 | 0, $zp_sroa_5_20__cast38 | 0, 16);
    $8 = $exc + 286 | 0;
    $p_0_in = $8;
    $zp_sroa_1_0 = $zp_sroa_1_8_copyload16;
    $zp_sroa_2_0 = $zp_sroa_2_10_copyload21;
    $zp_sroa_3_0 = $zp_sroa_3_12_copyload27;
    $zp_sroa_4_0 = $zp_sroa_4_16_copyload33;
    $14$1 = $7$1;
    $14$0 = $7$0;
    label = 4;
    break;
   case 3:
    $zp_sroa_0_0__idx = $exc + 72 | 0;
    $10 = $zp_sroa_0_0__idx;
    $ld$2$0 = $10 | 0;
    $11$0 = HEAP32[$ld$2$0 >> 2] | 0;
    $ld$3$1 = $10 + 4 | 0;
    $11$1 = HEAP32[$ld$3$1 >> 2] | 0;
    $zp_sroa_1_8__idx13 = $exc + 80 | 0;
    $zp_sroa_1_8_copyload14 = HEAP16[$zp_sroa_1_8__idx13 >> 1] | 0;
    $zp_sroa_2_10__idx18 = $exc + 82 | 0;
    $zp_sroa_2_10_copyload19 = HEAP16[$zp_sroa_2_10__idx18 >> 1] | 0;
    $zp_sroa_3_12__idx24 = $exc + 84 | 0;
    $zp_sroa_3_12_copyload25 = HEAP32[$zp_sroa_3_12__idx24 >> 2] | 0;
    $zp_sroa_4_16__idx30 = $exc + 88 | 0;
    $zp_sroa_4_16_copyload31 = HEAP32[$zp_sroa_4_16__idx30 >> 2] | 0;
    $zp_sroa_5_20__idx34 = $exc + 92 | 0;
    $zp_sroa_5_20__cast35 = $zp_sroa_5_20__idx34;
    $zp_sroa_5_20_cast36 = $zp_sroa_5;
    _memcpy($zp_sroa_5_20_cast36 | 0, $zp_sroa_5_20__cast35 | 0, 16);
    $12 = $exc + 288 | 0;
    $p_0_in = $12;
    $zp_sroa_1_0 = $zp_sroa_1_8_copyload14;
    $zp_sroa_2_0 = $zp_sroa_2_10_copyload19;
    $zp_sroa_3_0 = $zp_sroa_3_12_copyload25;
    $zp_sroa_4_0 = $zp_sroa_4_16_copyload31;
    $14$1 = $11$1;
    $14$0 = $11$0;
    label = 4;
    break;
   case 4:
    $p_0 = HEAP16[$p_0_in >> 1] | 0;
    $15 = $p_0 & 65535;
    $16 = ($p_0 & 65535) < ($zp_sroa_1_0 & 65535);
    if ($16) {
      label = 8;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $18 = $exc + 561 | 0;
    $19 = HEAP8[$18] | 0;
    $20 = $19 << 24 >> 24 == 0;
    if ($20) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $22 = $exc + 12 | 0;
    HEAP32[$22 >> 2] = 134;
    label = 7;
    break;
   case 7:
    HEAP16[$refp >> 1] = 0;
    $_0 = 1;
    label = 9;
    break;
   case 8:
    $25 = $zone;
    $st$4$0 = $25 | 0;
    HEAP32[$st$4$0 >> 2] = $14$0;
    $st$5$1 = $25 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $14$1;
    $zp_sroa_1_8__idx12 = $zone + 8 | 0;
    HEAP16[$zp_sroa_1_8__idx12 >> 1] = $zp_sroa_1_0;
    $zp_sroa_2_10__idx17 = $zone + 10 | 0;
    HEAP16[$zp_sroa_2_10__idx17 >> 1] = $zp_sroa_2_0;
    $zp_sroa_3_12__idx23 = $zone + 12 | 0;
    HEAP32[$zp_sroa_3_12__idx23 >> 2] = $zp_sroa_3_0;
    $zp_sroa_4_16__idx29 = $zone + 16 | 0;
    HEAP32[$zp_sroa_4_16__idx29 >> 2] = $zp_sroa_4_0;
    $zp_sroa_5_20__idx = $zone + 20 | 0;
    $zp_sroa_5_20__cast = $zp_sroa_5_20__idx;
    $zp_sroa_5_20_cast = $zp_sroa_5;
    _memcpy($zp_sroa_5_20__cast | 0, $zp_sroa_5_20_cast | 0, 16);
    HEAP16[$refp >> 1] = $p_0;
    $26 = $exc + 572 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $zp_sroa_4_0 + ($15 << 3) | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $zp_sroa_3_0 + ($15 << 3) | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $29 - $31 | 0;
    $33 = $zp_sroa_4_0 + ($15 << 3) + 4 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $zp_sroa_3_0 + ($15 << 3) + 4 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $34 - $36 | 0;
    $38 = FUNCTION_TABLE_iiii[$27 & 1023]($exc, $32, $37) | 0;
    $39 = $exc + 298 | 0;
    $40 = HEAP16[$39 >> 1] | 0;
    $41 = $40 << 16 >> 16;
    $42 = $41 << 16;
    $43 = $exc + 564 | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    $45 = _FT_MulDiv($38, $42, $44) | 0;
    HEAP32[$x >> 2] = $45;
    $46 = $exc + 300 | 0;
    $47 = HEAP16[$46 >> 1] | 0;
    $48 = $47 << 16 >> 16;
    $49 = $48 << 16;
    $50 = HEAP32[$43 >> 2] | 0;
    $51 = _FT_MulDiv($38, $49, $50) | 0;
    HEAP32[$y >> 2] = $51;
    $_0 = 0;
    label = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function __iup_worker_interpolate($worker, $p1, $p2, $ref1, $ref2) {
  $worker = $worker | 0;
  $p1 = $p1 | 0;
  $p2 = $p2 | 0;
  $ref1 = $ref1 | 0;
  $ref2 = $ref2 | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $or_cond = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $_ = 0, $_63 = 0, $ref1_ref2 = 0, $ref2_ref1 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $i_065 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $_64 = 0, $x_0 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $scale_valid_070 = 0, $scale_069 = 0, $i_168 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $49 = 0, $51 = 0, $53 = 0, $55 = 0, $scale_1 = 0, $scale_valid_1 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $scale_2 = 0, $scale_valid_2 = 0, $x1_0 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $p1 >>> 0 > $p2 >>> 0;
    if ($1) {
      label = 16;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $worker + 12 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 >>> 0 > $ref1 >>> 0;
    $6 = $4 >>> 0 > $ref2 >>> 0;
    $or_cond = $5 & $6;
    if ($or_cond) {
      label = 3;
      break;
    } else {
      label = 16;
      break;
    }
   case 3:
    $8 = $worker + 8 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 + ($ref1 << 3) | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $9 + ($ref2 << 3) | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = ($11 | 0) > ($13 | 0);
    $_ = $14 ? $11 : $13;
    $_63 = $14 ? $13 : $11;
    $ref1_ref2 = $14 ? $ref1 : $ref2;
    $ref2_ref1 = $14 ? $ref2 : $ref1;
    $15 = $worker | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $16 + ($ref2_ref1 << 3) | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $16 + ($ref1_ref2 << 3) | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $worker + 4 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22 + ($ref2_ref1 << 3) | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24 - $18 | 0;
    $26 = $22 + ($ref1_ref2 << 3) | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $27 - $20 | 0;
    $29 = ($_63 | 0) == ($_ | 0);
    $30 = $p1 >>> 0 > $p2 >>> 0;
    if ($29) {
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    if ($30) {
      label = 16;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $31 = $27 - $24 | 0;
    $32 = $_ - $_63 | 0;
    $i_168 = $p1;
    $scale_069 = 0;
    $scale_valid_070 = 0;
    label = 8;
    break;
   case 6:
    if ($30) {
      label = 16;
      break;
    } else {
      $i_065 = $p1;
      label = 7;
      break;
    }
   case 7:
    $33 = HEAP32[$15 >> 2] | 0;
    $34 = $33 + ($i_065 << 3) | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = ($35 | 0) > ($18 | 0);
    $_64 = $36 ? $28 : $25;
    $x_0 = $_64 + $35 | 0;
    $37 = HEAP32[$21 >> 2] | 0;
    $38 = $37 + ($i_065 << 3) | 0;
    HEAP32[$38 >> 2] = $x_0;
    $39 = $i_065 + 1 | 0;
    $40 = $39 >>> 0 > $p2 >>> 0;
    if ($40) {
      label = 16;
      break;
    } else {
      $i_065 = $39;
      label = 7;
      break;
    }
   case 8:
    $42 = HEAP32[$15 >> 2] | 0;
    $43 = $42 + ($i_168 << 3) | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    $45 = ($44 | 0) > ($18 | 0);
    if ($45) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $47 = $44 + $25 | 0;
    $x1_0 = $47;
    $scale_valid_2 = $scale_valid_070;
    $scale_2 = $scale_069;
    label = 15;
    break;
   case 10:
    $49 = ($44 | 0) < ($20 | 0);
    if ($49) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $51 = $44 + $28 | 0;
    $x1_0 = $51;
    $scale_valid_2 = $scale_valid_070;
    $scale_2 = $scale_069;
    label = 15;
    break;
   case 12:
    $53 = $scale_valid_070 << 24 >> 24 == 0;
    if ($53) {
      label = 13;
      break;
    } else {
      $scale_valid_1 = $scale_valid_070;
      $scale_1 = $scale_069;
      label = 14;
      break;
    }
   case 13:
    $55 = _FT_MulDiv($31, 65536, $32) | 0;
    $scale_valid_1 = 1;
    $scale_1 = $55;
    label = 14;
    break;
   case 14:
    $57 = HEAP32[$8 >> 2] | 0;
    $58 = $57 + ($i_168 << 3) | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = $59 - $_63 | 0;
    $61 = _FT_MulFix($60, $scale_1) | 0;
    $62 = $61 + $24 | 0;
    $x1_0 = $62;
    $scale_valid_2 = $scale_valid_1;
    $scale_2 = $scale_1;
    label = 15;
    break;
   case 15:
    $64 = HEAP32[$21 >> 2] | 0;
    $65 = $64 + ($i_168 << 3) | 0;
    HEAP32[$65 >> 2] = $x1_0;
    $66 = $i_168 + 1 | 0;
    $67 = $66 >>> 0 > $p2 >>> 0;
    if ($67) {
      label = 16;
      break;
    } else {
      $i_168 = $66;
      $scale_069 = $scale_2;
      $scale_valid_070 = $scale_valid_2;
      label = 8;
      break;
    }
   case 16:
    return;
  }
}
function _Project($exc, $dx, $dy) {
  $exc = $exc | 0;
  $dx = $dx | 0;
  $dy = $dy | 0;
  return _TT_DotFix14($dx, $dy, HEAP16[$exc + 294 >> 1] << 16 >> 16, HEAP16[$exc + 296 >> 1] << 16 >> 16) | 0;
}
function _Dual_Project($exc, $dx, $dy) {
  $exc = $exc | 0;
  $dx = $dx | 0;
  $dy = $dy | 0;
  return _TT_DotFix14($dx, $dy, HEAP16[$exc + 290 >> 1] << 16 >> 16, HEAP16[$exc + 292 >> 1] << 16 >> 16) | 0;
}
function _Direct_Move($exc, $zone, $point, $distance) {
  $exc = $exc | 0;
  $zone = $zone | 0;
  $point = $point | 0;
  $distance = $distance | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 298 | 0;
    $2 = HEAP16[$1 >> 1] | 0;
    $3 = $2 << 16 >> 16 == 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 << 16 >> 16;
    $6 = $5 << 16;
    $7 = $exc + 564 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = _FT_MulDiv($distance, $6, $8) | 0;
    $10 = $point & 65535;
    $11 = $zone + 16 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + ($10 << 3) | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 + $9 | 0;
    HEAP32[$13 >> 2] = $15;
    $16 = $zone + 24 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $17 + $10 | 0;
    $19 = HEAP8[$18] | 0;
    $20 = $19 | 8;
    HEAP8[$18] = $20;
    label = 3;
    break;
   case 3:
    $22 = $exc + 300 | 0;
    $23 = HEAP16[$22 >> 1] | 0;
    $24 = $23 << 16 >> 16 == 0;
    if ($24) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $26 = $23 << 16 >> 16;
    $27 = $26 << 16;
    $28 = $exc + 564 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = _FT_MulDiv($distance, $27, $29) | 0;
    $31 = $point & 65535;
    $32 = $zone + 16 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $33 + ($31 << 3) + 4 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $35 + $30 | 0;
    HEAP32[$34 >> 2] = $36;
    $37 = $zone + 24 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $38 + $31 | 0;
    $40 = HEAP8[$39] | 0;
    $41 = $40 | 16;
    HEAP8[$39] = $41;
    label = 5;
    break;
   case 5:
    return;
  }
}
function _Direct_Move_Orig($exc, $zone, $point, $distance) {
  $exc = $exc | 0;
  $zone = $zone | 0;
  $point = $point | 0;
  $distance = $distance | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $exc + 298 | 0;
    $2 = HEAP16[$1 >> 1] | 0;
    $3 = $2 << 16 >> 16 == 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 << 16 >> 16;
    $6 = $5 << 16;
    $7 = $exc + 564 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = _FT_MulDiv($distance, $6, $8) | 0;
    $10 = $point & 65535;
    $11 = $zone + 12 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + ($10 << 3) | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 + $9 | 0;
    HEAP32[$13 >> 2] = $15;
    label = 3;
    break;
   case 3:
    $17 = $exc + 300 | 0;
    $18 = HEAP16[$17 >> 1] | 0;
    $19 = $18 << 16 >> 16 == 0;
    if ($19) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $21 = $18 << 16 >> 16;
    $22 = $21 << 16;
    $23 = $exc + 564 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = _FT_MulDiv($distance, $22, $24) | 0;
    $26 = $point & 65535;
    $27 = $zone + 12 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $28 + ($26 << 3) + 4 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $30 + $25 | 0;
    HEAP32[$29 >> 2] = $31;
    label = 5;
    break;
   case 5:
    return;
  }
}
function _TT_DotFix14($ax, $ay, $bx, $by) {
  $ax = $ax | 0;
  $ay = $ay | 0;
  $bx = $bx | 0;
  $by = $by | 0;
  var $2 = 0, $4 = 0, $uadd$0 = 0, $10 = 0, $12 = 0, $14 = 0, $uadd31$0 = 0, $20 = 0, $uadd32$0 = 0, $29 = 0, $30 = 0, $uadd33$0 = 0, $33 = 0, $uadd34$0 = 0;
  $2 = Math_imul($ax & 65535, $bx);
  $4 = Math_imul($ax >> 16, $bx);
  $uadd$0 = _llvm_uadd_with_overflow_i32($2 | 0, $4 << 16 | 0) | 0;
  $10 = tempRet0 & 1;
  $12 = Math_imul($ay & 65535, $by);
  $14 = Math_imul($ay >> 16, $by);
  $uadd31$0 = _llvm_uadd_with_overflow_i32($12 | 0, $14 << 16 | 0) | 0;
  $20 = tempRet0 & 1;
  $uadd32$0 = _llvm_uadd_with_overflow_i32($uadd$0 | 0, $uadd31$0 | 0) | 0;
  $29 = (((((($4 >> 16) + ($2 >> 31) | 0) + ($12 >> 31) | 0) + ($14 >> 16) | 0) + $10 | 0) + $20 | 0) + (tempRet0 & 1) | 0;
  $30 = $29 >> 31;
  $uadd33$0 = _llvm_uadd_with_overflow_i32($uadd32$0 | 0, $30 | 0) | 0;
  $33 = tempRet0 & 1;
  $uadd34$0 = _llvm_uadd_with_overflow_i32($uadd33$0 | 0, 8192) | 0;
  return (($29 + $33 | 0) + $30 | 0) + (tempRet0 & 1) << 18 | $uadd34$0 >>> 14 | 0;
}
function _TT_Done_Context($exec) {
  $exec = $exec | 0;
  var $2 = 0, $5 = 0, $9 = 0, $14 = 0;
  $2 = HEAP32[$exec + 8 >> 2] | 0;
  HEAP16[$exec + 440 >> 1] = 0;
  HEAP16[$exec + 442 >> 1] = 0;
  $5 = $exec + 24 | 0;
  _ft_mem_free($2, HEAP32[$5 >> 2] | 0);
  HEAP32[$5 >> 2] = 0;
  HEAP32[$exec + 20 >> 2] = 0;
  $9 = $exec + 436 | 0;
  _ft_mem_free($2, HEAP32[$9 >> 2] | 0);
  HEAP32[$9 >> 2] = 0;
  HEAP32[$exec + 432 >> 2] = 0;
  HEAP32[$exec + 428 >> 2] = 0;
  $14 = $exec + 392 | 0;
  _ft_mem_free($2, HEAP32[$14 >> 2] | 0);
  HEAP32[$14 >> 2] = 0;
  HEAP32[$exec + 388 >> 2] = 0;
  HEAP32[$exec + 4 >> 2] = 0;
  HEAP32[$exec >> 2] = 0;
  _ft_mem_free($2, $exec);
  return;
}
function _tt_size_done_bytecode($ftsize) {
  $ftsize = $ftsize | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $ftsize;
    $2 = $ftsize | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 + 100 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $ftsize + 292 | 0;
    $7 = $6;
    $8 = HEAP8[$7] | 0;
    $9 = $8 << 24 >> 24 == 0;
    if ($9) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $11 = $ftsize + 296 | 0;
    HEAP32[$11 >> 2] = 0;
    HEAP8[$7] = 0;
    label = 3;
    break;
   case 3:
    $13 = $ftsize + 244 | 0;
    $14 = $13;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15;
    _ft_mem_free($5, $16);
    HEAP32[$13 >> 2] = 0;
    $17 = $ftsize + 240 | 0;
    HEAP32[$17 >> 2] = 0;
    $18 = $ftsize + 252 | 0;
    $19 = $18;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $20;
    _ft_mem_free($5, $21);
    HEAP32[$18 >> 2] = 0;
    $22 = $ftsize + 248 | 0;
    $23 = $22;
    HEAP16[$23 >> 1] = 0;
    $24 = $ftsize + 256 | 0;
    $25 = $24;
    _tt_glyphzone_done($25);
    $26 = $ftsize + 124 | 0;
    $27 = $26;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $28;
    _ft_mem_free($5, $29);
    HEAP32[$26 >> 2] = 0;
    $30 = $ftsize + 136 | 0;
    $31 = $30;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $32;
    _ft_mem_free($5, $33);
    $34 = $ftsize + 116 | 0;
    HEAP32[$34 >> 2] = 0;
    $35 = $ftsize + 120 | 0;
    HEAP32[$35 >> 2] = 0;
    $36 = $ftsize + 128 | 0;
    $37 = $ftsize + 300 | 0;
    $38 = $37;
    HEAP8[$38] = 0;
    $39 = $1 + 301 | 0;
    $40 = $36;
    _memset($40 | 0, 0, 20);
    HEAP8[$39] = 0;
    return;
  }
}
function _tt_glyphzone_done($zone) {
  $zone = $zone | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $zone | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $zone + 28 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6;
    _ft_mem_free($2, $7);
    HEAP32[$5 >> 2] = 0;
    $8 = $zone + 24 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    _ft_mem_free($2, $9);
    HEAP32[$8 >> 2] = 0;
    $10 = $zone + 16 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11;
    _ft_mem_free($2, $12);
    HEAP32[$10 >> 2] = 0;
    $13 = $zone + 12 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14;
    _ft_mem_free($2, $15);
    HEAP32[$13 >> 2] = 0;
    $16 = $zone + 20 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $17;
    _ft_mem_free($2, $18);
    HEAP32[$16 >> 2] = 0;
    $19 = $zone;
    _memset($19 | 0, 0, 12);
    label = 3;
    break;
   case 3:
    return;
  }
}
function _tt_face_done_loca($face) {
  $face = $face | 0;
  _FT_Stream_ReleaseFrame(HEAP32[$face + 104 >> 2] | 0, $face + 736 | 0);
  HEAP32[$face + 732 >> 2] = 0;
  return;
}
function _tt_face_free_hdmx($face) {
  $face = $face | 0;
  var $2 = 0, $5 = 0;
  $2 = HEAP32[$face + 104 >> 2] | 0;
  $5 = $face + 756 | 0;
  _ft_mem_free(HEAP32[$2 + 28 >> 2] | 0, HEAP32[$5 >> 2] | 0);
  HEAP32[$5 >> 2] = 0;
  _FT_Stream_ReleaseFrame($2, $face + 740 | 0);
  return;
}
function _tt_done_blend($memory, $blend) {
  $memory = $memory | 0;
  $blend = $blend | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $i_025 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $_lcssa = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($blend | 0) == 0;
    if ($1) {
      label = 7;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $blend + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4;
    _ft_mem_free($memory, $5);
    HEAP32[$3 >> 2] = 0;
    $6 = $blend + 8 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7;
    _ft_mem_free($memory, $8);
    HEAP32[$6 >> 2] = 0;
    $9 = $blend + 20 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = $blend | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = ($13 | 0) == 0;
    $15 = HEAP32[$9 >> 2] | 0;
    if ($14) {
      $_lcssa = $15;
      label = 5;
      break;
    } else {
      $i_025 = 0;
      $16 = $15;
      label = 4;
      break;
    }
   case 4:
    $17 = $16 + ($i_025 << 3) + 4 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $18;
    _ft_mem_free($memory, $19);
    $20 = HEAP32[$9 >> 2] | 0;
    $21 = $20 + ($i_025 << 3) + 4 | 0;
    HEAP32[$21 >> 2] = 0;
    $22 = $i_025 + 1 | 0;
    $23 = HEAP32[$12 >> 2] | 0;
    $24 = $22 >>> 0 < $23 >>> 0;
    $25 = HEAP32[$9 >> 2] | 0;
    if ($24) {
      $i_025 = $22;
      $16 = $25;
      label = 4;
      break;
    } else {
      $_lcssa = $25;
      label = 5;
      break;
    }
   case 5:
    $26 = $_lcssa;
    _ft_mem_free($memory, $26);
    HEAP32[$9 >> 2] = 0;
    label = 6;
    break;
   case 6:
    $28 = $blend + 28 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $29;
    _ft_mem_free($memory, $30);
    HEAP32[$28 >> 2] = 0;
    $31 = $blend + 36 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $32;
    _ft_mem_free($memory, $33);
    HEAP32[$31 >> 2] = 0;
    $34 = $blend;
    _ft_mem_free($memory, $34);
    label = 7;
    break;
   case 7:
    return;
  }
}
function _tt_check_trickyness($face) {
  $face = $face | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $not_ = 0, $_ = 0, $9 = 0, $10 = 0, $not_5 = 0, $_4 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($face | 0) == 0;
    if ($1) {
      $_0 = 0;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 20 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = _tt_check_trickyness_family($4) | 0;
    $not_ = $7 << 24 >> 24 != 0;
    $_ = $not_ & 1;
    $_0 = $_;
    label = 5;
    break;
   case 4:
    $9 = $face;
    $10 = _tt_check_trickyness_sfnt_ids($9) | 0;
    $not_5 = $10 << 24 >> 24 != 0;
    $_4 = $not_5 & 1;
    $_0 = $_4;
    label = 5;
    break;
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function _TT_Init_Glyph_Loading($face) {
  $face = $face | 0;
  HEAP32[$face + 512 >> 2] = 336;
  HEAP32[$face + 520 >> 2] = 660;
  HEAP32[$face + 524 >> 2] = 722;
  HEAP32[$face + 528 >> 2] = 652;
  HEAP32[$face + 516 >> 2] = 540;
  return;
}
function _TT_Load_Glyph_Header($loader) {
  $loader = $loader | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $loader + 200 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $loader + 204 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + 10 | 0;
    $6 = $5 >>> 0 > $4 >>> 0;
    if ($6) {
      $_0 = 20;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = HEAP8[$2] | 0;
    $9 = $8 & 255;
    $10 = $9 << 8;
    $11 = $2 + 1 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $12 & 255;
    $14 = $10 | $13;
    $15 = $loader + 32 | 0;
    HEAP16[$15 >> 1] = $14;
    $16 = $2 + 2 | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 & 255;
    $19 = $18 << 8;
    $20 = $2 + 3 | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $21 & 255;
    $23 = $19 | $22;
    $24 = $23 << 16 >> 16;
    $25 = $loader + 36 | 0;
    HEAP32[$25 >> 2] = $24;
    $26 = $2 + 4 | 0;
    $27 = HEAP8[$26] | 0;
    $28 = $27 & 255;
    $29 = $28 << 8;
    $30 = $2 + 5 | 0;
    $31 = HEAP8[$30] | 0;
    $32 = $31 & 255;
    $33 = $29 | $32;
    $34 = $33 << 16 >> 16;
    $35 = $loader + 40 | 0;
    HEAP32[$35 >> 2] = $34;
    $36 = $2 + 6 | 0;
    $37 = HEAP8[$36] | 0;
    $38 = $37 & 255;
    $39 = $38 << 8;
    $40 = $2 + 7 | 0;
    $41 = HEAP8[$40] | 0;
    $42 = $41 & 255;
    $43 = $39 | $42;
    $44 = $43 << 16 >> 16;
    $45 = $loader + 44 | 0;
    HEAP32[$45 >> 2] = $44;
    $46 = $2 + 8 | 0;
    $47 = HEAP8[$46] | 0;
    $48 = $47 & 255;
    $49 = $48 << 8;
    $50 = $2 + 9 | 0;
    $51 = HEAP8[$50] | 0;
    $52 = $51 & 255;
    $53 = $49 | $52;
    $54 = $53 << 16 >> 16;
    $55 = $loader + 48 | 0;
    HEAP32[$55 >> 2] = $54;
    HEAP32[$1 >> 2] = $5;
    $_0 = 0;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _tt_face_load_hdmx($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $error = 0, $table_size = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $record_size_0 = 0, $53 = 0, $54 = 0, $or_cond = 0, $55 = 0, $or_cond40 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $p_042 = 0, $nn_041 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $nn_0_lcssa = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $77 = 0, $79 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $table_size = __stackBase__ + 4 | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 508 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = FUNCTION_TABLE_iiiii[$4 & 1023]($face, 1751412088, $stream, $table_size) | 0;
    HEAP32[$error >> 2] = $5;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 13;
      break;
    }
   case 2:
    $8 = HEAP32[$table_size >> 2] | 0;
    $9 = $8 >>> 0 < 8;
    if ($9) {
      $_0 = 0;
      label = 13;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = $face + 740 | 0;
    $12 = _FT_Stream_ExtractFrame($stream, $8, $11) | 0;
    HEAP32[$error >> 2] = $12;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 4;
      break;
    } else {
      label = 11;
      break;
    }
   case 4:
    $15 = HEAP32[$11 >> 2] | 0;
    $16 = HEAP32[$table_size >> 2] | 0;
    $17 = $15 + $16 | 0;
    $18 = HEAP8[$15] | 0;
    $19 = $18 & 255;
    $20 = $19 << 8;
    $21 = $15 + 1 | 0;
    $22 = HEAP8[$21] | 0;
    $23 = $22 & 255;
    $24 = $20 | $23;
    $25 = $15 + 2 | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 & 255;
    $28 = $27 << 8;
    $29 = $15 + 3 | 0;
    $30 = HEAP8[$29] | 0;
    $31 = $30 & 255;
    $32 = $28 | $31;
    $33 = $15 + 4 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $35 << 24;
    $37 = $15 + 5 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 & 255;
    $40 = $39 << 16;
    $41 = $40 | $36;
    $42 = $15 + 6 | 0;
    $43 = HEAP8[$42] | 0;
    $44 = $43 & 255;
    $45 = $44 << 8;
    $46 = $41 | $45;
    $47 = $15 + 7 | 0;
    $48 = HEAP8[$47] | 0;
    $49 = $48 & 255;
    $50 = $46 | $49;
    $51 = $50 >>> 0 > 4294901759;
    $52 = $50 & 65535;
    $record_size_0 = $51 ? $52 : $50;
    $53 = ($24 | 0) != 0;
    $54 = $32 >>> 0 > 255;
    $or_cond = $53 | $54;
    $55 = $record_size_0 >>> 0 > 65537;
    $or_cond40 = $or_cond | $55;
    if ($or_cond40) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    HEAP32[$error >> 2] = 3;
    label = 12;
    break;
   case 6:
    $58 = _ft_mem_realloc($2, 1, 0, $32, 0, $error) | 0;
    $59 = $face + 756 | 0;
    HEAP32[$59 >> 2] = $58;
    $60 = HEAP32[$error >> 2] | 0;
    $61 = ($60 | 0) == 0;
    if ($61) {
      label = 7;
      break;
    } else {
      label = 12;
      break;
    }
   case 7:
    $62 = $15 + 8 | 0;
    $63 = ($32 | 0) == 0;
    if ($63) {
      $nn_0_lcssa = 0;
      label = 10;
      break;
    } else {
      $nn_041 = 0;
      $p_042 = $62;
      label = 8;
      break;
    }
   case 8:
    $64 = $p_042 + $record_size_0 | 0;
    $65 = $64 >>> 0 > $17 >>> 0;
    if ($65) {
      $nn_0_lcssa = $nn_041;
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $67 = HEAP8[$p_042] | 0;
    $68 = HEAP32[$59 >> 2] | 0;
    $69 = $68 + $nn_041 | 0;
    HEAP8[$69] = $67;
    $70 = $nn_041 + 1 | 0;
    $71 = $70 >>> 0 < $32 >>> 0;
    if ($71) {
      $nn_041 = $70;
      $p_042 = $64;
      label = 8;
      break;
    } else {
      $nn_0_lcssa = $70;
      label = 10;
      break;
    }
   case 10:
    $72 = $face + 748 | 0;
    HEAP32[$72 >> 2] = $nn_0_lcssa;
    $73 = HEAP32[$table_size >> 2] | 0;
    $74 = $face + 744 | 0;
    HEAP32[$74 >> 2] = $73;
    $75 = $face + 752 | 0;
    HEAP32[$75 >> 2] = $record_size_0;
    label = 11;
    break;
   case 11:
    $77 = HEAP32[$error >> 2] | 0;
    $_0 = $77;
    label = 13;
    break;
   case 12:
    _FT_Stream_ReleaseFrame($stream, $11);
    $79 = $face + 744 | 0;
    HEAP32[$79 >> 2] = 0;
    label = 11;
    break;
   case 13:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _tt_face_load_loca($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $table_len = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $18 = 0, $19 = 0, $21 = 0, $23 = 0, $24 = 0, $shift_0 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $dist_040 = 0, $entry_039 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $or_cond38 = 0, $dist_1 = 0, $46 = 0, $47 = 0, $dist_0_lcssa = 0, $entry_0_lcssa = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $dist_2 = 0, $54 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $table_len = __stackBase__ | 0;
    $1 = $face + 508 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 704 | 0;
    $4 = FUNCTION_TABLE_iiiii[$2 & 1023]($face, 1735162214, $stream, $3) | 0;
    if (($4 | 0) == 142) {
      label = 2;
      break;
    } else if (($4 | 0) == 0) {
      label = 3;
      break;
    } else {
      $error_0 = $4;
      label = 17;
      break;
    }
   case 2:
    HEAP32[$3 >> 2] = 0;
    label = 3;
    break;
   case 3:
    $7 = HEAP32[$1 >> 2] | 0;
    $8 = FUNCTION_TABLE_iiiii[$7 & 1023]($face, 1819239265, $stream, $table_len) | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 4;
      break;
    } else {
      $error_0 = 144;
      label = 17;
      break;
    }
   case 4:
    $11 = $face + 210 | 0;
    $12 = HEAP16[$11 >> 1] | 0;
    $13 = $12 << 16 >> 16 == 0;
    $14 = HEAP32[$table_len >> 2] | 0;
    if ($13) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $16 = $14 >>> 0 > 262143;
    if ($16) {
      $error_0 = 8;
      label = 17;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $18 = $14 >>> 2;
    $19 = $face + 732 | 0;
    HEAP32[$19 >> 2] = $18;
    $shift_0 = 2;
    label = 9;
    break;
   case 7:
    $21 = $14 >>> 0 > 131071;
    if ($21) {
      $error_0 = 8;
      label = 17;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $23 = $14 >>> 1;
    $24 = $face + 732 | 0;
    HEAP32[$24 >> 2] = $23;
    $shift_0 = 1;
    label = 9;
    break;
   case 9:
    $26 = $face + 732 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $face + 16 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $27 >>> 0 < $29 >>> 0;
    if ($30) {
      label = 10;
      break;
    } else {
      label = 16;
      break;
    }
   case 10:
    $32 = $29 << $shift_0;
    $33 = $face + 156 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $face + 152 | 0;
    $36 = HEAP16[$35 >> 1] | 0;
    $37 = $36 & 65535;
    $38 = $34 + ($37 << 4) | 0;
    $39 = _FT_Stream_Pos($stream) | 0;
    $40 = $36 << 16 >> 16 == 0;
    if ($40) {
      $entry_0_lcssa = $34;
      $dist_0_lcssa = 2147483647;
      label = 12;
      break;
    } else {
      $entry_039 = $34;
      $dist_040 = 2147483647;
      label = 11;
      break;
    }
   case 11:
    $41 = $entry_039 + 8 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = $42 - $39 | 0;
    $44 = ($43 | 0) > 0;
    $45 = ($43 | 0) < ($dist_040 | 0);
    $or_cond38 = $44 & $45;
    $dist_1 = $or_cond38 ? $43 : $dist_040;
    $46 = $entry_039 + 16 | 0;
    $47 = $46 >>> 0 < $38 >>> 0;
    if ($47) {
      $entry_039 = $46;
      $dist_040 = $dist_1;
      label = 11;
      break;
    } else {
      $entry_0_lcssa = $46;
      $dist_0_lcssa = $dist_1;
      label = 12;
      break;
    }
   case 12:
    $48 = ($entry_0_lcssa | 0) == ($38 | 0);
    if ($48) {
      label = 13;
      break;
    } else {
      $dist_2 = $dist_0_lcssa;
      label = 14;
      break;
    }
   case 13:
    $50 = $stream + 4 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = $51 - $39 | 0;
    $dist_2 = $52;
    label = 14;
    break;
   case 14:
    $54 = ($32 | 0) > ($dist_2 | 0);
    if ($54) {
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $56 = HEAP32[$28 >> 2] | 0;
    HEAP32[$26 >> 2] = $56;
    HEAP32[$table_len >> 2] = $32;
    label = 16;
    break;
   case 16:
    $58 = HEAP32[$table_len >> 2] | 0;
    $59 = $face + 736 | 0;
    $60 = _FT_Stream_ExtractFrame($stream, $58, $59) | 0;
    $error_0 = $60;
    label = 17;
    break;
   case 17:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _tt_face_load_cvt($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $error = 0, $table_len = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $cur_020 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $38 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $table_len = __stackBase__ + 4 | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 508 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = FUNCTION_TABLE_iiiii[$4 & 1023]($face, 1668707360, $stream, $table_len) | 0;
    HEAP32[$error >> 2] = $5;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $face + 668 | 0;
    HEAP32[$8 >> 2] = 0;
    $9 = $face + 672 | 0;
    HEAP32[$9 >> 2] = 0;
    HEAP32[$error >> 2] = 0;
    label = 9;
    break;
   case 3:
    $11 = HEAP32[$table_len >> 2] | 0;
    $12 = $11 >>> 1;
    $13 = $face + 668 | 0;
    HEAP32[$13 >> 2] = $12;
    $14 = _ft_mem_realloc($2, 2, 0, $12, 0, $error) | 0;
    $15 = $14;
    $16 = $face + 672 | 0;
    HEAP32[$16 >> 2] = $15;
    $17 = HEAP32[$error >> 2] | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 4;
      break;
    } else {
      label = 9;
      break;
    }
   case 4:
    $20 = HEAP32[$13 >> 2] | 0;
    $21 = $20 << 1;
    $22 = _FT_Stream_EnterFrame($stream, $21) | 0;
    HEAP32[$error >> 2] = $22;
    $23 = ($22 | 0) == 0;
    if ($23) {
      label = 5;
      break;
    } else {
      label = 9;
      break;
    }
   case 5:
    $25 = HEAP32[$16 >> 2] | 0;
    $26 = HEAP32[$13 >> 2] | 0;
    $27 = $25 + ($26 << 1) | 0;
    $28 = ($26 | 0) > 0;
    if ($28) {
      $cur_020 = $25;
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $29 = _FT_Stream_GetShort($stream) | 0;
    HEAP16[$cur_020 >> 1] = $29;
    $30 = $cur_020 + 2 | 0;
    $31 = $30 >>> 0 < $27 >>> 0;
    if ($31) {
      $cur_020 = $30;
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    _FT_Stream_ExitFrame($stream);
    $32 = $face + 708 | 0;
    $33 = HEAP8[$32] | 0;
    $34 = $33 << 24 >> 24 == 0;
    if ($34) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $36 = _tt_face_vary_cvt($face, $stream) | 0;
    HEAP32[$error >> 2] = $36;
    label = 9;
    break;
   case 9:
    $38 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $38 | 0;
  }
  return 0;
}
function _tt_face_load_fpgm($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $table_len = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $table_len = __stackBase__ | 0;
    $1 = $face + 508 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = FUNCTION_TABLE_iiiii[$2 & 1023]($face, 1718642541, $stream, $table_len) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $face + 656 | 0;
    HEAP32[$6 >> 2] = 0;
    $7 = $face + 652 | 0;
    HEAP32[$7 >> 2] = 0;
    $error_0 = 0;
    label = 4;
    break;
   case 3:
    $9 = HEAP32[$table_len >> 2] | 0;
    $10 = $face + 652 | 0;
    HEAP32[$10 >> 2] = $9;
    $11 = HEAP32[$table_len >> 2] | 0;
    $12 = $face + 656 | 0;
    $13 = _FT_Stream_ExtractFrame($stream, $11, $12) | 0;
    $error_0 = $13;
    label = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _tt_face_load_prep($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $table_len = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $table_len = __stackBase__ | 0;
    $1 = $face + 508 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = FUNCTION_TABLE_iiiii[$2 & 1023]($face, 1886545264, $stream, $table_len) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $face + 664 | 0;
    HEAP32[$6 >> 2] = 0;
    $7 = $face + 660 | 0;
    HEAP32[$7 >> 2] = 0;
    $error_0 = 0;
    label = 4;
    break;
   case 3:
    $9 = HEAP32[$table_len >> 2] | 0;
    $10 = $face + 660 | 0;
    HEAP32[$10 >> 2] = $9;
    $11 = HEAP32[$table_len >> 2] | 0;
    $12 = $face + 664 | 0;
    $13 = _FT_Stream_ExtractFrame($stream, $11, $12) | 0;
    $error_0 = $13;
    label = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _TT_Access_Glyph_Frame($loader, $glyph_index, $offset, $byte_count) {
  $loader = $loader | 0;
  $glyph_index = $glyph_index | 0;
  $offset = $offset | 0;
  $byte_count = $byte_count | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $loader + 24 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _FT_Stream_Seek($2, $offset) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 2;
      break;
    } else {
      $_0 = $3;
      label = 4;
      break;
    }
   case 2:
    $6 = _FT_Stream_EnterFrame($2, $byte_count) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 3;
      break;
    } else {
      $_0 = $6;
      label = 4;
      break;
    }
   case 3:
    $9 = $2 + 32 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $loader + 200 | 0;
    HEAP32[$11 >> 2] = $10;
    $12 = $2 + 36 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $loader + 204 | 0;
    HEAP32[$14 >> 2] = $13;
    $_0 = 0;
    label = 4;
    break;
   case 4:
    return $_0 | 0;
  }
  return 0;
}
function _TT_Load_Simple_Glyph($load) {
  $load = $load | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $_pn146_in = 0, $_pn146 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $_pn = 0, $prev_cont_0 = 0, $_pn139 = 0, $p_0 = 0, $cont_0 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $n_points_0141 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $77 = 0, $78 = 0, $n_points_0142145 = 0, $79 = 0, $_pn137 = 0, $cont_1 = 0, $81 = 0, $83 = 0, $84 = 0, $85 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $p_0_sum = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $scevgep182 = 0, $137 = 0, $138 = 0, $139 = 0, $scevgep_sum = 0, $scevgep181 = 0, $p_1170 = 0, $flag_0169 = 0, $140 = 0, $141 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $flag_0_be = 0, $p_1_be = 0, $147 = 0, $149 = 0, $150 = 0, $152 = 0, $153 = 0, $_sum138 = 0, $154 = 0, $155 = 0, $156 = 0, $p_1_lcssa = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $p_2157 = 0, $flag_2156 = 0, $x_0155 = 0, $vec_0154 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $168 = 0, $169 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $176 = 0, $178 = 0, $179 = 0, $181 = 0, $182 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $y_0 = 0, $p_3 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $202 = 0, $p_4151 = 0, $flag_3150 = 0, $x_1149 = 0, $vec_1148 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $209 = 0, $210 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $217 = 0, $219 = 0, $220 = 0, $222 = 0, $223 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $230 = 0, $231 = 0, $232 = 0, $p_5 = 0, $y1_0 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $p_4_lcssa = 0, $240 = 0, $241 = 0, $242 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $load + 200 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $load + 204 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $load + 12 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $load + 32 | 0;
    $8 = HEAP16[$7 >> 1] | 0;
    $9 = $8 << 16 >> 16;
    $10 = $load | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $8 << 16 >> 16 == 0;
    if ($12) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    label = 6;
    break;
   case 3:
    $14 = $6 + 20 | 0;
    $15 = HEAP16[$14 >> 1] | 0;
    $16 = $15 << 16 >> 16;
    $17 = $6 + 56 | 0;
    $18 = HEAP16[$17 >> 1] | 0;
    $19 = $18 << 16 >> 16;
    $20 = $16 + $9 | 0;
    $21 = $20 + $19 | 0;
    $22 = $6 + 8 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $21 >>> 0 > $23 >>> 0;
    if ($24) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $26 = _FT_GlyphLoader_CheckPoints($6, 0, $9) | 0;
    $27 = ($26 | 0) == 0;
    if ($27) {
      label = 5;
      break;
    } else {
      $error_0 = $26;
      label = 53;
      break;
    }
   case 5:
    $28 = $8 << 16 >> 16 > 4094;
    if ($28) {
      $error_0 = 20;
      label = 53;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $_pn146_in = $6 + 68 | 0;
    $_pn146 = HEAP32[$_pn146_in >> 2] | 0;
    $30 = $_pn146 + ($9 << 1) | 0;
    $31 = $9 << 1;
    $32 = $31 + 2 | 0;
    $33 = $2 + $32 | 0;
    $34 = $33 >>> 0 > $4 >>> 0;
    if ($34) {
      $error_0 = 20;
      label = 53;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $36 = HEAP8[$2] | 0;
    $37 = $36 & 255;
    $38 = $37 << 8;
    $39 = $2 + 1 | 0;
    $40 = HEAP8[$39] | 0;
    $41 = $40 & 255;
    $42 = $38 | $41;
    $43 = $8 << 16 >> 16 > 0;
    if ($43) {
      label = 8;
      break;
    } else {
      $_pn139 = $2;
      $prev_cont_0 = $42;
      $_pn = $_pn146;
      label = 9;
      break;
    }
   case 8:
    HEAP16[$_pn146 >> 1] = $42;
    $_pn139 = $2;
    $prev_cont_0 = $42;
    $_pn = $_pn146;
    label = 9;
    break;
   case 9:
    $p_0 = $_pn139 + 2 | 0;
    $cont_0 = $_pn + 2 | 0;
    $45 = $cont_0 >>> 0 < $30 >>> 0;
    if ($45) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $47 = HEAP8[$p_0] | 0;
    $48 = $47 & 255;
    $49 = $48 << 8;
    $50 = $_pn139 + 3 | 0;
    $51 = HEAP8[$50] | 0;
    $52 = $51 & 255;
    $53 = $49 | $52;
    HEAP16[$cont_0 >> 1] = $53;
    $54 = $53 << 16 >> 16 > $prev_cont_0 << 16 >> 16;
    if ($54) {
      $_pn139 = $p_0;
      $prev_cont_0 = $53;
      $_pn = $cont_0;
      label = 9;
      break;
    } else {
      $error_0 = 8;
      label = 53;
      break;
    }
   case 11:
    if ($43) {
      label = 12;
      break;
    } else {
      $n_points_0141 = 0;
      $64 = 4;
      label = 14;
      break;
    }
   case 12:
    $57 = HEAP16[$_pn >> 1] | 0;
    $58 = $57 << 16 >> 16;
    $59 = $58 + 1 | 0;
    $60 = ($59 | 0) < 0;
    if ($60) {
      $error_0 = 20;
      label = 53;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $62 = $58 + 5 | 0;
    $63 = ($62 | 0) == 0;
    if ($63) {
      $n_points_0142145 = $59;
      label = 16;
      break;
    } else {
      $n_points_0141 = $59;
      $64 = $62;
      label = 14;
      break;
    }
   case 14:
    $65 = $6 + 22 | 0;
    $66 = HEAP16[$65 >> 1] | 0;
    $67 = $66 << 16 >> 16;
    $68 = $6 + 58 | 0;
    $69 = HEAP16[$68 >> 1] | 0;
    $70 = $69 << 16 >> 16;
    $71 = $67 + $64 | 0;
    $72 = $71 + $70 | 0;
    $73 = $6 + 4 | 0;
    $74 = HEAP32[$73 >> 2] | 0;
    $75 = $72 >>> 0 > $74 >>> 0;
    if ($75) {
      label = 15;
      break;
    } else {
      $n_points_0142145 = $n_points_0141;
      label = 16;
      break;
    }
   case 15:
    $77 = _FT_GlyphLoader_CheckPoints($6, $64, 0) | 0;
    $78 = ($77 | 0) == 0;
    if ($78) {
      $n_points_0142145 = $n_points_0141;
      label = 16;
      break;
    } else {
      $error_0 = $77;
      label = 53;
      break;
    }
   case 16:
    $79 = HEAP32[$_pn146_in >> 2] | 0;
    $_pn137 = $79;
    label = 17;
    break;
   case 17:
    $cont_1 = $_pn137 + 2 | 0;
    $81 = $cont_1 >>> 0 < $30 >>> 0;
    if ($81) {
      label = 18;
      break;
    } else {
      label = 19;
      break;
    }
   case 18:
    $83 = HEAP16[$_pn137 >> 1] | 0;
    $84 = HEAP16[$cont_1 >> 1] | 0;
    $85 = $83 << 16 >> 16 < $84 << 16 >> 16;
    if ($85) {
      $_pn137 = $cont_1;
      label = 17;
      break;
    } else {
      $error_0 = 20;
      label = 53;
      break;
    }
   case 19:
    $87 = $load + 8 | 0;
    $88 = HEAP32[$87 >> 2] | 0;
    $89 = $88 + 140 | 0;
    HEAP32[$89 >> 2] = 0;
    $90 = HEAP32[$87 >> 2] | 0;
    $91 = $90 + 136 | 0;
    HEAP32[$91 >> 2] = 0;
    $92 = $_pn139 + 4 | 0;
    $93 = $92 >>> 0 > $4 >>> 0;
    if ($93) {
      $error_0 = 20;
      label = 53;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $95 = HEAP8[$p_0] | 0;
    $96 = $95 & 255;
    $97 = $96 << 8;
    $98 = $_pn139 + 3 | 0;
    $99 = HEAP8[$98] | 0;
    $100 = $99 & 255;
    $101 = $97 | $100;
    $102 = $11 + 260 | 0;
    $103 = $102;
    $104 = $103 + 26 | 0;
    $105 = HEAP16[$104 >> 1] | 0;
    $106 = $105 & 65535;
    $107 = $101 >>> 0 > $106 >>> 0;
    if ($107) {
      $error_0 = 22;
      label = 53;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $109 = $4;
    $110 = $92;
    $111 = $109 - $110 | 0;
    $112 = ($111 | 0) < ($101 | 0);
    if ($112) {
      $error_0 = 22;
      label = 53;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $114 = $load + 16 | 0;
    $115 = HEAP32[$114 >> 2] | 0;
    $116 = $115 & 2;
    $117 = ($116 | 0) == 0;
    if ($117) {
      label = 23;
      break;
    } else {
      label = 24;
      break;
    }
   case 23:
    $119 = HEAP32[$87 >> 2] | 0;
    $120 = $119 + 140 | 0;
    HEAP32[$120 >> 2] = $101;
    $121 = $load + 160 | 0;
    $122 = HEAP32[$121 >> 2] | 0;
    $123 = $122 + 392 | 0;
    $124 = HEAP32[$123 >> 2] | 0;
    $125 = HEAP32[$87 >> 2] | 0;
    $126 = $125 + 136 | 0;
    HEAP32[$126 >> 2] = $124;
    $127 = HEAP32[$121 >> 2] | 0;
    $128 = $127 + 392 | 0;
    $129 = HEAP32[$128 >> 2] | 0;
    _memcpy($129 | 0, $92 | 0, $101 | 0);
    label = 24;
    break;
   case 24:
    $p_0_sum = $101 + 4 | 0;
    $131 = $_pn139 + $p_0_sum | 0;
    $132 = $6 + 64 | 0;
    $133 = HEAP32[$132 >> 2] | 0;
    $134 = $133 + $n_points_0142145 | 0;
    $135 = ($n_points_0142145 | 0) > 0;
    if ($135) {
      $flag_0169 = $133;
      $p_1170 = $131;
      label = 26;
      break;
    } else {
      $p_1_lcssa = $131;
      label = 32;
      break;
    }
   case 25:
    $136 = $152 - 1 & 255;
    $scevgep182 = $flag_0169 + 1 | 0;
    $137 = $136 & 255;
    $138 = $137 + 1 | 0;
    _memset($scevgep182 | 0, $143 | 0, $138 | 0);
    $139 = $136 & 255;
    $scevgep_sum = $139 + 2 | 0;
    $scevgep181 = $flag_0169 + $scevgep_sum | 0;
    $p_1_be = $149;
    $flag_0_be = $scevgep181;
    label = 28;
    break;
   case 26:
    $140 = $p_1170 + 1 | 0;
    $141 = $140 >>> 0 > $4 >>> 0;
    if ($141) {
      $error_0 = 20;
      label = 53;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $143 = HEAP8[$p_1170] | 0;
    $144 = $flag_0169 + 1 | 0;
    HEAP8[$flag_0169] = $143;
    $145 = $143 & 8;
    $146 = $145 << 24 >> 24 == 0;
    if ($146) {
      $p_1_be = $140;
      $flag_0_be = $144;
      label = 28;
      break;
    } else {
      label = 29;
      break;
    }
   case 28:
    $147 = $flag_0_be >>> 0 < $134 >>> 0;
    if ($147) {
      $flag_0169 = $flag_0_be;
      $p_1170 = $p_1_be;
      label = 26;
      break;
    } else {
      $p_1_lcssa = $p_1_be;
      label = 32;
      break;
    }
   case 29:
    $149 = $p_1170 + 2 | 0;
    $150 = $149 >>> 0 > $4 >>> 0;
    if ($150) {
      $error_0 = 20;
      label = 53;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    $152 = HEAP8[$140] | 0;
    $153 = $152 & 255;
    $_sum138 = $153 + 1 | 0;
    $154 = $flag_0169 + $_sum138 | 0;
    $155 = $154 >>> 0 > $134 >>> 0;
    if ($155) {
      $error_0 = 20;
      label = 53;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    $156 = $152 << 24 >> 24 == 0;
    if ($156) {
      $p_1_be = $149;
      $flag_0_be = $144;
      label = 28;
      break;
    } else {
      label = 25;
      break;
    }
   case 32:
    $157 = $6 + 60 | 0;
    $158 = HEAP32[$157 >> 2] | 0;
    $159 = $158 + ($n_points_0142145 << 3) | 0;
    $160 = $p_1_lcssa >>> 0 > $4 >>> 0;
    if ($160) {
      $error_0 = 20;
      label = 53;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    $161 = HEAP32[$132 >> 2] | 0;
    $162 = ($n_points_0142145 | 0) > 0;
    if ($162) {
      $vec_0154 = $158;
      $x_0155 = 0;
      $flag_2156 = $161;
      $p_2157 = $p_1_lcssa;
      label = 34;
      break;
    } else {
      $p_4_lcssa = $p_1_lcssa;
      label = 52;
      break;
    }
   case 34:
    $163 = HEAP8[$flag_2156] | 0;
    $164 = $163 & 255;
    $165 = $164 & 2;
    $166 = ($165 | 0) == 0;
    if ($166) {
      label = 38;
      break;
    } else {
      label = 35;
      break;
    }
   case 35:
    $168 = $p_2157 + 1 | 0;
    $169 = $168 >>> 0 > $4 >>> 0;
    if ($169) {
      $error_0 = 20;
      label = 53;
      break;
    } else {
      label = 36;
      break;
    }
   case 36:
    $171 = HEAP8[$p_2157] | 0;
    $172 = $171 & 255;
    $173 = $164 & 16;
    $174 = ($173 | 0) == 0;
    if ($174) {
      label = 37;
      break;
    } else {
      $p_3 = $168;
      $y_0 = $172;
      label = 41;
      break;
    }
   case 37:
    $176 = -$172 | 0;
    $p_3 = $168;
    $y_0 = $176;
    label = 41;
    break;
   case 38:
    $178 = $164 & 16;
    $179 = ($178 | 0) == 0;
    if ($179) {
      label = 39;
      break;
    } else {
      $p_3 = $p_2157;
      $y_0 = 0;
      label = 41;
      break;
    }
   case 39:
    $181 = $p_2157 + 2 | 0;
    $182 = $181 >>> 0 > $4 >>> 0;
    if ($182) {
      $error_0 = 20;
      label = 53;
      break;
    } else {
      label = 40;
      break;
    }
   case 40:
    $184 = HEAP8[$p_2157] | 0;
    $185 = $184 & 255;
    $186 = $185 << 8;
    $187 = $p_2157 + 1 | 0;
    $188 = HEAP8[$187] | 0;
    $189 = $188 & 255;
    $190 = $186 | $189;
    $191 = $190 << 16 >> 16;
    $p_3 = $181;
    $y_0 = $191;
    label = 41;
    break;
   case 41:
    $193 = $y_0 + $x_0155 | 0;
    $194 = $vec_0154 | 0;
    HEAP32[$194 >> 2] = $193;
    $195 = $163 & -19;
    HEAP8[$flag_2156] = $195;
    $196 = $vec_0154 + 8 | 0;
    $197 = $flag_2156 + 1 | 0;
    $198 = $196 >>> 0 < $159 >>> 0;
    if ($198) {
      $vec_0154 = $196;
      $x_0155 = $193;
      $flag_2156 = $197;
      $p_2157 = $p_3;
      label = 34;
      break;
    } else {
      label = 42;
      break;
    }
   case 42:
    $199 = HEAP32[$157 >> 2] | 0;
    $200 = $199 + ($n_points_0142145 << 3) | 0;
    $201 = ($n_points_0142145 | 0) > 0;
    if ($201) {
      label = 43;
      break;
    } else {
      $p_4_lcssa = $p_3;
      label = 52;
      break;
    }
   case 43:
    $202 = HEAP32[$132 >> 2] | 0;
    $vec_1148 = $199;
    $x_1149 = 0;
    $flag_3150 = $202;
    $p_4151 = $p_3;
    label = 44;
    break;
   case 44:
    $204 = HEAP8[$flag_3150] | 0;
    $205 = $204 & 255;
    $206 = $205 & 4;
    $207 = ($206 | 0) == 0;
    if ($207) {
      label = 48;
      break;
    } else {
      label = 45;
      break;
    }
   case 45:
    $209 = $p_4151 + 1 | 0;
    $210 = $209 >>> 0 > $4 >>> 0;
    if ($210) {
      $error_0 = 20;
      label = 53;
      break;
    } else {
      label = 46;
      break;
    }
   case 46:
    $212 = HEAP8[$p_4151] | 0;
    $213 = $212 & 255;
    $214 = $205 & 32;
    $215 = ($214 | 0) == 0;
    if ($215) {
      label = 47;
      break;
    } else {
      $y1_0 = $213;
      $p_5 = $209;
      label = 51;
      break;
    }
   case 47:
    $217 = -$213 | 0;
    $y1_0 = $217;
    $p_5 = $209;
    label = 51;
    break;
   case 48:
    $219 = $205 & 32;
    $220 = ($219 | 0) == 0;
    if ($220) {
      label = 49;
      break;
    } else {
      $y1_0 = 0;
      $p_5 = $p_4151;
      label = 51;
      break;
    }
   case 49:
    $222 = $p_4151 + 2 | 0;
    $223 = $222 >>> 0 > $4 >>> 0;
    if ($223) {
      $error_0 = 20;
      label = 53;
      break;
    } else {
      label = 50;
      break;
    }
   case 50:
    $225 = HEAP8[$p_4151] | 0;
    $226 = $225 & 255;
    $227 = $226 << 8;
    $228 = $p_4151 + 1 | 0;
    $229 = HEAP8[$228] | 0;
    $230 = $229 & 255;
    $231 = $227 | $230;
    $232 = $231 << 16 >> 16;
    $y1_0 = $232;
    $p_5 = $222;
    label = 51;
    break;
   case 51:
    $234 = $y1_0 + $x_1149 | 0;
    $235 = $vec_1148 + 4 | 0;
    HEAP32[$235 >> 2] = $234;
    $236 = $204 & 1;
    HEAP8[$flag_3150] = $236;
    $237 = $vec_1148 + 8 | 0;
    $238 = $flag_3150 + 1 | 0;
    $239 = $237 >>> 0 < $200 >>> 0;
    if ($239) {
      $vec_1148 = $237;
      $x_1149 = $234;
      $flag_3150 = $238;
      $p_4151 = $p_5;
      label = 44;
      break;
    } else {
      $p_4_lcssa = $p_5;
      label = 52;
      break;
    }
   case 52:
    $240 = $n_points_0142145 & 65535;
    $241 = $6 + 58 | 0;
    HEAP16[$241 >> 1] = $240;
    $242 = $6 + 56 | 0;
    HEAP16[$242 >> 1] = $8;
    HEAP32[$1 >> 2] = $p_4_lcssa;
    $error_0 = 0;
    label = 53;
    break;
   case 53:
    return $error_0 | 0;
  }
  return 0;
}
function _TT_Load_Composite_Glyph($loader) {
  $loader = $loader | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $p_0 = 0, $num_subglyphs_0 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $_ = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $45 = 0, $46 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $__ = 0, $count_1 = 0, $_sum = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $storemerge = 0, $p_1 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $103 = 0, $104 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $127 = 0, $128 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $p_2 = 0, $xx_0 = 0, $xy_0 = 0, $yy_0 = 0, $yx_0 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $loader + 200 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $loader + 204 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $loader + 12 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + 88 | 0;
    $num_subglyphs_0 = 0;
    $p_0 = $2;
    label = 2;
    break;
   case 2:
    $9 = $num_subglyphs_0 + 1 | 0;
    $10 = _FT_GlyphLoader_CheckSubGlyphs($6, $9) | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 3;
      break;
    } else {
      $error_0 = $10;
      label = 21;
      break;
    }
   case 3:
    $13 = $p_0 + 4 | 0;
    $14 = $13 >>> 0 > $4 >>> 0;
    if ($14) {
      $error_0 = 21;
      label = 21;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $16 = HEAP32[$7 >> 2] | 0;
    $17 = $16 + ($num_subglyphs_0 << 5) + 12 | 0;
    HEAP32[$17 >> 2] = 0;
    $18 = $16 + ($num_subglyphs_0 << 5) + 8 | 0;
    HEAP32[$18 >> 2] = 0;
    $19 = HEAP8[$p_0] | 0;
    $20 = $19 & 255;
    $21 = $20 << 8;
    $22 = $p_0 + 1 | 0;
    $23 = HEAP8[$22] | 0;
    $24 = $23 & 255;
    $25 = $21 | $24;
    $26 = $16 + ($num_subglyphs_0 << 5) + 4 | 0;
    HEAP16[$26 >> 1] = $25;
    $27 = $p_0 + 2 | 0;
    $28 = HEAP8[$27] | 0;
    $29 = $28 & 255;
    $30 = $29 << 8;
    $31 = $p_0 + 3 | 0;
    $32 = HEAP8[$31] | 0;
    $33 = $32 & 255;
    $34 = $30 | $33;
    $35 = $16 + ($num_subglyphs_0 << 5) | 0;
    HEAP32[$35 >> 2] = $34;
    $36 = HEAP16[$26 >> 1] | 0;
    $37 = $36 & 1;
    $38 = $37 << 16 >> 16 == 0;
    $_ = $38 ? 2 : 4;
    $39 = $36 & 65535;
    $40 = $39 & 8;
    $41 = ($40 | 0) == 0;
    if ($41) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $43 = $_ + 2 | 0;
    $count_1 = $43;
    label = 9;
    break;
   case 6:
    $45 = $39 & 64;
    $46 = ($45 | 0) == 0;
    if ($46) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $48 = $_ + 4 | 0;
    $count_1 = $48;
    label = 9;
    break;
   case 8:
    $50 = $39 & 128;
    $51 = ($50 | 0) == 0;
    $52 = $_ | 8;
    $__ = $51 ? $_ : $52;
    $count_1 = $__;
    label = 9;
    break;
   case 9:
    $_sum = $count_1 + 4 | 0;
    $54 = $p_0 + $_sum | 0;
    $55 = $54 >>> 0 > $4 >>> 0;
    if ($55) {
      $error_0 = 21;
      label = 21;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $57 = HEAP16[$26 >> 1] | 0;
    $58 = $57 & 1;
    $59 = $58 << 16 >> 16 == 0;
    if ($59) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $61 = HEAP8[$13] | 0;
    $62 = $61 & 255;
    $63 = $62 << 8;
    $64 = $p_0 + 5 | 0;
    $65 = HEAP8[$64] | 0;
    $66 = $65 & 255;
    $67 = $63 | $66;
    $68 = $67 << 16 >> 16;
    HEAP32[$18 >> 2] = $68;
    $69 = $p_0 + 8 | 0;
    $70 = $p_0 + 6 | 0;
    $71 = HEAP8[$70] | 0;
    $72 = $71 & 255;
    $73 = $72 << 8;
    $74 = $p_0 + 7 | 0;
    $75 = HEAP8[$74] | 0;
    $76 = $75 & 255;
    $77 = $73 | $76;
    $78 = $77 << 16 >> 16;
    $p_1 = $69;
    $storemerge = $78;
    label = 13;
    break;
   case 12:
    $80 = $p_0 + 5 | 0;
    $81 = HEAP8[$13] | 0;
    $82 = $81 << 24 >> 24;
    HEAP32[$18 >> 2] = $82;
    $83 = $p_0 + 6 | 0;
    $84 = HEAP8[$80] | 0;
    $85 = $84 << 24 >> 24;
    $p_1 = $83;
    $storemerge = $85;
    label = 13;
    break;
   case 13:
    HEAP32[$17 >> 2] = $storemerge;
    $87 = HEAP16[$26 >> 1] | 0;
    $88 = $87 & 65535;
    $89 = $88 & 8;
    $90 = ($89 | 0) == 0;
    if ($90) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $92 = $p_1 + 2 | 0;
    $93 = HEAP8[$p_1] | 0;
    $94 = $93 & 255;
    $95 = $94 << 8;
    $96 = $p_1 + 1 | 0;
    $97 = HEAP8[$96] | 0;
    $98 = $97 & 255;
    $99 = $95 | $98;
    $100 = $99 << 16 >> 16;
    $101 = $100 << 2;
    $yx_0 = 0;
    $yy_0 = $101;
    $xy_0 = 0;
    $xx_0 = $101;
    $p_2 = $92;
    label = 19;
    break;
   case 15:
    $103 = $88 & 64;
    $104 = ($103 | 0) == 0;
    if ($104) {
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $106 = HEAP8[$p_1] | 0;
    $107 = $106 & 255;
    $108 = $107 << 8;
    $109 = $p_1 + 1 | 0;
    $110 = HEAP8[$109] | 0;
    $111 = $110 & 255;
    $112 = $108 | $111;
    $113 = $112 << 16 >> 16;
    $114 = $113 << 2;
    $115 = $p_1 + 4 | 0;
    $116 = $p_1 + 2 | 0;
    $117 = HEAP8[$116] | 0;
    $118 = $117 & 255;
    $119 = $118 << 8;
    $120 = $p_1 + 3 | 0;
    $121 = HEAP8[$120] | 0;
    $122 = $121 & 255;
    $123 = $119 | $122;
    $124 = $123 << 16 >> 16;
    $125 = $124 << 2;
    $yx_0 = 0;
    $yy_0 = $125;
    $xy_0 = 0;
    $xx_0 = $114;
    $p_2 = $115;
    label = 19;
    break;
   case 17:
    $127 = $88 & 128;
    $128 = ($127 | 0) == 0;
    if ($128) {
      $yx_0 = 0;
      $yy_0 = 65536;
      $xy_0 = 0;
      $xx_0 = 65536;
      $p_2 = $p_1;
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $130 = HEAP8[$p_1] | 0;
    $131 = $130 & 255;
    $132 = $131 << 8;
    $133 = $p_1 + 1 | 0;
    $134 = HEAP8[$133] | 0;
    $135 = $134 & 255;
    $136 = $132 | $135;
    $137 = $136 << 16 >> 16;
    $138 = $137 << 2;
    $139 = $p_1 + 2 | 0;
    $140 = HEAP8[$139] | 0;
    $141 = $140 & 255;
    $142 = $141 << 8;
    $143 = $p_1 + 3 | 0;
    $144 = HEAP8[$143] | 0;
    $145 = $144 & 255;
    $146 = $142 | $145;
    $147 = $146 << 16 >> 16;
    $148 = $147 << 2;
    $149 = $p_1 + 4 | 0;
    $150 = HEAP8[$149] | 0;
    $151 = $150 & 255;
    $152 = $151 << 8;
    $153 = $p_1 + 5 | 0;
    $154 = HEAP8[$153] | 0;
    $155 = $154 & 255;
    $156 = $152 | $155;
    $157 = $156 << 16 >> 16;
    $158 = $157 << 2;
    $159 = $p_1 + 8 | 0;
    $160 = $p_1 + 6 | 0;
    $161 = HEAP8[$160] | 0;
    $162 = $161 & 255;
    $163 = $162 << 8;
    $164 = $p_1 + 7 | 0;
    $165 = HEAP8[$164] | 0;
    $166 = $165 & 255;
    $167 = $163 | $166;
    $168 = $167 << 16 >> 16;
    $169 = $168 << 2;
    $yx_0 = $148;
    $yy_0 = $169;
    $xy_0 = $158;
    $xx_0 = $138;
    $p_2 = $159;
    label = 19;
    break;
   case 19:
    $171 = $16 + ($num_subglyphs_0 << 5) + 16 | 0;
    HEAP32[$171 >> 2] = $xx_0;
    $172 = $16 + ($num_subglyphs_0 << 5) + 20 | 0;
    HEAP32[$172 >> 2] = $xy_0;
    $173 = $16 + ($num_subglyphs_0 << 5) + 24 | 0;
    HEAP32[$173 >> 2] = $yx_0;
    $174 = $16 + ($num_subglyphs_0 << 5) + 28 | 0;
    HEAP32[$174 >> 2] = $yy_0;
    $175 = HEAP16[$26 >> 1] | 0;
    $176 = $175 & 32;
    $177 = $176 << 16 >> 16 == 0;
    if ($177) {
      label = 20;
      break;
    } else {
      $num_subglyphs_0 = $9;
      $p_0 = $p_2;
      label = 2;
      break;
    }
   case 20:
    $179 = $6 + 84 | 0;
    HEAP32[$179 >> 2] = $9;
    $180 = $loader + 24 | 0;
    $181 = HEAP32[$180 >> 2] | 0;
    $182 = _FT_Stream_Pos($181) | 0;
    $183 = $p_2 + $182 | 0;
    $184 = $183;
    $185 = $4;
    $186 = $184 - $185 | 0;
    $187 = $loader + 168 | 0;
    HEAP32[$187 >> 2] = $186;
    HEAP32[$1 >> 2] = $p_2;
    $error_0 = $10;
    label = 21;
    break;
   case 21:
    return $error_0 | 0;
  }
  return 0;
}
function _TT_Forget_Glyph_Frame($loader) {
  $loader = $loader | 0;
  _FT_Stream_ExitFrame(HEAP32[$loader + 24 >> 2] | 0);
  return;
}
function _tt_face_vary_cvt($face, $stream) {
  $face = $face | 0;
  $stream = $stream | 0;
  var $error = 0, $table_len = 0, $point_count = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $8 = 0, $9 = 0, $10 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $19 = 0, $20 = 0, $21 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $offsetToData_0114 = 0, $i_0113 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $j_093 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $81 = 0, $82 = 0, $83 = 0, $_mask = 0, $84 = 0, $j_1110 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $j_295 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $j_398 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $112 = 0, $113 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $125 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $or_cond = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $j_4106 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $j_5102 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $offsetToData_1 = 0, $172 = 0, $exitcond = 0, $im_end_coords_0 = 0, $im_start_coords_0 = 0, $tuple_coords_0 = 0, $im_end_coords_1 = 0, $im_start_coords_1 = 0, $tuple_coords_1 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $table_len = __stackBase__ + 4 | 0;
    $point_count = __stackBase__ + 8 | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 712 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    HEAP32[$error >> 2] = 0;
    $tuple_coords_1 = 0;
    $im_start_coords_1 = 0;
    $im_end_coords_1 = 0;
    label = 43;
    break;
   case 3:
    $8 = $face + 672 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    HEAP32[$error >> 2] = 0;
    $tuple_coords_1 = 0;
    $im_start_coords_1 = 0;
    $im_end_coords_1 = 0;
    label = 43;
    break;
   case 5:
    $13 = $face + 508 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = FUNCTION_TABLE_iiiii[$14 & 1023]($face, 1668702578, $stream, $table_len) | 0;
    HEAP32[$error >> 2] = $15;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    HEAP32[$error >> 2] = 0;
    $tuple_coords_1 = 0;
    $im_start_coords_1 = 0;
    $im_end_coords_1 = 0;
    label = 43;
    break;
   case 7:
    $19 = HEAP32[$table_len >> 2] | 0;
    $20 = _FT_Stream_EnterFrame($stream, $19) | 0;
    HEAP32[$error >> 2] = $20;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    HEAP32[$error >> 2] = 0;
    $tuple_coords_1 = 0;
    $im_start_coords_1 = 0;
    $im_end_coords_1 = 0;
    label = 43;
    break;
   case 9:
    $24 = $stream + 32 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $stream | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $25;
    $29 = $27;
    $30 = $28 - $29 | 0;
    $31 = _FT_Stream_GetLong($stream) | 0;
    $32 = ($31 | 0) == 65536;
    if ($32) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    HEAP32[$error >> 2] = 0;
    $tuple_coords_0 = 0;
    $im_start_coords_0 = 0;
    $im_end_coords_0 = 0;
    label = 42;
    break;
   case 11:
    $35 = $4 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = _ft_mem_realloc($2, 4, 0, $36, 0, $error) | 0;
    $38 = $37;
    $39 = HEAP32[$error >> 2] | 0;
    $40 = ($39 | 0) == 0;
    if ($40) {
      label = 12;
      break;
    } else {
      $tuple_coords_0 = $38;
      $im_start_coords_0 = 0;
      $im_end_coords_0 = 0;
      label = 42;
      break;
    }
   case 12:
    $42 = HEAP32[$35 >> 2] | 0;
    $43 = _ft_mem_realloc($2, 4, 0, $42, 0, $error) | 0;
    $44 = $43;
    $45 = HEAP32[$error >> 2] | 0;
    $46 = ($45 | 0) == 0;
    if ($46) {
      label = 13;
      break;
    } else {
      $tuple_coords_0 = $38;
      $im_start_coords_0 = $44;
      $im_end_coords_0 = 0;
      label = 42;
      break;
    }
   case 13:
    $48 = HEAP32[$35 >> 2] | 0;
    $49 = _ft_mem_realloc($2, 4, 0, $48, 0, $error) | 0;
    $50 = $49;
    $51 = HEAP32[$error >> 2] | 0;
    $52 = ($51 | 0) == 0;
    if ($52) {
      label = 14;
      break;
    } else {
      $tuple_coords_0 = $38;
      $im_start_coords_0 = $44;
      $im_end_coords_0 = $50;
      label = 42;
      break;
    }
   case 14:
    $54 = _FT_Stream_GetShort($stream) | 0;
    $55 = _FT_Stream_GetShort($stream) | 0;
    $56 = $54 & 4095;
    $57 = $56 << 16 >> 16 == 0;
    if ($57) {
      $tuple_coords_0 = $38;
      $im_start_coords_0 = $44;
      $im_end_coords_0 = $50;
      label = 42;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $58 = $55 & 65535;
    $59 = $30 + $58 | 0;
    $60 = $face + 668 | 0;
    $61 = $face + 668 | 0;
    $62 = $54 & 65535;
    $63 = $62 & 4095;
    $i_0113 = 0;
    $offsetToData_0114 = $59;
    label = 16;
    break;
   case 16:
    $65 = _FT_Stream_GetShort($stream) | 0;
    $66 = $65 & 65535;
    $67 = _FT_Stream_GetShort($stream) | 0;
    $68 = $67 & 65535;
    $69 = $68 & 32768;
    $70 = ($69 | 0) == 0;
    if ($70) {
      label = 19;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $71 = HEAP32[$35 >> 2] | 0;
    $72 = ($71 | 0) == 0;
    if ($72) {
      label = 22;
      break;
    } else {
      $j_093 = 0;
      label = 18;
      break;
    }
   case 18:
    $73 = _FT_Stream_GetShort($stream) | 0;
    $74 = $73 << 16 >> 16;
    $75 = $74 << 2;
    $76 = $38 + ($j_093 << 2) | 0;
    HEAP32[$76 >> 2] = $75;
    $77 = $j_093 + 1 | 0;
    $78 = HEAP32[$35 >> 2] | 0;
    $79 = $77 >>> 0 < $78 >>> 0;
    if ($79) {
      $j_093 = $77;
      label = 18;
      break;
    } else {
      label = 22;
      break;
    }
   case 19:
    $81 = $68 & 16384;
    $82 = ($81 | 0) == 0;
    if ($82) {
      label = 41;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $83 = HEAP32[$35 >> 2] | 0;
    $_mask = $83 & 2147483647;
    $84 = ($_mask | 0) == 0;
    if ($84) {
      label = 41;
      break;
    } else {
      $j_1110 = 0;
      label = 21;
      break;
    }
   case 21:
    $85 = _FT_Stream_GetShort($stream) | 0;
    $86 = $j_1110 + 1 | 0;
    $87 = HEAP32[$35 >> 2] | 0;
    $88 = $87 << 1;
    $89 = $86 >>> 0 < $88 >>> 0;
    if ($89) {
      $j_1110 = $86;
      label = 21;
      break;
    } else {
      label = 41;
      break;
    }
   case 22:
    $90 = $68 & 16384;
    $91 = ($90 | 0) == 0;
    if ($91) {
      label = 27;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $92 = HEAP32[$35 >> 2] | 0;
    $93 = ($92 | 0) == 0;
    if ($93) {
      label = 27;
      break;
    } else {
      $j_295 = 0;
      label = 24;
      break;
    }
   case 24:
    $94 = _FT_Stream_GetShort($stream) | 0;
    $95 = $94 << 16 >> 16;
    $96 = $95 << 2;
    $97 = $44 + ($j_295 << 2) | 0;
    HEAP32[$97 >> 2] = $96;
    $98 = $j_295 + 1 | 0;
    $99 = HEAP32[$35 >> 2] | 0;
    $100 = $98 >>> 0 < $99 >>> 0;
    if ($100) {
      $j_295 = $98;
      label = 24;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $101 = ($99 | 0) == 0;
    if ($101) {
      label = 27;
      break;
    } else {
      $j_398 = 0;
      label = 26;
      break;
    }
   case 26:
    $102 = _FT_Stream_GetShort($stream) | 0;
    $103 = $102 << 16 >> 16;
    $104 = $103 << 2;
    $105 = $50 + ($j_398 << 2) | 0;
    HEAP32[$105 >> 2] = $104;
    $106 = $j_398 + 1 | 0;
    $107 = HEAP32[$35 >> 2] | 0;
    $108 = $106 >>> 0 < $107 >>> 0;
    if ($108) {
      $j_398 = $106;
      label = 26;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $109 = _ft_var_apply_tuple($4, $67, $38, $44, $50) | 0;
    $110 = ($109 | 0) == 0;
    if ($110) {
      label = 41;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $112 = $68 & 8192;
    $113 = ($112 | 0) == 0;
    if ($113) {
      label = 41;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    $115 = HEAP32[$24 >> 2] | 0;
    $116 = HEAP32[$26 >> 2] | 0;
    $117 = $115;
    $118 = $116;
    $119 = $117 - $118 | 0;
    $120 = $116 + $offsetToData_0114 | 0;
    HEAP32[$24 >> 2] = $120;
    $121 = _ft_var_readpackedpoints($stream, $point_count) | 0;
    $122 = HEAP32[$point_count >> 2] | 0;
    $123 = ($122 | 0) == 0;
    if ($123) {
      label = 30;
      break;
    } else {
      $127 = $122;
      label = 31;
      break;
    }
   case 30:
    $125 = HEAP32[$60 >> 2] | 0;
    $127 = $125;
    label = 31;
    break;
   case 31:
    $128 = _ft_var_readpackeddeltas($stream, $127) | 0;
    $129 = ($121 | 0) == 0;
    $130 = ($128 | 0) == 0;
    $or_cond = $129 | $130;
    if ($or_cond) {
      label = 38;
      break;
    } else {
      label = 32;
      break;
    }
   case 32:
    $132 = ($121 | 0) == -1;
    if ($132) {
      label = 33;
      break;
    } else {
      label = 34;
      break;
    }
   case 33:
    $133 = HEAP32[$61 >> 2] | 0;
    $134 = ($133 | 0) == 0;
    if ($134) {
      label = 40;
      break;
    } else {
      $j_4106 = 0;
      label = 36;
      break;
    }
   case 34:
    $135 = HEAP32[$point_count >> 2] | 0;
    $136 = ($135 | 0) == 0;
    if ($136) {
      label = 39;
      break;
    } else {
      label = 35;
      break;
    }
   case 35:
    $137 = HEAP32[$point_count >> 2] | 0;
    $j_5102 = 0;
    label = 37;
    break;
   case 36:
    $138 = HEAP32[$8 >> 2] | 0;
    $139 = $138 + ($j_4106 << 1) | 0;
    $140 = HEAP16[$139 >> 1] | 0;
    $141 = $140 & 65535;
    $142 = $128 + ($j_4106 << 1) | 0;
    $143 = HEAP16[$142 >> 1] | 0;
    $144 = $143 << 16 >> 16;
    $145 = _FT_MulFix($144, $109) | 0;
    $146 = $145 + $141 | 0;
    $147 = $146 & 65535;
    HEAP16[$139 >> 1] = $147;
    $148 = $j_4106 + 1 | 0;
    $149 = HEAP32[$61 >> 2] | 0;
    $150 = $148 >>> 0 < $149 >>> 0;
    if ($150) {
      $j_4106 = $148;
      label = 36;
      break;
    } else {
      label = 38;
      break;
    }
   case 37:
    $152 = $121 + ($j_5102 << 1) | 0;
    $153 = HEAP16[$152 >> 1] | 0;
    $154 = $153 & 65535;
    $155 = HEAP32[$8 >> 2] | 0;
    $156 = $155 + ($154 << 1) | 0;
    $157 = HEAP16[$156 >> 1] | 0;
    $158 = $157 & 65535;
    $159 = $128 + ($j_5102 << 1) | 0;
    $160 = HEAP16[$159 >> 1] | 0;
    $161 = $160 << 16 >> 16;
    $162 = _FT_MulFix($161, $109) | 0;
    $163 = $162 + $158 | 0;
    $164 = $163 & 65535;
    HEAP16[$156 >> 1] = $164;
    $165 = $j_5102 + 1 | 0;
    $166 = $165 >>> 0 < $137 >>> 0;
    if ($166) {
      $j_5102 = $165;
      label = 37;
      break;
    } else {
      label = 38;
      break;
    }
   case 38:
    $167 = ($121 | 0) == -1;
    if ($167) {
      label = 40;
      break;
    } else {
      label = 39;
      break;
    }
   case 39:
    $168 = $121;
    _ft_mem_free($2, $168);
    label = 40;
    break;
   case 40:
    $169 = $128;
    _ft_mem_free($2, $169);
    $170 = HEAP32[$26 >> 2] | 0;
    $171 = $170 + $119 | 0;
    HEAP32[$24 >> 2] = $171;
    label = 41;
    break;
   case 41:
    $offsetToData_1 = $66 + $offsetToData_0114 | 0;
    $172 = $i_0113 + 1 | 0;
    $exitcond = ($172 | 0) == ($63 | 0);
    if ($exitcond) {
      $tuple_coords_0 = $38;
      $im_start_coords_0 = $44;
      $im_end_coords_0 = $50;
      label = 42;
      break;
    } else {
      $i_0113 = $172;
      $offsetToData_0114 = $offsetToData_1;
      label = 16;
      break;
    }
   case 42:
    _FT_Stream_ExitFrame($stream);
    $tuple_coords_1 = $tuple_coords_0;
    $im_start_coords_1 = $im_start_coords_0;
    $im_end_coords_1 = $im_end_coords_0;
    label = 43;
    break;
   case 43:
    $174 = $tuple_coords_1;
    _ft_mem_free($2, $174);
    $175 = $im_start_coords_1;
    _ft_mem_free($2, $175);
    $176 = $im_end_coords_1;
    _ft_mem_free($2, $176);
    $177 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $177 | 0;
  }
  return 0;
}
function _ft_var_apply_tuple($blend, $tupleIndex, $tuple_coords, $im_start_coords, $im_end_coords) {
  $blend = $blend | 0;
  $tupleIndex = $tupleIndex | 0;
  $tuple_coords = $tuple_coords | 0;
  $im_start_coords = $im_start_coords | 0;
  $im_end_coords = $im_end_coords | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $apply_052 = 0, $i_051 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $or_cond = 0, $20 = 0, $21 = 0, $or_cond50 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $apply_1 = 0, $53 = 0, $54 = 0, $55 = 0, $apply_2 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $blend + 4 | 0;
    $2 = $blend | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      $apply_2 = 65536;
      label = 15;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $tupleIndex & 16384;
    $6 = $5 << 16 >> 16 == 0;
    $i_051 = 0;
    $apply_052 = 65536;
    label = 3;
    break;
   case 3:
    $8 = $tuple_coords + ($i_051 << 2) | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      $apply_1 = $apply_052;
      label = 14;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $12 = HEAP32[$1 >> 2] | 0;
    $13 = $12 + ($i_051 << 2) | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      $apply_2 = 0;
      label = 15;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = ($14 | 0) < 0;
    $18 = ($9 | 0) > 0;
    $or_cond = $17 & $18;
    if ($or_cond) {
      $apply_2 = 0;
      label = 15;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $20 = ($14 | 0) > 0;
    $21 = ($9 | 0) < 0;
    $or_cond50 = $20 & $21;
    if ($or_cond50) {
      $apply_2 = 0;
      label = 15;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $23 = HEAP32[$1 >> 2] | 0;
    $24 = $23 + ($i_051 << 2) | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    if ($6) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $27 = ($25 | 0) > 0;
    $28 = -$25 | 0;
    $29 = $27 ? $25 : $28;
    $30 = _FT_MulDiv($apply_052, $29, 65536) | 0;
    $apply_1 = $30;
    label = 14;
    break;
   case 9:
    $32 = $im_start_coords + ($i_051 << 2) | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = ($25 | 0) > ($33 | 0);
    if ($34) {
      label = 10;
      break;
    } else {
      $apply_2 = 0;
      label = 15;
      break;
    }
   case 10:
    $36 = $im_end_coords + ($i_051 << 2) | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = ($25 | 0) < ($37 | 0);
    if ($38) {
      label = 11;
      break;
    } else {
      $apply_2 = 0;
      label = 15;
      break;
    }
   case 11:
    $40 = HEAP32[$8 >> 2] | 0;
    $41 = ($25 | 0) < ($40 | 0);
    if ($41) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $43 = $25 - $33 | 0;
    $44 = $40 - $33 | 0;
    $45 = _FT_MulDiv($43, 65536, $44) | 0;
    $46 = _FT_MulDiv($apply_052, $45, 65536) | 0;
    $apply_1 = $46;
    label = 14;
    break;
   case 13:
    $48 = $37 - $25 | 0;
    $49 = $37 - $40 | 0;
    $50 = _FT_MulDiv($48, 65536, $49) | 0;
    $51 = _FT_MulDiv($apply_052, $50, 65536) | 0;
    $apply_1 = $51;
    label = 14;
    break;
   case 14:
    $53 = $i_051 + 1 | 0;
    $54 = HEAP32[$2 >> 2] | 0;
    $55 = $53 >>> 0 < $54 >>> 0;
    if ($55) {
      $i_051 = $53;
      $apply_052 = $apply_1;
      label = 3;
      break;
    } else {
      $apply_2 = $apply_1;
      label = 15;
      break;
    }
   case 15:
    return $apply_2 | 0;
  }
  return 0;
}
function _ft_var_readpackedpoints($stream, $point_cnt) {
  $stream = $stream | 0;
  $point_cnt = $point_cnt | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $n_0 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $i_0_be = 0, $23 = 0, $24 = 0, $25 = 0, $i_049 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $smax = 0, $first_039 = 0, $j_038 = 0, $i_137 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $smax51 = 0, $first_144 = 0, $j_143 = 0, $i_242 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $3 = _FT_Stream_GetChar($stream) | 0;
    $4 = $3 & 255;
    HEAP32[$point_cnt >> 2] = $4;
    $5 = $3 << 24 >> 24 == 0;
    if ($5) {
      $_0 = -1;
      label = 20;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $4 & 128;
    $8 = ($7 | 0) == 0;
    if ($8) {
      $n_0 = $4;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $10 = _FT_Stream_GetChar($stream) | 0;
    $11 = $10 & 255;
    $12 = $4 << 8;
    $13 = $12 & 32512;
    $14 = $11 | $13;
    $n_0 = $14;
    label = 4;
    break;
   case 4:
    $16 = _ft_mem_realloc($2, 2, 0, $n_0, 0, $error) | 0;
    $17 = $16;
    $18 = HEAP32[$error >> 2] | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 5;
      break;
    } else {
      $_0 = 0;
      label = 20;
      break;
    }
   case 5:
    $20 = ($n_0 | 0) > 0;
    if ($20) {
      $i_049 = 0;
      label = 9;
      break;
    } else {
      $_0 = $17;
      label = 20;
      break;
    }
   case 6:
    $21 = $i_049 + 1 | 0;
    $22 = $21 + $smax | 0;
    $i_0_be = $22;
    label = 7;
    break;
   case 7:
    $23 = ($i_0_be | 0) < ($n_0 | 0);
    if ($23) {
      $i_049 = $i_0_be;
      label = 9;
      break;
    } else {
      $_0 = $17;
      label = 20;
      break;
    }
   case 8:
    $24 = $i_049 + 1 | 0;
    $25 = $24 + $smax51 | 0;
    $i_0_be = $25;
    label = 7;
    break;
   case 9:
    $26 = _FT_Stream_GetChar($stream) | 0;
    $27 = $26 & 255;
    $28 = $27 & 128;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 15;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $31 = $27 & 127;
    $32 = _FT_Stream_GetShort($stream) | 0;
    $33 = $i_049 + 1 | 0;
    $34 = $17 + ($i_049 << 1) | 0;
    HEAP16[$34 >> 1] = $32;
    $35 = ($31 | 0) == 0;
    if ($35) {
      $_0 = $17;
      label = 20;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $37 = $32 & 65535;
    $38 = $31 + $33 | 0;
    $39 = ($38 | 0) < ($n_0 | 0);
    if ($39) {
      label = 12;
      break;
    } else {
      $_0 = $17;
      label = 20;
      break;
    }
   case 12:
    $40 = ($31 | 0) == 0;
    if ($40) {
      $i_0_be = $33;
      label = 7;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $41 = $26 & 255;
    $42 = $41 & 127;
    $43 = $42 >>> 0 > 1;
    $smax = $43 ? $42 : 1;
    $i_137 = $33;
    $j_038 = 0;
    $first_039 = $37;
    label = 14;
    break;
   case 14:
    $45 = _FT_Stream_GetShort($stream) | 0;
    $46 = $45 & 65535;
    $47 = $46 + $first_039 | 0;
    $48 = $47 & 65535;
    $49 = $i_137 + 1 | 0;
    $50 = $17 + ($i_137 << 1) | 0;
    HEAP16[$50 >> 1] = $48;
    $51 = $j_038 + 1 | 0;
    $52 = ($51 | 0) < ($31 | 0);
    if ($52) {
      $i_137 = $49;
      $j_038 = $51;
      $first_039 = $47;
      label = 14;
      break;
    } else {
      label = 6;
      break;
    }
   case 15:
    $54 = _FT_Stream_GetChar($stream) | 0;
    $55 = $54 & 255;
    $56 = $i_049 + 1 | 0;
    $57 = $17 + ($i_049 << 1) | 0;
    HEAP16[$57 >> 1] = $55;
    $58 = $26 << 24 >> 24 == 0;
    if ($58) {
      $_0 = $17;
      label = 20;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $60 = $54 & 255;
    $61 = $27 + $56 | 0;
    $62 = ($61 | 0) < ($n_0 | 0);
    if ($62) {
      label = 17;
      break;
    } else {
      $_0 = $17;
      label = 20;
      break;
    }
   case 17:
    $63 = $26 << 24 >> 24 == 0;
    if ($63) {
      $i_0_be = $56;
      label = 7;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $64 = $26 & 255;
    $65 = $64 >>> 0 > 1;
    $smax51 = $65 ? $64 : 1;
    $i_242 = $56;
    $j_143 = 0;
    $first_144 = $60;
    label = 19;
    break;
   case 19:
    $67 = _FT_Stream_GetChar($stream) | 0;
    $68 = $67 & 255;
    $69 = $68 + $first_144 | 0;
    $70 = $69 & 65535;
    $71 = $i_242 + 1 | 0;
    $72 = $17 + ($i_242 << 1) | 0;
    HEAP16[$72 >> 1] = $70;
    $73 = $j_143 + 1 | 0;
    $74 = ($73 | 0) < ($27 | 0);
    if ($74) {
      $i_242 = $71;
      $j_143 = $73;
      $first_144 = $69;
      label = 19;
      break;
    } else {
      label = 8;
      break;
    }
   case 20:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _ft_var_readpackeddeltas($stream, $delta_cnt) {
  $stream = $stream | 0;
  $delta_cnt = $delta_cnt | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $i_0 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $_not66 = 0, $20 = 0, $21 = 0, $umax62 = 0, $22 = 0, $23 = 0, $24 = 0, $_not65 = 0, $25 = 0, $26 = 0, $umax60 = 0, $27 = 0, $j_144 = 0, $i_243 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $exitcond = 0, $j_252 = 0, $i_351 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $exitcond63 = 0, $39 = 0, $40 = 0, $_not = 0, $41 = 0, $42 = 0, $umax = 0, $43 = 0, $scevgep = 0, $44 = 0, $45 = 0, $_not64 = 0, $46 = 0, $47 = 0, $umax58 = 0, $48 = 0, $49 = 0, $umax_pn = 0, $j_3 = 0, $i_4 = 0, $50 = 0, $51 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $3 = _ft_mem_realloc($2, 2, 0, $delta_cnt, 0, $error) | 0;
    $4 = $3;
    $5 = HEAP32[$error >> 2] | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      $i_0 = 0;
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 17;
      break;
    }
   case 2:
    $7 = $i_0 >>> 0 < $delta_cnt >>> 0;
    if ($7) {
      label = 3;
      break;
    } else {
      $_0 = $4;
      label = 17;
      break;
    }
   case 3:
    $9 = _FT_Stream_GetChar($stream) | 0;
    $10 = $9 & 255;
    $11 = $10 & 128;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $13 = $i_0 >>> 0 < $delta_cnt >>> 0;
    if ($13) {
      label = 12;
      break;
    } else {
      label = 16;
      break;
    }
   case 5:
    $15 = $10 & 64;
    $16 = ($15 | 0) == 0;
    $17 = $i_0 >>> 0 < $delta_cnt >>> 0;
    if ($16) {
      label = 6;
      break;
    } else {
      label = 8;
      break;
    }
   case 6:
    if ($17) {
      label = 7;
      break;
    } else {
      label = 16;
      break;
    }
   case 7:
    $18 = $i_0 - $delta_cnt | 0;
    $19 = $9 & 255;
    $_not66 = $19 | -64;
    $20 = $_not66 ^ 63;
    $21 = $18 >>> 0 > $20 >>> 0;
    $umax62 = $21 ? $18 : $20;
    $22 = -$umax62 | 0;
    $i_351 = $i_0;
    $j_252 = 0;
    label = 11;
    break;
   case 8:
    if ($17) {
      label = 9;
      break;
    } else {
      label = 16;
      break;
    }
   case 9:
    $23 = $i_0 - $delta_cnt | 0;
    $24 = $9 & 255;
    $_not65 = $24 | -64;
    $25 = $_not65 ^ 63;
    $26 = $23 >>> 0 > $25 >>> 0;
    $umax60 = $26 ? $23 : $25;
    $27 = -$umax60 | 0;
    $i_243 = $i_0;
    $j_144 = 0;
    label = 10;
    break;
   case 10:
    $29 = _FT_Stream_GetShort($stream) | 0;
    $30 = $i_243 + 1 | 0;
    $31 = $4 + ($i_243 << 1) | 0;
    HEAP16[$31 >> 1] = $29;
    $32 = $j_144 + 1 | 0;
    $exitcond = ($32 | 0) == ($27 | 0);
    if ($exitcond) {
      label = 13;
      break;
    } else {
      $i_243 = $30;
      $j_144 = $32;
      label = 10;
      break;
    }
   case 11:
    $34 = _FT_Stream_GetChar($stream) | 0;
    $35 = $34 << 24 >> 24;
    $36 = $i_351 + 1 | 0;
    $37 = $4 + ($i_351 << 1) | 0;
    HEAP16[$37 >> 1] = $35;
    $38 = $j_252 + 1 | 0;
    $exitcond63 = ($38 | 0) == ($22 | 0);
    if ($exitcond63) {
      label = 14;
      break;
    } else {
      $i_351 = $36;
      $j_252 = $38;
      label = 11;
      break;
    }
   case 12:
    $39 = $i_0 - $delta_cnt | 0;
    $40 = $9 & 255;
    $_not = $40 | -64;
    $41 = $_not ^ 63;
    $42 = $39 >>> 0 > $41 >>> 0;
    $umax = $42 ? $39 : $41;
    $43 = $i_0 << 1;
    $scevgep = $3 + $43 | 0;
    $44 = $i_0 - $delta_cnt | 0;
    $45 = $9 & 255;
    $_not64 = $45 | -64;
    $46 = $_not64 ^ 63;
    $47 = $44 >>> 0 > $46 >>> 0;
    $umax58 = $47 ? $44 : $46;
    $48 = $umax58 * -2 & -1;
    _memset($scevgep | 0, 0, $48 | 0);
    $49 = -$umax | 0;
    $j_3 = $49;
    $umax_pn = $umax;
    label = 15;
    break;
   case 13:
    $j_3 = $27;
    $umax_pn = $umax60;
    label = 15;
    break;
   case 14:
    $j_3 = $22;
    $umax_pn = $umax62;
    label = 15;
    break;
   case 15:
    $i_4 = $i_0 - $umax_pn | 0;
    $50 = $10 & 63;
    $51 = $j_3 >>> 0 > $50 >>> 0;
    if ($51) {
      $i_0 = $i_4;
      label = 2;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    _ft_mem_free($2, $3);
    $_0 = 0;
    label = 17;
    break;
   case 17:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _tt_check_trickyness_family($name) {
  $name = $name | 0;
  var $nn_0 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $nn_0 = 0;
    label = 2;
    break;
   case 2:
    $2 = ($nn_0 | 0) < 8;
    if ($2) {
      label = 3;
      break;
    } else {
      $_0 = 0;
      label = 4;
      break;
    }
   case 3:
    $4 = 5245e3 + ($nn_0 * 17 & -1) | 0;
    $5 = _strstr($name | 0, $4 | 0) | 0;
    $6 = ($5 | 0) == 0;
    $7 = $nn_0 + 1 | 0;
    if ($6) {
      $nn_0 = $7;
      label = 2;
      break;
    } else {
      $_0 = 1;
      label = 4;
      break;
    }
   case 4:
    return $_0 | 0;
  }
  return 0;
}
function _tt_check_trickyness_sfnt_ids($face) {
  $face = $face | 0;
  var $num_matched_ids = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $i_021 = 0, $7 = 0, $8 = 0, $9 = 0, $k_0 = 0, $13 = 0, $j_018 = 0, $checksum_017 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $24 = 0, $checksum_1 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $checksum_2 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 20 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $num_matched_ids = __stackBase__ | 0;
    $1 = $num_matched_ids;
    _memset($1 | 0, 0, 20);
    $2 = $face + 152 | 0;
    $3 = HEAP16[$2 >> 1] | 0;
    $4 = $3 << 16 >> 16 == 0;
    if ($4) {
      $_0 = 0;
      label = 15;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $face + 156 | 0;
    $i_021 = 0;
    label = 3;
    break;
   case 3:
    $7 = HEAP32[$5 >> 2] | 0;
    $8 = $7 + ($i_021 << 4) | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    if (($9 | 0) == 1718642541) {
      label = 4;
      break;
    } else if (($9 | 0) == 1886545264) {
      label = 5;
      break;
    } else if (($9 | 0) == 1668707360) {
      $k_0 = 0;
      label = 6;
      break;
    } else {
      label = 14;
      break;
    }
   case 4:
    $k_0 = 1;
    label = 6;
    break;
   case 5:
    $k_0 = 2;
    label = 6;
    break;
   case 6:
    $13 = $i_021 & 65535;
    $checksum_017 = 0;
    $j_018 = 0;
    label = 7;
    break;
   case 7:
    $15 = HEAP32[$5 >> 2] | 0;
    $16 = $15 + ($i_021 << 4) + 12 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = 5244880 + ($j_018 * 24 & -1) + ($k_0 << 3) + 4 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = ($17 | 0) == ($19 | 0);
    if ($20) {
      label = 8;
      break;
    } else {
      $checksum_2 = $checksum_017;
      label = 13;
      break;
    }
   case 8:
    $22 = ($checksum_017 | 0) == 0;
    if ($22) {
      label = 9;
      break;
    } else {
      $checksum_1 = $checksum_017;
      label = 10;
      break;
    }
   case 9:
    $24 = _tt_get_sfnt_checksum($face, $13) | 0;
    $checksum_1 = $24;
    label = 10;
    break;
   case 10:
    $26 = 5244880 + ($j_018 * 24 & -1) + ($k_0 << 3) | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = ($27 | 0) == ($checksum_1 | 0);
    if ($28) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $30 = $num_matched_ids + ($j_018 << 2) | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $31 + 1 | 0;
    HEAP32[$30 >> 2] = $32;
    label = 12;
    break;
   case 12:
    $34 = $num_matched_ids + ($j_018 << 2) | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = ($35 | 0) == 3;
    if ($36) {
      $_0 = 1;
      label = 15;
      break;
    } else {
      $checksum_2 = $checksum_1;
      label = 13;
      break;
    }
   case 13:
    $38 = $j_018 + 1 | 0;
    $39 = ($38 | 0) < 5;
    if ($39) {
      $checksum_017 = $checksum_2;
      $j_018 = $38;
      label = 7;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $40 = $i_021 + 1 | 0;
    $41 = HEAP16[$2 >> 1] | 0;
    $42 = $41 & 65535;
    $43 = ($40 | 0) < ($42 | 0);
    if ($43) {
      $i_021 = $40;
      label = 3;
      break;
    } else {
      $_0 = 0;
      label = 15;
      break;
    }
   case 15:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _tt_get_sfnt_checksum($face, $i) {
  $face = $face | 0;
  $i = $i | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $i & 65535;
    $2 = $face + 156 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 + ($1 << 4) + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 2;
      break;
    } else {
      $_0 = $5;
      label = 5;
      break;
    }
   case 2:
    $8 = $face + 508 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      $_0 = 0;
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = $3 + ($1 << 4) | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $face + 104 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = FUNCTION_TABLE_iiiii[$9 & 1023]($face, $13, $15, 0) | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      $_0 = 0;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $19 = HEAP32[$14 >> 2] | 0;
    $20 = HEAP32[$2 >> 2] | 0;
    $21 = $20 + ($1 << 4) + 12 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = _tt_synth_sfnt_checksum($19, $22) | 0;
    $_0 = $23;
    label = 5;
    break;
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function _tt_synth_sfnt_checksum($stream, $length) {
  $stream = $stream | 0;
  $length = $length | 0;
  var $1 = 0, $2 = 0, $3 = 0, $checksum_0_lcssa = 0, $_012_lcssa = 0, $4 = 0, $checksum_018 = 0, $_01217 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $i_015 = 0, $checksum_114 = 0, $_113 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $checksum_1_lcssa = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _FT_Stream_EnterFrame($stream, $length) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 7;
      break;
    }
   case 2:
    $3 = $length >>> 0 > 3;
    if ($3) {
      $_01217 = $length;
      $checksum_018 = 0;
      label = 4;
      break;
    } else {
      $_012_lcssa = $length;
      $checksum_0_lcssa = 0;
      label = 3;
      break;
    }
   case 3:
    $4 = ($_012_lcssa | 0) == 0;
    if ($4) {
      $checksum_1_lcssa = $checksum_0_lcssa;
      label = 6;
      break;
    } else {
      $_113 = $_012_lcssa;
      $checksum_114 = $checksum_0_lcssa;
      $i_015 = 3;
      label = 5;
      break;
    }
   case 4:
    $5 = _FT_Stream_GetLong($stream) | 0;
    $6 = $5 + $checksum_018 | 0;
    $7 = $_01217 - 4 | 0;
    $8 = $7 >>> 0 > 3;
    if ($8) {
      $_01217 = $7;
      $checksum_018 = $6;
      label = 4;
      break;
    } else {
      $_012_lcssa = $7;
      $checksum_0_lcssa = $6;
      label = 3;
      break;
    }
   case 5:
    $9 = _FT_Stream_GetChar($stream) | 0;
    $10 = $9 & 255;
    $11 = $i_015 << 3;
    $12 = $10 << $11;
    $13 = $12 + $checksum_114 | 0;
    $14 = $_113 - 1 | 0;
    $15 = $i_015 - 1 | 0;
    $16 = ($14 | 0) == 0;
    if ($16) {
      $checksum_1_lcssa = $13;
      label = 6;
      break;
    } else {
      $_113 = $14;
      $checksum_114 = $13;
      $i_015 = $15;
      label = 5;
      break;
    }
   case 6:
    _FT_Stream_ExitFrame($stream);
    $_0 = $checksum_1_lcssa;
    label = 7;
    break;
   case 7:
    return $_0 | 0;
  }
  return 0;
}
function _tt_size_reset($size) {
  $size = $size | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $100 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size + 72 | 0;
    $2 = $size + 108 | 0;
    HEAP8[$2] = 0;
    $3 = $size | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $size + 44 | 0;
    $6 = $size + 12 | 0;
    $7 = $5;
    $8 = $6;
    _memcpy($7 | 0, $8 | 0, 28);
    $9 = $5 | 0;
    $10 = HEAP16[$9 >> 1] | 0;
    $11 = $10 & 65535;
    $12 = $10 << 16 >> 16 == 0;
    if ($12) {
      $_0 = 151;
      label = 9;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $14 = $size + 46 | 0;
    $15 = HEAP16[$14 >> 1] | 0;
    $16 = $15 << 16 >> 16 == 0;
    if ($16) {
      $_0 = 151;
      label = 9;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $18 = $4 + 160 | 0;
    $19 = $18 + 16 | 0;
    $20 = $19;
    $21 = HEAP16[$20 >> 1] | 0;
    $22 = $21 & 8;
    $23 = $22 << 16 >> 16 == 0;
    if ($23) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $25 = $11 << 6;
    $26 = $4 + 68 | 0;
    $27 = HEAP16[$26 >> 1] | 0;
    $28 = $27 & 65535;
    $29 = _FT_DivFix($25, $28) | 0;
    $30 = $size + 48 | 0;
    HEAP32[$30 >> 2] = $29;
    $31 = HEAP16[$14 >> 1] | 0;
    $32 = $31 & 65535;
    $33 = $32 << 6;
    $34 = HEAP16[$26 >> 1] | 0;
    $35 = $34 & 65535;
    $36 = _FT_DivFix($33, $35) | 0;
    $37 = $size + 52 | 0;
    HEAP32[$37 >> 2] = $36;
    $38 = $4 + 70 | 0;
    $39 = HEAP16[$38 >> 1] | 0;
    $40 = $39 << 16 >> 16;
    $41 = _FT_MulFix($40, $36) | 0;
    $42 = $41 + 32 | 0;
    $43 = $42 & -64;
    $44 = $size + 56 | 0;
    HEAP32[$44 >> 2] = $43;
    $45 = $4 + 72 | 0;
    $46 = HEAP16[$45 >> 1] | 0;
    $47 = $46 << 16 >> 16;
    $48 = HEAP32[$37 >> 2] | 0;
    $49 = _FT_MulFix($47, $48) | 0;
    $50 = $49 + 32 | 0;
    $51 = $50 & -64;
    $52 = $size + 60 | 0;
    HEAP32[$52 >> 2] = $51;
    $53 = $4 + 74 | 0;
    $54 = HEAP16[$53 >> 1] | 0;
    $55 = $54 << 16 >> 16;
    $56 = HEAP32[$37 >> 2] | 0;
    $57 = _FT_MulFix($55, $56) | 0;
    $58 = $57 + 32 | 0;
    $59 = $58 & -64;
    $60 = $size + 64 | 0;
    HEAP32[$60 >> 2] = $59;
    $61 = $4 + 76 | 0;
    $62 = HEAP16[$61 >> 1] | 0;
    $63 = $62 << 16 >> 16;
    $64 = HEAP32[$30 >> 2] | 0;
    $65 = _FT_MulFix($63, $64) | 0;
    $66 = $65 + 32 | 0;
    $67 = $66 & -64;
    $68 = $size + 68 | 0;
    HEAP32[$68 >> 2] = $67;
    label = 5;
    break;
   case 5:
    $70 = HEAP16[$9 >> 1] | 0;
    $71 = HEAP16[$14 >> 1] | 0;
    $72 = ($70 & 65535) < ($71 & 65535);
    if ($72) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $74 = $size + 48 | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    $76 = $size + 88 | 0;
    HEAP32[$76 >> 2] = $75;
    $77 = HEAP16[$9 >> 1] | 0;
    $78 = $size + 80 | 0;
    HEAP16[$78 >> 1] = $77;
    $79 = $1 | 0;
    HEAP32[$79 >> 2] = 65536;
    $80 = HEAP16[$14 >> 1] | 0;
    $81 = $80 & 65535;
    $82 = HEAP16[$9 >> 1] | 0;
    $83 = $82 & 65535;
    $84 = _FT_MulDiv($81, 65536, $83) | 0;
    $85 = $size + 76 | 0;
    HEAP32[$85 >> 2] = $84;
    label = 8;
    break;
   case 7:
    $87 = $size + 52 | 0;
    $88 = HEAP32[$87 >> 2] | 0;
    $89 = $size + 88 | 0;
    HEAP32[$89 >> 2] = $88;
    $90 = HEAP16[$14 >> 1] | 0;
    $91 = $size + 80 | 0;
    HEAP16[$91 >> 1] = $90;
    $92 = HEAP16[$9 >> 1] | 0;
    $93 = $92 & 65535;
    $94 = HEAP16[$14 >> 1] | 0;
    $95 = $94 & 65535;
    $96 = _FT_MulDiv($93, 65536, $95) | 0;
    $97 = $1 | 0;
    HEAP32[$97 >> 2] = $96;
    $98 = $size + 76 | 0;
    HEAP32[$98 >> 2] = 65536;
    label = 8;
    break;
   case 8:
    $100 = $size + 301 | 0;
    HEAP8[$100] = 0;
    HEAP8[$2] = 1;
    $_0 = 0;
    label = 9;
    break;
   case 9:
    return $_0 | 0;
  }
  return 0;
}
function _TT_Get_VMetrics($face, $idx, $tsb, $ah) {
  $face = $face | 0;
  $idx = $idx | 0;
  $tsb = $tsb | 0;
  $ah = $ah | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 296 | 0;
    $2 = HEAP8[$1] | 0;
    $3 = $2 << 24 >> 24 == 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $face + 532 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + 156 | 0;
    $8 = $7;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = FUNCTION_TABLE_iiiiii[$9 & 1023]($face, 1, $idx, $tsb, $ah) | 0;
    label = 4;
    break;
   case 3:
    HEAP16[$tsb >> 1] = 0;
    $12 = $face + 68 | 0;
    $13 = HEAP16[$12 >> 1] | 0;
    HEAP16[$ah >> 1] = $13;
    label = 4;
    break;
   case 4:
    return;
  }
}
function _TT_Get_HMetrics($face, $idx, $check, $lsb, $aw) {
  $face = $face | 0;
  $idx = $idx | 0;
  $check = $check | 0;
  $lsb = $lsb | 0;
  $aw = $aw | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 532 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 156 | 0;
    $4 = $3;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = FUNCTION_TABLE_iiiiii[$5 & 1023]($face, 0, $idx, $lsb, $aw) | 0;
    $7 = $check << 24 >> 24 == 0;
    if ($7) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = $face + 480 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $13 = $face + 226 | 0;
    $14 = HEAP16[$13 >> 1] | 0;
    HEAP16[$aw >> 1] = $14;
    label = 4;
    break;
   case 4:
    return;
  }
}
function _TT_Load_Glyph($size, $glyph, $glyph_index, $load_flags) {
  $size = $size | 0;
  $glyph = $glyph | 0;
  $glyph_index = $glyph_index | 0;
  $load_flags = $load_flags | 0;
  var $loader = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $88 = 0, $90 = 0, $91 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $99 = 0, $100 = 0, $102 = 0, $103 = 0, $105 = 0, $106 = 0, $108 = 0, $109 = 0, $111 = 0, $112 = 0, $114 = 0, $115 = 0, $119 = 0, $120 = 0, $121 = 0, $123 = 0, $124 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 208 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $loader = __stackBase__ | 0;
    $1 = $glyph + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $size + 112 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == -1;
    if ($5) {
      label = 8;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $load_flags & 8;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 3;
      break;
    } else {
      label = 8;
      break;
    }
   case 3:
    $10 = _load_sbit_image($size, $glyph, $glyph_index, $load_flags) | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 4;
      break;
    } else {
      label = 8;
      break;
    }
   case 4:
    $13 = $2 + 8 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 & 1;
    $16 = ($15 | 0) == 0;
    if ($16) {
      $_0 = 0;
      label = 29;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $18 = _tt_loader_init($loader, $size, $glyph, $load_flags, 1) | 0;
    $19 = _load_truetype_glyph($loader, $glyph_index, 0, 1) | 0;
    $20 = $loader + 60 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $glyph + 56 | 0;
    HEAP32[$22 >> 2] = $21;
    $23 = $loader + 176 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $loader + 48 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $26 + $24 | 0;
    $28 = $loader + 180 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $27 - $29 | 0;
    $31 = $glyph + 60 | 0;
    HEAP32[$31 >> 2] = $30;
    $32 = $2 + 468 | 0;
    $33 = $32 + 12 | 0;
    $34 = $33;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = ($35 | 0) == 0;
    if ($36) {
      $_0 = 0;
      label = 29;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $38 = $load_flags & 512;
    $39 = ($38 | 0) == 0;
    if ($39) {
      label = 7;
      break;
    } else {
      $_0 = 0;
      label = 29;
      break;
    }
   case 7:
    $41 = $2 + 216 | 0;
    $42 = $41;
    $43 = $42 + 10 | 0;
    $44 = HEAP16[$43 >> 1] | 0;
    $45 = $44 & 65535;
    HEAP32[$22 >> 2] = $45;
    $_0 = 0;
    label = 29;
    break;
   case 8:
    $47 = $load_flags & 1;
    $48 = ($47 | 0) != 0;
    if ($48) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $50 = $size + 108 | 0;
    $51 = HEAP8[$50] | 0;
    $52 = $51 << 24 >> 24 == 0;
    if ($52) {
      $_0 = 36;
      label = 29;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $54 = $load_flags & 16384;
    $55 = ($54 | 0) == 0;
    if ($55) {
      label = 11;
      break;
    } else {
      $_0 = 6;
      label = 29;
      break;
    }
   case 11:
    $57 = _tt_loader_init($loader, $size, $glyph, $load_flags, 0) | 0;
    $58 = ($57 | 0) == 0;
    if ($58) {
      label = 12;
      break;
    } else {
      $_0 = $57;
      label = 29;
      break;
    }
   case 12:
    $60 = $glyph + 72 | 0;
    HEAP32[$60 >> 2] = 1869968492;
    $61 = $glyph + 128 | 0;
    HEAP32[$61 >> 2] = 0;
    $62 = $glyph + 108 | 0;
    $63 = $glyph + 124 | 0;
    HEAP32[$63 >> 2] = 0;
    $64 = _load_truetype_glyph($loader, $glyph_index, 0, 0) | 0;
    $65 = ($64 | 0) == 0;
    if ($65) {
      label = 13;
      break;
    } else {
      label = 26;
      break;
    }
   case 13:
    $67 = HEAP32[$60 >> 2] | 0;
    $68 = ($67 | 0) == 1668246896;
    $69 = $loader + 12 | 0;
    $70 = HEAP32[$69 >> 2] | 0;
    if ($68) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $72 = $70 + 48 | 0;
    $73 = HEAP32[$72 >> 2] | 0;
    HEAP32[$61 >> 2] = $73;
    $74 = HEAP32[$69 >> 2] | 0;
    $75 = $74 + 52 | 0;
    $76 = HEAP32[$75 >> 2] | 0;
    $77 = $glyph + 132 | 0;
    HEAP32[$77 >> 2] = $76;
    label = 17;
    break;
   case 15:
    $79 = $70 + 20 | 0;
    $80 = $62;
    $81 = $79;
    _memcpy($80 | 0, $81 | 0, 20);
    $82 = HEAP32[$63 >> 2] | 0;
    $83 = $82 & -513;
    HEAP32[$63 >> 2] = $83;
    $84 = $loader + 68 | 0;
    $85 = HEAP32[$84 >> 2] | 0;
    $86 = ($85 | 0) == 0;
    if ($86) {
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $88 = -$85 | 0;
    _FT_Outline_Translate($62, $88, 0);
    label = 17;
    break;
   case 17:
    $90 = $load_flags & 2;
    $91 = ($90 | 0) == 0;
    if ($91) {
      label = 18;
      break;
    } else {
      label = 25;
      break;
    }
   case 18:
    $93 = $loader + 160 | 0;
    $94 = HEAP32[$93 >> 2] | 0;
    $95 = $94 + 337 | 0;
    $96 = HEAP8[$95] | 0;
    $97 = $96 << 24 >> 24 == 0;
    if ($97) {
      label = 24;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $99 = $94 + 340 | 0;
    $100 = HEAP32[$99 >> 2] | 0;
    if (($100 | 0) == 0) {
      label = 20;
      break;
    } else if (($100 | 0) == 4) {
      label = 21;
      break;
    } else if (($100 | 0) == 5) {
      label = 22;
      break;
    } else if (($100 | 0) == 1) {
      label = 25;
      break;
    } else {
      label = 23;
      break;
    }
   case 20:
    $102 = HEAP32[$63 >> 2] | 0;
    $103 = $102 | 32;
    HEAP32[$63 >> 2] = $103;
    label = 25;
    break;
   case 21:
    $105 = HEAP32[$63 >> 2] | 0;
    $106 = $105 | 48;
    HEAP32[$63 >> 2] = $106;
    label = 25;
    break;
   case 22:
    $108 = HEAP32[$63 >> 2] | 0;
    $109 = $108 | 16;
    HEAP32[$63 >> 2] = $109;
    label = 25;
    break;
   case 23:
    $111 = HEAP32[$63 >> 2] | 0;
    $112 = $111 | 8;
    HEAP32[$63 >> 2] = $112;
    label = 25;
    break;
   case 24:
    $114 = HEAP32[$63 >> 2] | 0;
    $115 = $114 | 8;
    HEAP32[$63 >> 2] = $115;
    label = 25;
    break;
   case 25:
    _compute_glyph_metrics($loader, $glyph_index);
    label = 26;
    break;
   case 26:
    if ($48) {
      $_0 = $64;
      label = 29;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $119 = $size + 14 | 0;
    $120 = HEAP16[$119 >> 1] | 0;
    $121 = ($120 & 65535) < 24;
    if ($121) {
      label = 28;
      break;
    } else {
      $_0 = $64;
      label = 29;
      break;
    }
   case 28:
    $123 = HEAP32[$63 >> 2] | 0;
    $124 = $123 | 256;
    HEAP32[$63 >> 2] = $124;
    $_0 = $64;
    label = 29;
    break;
   case 29:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _load_sbit_image($size, $glyph, $glyph_index, $load_flags) {
  $size = $size | 0;
  $glyph = $glyph | 0;
  $glyph_index = $glyph_index | 0;
  $load_flags = $load_flags | 0;
  var $metrics = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $metrics = __stackBase__ | 0;
    $1 = $glyph + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    $4 = $2 + 532 | 0;
    $5 = $4;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $2 + 104 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $6 + 104 | 0;
    $10 = $9;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $size + 112 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $glyph + 76 | 0;
    $15 = FUNCTION_TABLE_iiiiiiii[$11 & 1023]($3, $13, $glyph_index, $load_flags, $8, $14, $metrics) | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 2:
    $18 = $glyph + 110 | 0;
    HEAP16[$18 >> 1] = 0;
    $19 = $glyph + 108 | 0;
    HEAP16[$19 >> 1] = 0;
    $20 = $metrics + 1 | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $21 & 255;
    $23 = $22 << 6;
    $24 = $glyph + 24 | 0;
    HEAP32[$24 >> 2] = $23;
    $25 = $metrics | 0;
    $26 = HEAP8[$25] | 0;
    $27 = $26 & 255;
    $28 = $27 << 6;
    $29 = $glyph + 28 | 0;
    HEAP32[$29 >> 2] = $28;
    $30 = $metrics + 2 | 0;
    $31 = HEAP8[$30] | 0;
    $32 = $31 << 24 >> 24;
    $33 = $32 << 6;
    $34 = $glyph + 32 | 0;
    HEAP32[$34 >> 2] = $33;
    $35 = $metrics + 3 | 0;
    $36 = HEAP8[$35] | 0;
    $37 = $36 << 24 >> 24;
    $38 = $37 << 6;
    $39 = $glyph + 36 | 0;
    HEAP32[$39 >> 2] = $38;
    $40 = $metrics + 4 | 0;
    $41 = HEAP8[$40] | 0;
    $42 = $41 & 255;
    $43 = $42 << 6;
    $44 = $glyph + 40 | 0;
    HEAP32[$44 >> 2] = $43;
    $45 = $metrics + 5 | 0;
    $46 = HEAP8[$45] | 0;
    $47 = $46 << 24 >> 24;
    $48 = $47 << 6;
    $49 = $glyph + 44 | 0;
    HEAP32[$49 >> 2] = $48;
    $50 = $metrics + 6 | 0;
    $51 = HEAP8[$50] | 0;
    $52 = $51 << 24 >> 24;
    $53 = $52 << 6;
    $54 = $glyph + 48 | 0;
    HEAP32[$54 >> 2] = $53;
    $55 = $metrics + 7 | 0;
    $56 = HEAP8[$55] | 0;
    $57 = $56 & 255;
    $58 = $57 << 6;
    $59 = $glyph + 52 | 0;
    HEAP32[$59 >> 2] = $58;
    $60 = $glyph + 72 | 0;
    HEAP32[$60 >> 2] = 1651078259;
    $61 = $load_flags & 16;
    $62 = ($61 | 0) == 0;
    if ($62) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $64 = HEAP8[$45] | 0;
    $65 = $64 << 24 >> 24;
    $66 = $glyph + 100 | 0;
    HEAP32[$66 >> 2] = $65;
    $67 = HEAP8[$50] | 0;
    $68 = $67 << 24 >> 24;
    $69 = $glyph + 104 | 0;
    HEAP32[$69 >> 2] = $68;
    label = 5;
    break;
   case 4:
    $71 = HEAP8[$30] | 0;
    $72 = $71 << 24 >> 24;
    $73 = $glyph + 100 | 0;
    HEAP32[$73 >> 2] = $72;
    $74 = HEAP8[$35] | 0;
    $75 = $74 << 24 >> 24;
    $76 = $glyph + 104 | 0;
    HEAP32[$76 >> 2] = $75;
    label = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return $15 | 0;
  }
  return 0;
}
function _tt_loader_init($loader, $size, $glyph, $load_flags, $glyf_table_only) {
  $loader = $loader | 0;
  $size = $size | 0;
  $glyph = $glyph | 0;
  $load_flags = $load_flags | 0;
  $glyf_table_only = $glyf_table_only | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or_cond = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $_in = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $i_060 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $load_flags_ = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $_059_tr = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $_1 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $86 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $93 = 0, $95 = 0, $96 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $glyph + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    $4 = $2 + 104 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $loader;
    _memset($6 | 0, 0, 208);
    $7 = $load_flags & 2;
    $8 = ($7 | 0) == 0;
    $9 = $glyf_table_only << 24 >> 24 == 0;
    $or_cond = $8 & $9;
    if ($or_cond) {
      label = 2;
      break;
    } else {
      $_1 = $load_flags;
      label = 16;
      break;
    }
   case 2:
    $11 = $size + 301 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $12 << 24 >> 24 == 0;
    if ($13) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $15 = _tt_size_ready_bytecode($size) | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 4;
      break;
    } else {
      $_0 = $15;
      label = 24;
      break;
    }
   case 4:
    $18 = $size + 292 | 0;
    $19 = HEAP8[$18] | 0;
    $20 = $19 << 24 >> 24 == 0;
    if ($20) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $22 = $size + 296 | 0;
    $_in = $22;
    label = 7;
    break;
   case 6:
    $24 = $2 + 96 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $25 + 40 | 0;
    $27 = $26;
    $_in = $27;
    label = 7;
    break;
   case 7:
    $29 = HEAP32[$_in >> 2] | 0;
    $30 = ($29 | 0) == 0;
    if ($30) {
      $_0 = 153;
      label = 24;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $32 = $load_flags & 983040;
    $33 = ($32 | 0) != 131072;
    _TT_Load_Context($29, $3, $size);
    $34 = $33 & 1;
    $35 = $29 + 604 | 0;
    $36 = HEAP8[$35] | 0;
    $37 = $36 & 255;
    $38 = ($34 | 0) == ($37 | 0);
    if ($38) {
      label = 13;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $40 = $33 & 1;
    HEAP8[$35] = $40;
    $41 = $size + 240 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = ($42 | 0) == 0;
    if ($43) {
      label = 12;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $44 = $2 + 672 | 0;
    $45 = $44;
    $46 = $size + 88 | 0;
    $47 = $size + 244 | 0;
    $i_060 = 0;
    label = 11;
    break;
   case 11:
    $49 = HEAP32[$45 >> 2] | 0;
    $50 = $49 + ($i_060 << 1) | 0;
    $51 = HEAP16[$50 >> 1] | 0;
    $52 = $51 << 16 >> 16;
    $53 = HEAP32[$46 >> 2] | 0;
    $54 = _FT_MulFix($52, $53) | 0;
    $55 = HEAP32[$47 >> 2] | 0;
    $56 = $55 + ($i_060 << 2) | 0;
    HEAP32[$56 >> 2] = $54;
    $57 = $i_060 + 1 | 0;
    $58 = HEAP32[$41 >> 2] | 0;
    $59 = $57 >>> 0 < $58 >>> 0;
    if ($59) {
      $i_060 = $57;
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $60 = _tt_size_run_prep($size) | 0;
    label = 13;
    break;
   case 13:
    $62 = $29 + 336 | 0;
    $63 = HEAP8[$62] | 0;
    $64 = $63 & 1;
    $65 = $64 << 24 >> 24 == 0;
    $66 = $load_flags | 2;
    $load_flags_ = $65 ? $load_flags : $66;
    $67 = $63 & 2;
    $68 = $67 << 24 >> 24 == 0;
    if ($68) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $70 = $29 + 284 | 0;
    $71 = $70;
    _memcpy($71 | 0, 5244304, 68);
    label = 15;
    break;
   case 15:
    $_059_tr = $load_flags_ & 255;
    $73 = $_059_tr & -128;
    $74 = $29 + 561 | 0;
    HEAP8[$74] = $73;
    $75 = $loader + 160 | 0;
    HEAP32[$75 >> 2] = $29;
    $76 = $29 + 392 | 0;
    $77 = HEAP32[$76 >> 2] | 0;
    $78 = $loader + 164 | 0;
    HEAP32[$78 >> 2] = $77;
    $_1 = $load_flags_;
    label = 16;
    break;
   case 16:
    $80 = $2 + 128 | 0;
    $81 = HEAP32[$80 >> 2] | 0;
    $82 = $81 + 52 | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = ($83 | 0) == 0;
    if ($84) {
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $86 = $loader + 84 | 0;
    HEAP32[$86 >> 2] = 0;
    label = 21;
    break;
   case 18:
    $88 = $2 + 508 | 0;
    $89 = HEAP32[$88 >> 2] | 0;
    $90 = $89;
    $91 = FUNCTION_TABLE_iiiii[$90 & 1023]($3, 1735162214, $5, 0) | 0;
    if (($91 | 0) == 142) {
      label = 19;
      break;
    } else if (($91 | 0) == 0) {
      label = 20;
      break;
    } else {
      $_0 = $91;
      label = 24;
      break;
    }
   case 19:
    $93 = $loader + 84 | 0;
    HEAP32[$93 >> 2] = 0;
    label = 21;
    break;
   case 20:
    $95 = _FT_Stream_Pos($5) | 0;
    $96 = $loader + 84 | 0;
    HEAP32[$96 >> 2] = $95;
    label = 21;
    break;
   case 21:
    if ($9) {
      label = 22;
      break;
    } else {
      label = 23;
      break;
    }
   case 22:
    $99 = $glyph + 156 | 0;
    $100 = HEAP32[$99 >> 2] | 0;
    $101 = $100 | 0;
    $102 = HEAP32[$101 >> 2] | 0;
    _FT_GlyphLoader_Rewind($102);
    $103 = $loader + 12 | 0;
    HEAP32[$103 >> 2] = $102;
    label = 23;
    break;
   case 23:
    $105 = $loader + 16 | 0;
    HEAP32[$105 >> 2] = $_1;
    $106 = $loader | 0;
    HEAP32[$106 >> 2] = $2;
    $107 = $size | 0;
    $108 = $loader + 4 | 0;
    HEAP32[$108 >> 2] = $107;
    $109 = $loader + 8 | 0;
    HEAP32[$109 >> 2] = $glyph;
    $110 = $loader + 24 | 0;
    HEAP32[$110 >> 2] = $5;
    $_0 = 0;
    label = 24;
    break;
   case 24:
    return $_0 | 0;
  }
  return 0;
}
function _tt_face_get_device_metrics($face, $ppem, $gindex) {
  $face = $face | 0;
  $ppem = $ppem | 0;
  $gindex = $gindex | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $nn_0 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $21 = 0, $_sum = 0, $_sum12 = 0, $22 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 752 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 740 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $face + 748 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $face + 756 | 0;
    $nn_0 = 0;
    label = 2;
    break;
   case 2:
    $9 = $nn_0 >>> 0 < $6 >>> 0;
    if ($9) {
      label = 3;
      break;
    } else {
      $result_0 = 0;
      label = 6;
      break;
    }
   case 3:
    $11 = HEAP32[$7 >> 2] | 0;
    $12 = $11 + $nn_0 | 0;
    $13 = HEAP8[$12] | 0;
    $14 = $13 & 255;
    $15 = ($14 | 0) == ($ppem | 0);
    $16 = $nn_0 + 1 | 0;
    if ($15) {
      label = 4;
      break;
    } else {
      $nn_0 = $16;
      label = 2;
      break;
    }
   case 4:
    $18 = $gindex + 2 | 0;
    $19 = $18 >>> 0 < $2 >>> 0;
    if ($19) {
      label = 5;
      break;
    } else {
      $result_0 = 0;
      label = 6;
      break;
    }
   case 5:
    $21 = Math_imul($nn_0, $2);
    $_sum = $gindex + 10 | 0;
    $_sum12 = $_sum + $21 | 0;
    $22 = $4 + $_sum12 | 0;
    $result_0 = $22;
    label = 6;
    break;
   case 6:
    return $result_0 | 0;
  }
  return 0;
}
function _load_truetype_glyph($loader, $glyph_index, $recurse_count, $header_only) {
  $loader = $loader | 0;
  $glyph_index = $glyph_index | 0;
  $recurse_count = $recurse_count | 0;
  $header_only = $header_only | 0;
  var $deltas = 0, $inc_stream = 0, $glyph_data = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $y_scale_0 = 0, $x_scale_0 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $glyph_data_loaded_0 = 0, $offset_0 = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $or_cond = 0, $_pr = 0, $90 = 0, $opened_frame_0 = 0, $error_1 = 0, $91 = 0, $93 = 0, $94 = 0, $95 = 0, $97 = 0, $98 = 0, $99 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $181 = 0, $182 = 0, $183 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $192 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $227 = 0, $228 = 0, $229 = 0, $230 = 0, $231 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $240 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $250 = 0, $251 = 0, $252 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $260 = 0, $261 = 0, $262 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $270 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $subglyph_0235 = 0, $i_0234 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $285 = 0, $286 = 0, $287 = 0, $sext = 0, $288 = 0, $289 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $sext220 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $300 = 0, $301 = 0, $exitcond = 0, $i_0_lcssa = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $error_2 = 0, $348 = 0, $349 = 0, $350 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $361 = 0, $362 = 0, $363 = 0, $365 = 0, $366 = 0, $367 = 0, $369 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $380 = 0, $381 = 0, $382 = 0, $n_0231 = 0, $384 = 0, $_sum = 0, $ld$0$0 = 0, $385$0 = 0, $ld$1$1 = 0, $385$1 = 0, $ld$2$0 = 0, $386$0 = 0, $ld$3$1 = 0, $386$1 = 0, $ld$4$0 = 0, $387$0 = 0, $ld$5$1 = 0, $387$1 = 0, $ld$6$0 = 0, $388$0 = 0, $ld$7$1 = 0, $388$1 = 0, $389 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $400 = 0, $401 = 0, $st$8$0 = 0, $st$9$1 = 0, $st$10$0 = 0, $st$11$1 = 0, $st$12$0 = 0, $st$13$1 = 0, $st$14$0 = 0, $st$15$1 = 0, $404 = 0, $405 = 0, $406 = 0, $409 = 0, $410 = 0, $error_3_lcssa = 0, $num_points_0_lcssa = 0, $subglyph2_0_lcssa = 0, $411 = 0, $412 = 0, $413 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $or_cond221 = 0, $error_4 = 0, $422 = 0, $error_4226 = 0, $423 = 0, $424 = 0, $425 = 0, $error_4223 = 0, $426 = 0, $428 = 0, $429 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $error_4223227 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 52 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $deltas = __stackBase__ | 0;
    $inc_stream = __stackBase__ + 4 | 0;
    $glyph_data = __stackBase__ + 44 | 0;
    $1 = $loader | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    $4 = $loader + 12 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    HEAP32[$deltas >> 2] = 0;
    $6 = $recurse_count >>> 0 > 1;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $8 = $2 + 260 | 0;
    $9 = $8;
    $10 = $9 + 30 | 0;
    $11 = HEAP16[$10 >> 1] | 0;
    $12 = $11 & 65535;
    $13 = $12 >>> 0 < $recurse_count >>> 0;
    if ($13) {
      $error_4223227 = 21;
      label = 57;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $15 = $2 + 16 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $16 >>> 0 > $glyph_index >>> 0;
    if ($17) {
      label = 4;
      break;
    } else {
      $error_4223227 = 16;
      label = 57;
      break;
    }
   case 4:
    $19 = $loader + 20 | 0;
    HEAP32[$19 >> 2] = $glyph_index;
    $20 = $loader + 16 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $21 & 1;
    $23 = ($22 | 0) == 0;
    if ($23) {
      label = 5;
      break;
    } else {
      $x_scale_0 = 65536;
      $y_scale_0 = 65536;
      label = 6;
      break;
    }
   case 5:
    $25 = $loader + 4 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $26 + 48 | 0;
    $28 = $27;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $26 + 52 | 0;
    $31 = $30;
    $32 = HEAP32[$31 >> 2] | 0;
    $x_scale_0 = $29;
    $y_scale_0 = $32;
    label = 6;
    break;
   case 6:
    _tt_get_metrics($loader, $glyph_index);
    $34 = $2 + 128 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $35 + 52 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = ($37 | 0) == 0;
    if ($38) {
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $40 = $37 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = $41 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $37 + 4 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = FUNCTION_TABLE_iiii[$43 & 1023]($45, $glyph_index, $glyph_data) | 0;
    $47 = ($46 | 0) == 0;
    if ($47) {
      label = 8;
      break;
    } else {
      $error_4223227 = $46;
      label = 57;
      break;
    }
   case 8:
    $49 = $glyph_data + 4 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $loader + 28 | 0;
    HEAP32[$51 >> 2] = $50;
    $52 = $inc_stream;
    _memset($52 | 0, 0, 40);
    $53 = $glyph_data | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = HEAP32[$49 >> 2] | 0;
    _FT_Stream_OpenMemory($inc_stream, $54, $55);
    $56 = $loader + 24 | 0;
    HEAP32[$56 >> 2] = $inc_stream;
    $offset_0 = 0;
    $glyph_data_loaded_0 = 1;
    label = 10;
    break;
   case 9:
    $58 = $loader + 28 | 0;
    $59 = _tt_face_get_location($3, $glyph_index, $58) | 0;
    $offset_0 = $59;
    $glyph_data_loaded_0 = 0;
    label = 10;
    break;
   case 10:
    $61 = $loader + 28 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = ($62 | 0) > 0;
    if ($63) {
      label = 11;
      break;
    } else {
      $error_1 = 0;
      $opened_frame_0 = 0;
      $90 = $62;
      label = 16;
      break;
    }
   case 11:
    $65 = $loader + 84 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = ($66 | 0) == 0;
    if ($67) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $69 = HEAP32[$34 >> 2] | 0;
    $70 = $69 + 52 | 0;
    $71 = HEAP32[$70 >> 2] | 0;
    $72 = ($71 | 0) == 0;
    if ($72) {
      $error_4223 = 8;
      label = 55;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $74 = $2 + 512 | 0;
    $75 = $74;
    $76 = HEAP32[$75 >> 2] | 0;
    $77 = HEAP32[$65 >> 2] | 0;
    $78 = $77 + $offset_0 | 0;
    $79 = HEAP32[$61 >> 2] | 0;
    $80 = FUNCTION_TABLE_iiiii[$76 & 1023]($loader, $glyph_index, $78, $79) | 0;
    $81 = ($80 | 0) == 0;
    if ($81) {
      label = 14;
      break;
    } else {
      $error_4223 = $80;
      label = 55;
      break;
    }
   case 14:
    $83 = $2 + 520 | 0;
    $84 = HEAP32[$83 >> 2] | 0;
    $85 = $84;
    $86 = FUNCTION_TABLE_ii[$85 & 1023]($loader) | 0;
    $87 = ($86 | 0) == 0;
    $88 = $header_only << 24 >> 24 == 0;
    $or_cond = $87 & $88;
    if ($or_cond) {
      label = 15;
      break;
    } else {
      $error_4226 = $86;
      label = 54;
      break;
    }
   case 15:
    $_pr = HEAP32[$61 >> 2] | 0;
    $error_1 = $86;
    $opened_frame_0 = 1;
    $90 = $_pr;
    label = 16;
    break;
   case 16:
    $91 = ($90 | 0) == 0;
    if ($91) {
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $93 = $loader + 32 | 0;
    $94 = HEAP16[$93 >> 1] | 0;
    $95 = $94 << 16 >> 16 == 0;
    if ($95) {
      label = 18;
      break;
    } else {
      label = 24;
      break;
    }
   case 18:
    $97 = $loader + 36 | 0;
    $98 = $header_only << 24 >> 24 == 0;
    $99 = $97;
    _memset($99 | 0, 0, 16);
    if ($98) {
      label = 19;
      break;
    } else {
      $error_4 = $error_1;
      label = 53;
      break;
    }
   case 19:
    $101 = $loader + 48 | 0;
    $102 = HEAP32[$97 >> 2] | 0;
    $103 = $loader + 52 | 0;
    $104 = HEAP32[$103 >> 2] | 0;
    $105 = $102 - $104 | 0;
    $106 = $loader + 68 | 0;
    HEAP32[$106 >> 2] = $105;
    $107 = $loader + 72 | 0;
    HEAP32[$107 >> 2] = 0;
    $108 = HEAP32[$106 >> 2] | 0;
    $109 = $loader + 56 | 0;
    $110 = HEAP32[$109 >> 2] | 0;
    $111 = $110 + $108 | 0;
    $112 = $loader + 76 | 0;
    HEAP32[$112 >> 2] = $111;
    $113 = $loader + 80 | 0;
    HEAP32[$113 >> 2] = 0;
    $114 = $loader + 184 | 0;
    HEAP32[$114 >> 2] = 0;
    $115 = $loader + 176 | 0;
    $116 = HEAP32[$115 >> 2] | 0;
    $117 = HEAP32[$101 >> 2] | 0;
    $118 = $117 + $116 | 0;
    $119 = $loader + 188 | 0;
    HEAP32[$119 >> 2] = $118;
    $120 = $loader + 192 | 0;
    HEAP32[$120 >> 2] = 0;
    $121 = HEAP32[$119 >> 2] | 0;
    $122 = $loader + 180 | 0;
    $123 = HEAP32[$122 >> 2] | 0;
    $124 = $121 - $123 | 0;
    $125 = $loader + 196 | 0;
    HEAP32[$125 >> 2] = $124;
    _tt_get_metrics_incr_overrides($loader, $glyph_index);
    $126 = HEAP32[$1 >> 2] | 0;
    $127 = $126 + 708 | 0;
    $128 = $127;
    $129 = HEAP8[$128] | 0;
    $130 = $129 << 24 >> 24 == 0;
    if ($130) {
      label = 22;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $132 = $126;
    $133 = $126 + 100 | 0;
    $134 = HEAP32[$133 >> 2] | 0;
    $135 = _TT_Vary_Get_Glyph_Deltas($132, $glyph_index, $deltas, 4) | 0;
    $136 = ($135 | 0) == 0;
    if ($136) {
      label = 21;
      break;
    } else {
      $error_4 = $135;
      label = 53;
      break;
    }
   case 21:
    $138 = HEAP32[$deltas >> 2] | 0;
    $139 = $138 | 0;
    $140 = HEAP32[$139 >> 2] | 0;
    $141 = HEAP32[$106 >> 2] | 0;
    $142 = $141 + $140 | 0;
    HEAP32[$106 >> 2] = $142;
    $143 = HEAP32[$deltas >> 2] | 0;
    $144 = $143 + 4 | 0;
    $145 = HEAP32[$144 >> 2] | 0;
    $146 = HEAP32[$107 >> 2] | 0;
    $147 = $146 + $145 | 0;
    HEAP32[$107 >> 2] = $147;
    $148 = HEAP32[$deltas >> 2] | 0;
    $149 = $148 + 8 | 0;
    $150 = HEAP32[$149 >> 2] | 0;
    $151 = HEAP32[$112 >> 2] | 0;
    $152 = $151 + $150 | 0;
    HEAP32[$112 >> 2] = $152;
    $153 = HEAP32[$deltas >> 2] | 0;
    $154 = $153 + 12 | 0;
    $155 = HEAP32[$154 >> 2] | 0;
    $156 = HEAP32[$113 >> 2] | 0;
    $157 = $156 + $155 | 0;
    HEAP32[$113 >> 2] = $157;
    $158 = HEAP32[$deltas >> 2] | 0;
    $159 = $158 + 16 | 0;
    $160 = HEAP32[$159 >> 2] | 0;
    $161 = HEAP32[$114 >> 2] | 0;
    $162 = $161 + $160 | 0;
    HEAP32[$114 >> 2] = $162;
    $163 = HEAP32[$deltas >> 2] | 0;
    $164 = $163 + 20 | 0;
    $165 = HEAP32[$164 >> 2] | 0;
    $166 = HEAP32[$119 >> 2] | 0;
    $167 = $166 + $165 | 0;
    HEAP32[$119 >> 2] = $167;
    $168 = HEAP32[$deltas >> 2] | 0;
    $169 = $168 + 24 | 0;
    $170 = HEAP32[$169 >> 2] | 0;
    $171 = HEAP32[$120 >> 2] | 0;
    $172 = $171 + $170 | 0;
    HEAP32[$120 >> 2] = $172;
    $173 = HEAP32[$deltas >> 2] | 0;
    $174 = $173 + 28 | 0;
    $175 = HEAP32[$174 >> 2] | 0;
    $176 = HEAP32[$125 >> 2] | 0;
    $177 = $176 + $175 | 0;
    HEAP32[$125 >> 2] = $177;
    $178 = HEAP32[$deltas >> 2] | 0;
    $179 = $178;
    _ft_mem_free($134, $179);
    HEAP32[$deltas >> 2] = 0;
    label = 22;
    break;
   case 22:
    $181 = HEAP32[$20 >> 2] | 0;
    $182 = $181 & 1;
    $183 = ($182 | 0) == 0;
    if ($183) {
      label = 23;
      break;
    } else {
      $error_4 = 0;
      label = 53;
      break;
    }
   case 23:
    $185 = HEAP32[$106 >> 2] | 0;
    $186 = _FT_MulFix($185, $x_scale_0) | 0;
    HEAP32[$106 >> 2] = $186;
    $187 = HEAP32[$112 >> 2] | 0;
    $188 = _FT_MulFix($187, $x_scale_0) | 0;
    HEAP32[$112 >> 2] = $188;
    $189 = HEAP32[$119 >> 2] | 0;
    $190 = _FT_MulFix($189, $y_scale_0) | 0;
    HEAP32[$119 >> 2] = $190;
    $191 = HEAP32[$125 >> 2] | 0;
    $192 = _FT_MulFix($191, $y_scale_0) | 0;
    HEAP32[$125 >> 2] = $192;
    $error_4 = 0;
    label = 53;
    break;
   case 24:
    $194 = $loader + 36 | 0;
    $195 = HEAP32[$194 >> 2] | 0;
    $196 = $loader + 52 | 0;
    $197 = HEAP32[$196 >> 2] | 0;
    $198 = $195 - $197 | 0;
    $199 = $loader + 68 | 0;
    $200 = $199 | 0;
    HEAP32[$200 >> 2] = $198;
    $201 = $loader + 72 | 0;
    HEAP32[$201 >> 2] = 0;
    $202 = HEAP32[$200 >> 2] | 0;
    $203 = $loader + 56 | 0;
    $204 = HEAP32[$203 >> 2] | 0;
    $205 = $204 + $202 | 0;
    $206 = $loader + 76 | 0;
    $207 = $206 | 0;
    HEAP32[$207 >> 2] = $205;
    $208 = $loader + 80 | 0;
    HEAP32[$208 >> 2] = 0;
    $209 = $loader + 184 | 0;
    $210 = $209 | 0;
    HEAP32[$210 >> 2] = 0;
    $211 = $loader + 176 | 0;
    $212 = HEAP32[$211 >> 2] | 0;
    $213 = $loader + 48 | 0;
    $214 = HEAP32[$213 >> 2] | 0;
    $215 = $214 + $212 | 0;
    $216 = $loader + 188 | 0;
    HEAP32[$216 >> 2] = $215;
    $217 = $loader + 192 | 0;
    $218 = $217 | 0;
    HEAP32[$218 >> 2] = 0;
    $219 = HEAP32[$216 >> 2] | 0;
    $220 = $loader + 180 | 0;
    $221 = HEAP32[$220 >> 2] | 0;
    $222 = $219 - $221 | 0;
    $223 = $loader + 196 | 0;
    HEAP32[$223 >> 2] = $222;
    _tt_get_metrics_incr_overrides($loader, $glyph_index);
    $224 = HEAP16[$93 >> 1] | 0;
    $225 = $224 << 16 >> 16 > 0;
    if ($225) {
      label = 25;
      break;
    } else {
      label = 28;
      break;
    }
   case 25:
    $227 = $2 + 524 | 0;
    $228 = HEAP32[$227 >> 2] | 0;
    $229 = $228;
    $230 = FUNCTION_TABLE_ii[$229 & 1023]($loader) | 0;
    $231 = ($230 | 0) == 0;
    if ($231) {
      label = 26;
      break;
    } else {
      $error_4 = $230;
      label = 53;
      break;
    }
   case 26:
    $233 = $2 + 516 | 0;
    $234 = HEAP32[$233 >> 2] | 0;
    $235 = $234;
    FUNCTION_TABLE_vi[$235 & 1023]($loader);
    $236 = _TT_Process_Simple_Glyph($loader) | 0;
    $237 = ($236 | 0) == 0;
    if ($237) {
      label = 27;
      break;
    } else {
      $error_4223 = $236;
      label = 55;
      break;
    }
   case 27:
    _FT_GlyphLoader_Add($5);
    $error_4223 = 0;
    label = 55;
    break;
   case 28:
    $240 = $224 << 16 >> 16 == -1;
    if ($240) {
      label = 29;
      break;
    } else {
      $error_4 = 20;
      label = 53;
      break;
    }
   case 29:
    $242 = $5 + 22 | 0;
    $243 = HEAP16[$242 >> 1] | 0;
    $244 = $243 << 16 >> 16;
    $245 = $5 + 20 | 0;
    $246 = HEAP16[$245 >> 1] | 0;
    $247 = $246 << 16 >> 16;
    $248 = $2 + 528 | 0;
    $249 = $248;
    $250 = HEAP32[$249 >> 2] | 0;
    $251 = FUNCTION_TABLE_ii[$250 & 1023]($loader) | 0;
    $252 = ($251 | 0) == 0;
    if ($252) {
      label = 30;
      break;
    } else {
      $error_4 = $251;
      label = 53;
      break;
    }
   case 30:
    $254 = $loader + 168 | 0;
    $255 = HEAP32[$254 >> 2] | 0;
    $256 = $2 + 516 | 0;
    $257 = HEAP32[$256 >> 2] | 0;
    $258 = $257;
    FUNCTION_TABLE_vi[$258 & 1023]($loader);
    $259 = $2 + 708 | 0;
    $260 = $259;
    $261 = HEAP8[$260] | 0;
    $262 = $261 << 24 >> 24 == 0;
    if ($262) {
      $error_2 = 0;
      label = 38;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    $264 = $2 + 100 | 0;
    $265 = HEAP32[$264 >> 2] | 0;
    $266 = $5 + 84 | 0;
    $267 = HEAP32[$266 >> 2] | 0;
    $268 = $267 + 4 | 0;
    $269 = _TT_Vary_Get_Glyph_Deltas($3, $glyph_index, $deltas, $268) | 0;
    $270 = ($269 | 0) == 0;
    if ($270) {
      label = 32;
      break;
    } else {
      $error_4223 = $269;
      label = 55;
      break;
    }
   case 32:
    $272 = HEAP32[$266 >> 2] | 0;
    $273 = ($272 | 0) > 0;
    if ($273) {
      label = 33;
      break;
    } else {
      $i_0_lcssa = 0;
      label = 37;
      break;
    }
   case 33:
    $274 = $5 + 48 | 0;
    $275 = $5 + 88 | 0;
    $276 = HEAP32[$274 >> 2] | 0;
    $277 = HEAP32[$275 >> 2] | 0;
    $278 = $277 + ($276 << 5) | 0;
    $i_0234 = 0;
    $subglyph_0235 = $278;
    label = 34;
    break;
   case 34:
    $280 = $subglyph_0235 + 4 | 0;
    $281 = HEAP16[$280 >> 1] | 0;
    $282 = $281 & 2;
    $283 = $282 << 16 >> 16 == 0;
    if ($283) {
      label = 36;
      break;
    } else {
      label = 35;
      break;
    }
   case 35:
    $285 = HEAP32[$deltas >> 2] | 0;
    $286 = $285 + ($i_0234 << 3) | 0;
    $287 = HEAP32[$286 >> 2] | 0;
    $sext = $287 << 16;
    $288 = $sext >> 16;
    $289 = $subglyph_0235 + 8 | 0;
    $290 = HEAP32[$289 >> 2] | 0;
    $291 = $288 + $290 | 0;
    HEAP32[$289 >> 2] = $291;
    $292 = HEAP32[$deltas >> 2] | 0;
    $293 = $292 + ($i_0234 << 3) + 4 | 0;
    $294 = HEAP32[$293 >> 2] | 0;
    $sext220 = $294 << 16;
    $295 = $sext220 >> 16;
    $296 = $subglyph_0235 + 12 | 0;
    $297 = HEAP32[$296 >> 2] | 0;
    $298 = $295 + $297 | 0;
    HEAP32[$296 >> 2] = $298;
    label = 36;
    break;
   case 36:
    $300 = $i_0234 + 1 | 0;
    $301 = $subglyph_0235 + 32 | 0;
    $exitcond = ($300 | 0) == ($272 | 0);
    if ($exitcond) {
      $i_0_lcssa = $272;
      label = 37;
      break;
    } else {
      $i_0234 = $300;
      $subglyph_0235 = $301;
      label = 34;
      break;
    }
   case 37:
    $302 = HEAP32[$deltas >> 2] | 0;
    $303 = $302 + ($i_0_lcssa << 3) | 0;
    $304 = HEAP32[$303 >> 2] | 0;
    $305 = HEAP32[$200 >> 2] | 0;
    $306 = $305 + $304 | 0;
    HEAP32[$200 >> 2] = $306;
    $307 = HEAP32[$deltas >> 2] | 0;
    $308 = $307 + ($i_0_lcssa << 3) + 4 | 0;
    $309 = HEAP32[$308 >> 2] | 0;
    $310 = HEAP32[$201 >> 2] | 0;
    $311 = $310 + $309 | 0;
    HEAP32[$201 >> 2] = $311;
    $312 = $i_0_lcssa + 1 | 0;
    $313 = HEAP32[$deltas >> 2] | 0;
    $314 = $313 + ($312 << 3) | 0;
    $315 = HEAP32[$314 >> 2] | 0;
    $316 = HEAP32[$207 >> 2] | 0;
    $317 = $316 + $315 | 0;
    HEAP32[$207 >> 2] = $317;
    $318 = HEAP32[$deltas >> 2] | 0;
    $319 = $318 + ($312 << 3) + 4 | 0;
    $320 = HEAP32[$319 >> 2] | 0;
    $321 = HEAP32[$208 >> 2] | 0;
    $322 = $321 + $320 | 0;
    HEAP32[$208 >> 2] = $322;
    $323 = $i_0_lcssa + 2 | 0;
    $324 = HEAP32[$deltas >> 2] | 0;
    $325 = $324 + ($323 << 3) | 0;
    $326 = HEAP32[$325 >> 2] | 0;
    $327 = HEAP32[$210 >> 2] | 0;
    $328 = $327 + $326 | 0;
    HEAP32[$210 >> 2] = $328;
    $329 = HEAP32[$deltas >> 2] | 0;
    $330 = $329 + ($323 << 3) + 4 | 0;
    $331 = HEAP32[$330 >> 2] | 0;
    $332 = HEAP32[$216 >> 2] | 0;
    $333 = $332 + $331 | 0;
    HEAP32[$216 >> 2] = $333;
    $334 = $i_0_lcssa + 3 | 0;
    $335 = HEAP32[$deltas >> 2] | 0;
    $336 = $335 + ($334 << 3) | 0;
    $337 = HEAP32[$336 >> 2] | 0;
    $338 = HEAP32[$218 >> 2] | 0;
    $339 = $338 + $337 | 0;
    HEAP32[$218 >> 2] = $339;
    $340 = HEAP32[$deltas >> 2] | 0;
    $341 = $340 + ($334 << 3) + 4 | 0;
    $342 = HEAP32[$341 >> 2] | 0;
    $343 = HEAP32[$223 >> 2] | 0;
    $344 = $343 + $342 | 0;
    HEAP32[$223 >> 2] = $344;
    $345 = HEAP32[$deltas >> 2] | 0;
    $346 = $345;
    _ft_mem_free($265, $346);
    HEAP32[$deltas >> 2] = 0;
    $error_2 = $269;
    label = 38;
    break;
   case 38:
    $348 = HEAP32[$20 >> 2] | 0;
    $349 = $348 & 1;
    $350 = ($349 | 0) == 0;
    if ($350) {
      label = 39;
      break;
    } else {
      label = 40;
      break;
    }
   case 39:
    $352 = HEAP32[$200 >> 2] | 0;
    $353 = _FT_MulFix($352, $x_scale_0) | 0;
    HEAP32[$200 >> 2] = $353;
    $354 = HEAP32[$207 >> 2] | 0;
    $355 = _FT_MulFix($354, $x_scale_0) | 0;
    HEAP32[$207 >> 2] = $355;
    $356 = HEAP32[$216 >> 2] | 0;
    $357 = _FT_MulFix($356, $y_scale_0) | 0;
    HEAP32[$216 >> 2] = $357;
    $358 = HEAP32[$223 >> 2] | 0;
    $359 = _FT_MulFix($358, $y_scale_0) | 0;
    HEAP32[$223 >> 2] = $359;
    label = 40;
    break;
   case 40:
    $361 = HEAP32[$20 >> 2] | 0;
    $362 = $361 & 1024;
    $363 = ($362 | 0) == 0;
    if ($363) {
      label = 42;
      break;
    } else {
      label = 41;
      break;
    }
   case 41:
    _FT_GlyphLoader_Add($5);
    $365 = $loader + 8 | 0;
    $366 = HEAP32[$365 >> 2] | 0;
    $367 = $366 + 72 | 0;
    HEAP32[$367 >> 2] = 1668246896;
    $error_4223 = $error_2;
    label = 55;
    break;
   case 42:
    $369 = $5 + 84 | 0;
    $370 = HEAP32[$369 >> 2] | 0;
    $371 = $5 + 48 | 0;
    $372 = HEAP32[$371 >> 2] | 0;
    $373 = $loader + 24 | 0;
    $374 = HEAP32[$373 >> 2] | 0;
    $375 = HEAP32[$61 >> 2] | 0;
    _FT_GlyphLoader_Add($5);
    $376 = ($370 | 0) == 0;
    if ($376) {
      $subglyph2_0_lcssa = 0;
      $num_points_0_lcssa = $244;
      $error_3_lcssa = $error_2;
      label = 50;
      break;
    } else {
      label = 43;
      break;
    }
   case 43:
    $377 = $5 + 52 | 0;
    $378 = $199;
    $379 = $206;
    $380 = $209;
    $381 = $217;
    $382 = $recurse_count + 1 | 0;
    $n_0231 = 0;
    label = 44;
    break;
   case 44:
    $384 = HEAP32[$377 >> 2] | 0;
    $_sum = $n_0231 + $372 | 0;
    $ld$0$0 = $378 | 0;
    $385$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $378 + 4 | 0;
    $385$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $ld$2$0 = $379 | 0;
    $386$0 = HEAP32[$ld$2$0 >> 2] | 0;
    $ld$3$1 = $379 + 4 | 0;
    $386$1 = HEAP32[$ld$3$1 >> 2] | 0;
    $ld$4$0 = $380 | 0;
    $387$0 = HEAP32[$ld$4$0 >> 2] | 0;
    $ld$5$1 = $380 + 4 | 0;
    $387$1 = HEAP32[$ld$5$1 >> 2] | 0;
    $ld$6$0 = $381 | 0;
    $388$0 = HEAP32[$ld$6$0 >> 2] | 0;
    $ld$7$1 = $381 + 4 | 0;
    $388$1 = HEAP32[$ld$7$1 >> 2] | 0;
    $389 = HEAP16[$242 >> 1] | 0;
    $390 = $389 << 16 >> 16;
    $391 = $384 + ($_sum << 5) | 0;
    $392 = HEAP32[$391 >> 2] | 0;
    $393 = _load_truetype_glyph($loader, $392, $382, 0) | 0;
    $394 = ($393 | 0) == 0;
    if ($394) {
      label = 45;
      break;
    } else {
      $error_4223 = $393;
      label = 55;
      break;
    }
   case 45:
    $396 = HEAP32[$377 >> 2] | 0;
    $397 = $396 + ($_sum << 5) | 0;
    $398 = $396 + ($_sum << 5) + 4 | 0;
    $399 = HEAP16[$398 >> 1] | 0;
    $400 = $399 & 512;
    $401 = $400 << 16 >> 16 == 0;
    if ($401) {
      label = 46;
      break;
    } else {
      label = 47;
      break;
    }
   case 46:
    $st$8$0 = $378 | 0;
    HEAP32[$st$8$0 >> 2] = $385$0;
    $st$9$1 = $378 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $385$1;
    $st$10$0 = $379 | 0;
    HEAP32[$st$10$0 >> 2] = $386$0;
    $st$11$1 = $379 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $386$1;
    $st$12$0 = $380 | 0;
    HEAP32[$st$12$0 >> 2] = $387$0;
    $st$13$1 = $380 + 4 | 0;
    HEAP32[$st$13$1 >> 2] = $387$1;
    $st$14$0 = $381 | 0;
    HEAP32[$st$14$0 >> 2] = $388$0;
    $st$15$1 = $381 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $388$1;
    label = 47;
    break;
   case 47:
    $404 = HEAP16[$242 >> 1] | 0;
    $405 = $404 << 16 >> 16;
    $406 = $404 << 16 >> 16 == $389 << 16 >> 16;
    if ($406) {
      label = 49;
      break;
    } else {
      label = 48;
      break;
    }
   case 48:
    _TT_Process_Composite_Component($loader, $397, $244, $390);
    label = 49;
    break;
   case 49:
    $409 = $n_0231 + 1 | 0;
    $410 = $409 >>> 0 < $370 >>> 0;
    if ($410) {
      $n_0231 = $409;
      label = 44;
      break;
    } else {
      $subglyph2_0_lcssa = $397;
      $num_points_0_lcssa = $405;
      $error_3_lcssa = $393;
      label = 50;
      break;
    }
   case 50:
    HEAP32[$373 >> 2] = $374;
    HEAP32[$61 >> 2] = $375;
    HEAP32[$254 >> 2] = $255;
    $411 = HEAP32[$20 >> 2] | 0;
    $412 = $411 & 2;
    $413 = ($412 | 0) == 0;
    if ($413) {
      label = 51;
      break;
    } else {
      $error_4223 = $error_3_lcssa;
      label = 55;
      break;
    }
   case 51:
    $415 = $subglyph2_0_lcssa + 4 | 0;
    $416 = HEAP16[$415 >> 1] | 0;
    $417 = $416 & 256;
    $418 = $417 << 16 >> 16 != 0;
    $419 = $num_points_0_lcssa >>> 0 > $244 >>> 0;
    $or_cond221 = $418 & $419;
    if ($or_cond221) {
      label = 52;
      break;
    } else {
      $error_4223 = $error_3_lcssa;
      label = 55;
      break;
    }
   case 52:
    _TT_Process_Composite_Glyph($loader, $244, $247);
    $error_4223 = $error_3_lcssa;
    label = 55;
    break;
   case 53:
    $422 = $opened_frame_0 << 24 >> 24 == 0;
    if ($422) {
      $error_4223 = $error_4;
      label = 55;
      break;
    } else {
      $error_4226 = $error_4;
      label = 54;
      break;
    }
   case 54:
    $423 = $2 + 516 | 0;
    $424 = HEAP32[$423 >> 2] | 0;
    $425 = $424;
    FUNCTION_TABLE_vi[$425 & 1023]($loader);
    $error_4223 = $error_4226;
    label = 55;
    break;
   case 55:
    $426 = $glyph_data_loaded_0 << 24 >> 24 == 0;
    if ($426) {
      $error_4223227 = $error_4223;
      label = 57;
      break;
    } else {
      label = 56;
      break;
    }
   case 56:
    $428 = $2 + 128 | 0;
    $429 = HEAP32[$428 >> 2] | 0;
    $430 = $429 + 52 | 0;
    $431 = HEAP32[$430 >> 2] | 0;
    $432 = $431 | 0;
    $433 = HEAP32[$432 >> 2] | 0;
    $434 = $433 + 4 | 0;
    $435 = HEAP32[$434 >> 2] | 0;
    $436 = $431 + 4 | 0;
    $437 = HEAP32[$436 >> 2] | 0;
    FUNCTION_TABLE_vii[$435 & 1023]($437, $glyph_data);
    $error_4223227 = $error_4223;
    label = 57;
    break;
   case 57:
    STACKTOP = __stackBase__;
    return $error_4223227 | 0;
  }
  return 0;
}
function _compute_glyph_metrics($loader, $glyph_index) {
  $loader = $loader | 0;
  $glyph_index = $glyph_index | 0;
  var $bbox = 0, $metrics = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $y_scale_0 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $advance_0 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $sext1 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $106 = 0, $107 = 0, $108 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $sext = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $advance1_0 = 0, $141 = 0, $142 = 0, $top_0 = 0, $advance1_1 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $167 = 0, $168 = 0, $top_1 = 0, $advance1_2 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $175 = 0, $176 = 0, $top_2 = 0, $advance1_3 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 32 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $bbox = __stackBase__ | 0;
    $metrics = __stackBase__ + 16 | 0;
    $1 = $loader | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    $4 = $loader + 8 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $loader + 4 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $loader + 16 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 & 1;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 2;
      break;
    } else {
      $y_scale_0 = 65536;
      label = 3;
      break;
    }
   case 2:
    $13 = $7 + 20 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $y_scale_0 = $14;
    label = 3;
    break;
   case 3:
    $16 = $5 + 72 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($17 | 0) == 1668246896;
    if ($18) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $20 = $5 + 108 | 0;
    _FT_Outline_Get_CBox($20, $bbox);
    label = 6;
    break;
   case 5:
    $22 = $loader + 36 | 0;
    $23 = $bbox;
    $24 = $22;
    _memcpy($23 | 0, $24 | 0, 16);
    label = 6;
    break;
   case 6:
    $26 = $loader + 60 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $2 + 468 | 0;
    $29 = $28 + 12 | 0;
    $30 = $29;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = ($31 | 0) == 0;
    if ($32) {
      $advance_0 = $27;
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $34 = HEAP32[$8 >> 2] | 0;
    $35 = $34 & 512;
    $36 = ($35 | 0) == 0;
    if ($36) {
      label = 8;
      break;
    } else {
      $advance_0 = $27;
      label = 9;
      break;
    }
   case 8:
    $38 = $2 + 216 | 0;
    $39 = $38;
    $40 = $39 + 10 | 0;
    $41 = HEAP16[$40 >> 1] | 0;
    $42 = $41 & 65535;
    $advance_0 = $42;
    label = 9;
    break;
   case 9:
    $44 = $5 + 56 | 0;
    HEAP32[$44 >> 2] = $advance_0;
    $45 = $bbox | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $5 + 32 | 0;
    HEAP32[$47 >> 2] = $46;
    $48 = $bbox + 12 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = $5 + 36 | 0;
    HEAP32[$50 >> 2] = $49;
    $51 = $loader + 76 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = $loader + 68 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = $52 - $54 | 0;
    $56 = $5 + 40 | 0;
    HEAP32[$56 >> 2] = $55;
    $57 = HEAP32[$30 >> 2] | 0;
    $58 = ($57 | 0) == 0;
    if ($58) {
      label = 10;
      break;
    } else {
      label = 13;
      break;
    }
   case 10:
    $60 = HEAP32[$8 >> 2] | 0;
    $61 = $60 & 2;
    $62 = ($61 | 0) == 0;
    if ($62) {
      label = 11;
      break;
    } else {
      label = 13;
      break;
    }
   case 11:
    $64 = $7 + 12 | 0;
    $65 = HEAP16[$64 >> 1] | 0;
    $66 = $65 & 65535;
    $67 = _tt_face_get_device_metrics($3, $66, $glyph_index) | 0;
    $68 = ($67 | 0) == 0;
    if ($68) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $70 = HEAP8[$67] | 0;
    $71 = $70 & 255;
    $72 = $71 << 6;
    HEAP32[$56 >> 2] = $72;
    label = 13;
    break;
   case 13:
    $74 = $bbox + 8 | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    $76 = HEAP32[$45 >> 2] | 0;
    $77 = $75 - $76 | 0;
    $78 = $5 + 24 | 0;
    HEAP32[$78 >> 2] = $77;
    $79 = HEAP32[$48 >> 2] | 0;
    $80 = $bbox + 4 | 0;
    $81 = HEAP32[$80 >> 2] | 0;
    $82 = $79 - $81 | 0;
    $83 = $5 + 28 | 0;
    HEAP32[$83 >> 2] = $82;
    $84 = $2 + 296 | 0;
    $85 = $84;
    $86 = HEAP8[$85] | 0;
    $87 = $86 << 24 >> 24 == 0;
    if ($87) {
      label = 17;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $89 = $2 + 300 | 0;
    $90 = $89;
    $91 = $90 + 34 | 0;
    $92 = HEAP16[$91 >> 1] | 0;
    $93 = $92 << 16 >> 16 == 0;
    if ($93) {
      label = 17;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $95 = $loader + 188 | 0;
    $96 = HEAP32[$95 >> 2] | 0;
    $97 = HEAP32[$48 >> 2] | 0;
    $98 = $96 - $97 | 0;
    $99 = _FT_DivFix($98, $y_scale_0) | 0;
    $sext1 = $99 << 16;
    $100 = $sext1 >> 16;
    $101 = HEAP32[$95 >> 2] | 0;
    $102 = $loader + 196 | 0;
    $103 = HEAP32[$102 >> 2] | 0;
    $104 = ($101 | 0) > ($103 | 0);
    if ($104) {
      label = 16;
      break;
    } else {
      $advance1_1 = 0;
      $top_0 = $100;
      label = 21;
      break;
    }
   case 16:
    $106 = $101 - $103 | 0;
    $107 = _FT_DivFix($106, $y_scale_0) | 0;
    $108 = $107 & 65535;
    $advance1_1 = $108;
    $top_0 = $100;
    label = 21;
    break;
   case 17:
    $110 = HEAP32[$48 >> 2] | 0;
    $111 = HEAP32[$80 >> 2] | 0;
    $112 = $110 - $111 | 0;
    $113 = _FT_DivFix($112, $y_scale_0) | 0;
    $sext = $113 << 16;
    $114 = $sext >> 16;
    $115 = $2 + 368 | 0;
    $116 = $115;
    $117 = HEAP16[$116 >> 1] | 0;
    $118 = $117 << 16 >> 16 == -1;
    if ($118) {
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $120 = $115;
    $121 = $120 + 70 | 0;
    $122 = HEAP16[$121 >> 1] | 0;
    $123 = $122 << 16 >> 16;
    $124 = $115 + 72 | 0;
    $125 = $124;
    $126 = HEAP16[$125 >> 1] | 0;
    $127 = $126 << 16 >> 16;
    $128 = $123 - $127 | 0;
    $advance1_0 = $128;
    label = 20;
    break;
   case 19:
    $130 = $2 + 216 | 0;
    $131 = $130;
    $132 = $130 + 4 | 0;
    $133 = $132;
    $134 = HEAP16[$133 >> 1] | 0;
    $135 = $134 << 16 >> 16;
    $136 = $131 + 6 | 0;
    $137 = HEAP16[$136 >> 1] | 0;
    $138 = $137 << 16 >> 16;
    $139 = $135 - $138 | 0;
    $advance1_0 = $139;
    label = 20;
    break;
   case 20:
    $141 = $advance1_0 - $114 | 0;
    $142 = ($141 | 0) / 2 & -1;
    $advance1_1 = $advance1_0;
    $top_0 = $142;
    label = 21;
    break;
   case 21:
    $144 = $2 + 128 | 0;
    $145 = HEAP32[$144 >> 2] | 0;
    $146 = $145 + 52 | 0;
    $147 = HEAP32[$146 >> 2] | 0;
    $148 = ($147 | 0) == 0;
    if ($148) {
      $advance1_2 = $advance1_1;
      $top_1 = $top_0;
      label = 25;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $150 = $147 | 0;
    $151 = HEAP32[$150 >> 2] | 0;
    $152 = $151 + 8 | 0;
    $153 = HEAP32[$152 >> 2] | 0;
    $154 = ($153 | 0) == 0;
    if ($154) {
      $advance1_2 = $advance1_1;
      $top_1 = $top_0;
      label = 25;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $156 = $metrics | 0;
    HEAP32[$156 >> 2] = 0;
    $157 = $metrics + 4 | 0;
    HEAP32[$157 >> 2] = $top_0;
    $158 = $metrics + 8 | 0;
    HEAP32[$158 >> 2] = $advance1_1;
    $159 = HEAP32[$150 >> 2] | 0;
    $160 = $159 + 8 | 0;
    $161 = HEAP32[$160 >> 2] | 0;
    $162 = $147 + 4 | 0;
    $163 = HEAP32[$162 >> 2] | 0;
    $164 = FUNCTION_TABLE_iiiii[$161 & 1023]($163, $glyph_index, 1, $metrics) | 0;
    $165 = ($164 | 0) == 0;
    if ($165) {
      label = 24;
      break;
    } else {
      label = 28;
      break;
    }
   case 24:
    $167 = HEAP32[$157 >> 2] | 0;
    $168 = HEAP32[$158 >> 2] | 0;
    $advance1_2 = $168;
    $top_1 = $167;
    label = 25;
    break;
   case 25:
    $170 = $5 + 60 | 0;
    HEAP32[$170 >> 2] = $advance1_2;
    $171 = HEAP32[$8 >> 2] | 0;
    $172 = $171 & 1;
    $173 = ($172 | 0) == 0;
    if ($173) {
      label = 26;
      break;
    } else {
      $advance1_3 = $advance1_2;
      $top_2 = $top_1;
      label = 27;
      break;
    }
   case 26:
    $175 = _FT_MulFix($top_1, $y_scale_0) | 0;
    $176 = _FT_MulFix($advance1_2, $y_scale_0) | 0;
    $advance1_3 = $176;
    $top_2 = $175;
    label = 27;
    break;
   case 27:
    $178 = HEAP32[$47 >> 2] | 0;
    $179 = HEAP32[$56 >> 2] | 0;
    $180 = ($179 | 0) / 2 & -1;
    $181 = $178 - $180 | 0;
    $182 = $5 + 44 | 0;
    HEAP32[$182 >> 2] = $181;
    $183 = $5 + 48 | 0;
    HEAP32[$183 >> 2] = $top_2;
    $184 = $5 + 52 | 0;
    HEAP32[$184 >> 2] = $advance1_3;
    label = 28;
    break;
   case 28:
    STACKTOP = __stackBase__;
    return;
  }
}
function _tt_face_get_location($face, $gindex, $asize) {
  $face = $face | 0;
  $gindex = $gindex | 0;
  $asize = $asize | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $_sum5455 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $_sum5657 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $_sum5859 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $_sum60 = 0, $31 = 0, $_sum61 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $_sum62 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $_sum63 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $_sum64 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $_sum4748 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $_sum49 = 0, $62 = 0, $_sum50 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $_sum51 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $pos2_0 = 0, $73 = 0, $74 = 0, $pos1_0 = 0, $pos2_1 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $pos2_1_ = 0, $81 = 0, $_pos2_1_ = 0, $storemerge = 0, $storemerge45 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 732 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 >>> 0 > $gindex >>> 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $pos2_1 = 0;
      $pos1_0 = 0;
      label = 8;
      break;
    }
   case 2:
    $5 = $face + 210 | 0;
    $6 = HEAP16[$5 >> 1] | 0;
    $7 = $6 << 16 >> 16 == 0;
    $8 = $face + 736 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    if ($7) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = $gindex << 2;
    $12 = $2 << 2;
    $13 = $9 + $11 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 & 255;
    $16 = $15 << 24;
    $_sum5455 = $11 | 1;
    $17 = $9 + $_sum5455 | 0;
    $18 = HEAP8[$17] | 0;
    $19 = $18 & 255;
    $20 = $19 << 16;
    $21 = $20 | $16;
    $_sum5657 = $11 | 2;
    $22 = $9 + $_sum5657 | 0;
    $23 = HEAP8[$22] | 0;
    $24 = $23 & 255;
    $25 = $24 << 8;
    $26 = $21 | $25;
    $_sum5859 = $11 | 3;
    $27 = $9 + $_sum5859 | 0;
    $28 = HEAP8[$27] | 0;
    $29 = $28 & 255;
    $30 = $26 | $29;
    $_sum60 = $11 + 8 | 0;
    $31 = ($_sum60 | 0) > ($12 | 0);
    if ($31) {
      $pos2_1 = $30;
      $pos1_0 = $30;
      label = 8;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $_sum61 = $11 + 4 | 0;
    $33 = $9 + $_sum61 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $35 << 24;
    $_sum62 = $11 + 5 | 0;
    $37 = $9 + $_sum62 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 & 255;
    $40 = $39 << 16;
    $41 = $40 | $36;
    $_sum63 = $11 + 6 | 0;
    $42 = $9 + $_sum63 | 0;
    $43 = HEAP8[$42] | 0;
    $44 = $43 & 255;
    $45 = $44 << 8;
    $46 = $41 | $45;
    $_sum64 = $11 + 7 | 0;
    $47 = $9 + $_sum64 | 0;
    $48 = HEAP8[$47] | 0;
    $49 = $48 & 255;
    $50 = $46 | $49;
    $pos2_1 = $50;
    $pos1_0 = $30;
    label = 8;
    break;
   case 5:
    $52 = $gindex << 1;
    $53 = $2 << 1;
    $54 = $9 + $52 | 0;
    $55 = HEAP8[$54] | 0;
    $56 = $55 & 255;
    $57 = $56 << 8;
    $_sum4748 = $52 | 1;
    $58 = $9 + $_sum4748 | 0;
    $59 = HEAP8[$58] | 0;
    $60 = $59 & 255;
    $61 = $57 | $60;
    $_sum49 = $52 + 4 | 0;
    $62 = ($_sum49 | 0) > ($53 | 0);
    if ($62) {
      $pos2_0 = $61;
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $_sum50 = $52 + 2 | 0;
    $64 = $9 + $_sum50 | 0;
    $65 = HEAP8[$64] | 0;
    $66 = $65 & 255;
    $67 = $66 << 8;
    $_sum51 = $52 + 3 | 0;
    $68 = $9 + $_sum51 | 0;
    $69 = HEAP8[$68] | 0;
    $70 = $69 & 255;
    $71 = $67 | $70;
    $pos2_0 = $71;
    label = 7;
    break;
   case 7:
    $73 = $61 << 1;
    $74 = $pos2_0 << 1;
    $pos2_1 = $74;
    $pos1_0 = $73;
    label = 8;
    break;
   case 8:
    $76 = $face + 704 | 0;
    $77 = HEAP32[$76 >> 2] | 0;
    $78 = $pos1_0 >>> 0 < $77 >>> 0;
    if ($78) {
      label = 9;
      break;
    } else {
      $_0 = 0;
      $storemerge45 = 0;
      label = 10;
      break;
    }
   case 9:
    $80 = $pos2_1 >>> 0 < $77 >>> 0;
    $pos2_1_ = $80 ? $pos2_1 : $77;
    $81 = $pos2_1_ >>> 0 < $pos1_0 >>> 0;
    $_pos2_1_ = $81 ? $77 : $pos2_1_;
    $storemerge = $_pos2_1_ - $pos1_0 | 0;
    $_0 = $pos1_0;
    $storemerge45 = $storemerge;
    label = 10;
    break;
   case 10:
    HEAP32[$asize >> 2] = $storemerge45;
    return $_0 | 0;
  }
  return 0;
}
function _tt_get_metrics($loader, $glyph_index) {
  $loader = $loader | 0;
  $glyph_index = $glyph_index | 0;
  var $left_bearing = 0, $top_bearing = 0, $advance_width = 0, $advance_height = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_lobit = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $left_bearing = __stackBase__ | 0;
    $top_bearing = __stackBase__ + 4 | 0;
    $advance_width = __stackBase__ + 8 | 0;
    $advance_height = __stackBase__ + 12 | 0;
    $1 = $loader | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    HEAP16[$left_bearing >> 1] = 0;
    HEAP16[$top_bearing >> 1] = 0;
    HEAP16[$advance_width >> 1] = 0;
    HEAP16[$advance_height >> 1] = 0;
    $4 = $loader + 16 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 >>> 9;
    $_lobit = $6 & 1;
    $7 = $_lobit ^ 1;
    $8 = $7 & 255;
    _TT_Get_HMetrics($3, $glyph_index, $8, $left_bearing, $advance_width);
    _TT_Get_VMetrics($3, $glyph_index, $top_bearing, $advance_height);
    $9 = HEAP16[$left_bearing >> 1] | 0;
    $10 = $9 << 16 >> 16;
    $11 = $loader + 52 | 0;
    HEAP32[$11 >> 2] = $10;
    $12 = HEAP16[$advance_width >> 1] | 0;
    $13 = $12 & 65535;
    $14 = $loader + 56 | 0;
    HEAP32[$14 >> 2] = $13;
    $15 = HEAP16[$top_bearing >> 1] | 0;
    $16 = $15 << 16 >> 16;
    $17 = $loader + 176 | 0;
    HEAP32[$17 >> 2] = $16;
    $18 = HEAP16[$advance_height >> 1] | 0;
    $19 = $18 & 65535;
    $20 = $loader + 180 | 0;
    HEAP32[$20 >> 2] = $19;
    $21 = $loader + 64 | 0;
    $22 = HEAP8[$21] | 0;
    $23 = $22 << 24 >> 24 == 0;
    if ($23) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    HEAP8[$21] = 1;
    $25 = HEAP16[$advance_width >> 1] | 0;
    $26 = $25 & 65535;
    $27 = $loader + 60 | 0;
    HEAP32[$27 >> 2] = $26;
    label = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
  }
}
function _tt_get_metrics_incr_overrides($loader, $glyph_index) {
  $loader = $loader | 0;
  $glyph_index = $glyph_index | 0;
  var $metrics = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $sext = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $metrics = __stackBase__ | 0;
    $1 = $loader | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 128 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 52 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = $6 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10 + 8 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $15 = $loader + 52 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $metrics | 0;
    HEAP32[$17 >> 2] = $16;
    $18 = $metrics + 4 | 0;
    HEAP32[$18 >> 2] = 0;
    $19 = $loader + 56 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $metrics + 8 | 0;
    HEAP32[$21 >> 2] = $20;
    $22 = $metrics + 12 | 0;
    HEAP32[$22 >> 2] = 0;
    $23 = HEAP32[$3 >> 2] | 0;
    $24 = $23 + 52 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $25 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $27 + 8 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $25 + 4 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = FUNCTION_TABLE_iiiii[$29 & 1023]($31, $glyph_index, 0, $metrics) | 0;
    $33 = ($32 | 0) == 0;
    if ($33) {
      label = 4;
      break;
    } else {
      label = 6;
      break;
    }
   case 4:
    $35 = HEAP32[$17 >> 2] | 0;
    $36 = HEAP32[$21 >> 2] | 0;
    $sext = $35 << 16;
    $37 = $sext >> 16;
    HEAP32[$15 >> 2] = $37;
    $38 = $36 & 65535;
    HEAP32[$19 >> 2] = $38;
    $39 = $loader + 176 | 0;
    HEAP32[$39 >> 2] = 0;
    $40 = $loader + 180 | 0;
    HEAP32[$40 >> 2] = 0;
    $41 = $loader + 64 | 0;
    $42 = HEAP8[$41] | 0;
    $43 = $42 << 24 >> 24 == 0;
    if ($43) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    HEAP8[$41] = 1;
    $45 = $loader + 60 | 0;
    HEAP32[$45 >> 2] = $38;
    label = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
  }
}
function _TT_Vary_Get_Glyph_Deltas($face, $glyph_index, $deltas, $n_points) {
  $face = $face | 0;
  $glyph_index = $glyph_index | 0;
  $deltas = $deltas | 0;
  $n_points = $n_points | 0;
  var $error = 0, $point_count = 0, $spoint_count = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $or_cond = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $sharedpoints_0 = 0, $offsetToData_0 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $offsetToData_1153 = 0, $localpoints_0152 = 0, $i_0151 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $j_0134 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $112 = 0, $113 = 0, $114 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $j_1137 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $j_2140 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $153 = 0, $154 = 0, $156 = 0, $localpoints_1 = 0, $points_0 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $or_cond132 = 0, $168 = 0, $or_cond133 = 0, $170 = 0, $171 = 0, $172 = 0, $j_3148 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $exitcond = 0, $j_4144 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $210 = 0, $212 = 0, $localpoints_2 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $localpoints_3 = 0, $offsetToData_2 = 0, $219 = 0, $220 = 0, $_pr = 0, $222 = 0, $224 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $point_count = __stackBase__ + 4 | 0;
    $spoint_count = __stackBase__ + 8 | 0;
    $1 = $face + 104 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 28 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $face + 712 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    HEAP32[$spoint_count >> 2] = 0;
    $7 = $face + 708 | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 << 24 >> 24 == 0;
    $10 = ($6 | 0) == 0;
    $or_cond = $9 | $10;
    if ($or_cond) {
      $_0 = 6;
      label = 43;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $12 = _ft_mem_realloc($4, 8, 0, $n_points, 0, $error) | 0;
    $13 = $12;
    $14 = HEAP32[$error >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 3;
      break;
    } else {
      label = 42;
      break;
    }
   case 3:
    HEAP32[$deltas >> 2] = $13;
    $17 = $6 + 32 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $18 >>> 0 > $glyph_index >>> 0;
    if ($19) {
      label = 4;
      break;
    } else {
      $_0 = 0;
      label = 43;
      break;
    }
   case 4:
    $21 = $6 + 36 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22 + ($glyph_index << 2) | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $glyph_index + 1 | 0;
    $26 = $22 + ($25 << 2) | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = ($24 | 0) == ($27 | 0);
    if ($28) {
      $_0 = 0;
      label = 43;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $30 = _FT_Stream_Seek($2, $24) | 0;
    HEAP32[$error >> 2] = $30;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 6;
      break;
    } else {
      label = 41;
      break;
    }
   case 6:
    $33 = HEAP32[$21 >> 2] | 0;
    $34 = $33 + ($25 << 2) | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $33 + ($glyph_index << 2) | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $35 - $37 | 0;
    $39 = _FT_Stream_EnterFrame($2, $38) | 0;
    HEAP32[$error >> 2] = $39;
    $40 = ($39 | 0) == 0;
    if ($40) {
      label = 7;
      break;
    } else {
      label = 41;
      break;
    }
   case 7:
    $42 = $2 + 32 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $2 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = $43;
    $47 = $45;
    $48 = $46 - $47 | 0;
    $49 = $6 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = _ft_mem_realloc($4, 4, 0, $50, 0, $error) | 0;
    $52 = $51;
    $53 = HEAP32[$error >> 2] | 0;
    $54 = ($53 | 0) == 0;
    if ($54) {
      label = 8;
      break;
    } else {
      label = 40;
      break;
    }
   case 8:
    $56 = HEAP32[$49 >> 2] | 0;
    $57 = _ft_mem_realloc($4, 4, 0, $56, 0, $error) | 0;
    $58 = $57;
    $59 = HEAP32[$error >> 2] | 0;
    $60 = ($59 | 0) == 0;
    if ($60) {
      label = 9;
      break;
    } else {
      label = 40;
      break;
    }
   case 9:
    $62 = HEAP32[$49 >> 2] | 0;
    $63 = _ft_mem_realloc($4, 4, 0, $62, 0, $error) | 0;
    $64 = $63;
    $65 = HEAP32[$error >> 2] | 0;
    $66 = ($65 | 0) == 0;
    if ($66) {
      label = 10;
      break;
    } else {
      label = 40;
      break;
    }
   case 10:
    $68 = _FT_Stream_GetShort($2) | 0;
    $69 = $68 & 65535;
    $70 = _FT_Stream_GetShort($2) | 0;
    $71 = $70 & 65535;
    $72 = $71 + $48 | 0;
    $73 = $69 & 32768;
    $74 = ($73 | 0) == 0;
    if ($74) {
      $offsetToData_0 = $72;
      $sharedpoints_0 = 0;
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $76 = HEAP32[$42 >> 2] | 0;
    $77 = HEAP32[$44 >> 2] | 0;
    $78 = $76;
    $79 = $77;
    $80 = $78 - $79 | 0;
    $81 = $77 + $72 | 0;
    HEAP32[$42 >> 2] = $81;
    $82 = _ft_var_readpackedpoints($2, $spoint_count) | 0;
    $83 = HEAP32[$42 >> 2] | 0;
    $84 = HEAP32[$44 >> 2] | 0;
    $85 = $83;
    $86 = $84;
    $87 = $85 - $86 | 0;
    $88 = $84 + $80 | 0;
    HEAP32[$42 >> 2] = $88;
    $offsetToData_0 = $87;
    $sharedpoints_0 = $82;
    label = 12;
    break;
   case 12:
    $90 = $69 & 4095;
    $91 = ($90 | 0) == 0;
    if ($91) {
      label = 39;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $92 = $6 + 24 | 0;
    $93 = $6 + 28 | 0;
    $94 = ($n_points | 0) == 0;
    $i_0151 = 0;
    $localpoints_0152 = 0;
    $offsetToData_1153 = $offsetToData_0;
    label = 14;
    break;
   case 14:
    $96 = _FT_Stream_GetShort($2) | 0;
    $97 = $96 & 65535;
    $98 = _FT_Stream_GetShort($2) | 0;
    $99 = $98 & 65535;
    $100 = $99 & 32768;
    $101 = ($100 | 0) == 0;
    if ($101) {
      label = 17;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $102 = HEAP32[$49 >> 2] | 0;
    $103 = ($102 | 0) == 0;
    if ($103) {
      label = 20;
      break;
    } else {
      $j_0134 = 0;
      label = 16;
      break;
    }
   case 16:
    $104 = _FT_Stream_GetShort($2) | 0;
    $105 = $104 << 16 >> 16;
    $106 = $105 << 2;
    $107 = $52 + ($j_0134 << 2) | 0;
    HEAP32[$107 >> 2] = $106;
    $108 = $j_0134 + 1 | 0;
    $109 = HEAP32[$49 >> 2] | 0;
    $110 = $108 >>> 0 < $109 >>> 0;
    if ($110) {
      $j_0134 = $108;
      label = 16;
      break;
    } else {
      label = 20;
      break;
    }
   case 17:
    $112 = $99 & 4095;
    $113 = HEAP32[$92 >> 2] | 0;
    $114 = $112 >>> 0 < $113 >>> 0;
    if ($114) {
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    HEAP32[$error >> 2] = 8;
    label = 39;
    break;
   case 19:
    $117 = HEAP32[$49 >> 2] | 0;
    $118 = Math_imul($117, $112);
    $119 = HEAP32[$93 >> 2] | 0;
    $120 = $119 + ($118 << 2) | 0;
    $121 = $120;
    $122 = $117 << 2;
    _memcpy($51 | 0, $121 | 0, $122 | 0);
    label = 20;
    break;
   case 20:
    $123 = $99 & 16384;
    $124 = ($123 | 0) == 0;
    if ($124) {
      label = 25;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $125 = HEAP32[$49 >> 2] | 0;
    $126 = ($125 | 0) == 0;
    if ($126) {
      label = 25;
      break;
    } else {
      $j_1137 = 0;
      label = 22;
      break;
    }
   case 22:
    $127 = _FT_Stream_GetShort($2) | 0;
    $128 = $127 << 16 >> 16;
    $129 = $128 << 2;
    $130 = $58 + ($j_1137 << 2) | 0;
    HEAP32[$130 >> 2] = $129;
    $131 = $j_1137 + 1 | 0;
    $132 = HEAP32[$49 >> 2] | 0;
    $133 = $131 >>> 0 < $132 >>> 0;
    if ($133) {
      $j_1137 = $131;
      label = 22;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $134 = ($132 | 0) == 0;
    if ($134) {
      label = 25;
      break;
    } else {
      $j_2140 = 0;
      label = 24;
      break;
    }
   case 24:
    $135 = _FT_Stream_GetShort($2) | 0;
    $136 = $135 << 16 >> 16;
    $137 = $136 << 2;
    $138 = $64 + ($j_2140 << 2) | 0;
    HEAP32[$138 >> 2] = $137;
    $139 = $j_2140 + 1 | 0;
    $140 = HEAP32[$49 >> 2] | 0;
    $141 = $139 >>> 0 < $140 >>> 0;
    if ($141) {
      $j_2140 = $139;
      label = 24;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $142 = _ft_var_apply_tuple($6, $98, $52, $58, $64) | 0;
    $143 = ($142 | 0) == 0;
    if ($143) {
      $localpoints_3 = $localpoints_0152;
      label = 38;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $145 = HEAP32[$42 >> 2] | 0;
    $146 = HEAP32[$44 >> 2] | 0;
    $147 = $145;
    $148 = $146;
    $149 = $147 - $148 | 0;
    $150 = $99 & 8192;
    $151 = ($150 | 0) == 0;
    if ($151) {
      label = 28;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $153 = $146 + $offsetToData_1153 | 0;
    HEAP32[$42 >> 2] = $153;
    $154 = _ft_var_readpackedpoints($2, $point_count) | 0;
    $points_0 = $154;
    $localpoints_1 = $154;
    label = 29;
    break;
   case 28:
    $156 = HEAP32[$spoint_count >> 2] | 0;
    HEAP32[$point_count >> 2] = $156;
    $points_0 = $sharedpoints_0;
    $localpoints_1 = $localpoints_0152;
    label = 29;
    break;
   case 29:
    $158 = HEAP32[$point_count >> 2] | 0;
    $159 = ($158 | 0) == 0;
    $160 = $159 ? $n_points : $158;
    $161 = _ft_var_readpackeddeltas($2, $160) | 0;
    $162 = HEAP32[$point_count >> 2] | 0;
    $163 = ($162 | 0) == 0;
    $164 = $163 ? $n_points : $162;
    $165 = _ft_var_readpackeddeltas($2, $164) | 0;
    $166 = ($points_0 | 0) == 0;
    $167 = ($165 | 0) == 0;
    $or_cond132 = $166 | $167;
    $168 = ($161 | 0) == 0;
    $or_cond133 = $or_cond132 | $168;
    if ($or_cond133) {
      label = 35;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    $170 = ($points_0 | 0) == -1;
    if ($170) {
      label = 31;
      break;
    } else {
      label = 32;
      break;
    }
   case 31:
    if ($94) {
      label = 35;
      break;
    } else {
      $j_3148 = 0;
      label = 33;
      break;
    }
   case 32:
    $171 = HEAP32[$point_count >> 2] | 0;
    $172 = ($171 | 0) == 0;
    if ($172) {
      label = 35;
      break;
    } else {
      $j_4144 = 0;
      label = 34;
      break;
    }
   case 33:
    $173 = $161 + ($j_3148 << 1) | 0;
    $174 = HEAP16[$173 >> 1] | 0;
    $175 = $174 << 16 >> 16;
    $176 = _FT_MulFix($175, $142) | 0;
    $177 = $13 + ($j_3148 << 3) | 0;
    $178 = HEAP32[$177 >> 2] | 0;
    $179 = $178 + $176 | 0;
    HEAP32[$177 >> 2] = $179;
    $180 = $165 + ($j_3148 << 1) | 0;
    $181 = HEAP16[$180 >> 1] | 0;
    $182 = $181 << 16 >> 16;
    $183 = _FT_MulFix($182, $142) | 0;
    $184 = $13 + ($j_3148 << 3) + 4 | 0;
    $185 = HEAP32[$184 >> 2] | 0;
    $186 = $185 + $183 | 0;
    HEAP32[$184 >> 2] = $186;
    $187 = $j_3148 + 1 | 0;
    $exitcond = ($187 | 0) == ($n_points | 0);
    if ($exitcond) {
      label = 35;
      break;
    } else {
      $j_3148 = $187;
      label = 33;
      break;
    }
   case 34:
    $188 = $161 + ($j_4144 << 1) | 0;
    $189 = HEAP16[$188 >> 1] | 0;
    $190 = $189 << 16 >> 16;
    $191 = _FT_MulFix($190, $142) | 0;
    $192 = $localpoints_1 + ($j_4144 << 1) | 0;
    $193 = HEAP16[$192 >> 1] | 0;
    $194 = $193 & 65535;
    $195 = $13 + ($194 << 3) | 0;
    $196 = HEAP32[$195 >> 2] | 0;
    $197 = $196 + $191 | 0;
    HEAP32[$195 >> 2] = $197;
    $198 = $165 + ($j_4144 << 1) | 0;
    $199 = HEAP16[$198 >> 1] | 0;
    $200 = $199 << 16 >> 16;
    $201 = _FT_MulFix($200, $142) | 0;
    $202 = HEAP16[$192 >> 1] | 0;
    $203 = $202 & 65535;
    $204 = $13 + ($203 << 3) + 4 | 0;
    $205 = HEAP32[$204 >> 2] | 0;
    $206 = $205 + $201 | 0;
    HEAP32[$204 >> 2] = $206;
    $207 = $j_4144 + 1 | 0;
    $208 = HEAP32[$point_count >> 2] | 0;
    $209 = $207 >>> 0 < $208 >>> 0;
    if ($209) {
      $j_4144 = $207;
      label = 34;
      break;
    } else {
      label = 35;
      break;
    }
   case 35:
    $210 = ($localpoints_1 | 0) == -1;
    if ($210) {
      $localpoints_2 = -1;
      label = 37;
      break;
    } else {
      label = 36;
      break;
    }
   case 36:
    $212 = $localpoints_1;
    _ft_mem_free($4, $212);
    $localpoints_2 = 0;
    label = 37;
    break;
   case 37:
    $214 = $161;
    _ft_mem_free($4, $214);
    $215 = $165;
    _ft_mem_free($4, $215);
    $216 = HEAP32[$44 >> 2] | 0;
    $217 = $216 + $149 | 0;
    HEAP32[$42 >> 2] = $217;
    $localpoints_3 = $localpoints_2;
    label = 38;
    break;
   case 38:
    $offsetToData_2 = $97 + $offsetToData_1153 | 0;
    $219 = $i_0151 + 1 | 0;
    $220 = $219 >>> 0 < $90 >>> 0;
    if ($220) {
      $i_0151 = $219;
      $localpoints_0152 = $localpoints_3;
      $offsetToData_1153 = $offsetToData_2;
      label = 14;
      break;
    } else {
      label = 39;
      break;
    }
   case 39:
    _ft_mem_free($4, $51);
    _ft_mem_free($4, $57);
    _ft_mem_free($4, $63);
    label = 40;
    break;
   case 40:
    _FT_Stream_ExitFrame($2);
    $_pr = HEAP32[$error >> 2] | 0;
    $222 = ($_pr | 0) == 0;
    if ($222) {
      label = 42;
      break;
    } else {
      label = 41;
      break;
    }
   case 41:
    _ft_mem_free($4, $12);
    HEAP32[$deltas >> 2] = 0;
    label = 42;
    break;
   case 42:
    $224 = HEAP32[$error >> 2] | 0;
    $_0 = $224;
    label = 43;
    break;
   case 43:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _TT_Process_Simple_Glyph($loader) {
  $loader = $loader | 0;
  var $deltas = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $ld$0$0 = 0, $13$0 = 0, $ld$1$1 = 0, $13$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $ld$4$0 = 0, $20$0 = 0, $ld$5$1 = 0, $20$1 = 0, $st$6$0 = 0, $st$7$1 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $ld$8$0 = 0, $27$0 = 0, $ld$9$1 = 0, $27$1 = 0, $st$10$0 = 0, $st$11$1 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $ld$12$0 = 0, $34$0 = 0, $ld$13$1 = 0, $34$1 = 0, $st$14$0 = 0, $st$15$1 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $i_070 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $exitcond = 0, $_lcssa = 0, $79 = 0, $error_0 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $99 = 0, $100 = 0, $101 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $vec_069 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $ld$16$0 = 0, $125$0 = 0, $ld$17$1 = 0, $125$1 = 0, $st$18$0 = 0, $st$19$1 = 0, $126 = 0, $127 = 0, $128 = 0, $ld$20$0 = 0, $129$0 = 0, $ld$21$1 = 0, $129$1 = 0, $st$22$0 = 0, $st$23$1 = 0, $130 = 0, $131 = 0, $132 = 0, $ld$24$0 = 0, $133$0 = 0, $ld$25$1 = 0, $133$1 = 0, $st$26$0 = 0, $st$27$1 = 0, $134 = 0, $135 = 0, $136 = 0, $ld$28$0 = 0, $137$0 = 0, $ld$29$1 = 0, $137$1 = 0, $st$30$0 = 0, $st$31$1 = 0, $139 = 0, $140 = 0, $141 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $deltas = __stackBase__ | 0;
    $1 = $loader + 12 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 56 | 0;
    $4 = $2 + 58 | 0;
    $5 = HEAP16[$4 >> 1] | 0;
    $6 = $5 << 16 >> 16;
    $7 = $2 + 60 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 + ($6 << 3) | 0;
    $10 = $loader + 68 | 0;
    $11 = $10;
    $12 = $9;
    $ld$0$0 = $11 | 0;
    $13$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $11 + 4 | 0;
    $13$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $12 | 0;
    HEAP32[$st$2$0 >> 2] = $13$0;
    $st$3$1 = $12 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $13$1;
    $14 = $6 + 1 | 0;
    $15 = HEAP32[$7 >> 2] | 0;
    $16 = $15 + ($14 << 3) | 0;
    $17 = $loader + 76 | 0;
    $18 = $17;
    $19 = $16;
    $ld$4$0 = $18 | 0;
    $20$0 = HEAP32[$ld$4$0 >> 2] | 0;
    $ld$5$1 = $18 + 4 | 0;
    $20$1 = HEAP32[$ld$5$1 >> 2] | 0;
    $st$6$0 = $19 | 0;
    HEAP32[$st$6$0 >> 2] = $20$0;
    $st$7$1 = $19 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $20$1;
    $21 = $6 + 2 | 0;
    $22 = HEAP32[$7 >> 2] | 0;
    $23 = $22 + ($21 << 3) | 0;
    $24 = $loader + 184 | 0;
    $25 = $24;
    $26 = $23;
    $ld$8$0 = $25 | 0;
    $27$0 = HEAP32[$ld$8$0 >> 2] | 0;
    $ld$9$1 = $25 + 4 | 0;
    $27$1 = HEAP32[$ld$9$1 >> 2] | 0;
    $st$10$0 = $26 | 0;
    HEAP32[$st$10$0 >> 2] = $27$0;
    $st$11$1 = $26 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $27$1;
    $28 = $6 + 3 | 0;
    $29 = HEAP32[$7 >> 2] | 0;
    $30 = $29 + ($28 << 3) | 0;
    $31 = $loader + 192 | 0;
    $32 = $31;
    $33 = $30;
    $ld$12$0 = $32 | 0;
    $34$0 = HEAP32[$ld$12$0 >> 2] | 0;
    $ld$13$1 = $32 + 4 | 0;
    $34$1 = HEAP32[$ld$13$1 >> 2] | 0;
    $st$14$0 = $33 | 0;
    HEAP32[$st$14$0 >> 2] = $34$0;
    $st$15$1 = $33 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $34$1;
    $35 = $2 + 64 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $36 + $6 | 0;
    HEAP8[$37] = 0;
    $38 = HEAP32[$35 >> 2] | 0;
    $39 = $38 + $14 | 0;
    HEAP8[$39] = 0;
    $40 = HEAP32[$35 >> 2] | 0;
    $41 = $40 + $21 | 0;
    HEAP8[$41] = 0;
    $42 = HEAP32[$35 >> 2] | 0;
    $43 = $42 + $28 | 0;
    HEAP8[$43] = 0;
    $44 = $6 + 4 | 0;
    $45 = $loader | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $46 + 708 | 0;
    $48 = $47;
    $49 = HEAP8[$48] | 0;
    $50 = $49 << 24 >> 24 == 0;
    if ($50) {
      $error_0 = 0;
      label = 7;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $52 = $46;
    $53 = $46 + 100 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = $loader + 20 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = _TT_Vary_Get_Glyph_Deltas($52, $56, $deltas, $44) | 0;
    $58 = ($57 | 0) == 0;
    if ($58) {
      label = 3;
      break;
    } else {
      $_0 = $57;
      label = 15;
      break;
    }
   case 3:
    $59 = ($44 | 0) > 0;
    $60 = HEAP32[$deltas >> 2] | 0;
    if ($59) {
      label = 4;
      break;
    } else {
      $_lcssa = $60;
      label = 6;
      break;
    }
   case 4:
    $61 = HEAP32[$deltas >> 2] | 0;
    $62 = $5 << 16 >> 16;
    $63 = $62 + 4 | 0;
    $i_070 = 0;
    $65 = $60;
    label = 5;
    break;
   case 5:
    $66 = $65 + ($i_070 << 3) | 0;
    $67 = HEAP32[$66 >> 2] | 0;
    $68 = HEAP32[$7 >> 2] | 0;
    $69 = $68 + ($i_070 << 3) | 0;
    $70 = HEAP32[$69 >> 2] | 0;
    $71 = $70 + $67 | 0;
    HEAP32[$69 >> 2] = $71;
    $72 = $61 + ($i_070 << 3) + 4 | 0;
    $73 = HEAP32[$72 >> 2] | 0;
    $74 = HEAP32[$7 >> 2] | 0;
    $75 = $74 + ($i_070 << 3) + 4 | 0;
    $76 = HEAP32[$75 >> 2] | 0;
    $77 = $76 + $73 | 0;
    HEAP32[$75 >> 2] = $77;
    $78 = $i_070 + 1 | 0;
    $exitcond = ($78 | 0) == ($63 | 0);
    if ($exitcond) {
      $_lcssa = $61;
      label = 6;
      break;
    } else {
      $i_070 = $78;
      $65 = $61;
      label = 5;
      break;
    }
   case 6:
    $79 = $_lcssa;
    _ft_mem_free($54, $79);
    HEAP32[$deltas >> 2] = 0;
    $error_0 = $57;
    label = 7;
    break;
   case 7:
    $81 = $loader + 16 | 0;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = $82 & 2;
    $84 = ($83 | 0) == 0;
    if ($84) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $86 = $loader + 124 | 0;
    _tt_prepare_zone($86, $3, 0, 0);
    $87 = $loader + 144 | 0;
    $88 = HEAP32[$87 >> 2] | 0;
    $89 = $88;
    $90 = $loader + 140 | 0;
    $91 = HEAP32[$90 >> 2] | 0;
    $92 = $91;
    $93 = $loader + 132 | 0;
    $94 = HEAP16[$93 >> 1] | 0;
    $95 = $94 & 65535;
    $96 = $95 << 3;
    $97 = $96 + 32 | 0;
    _memcpy($89 | 0, $92 | 0, $97 | 0);
    label = 9;
    break;
   case 9:
    $99 = HEAP32[$81 >> 2] | 0;
    $100 = $99 & 1;
    $101 = ($100 | 0) == 0;
    if ($101) {
      label = 10;
      break;
    } else {
      label = 13;
      break;
    }
   case 10:
    $103 = HEAP32[$7 >> 2] | 0;
    $104 = $103 + ($44 << 3) | 0;
    $105 = $loader + 4 | 0;
    $106 = HEAP32[$105 >> 2] | 0;
    $107 = $106 + 48 | 0;
    $108 = $107;
    $109 = HEAP32[$108 >> 2] | 0;
    $110 = $106 + 52 | 0;
    $111 = $110;
    $112 = HEAP32[$111 >> 2] | 0;
    $113 = ($44 | 0) > 0;
    if ($113) {
      $vec_069 = $103;
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $114 = $vec_069 | 0;
    $115 = HEAP32[$114 >> 2] | 0;
    $116 = _FT_MulFix($115, $109) | 0;
    HEAP32[$114 >> 2] = $116;
    $117 = $vec_069 + 4 | 0;
    $118 = HEAP32[$117 >> 2] | 0;
    $119 = _FT_MulFix($118, $112) | 0;
    HEAP32[$117 >> 2] = $119;
    $120 = $vec_069 + 8 | 0;
    $121 = $120 >>> 0 < $104 >>> 0;
    if ($121) {
      $vec_069 = $120;
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $122 = HEAP32[$7 >> 2] | 0;
    $123 = $122 + ($6 << 3) | 0;
    $124 = $123;
    $ld$16$0 = $124 | 0;
    $125$0 = HEAP32[$ld$16$0 >> 2] | 0;
    $ld$17$1 = $124 + 4 | 0;
    $125$1 = HEAP32[$ld$17$1 >> 2] | 0;
    $st$18$0 = $11 | 0;
    HEAP32[$st$18$0 >> 2] = $125$0;
    $st$19$1 = $11 + 4 | 0;
    HEAP32[$st$19$1 >> 2] = $125$1;
    $126 = HEAP32[$7 >> 2] | 0;
    $127 = $126 + ($14 << 3) | 0;
    $128 = $127;
    $ld$20$0 = $128 | 0;
    $129$0 = HEAP32[$ld$20$0 >> 2] | 0;
    $ld$21$1 = $128 + 4 | 0;
    $129$1 = HEAP32[$ld$21$1 >> 2] | 0;
    $st$22$0 = $18 | 0;
    HEAP32[$st$22$0 >> 2] = $129$0;
    $st$23$1 = $18 + 4 | 0;
    HEAP32[$st$23$1 >> 2] = $129$1;
    $130 = HEAP32[$7 >> 2] | 0;
    $131 = $130 + ($21 << 3) | 0;
    $132 = $131;
    $ld$24$0 = $132 | 0;
    $133$0 = HEAP32[$ld$24$0 >> 2] | 0;
    $ld$25$1 = $132 + 4 | 0;
    $133$1 = HEAP32[$ld$25$1 >> 2] | 0;
    $st$26$0 = $25 | 0;
    HEAP32[$st$26$0 >> 2] = $133$0;
    $st$27$1 = $25 + 4 | 0;
    HEAP32[$st$27$1 >> 2] = $133$1;
    $134 = HEAP32[$7 >> 2] | 0;
    $135 = $134 + ($28 << 3) | 0;
    $136 = $135;
    $ld$28$0 = $136 | 0;
    $137$0 = HEAP32[$ld$28$0 >> 2] | 0;
    $ld$29$1 = $136 + 4 | 0;
    $137$1 = HEAP32[$ld$29$1 >> 2] | 0;
    $st$30$0 = $32 | 0;
    HEAP32[$st$30$0 >> 2] = $137$0;
    $st$31$1 = $32 + 4 | 0;
    HEAP32[$st$31$1 >> 2] = $137$1;
    label = 13;
    break;
   case 13:
    $139 = HEAP32[$81 >> 2] | 0;
    $140 = $139 & 2;
    $141 = ($140 | 0) == 0;
    if ($141) {
      label = 14;
      break;
    } else {
      $_0 = $error_0;
      label = 15;
      break;
    }
   case 14:
    $143 = $loader + 132 | 0;
    $144 = HEAP16[$143 >> 1] | 0;
    $145 = $144 + 4 & 65535;
    HEAP16[$143 >> 1] = $145;
    $146 = _TT_Hint_Glyph($loader, 0) | 0;
    $_0 = $146;
    label = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _TT_Process_Composite_Component($loader, $subglyph, $start_point, $num_base_points) {
  $loader = $loader | 0;
  $subglyph = $subglyph | 0;
  $start_point = $start_point | 0;
  $num_base_points = $num_base_points | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $_not = 0, $12 = 0, $or_cond4 = 0, $13 = 0, $14 = 0, $i_03 = 0, $16 = 0, $17 = 0, $exitcond = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $or_cond = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $y_0 = 0, $x_0 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $y_1 = 0, $x_1 = 0, $93 = 0, $94 = 0, $96 = 0, $97 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $loader + 12 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 24 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + 22 | 0;
    $6 = HEAP16[$5 >> 1] | 0;
    $7 = $6 << 16 >> 16;
    $8 = $subglyph + 4 | 0;
    $9 = HEAP16[$8 >> 1] | 0;
    $10 = $9 & 200;
    $11 = $10 << 16 >> 16 == 0;
    $_not = $11 ^ 1;
    $12 = $7 >>> 0 > $num_base_points >>> 0;
    $or_cond4 = $12 & $_not;
    if ($or_cond4) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $13 = $subglyph + 16 | 0;
    $14 = $6 << 16 >> 16;
    $i_03 = $num_base_points;
    label = 3;
    break;
   case 3:
    $16 = $4 + ($i_03 << 3) | 0;
    _FT_Vector_Transform($16, $13);
    $17 = $i_03 + 1 | 0;
    $exitcond = ($17 | 0) == ($14 | 0);
    if ($exitcond) {
      label = 4;
      break;
    } else {
      $i_03 = $17;
      label = 3;
      break;
    }
   case 4:
    $18 = HEAP16[$8 >> 1] | 0;
    $19 = $18 & 2;
    $20 = $19 << 16 >> 16 == 0;
    $21 = $subglyph + 8 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $subglyph + 12 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    if ($20) {
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    $26 = $22 + $start_point | 0;
    $27 = $24 + $num_base_points | 0;
    $28 = $26 >>> 0 < $num_base_points >>> 0;
    $29 = $27 >>> 0 < $7 >>> 0;
    $or_cond = $28 & $29;
    if ($or_cond) {
      label = 6;
      break;
    } else {
      label = 16;
      break;
    }
   case 6:
    $31 = HEAP32[$3 >> 2] | 0;
    $32 = $31 + ($26 << 3) | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $31 + ($27 << 3) | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $33 - $35 | 0;
    $37 = $31 + ($26 << 3) + 4 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $31 + ($27 << 3) + 4 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $38 - $40 | 0;
    $x_1 = $36;
    $y_1 = $41;
    label = 14;
    break;
   case 7:
    $43 = $24 | $22;
    $44 = ($43 | 0) == 0;
    if ($44) {
      label = 16;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    if ($11) {
      $x_0 = $22;
      $y_0 = $24;
      label = 11;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $47 = $18 & 2048;
    $48 = $47 << 16 >> 16 == 0;
    if ($48) {
      $x_0 = $22;
      $y_0 = $24;
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $50 = $subglyph + 16 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = _FT_MulFix($51, $51) | 0;
    $53 = $subglyph + 20 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = _FT_MulFix($54, $54) | 0;
    $56 = $55 + $52 | 0;
    $57 = _FT_SqrtFixed($56) | 0;
    $58 = $subglyph + 28 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = _FT_MulFix($59, $59) | 0;
    $61 = $subglyph + 24 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = _FT_MulFix($62, $62) | 0;
    $64 = $63 + $60 | 0;
    $65 = _FT_SqrtFixed($64) | 0;
    $66 = _FT_MulFix($22, $57) | 0;
    $67 = _FT_MulFix($24, $65) | 0;
    $x_0 = $66;
    $y_0 = $67;
    label = 11;
    break;
   case 11:
    $69 = $loader + 16 | 0;
    $70 = HEAP32[$69 >> 2] | 0;
    $71 = $70 & 1;
    $72 = ($71 | 0) == 0;
    if ($72) {
      label = 12;
      break;
    } else {
      $x_1 = $x_0;
      $y_1 = $y_0;
      label = 14;
      break;
    }
   case 12:
    $74 = $loader + 4 | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    $76 = $75 + 48 | 0;
    $77 = $76;
    $78 = HEAP32[$77 >> 2] | 0;
    $79 = $75 + 52 | 0;
    $80 = $79;
    $81 = HEAP32[$80 >> 2] | 0;
    $82 = _FT_MulFix($x_0, $78) | 0;
    $83 = _FT_MulFix($y_0, $81) | 0;
    $84 = HEAP16[$8 >> 1] | 0;
    $85 = $84 & 4;
    $86 = $85 << 16 >> 16 == 0;
    if ($86) {
      $x_1 = $82;
      $y_1 = $83;
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $88 = $82 + 32 | 0;
    $89 = $88 & -64;
    $90 = $83 + 32 | 0;
    $91 = $90 & -64;
    $x_1 = $89;
    $y_1 = $91;
    label = 14;
    break;
   case 14:
    $93 = $x_1 | $y_1;
    $94 = ($93 | 0) == 0;
    if ($94) {
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $96 = $7 - $num_base_points | 0;
    $97 = $4 + ($num_base_points << 3) | 0;
    _translate_array($96, $97, $x_1, $y_1);
    label = 16;
    break;
   case 16:
    return;
  }
}
function _tt_prepare_zone($zone, $load, $start_point, $start_contour) {
  $zone = $zone | 0;
  $load = $load | 0;
  $start_point = $start_point | 0;
  $start_contour = $start_contour | 0;
  HEAP16[$zone + 8 >> 1] = (HEAPU16[$load + 2 >> 1] | 0) - $start_point & 65535;
  HEAP16[$zone + 10 >> 1] = (HEAPU16[$load >> 1] | 0) - $start_contour & 65535;
  HEAP32[$zone + 12 >> 2] = (HEAP32[$load + 20 >> 2] | 0) + ($start_point << 3) | 0;
  HEAP32[$zone + 16 >> 2] = (HEAP32[$load + 4 >> 2] | 0) + ($start_point << 3) | 0;
  HEAP32[$zone + 20 >> 2] = (HEAP32[$load + 24 >> 2] | 0) + ($start_point << 3) | 0;
  HEAP32[$zone + 24 >> 2] = (HEAP32[$load + 8 >> 2] | 0) + $start_point | 0;
  HEAP32[$zone + 28 >> 2] = (HEAP32[$load + 12 >> 2] | 0) + ($start_contour << 1) | 0;
  HEAP16[$zone + 32 >> 1] = $start_point & 65535;
  return;
}
function _translate_array($n, $coords, $delta_x, $delta_y) {
  $n = $n | 0;
  $coords = $coords | 0;
  $delta_x = $delta_x | 0;
  $delta_y = $delta_y | 0;
  var $1 = 0, $2 = 0, $or_cond = 0, $k_016 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $exitcond18 = 0, $7 = 0, $8 = 0, $or_cond19 = 0, $k_113 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $exitcond = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($delta_x | 0) == 0;
    $2 = ($n | 0) == 0;
    $or_cond = $1 | $2;
    if ($or_cond) {
      label = 3;
      break;
    } else {
      $k_016 = 0;
      label = 2;
      break;
    }
   case 2:
    $3 = $coords + ($k_016 << 3) | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + $delta_x | 0;
    HEAP32[$3 >> 2] = $5;
    $6 = $k_016 + 1 | 0;
    $exitcond18 = ($6 | 0) == ($n | 0);
    if ($exitcond18) {
      label = 3;
      break;
    } else {
      $k_016 = $6;
      label = 2;
      break;
    }
   case 3:
    $7 = ($delta_y | 0) == 0;
    $8 = ($n | 0) == 0;
    $or_cond19 = $7 | $8;
    if ($or_cond19) {
      label = 5;
      break;
    } else {
      $k_113 = 0;
      label = 4;
      break;
    }
   case 4:
    $9 = $coords + ($k_113 << 3) + 4 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10 + $delta_y | 0;
    HEAP32[$9 >> 2] = $11;
    $12 = $k_113 + 1 | 0;
    $exitcond = ($12 | 0) == ($n | 0);
    if ($exitcond) {
      label = 5;
      break;
    } else {
      $k_113 = $12;
      label = 4;
      break;
    }
   case 5:
    return;
  }
}
function _TT_Set_CodeRange($exec, $range, $base, $length) {
  $exec = $exec | 0;
  $range = $range | 0;
  $base = $base | 0;
  $length = $length | 0;
  var $1 = 0;
  $1 = $range - 1 | 0;
  HEAP32[$exec + 444 + ($1 << 3) >> 2] = $base;
  HEAP32[$exec + 444 + ($1 << 3) + 4 >> 2] = $length;
  return;
}
function _TT_Goto_CodeRange($exec, $range) {
  $exec = $exec | 0;
  $range = $range | 0;
  var $1 = 0;
  $1 = $range - 1 | 0;
  HEAP32[$exec + 356 >> 2] = HEAP32[$exec + 444 + ($1 << 3) >> 2] | 0;
  HEAP32[$exec + 364 >> 2] = HEAP32[$exec + 444 + ($1 << 3) + 4 >> 2] | 0;
  HEAP32[$exec + 360 >> 2] = 0;
  HEAP32[$exec + 352 >> 2] = $range;
  return;
}
function _TT_Clear_CodeRange($exec, $range) {
  $exec = $exec | 0;
  $range = $range | 0;
  var $1 = 0;
  $1 = $range - 1 | 0;
  HEAP32[$exec + 444 + ($1 << 3) >> 2] = 0;
  HEAP32[$exec + 444 + ($1 << 3) + 4 >> 2] = 0;
  return;
}
function _TT_Save_Context($exec, $size) {
  $exec = $exec | 0;
  $size = $size | 0;
  var $15 = 0, $16 = 0, $17$1 = 0, $20 = 0, $21 = 0, $22$1 = 0, $25 = 0, $26 = 0, $27$1 = 0;
  HEAP32[$size + 116 >> 2] = HEAP32[$exec + 396 >> 2] | 0;
  HEAP32[$size + 128 >> 2] = HEAP32[$exec + 408 >> 2] | 0;
  HEAP32[$size + 140 >> 2] = HEAP32[$exec + 420 >> 2] | 0;
  HEAP32[$size + 144 >> 2] = HEAP32[$exec + 424 >> 2] | 0;
  $15 = $exec + 444 | 0;
  $16 = $size + 148 | 0;
  $17$1 = HEAP32[$15 + 4 >> 2] | 0;
  HEAP32[$16 >> 2] = HEAP32[$15 >> 2] | 0;
  HEAP32[$16 + 4 >> 2] = $17$1;
  $20 = $exec + 452 | 0;
  $21 = $size + 156 | 0;
  $22$1 = HEAP32[$20 + 4 >> 2] | 0;
  HEAP32[$21 >> 2] = HEAP32[$20 >> 2] | 0;
  HEAP32[$21 + 4 >> 2] = $22$1;
  $25 = $exec + 460 | 0;
  $26 = $size + 164 | 0;
  $27$1 = HEAP32[$25 + 4 >> 2] | 0;
  HEAP32[$26 >> 2] = HEAP32[$25 >> 2] | 0;
  HEAP32[$26 + 4 >> 2] = $27$1;
  return;
}
function _TT_Process_Composite_Glyph($loader, $start_point, $start_contour) {
  $loader = $loader | 0;
  $start_point = $start_point | 0;
  $start_contour = $start_contour | 0;
  var $error = 0, $tmp = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $ld$0$0 = 0, $29$0 = 0, $ld$1$1 = 0, $29$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $ld$4$0 = 0, $38$0 = 0, $ld$5$1 = 0, $38$1 = 0, $st$6$0 = 0, $st$7$1 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $ld$8$0 = 0, $47$0 = 0, $ld$9$1 = 0, $47$1 = 0, $st$10$0 = 0, $st$11$1 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $ld$12$0 = 0, $56$0 = 0, $ld$13$1 = 0, $56$1 = 0, $st$14$0 = 0, $st$15$1 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $84 = 0, $85 = 0, $86 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $97 = 0, $98 = 0, $99 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $118 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $i_02 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $_lcssa1 = 0, $152 = 0, $153 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $tmp = __stackBase__ + 4 | 0;
    $1 = $loader + 12 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 22 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 << 16 >> 16;
    $6 = $5 + 4 | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = $2 + 58 | 0;
    $10 = HEAP16[$9 >> 1] | 0;
    $11 = $10 << 16 >> 16;
    $12 = $6 + $5 | 0;
    $13 = $12 + $11 | 0;
    $14 = $2 + 4 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $13 >>> 0 > $15 >>> 0;
    if ($16) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    HEAP32[$error >> 2] = 0;
    label = 5;
    break;
   case 4:
    $18 = _FT_GlyphLoader_CheckPoints($2, $6, 0) | 0;
    HEAP32[$error >> 2] = $18;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 5;
      break;
    } else {
      label = 16;
      break;
    }
   case 5:
    $21 = HEAP16[$3 >> 1] | 0;
    $22 = $21 << 16 >> 16;
    $23 = $2 + 24 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24 + ($22 << 3) | 0;
    $26 = $loader + 68 | 0;
    $27 = $26;
    $28 = $25;
    $ld$0$0 = $27 | 0;
    $29$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $27 + 4 | 0;
    $29$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $28 | 0;
    HEAP32[$st$2$0 >> 2] = $29$0;
    $st$3$1 = $28 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $29$1;
    $30 = HEAP16[$3 >> 1] | 0;
    $31 = $30 << 16 >> 16;
    $32 = $31 + 1 | 0;
    $33 = HEAP32[$23 >> 2] | 0;
    $34 = $33 + ($32 << 3) | 0;
    $35 = $loader + 76 | 0;
    $36 = $35;
    $37 = $34;
    $ld$4$0 = $36 | 0;
    $38$0 = HEAP32[$ld$4$0 >> 2] | 0;
    $ld$5$1 = $36 + 4 | 0;
    $38$1 = HEAP32[$ld$5$1 >> 2] | 0;
    $st$6$0 = $37 | 0;
    HEAP32[$st$6$0 >> 2] = $38$0;
    $st$7$1 = $37 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $38$1;
    $39 = HEAP16[$3 >> 1] | 0;
    $40 = $39 << 16 >> 16;
    $41 = $40 + 2 | 0;
    $42 = HEAP32[$23 >> 2] | 0;
    $43 = $42 + ($41 << 3) | 0;
    $44 = $loader + 184 | 0;
    $45 = $44;
    $46 = $43;
    $ld$8$0 = $45 | 0;
    $47$0 = HEAP32[$ld$8$0 >> 2] | 0;
    $ld$9$1 = $45 + 4 | 0;
    $47$1 = HEAP32[$ld$9$1 >> 2] | 0;
    $st$10$0 = $46 | 0;
    HEAP32[$st$10$0 >> 2] = $47$0;
    $st$11$1 = $46 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $47$1;
    $48 = HEAP16[$3 >> 1] | 0;
    $49 = $48 << 16 >> 16;
    $50 = $49 + 3 | 0;
    $51 = HEAP32[$23 >> 2] | 0;
    $52 = $51 + ($50 << 3) | 0;
    $53 = $loader + 192 | 0;
    $54 = $53;
    $55 = $52;
    $ld$12$0 = $54 | 0;
    $56$0 = HEAP32[$ld$12$0 >> 2] | 0;
    $ld$13$1 = $54 + 4 | 0;
    $56$1 = HEAP32[$ld$13$1 >> 2] | 0;
    $st$14$0 = $55 | 0;
    HEAP32[$st$14$0 >> 2] = $56$0;
    $st$15$1 = $55 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $56$1;
    $57 = HEAP16[$3 >> 1] | 0;
    $58 = $57 << 16 >> 16;
    $59 = $2 + 28 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = $60 + $58 | 0;
    HEAP8[$61] = 0;
    $62 = HEAP16[$3 >> 1] | 0;
    $63 = $62 << 16 >> 16;
    $64 = $63 + 1 | 0;
    $65 = HEAP32[$59 >> 2] | 0;
    $66 = $65 + $64 | 0;
    HEAP8[$66] = 0;
    $67 = HEAP16[$3 >> 1] | 0;
    $68 = $67 << 16 >> 16;
    $69 = $68 + 2 | 0;
    $70 = HEAP32[$59 >> 2] | 0;
    $71 = $70 + $69 | 0;
    HEAP8[$71] = 0;
    $72 = HEAP16[$3 >> 1] | 0;
    $73 = $72 << 16 >> 16;
    $74 = $73 + 3 | 0;
    $75 = HEAP32[$59 >> 2] | 0;
    $76 = $75 + $74 | 0;
    HEAP8[$76] = 0;
    $77 = $loader + 24 | 0;
    $78 = HEAP32[$77 >> 2] | 0;
    $79 = $loader + 168 | 0;
    $80 = HEAP32[$79 >> 2] | 0;
    $81 = _FT_Stream_Seek($78, $80) | 0;
    HEAP32[$error >> 2] = $81;
    $82 = ($81 | 0) == 0;
    if ($82) {
      label = 6;
      break;
    } else {
      label = 16;
      break;
    }
   case 6:
    $84 = _FT_Stream_ReadShort($78, $error) | 0;
    $85 = HEAP32[$error >> 2] | 0;
    $86 = ($85 | 0) == 0;
    if ($86) {
      label = 7;
      break;
    } else {
      label = 16;
      break;
    }
   case 7:
    $88 = $loader | 0;
    $89 = HEAP32[$88 >> 2] | 0;
    $90 = $89 + 260 | 0;
    $91 = $90;
    $92 = $91 + 26 | 0;
    $93 = HEAP16[$92 >> 1] | 0;
    $94 = $84 & 65535;
    $95 = ($84 & 65535) > ($93 & 65535);
    if ($95) {
      label = 8;
      break;
    } else {
      label = 10;
      break;
    }
   case 8:
    $97 = $loader + 28 | 0;
    $98 = HEAP32[$97 >> 2] | 0;
    $99 = ($94 | 0) > ($98 | 0);
    if ($99) {
      label = 16;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $101 = $loader + 160 | 0;
    $102 = HEAP32[$101 >> 2] | 0;
    $103 = $102 + 388 | 0;
    $104 = HEAP32[$103 >> 2] | 0;
    HEAP32[$tmp >> 2] = $104;
    $105 = HEAP32[$101 >> 2] | 0;
    $106 = $105 + 8 | 0;
    $107 = HEAP32[$106 >> 2] | 0;
    $108 = $105 + 392 | 0;
    $109 = $108;
    $110 = _Update_Max($107, $tmp, 1, $109, $94) | 0;
    HEAP32[$error >> 2] = $110;
    $111 = HEAP32[$tmp >> 2] | 0;
    $112 = $111 & 65535;
    $113 = HEAP32[$101 >> 2] | 0;
    $114 = $113 + 388 | 0;
    HEAP32[$114 >> 2] = $112;
    $115 = HEAP32[$error >> 2] | 0;
    $116 = ($115 | 0) == 0;
    if ($116) {
      label = 11;
      break;
    } else {
      label = 16;
      break;
    }
   case 10:
    $118 = $84 << 16 >> 16 == 0;
    if ($118) {
      label = 16;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $120 = $loader + 160 | 0;
    $121 = HEAP32[$120 >> 2] | 0;
    $122 = $121 + 392 | 0;
    $123 = HEAP32[$122 >> 2] | 0;
    $124 = _FT_Stream_Read($78, $123, $94) | 0;
    HEAP32[$error >> 2] = $124;
    $125 = ($124 | 0) == 0;
    if ($125) {
      label = 12;
      break;
    } else {
      label = 16;
      break;
    }
   case 12:
    $127 = HEAP32[$120 >> 2] | 0;
    $128 = $127 + 392 | 0;
    $129 = HEAP32[$128 >> 2] | 0;
    $130 = $loader + 8 | 0;
    $131 = HEAP32[$130 >> 2] | 0;
    $132 = $131 + 136 | 0;
    HEAP32[$132 >> 2] = $129;
    $133 = HEAP32[$130 >> 2] | 0;
    $134 = $133 + 140 | 0;
    HEAP32[$134 >> 2] = $94;
    $135 = $loader + 124 | 0;
    $136 = HEAP32[$1 >> 2] | 0;
    $137 = $136 + 20 | 0;
    _tt_prepare_zone($135, $137, $start_point, $start_contour);
    $138 = $loader + 132 | 0;
    $139 = HEAP16[$138 >> 1] | 0;
    $140 = $139 & 65535;
    $141 = $140 >>> 0 > $start_point >>> 0;
    if ($141) {
      label = 13;
      break;
    } else {
      $_lcssa1 = $139;
      label = 15;
      break;
    }
   case 13:
    $142 = $loader + 148 | 0;
    $i_02 = $start_point;
    label = 14;
    break;
   case 14:
    $144 = HEAP32[$142 >> 2] | 0;
    $145 = $144 + $i_02 | 0;
    $146 = HEAP8[$145] | 0;
    $147 = $146 & -25;
    HEAP8[$145] = $147;
    $148 = $i_02 + 1 | 0;
    $149 = HEAP16[$138 >> 1] | 0;
    $150 = $149 & 65535;
    $151 = $148 >>> 0 < $150 >>> 0;
    if ($151) {
      $i_02 = $148;
      label = 14;
      break;
    } else {
      $_lcssa1 = $149;
      label = 15;
      break;
    }
   case 15:
    $152 = $_lcssa1 + 4 & 65535;
    HEAP16[$138 >> 1] = $152;
    $153 = _TT_Hint_Glyph($loader, 1) | 0;
    label = 16;
    break;
   case 16:
    STACKTOP = __stackBase__;
    return;
  }
}
function _Update_Max($memory, $size, $multiplier, $_pbuff, $new_max) {
  $memory = $memory | 0;
  $size = $size | 0;
  $multiplier = $multiplier | 0;
  $_pbuff = $_pbuff | 0;
  $new_max = $new_max | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $_pbuff;
    $2 = HEAP32[$size >> 2] | 0;
    $3 = $2 >>> 0 < $new_max >>> 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 4;
      break;
    }
   case 2:
    $5 = Math_imul($2, $multiplier);
    $6 = Math_imul($new_max, $multiplier);
    $7 = HEAP32[$1 >> 2] | 0;
    $8 = _ft_mem_realloc($memory, 1, $5, $6, $7, $error) | 0;
    HEAP32[$1 >> 2] = $8;
    $9 = HEAP32[$error >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 3;
      break;
    } else {
      $_0 = $9;
      label = 4;
      break;
    }
   case 3:
    HEAP32[$size >> 2] = $new_max;
    $_0 = 0;
    label = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _TT_Hint_Glyph($loader, $is_composite) {
  $loader = $loader | 0;
  $is_composite = $is_composite | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $84 = 0, $85 = 0, $current_outline_sroa_1_8__idx1 = 0, $current_outline_sroa_1_8_copyload = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $114 = 0, $115 = 0, $116 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $ld$0$0 = 0, $126$0 = 0, $ld$1$1 = 0, $126$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $ld$4$0 = 0, $135$0 = 0, $ld$5$1 = 0, $135$1 = 0, $st$6$0 = 0, $st$7$1 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $ld$8$0 = 0, $144$0 = 0, $ld$9$1 = 0, $144$1 = 0, $st$10$0 = 0, $st$11$1 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $ld$12$0 = 0, $153$0 = 0, $ld$13$1 = 0, $153$1 = 0, $st$14$0 = 0, $st$15$1 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $loader + 124 | 0;
    $2 = $loader + 8 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 + 140 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $loader + 132 | 0;
    $7 = HEAP16[$6 >> 1] | 0;
    $8 = $7 & 65535;
    $9 = $8 - 4 | 0;
    $10 = $loader + 140 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 + ($9 << 3) | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 + 32 | 0;
    $15 = $14 & -64;
    $16 = ($15 | 0) == ($13 | 0);
    if ($16) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $18 = $15 - $13 | 0;
    _translate_array($8, $11, $18, 0);
    label = 3;
    break;
   case 3:
    $20 = ($5 | 0) != 0;
    if ($20) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $22 = $loader + 136 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $23;
    $25 = HEAP32[$10 >> 2] | 0;
    $26 = $25;
    $27 = HEAP16[$6 >> 1] | 0;
    $28 = $27 & 65535;
    $29 = $28 << 3;
    _memcpy($24 | 0, $26 | 0, $29 | 0);
    label = 5;
    break;
   case 5:
    $31 = $loader + 160 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $32 + 284 | 0;
    $34 = $loader + 4 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $35 + 172 | 0;
    $37 = $33;
    $38 = $36;
    _memcpy($37 | 0, $38 | 0, 68);
    $39 = $is_composite << 24 >> 24 == 0;
    if ($39) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $41 = HEAP32[$31 >> 2] | 0;
    $42 = $41 + 220 | 0;
    HEAP32[$42 >> 2] = 65536;
    $43 = HEAP32[$31 >> 2] | 0;
    $44 = $43 + 224 | 0;
    HEAP32[$44 >> 2] = 65536;
    $45 = $loader + 144 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $46;
    $48 = HEAP32[$10 >> 2] | 0;
    $49 = $48;
    $50 = HEAP16[$6 >> 1] | 0;
    $51 = $50 & 65535;
    $52 = $51 << 3;
    _memcpy($47 | 0, $49 | 0, $52 | 0);
    label = 8;
    break;
   case 7:
    $54 = HEAP32[$34 >> 2] | 0;
    $55 = $54 + 48 | 0;
    $56 = $55;
    $57 = HEAP32[$56 >> 2] | 0;
    $58 = HEAP32[$31 >> 2] | 0;
    $59 = $58 + 220 | 0;
    HEAP32[$59 >> 2] = $57;
    $60 = HEAP32[$34 >> 2] | 0;
    $61 = $60 + 52 | 0;
    $62 = $61;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = HEAP32[$31 >> 2] | 0;
    $65 = $64 + 224 | 0;
    HEAP32[$65 >> 2] = $63;
    label = 8;
    break;
   case 8:
    $67 = HEAP16[$6 >> 1] | 0;
    $68 = $67 & 65535;
    $69 = $68 - 3 | 0;
    $70 = HEAP32[$10 >> 2] | 0;
    $71 = $70 + ($69 << 3) | 0;
    $72 = HEAP32[$71 >> 2] | 0;
    $73 = $72 + 32 | 0;
    $74 = $73 & -64;
    HEAP32[$71 >> 2] = $74;
    $75 = HEAP16[$6 >> 1] | 0;
    $76 = $75 & 65535;
    $77 = $76 - 1 | 0;
    $78 = HEAP32[$10 >> 2] | 0;
    $79 = $78 + ($77 << 3) + 4 | 0;
    $80 = HEAP32[$79 >> 2] | 0;
    $81 = $80 + 32 | 0;
    $82 = $81 & -64;
    HEAP32[$79 >> 2] = $82;
    if ($20) {
      label = 9;
      break;
    } else {
      label = 12;
      break;
    }
   case 9:
    $84 = $loader + 12 | 0;
    $85 = HEAP32[$84 >> 2] | 0;
    $current_outline_sroa_1_8__idx1 = $85 + 64 | 0;
    $current_outline_sroa_1_8_copyload = HEAP32[$current_outline_sroa_1_8__idx1 >> 2] | 0;
    $86 = HEAP32[$31 >> 2] | 0;
    $87 = $86 + 392 | 0;
    $88 = HEAP32[$87 >> 2] | 0;
    _TT_Set_CodeRange($86, 3, $88, $5);
    $89 = HEAP32[$31 >> 2] | 0;
    $90 = $89 + 560 | 0;
    HEAP8[$90] = $is_composite;
    $91 = HEAP32[$31 >> 2] | 0;
    $92 = $91 + 144 | 0;
    $93 = $92;
    $94 = $1;
    _memcpy($93 | 0, $94 | 0, 36);
    $95 = HEAP32[$31 >> 2] | 0;
    $96 = _TT_Run_Context($95) | 0;
    $97 = ($96 | 0) == 0;
    if ($97) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $99 = HEAP32[$31 >> 2] | 0;
    $100 = $99 + 561 | 0;
    $101 = HEAP8[$100] | 0;
    $102 = $101 << 24 >> 24 == 0;
    if ($102) {
      label = 11;
      break;
    } else {
      $_0 = $96;
      label = 14;
      break;
    }
   case 11:
    $104 = HEAP32[$31 >> 2] | 0;
    $105 = $104 + 340 | 0;
    $106 = HEAP32[$105 >> 2] | 0;
    $107 = $106 << 5;
    $108 = HEAP8[$current_outline_sroa_1_8_copyload] | 0;
    $109 = $108 & 255;
    $110 = $107 | $109;
    $111 = $110 | 4;
    $112 = $111 & 255;
    HEAP8[$current_outline_sroa_1_8_copyload] = $112;
    label = 12;
    break;
   case 12:
    $114 = $loader + 65 | 0;
    $115 = HEAP8[$114] | 0;
    $116 = $115 << 24 >> 24 == 0;
    if ($116) {
      label = 13;
      break;
    } else {
      $_0 = 0;
      label = 14;
      break;
    }
   case 13:
    $118 = $loader + 68 | 0;
    $119 = HEAP16[$6 >> 1] | 0;
    $120 = $119 & 65535;
    $121 = $120 - 4 | 0;
    $122 = HEAP32[$10 >> 2] | 0;
    $123 = $122 + ($121 << 3) | 0;
    $124 = $123;
    $125 = $118;
    $ld$0$0 = $124 | 0;
    $126$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $124 + 4 | 0;
    $126$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $125 | 0;
    HEAP32[$st$2$0 >> 2] = $126$0;
    $st$3$1 = $125 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $126$1;
    $127 = $loader + 76 | 0;
    $128 = HEAP16[$6 >> 1] | 0;
    $129 = $128 & 65535;
    $130 = $129 - 3 | 0;
    $131 = HEAP32[$10 >> 2] | 0;
    $132 = $131 + ($130 << 3) | 0;
    $133 = $132;
    $134 = $127;
    $ld$4$0 = $133 | 0;
    $135$0 = HEAP32[$ld$4$0 >> 2] | 0;
    $ld$5$1 = $133 + 4 | 0;
    $135$1 = HEAP32[$ld$5$1 >> 2] | 0;
    $st$6$0 = $134 | 0;
    HEAP32[$st$6$0 >> 2] = $135$0;
    $st$7$1 = $134 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $135$1;
    $136 = $loader + 184 | 0;
    $137 = HEAP16[$6 >> 1] | 0;
    $138 = $137 & 65535;
    $139 = $138 - 2 | 0;
    $140 = HEAP32[$10 >> 2] | 0;
    $141 = $140 + ($139 << 3) | 0;
    $142 = $141;
    $143 = $136;
    $ld$8$0 = $142 | 0;
    $144$0 = HEAP32[$ld$8$0 >> 2] | 0;
    $ld$9$1 = $142 + 4 | 0;
    $144$1 = HEAP32[$ld$9$1 >> 2] | 0;
    $st$10$0 = $143 | 0;
    HEAP32[$st$10$0 >> 2] = $144$0;
    $st$11$1 = $143 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $144$1;
    $145 = $loader + 192 | 0;
    $146 = HEAP16[$6 >> 1] | 0;
    $147 = $146 & 65535;
    $148 = $147 - 1 | 0;
    $149 = HEAP32[$10 >> 2] | 0;
    $150 = $149 + ($148 << 3) | 0;
    $151 = $150;
    $152 = $145;
    $ld$12$0 = $151 | 0;
    $153$0 = HEAP32[$ld$12$0 >> 2] | 0;
    $ld$13$1 = $151 + 4 | 0;
    $153$1 = HEAP32[$ld$13$1 >> 2] | 0;
    $st$14$0 = $152 | 0;
    HEAP32[$st$14$0 >> 2] = $153$0;
    $st$15$1 = $152 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $153$1;
    $_0 = 0;
    label = 14;
    break;
   case 14:
    return $_0 | 0;
  }
  return 0;
}
function _TT_Run_Context($exec) {
  $exec = $exec | 0;
  var $4 = 0, $12 = 0, $16 = 0, $17 = 0, $20 = 0;
  _TT_Goto_CodeRange($exec, 3);
  $4 = $exec + 144 | 0;
  _memcpy($exec + 36 | 0, $4 | 0, 36);
  _memcpy($exec + 72 | 0, $4 | 0, 36);
  _memcpy($exec + 108 | 0, $4 | 0, 36);
  HEAP16[$exec + 344 >> 1] = 1;
  HEAP16[$exec + 346 >> 1] = 1;
  HEAP16[$exec + 348 >> 1] = 1;
  $12 = $exec + 294 | 0;
  HEAP16[$12 >> 1] = 16384;
  HEAP16[$exec + 296 >> 1] = 0;
  $16 = $12;
  $17 = $exec + 298 | 0;
  tempBigInt = HEAPU16[$16 >> 1] | HEAPU16[$16 + 2 >> 1] << 16;
  HEAP16[$17 >> 1] = tempBigInt & 65535;
  HEAP16[$17 + 2 >> 1] = tempBigInt >> 16;
  $20 = $exec + 290 | 0;
  tempBigInt = HEAPU16[$16 >> 1] | HEAPU16[$16 + 2 >> 1] << 16;
  HEAP16[$20 >> 1] = tempBigInt & 65535;
  HEAP16[$20 + 2 >> 1] = tempBigInt >> 16;
  HEAP32[$exec + 312 >> 2] = 1;
  HEAP32[$exec + 304 >> 2] = 1;
  HEAP32[$exec + 16 >> 2] = 0;
  HEAP32[$exec + 428 >> 2] = 0;
  return FUNCTION_TABLE_ii[HEAP32[(HEAP32[$exec >> 2] | 0) + 688 >> 2] & 1023]($exec) | 0;
}
function _tt_size_ready_bytecode($size) {
  $size = $size | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $i_035 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $i_133 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $i_231 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $error_1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size + 300 | 0;
    $2 = HEAP8[$1] | 0;
    $3 = $2 << 24 >> 24 == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $5 = $size | 0;
    $6 = _tt_size_init_bytecode($5) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 3;
      break;
    } else {
      $error_1 = $6;
      label = 15;
      break;
    }
   case 3:
    $9 = $size + 301 | 0;
    $10 = HEAP8[$9] | 0;
    $11 = $10 << 24 >> 24 == 0;
    if ($11) {
      label = 4;
      break;
    } else {
      $error_1 = 0;
      label = 15;
      break;
    }
   case 4:
    $13 = $size + 240 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $16 = $size | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $17 + 672 | 0;
    $19 = $18;
    $20 = $size + 88 | 0;
    $21 = $size + 244 | 0;
    $i_035 = 0;
    label = 8;
    break;
   case 6:
    $22 = $size + 264 | 0;
    $23 = HEAP16[$22 >> 1] | 0;
    $24 = $23 << 16 >> 16 == 0;
    if ($24) {
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $25 = $size + 268 | 0;
    $26 = $size + 272 | 0;
    $i_133 = 0;
    label = 11;
    break;
   case 8:
    $28 = HEAP32[$19 >> 2] | 0;
    $29 = $28 + ($i_035 << 1) | 0;
    $30 = HEAP16[$29 >> 1] | 0;
    $31 = $30 << 16 >> 16;
    $32 = HEAP32[$20 >> 2] | 0;
    $33 = _FT_MulFix($31, $32) | 0;
    $34 = HEAP32[$21 >> 2] | 0;
    $35 = $34 + ($i_035 << 2) | 0;
    HEAP32[$35 >> 2] = $33;
    $36 = $i_035 + 1 | 0;
    $37 = HEAP32[$13 >> 2] | 0;
    $38 = $36 >>> 0 < $37 >>> 0;
    if ($38) {
      $i_035 = $36;
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 9:
    $39 = $size + 248 | 0;
    $40 = HEAP16[$39 >> 1] | 0;
    $41 = $40 << 16 >> 16 == 0;
    if ($41) {
      label = 13;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $42 = $size + 252 | 0;
    $i_231 = 0;
    label = 12;
    break;
   case 11:
    $44 = HEAP32[$25 >> 2] | 0;
    $45 = $44 + ($i_133 << 3) | 0;
    HEAP32[$45 >> 2] = 0;
    $46 = HEAP32[$25 >> 2] | 0;
    $47 = $46 + ($i_133 << 3) + 4 | 0;
    HEAP32[$47 >> 2] = 0;
    $48 = HEAP32[$26 >> 2] | 0;
    $49 = $48 + ($i_133 << 3) | 0;
    HEAP32[$49 >> 2] = 0;
    $50 = HEAP32[$26 >> 2] | 0;
    $51 = $50 + ($i_133 << 3) + 4 | 0;
    HEAP32[$51 >> 2] = 0;
    $52 = $i_133 + 1 | 0;
    $53 = HEAP16[$22 >> 1] | 0;
    $54 = $53 & 65535;
    $55 = $52 >>> 0 < $54 >>> 0;
    if ($55) {
      $i_133 = $52;
      label = 11;
      break;
    } else {
      label = 9;
      break;
    }
   case 12:
    $57 = HEAP32[$42 >> 2] | 0;
    $58 = $57 + ($i_231 << 2) | 0;
    HEAP32[$58 >> 2] = 0;
    $59 = $i_231 + 1 | 0;
    $60 = HEAP16[$39 >> 1] | 0;
    $61 = $60 & 65535;
    $62 = $59 >>> 0 < $61 >>> 0;
    if ($62) {
      $i_231 = $59;
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $63 = $size + 172 | 0;
    $64 = $63;
    _memcpy($64 | 0, 5244304, 68);
    $65 = _tt_size_run_prep($size) | 0;
    $66 = ($65 | 0) == 0;
    if ($66) {
      label = 14;
      break;
    } else {
      $error_1 = $65;
      label = 15;
      break;
    }
   case 14:
    HEAP8[$9] = 1;
    $error_1 = 0;
    label = 15;
    break;
   case 15:
    return $error_1 | 0;
  }
  return 0;
}
function _TT_Load_Context($exec, $face, $size) {
  $exec = $exec | 0;
  $face = $face | 0;
  $size = $size | 0;
  var $tmp = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $ld$0$0 = 0, $41$0 = 0, $ld$1$1 = 0, $41$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $ld$4$0 = 0, $46$0 = 0, $ld$5$1 = 0, $46$1 = 0, $st$6$0 = 0, $st$7$1 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $ld$8$0 = 0, $51$0 = 0, $ld$9$1 = 0, $51$1 = 0, $st$10$0 = 0, $st$11$1 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $tmp = __stackBase__ | 0;
    $1 = $exec | 0;
    HEAP32[$1 >> 2] = $face;
    $2 = $exec + 4 | 0;
    HEAP32[$2 >> 2] = $size;
    $3 = ($size | 0) == 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $size + 116 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $exec + 396 | 0;
    HEAP32[$7 >> 2] = $6;
    $8 = $size + 120 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $exec + 400 | 0;
    HEAP32[$10 >> 2] = $9;
    $11 = $size + 128 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $exec + 408 | 0;
    HEAP32[$13 >> 2] = $12;
    $14 = $size + 132 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $exec + 412 | 0;
    HEAP32[$16 >> 2] = $15;
    $17 = $size + 124 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $exec + 404 | 0;
    HEAP32[$19 >> 2] = $18;
    $20 = $size + 136 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $exec + 416 | 0;
    HEAP32[$22 >> 2] = $21;
    $23 = $exec + 244 | 0;
    $24 = $size + 72 | 0;
    $25 = $23;
    $26 = $24;
    _memcpy($25 | 0, $26 | 0, 40);
    $27 = $exec + 216 | 0;
    $28 = $size + 44 | 0;
    $29 = $27;
    $30 = $28;
    _memcpy($29 | 0, $30 | 0, 28);
    $31 = $size + 140 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $exec + 420 | 0;
    HEAP32[$33 >> 2] = $32;
    $34 = $size + 144 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $exec + 424 | 0;
    HEAP32[$36 >> 2] = $35;
    $37 = $exec + 444 | 0;
    $38 = $size + 148 | 0;
    $39 = $38;
    $40 = $37;
    $ld$0$0 = $39 | 0;
    $41$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $39 + 4 | 0;
    $41$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $40 | 0;
    HEAP32[$st$2$0 >> 2] = $41$0;
    $st$3$1 = $40 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $41$1;
    $42 = $exec + 452 | 0;
    $43 = $size + 156 | 0;
    $44 = $43;
    $45 = $42;
    $ld$4$0 = $44 | 0;
    $46$0 = HEAP32[$ld$4$0 >> 2] | 0;
    $ld$5$1 = $44 + 4 | 0;
    $46$1 = HEAP32[$ld$5$1 >> 2] | 0;
    $st$6$0 = $45 | 0;
    HEAP32[$st$6$0 >> 2] = $46$0;
    $st$7$1 = $45 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $46$1;
    $47 = $exec + 460 | 0;
    $48 = $size + 164 | 0;
    $49 = $48;
    $50 = $47;
    $ld$8$0 = $49 | 0;
    $51$0 = HEAP32[$ld$8$0 >> 2] | 0;
    $ld$9$1 = $49 + 4 | 0;
    $51$1 = HEAP32[$ld$9$1 >> 2] | 0;
    $st$10$0 = $50 | 0;
    HEAP32[$st$10$0 >> 2] = $51$0;
    $st$11$1 = $50 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $51$1;
    $52 = $exec + 284 | 0;
    $53 = $size + 172 | 0;
    $54 = $52;
    $55 = $53;
    _memcpy($54 | 0, $55 | 0, 68);
    $56 = $size + 240 | 0;
    $57 = HEAP32[$56 >> 2] | 0;
    $58 = $exec + 380 | 0;
    HEAP32[$58 >> 2] = $57;
    $59 = $size + 244 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = $exec + 384 | 0;
    HEAP32[$61 >> 2] = $60;
    $62 = $size + 248 | 0;
    $63 = HEAP16[$62 >> 1] | 0;
    $64 = $exec + 468 | 0;
    HEAP16[$64 >> 1] = $63;
    $65 = $size + 252 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = $exec + 472 | 0;
    HEAP32[$67 >> 2] = $66;
    $68 = $exec + 180 | 0;
    $69 = $size + 256 | 0;
    $70 = $68;
    $71 = $69;
    _memcpy($70 | 0, $71 | 0, 36);
    $72 = $exec + 36 | 0;
    $73 = $72;
    _memset($73 | 0, 0, 36);
    $74 = $exec + 72 | 0;
    $75 = $74;
    _memcpy($75 | 0, $73 | 0, 36);
    $76 = $exec + 108 | 0;
    $77 = $76;
    _memcpy($77 | 0, $73 | 0, 36);
    label = 3;
    break;
   case 3:
    $79 = $exec + 20 | 0;
    $80 = HEAP32[$79 >> 2] | 0;
    HEAP32[$tmp >> 2] = $80;
    $81 = $exec + 8 | 0;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = $exec + 24 | 0;
    $84 = $83;
    $85 = $face + 284 | 0;
    $86 = HEAP16[$85 >> 1] | 0;
    $87 = $86 & 65535;
    $88 = $87 + 32 | 0;
    $89 = _Update_Max($82, $tmp, 4, $84, $88) | 0;
    $90 = HEAP32[$tmp >> 2] | 0;
    HEAP32[$79 >> 2] = $90;
    $91 = ($89 | 0) == 0;
    if ($91) {
      label = 4;
      break;
    } else {
      label = 6;
      break;
    }
   case 4:
    $93 = $exec + 388 | 0;
    $94 = HEAP32[$93 >> 2] | 0;
    HEAP32[$tmp >> 2] = $94;
    $95 = HEAP32[$81 >> 2] | 0;
    $96 = $exec + 392 | 0;
    $97 = $96;
    $98 = $face + 286 | 0;
    $99 = HEAP16[$98 >> 1] | 0;
    $100 = $99 & 65535;
    $101 = _Update_Max($95, $tmp, 1, $97, $100) | 0;
    $102 = HEAP32[$tmp >> 2] | 0;
    $103 = $102 & 65535;
    HEAP32[$93 >> 2] = $103;
    $104 = ($101 | 0) == 0;
    if ($104) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $106 = $exec + 144 | 0;
    $107 = $exec + 152 | 0;
    HEAP16[$107 >> 1] = 0;
    $108 = $exec + 154 | 0;
    HEAP16[$108 >> 1] = 0;
    $109 = $exec + 72 | 0;
    $110 = $109;
    $111 = $106;
    _memcpy($110 | 0, $111 | 0, 36);
    $112 = $exec + 108 | 0;
    $113 = $112;
    _memcpy($113 | 0, $111 | 0, 36);
    $114 = $exec + 36 | 0;
    $115 = $114;
    _memcpy($115 | 0, $111 | 0, 36);
    $116 = $exec + 488 | 0;
    HEAP8[$116] = 0;
    label = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
  }
}
function _tt_size_run_prep($size) {
  $size = $size | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $exec_0_in = 0, $exec_0 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $error_0 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    $4 = $size + 292 | 0;
    $5 = HEAP8[$4] | 0;
    $6 = $5 << 24 >> 24 == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $size + 296 | 0;
    $exec_0_in = $8;
    label = 4;
    break;
   case 3:
    $10 = $2 + 96 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 + 40 | 0;
    $13 = $12;
    $exec_0_in = $13;
    label = 4;
    break;
   case 4:
    $exec_0 = HEAP32[$exec_0_in >> 2] | 0;
    $15 = ($exec_0 | 0) == 0;
    if ($15) {
      $_0 = 153;
      label = 9;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    _TT_Load_Context($exec_0, $3, $size);
    $17 = $exec_0 + 428 | 0;
    HEAP32[$17 >> 2] = 0;
    $18 = $exec_0 + 16 | 0;
    HEAP32[$18 >> 2] = 0;
    $19 = $exec_0 + 488 | 0;
    HEAP8[$19] = 0;
    $20 = $2 + 664 | 0;
    $21 = $20;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $2 + 660 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    _TT_Set_CodeRange($exec_0, 2, $22, $24);
    _TT_Clear_CodeRange($exec_0, 3);
    $25 = HEAP32[$23 >> 2] | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      $error_0 = 0;
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    _TT_Goto_CodeRange($exec_0, 2);
    $28 = HEAP8[$4] | 0;
    $29 = $28 << 24 >> 24 == 0;
    if ($29) {
      label = 7;
      break;
    } else {
      $error_0 = 0;
      label = 8;
      break;
    }
   case 7:
    $31 = $2 + 688 | 0;
    $32 = $31;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $exec_0;
    $35 = FUNCTION_TABLE_ii[$33 & 1023]($34) | 0;
    $error_0 = $35;
    label = 8;
    break;
   case 8:
    $37 = $size + 172 | 0;
    $38 = $exec_0 + 284 | 0;
    $39 = $37;
    $40 = $38;
    _memcpy($39 | 0, $40 | 0, 68);
    _TT_Save_Context($exec_0, $size);
    $_0 = $error_0;
    label = 9;
    break;
   case 9:
    return $_0 | 0;
  }
  return 0;
}
function _tt_size_init_bytecode($ftsize) {
  $ftsize = $ftsize | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $_c = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $scevgep = 0, $scevgep50 = 0, $37 = 0, $38 = 0, $39 = 0, $_c44 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $_c46 = 0, $53 = 0, $54 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $_c47 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $_c48 = 0, $83 = 0, $storemerge = 0, $84 = 0, $85 = 0, $87 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $ftsize;
    $2 = $ftsize | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 + 100 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $3 + 260 | 0;
    $7 = $6;
    $8 = $ftsize + 300 | 0;
    $9 = $8;
    HEAP8[$9] = 1;
    $10 = $1 + 301 | 0;
    HEAP8[$10] = 0;
    $11 = $6 + 20 | 0;
    $12 = $11;
    $13 = HEAP16[$12 >> 1] | 0;
    $14 = $13 & 65535;
    $15 = $ftsize + 120 | 0;
    HEAP32[$15 >> 2] = $14;
    $16 = $7 + 22 | 0;
    $17 = HEAP16[$16 >> 1] | 0;
    $18 = $17 & 65535;
    $19 = $ftsize + 132 | 0;
    $20 = $19 | 0;
    $_c = $18;
    HEAP32[$20 >> 2] = $_c;
    $21 = $ftsize + 116 | 0;
    HEAP32[$21 >> 2] = 0;
    $22 = $ftsize + 128 | 0;
    HEAP32[$22 >> 2] = 0;
    $23 = $ftsize + 140 | 0;
    HEAP32[$23 >> 2] = 0;
    $24 = $ftsize + 144 | 0;
    $25 = $24;
    HEAP32[$25 >> 2] = 0;
    $26 = $3 + 668 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $ftsize + 240 | 0;
    HEAP32[$28 >> 2] = $27;
    $29 = $7 + 18 | 0;
    $30 = HEAP16[$29 >> 1] | 0;
    $31 = $ftsize + 248 | 0;
    $32 = $31;
    HEAP16[$32 >> 1] = $30;
    $33 = $ftsize + 72 | 0;
    $34 = $33;
    $35 = $34 + 37 | 0;
    HEAP8[$35] = 0;
    $36 = $34 + 38 | 0;
    HEAP8[$36] = 0;
    $scevgep = $ftsize + 92 | 0;
    $scevgep50 = $scevgep;
    _memset($scevgep50 | 0, 0, 16);
    $37 = HEAP32[$15 >> 2] | 0;
    $38 = _ft_mem_realloc($5, 16, 0, $37, 0, $error) | 0;
    $39 = $ftsize + 124 | 0;
    $_c44 = $38;
    HEAP32[$39 >> 2] = $_c44;
    $40 = HEAP32[$error >> 2] | 0;
    $41 = ($40 | 0) == 0;
    if ($41) {
      label = 2;
      break;
    } else {
      label = 7;
      break;
    }
   case 2:
    $43 = $19;
    $44 = HEAP32[$43 >> 2] | 0;
    $45 = _ft_mem_realloc($5, 16, 0, $44, 0, $error) | 0;
    $46 = $ftsize + 136 | 0;
    HEAP32[$46 >> 2] = $45;
    $47 = HEAP32[$error >> 2] | 0;
    $48 = ($47 | 0) == 0;
    if ($48) {
      label = 3;
      break;
    } else {
      label = 7;
      break;
    }
   case 3:
    $50 = HEAP32[$28 >> 2] | 0;
    $51 = _ft_mem_realloc($5, 4, 0, $50, 0, $error) | 0;
    $52 = $ftsize + 244 | 0;
    $_c46 = $51;
    HEAP32[$52 >> 2] = $_c46;
    $53 = HEAP32[$error >> 2] | 0;
    $54 = ($53 | 0) == 0;
    if ($54) {
      label = 4;
      break;
    } else {
      label = 7;
      break;
    }
   case 4:
    $56 = HEAP16[$32 >> 1] | 0;
    $57 = $56 & 65535;
    $58 = _ft_mem_realloc($5, 4, 0, $57, 0, $error) | 0;
    $59 = $ftsize + 252 | 0;
    $_c47 = $58;
    HEAP32[$59 >> 2] = $_c47;
    $60 = HEAP32[$error >> 2] | 0;
    $61 = ($60 | 0) == 0;
    if ($61) {
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    $63 = $6 + 16 | 0;
    $64 = $63;
    $65 = HEAP16[$64 >> 1] | 0;
    $66 = $65 + 4 & 65535;
    $67 = $ftsize + 256 | 0;
    $68 = $67;
    $69 = _tt_glyphzone_new($5, $66, $68) | 0;
    HEAP32[$error >> 2] = $69;
    $70 = ($69 | 0) == 0;
    if ($70) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $72 = $67 + 8 | 0;
    $73 = $72;
    HEAP16[$73 >> 1] = $66;
    $74 = $ftsize + 172 | 0;
    $75 = $74;
    _memcpy($75 | 0, 5244304, 68);
    $76 = $3 + 96 | 0;
    $77 = HEAP32[$76 >> 2] | 0;
    $78 = $77 + 4 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = $79 + 180 | 0;
    $81 = HEAP32[$80 >> 2] | 0;
    $82 = $3 + 688 | 0;
    $_c48 = $81;
    $83 = ($81 | 0) == 0;
    $storemerge = $83 ? 118 : $_c48;
    HEAP32[$82 >> 2] = $storemerge;
    $84 = _tt_size_run_fpgm($1) | 0;
    HEAP32[$error >> 2] = $84;
    $85 = ($84 | 0) == 0;
    if ($85) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    _tt_size_done_bytecode($ftsize);
    label = 8;
    break;
   case 8:
    $87 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $87 | 0;
  }
  return 0;
}
function _tt_glyphzone_new($memory, $maxPoints, $zone) {
  $memory = $memory | 0;
  $maxPoints = $maxPoints | 0;
  $zone = $zone | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $34 = 0, $35 = 0, $37 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $zone;
    _memset($1 | 0, 0, 36);
    $2 = $zone | 0;
    HEAP32[$2 >> 2] = $memory;
    $3 = $maxPoints & 65535;
    $4 = _ft_mem_realloc($memory, 8, 0, $3, 0, $error) | 0;
    $5 = $4;
    $6 = $zone + 12 | 0;
    HEAP32[$6 >> 2] = $5;
    $7 = HEAP32[$error >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $10 = _ft_mem_realloc($memory, 8, 0, $3, 0, $error) | 0;
    $11 = $10;
    $12 = $zone + 16 | 0;
    HEAP32[$12 >> 2] = $11;
    $13 = HEAP32[$error >> 2] | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 3:
    $16 = _ft_mem_realloc($memory, 8, 0, $3, 0, $error) | 0;
    $17 = $16;
    $18 = $zone + 20 | 0;
    HEAP32[$18 >> 2] = $17;
    $19 = HEAP32[$error >> 2] | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 4;
      break;
    } else {
      label = 6;
      break;
    }
   case 4:
    $22 = _ft_mem_realloc($memory, 1, 0, $3, 0, $error) | 0;
    $23 = $zone + 24 | 0;
    HEAP32[$23 >> 2] = $22;
    $24 = HEAP32[$error >> 2] | 0;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $27 = _ft_mem_realloc($memory, 2, 0, 0, 0, $error) | 0;
    $28 = $27;
    $29 = $zone + 28 | 0;
    HEAP32[$29 >> 2] = $28;
    $30 = HEAP32[$error >> 2] | 0;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    _tt_glyphzone_done($zone);
    label = 8;
    break;
   case 7:
    $34 = $zone + 4 | 0;
    HEAP16[$34 >> 1] = $maxPoints;
    $35 = $zone + 6 | 0;
    HEAP16[$35 >> 1] = 0;
    label = 8;
    break;
   case 8:
    $37 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $37 | 0;
  }
  return 0;
}
function _tt_size_run_fpgm($size) {
  $size = $size | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $exec_0_in = 0, $exec_0 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    $4 = $size + 292 | 0;
    $5 = HEAP8[$4] | 0;
    $6 = $5 << 24 >> 24 == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $size + 296 | 0;
    $exec_0_in = $8;
    label = 4;
    break;
   case 3:
    $10 = $2 + 96 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 + 40 | 0;
    $13 = $12;
    $exec_0_in = $13;
    label = 4;
    break;
   case 4:
    $exec_0 = HEAP32[$exec_0_in >> 2] | 0;
    $15 = ($exec_0 | 0) == 0;
    if ($15) {
      $_0 = 153;
      label = 8;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    _TT_Load_Context($exec_0, $3, $size);
    $17 = $exec_0 + 428 | 0;
    HEAP32[$17 >> 2] = 0;
    $18 = $exec_0 + 16 | 0;
    HEAP32[$18 >> 2] = 0;
    $19 = $exec_0 + 476 | 0;
    HEAP32[$19 >> 2] = 64;
    $20 = $exec_0 + 480 | 0;
    HEAP32[$20 >> 2] = 0;
    $21 = $exec_0 + 484 | 0;
    HEAP32[$21 >> 2] = 0;
    $22 = $exec_0 + 488 | 0;
    HEAP8[$22] = 0;
    $23 = $exec_0 + 564 | 0;
    HEAP32[$23 >> 2] = 65536;
    $24 = $exec_0 + 216 | 0;
    $25 = $exec_0 + 252 | 0;
    HEAP16[$25 >> 1] = 0;
    $26 = $exec_0 + 260 | 0;
    HEAP32[$26 >> 2] = 0;
    $27 = $exec_0 + 256 | 0;
    $28 = $24;
    _memset($28 | 0, 0, 12);
    HEAP32[$27 >> 2] = 65536;
    $29 = $2 + 656 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $30;
    $32 = $2 + 652 | 0;
    $33 = $32;
    $34 = HEAP32[$33 >> 2] | 0;
    _TT_Set_CodeRange($exec_0, 1, $31, $34);
    _TT_Clear_CodeRange($exec_0, 2);
    _TT_Clear_CodeRange($exec_0, 3);
    $35 = HEAP32[$33 >> 2] | 0;
    $36 = ($35 | 0) == 0;
    if ($36) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    _TT_Goto_CodeRange($exec_0, 1);
    $38 = $2 + 688 | 0;
    $39 = $38;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $exec_0;
    $42 = FUNCTION_TABLE_ii[$40 & 1023]($41) | 0;
    $43 = ($42 | 0) == 0;
    if ($43) {
      label = 7;
      break;
    } else {
      $_0 = $42;
      label = 8;
      break;
    }
   case 7:
    _TT_Save_Context($exec_0, $size);
    $_0 = 0;
    label = 8;
    break;
   case 8:
    return $_0 | 0;
  }
  return 0;
}
function _TT_Set_MM_Blend($face, $num_coords, $coords) {
  $face = $face | 0;
  $num_coords = $num_coords | 0;
  $coords = $coords | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $i_0 = 0, $18 = 0, $20 = 0, $21 = 0, $_off = 0, $22 = 0, $23 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $i_1 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $manageCvt_0 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $66 = 0, $67 = 0, $69 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 708 | 0;
    HEAP8[$3] = 0;
    $4 = $face + 712 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $8 = _TT_Get_MM_Var($face, 0) | 0;
    HEAP32[$error >> 2] = $8;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 3;
      break;
    } else {
      label = 18;
      break;
    }
   case 3:
    $11 = HEAP32[$4 >> 2] | 0;
    $12 = $11 + 8 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = ($15 | 0) == ($num_coords | 0);
    if ($16) {
      $i_0 = 0;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    HEAP32[$error >> 2] = 6;
    label = 18;
    break;
   case 5:
    $18 = $i_0 >>> 0 < $num_coords >>> 0;
    if ($18) {
      label = 6;
      break;
    } else {
      label = 8;
      break;
    }
   case 6:
    $20 = $coords + ($i_0 << 2) | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $_off = $21 + 65536 | 0;
    $22 = $_off >>> 0 > 131072;
    $23 = $i_0 + 1 | 0;
    if ($22) {
      label = 7;
      break;
    } else {
      $i_0 = $23;
      label = 5;
      break;
    }
   case 7:
    HEAP32[$error >> 2] = 6;
    label = 18;
    break;
   case 8:
    $26 = $11 + 36 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = ($27 | 0) == 0;
    if ($28) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $30 = _ft_var_load_gvar($face) | 0;
    HEAP32[$error >> 2] = $30;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 10;
      break;
    } else {
      label = 18;
      break;
    }
   case 10:
    $33 = $11 + 4 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = ($34 | 0) == 0;
    if ($35) {
      label = 11;
      break;
    } else {
      $i_1 = 0;
      label = 12;
      break;
    }
   case 11:
    $37 = _ft_mem_realloc($2, 4, 0, $num_coords, 0, $error) | 0;
    $38 = $37;
    HEAP32[$33 >> 2] = $38;
    $39 = HEAP32[$error >> 2] | 0;
    $40 = ($39 | 0) == 0;
    if ($40) {
      $manageCvt_0 = 1;
      label = 14;
      break;
    } else {
      label = 18;
      break;
    }
   case 12:
    $41 = $i_1 >>> 0 < $num_coords >>> 0;
    if ($41) {
      label = 13;
      break;
    } else {
      $manageCvt_0 = 0;
      label = 14;
      break;
    }
   case 13:
    $43 = HEAP32[$33 >> 2] | 0;
    $44 = $43 + ($i_1 << 2) | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = $coords + ($i_1 << 2) | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = ($45 | 0) == ($47 | 0);
    $49 = $i_1 + 1 | 0;
    if ($48) {
      $i_1 = $49;
      label = 12;
      break;
    } else {
      $manageCvt_0 = 2;
      label = 14;
      break;
    }
   case 14:
    $50 = $11 | 0;
    HEAP32[$50 >> 2] = $num_coords;
    $51 = HEAP32[$33 >> 2] | 0;
    $52 = $51;
    $53 = $coords;
    $54 = $num_coords << 2;
    _memcpy($52 | 0, $53 | 0, $54 | 0);
    HEAP8[$3] = 1;
    $55 = $face + 672 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = ($56 | 0) == 0;
    if ($57) {
      label = 18;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    if (($manageCvt_0 | 0) == 2) {
      label = 16;
      break;
    } else if (($manageCvt_0 | 0) == 1) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 16:
    $60 = $56;
    _ft_mem_free($2, $60);
    HEAP32[$55 >> 2] = 0;
    $61 = $face + 104 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = _tt_face_load_cvt($face, $62) | 0;
    label = 18;
    break;
   case 17:
    $65 = $face + 104 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = _tt_face_vary_cvt($face, $66) | 0;
    label = 18;
    break;
   case 18:
    $69 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $69 | 0;
  }
  return 0;
}
function _TT_Get_MM_Var($face, $master) {
  $face = $face | 0;
  $master = $master | 0;
  var $table_len = 0, $error = 0, $fvar_head = 0, $axis_rec = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $tmp98 = 0, $tmp99 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $smax = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $scevgep = 0, $next_coords_0129 = 0, $i_0128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $scevgep135 = 0, $next_coords_0_lcssa = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $next_name_0124 = 0, $i_1123 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $a_0119 = 0, $i_2118 = 0, $162 = 0, $163 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $ns_0114 = 0, $i_3113 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $210 = 0, $211 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $j_0108 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $240 = 0, $241 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $n_0104 = 0, $next_coords_1103 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $270 = 0, $271 = 0, $_pr = 0, $272 = 0, $next_coords_1_lcssa = 0, $273 = 0, $274 = 0, $275 = 0, $n_1102 = 0, $a_1101 = 0, $next_name_1100 = 0, $277 = 0, $278 = 0, $279 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $290 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 44 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $table_len = __stackBase__ | 0;
    $error = __stackBase__ + 4 | 0;
    $fvar_head = __stackBase__ + 8 | 0;
    $axis_rec = __stackBase__ + 24 | 0;
    $1 = $face + 104 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 100 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $5 = $face + 712 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 2;
      break;
    } else {
      label = 34;
      break;
    }
   case 2:
    $9 = $face + 508 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = FUNCTION_TABLE_iiiii[$10 & 1023]($face, 1735811442, $2, $table_len) | 0;
    HEAP32[$error >> 2] = $11;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 3;
      break;
    } else {
      label = 48;
      break;
    }
   case 3:
    $14 = HEAP32[$9 >> 2] | 0;
    $15 = FUNCTION_TABLE_iiiii[$14 & 1023]($face, 1719034226, $2, $table_len) | 0;
    HEAP32[$error >> 2] = $15;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 4;
      break;
    } else {
      label = 48;
      break;
    }
   case 4:
    $18 = _FT_Stream_Pos($2) | 0;
    $19 = $fvar_head;
    $20 = _FT_Stream_ReadFields($2, 5326808, $19) | 0;
    HEAP32[$error >> 2] = $20;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 5;
      break;
    } else {
      label = 48;
      break;
    }
   case 5:
    $23 = $fvar_head | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = ($24 | 0) == 65536;
    if ($25) {
      label = 6;
      break;
    } else {
      label = 12;
      break;
    }
   case 6:
    $27 = $fvar_head + 6 | 0;
    $28 = HEAP16[$27 >> 1] | 0;
    $29 = $28 << 16 >> 16 == 2;
    if ($29) {
      label = 7;
      break;
    } else {
      label = 12;
      break;
    }
   case 7:
    $31 = $fvar_head + 10 | 0;
    $32 = HEAP16[$31 >> 1] | 0;
    $33 = $32 << 16 >> 16 == 20;
    if ($33) {
      label = 8;
      break;
    } else {
      label = 12;
      break;
    }
   case 8:
    $35 = $fvar_head + 8 | 0;
    $36 = HEAP16[$35 >> 1] | 0;
    $37 = $36 & 65535;
    $38 = ($36 & 65535) > 16382;
    if ($38) {
      label = 12;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $40 = $fvar_head + 14 | 0;
    $41 = HEAP16[$40 >> 1] | 0;
    $42 = $41 & 65535;
    $43 = $37 << 2;
    $44 = $43 + 4 | 0;
    $45 = ($42 | 0) == ($44 | 0);
    if ($45) {
      label = 10;
      break;
    } else {
      label = 12;
      break;
    }
   case 10:
    $47 = $fvar_head + 12 | 0;
    $48 = HEAP16[$47 >> 1] | 0;
    $49 = ($48 & 65535) > 32511;
    if ($49) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $51 = $48 & 65535;
    $52 = $fvar_head + 4 | 0;
    $53 = HEAP16[$52 >> 1] | 0;
    $54 = $53 & 65535;
    $55 = $37 * 20 & -1;
    $56 = Math_imul($51, $42);
    $57 = $56 + $55 | 0;
    $58 = $57 + $54 | 0;
    $59 = HEAP32[$table_len >> 2] | 0;
    $60 = $58 >>> 0 > $59 >>> 0;
    if ($60) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    HEAP32[$error >> 2] = 8;
    label = 48;
    break;
   case 13:
    $63 = _ft_mem_alloc($4, 40, $error) | 0;
    $64 = $63;
    HEAP32[$5 >> 2] = $64;
    $65 = HEAP32[$error >> 2] | 0;
    $66 = ($65 | 0) == 0;
    if ($66) {
      label = 14;
      break;
    } else {
      label = 48;
      break;
    }
   case 14:
    $68 = HEAP16[$35 >> 1] | 0;
    $69 = $68 & 65535;
    $70 = HEAP16[$47 >> 1] | 0;
    $71 = $70 & 65535;
    $72 = $71 << 3;
    $73 = $71 << 2;
    $tmp98 = $73 + 29 | 0;
    $tmp99 = Math_imul($tmp98, $69);
    $74 = $72 + 20 | 0;
    $75 = $74 + $tmp99 | 0;
    $76 = $63 + 12 | 0;
    $77 = $76;
    HEAP32[$77 >> 2] = $75;
    $78 = HEAP32[$5 >> 2] | 0;
    $79 = $78 + 12 | 0;
    $80 = HEAP32[$79 >> 2] | 0;
    $81 = _ft_mem_alloc($4, $80, $error) | 0;
    $82 = HEAP32[$error >> 2] | 0;
    $83 = ($82 | 0) == 0;
    if ($83) {
      label = 15;
      break;
    } else {
      label = 48;
      break;
    }
   case 15:
    $85 = $81;
    $86 = HEAP32[$5 >> 2] | 0;
    $87 = $86 + 8 | 0;
    HEAP32[$87 >> 2] = $85;
    $88 = HEAP16[$35 >> 1] | 0;
    $89 = $88 & 65535;
    $90 = $81;
    HEAP32[$90 >> 2] = $89;
    $91 = $81 + 4 | 0;
    $92 = $91;
    HEAP32[$92 >> 2] = -1;
    $93 = HEAP16[$47 >> 1] | 0;
    $94 = $93 & 65535;
    $95 = $81 + 8 | 0;
    $96 = $95;
    HEAP32[$96 >> 2] = $94;
    $97 = $81 + 20 | 0;
    $98 = $97;
    $99 = $81 + 12 | 0;
    $100 = $99;
    HEAP32[$100 >> 2] = $98;
    $101 = HEAP16[$35 >> 1] | 0;
    $102 = $101 & 65535;
    $103 = $98 + ($102 * 24 & -1) | 0;
    $104 = $103;
    $105 = $81 + 16 | 0;
    $106 = $105;
    HEAP32[$106 >> 2] = $104;
    $107 = HEAP16[$47 >> 1] | 0;
    $108 = $107 & 65535;
    $109 = $104 + ($108 << 3) | 0;
    $110 = $109;
    $111 = $107 << 16 >> 16 == 0;
    if ($111) {
      $next_coords_0_lcssa = $110;
      label = 19;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $112 = HEAP16[$35 >> 1] | 0;
    $113 = $112 & 65535;
    $114 = HEAP16[$47 >> 1] | 0;
    $115 = $114 & 65535;
    $116 = $101 & 65535;
    $117 = $116 * 24 & -1;
    $118 = $107 & 65535;
    $119 = $118 << 3;
    $120 = $117 + $119 | 0;
    $121 = $114 & 65535;
    $122 = $121 >>> 0 > 1;
    $smax = $122 ? $121 : 1;
    $123 = $112 & 65535;
    $124 = Math_imul($smax, $123);
    $125 = $124 << 2;
    $126 = $120 + $125 | 0;
    $127 = $126 + 20 | 0;
    $scevgep = $81 + $127 | 0;
    $i_0128 = 0;
    $next_coords_0129 = $110;
    label = 17;
    break;
   case 17:
    $129 = HEAP32[$106 >> 2] | 0;
    $130 = $129 + ($i_0128 << 3) | 0;
    HEAP32[$130 >> 2] = $next_coords_0129;
    $131 = $next_coords_0129 + ($113 << 2) | 0;
    $132 = $i_0128 + 1 | 0;
    $133 = ($132 | 0) < ($115 | 0);
    if ($133) {
      $i_0128 = $132;
      $next_coords_0129 = $131;
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $scevgep135 = $scevgep;
    $next_coords_0_lcssa = $scevgep135;
    label = 19;
    break;
   case 19:
    $135 = HEAP16[$35 >> 1] | 0;
    $136 = $135 << 16 >> 16 == 0;
    if ($136) {
      label = 22;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $137 = $next_coords_0_lcssa;
    $138 = HEAP16[$35 >> 1] | 0;
    $139 = $138 & 65535;
    $i_1123 = 0;
    $next_name_0124 = $137;
    label = 21;
    break;
   case 21:
    $141 = HEAP32[$100 >> 2] | 0;
    $142 = $141 + ($i_1123 * 24 & -1) | 0;
    HEAP32[$142 >> 2] = $next_name_0124;
    $143 = $next_name_0124 + 5 | 0;
    $144 = $i_1123 + 1 | 0;
    $145 = ($144 | 0) < ($139 | 0);
    if ($145) {
      $i_1123 = $144;
      $next_name_0124 = $143;
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $146 = HEAP16[$52 >> 1] | 0;
    $147 = $146 & 65535;
    $148 = $147 + $18 | 0;
    $149 = _FT_Stream_Seek($2, $148) | 0;
    HEAP32[$error >> 2] = $149;
    $150 = ($149 | 0) == 0;
    if ($150) {
      label = 23;
      break;
    } else {
      label = 48;
      break;
    }
   case 23:
    $152 = HEAP16[$35 >> 1] | 0;
    $153 = $152 << 16 >> 16 == 0;
    if ($153) {
      label = 27;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $154 = HEAP32[$100 >> 2] | 0;
    $155 = $axis_rec;
    $156 = $axis_rec | 0;
    $157 = $axis_rec + 4 | 0;
    $158 = $axis_rec + 8 | 0;
    $159 = $axis_rec + 12 | 0;
    $160 = $axis_rec + 18 | 0;
    $i_2118 = 0;
    $a_0119 = $154;
    label = 25;
    break;
   case 25:
    $162 = _FT_Stream_ReadFields($2, 5326776, $155) | 0;
    HEAP32[$error >> 2] = $162;
    $163 = ($162 | 0) == 0;
    if ($163) {
      label = 26;
      break;
    } else {
      label = 48;
      break;
    }
   case 26:
    $165 = HEAP32[$156 >> 2] | 0;
    $166 = $a_0119 + 16 | 0;
    HEAP32[$166 >> 2] = $165;
    $167 = HEAP32[$157 >> 2] | 0;
    $168 = $a_0119 + 4 | 0;
    HEAP32[$168 >> 2] = $167;
    $169 = HEAP32[$158 >> 2] | 0;
    $170 = $a_0119 + 8 | 0;
    HEAP32[$170 >> 2] = $169;
    $171 = HEAP32[$159 >> 2] | 0;
    $172 = $a_0119 + 12 | 0;
    HEAP32[$172 >> 2] = $171;
    $173 = HEAP16[$160 >> 1] | 0;
    $174 = $173 & 65535;
    $175 = $a_0119 + 20 | 0;
    HEAP32[$175 >> 2] = $174;
    $176 = HEAP32[$166 >> 2] | 0;
    $177 = $176 >>> 24;
    $178 = $177 & 255;
    $179 = $a_0119 | 0;
    $180 = HEAP32[$179 >> 2] | 0;
    HEAP8[$180] = $178;
    $181 = HEAP32[$166 >> 2] | 0;
    $182 = $181 >>> 16;
    $183 = $182 & 255;
    $184 = HEAP32[$179 >> 2] | 0;
    $185 = $184 + 1 | 0;
    HEAP8[$185] = $183;
    $186 = HEAP32[$166 >> 2] | 0;
    $187 = $186 >>> 8;
    $188 = $187 & 255;
    $189 = HEAP32[$179 >> 2] | 0;
    $190 = $189 + 2 | 0;
    HEAP8[$190] = $188;
    $191 = HEAP32[$166 >> 2] | 0;
    $192 = $191 & 255;
    $193 = HEAP32[$179 >> 2] | 0;
    $194 = $193 + 3 | 0;
    HEAP8[$194] = $192;
    $195 = HEAP32[$179 >> 2] | 0;
    $196 = $195 + 4 | 0;
    HEAP8[$196] = 0;
    $197 = $a_0119 + 24 | 0;
    $198 = $i_2118 + 1 | 0;
    $199 = HEAP16[$35 >> 1] | 0;
    $200 = $199 & 65535;
    $201 = ($198 | 0) < ($200 | 0);
    if ($201) {
      $i_2118 = $198;
      $a_0119 = $197;
      label = 25;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $202 = HEAP16[$47 >> 1] | 0;
    $203 = $202 << 16 >> 16 == 0;
    if ($203) {
      label = 34;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $204 = HEAP32[$106 >> 2] | 0;
    $i_3113 = 0;
    $ns_0114 = $204;
    label = 29;
    break;
   case 29:
    $206 = HEAP16[$35 >> 1] | 0;
    $207 = $206 & 65535;
    $208 = $207 << 2;
    $209 = $208 + 4 | 0;
    $210 = _FT_Stream_EnterFrame($2, $209) | 0;
    HEAP32[$error >> 2] = $210;
    $211 = ($210 | 0) == 0;
    if ($211) {
      label = 30;
      break;
    } else {
      label = 48;
      break;
    }
   case 30:
    $213 = _FT_Stream_GetShort($2) | 0;
    $214 = $213 & 65535;
    $215 = $ns_0114 + 4 | 0;
    HEAP32[$215 >> 2] = $214;
    $216 = _FT_Stream_GetShort($2) | 0;
    $217 = HEAP16[$35 >> 1] | 0;
    $218 = $217 << 16 >> 16 == 0;
    if ($218) {
      label = 33;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    $219 = $ns_0114 | 0;
    $j_0108 = 0;
    label = 32;
    break;
   case 32:
    $221 = _FT_Stream_GetLong($2) | 0;
    $222 = HEAP32[$219 >> 2] | 0;
    $223 = $222 + ($j_0108 << 2) | 0;
    HEAP32[$223 >> 2] = $221;
    $224 = $j_0108 + 1 | 0;
    $225 = HEAP16[$35 >> 1] | 0;
    $226 = $225 & 65535;
    $227 = ($224 | 0) < ($226 | 0);
    if ($227) {
      $j_0108 = $224;
      label = 32;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    _FT_Stream_ExitFrame($2);
    $228 = $i_3113 + 1 | 0;
    $229 = $ns_0114 + 8 | 0;
    $230 = HEAP16[$47 >> 1] | 0;
    $231 = $230 & 65535;
    $232 = ($228 | 0) < ($231 | 0);
    if ($232) {
      $i_3113 = $228;
      $ns_0114 = $229;
      label = 29;
      break;
    } else {
      label = 34;
      break;
    }
   case 34:
    $233 = ($master | 0) == 0;
    if ($233) {
      label = 48;
      break;
    } else {
      label = 35;
      break;
    }
   case 35:
    $235 = HEAP32[$5 >> 2] | 0;
    $236 = $235 + 12 | 0;
    $237 = HEAP32[$236 >> 2] | 0;
    $238 = _ft_mem_alloc($4, $237, $error) | 0;
    $239 = $238;
    $240 = HEAP32[$error >> 2] | 0;
    $241 = ($240 | 0) == 0;
    if ($241) {
      label = 36;
      break;
    } else {
      label = 48;
      break;
    }
   case 36:
    $243 = HEAP32[$5 >> 2] | 0;
    $244 = $243 + 8 | 0;
    $245 = HEAP32[$244 >> 2] | 0;
    $246 = $245;
    $247 = $243 + 12 | 0;
    $248 = HEAP32[$247 >> 2] | 0;
    _memcpy($238 | 0, $246 | 0, $248 | 0);
    $249 = $238 + 20 | 0;
    $250 = $249;
    $251 = $238 + 12 | 0;
    $252 = $251;
    HEAP32[$252 >> 2] = $250;
    $253 = $238;
    $254 = HEAP32[$253 >> 2] | 0;
    $255 = $250 + ($254 * 24 & -1) | 0;
    $256 = $255;
    $257 = $238 + 16 | 0;
    $258 = $257;
    HEAP32[$258 >> 2] = $256;
    $259 = $238 + 8 | 0;
    $260 = $259;
    $261 = HEAP32[$260 >> 2] | 0;
    $262 = $256 + ($261 << 3) | 0;
    $263 = $262;
    $264 = ($261 | 0) == 0;
    if ($264) {
      label = 38;
      break;
    } else {
      $next_coords_1103 = $263;
      $n_0104 = 0;
      label = 37;
      break;
    }
   case 37:
    $265 = HEAP32[$258 >> 2] | 0;
    $266 = $265 + ($n_0104 << 3) | 0;
    HEAP32[$266 >> 2] = $next_coords_1103;
    $267 = HEAP32[$253 >> 2] | 0;
    $268 = $next_coords_1103 + ($267 << 2) | 0;
    $269 = $n_0104 + 1 | 0;
    $270 = HEAP32[$260 >> 2] | 0;
    $271 = $269 >>> 0 < $270 >>> 0;
    if ($271) {
      $next_coords_1103 = $268;
      $n_0104 = $269;
      label = 37;
      break;
    } else {
      $next_coords_1_lcssa = $268;
      $272 = $267;
      label = 39;
      break;
    }
   case 38:
    $_pr = HEAP32[$253 >> 2] | 0;
    $next_coords_1_lcssa = $263;
    $272 = $_pr;
    label = 39;
    break;
   case 39:
    $273 = ($272 | 0) == 0;
    if ($273) {
      label = 47;
      break;
    } else {
      label = 40;
      break;
    }
   case 40:
    $274 = $next_coords_1_lcssa;
    $275 = HEAP32[$252 >> 2] | 0;
    $next_name_1100 = $274;
    $a_1101 = $275;
    $n_1102 = 0;
    label = 41;
    break;
   case 41:
    $277 = $a_1101 | 0;
    HEAP32[$277 >> 2] = $next_name_1100;
    $278 = $a_1101 + 16 | 0;
    $279 = HEAP32[$278 >> 2] | 0;
    if (($279 | 0) == 2003265652) {
      label = 42;
      break;
    } else if (($279 | 0) == 2003072104) {
      label = 43;
      break;
    } else if (($279 | 0) == 1869640570) {
      label = 44;
      break;
    } else if (($279 | 0) == 1936486004) {
      label = 45;
      break;
    } else {
      label = 46;
      break;
    }
   case 42:
    HEAP32[$277 >> 2] = 5320116;
    label = 46;
    break;
   case 43:
    HEAP32[$277 >> 2] = 5319716;
    label = 46;
    break;
   case 44:
    HEAP32[$277 >> 2] = 5319412;
    label = 46;
    break;
   case 45:
    HEAP32[$277 >> 2] = 5324840;
    label = 46;
    break;
   case 46:
    $285 = $next_name_1100 + 5 | 0;
    $286 = $a_1101 + 24 | 0;
    $287 = $n_1102 + 1 | 0;
    $288 = HEAP32[$253 >> 2] | 0;
    $289 = $287 >>> 0 < $288 >>> 0;
    if ($289) {
      $next_name_1100 = $285;
      $a_1101 = $286;
      $n_1102 = $287;
      label = 41;
      break;
    } else {
      label = 47;
      break;
    }
   case 47:
    HEAP32[$master >> 2] = $239;
    label = 48;
    break;
   case 48:
    $290 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $290 | 0;
  }
  return 0;
}
function _T1_Driver_Init($driver) {
  $driver = $driver | 0;
  return 0;
}
function _T1_Driver_Done($driver) {
  $driver = $driver | 0;
  return;
}
function _TT_Set_Var_Design($face, $num_coords, $coords) {
  $face = $face | 0;
  $num_coords = $num_coords | 0;
  $coords = $coords | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $a_078 = 0, $i_077 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $av_076 = 0, $i_175 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $j_0 = 0, $78 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $normalized_0 = 0, $110 = 0, $111 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 712 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $7 = _TT_Get_MM_Var($face, 0) | 0;
    HEAP32[$error >> 2] = $7;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 3;
      break;
    } else {
      $normalized_0 = 0;
      label = 27;
      break;
    }
   case 3:
    $10 = HEAP32[$3 >> 2] | 0;
    $11 = $10 + 8 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($14 | 0) == ($num_coords | 0);
    if ($15) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    HEAP32[$error >> 2] = 6;
    $normalized_0 = 0;
    label = 27;
    break;
   case 5:
    $18 = _ft_mem_realloc($2, 4, 0, $14, 0, $error) | 0;
    $19 = $18;
    $20 = HEAP32[$error >> 2] | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 6;
      break;
    } else {
      $normalized_0 = $19;
      label = 27;
      break;
    }
   case 6:
    $23 = HEAP32[$13 >> 2] | 0;
    $24 = ($23 | 0) == 0;
    if ($24) {
      label = 17;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $25 = $12 + 12 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $i_077 = 0;
    $a_078 = $26;
    label = 8;
    break;
   case 8:
    $28 = $coords + ($i_077 << 2) | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $a_078 + 12 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = ($29 | 0) > ($31 | 0);
    if ($32) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $34 = $a_078 + 4 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = ($29 | 0) < ($35 | 0);
    if ($36) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    HEAP32[$error >> 2] = 6;
    $normalized_0 = $19;
    label = 27;
    break;
   case 11:
    $39 = $a_078 + 8 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = ($29 | 0) < ($40 | 0);
    if ($41) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $43 = $29 - $40 | 0;
    $44 = $35 - $40 | 0;
    $45 = _FT_MulDiv($43, 65536, $44) | 0;
    $46 = -$45 | 0;
    $47 = $19 + ($i_077 << 2) | 0;
    HEAP32[$47 >> 2] = $46;
    label = 16;
    break;
   case 13:
    $49 = ($31 | 0) == ($40 | 0);
    if ($49) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $51 = $19 + ($i_077 << 2) | 0;
    HEAP32[$51 >> 2] = 0;
    label = 16;
    break;
   case 15:
    $53 = $29 - $40 | 0;
    $54 = $31 - $40 | 0;
    $55 = _FT_MulDiv($53, 65536, $54) | 0;
    $56 = $19 + ($i_077 << 2) | 0;
    HEAP32[$56 >> 2] = $55;
    label = 16;
    break;
   case 16:
    $58 = $i_077 + 1 | 0;
    $59 = $a_078 + 24 | 0;
    $60 = HEAP32[$13 >> 2] | 0;
    $61 = $58 >>> 0 < $60 >>> 0;
    if ($61) {
      $i_077 = $58;
      $a_078 = $59;
      label = 8;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $62 = $10 + 16 | 0;
    $63 = HEAP8[$62] | 0;
    $64 = $63 << 24 >> 24 == 0;
    if ($64) {
      label = 18;
      break;
    } else {
      label = 19;
      break;
    }
   case 18:
    _ft_var_load_avar($face);
    label = 19;
    break;
   case 19:
    $67 = $10 + 20 | 0;
    $68 = HEAP32[$67 >> 2] | 0;
    $69 = ($68 | 0) == 0;
    if ($69) {
      label = 26;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $70 = HEAP32[$13 >> 2] | 0;
    $71 = ($70 | 0) == 0;
    if ($71) {
      label = 26;
      break;
    } else {
      $i_175 = 0;
      $av_076 = $68;
      label = 21;
      break;
    }
   case 21:
    $72 = $av_076 | 0;
    $73 = HEAP16[$72 >> 1] | 0;
    $74 = $73 & 65535;
    $75 = $19 + ($i_175 << 2) | 0;
    $76 = $av_076 + 4 | 0;
    $j_0 = 1;
    label = 22;
    break;
   case 22:
    $78 = $j_0 >>> 0 < $74 >>> 0;
    if ($78) {
      label = 23;
      break;
    } else {
      label = 25;
      break;
    }
   case 23:
    $80 = HEAP32[$75 >> 2] | 0;
    $81 = HEAP32[$76 >> 2] | 0;
    $82 = $81 + ($j_0 << 3) | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = ($80 | 0) < ($83 | 0);
    $85 = $j_0 + 1 | 0;
    if ($84) {
      label = 24;
      break;
    } else {
      $j_0 = $85;
      label = 22;
      break;
    }
   case 24:
    $87 = $j_0 - 1 | 0;
    $88 = $81 + ($87 << 3) | 0;
    $89 = HEAP32[$88 >> 2] | 0;
    $90 = $80 - $89 | 0;
    $91 = $83 - $89 | 0;
    $92 = _FT_MulDiv($90, 65536, $91) | 0;
    $93 = HEAP32[$76 >> 2] | 0;
    $94 = $93 + ($j_0 << 3) + 4 | 0;
    $95 = HEAP32[$94 >> 2] | 0;
    $96 = $93 + ($87 << 3) + 4 | 0;
    $97 = HEAP32[$96 >> 2] | 0;
    $98 = $95 - $97 | 0;
    $99 = _FT_MulDiv($92, $98, 65536) | 0;
    $100 = HEAP32[$76 >> 2] | 0;
    $101 = $100 + ($87 << 3) + 4 | 0;
    $102 = HEAP32[$101 >> 2] | 0;
    $103 = $102 + $99 | 0;
    HEAP32[$75 >> 2] = $103;
    label = 25;
    break;
   case 25:
    $104 = $i_175 + 1 | 0;
    $105 = $av_076 + 8 | 0;
    $106 = HEAP32[$13 >> 2] | 0;
    $107 = $104 >>> 0 < $106 >>> 0;
    if ($107) {
      $i_175 = $104;
      $av_076 = $105;
      label = 21;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $108 = _TT_Set_MM_Blend($face, $num_coords, $19) | 0;
    HEAP32[$error >> 2] = $108;
    $normalized_0 = $19;
    label = 27;
    break;
   case 27:
    $110 = $normalized_0;
    _ft_mem_free($2, $110);
    $111 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $111 | 0;
  }
  return 0;
}
function _ft_var_load_avar($face) {
  $face = $face | 0;
  var $error = 0, $table_len = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $or_cond = 0, $i_048 = 0, $segment_047 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $j_040_in = 0, $j_040 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $_lcssa = 0, $53 = 0, $j_142 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $table_len = __stackBase__ + 4 | 0;
    $1 = $face + 104 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 28 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $face + 712 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + 16 | 0;
    HEAP8[$7] = 1;
    $8 = $face + 508 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = FUNCTION_TABLE_iiiii[$9 & 1023]($face, 1635148146, $2, $table_len) | 0;
    HEAP32[$error >> 2] = $10;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 2;
      break;
    } else {
      label = 14;
      break;
    }
   case 2:
    $13 = HEAP32[$table_len >> 2] | 0;
    $14 = _FT_Stream_EnterFrame($2, $13) | 0;
    HEAP32[$error >> 2] = $14;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 3;
      break;
    } else {
      label = 14;
      break;
    }
   case 3:
    $17 = _FT_Stream_GetLong($2) | 0;
    $18 = _FT_Stream_GetLong($2) | 0;
    $19 = ($17 | 0) == 65536;
    if ($19) {
      label = 4;
      break;
    } else {
      label = 13;
      break;
    }
   case 4:
    $21 = $6 + 8 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = ($18 | 0) == ($24 | 0);
    if ($25) {
      label = 5;
      break;
    } else {
      label = 13;
      break;
    }
   case 5:
    $27 = _ft_mem_realloc($4, 8, 0, $18, 0, $error) | 0;
    $28 = $27;
    $29 = $6 + 20 | 0;
    HEAP32[$29 >> 2] = $28;
    $30 = HEAP32[$error >> 2] | 0;
    $31 = ($30 | 0) == 0;
    $32 = ($18 | 0) > 0;
    $or_cond = $31 & $32;
    if ($or_cond) {
      $segment_047 = $28;
      $i_048 = 0;
      label = 6;
      break;
    } else {
      label = 13;
      break;
    }
   case 6:
    $33 = _FT_Stream_GetShort($2) | 0;
    $34 = $segment_047 | 0;
    HEAP16[$34 >> 1] = $33;
    $35 = $33 & 65535;
    $36 = _ft_mem_realloc($4, 8, 0, $35, 0, $error) | 0;
    $37 = $36;
    $38 = $segment_047 + 4 | 0;
    HEAP32[$38 >> 2] = $37;
    $39 = HEAP32[$error >> 2] | 0;
    $40 = ($39 | 0) == 0;
    if ($40) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $41 = HEAP16[$34 >> 1] | 0;
    $42 = $41 << 16 >> 16 == 0;
    if ($42) {
      label = 12;
      break;
    } else {
      $j_142 = 0;
      label = 11;
      break;
    }
   case 8:
    $43 = ($i_048 | 0) > 0;
    $44 = HEAP32[$29 >> 2] | 0;
    if ($43) {
      $j_040_in = $i_048;
      $45 = $44;
      label = 9;
      break;
    } else {
      $_lcssa = $44;
      label = 10;
      break;
    }
   case 9:
    $j_040 = $j_040_in - 1 | 0;
    $46 = $45 + ($j_040 << 3) + 4 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $47;
    _ft_mem_free($4, $48);
    $49 = HEAP32[$29 >> 2] | 0;
    $50 = $49 + ($j_040 << 3) + 4 | 0;
    HEAP32[$50 >> 2] = 0;
    $51 = ($j_040 | 0) > 0;
    $52 = HEAP32[$29 >> 2] | 0;
    if ($51) {
      $j_040_in = $j_040;
      $45 = $52;
      label = 9;
      break;
    } else {
      $_lcssa = $52;
      label = 10;
      break;
    }
   case 10:
    $53 = $_lcssa;
    _ft_mem_free($4, $53);
    HEAP32[$29 >> 2] = 0;
    label = 13;
    break;
   case 11:
    $54 = _FT_Stream_GetShort($2) | 0;
    $55 = $54 << 16 >> 16;
    $56 = $55 << 2;
    $57 = HEAP32[$38 >> 2] | 0;
    $58 = $57 + ($j_142 << 3) | 0;
    HEAP32[$58 >> 2] = $56;
    $59 = _FT_Stream_GetShort($2) | 0;
    $60 = $59 << 16 >> 16;
    $61 = $60 << 2;
    $62 = HEAP32[$38 >> 2] | 0;
    $63 = $62 + ($j_142 << 3) + 4 | 0;
    HEAP32[$63 >> 2] = $61;
    $64 = $j_142 + 1 | 0;
    $65 = HEAP16[$34 >> 1] | 0;
    $66 = $65 & 65535;
    $67 = ($64 | 0) < ($66 | 0);
    if ($67) {
      $j_142 = $64;
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $68 = $i_048 + 1 | 0;
    $69 = $segment_047 + 8 | 0;
    $70 = ($68 | 0) < ($18 | 0);
    if ($70) {
      $segment_047 = $69;
      $i_048 = $68;
      label = 6;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    _FT_Stream_ExitFrame($2);
    label = 14;
    break;
   case 14:
    STACKTOP = __stackBase__;
    return;
  }
}
function _ft_var_load_gvar($face) {
  $face = $face | 0;
  var $error = 0, $table_len = 0, $gvar_head = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $56 = 0, $57 = 0, $58 = 0, $i_051 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $68 = 0, $69 = 0, $70 = 0, $i_149 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $82 = 0, $83 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $i_246 = 0, $113 = 0, $j_044 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $exitcond = 0, $122 = 0, $123 = 0, $124 = 0, $126 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 28 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $table_len = __stackBase__ + 4 | 0;
    $gvar_head = __stackBase__ + 8 | 0;
    $1 = $face + 104 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 28 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $face + 712 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $face + 508 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = FUNCTION_TABLE_iiiii[$8 & 1023]($face, 1735811442, $2, $table_len) | 0;
    HEAP32[$error >> 2] = $9;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 2;
      break;
    } else {
      label = 25;
      break;
    }
   case 2:
    $12 = _FT_Stream_Pos($2) | 0;
    $13 = $gvar_head;
    $14 = _FT_Stream_ReadFields($2, 5251372, $13) | 0;
    HEAP32[$error >> 2] = $14;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 3;
      break;
    } else {
      label = 25;
      break;
    }
   case 3:
    $17 = $gvar_head + 6 | 0;
    $18 = HEAP16[$17 >> 1] | 0;
    $19 = $18 & 65535;
    $20 = $6 + 24 | 0;
    HEAP32[$20 >> 2] = $19;
    $21 = $gvar_head + 12 | 0;
    $22 = HEAP16[$21 >> 1] | 0;
    $23 = $22 & 65535;
    $24 = $6 + 32 | 0;
    HEAP32[$24 >> 2] = $23;
    $25 = $gvar_head + 16 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $26 + $12 | 0;
    $28 = $gvar_head | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = ($29 | 0) == 65536;
    if ($30) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $32 = $gvar_head + 4 | 0;
    $33 = HEAP16[$32 >> 1] | 0;
    $34 = $6 + 8 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $35 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $37 & 65535;
    $39 = $33 << 16 >> 16 == $38 << 16 >> 16;
    if ($39) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    HEAP32[$error >> 2] = 8;
    label = 25;
    break;
   case 6:
    $42 = $23 + 1 | 0;
    $43 = _ft_mem_realloc($4, 4, 0, $42, 0, $error) | 0;
    $44 = $43;
    $45 = $6 + 36 | 0;
    HEAP32[$45 >> 2] = $44;
    $46 = HEAP32[$error >> 2] | 0;
    $47 = ($46 | 0) == 0;
    if ($47) {
      label = 7;
      break;
    } else {
      label = 25;
      break;
    }
   case 7:
    $49 = $gvar_head + 14 | 0;
    $50 = HEAP16[$49 >> 1] | 0;
    $51 = $50 & 1;
    $52 = $51 << 16 >> 16 == 0;
    $53 = HEAP32[$24 >> 2] | 0;
    $54 = $53 + 1 | 0;
    if ($52) {
      label = 11;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $56 = $54 << 2;
    $57 = _FT_Stream_EnterFrame($2, $56) | 0;
    HEAP32[$error >> 2] = $57;
    $58 = ($57 | 0) == 0;
    if ($58) {
      $i_051 = 0;
      label = 9;
      break;
    } else {
      label = 25;
      break;
    }
   case 9:
    $59 = _FT_Stream_GetLong($2) | 0;
    $60 = $59 + $27 | 0;
    $61 = HEAP32[$45 >> 2] | 0;
    $62 = $61 + ($i_051 << 2) | 0;
    HEAP32[$62 >> 2] = $60;
    $63 = $i_051 + 1 | 0;
    $64 = HEAP32[$24 >> 2] | 0;
    $65 = $63 >>> 0 > $64 >>> 0;
    if ($65) {
      label = 10;
      break;
    } else {
      $i_051 = $63;
      label = 9;
      break;
    }
   case 10:
    _FT_Stream_ExitFrame($2);
    label = 14;
    break;
   case 11:
    $68 = $54 << 1;
    $69 = _FT_Stream_EnterFrame($2, $68) | 0;
    HEAP32[$error >> 2] = $69;
    $70 = ($69 | 0) == 0;
    if ($70) {
      $i_149 = 0;
      label = 12;
      break;
    } else {
      label = 25;
      break;
    }
   case 12:
    $71 = _FT_Stream_GetShort($2) | 0;
    $72 = $71 & 65535;
    $73 = $72 << 1;
    $74 = $73 + $27 | 0;
    $75 = HEAP32[$45 >> 2] | 0;
    $76 = $75 + ($i_149 << 2) | 0;
    HEAP32[$76 >> 2] = $74;
    $77 = $i_149 + 1 | 0;
    $78 = HEAP32[$24 >> 2] | 0;
    $79 = $77 >>> 0 > $78 >>> 0;
    if ($79) {
      label = 13;
      break;
    } else {
      $i_149 = $77;
      label = 12;
      break;
    }
   case 13:
    _FT_Stream_ExitFrame($2);
    label = 14;
    break;
   case 14:
    $82 = HEAP32[$20 >> 2] | 0;
    $83 = ($82 | 0) == 0;
    if ($83) {
      label = 25;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $85 = HEAP16[$32 >> 1] | 0;
    $86 = $85 & 65535;
    $87 = Math_imul($86, $82);
    $88 = _ft_mem_realloc($4, 4, 0, $87, 0, $error) | 0;
    $89 = $88;
    $90 = $6 + 28 | 0;
    HEAP32[$90 >> 2] = $89;
    $91 = HEAP32[$error >> 2] | 0;
    $92 = ($91 | 0) == 0;
    if ($92) {
      label = 16;
      break;
    } else {
      label = 25;
      break;
    }
   case 16:
    $94 = $gvar_head + 8 | 0;
    $95 = HEAP32[$94 >> 2] | 0;
    $96 = $95 + $12 | 0;
    $97 = _FT_Stream_Seek($2, $96) | 0;
    HEAP32[$error >> 2] = $97;
    $98 = ($97 | 0) == 0;
    if ($98) {
      label = 17;
      break;
    } else {
      label = 25;
      break;
    }
   case 17:
    $100 = HEAP32[$20 >> 2] | 0;
    $101 = HEAP16[$32 >> 1] | 0;
    $102 = $101 & 65535;
    $103 = $100 << 1;
    $104 = Math_imul($103, $102);
    $105 = _FT_Stream_EnterFrame($2, $104) | 0;
    HEAP32[$error >> 2] = $105;
    $106 = ($105 | 0) == 0;
    if ($106) {
      label = 18;
      break;
    } else {
      label = 25;
      break;
    }
   case 18:
    $107 = HEAP32[$20 >> 2] | 0;
    $108 = ($107 | 0) == 0;
    if ($108) {
      label = 24;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $109 = HEAP16[$32 >> 1] | 0;
    $110 = $109 << 16 >> 16 == 0;
    $111 = $109 & 65535;
    $112 = $109 & 65535;
    $i_246 = 0;
    label = 20;
    break;
   case 20:
    if ($110) {
      label = 23;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $113 = Math_imul($111, $i_246);
    $j_044 = 0;
    label = 22;
    break;
   case 22:
    $115 = _FT_Stream_GetShort($2) | 0;
    $116 = $115 << 16 >> 16;
    $117 = $116 << 2;
    $118 = $113 + $j_044 | 0;
    $119 = HEAP32[$90 >> 2] | 0;
    $120 = $119 + ($118 << 2) | 0;
    HEAP32[$120 >> 2] = $117;
    $121 = $j_044 + 1 | 0;
    $exitcond = ($121 | 0) == ($112 | 0);
    if ($exitcond) {
      label = 23;
      break;
    } else {
      $j_044 = $121;
      label = 22;
      break;
    }
   case 23:
    $122 = $i_246 + 1 | 0;
    $123 = HEAP32[$20 >> 2] | 0;
    $124 = $122 >>> 0 < $123 >>> 0;
    if ($124) {
      $i_246 = $122;
      label = 20;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    _FT_Stream_ExitFrame($2);
    label = 25;
    break;
   case 25:
    $126 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $126 | 0;
  }
  return 0;
}
function _Get_Interface($driver, $t1_interface) {
  $driver = $driver | 0;
  $t1_interface = $t1_interface | 0;
  return _ft_service_list_lookup(5246644, $t1_interface) | 0;
}
function _T1_Face_Init($stream, $face, $face_index, $num_params, $params) {
  $stream = $stream | 0;
  $face = $face | 0;
  $face_index = $face_index | 0;
  $num_params = $num_params | 0;
  $params = $params | 0;
  var $max_advance = 0, $charmap = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $or_cond105 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $full_0_ph115 = 0, $family_0_ph114 = 0, $56 = 0, $58 = 0, $full_0112 = 0, $59 = 0, $61 = 0, $full_0_ph_be = 0, $family_0_ph_be = 0, $62 = 0, $63 = 0, $66 = 0, $67 = 0, $68 = 0, $71 = 0, $72 = 0, $73 = 0, $_pr = 0, $76 = 0, $77 = 0, $79 = 0, $80 = 0, $81 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $91 = 0, $92 = 0, $93 = 0, $95 = 0, $96 = 0, $98 = 0, $99 = 0, $101 = 0, $102 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $sext = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $149 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $or_cond107 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $186 = 0, $187 = 0, $189 = 0, $191 = 0, $193 = 0, $clazz_0_in = 0, $clazz_0 = 0, $196 = 0, $198 = 0, $199 = 0, $error_1 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $max_advance = __stackBase__ | 0;
    $charmap = __stackBase__ + 4 | 0;
    $1 = $face | 0;
    $2 = $face | 0;
    HEAP32[$2 >> 2] = 1;
    $3 = $face + 96 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4;
    $6 = _ft_module_get_service($5, 5323452) | 0;
    $7 = $face + 484 | 0;
    HEAP32[$7 >> 2] = $6;
    $8 = HEAP32[$3 >> 2] | 0;
    $9 = $8 + 4 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10;
    $12 = _FT_Get_Module_Interface($11, 5322628) | 0;
    $13 = $face + 488 | 0;
    HEAP32[$13 >> 2] = $12;
    $14 = HEAP32[$3 >> 2] | 0;
    $15 = $14 + 4 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $16;
    $18 = _FT_Get_Module_Interface($17, 5324472) | 0;
    $19 = $face + 552 | 0;
    HEAP32[$19 >> 2] = $18;
    $20 = _T1_Open_Face($face) | 0;
    $21 = ($20 | 0) != 0;
    $22 = ($face_index | 0) < 0;
    $or_cond105 = $21 | $22;
    if ($or_cond105) {
      $error_1 = $20;
      label = 47;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $24 = ($face_index | 0) > 0;
    if ($24) {
      $error_1 = 6;
      label = 47;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $26 = $face + 416 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $face + 16 | 0;
    HEAP32[$28 >> 2] = $27;
    $29 = $face + 4 | 0;
    HEAP32[$29 >> 2] = 0;
    $30 = $face + 8 | 0;
    HEAP32[$30 >> 2] = 2577;
    $31 = $face + 156 | 0;
    $32 = HEAP8[$31] | 0;
    $33 = $32 << 24 >> 24 == 0;
    if ($33) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    HEAP32[$30 >> 2] = 2581;
    label = 5;
    break;
   case 5:
    $36 = $face + 532 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = ($37 | 0) == 0;
    if ($38) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $40 = HEAP32[$30 >> 2] | 0;
    $41 = $40 | 256;
    HEAP32[$30 >> 2] = $41;
    label = 7;
    break;
   case 7:
    $43 = $face + 144 | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    $45 = $face + 20 | 0;
    HEAP32[$45 >> 2] = $44;
    $46 = $face + 24 | 0;
    HEAP32[$46 >> 2] = 0;
    $47 = HEAP32[$45 >> 2] | 0;
    $48 = ($47 | 0) == 0;
    if ($48) {
      label = 19;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $50 = $face + 140 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = ($51 | 0) == 0;
    if ($52) {
      label = 21;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $53 = HEAP8[$51] | 0;
    $54 = $53 << 24 >> 24 == 0;
    if ($54) {
      label = 18;
      break;
    } else {
      $family_0_ph114 = $47;
      $full_0_ph115 = $51;
      $55 = $53;
      label = 10;
      break;
    }
   case 10:
    $56 = HEAP8[$family_0_ph114] | 0;
    $full_0112 = $full_0_ph115;
    $58 = $55;
    label = 11;
    break;
   case 11:
    $59 = $58 << 24 >> 24 == $56 << 24 >> 24;
    if ($59) {
      label = 12;
      break;
    } else {
      label = 14;
      break;
    }
   case 12:
    $61 = $full_0112 + 1 | 0;
    $full_0_ph_be = $61;
    label = 13;
    break;
   case 13:
    $family_0_ph_be = $family_0_ph114 + 1 | 0;
    $62 = HEAP8[$full_0_ph_be] | 0;
    $63 = $62 << 24 >> 24 == 0;
    if ($63) {
      label = 18;
      break;
    } else {
      $family_0_ph114 = $family_0_ph_be;
      $full_0_ph115 = $full_0_ph_be;
      $55 = $62;
      label = 10;
      break;
    }
   case 14:
    if (($58 << 24 >> 24 | 0) == 32 | ($58 << 24 >> 24 | 0) == 45) {
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 15:
    $66 = $full_0112 + 1 | 0;
    $67 = HEAP8[$66] | 0;
    $68 = $67 << 24 >> 24 == 0;
    if ($68) {
      label = 18;
      break;
    } else {
      $full_0112 = $66;
      $58 = $67;
      label = 11;
      break;
    }
   case 16:
    if (($56 << 24 >> 24 | 0) == 32 | ($56 << 24 >> 24 | 0) == 45) {
      $full_0_ph_be = $full_0112;
      label = 13;
      break;
    } else if (($56 << 24 >> 24 | 0) == 0) {
      label = 17;
      break;
    } else {
      label = 21;
      break;
    }
   case 17:
    HEAP32[$46 >> 2] = $full_0112;
    $76 = $full_0112;
    label = 22;
    break;
   case 18:
    HEAP32[$46 >> 2] = 5321980;
    label = 26;
    break;
   case 19:
    $71 = $face + 364 | 0;
    $72 = HEAP32[$71 >> 2] | 0;
    $73 = ($72 | 0) == 0;
    if ($73) {
      label = 21;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    HEAP32[$45 >> 2] = $72;
    label = 21;
    break;
   case 21:
    $_pr = HEAP32[$46 >> 2] | 0;
    $76 = $_pr;
    label = 22;
    break;
   case 22:
    $77 = ($76 | 0) == 0;
    if ($77) {
      label = 23;
      break;
    } else {
      label = 26;
      break;
    }
   case 23:
    $79 = $face + 148 | 0;
    $80 = HEAP32[$79 >> 2] | 0;
    $81 = ($80 | 0) == 0;
    if ($81) {
      label = 25;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    HEAP32[$46 >> 2] = $80;
    label = 26;
    break;
   case 25:
    HEAP32[$46 >> 2] = 5321980;
    label = 26;
    break;
   case 26:
    $85 = $face + 12 | 0;
    HEAP32[$85 >> 2] = 0;
    $86 = $face + 152 | 0;
    $87 = HEAP32[$86 >> 2] | 0;
    $88 = ($87 | 0) == 0;
    if ($88) {
      label = 28;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    HEAP32[$85 >> 2] = 1;
    label = 28;
    break;
   case 28:
    $91 = $face + 148 | 0;
    $92 = HEAP32[$91 >> 2] | 0;
    $93 = ($92 | 0) == 0;
    if ($93) {
      label = 32;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    $95 = _strcmp($92 | 0, 5321328) | 0;
    $96 = ($95 | 0) == 0;
    if ($96) {
      label = 31;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    $98 = _strcmp($92 | 0, 5320624) | 0;
    $99 = ($98 | 0) == 0;
    if ($99) {
      label = 31;
      break;
    } else {
      label = 32;
      break;
    }
   case 31:
    $101 = HEAP32[$85 >> 2] | 0;
    $102 = $101 | 2;
    HEAP32[$85 >> 2] = $102;
    label = 32;
    break;
   case 32:
    $104 = $face + 28 | 0;
    HEAP32[$104 >> 2] = 0;
    $105 = $face + 32 | 0;
    HEAP32[$105 >> 2] = 0;
    $106 = $face + 460 | 0;
    $107 = HEAP32[$106 >> 2] | 0;
    $108 = $107 >> 16;
    $109 = $face + 52 | 0;
    HEAP32[$109 >> 2] = $108;
    $110 = $face + 464 | 0;
    $111 = HEAP32[$110 >> 2] | 0;
    $112 = $111 >> 16;
    $113 = $face + 56 | 0;
    HEAP32[$113 >> 2] = $112;
    $114 = $face + 468 | 0;
    $115 = HEAP32[$114 >> 2] | 0;
    $116 = $115 + 65535 | 0;
    $117 = $116 >> 16;
    $118 = $face + 60 | 0;
    HEAP32[$118 >> 2] = $117;
    $119 = $face + 472 | 0;
    $120 = HEAP32[$119 >> 2] | 0;
    $121 = $120 + 65535 | 0;
    $122 = $121 >> 16;
    $123 = $face + 64 | 0;
    HEAP32[$123 >> 2] = $122;
    $124 = $face + 68 | 0;
    $125 = HEAP16[$124 >> 1] | 0;
    $126 = $125 << 16 >> 16 == 0;
    if ($126) {
      label = 33;
      break;
    } else {
      label = 34;
      break;
    }
   case 33:
    HEAP16[$124 >> 1] = 1e3;
    label = 34;
    break;
   case 34:
    $129 = HEAP32[$123 >> 2] | 0;
    $130 = $129 & 65535;
    $131 = $face + 70 | 0;
    HEAP16[$131 >> 1] = $130;
    $132 = HEAP32[$113 >> 2] | 0;
    $133 = $132 & 65535;
    $134 = $face + 72 | 0;
    HEAP16[$134 >> 1] = $133;
    $135 = HEAP16[$124 >> 1] | 0;
    $136 = $135 & 65535;
    $137 = $136 * 12 & -1;
    $138 = ($137 >>> 0) / 10 >>> 0;
    $139 = $138 & 65535;
    $140 = $face + 74 | 0;
    HEAP16[$140 >> 1] = $139;
    $sext = $138 << 16;
    $141 = $sext >> 16;
    $142 = HEAP16[$131 >> 1] | 0;
    $143 = $142 << 16 >> 16;
    $144 = HEAP16[$134 >> 1] | 0;
    $145 = $144 << 16 >> 16;
    $146 = $143 - $145 | 0;
    $147 = ($141 | 0) < ($146 | 0);
    if ($147) {
      label = 35;
      break;
    } else {
      label = 36;
      break;
    }
   case 35:
    $149 = $146 & 65535;
    HEAP16[$140 >> 1] = $149;
    label = 36;
    break;
   case 36:
    $151 = HEAP32[$118 >> 2] | 0;
    $152 = $151 & 65535;
    $153 = $face + 76 | 0;
    HEAP16[$153 >> 1] = $152;
    $154 = _T1_Compute_Max_Advance($face, $max_advance) | 0;
    $155 = ($154 | 0) == 0;
    if ($155) {
      label = 37;
      break;
    } else {
      label = 38;
      break;
    }
   case 37:
    $157 = HEAP32[$max_advance >> 2] | 0;
    $158 = _FT_RoundFix($157) | 0;
    $159 = $158 >>> 16;
    $160 = $159 & 65535;
    HEAP16[$153 >> 1] = $160;
    label = 38;
    break;
   case 38:
    $162 = HEAP16[$140 >> 1] | 0;
    $163 = $face + 78 | 0;
    HEAP16[$163 >> 1] = $162;
    $164 = $face + 158 | 0;
    $165 = HEAP16[$164 >> 1] | 0;
    $166 = $face + 80 | 0;
    HEAP16[$166 >> 1] = $165;
    $167 = $face + 160 | 0;
    $168 = HEAP16[$167 >> 1] | 0;
    $169 = $face + 82 | 0;
    HEAP16[$169 >> 1] = $168;
    $170 = ($6 | 0) == 0;
    $171 = ($12 | 0) == 0;
    $or_cond107 = $170 | $171;
    if ($or_cond107) {
      $error_1 = 0;
      label = 47;
      break;
    } else {
      label = 39;
      break;
    }
   case 39:
    $173 = $12 + 20 | 0;
    $174 = $173;
    $175 = HEAP32[$174 >> 2] | 0;
    $176 = $charmap | 0;
    HEAP32[$176 >> 2] = $1;
    $177 = $charmap + 8 | 0;
    HEAP16[$177 >> 1] = 3;
    $178 = $charmap + 10 | 0;
    HEAP16[$178 >> 1] = 1;
    $179 = $charmap + 4 | 0;
    HEAP32[$179 >> 2] = 1970170211;
    $180 = $175 + 12 | 0;
    $181 = HEAP32[$180 >> 2] | 0;
    $182 = $181;
    $183 = $charmap;
    $184 = _FT_CMap_New($182, 0, $183, 0) | 0;
    if (($184 | 0) == 163 | ($184 | 0) == 0) {
      label = 40;
      break;
    } else {
      $error_1 = $184;
      label = 47;
      break;
    }
   case 40:
    HEAP16[$177 >> 1] = 7;
    $186 = $face + 368 | 0;
    $187 = HEAP32[$186 >> 2] | 0;
    if (($187 | 0) == 2) {
      label = 41;
      break;
    } else if (($187 | 0) == 4) {
      label = 42;
      break;
    } else if (($187 | 0) == 1) {
      label = 43;
      break;
    } else if (($187 | 0) == 3) {
      label = 44;
      break;
    } else {
      $error_1 = 0;
      label = 47;
      break;
    }
   case 41:
    HEAP32[$179 >> 2] = 1094995778;
    HEAP16[$178 >> 1] = 0;
    $189 = $175 | 0;
    $clazz_0_in = $189;
    label = 45;
    break;
   case 42:
    HEAP32[$179 >> 2] = 1094992453;
    HEAP16[$178 >> 1] = 1;
    $191 = $175 + 4 | 0;
    $clazz_0_in = $191;
    label = 45;
    break;
   case 43:
    HEAP32[$179 >> 2] = 1094992451;
    HEAP16[$178 >> 1] = 2;
    $193 = $175 + 8 | 0;
    $clazz_0_in = $193;
    label = 45;
    break;
   case 44:
    HEAP32[$179 >> 2] = 1818326065;
    HEAP16[$178 >> 1] = 3;
    $clazz_0_in = $180;
    label = 45;
    break;
   case 45:
    $clazz_0 = HEAP32[$clazz_0_in >> 2] | 0;
    $196 = ($clazz_0 | 0) == 0;
    if ($196) {
      $error_1 = 0;
      label = 47;
      break;
    } else {
      label = 46;
      break;
    }
   case 46:
    $198 = $clazz_0;
    $199 = _FT_CMap_New($198, 0, $183, 0) | 0;
    $error_1 = $199;
    label = 47;
    break;
   case 47:
    STACKTOP = __stackBase__;
    return $error_1 | 0;
  }
  return 0;
}
function _T1_GlyphSlot_Done($slot) {
  $slot = $slot | 0;
  HEAP32[(HEAP32[$slot + 156 >> 2] | 0) + 36 >> 2] = 0;
  return;
}
function _T1_Face_Done($face) {
  $face = $face | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $56 = 0, $58 = 0, $59 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($face | 0) == 0;
    if ($1) {
      label = 7;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 100 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $face + 548 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = $6;
    _ft_mem_free($4, $9);
    HEAP32[$5 >> 2] = 0;
    $10 = $face + 544 | 0;
    HEAP32[$10 >> 2] = 0;
    label = 4;
    break;
   case 4:
    _T1_Done_Blend($face);
    $12 = $face + 532 | 0;
    HEAP32[$12 >> 2] = 0;
    $13 = $face + 132 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    _ft_mem_free($4, $14);
    HEAP32[$13 >> 2] = 0;
    $15 = $face + 136 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    _ft_mem_free($4, $16);
    HEAP32[$15 >> 2] = 0;
    $17 = $face + 140 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    _ft_mem_free($4, $18);
    HEAP32[$17 >> 2] = 0;
    $19 = $face + 144 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    _ft_mem_free($4, $20);
    HEAP32[$19 >> 2] = 0;
    $21 = $face + 148 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    _ft_mem_free($4, $22);
    HEAP32[$21 >> 2] = 0;
    $23 = $face + 428 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24;
    _ft_mem_free($4, $25);
    HEAP32[$23 >> 2] = 0;
    $26 = $face + 424 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $27;
    _ft_mem_free($4, $28);
    HEAP32[$26 >> 2] = 0;
    $29 = $face + 420 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $30;
    _ft_mem_free($4, $31);
    HEAP32[$29 >> 2] = 0;
    $32 = $face + 408 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $33;
    _ft_mem_free($4, $34);
    HEAP32[$32 >> 2] = 0;
    $35 = $face + 412 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $36;
    _ft_mem_free($4, $37);
    HEAP32[$35 >> 2] = 0;
    $38 = $face + 392 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    _ft_mem_free($4, $39);
    HEAP32[$38 >> 2] = 0;
    $40 = $face + 396 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    _ft_mem_free($4, $41);
    HEAP32[$40 >> 2] = 0;
    $42 = $face + 400 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    _ft_mem_free($4, $43);
    HEAP32[$42 >> 2] = 0;
    $44 = $face + 384 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = $45;
    _ft_mem_free($4, $46);
    HEAP32[$44 >> 2] = 0;
    $47 = $face + 388 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $48;
    _ft_mem_free($4, $49);
    HEAP32[$47 >> 2] = 0;
    $50 = $face + 364 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    _ft_mem_free($4, $51);
    HEAP32[$50 >> 2] = 0;
    $52 = $face + 492 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = ($53 | 0) == 0;
    if ($54) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $56 = $53;
    _T1_Done_Metrics($4, $56);
    label = 6;
    break;
   case 6:
    $58 = $face + 20 | 0;
    HEAP32[$58 >> 2] = 0;
    $59 = $face + 24 | 0;
    HEAP32[$59 >> 2] = 0;
    label = 7;
    break;
   case 7:
    return;
  }
}
function _T1_Size_Init($size) {
  $size = $size | 0;
  var $globals = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $globals = __stackBase__ | 0;
    $1 = _T1_Size_Get_Globals_Funcs($size) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      $error_0 = 0;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $size | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $1 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $5 + 100 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $5 + 168 | 0;
    $11 = $10;
    $12 = FUNCTION_TABLE_iiii[$7 & 1023]($9, $11, $globals) | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 3;
      break;
    } else {
      $error_0 = $12;
      label = 4;
      break;
    }
   case 3:
    $15 = HEAP32[$globals >> 2] | 0;
    $16 = $15;
    $17 = $size + 40 | 0;
    HEAP32[$17 >> 2] = $16;
    $error_0 = 0;
    label = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _T1_Size_Done($size) {
  $size = $size | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size + 40 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = _T1_Size_Get_Globals_Funcs($size) | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $8 = $5 + 8 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = HEAP32[$1 >> 2] | 0;
    $11 = $10;
    FUNCTION_TABLE_vi[$9 & 1023]($11);
    label = 4;
    break;
   case 4:
    HEAP32[$1 >> 2] = 0;
    label = 5;
    break;
   case 5:
    return;
  }
}
function _T1_GlyphSlot_Init($slot) {
  $slot = $slot | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $slot + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 552 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $2 + 96 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 + 4 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10;
    $12 = _FT_Get_Module($11, 5324472) | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $15 = $12;
    $16 = $4 + 4 | 0;
    $17 = $16;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = FUNCTION_TABLE_ii[$18 & 1023]($15) | 0;
    $20 = $19;
    $21 = $slot + 156 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22 + 36 | 0;
    HEAP32[$23 >> 2] = $20;
    label = 4;
    break;
   case 4:
    return 0;
  }
  return 0;
}
function _T1_Load_Glyph($glyph, $size, $glyph_index, $load_flags) {
  $glyph = $glyph | 0;
  $size = $size | 0;
  $glyph_index = $glyph_index | 0;
  $load_flags = $load_flags | 0;
  var $decoder = 0, $font_matrix = 0, $glyph_data = 0, $cbox = 0, $advance = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $load_flags_ = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $60 = 0, $_lobit = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $font_offset_sroa_0_0__idx30 = 0, $font_offset_sroa_0_0_copyload31 = 0, $font_offset_sroa_1_4__idx35 = 0, $font_offset_sroa_1_4_copyload36 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $font_offset_sroa_0_0__idx = 0, $font_offset_sroa_1_4__idx34 = 0, $109 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $148 = 0, $149 = 0, $150 = 0, $152 = 0, $153 = 0, $155 = 0, $156 = 0, $157 = 0, $159 = 0, $160 = 0, $161 = 0, $163 = 0, $164 = 0, $165 = 0, $167 = 0, $168 = 0, $169 = 0, $172 = 0, $173 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $195 = 0, $196 = 0, $197 = 0, $199 = 0, $200 = 0, $201 = 0, $202 = 0, $vec_0112 = 0, $n_0111 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $218 = 0, $219 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $235 = 0, $237 = 0, $238 = 0, $239 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $249 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $258 = 0, $259 = 0, $error_0105108 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 1548 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $decoder = __stackBase__ | 0;
    $font_matrix = __stackBase__ + 1500 | 0;
    $glyph_data = __stackBase__ + 1516 | 0;
    $cbox = __stackBase__ + 1524 | 0;
    $advance = __stackBase__ + 1540 | 0;
    $1 = $glyph + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 488 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 12 | 0;
    $6 = $5;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $2 + 16 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 >>> 0 > $glyph_index >>> 0;
    if ($10) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $12 = $2 + 128 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 + 52 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      $error_0105108 = 6;
      label = 37;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $18 = $load_flags & 1024;
    $19 = ($18 | 0) == 0;
    $20 = $load_flags | 3;
    $load_flags_ = $19 ? $load_flags : $20;
    $21 = ($size | 0) != 0;
    if ($21) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $23 = $size + 16 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $glyph + 172 | 0;
    HEAP32[$25 >> 2] = $24;
    $26 = $size + 20 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $glyph + 176 | 0;
    HEAP32[$28 >> 2] = $27;
    label = 6;
    break;
   case 5:
    $30 = $glyph + 172 | 0;
    HEAP32[$30 >> 2] = 65536;
    $31 = $glyph + 176 | 0;
    HEAP32[$31 >> 2] = 65536;
    label = 6;
    break;
   case 6:
    $33 = $glyph + 108 | 0;
    $34 = $glyph + 110 | 0;
    HEAP16[$34 >> 1] = 0;
    $35 = $33 | 0;
    HEAP16[$35 >> 1] = 0;
    $36 = $load_flags_ & 1;
    $37 = ($36 | 0) == 0;
    if ($37) {
      label = 7;
      break;
    } else {
      $42 = 0;
      label = 8;
      break;
    }
   case 7:
    $39 = $load_flags_ & 2;
    $40 = ($39 | 0) == 0;
    $42 = $40;
    label = 8;
    break;
   case 8:
    $43 = $42 & 1;
    $44 = $glyph + 72 | 0;
    HEAP32[$44 >> 2] = 1869968492;
    $45 = $7 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $size | 0;
    $48 = $glyph | 0;
    $49 = $2 + 420 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $50;
    $52 = $2 + 532 | 0;
    $53 = $52;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = $load_flags_ >>> 16;
    $56 = $55 & 15;
    $57 = FUNCTION_TABLE_iiiiiiiiii[$46 & 1023]($decoder, $2, $47, $48, $51, $54, $43, $56, 520) | 0;
    $58 = ($57 | 0) == 0;
    if ($58) {
      label = 9;
      break;
    } else {
      $error_0105108 = $57;
      label = 37;
      break;
    }
   case 9:
    $60 = $load_flags_ & 1024;
    $_lobit = $60 >>> 10;
    $61 = $_lobit & 255;
    $62 = $decoder + 69 | 0;
    HEAP8[$62] = $61;
    $63 = $2 + 404 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = $decoder + 1364 | 0;
    HEAP32[$65 >> 2] = $64;
    $66 = $2 + 408 | 0;
    $67 = $66;
    $68 = HEAP32[$67 >> 2] | 0;
    $69 = $decoder + 1368 | 0;
    HEAP32[$69 >> 2] = $68;
    $70 = $2 + 412 | 0;
    $71 = $70;
    $72 = HEAP32[$71 >> 2] | 0;
    $73 = $decoder + 1372 | 0;
    HEAP32[$73 >> 2] = $72;
    $74 = $2 + 548 | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    $76 = $75;
    $77 = $decoder + 1488 | 0;
    HEAP32[$77 >> 2] = $76;
    $78 = $2 + 544 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = $decoder + 1492 | 0;
    HEAP32[$80 >> 2] = $79;
    $81 = _T1_Parse_Glyph_And_Get_Char_String($decoder, $glyph_index, $glyph_data) | 0;
    $82 = ($81 | 0) == 0;
    if ($82) {
      label = 10;
      break;
    } else {
      label = 36;
      break;
    }
   case 10:
    $84 = ($60 | 0) == 0;
    $85 = $decoder + 1376 | 0;
    $86 = $font_matrix;
    $87 = $85;
    _memcpy($86 | 0, $87 | 0, 16);
    $font_offset_sroa_0_0__idx30 = $decoder + 1392 | 0;
    $font_offset_sroa_0_0_copyload31 = HEAP32[$font_offset_sroa_0_0__idx30 >> 2] | 0;
    $font_offset_sroa_1_4__idx35 = $decoder + 1396 | 0;
    $font_offset_sroa_1_4_copyload36 = HEAP32[$font_offset_sroa_1_4__idx35 >> 2] | 0;
    $88 = $7 + 4 | 0;
    $89 = HEAP32[$88 >> 2] | 0;
    FUNCTION_TABLE_vi[$89 & 1023]($decoder);
    $90 = $glyph + 124 | 0;
    $91 = HEAP32[$90 >> 2] | 0;
    $92 = $91 & 1;
    $93 = $92 | 4;
    HEAP32[$90 >> 2] = $93;
    if ($84) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $95 = $glyph + 156 | 0;
    $96 = HEAP32[$95 >> 2] | 0;
    $97 = $decoder + 32 | 0;
    $98 = HEAP32[$97 >> 2] | 0;
    $99 = _FT_RoundFix($98) | 0;
    $100 = $99 >> 16;
    $101 = $glyph + 32 | 0;
    HEAP32[$101 >> 2] = $100;
    $102 = $decoder + 40 | 0;
    $103 = HEAP32[$102 >> 2] | 0;
    $104 = _FT_RoundFix($103) | 0;
    $105 = $104 >> 16;
    $106 = $glyph + 40 | 0;
    HEAP32[$106 >> 2] = $105;
    $107 = $96 + 12 | 0;
    $108 = $107;
    _memcpy($108 | 0, $86 | 0, 16);
    $font_offset_sroa_0_0__idx = $96 + 28 | 0;
    HEAP32[$font_offset_sroa_0_0__idx >> 2] = $font_offset_sroa_0_0_copyload31;
    $font_offset_sroa_1_4__idx34 = $96 + 32 | 0;
    HEAP32[$font_offset_sroa_1_4__idx34 >> 2] = $font_offset_sroa_1_4_copyload36;
    $109 = $96 + 8 | 0;
    HEAP8[$109] = 1;
    label = 34;
    break;
   case 12:
    $111 = $glyph + 24 | 0;
    $112 = $decoder + 40 | 0;
    $113 = HEAP32[$112 >> 2] | 0;
    $114 = _FT_RoundFix($113) | 0;
    $115 = $114 >> 16;
    $116 = $glyph + 40 | 0;
    HEAP32[$116 >> 2] = $115;
    $117 = HEAP32[$112 >> 2] | 0;
    $118 = _FT_RoundFix($117) | 0;
    $119 = $118 >> 16;
    $120 = $glyph + 56 | 0;
    HEAP32[$120 >> 2] = $119;
    $121 = $glyph + 156 | 0;
    $122 = HEAP32[$121 >> 2] | 0;
    $123 = $122 + 8 | 0;
    HEAP8[$123] = 0;
    $124 = $load_flags_ & 16;
    $125 = ($124 | 0) != 0;
    if ($125) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    $127 = $2 + 460 | 0;
    $128 = $127 + 12 | 0;
    $129 = HEAP32[$128 >> 2] | 0;
    $130 = $127 + 4 | 0;
    $131 = HEAP32[$130 >> 2] | 0;
    $132 = $129 - $131 | 0;
    $133 = $132 >> 16;
    $134 = $glyph + 52 | 0;
    HEAP32[$134 >> 2] = $133;
    $135 = $glyph + 60 | 0;
    HEAP32[$135 >> 2] = $133;
    label = 15;
    break;
   case 14:
    $137 = $decoder + 44 | 0;
    $138 = HEAP32[$137 >> 2] | 0;
    $139 = _FT_RoundFix($138) | 0;
    $140 = $139 >> 16;
    $141 = $glyph + 52 | 0;
    HEAP32[$141 >> 2] = $140;
    $142 = HEAP32[$137 >> 2] | 0;
    $143 = _FT_RoundFix($142) | 0;
    $144 = $143 >> 16;
    $145 = $glyph + 60 | 0;
    HEAP32[$145 >> 2] = $144;
    label = 15;
    break;
   case 15:
    HEAP32[$44 >> 2] = 1869968492;
    if ($21) {
      label = 16;
      break;
    } else {
      label = 18;
      break;
    }
   case 16:
    $148 = $size + 14 | 0;
    $149 = HEAP16[$148 >> 1] | 0;
    $150 = ($149 & 65535) < 24;
    if ($150) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    $152 = HEAP32[$90 >> 2] | 0;
    $153 = $152 | 256;
    HEAP32[$90 >> 2] = $153;
    label = 18;
    break;
   case 18:
    $155 = $font_matrix | 0;
    $156 = HEAP32[$155 >> 2] | 0;
    $157 = ($156 | 0) == 65536;
    if ($157) {
      label = 19;
      break;
    } else {
      label = 22;
      break;
    }
   case 19:
    $159 = $font_matrix + 12 | 0;
    $160 = HEAP32[$159 >> 2] | 0;
    $161 = ($160 | 0) == ($156 | 0);
    if ($161) {
      label = 20;
      break;
    } else {
      label = 22;
      break;
    }
   case 20:
    $163 = $font_matrix + 4 | 0;
    $164 = HEAP32[$163 >> 2] | 0;
    $165 = ($164 | 0) == 0;
    if ($165) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    $167 = $font_matrix + 8 | 0;
    $168 = HEAP32[$167 >> 2] | 0;
    $169 = ($168 | 0) == 0;
    if ($169) {
      label = 23;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    _FT_Outline_Transform($33, $font_matrix);
    label = 23;
    break;
   case 23:
    $172 = $font_offset_sroa_1_4_copyload36 | $font_offset_sroa_0_0_copyload31;
    $173 = ($172 | 0) == 0;
    if ($173) {
      label = 25;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    _FT_Outline_Translate($33, $font_offset_sroa_0_0_copyload31, $font_offset_sroa_1_4_copyload36);
    label = 25;
    break;
   case 25:
    $176 = HEAP32[$116 >> 2] | 0;
    $177 = $advance | 0;
    HEAP32[$177 >> 2] = $176;
    $178 = $advance + 4 | 0;
    HEAP32[$178 >> 2] = 0;
    _FT_Vector_Transform($advance, $font_matrix);
    $179 = HEAP32[$177 >> 2] | 0;
    $180 = $179 + $font_offset_sroa_0_0_copyload31 | 0;
    HEAP32[$116 >> 2] = $180;
    HEAP32[$177 >> 2] = 0;
    $181 = $glyph + 52 | 0;
    $182 = HEAP32[$181 >> 2] | 0;
    HEAP32[$178 >> 2] = $182;
    _FT_Vector_Transform($advance, $font_matrix);
    $183 = HEAP32[$178 >> 2] | 0;
    $184 = $183 + $font_offset_sroa_1_4_copyload36 | 0;
    HEAP32[$181 >> 2] = $184;
    if ($37) {
      label = 26;
      break;
    } else {
      label = 32;
      break;
    }
   case 26:
    $186 = $decoder + 16 | 0;
    $187 = HEAP32[$186 >> 2] | 0;
    $188 = $187 + 4 | 0;
    $189 = HEAP32[$188 >> 2] | 0;
    $190 = $glyph + 172 | 0;
    $191 = HEAP32[$190 >> 2] | 0;
    $192 = $glyph + 176 | 0;
    $193 = HEAP32[$192 >> 2] | 0;
    if ($42) {
      label = 27;
      break;
    } else {
      label = 28;
      break;
    }
   case 27:
    $195 = $decoder + 72 | 0;
    $196 = HEAP32[$195 >> 2] | 0;
    $197 = ($196 | 0) == 0;
    if ($197) {
      label = 28;
      break;
    } else {
      label = 31;
      break;
    }
   case 28:
    $199 = $187 + 2 | 0;
    $200 = HEAP16[$199 >> 1] | 0;
    $201 = $200 << 16 >> 16 > 0;
    if ($201) {
      label = 29;
      break;
    } else {
      label = 31;
      break;
    }
   case 29:
    $202 = $200 << 16 >> 16;
    $n_0111 = $202;
    $vec_0112 = $189;
    label = 30;
    break;
   case 30:
    $204 = $vec_0112 | 0;
    $205 = HEAP32[$204 >> 2] | 0;
    $206 = _FT_MulFix($205, $191) | 0;
    HEAP32[$204 >> 2] = $206;
    $207 = $vec_0112 + 4 | 0;
    $208 = HEAP32[$207 >> 2] | 0;
    $209 = _FT_MulFix($208, $193) | 0;
    HEAP32[$207 >> 2] = $209;
    $210 = $n_0111 - 1 | 0;
    $211 = $vec_0112 + 8 | 0;
    $212 = ($210 | 0) > 0;
    if ($212) {
      $n_0111 = $210;
      $vec_0112 = $211;
      label = 30;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    $213 = HEAP32[$116 >> 2] | 0;
    $214 = _FT_MulFix($213, $191) | 0;
    HEAP32[$116 >> 2] = $214;
    $215 = HEAP32[$181 >> 2] | 0;
    $216 = _FT_MulFix($215, $193) | 0;
    HEAP32[$181 >> 2] = $216;
    label = 32;
    break;
   case 32:
    _FT_Outline_Get_CBox($33, $cbox);
    $218 = $cbox + 8 | 0;
    $219 = HEAP32[$218 >> 2] | 0;
    $220 = $cbox | 0;
    $221 = HEAP32[$220 >> 2] | 0;
    $222 = $219 - $221 | 0;
    $223 = $111 | 0;
    HEAP32[$223 >> 2] = $222;
    $224 = $cbox + 12 | 0;
    $225 = HEAP32[$224 >> 2] | 0;
    $226 = $cbox + 4 | 0;
    $227 = HEAP32[$226 >> 2] | 0;
    $228 = $225 - $227 | 0;
    $229 = $glyph + 28 | 0;
    HEAP32[$229 >> 2] = $228;
    $230 = HEAP32[$220 >> 2] | 0;
    $231 = $glyph + 32 | 0;
    HEAP32[$231 >> 2] = $230;
    $232 = HEAP32[$224 >> 2] | 0;
    $233 = $glyph + 36 | 0;
    HEAP32[$233 >> 2] = $232;
    if ($125) {
      label = 33;
      break;
    } else {
      label = 34;
      break;
    }
   case 33:
    $235 = HEAP32[$181 >> 2] | 0;
    _ft_synthesize_vertical_metrics($111, $235);
    label = 34;
    break;
   case 34:
    $237 = $glyph_data | 0;
    $238 = HEAP32[$237 >> 2] | 0;
    $239 = $glyph + 136 | 0;
    HEAP32[$239 >> 2] = $238;
    $240 = $glyph_data + 4 | 0;
    $241 = HEAP32[$240 >> 2] | 0;
    $242 = $glyph + 140 | 0;
    HEAP32[$242 >> 2] = $241;
    $243 = $2 + 128 | 0;
    $244 = HEAP32[$243 >> 2] | 0;
    $245 = $244 + 52 | 0;
    $246 = HEAP32[$245 >> 2] | 0;
    $247 = ($246 | 0) == 0;
    if ($247) {
      $error_0105108 = $81;
      label = 37;
      break;
    } else {
      label = 35;
      break;
    }
   case 35:
    $249 = $246 | 0;
    $250 = HEAP32[$249 >> 2] | 0;
    $251 = $250 + 4 | 0;
    $252 = HEAP32[$251 >> 2] | 0;
    $253 = $246 + 4 | 0;
    $254 = HEAP32[$253 >> 2] | 0;
    FUNCTION_TABLE_vii[$252 & 1023]($254, $glyph_data);
    $255 = $glyph + 136 | 0;
    HEAP32[$255 >> 2] = 0;
    $256 = $glyph + 140 | 0;
    HEAP32[$256 >> 2] = 0;
    $error_0105108 = $81;
    label = 37;
    break;
   case 36:
    $258 = $7 + 4 | 0;
    $259 = HEAP32[$258 >> 2] | 0;
    FUNCTION_TABLE_vi[$259 & 1023]($decoder);
    $error_0105108 = $81;
    label = 37;
    break;
   case 37:
    STACKTOP = __stackBase__;
    return $error_0105108 | 0;
  }
  return 0;
}
function _Get_Kerning($face, $left_glyph, $right_glyph, $kerning) {
  $face = $face | 0;
  $left_glyph = $left_glyph | 0;
  $right_glyph = $right_glyph | 0;
  $kerning = $kerning | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $kerning | 0;
    HEAP32[$1 >> 2] = 0;
    $2 = $kerning + 4 | 0;
    HEAP32[$2 >> 2] = 0;
    $3 = $face + 492 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $4;
    _T1_Get_Kerning($7, $left_glyph, $right_glyph, $kerning);
    label = 3;
    break;
   case 3:
    return 0;
  }
  return 0;
}
function _T1_Read_Metrics($t1_face, $stream) {
  $t1_face = $t1_face | 0;
  $stream = $stream | 0;
  var $parser = 0, $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $_pr = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $88 = 0, $_pr51 = 0, $90 = 0, $91 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $_c = 0, $fi_0 = 0, $fi_1 = 0, $135 = 0, $138 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 24 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $parser = __stackBase__ | 0;
    $error = __stackBase__ + 20 | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 2;
    $3 = $t1_face + 132 | 0;
    $4 = _ft_mem_alloc($2, 44, $error) | 0;
    $5 = $4;
    $6 = HEAP32[$error >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 2;
      break;
    } else {
      $fi_1 = $5;
      label = 18;
      break;
    }
   case 2:
    $9 = $stream + 4 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = _FT_Stream_EnterFrame($stream, $10) | 0;
    HEAP32[$error >> 2] = $11;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 3;
      break;
    } else {
      $fi_1 = $5;
      label = 18;
      break;
    }
   case 3:
    $14 = $4 + 4 | 0;
    $15 = $t1_face + 460 | 0;
    $16 = $15;
    _memcpy($14 | 0, $16 | 0, 16);
    $17 = $15 + 12 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $4 + 20 | 0;
    $20 = $19;
    HEAP32[$20 >> 2] = $18;
    $21 = $15 + 4 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $4 + 24 | 0;
    $24 = $23;
    HEAP32[$24 >> 2] = $22;
    $25 = $t1_face + 488 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = ($26 | 0) == 0;
    if ($27) {
      label = 7;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $29 = $26 + 24 | 0;
    $30 = $29;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = ($31 | 0) == 0;
    if ($32) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $34 = $31 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = HEAP32[$1 >> 2] | 0;
    $37 = $stream + 32 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $stream + 36 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = FUNCTION_TABLE_iiiii[$35 & 1023]($parser, $36, $38, $40) | 0;
    HEAP32[$error >> 2] = $41;
    $42 = ($41 | 0) == 0;
    if ($42) {
      label = 6;
      break;
    } else {
      $56 = $41;
      label = 8;
      break;
    }
   case 6:
    $44 = $parser + 8 | 0;
    HEAP32[$44 >> 2] = $5;
    $45 = $parser + 12 | 0;
    HEAP32[$45 >> 2] = 52;
    $46 = $3;
    $47 = $parser + 16 | 0;
    HEAP32[$47 >> 2] = $46;
    $48 = HEAP32[$30 >> 2] | 0;
    $49 = $48 + 8 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = FUNCTION_TABLE_ii[$50 & 1023]($parser) | 0;
    HEAP32[$error >> 2] = $51;
    $52 = HEAP32[$30 >> 2] | 0;
    $53 = $52 + 4 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    FUNCTION_TABLE_vi[$54 & 1023]($parser);
    label = 7;
    break;
   case 7:
    $_pr = HEAP32[$error >> 2] | 0;
    $56 = $_pr;
    label = 8;
    break;
   case 8:
    $57 = ($56 | 0) == 2;
    if ($57) {
      label = 9;
      break;
    } else {
      label = 13;
      break;
    }
   case 9:
    $59 = $stream + 32 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = HEAP32[$9 >> 2] | 0;
    $62 = $61 >>> 0 > 6;
    if ($62) {
      label = 10;
      break;
    } else {
      label = 13;
      break;
    }
   case 10:
    $64 = $60 + 1 | 0;
    $65 = HEAP8[$64] | 0;
    $66 = ($65 & 255) < 4;
    if ($66) {
      label = 11;
      break;
    } else {
      label = 13;
      break;
    }
   case 11:
    $68 = $60 + 2 | 0;
    $69 = $60 + 5 | 0;
    $70 = HEAP8[$69] | 0;
    $71 = $70 & 255;
    $72 = $71 << 24;
    $73 = $60 + 4 | 0;
    $74 = HEAP8[$73] | 0;
    $75 = $74 & 255;
    $76 = $75 << 16;
    $77 = $76 | $72;
    $78 = $60 + 3 | 0;
    $79 = HEAP8[$78] | 0;
    $80 = $79 & 255;
    $81 = $80 << 8;
    $82 = $77 | $81;
    $83 = HEAP8[$68] | 0;
    $84 = $83 & 255;
    $85 = $82 | $84;
    $86 = ($85 | 0) == ($61 | 0);
    if ($86) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $88 = _T1_Read_PFM($t1_face, $stream, $5) | 0;
    HEAP32[$error >> 2] = $88;
    $90 = $88;
    label = 14;
    break;
   case 13:
    $_pr51 = HEAP32[$error >> 2] | 0;
    $90 = $_pr51;
    label = 14;
    break;
   case 14:
    $91 = ($90 | 0) == 0;
    if ($91) {
      label = 15;
      break;
    } else {
      $fi_0 = $5;
      label = 17;
      break;
    }
   case 15:
    _memcpy($16 | 0, $14 | 0, 16);
    $93 = $14;
    $94 = HEAP32[$93 >> 2] | 0;
    $95 = $94 >> 16;
    $96 = $t1_face + 52 | 0;
    HEAP32[$96 >> 2] = $95;
    $97 = $4 + 8 | 0;
    $98 = $97;
    $99 = HEAP32[$98 >> 2] | 0;
    $100 = $99 >> 16;
    $101 = $t1_face + 56 | 0;
    HEAP32[$101 >> 2] = $100;
    $102 = $4 + 12 | 0;
    $103 = $102;
    $104 = HEAP32[$103 >> 2] | 0;
    $105 = $104 + 65535 | 0;
    $106 = $105 >> 16;
    $107 = $t1_face + 60 | 0;
    HEAP32[$107 >> 2] = $106;
    $108 = $4 + 16 | 0;
    $109 = $108;
    $110 = HEAP32[$109 >> 2] | 0;
    $111 = $110 + 65535 | 0;
    $112 = $111 >> 16;
    $113 = $t1_face + 64 | 0;
    HEAP32[$113 >> 2] = $112;
    $114 = HEAP32[$20 >> 2] | 0;
    $115 = $114 + 32768 | 0;
    $116 = $115 >>> 16;
    $117 = $116 & 65535;
    $118 = $t1_face + 70 | 0;
    HEAP16[$118 >> 1] = $117;
    $119 = HEAP32[$24 >> 2] | 0;
    $120 = $119 + 32768 | 0;
    $121 = $120 >>> 16;
    $122 = $121 & 65535;
    $123 = $t1_face + 72 | 0;
    HEAP16[$123 >> 1] = $122;
    $124 = $4 + 40 | 0;
    $125 = $124;
    $126 = HEAP32[$125 >> 2] | 0;
    $127 = ($126 | 0) == 0;
    if ($127) {
      $fi_0 = $5;
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $129 = $t1_face + 8 | 0;
    $130 = HEAP32[$129 >> 2] | 0;
    $131 = $130 | 64;
    HEAP32[$129 >> 2] = $131;
    $132 = $t1_face + 492 | 0;
    $_c = $4;
    HEAP32[$132 >> 2] = $_c;
    $fi_0 = 0;
    label = 17;
    break;
   case 17:
    _FT_Stream_ExitFrame($stream);
    $fi_1 = $fi_0;
    label = 18;
    break;
   case 18:
    $135 = ($fi_1 | 0) == 0;
    if ($135) {
      label = 20;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    _T1_Done_Metrics($2, $fi_1);
    label = 20;
    break;
   case 20:
    $138 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $138 | 0;
  }
  return 0;
}
function _T1_Get_Advances($face, $first, $count, $load_flags, $advances) {
  $face = $face | 0;
  $first = $first | 0;
  $count = $count | 0;
  $load_flags = $load_flags | 0;
  $advances = $advances | 0;
  var $advances31 = 0, $decoder = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $nn_126 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $51 = 0, $exitcond = 0, $52 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $advances31 = $advances;
    $decoder = STACKTOP;
    STACKTOP = STACKTOP + 1500 | 0;
    $1 = $load_flags & 16;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = ($count | 0) == 0;
    if ($3) {
      $_0 = 0;
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 3:
    $5 = $face + 488 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + 12 | 0;
    $8 = $7;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $face | 0;
    $13 = $face + 420 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $face + 532 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = FUNCTION_TABLE_iiiiiiiiii[$11 & 1023]($decoder, $12, 0, 0, $14, $16, 0, 0, 520) | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 4;
      break;
    } else {
      $_0 = $17;
      label = 11;
      break;
    }
   case 4:
    $20 = $decoder + 70 | 0;
    HEAP8[$20] = 1;
    $21 = $decoder + 68 | 0;
    HEAP8[$21] = 0;
    $22 = $face + 404 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $decoder + 1364 | 0;
    HEAP32[$24 >> 2] = $23;
    $25 = $face + 408 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $decoder + 1368 | 0;
    HEAP32[$27 >> 2] = $26;
    $28 = $face + 412 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $decoder + 1372 | 0;
    HEAP32[$30 >> 2] = $29;
    $31 = $face + 548 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $decoder + 1488 | 0;
    HEAP32[$33 >> 2] = $32;
    $34 = $face + 544 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $decoder + 1492 | 0;
    HEAP32[$36 >> 2] = $35;
    $37 = ($count | 0) == 0;
    if ($37) {
      $_0 = 0;
      label = 11;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $38 = $decoder + 40 | 0;
    $nn_126 = 0;
    label = 6;
    break;
   case 6:
    $40 = $nn_126 + $first | 0;
    $41 = _T1_Parse_Glyph($decoder, $40) | 0;
    $42 = ($41 | 0) == 0;
    if ($42) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $44 = HEAP32[$38 >> 2] | 0;
    $45 = _FT_RoundFix($44) | 0;
    $46 = $45 >> 16;
    $47 = $advances + ($nn_126 << 2) | 0;
    HEAP32[$47 >> 2] = $46;
    label = 9;
    break;
   case 8:
    $49 = $advances + ($nn_126 << 2) | 0;
    HEAP32[$49 >> 2] = 0;
    label = 9;
    break;
   case 9:
    $51 = $nn_126 + 1 | 0;
    $exitcond = ($51 | 0) == ($count | 0);
    if ($exitcond) {
      $_0 = 0;
      label = 11;
      break;
    } else {
      $nn_126 = $51;
      label = 6;
      break;
    }
   case 10:
    $52 = $count << 2;
    _memset($advances31 | 0, 0, $52 | 0);
    $_0 = 0;
    label = 11;
    break;
   case 11:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _T1_Size_Request($size, $req) {
  $size = $size | 0;
  $req = $req | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _T1_Size_Get_Globals_Funcs($size) | 0;
    $2 = $size | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3;
    _FT_Request_Metrics($4, $req);
    $5 = ($1 | 0) == 0;
    if ($5) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $1 + 4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $size + 40 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10;
    $12 = $size + 16 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $size + 20 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = FUNCTION_TABLE_iiiiii[$8 & 1023]($11, $13, $15, 0, 0) | 0;
    label = 3;
    break;
   case 3:
    return 0;
  }
  return 0;
}
function _compare_kern_pairs($a, $b) {
  $a = $a | 0;
  $b = $b | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $_ = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $a;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 << 16;
    $4 = $a + 4 | 0;
    $5 = $4;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $3 | $6;
    $8 = $b;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 << 16;
    $11 = $b + 4 | 0;
    $12 = $11;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $10 | $13;
    $15 = $7 >>> 0 > $14 >>> 0;
    if ($15) {
      $_0 = 1;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $17 = $7 >>> 0 < $14 >>> 0;
    $_ = $17 << 31 >> 31;
    $_0 = $_;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _T1_Get_Kerning($fi, $glyph1, $glyph2, $kerning) {
  $fi = $fi | 0;
  $glyph1 = $glyph1 | 0;
  $glyph2 = $glyph2 | 0;
  $kerning = $kerning | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_sum = 0, $7 = 0, $8 = 0, $min_0_ph25 = 0, $max_0_ph24 = 0, $9 = 0, $min_023 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $_sum19 = 0, $32 = 0, $33 = 0, $_sum18 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $glyph1 << 16;
    $2 = $1 | $glyph2;
    $3 = $fi + 36 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $fi + 40 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $_sum = $6 - 1 | 0;
    $7 = ($_sum | 0) < 0;
    if ($7) {
      label = 9;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $4 + ($_sum << 4) | 0;
    $max_0_ph24 = $8;
    $min_0_ph25 = $4;
    label = 3;
    break;
   case 3:
    $9 = $max_0_ph24;
    $min_023 = $min_0_ph25;
    label = 4;
    break;
   case 4:
    $11 = $min_023;
    $12 = $9 - $11 | 0;
    $13 = $12 >> 4;
    $14 = ($13 | 0) / 2 & -1;
    $15 = $min_023 + ($14 << 4) | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $16 << 16;
    $18 = $min_023 + ($14 << 4) + 4 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $17 | $19;
    $21 = ($20 | 0) == ($2 | 0);
    if ($21) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $23 = $min_023 + ($14 << 4) + 8 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $kerning | 0;
    HEAP32[$25 >> 2] = $24;
    $26 = $min_023 + ($14 << 4) + 12 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $kerning + 4 | 0;
    HEAP32[$28 >> 2] = $27;
    label = 10;
    break;
   case 6:
    $30 = $20 >>> 0 < $2 >>> 0;
    if ($30) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $_sum19 = $14 + 1 | 0;
    $32 = $min_023 + ($_sum19 << 4) | 0;
    $33 = $32 >>> 0 > $max_0_ph24 >>> 0;
    if ($33) {
      label = 9;
      break;
    } else {
      $min_023 = $32;
      label = 4;
      break;
    }
   case 8:
    $_sum18 = $14 - 1 | 0;
    $34 = $min_023 + ($_sum18 << 4) | 0;
    $35 = ($_sum18 | 0) < 0;
    if ($35) {
      label = 9;
      break;
    } else {
      $max_0_ph24 = $34;
      $min_0_ph25 = $min_023;
      label = 3;
      break;
    }
   case 9:
    $36 = $kerning | 0;
    HEAP32[$36 >> 2] = 0;
    $37 = $kerning + 4 | 0;
    HEAP32[$37 >> 2] = 0;
    label = 10;
    break;
   case 10:
    return;
  }
}
function _t1_get_index($name, $len, $user_data) {
  $name = $name | 0;
  $len = $len | 0;
  $user_data = $user_data | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $n_014 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $len >>> 0 > 65535;
    if ($1) {
      $_0 = 0;
      label = 9;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $2 = $user_data + 284 | 0;
    $3 = $2;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) > 0;
    if ($5) {
      label = 3;
      break;
    } else {
      $_0 = 0;
      label = 9;
      break;
    }
   case 3:
    $6 = $user_data + 288 | 0;
    $7 = $6;
    $8 = HEAP32[$7 >> 2] | 0;
    $n_014 = 0;
    label = 4;
    break;
   case 4:
    $10 = $8 + ($n_014 << 2) | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 8;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $14 = HEAP8[$11] | 0;
    $15 = HEAP8[$name] | 0;
    $16 = $14 << 24 >> 24 == $15 << 24 >> 24;
    if ($16) {
      label = 6;
      break;
    } else {
      label = 8;
      break;
    }
   case 6:
    $18 = _strlen($11 | 0) | 0;
    $19 = ($18 | 0) == ($len | 0);
    if ($19) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $21 = _strncmp($11 | 0, $name | 0, $len | 0) | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      $_0 = $n_014;
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $24 = $n_014 + 1 | 0;
    $25 = HEAP32[$3 >> 2] | 0;
    $26 = ($24 | 0) < ($25 | 0);
    if ($26) {
      $n_014 = $24;
      label = 4;
      break;
    } else {
      $_0 = 0;
      label = 9;
      break;
    }
   case 9:
    return $_0 | 0;
  }
  return 0;
}
function _T1_Read_PFM($t1_face, $stream, $fi) {
  $t1_face = $t1_face | 0;
  $stream = $stream | 0;
  $fi = $fi | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $_sum62 = 0, $19 = 0, $20 = 0, $_sum = 0, $22 = 0, $_sum63 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $_sum64 = 0, $32 = 0, $_sum65 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $_sum66 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $_sum67 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $_sum68 = 0, $53 = 0, $54 = 0, $_sum69 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $_sum70 = 0, $66 = 0, $67 = 0, $70 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $_sum71 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $n_0 = 0, $87 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $p_075 = 0, $kp_074 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $129 = 0, $130 = 0, $131 = 0, $_pr = 0, $133 = 0, $134 = 0, $136 = 0, $137 = 0, $138 = 0, $_pr73 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $146 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $stream + 32 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $stream + 36 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $4 + 101 | 0;
    $8 = $7 >>> 0 > $6 >>> 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    HEAP32[$error >> 2] = 2;
    label = 25;
    break;
   case 3:
    $11 = $4 + 99 | 0;
    $12 = $4 + 100 | 0;
    $13 = HEAP8[$12] | 0;
    $14 = $13 & 255;
    $15 = $14 << 8;
    $16 = HEAP8[$11] | 0;
    $17 = $16 & 255;
    $18 = $15 | $17;
    $_sum62 = $18 + 135 | 0;
    $19 = $4 + $_sum62 | 0;
    $20 = $19 >>> 0 > $6 >>> 0;
    if ($20) {
      label = 24;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $_sum = $18 + 117 | 0;
    $22 = $4 + $_sum | 0;
    $_sum63 = $18 + 118 | 0;
    $23 = $4 + $_sum63 | 0;
    $24 = HEAP8[$23] | 0;
    $25 = $24 & 255;
    $26 = $25 << 8;
    $27 = HEAP8[$22] | 0;
    $28 = $27 & 255;
    $29 = $26 | $28;
    $30 = $29 >>> 0 < 18;
    if ($30) {
      label = 24;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $_sum64 = $18 + 131 | 0;
    $32 = $4 + $_sum64 | 0;
    $_sum65 = $18 + 134 | 0;
    $33 = $4 + $_sum65 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $35 << 24;
    $_sum66 = $18 + 133 | 0;
    $37 = $4 + $_sum66 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 & 255;
    $40 = $39 << 16;
    $41 = $40 | $36;
    $_sum67 = $18 + 132 | 0;
    $42 = $4 + $_sum67 | 0;
    $43 = HEAP8[$42] | 0;
    $44 = $43 & 255;
    $45 = $44 << 8;
    $46 = $41 | $45;
    $47 = HEAP8[$32] | 0;
    $48 = $47 & 255;
    $49 = $46 | $48;
    $50 = $4 + $49 | 0;
    $51 = ($49 | 0) == 0;
    if ($51) {
      label = 24;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $_sum68 = $49 + 2 | 0;
    $53 = $4 + $_sum68 | 0;
    $54 = $53 >>> 0 > $6 >>> 0;
    if ($54) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    HEAP32[$error >> 2] = 2;
    label = 25;
    break;
   case 8:
    $_sum69 = $49 + 1 | 0;
    $57 = $4 + $_sum69 | 0;
    $58 = HEAP8[$57] | 0;
    $59 = $58 & 255;
    $60 = $59 << 8;
    $61 = HEAP8[$50] | 0;
    $62 = $61 & 255;
    $63 = $60 | $62;
    $64 = $fi + 40 | 0;
    HEAP32[$64 >> 2] = $63;
    $65 = $63 << 2;
    $_sum70 = $65 + $_sum68 | 0;
    $66 = $4 + $_sum70 | 0;
    $67 = $66 >>> 0 > $6 >>> 0;
    if ($67) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    HEAP32[$error >> 2] = 2;
    label = 25;
    break;
   case 10:
    $70 = ($63 | 0) == 0;
    if ($70) {
      label = 24;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $72 = _ft_mem_realloc($2, 16, 0, $63, 0, $error) | 0;
    $73 = $72;
    $74 = $fi + 36 | 0;
    HEAP32[$74 >> 2] = $73;
    $75 = HEAP32[$error >> 2] | 0;
    $76 = ($75 | 0) == 0;
    if ($76) {
      label = 12;
      break;
    } else {
      label = 25;
      break;
    }
   case 12:
    $78 = HEAP32[$64 >> 2] | 0;
    $79 = $78 << 2;
    $_sum71 = $79 + $_sum68 | 0;
    $80 = $4 + $_sum71 | 0;
    $81 = $t1_face + 92 | 0;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = $t1_face + 36 | 0;
    $84 = HEAP32[$83 >> 2] | 0;
    $85 = $t1_face + 40 | 0;
    $n_0 = 0;
    label = 13;
    break;
   case 13:
    $87 = ($n_0 | 0) < ($84 | 0);
    if ($87) {
      label = 14;
      break;
    } else {
      label = 16;
      break;
    }
   case 14:
    $89 = HEAP32[$85 >> 2] | 0;
    $90 = $89 + ($n_0 << 2) | 0;
    $91 = HEAP32[$90 >> 2] | 0;
    $92 = $91 + 8 | 0;
    $93 = HEAP16[$92 >> 1] | 0;
    $94 = $93 << 16 >> 16 == 7;
    $95 = $n_0 + 1 | 0;
    if ($94) {
      label = 15;
      break;
    } else {
      $n_0 = $95;
      label = 13;
      break;
    }
   case 15:
    $97 = $t1_face;
    $98 = $91;
    $99 = _FT_Set_Charmap($97, $98) | 0;
    HEAP32[$error >> 2] = $99;
    $100 = ($99 | 0) == 0;
    if ($100) {
      label = 16;
      break;
    } else {
      label = 25;
      break;
    }
   case 16:
    $101 = ($_sum68 | 0) < ($_sum71 | 0);
    if ($101) {
      label = 17;
      break;
    } else {
      label = 19;
      break;
    }
   case 17:
    $102 = $t1_face;
    $kp_074 = $73;
    $p_075 = $53;
    label = 18;
    break;
   case 18:
    $104 = HEAP8[$p_075] | 0;
    $105 = $104 & 255;
    $106 = _FT_Get_Char_Index($102, $105) | 0;
    $107 = $kp_074 | 0;
    HEAP32[$107 >> 2] = $106;
    $108 = $p_075 + 1 | 0;
    $109 = HEAP8[$108] | 0;
    $110 = $109 & 255;
    $111 = _FT_Get_Char_Index($102, $110) | 0;
    $112 = $kp_074 + 4 | 0;
    HEAP32[$112 >> 2] = $111;
    $113 = $p_075 + 2 | 0;
    $114 = $p_075 + 3 | 0;
    $115 = HEAP8[$114] | 0;
    $116 = $115 & 255;
    $117 = $116 << 8;
    $118 = HEAP8[$113] | 0;
    $119 = $118 & 255;
    $120 = $117 | $119;
    $121 = $120 << 16 >> 16;
    $122 = $kp_074 + 8 | 0;
    HEAP32[$122 >> 2] = $121;
    $123 = $kp_074 + 12 | 0;
    HEAP32[$123 >> 2] = 0;
    $124 = $kp_074 + 16 | 0;
    $125 = $p_075 + 4 | 0;
    $126 = $125 >>> 0 < $80 >>> 0;
    if ($126) {
      $kp_074 = $124;
      $p_075 = $125;
      label = 18;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $127 = ($82 | 0) == 0;
    if ($127) {
      label = 21;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $129 = $t1_face;
    $130 = $82;
    $131 = _FT_Set_Charmap($129, $130) | 0;
    HEAP32[$error >> 2] = $131;
    $133 = $131;
    label = 22;
    break;
   case 21:
    $_pr = HEAP32[$error >> 2] | 0;
    $133 = $_pr;
    label = 22;
    break;
   case 22:
    $134 = ($133 | 0) == 0;
    if ($134) {
      label = 23;
      break;
    } else {
      label = 24;
      break;
    }
   case 23:
    $136 = HEAP32[$74 >> 2] | 0;
    $137 = $136;
    $138 = HEAP32[$64 >> 2] | 0;
    _qsort($137 | 0, $138 | 0, 16, 674);
    label = 24;
    break;
   case 24:
    $_pr73 = HEAP32[$error >> 2] | 0;
    $140 = ($_pr73 | 0) == 0;
    if ($140) {
      label = 26;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $141 = $fi + 36 | 0;
    $142 = HEAP32[$141 >> 2] | 0;
    $143 = $142;
    _ft_mem_free($2, $143);
    HEAP32[$141 >> 2] = 0;
    $144 = $fi + 40 | 0;
    HEAP32[$144 >> 2] = 0;
    label = 26;
    break;
   case 26:
    $146 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $146 | 0;
  }
  return 0;
}
function _T1_Done_Metrics($memory, $fi) {
  $memory = $memory | 0;
  $fi = $fi | 0;
  var $1 = 0, $5 = 0;
  $1 = $fi + 36 | 0;
  _ft_mem_free($memory, HEAP32[$1 >> 2] | 0);
  HEAP32[$1 >> 2] = 0;
  HEAP32[$fi + 40 >> 2] = 0;
  $5 = $fi + 28 | 0;
  _ft_mem_free($memory, HEAP32[$5 >> 2] | 0);
  HEAP32[$5 >> 2] = 0;
  HEAP32[$fi + 32 >> 2] = 0;
  _ft_mem_free($memory, $fi | 0);
  return;
}
function _T1_Parse_Glyph($decoder, $glyph_index) {
  $decoder = $decoder | 0;
  $glyph_index = $glyph_index | 0;
  var $glyph_data = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $glyph_data = __stackBase__ | 0;
    $1 = _T1_Parse_Glyph_And_Get_Char_String($decoder, $glyph_index, $glyph_data) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $4 = $decoder + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 + 128 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 + 52 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $12 = $9 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 + 4 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $9 + 4 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    FUNCTION_TABLE_vii[$15 & 1023]($17, $glyph_data);
    label = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return $1 | 0;
  }
  return 0;
}
function _T1_Parse_Glyph_And_Get_Char_String($decoder, $glyph_index, $char_string) {
  $decoder = $decoder | 0;
  $glyph_index = $glyph_index | 0;
  $char_string = $char_string | 0;
  var $metrics = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $ld$0$0 = 0, $15$0 = 0, $ld$1$1 = 0, $15$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $_not = 0, $_not32 = 0, $brmerge = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $error_2 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $metrics = __stackBase__ | 0;
    $1 = $decoder + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 128 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 52 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $decoder + 1376 | 0;
    $8 = $2 + 436 | 0;
    $9 = $7;
    $10 = $8;
    _memcpy($9 | 0, $10 | 0, 16);
    $11 = $decoder + 1392 | 0;
    $12 = $2 + 452 | 0;
    $13 = $12;
    $14 = $11;
    $ld$0$0 = $13 | 0;
    $15$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $13 + 4 | 0;
    $15$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $14 | 0;
    HEAP32[$st$2$0 >> 2] = $15$0;
    $st$3$1 = $14 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $15$1;
    $16 = ($6 | 0) != 0;
    if ($16) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $17 = $2 + 424 | 0;
    $18 = $17;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $19 + ($glyph_index << 2) | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $char_string | 0;
    HEAP32[$22 >> 2] = $21;
    $23 = $2 + 428 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24;
    $26 = $25 + ($glyph_index << 2) | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $char_string + 4 | 0;
    HEAP32[$28 >> 2] = $27;
    label = 4;
    break;
   case 3:
    $30 = $6 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $31 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $6 + 4 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = FUNCTION_TABLE_iiii[$33 & 1023]($35, $glyph_index, $char_string) | 0;
    $37 = ($36 | 0) == 0;
    if ($37) {
      label = 4;
      break;
    } else {
      $error_2 = $36;
      label = 7;
      break;
    }
   case 4:
    $39 = $decoder + 1484 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $char_string | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = $char_string + 4 | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    $45 = FUNCTION_TABLE_iiii[$40 & 1023]($decoder, $42, $44) | 0;
    $_not = ($45 | 0) != 0;
    $_not32 = $16 ^ 1;
    $brmerge = $_not | $_not32;
    if ($brmerge) {
      $error_2 = $45;
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $47 = $6 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $48 + 8 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = ($50 | 0) == 0;
    if ($51) {
      $error_2 = $45;
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $53 = $decoder + 32 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = _FT_RoundFix($54) | 0;
    $56 = $55 >> 16;
    $57 = $metrics | 0;
    HEAP32[$57 >> 2] = $56;
    $58 = $metrics + 4 | 0;
    HEAP32[$58 >> 2] = 0;
    $59 = $decoder + 40 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = _FT_RoundFix($60) | 0;
    $62 = $61 >> 16;
    $63 = $metrics + 8 | 0;
    HEAP32[$63 >> 2] = $62;
    $64 = $decoder + 44 | 0;
    $65 = HEAP32[$64 >> 2] | 0;
    $66 = _FT_RoundFix($65) | 0;
    $67 = $66 >> 16;
    $68 = $metrics + 12 | 0;
    HEAP32[$68 >> 2] = $67;
    $69 = HEAP32[$47 >> 2] | 0;
    $70 = $69 + 8 | 0;
    $71 = HEAP32[$70 >> 2] | 0;
    $72 = $6 + 4 | 0;
    $73 = HEAP32[$72 >> 2] | 0;
    $74 = FUNCTION_TABLE_iiiii[$71 & 1023]($73, $glyph_index, 0, $metrics) | 0;
    $75 = HEAP32[$57 >> 2] | 0;
    $76 = $75 << 16;
    HEAP32[$53 >> 2] = $76;
    $77 = HEAP32[$63 >> 2] | 0;
    $78 = $77 << 16;
    HEAP32[$59 >> 2] = $78;
    $79 = HEAP32[$68 >> 2] | 0;
    $80 = $79 << 16;
    HEAP32[$64 >> 2] = $80;
    $error_2 = $74;
    label = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return $error_2 | 0;
  }
  return 0;
}
function _T1_Size_Get_Globals_Funcs($size) {
  $size = $size | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $or_cond = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $21 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 552 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + 96 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + 4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8;
    $10 = _FT_Get_Module($9, 5324472) | 0;
    $11 = $10;
    $12 = ($10 | 0) == 0;
    $13 = ($4 | 0) == 0;
    $or_cond = $12 | $13;
    if ($or_cond) {
      $21 = 0;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $15 = $4;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      $21 = 0;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $19 = FUNCTION_TABLE_ii[$16 & 1023]($11) | 0;
    $21 = $19;
    label = 4;
    break;
   case 4:
    return $21 | 0;
  }
  return 0;
}
function _T1_Done_Blend($face) {
  $face = $face | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $scevgep = 0, $scevgep68 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $n_153 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $exitcond63 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $n_250 = 0, $38 = 0, $39 = 0, $40 = 0, $exitcond61 = 0, $n_349 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $exitcond = 0, $46 = 0, $47 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 532 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 11;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $4 + 4 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $4 + 24 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12;
    _ft_mem_free($2, $13);
    HEAP32[$11 >> 2] = 0;
    $14 = $8 >>> 0 > 1;
    if ($14) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $scevgep = $4 + 28 | 0;
    $scevgep68 = $scevgep;
    $15 = $8 << 2;
    $16 = $15 - 4 | 0;
    _memset($scevgep68 | 0, 0, $16 | 0);
    label = 4;
    break;
   case 4:
    $18 = $4 + 216 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $19;
    _ft_mem_free($2, $20);
    HEAP32[$18 >> 2] = 0;
    $21 = $4 + 148 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22;
    _ft_mem_free($2, $23);
    HEAP32[$21 >> 2] = 0;
    $24 = $4 + 288 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $25;
    _ft_mem_free($2, $26);
    HEAP32[$24 >> 2] = 0;
    $27 = ($8 | 0) == 0;
    if ($27) {
      label = 6;
      break;
    } else {
      $n_153 = 0;
      label = 5;
      break;
    }
   case 5:
    $28 = $4 + 212 + ($n_153 << 2) | 0;
    HEAP32[$28 >> 2] = 0;
    $29 = $4 + 144 + ($n_153 << 2) | 0;
    HEAP32[$29 >> 2] = 0;
    $30 = $4 + 284 + ($n_153 << 2) | 0;
    HEAP32[$30 >> 2] = 0;
    $31 = $n_153 + 1 | 0;
    $exitcond63 = ($31 | 0) == ($8 | 0);
    if ($exitcond63) {
      label = 6;
      break;
    } else {
      $n_153 = $31;
      label = 5;
      break;
    }
   case 6:
    $32 = $4 + 136 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $33;
    _ft_mem_free($2, $34);
    HEAP32[$32 >> 2] = 0;
    $35 = $4 + 140 | 0;
    HEAP32[$35 >> 2] = 0;
    $36 = ($10 | 0) == 0;
    if ($36) {
      label = 10;
      break;
    } else {
      $n_250 = 0;
      label = 8;
      break;
    }
   case 7:
    $37 = ($10 | 0) == 0;
    if ($37) {
      label = 10;
      break;
    } else {
      $n_349 = 0;
      label = 9;
      break;
    }
   case 8:
    $38 = $4 + 8 + ($n_250 << 2) | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    _ft_mem_free($2, $39);
    HEAP32[$38 >> 2] = 0;
    $40 = $n_250 + 1 | 0;
    $exitcond61 = ($40 | 0) == ($10 | 0);
    if ($exitcond61) {
      label = 7;
      break;
    } else {
      $n_250 = $40;
      label = 8;
      break;
    }
   case 9:
    $41 = $4 + 88 + ($n_349 * 12 & -1) + 4 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = $42;
    _ft_mem_free($2, $43);
    HEAP32[$41 >> 2] = 0;
    $44 = $4 + 88 + ($n_349 * 12 & -1) | 0;
    HEAP8[$44] = 0;
    $45 = $n_349 + 1 | 0;
    $exitcond = ($45 | 0) == ($10 | 0);
    if ($exitcond) {
      label = 10;
      break;
    } else {
      $n_349 = $45;
      label = 9;
      break;
    }
   case 10:
    $46 = HEAP32[$3 >> 2] | 0;
    $47 = $46;
    _ft_mem_free($2, $47);
    HEAP32[$3 >> 2] = 0;
    label = 11;
    break;
   case 11:
    return;
  }
}
function _T1_Open_Face($face) {
  $face = $face | 0;
  var $loader = 0, $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $_pr = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $_pr80_pr = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $i_0 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $_pr82 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $114 = 0, $115 = 0, $116 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $charcode_088 = 0, $max_char_087 = 0, $min_char_086 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $idx_0 = 0, $155 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $172 = 0, $charcode_0_min_char_0 = 0, $173 = 0, $174 = 0, $max_char_0_ = 0, $min_char_2 = 0, $max_char_1 = 0, $175 = 0, $176 = 0, $177 = 0, $max_char_0_lcssa = 0, $min_char_0_lcssa = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $184 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 380 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $loader = __stackBase__ | 0;
    $error = __stackBase__ + 376 | 0;
    $1 = $face + 488 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    _t1_init_loader($loader);
    $4 = $face + 536 | 0;
    HEAP32[$4 >> 2] = -1;
    $5 = $face + 540 | 0;
    HEAP32[$5 >> 2] = -1;
    $6 = $face + 544 | 0;
    HEAP32[$6 >> 2] = 0;
    $7 = $face + 280 | 0;
    HEAP32[$7 >> 2] = 7;
    $8 = $face + 284 | 0;
    HEAP32[$8 >> 2] = 1;
    $9 = $face + 172 | 0;
    HEAP32[$9 >> 2] = 4;
    $10 = $face + 348 | 0;
    HEAP32[$10 >> 2] = 3932;
    $11 = $face + 276 | 0;
    HEAP32[$11 >> 2] = 2596864;
    $12 = $loader | 0;
    $13 = $face + 104 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $face + 100 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = _T1_New_Parser($12, $14, $16, $3) | 0;
    HEAP32[$error >> 2] = $17;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 2;
      break;
    } else {
      label = 39;
      break;
    }
   case 2:
    $20 = $loader + 76 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $loader + 80 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = _parse_dict($face, $loader, $21, $23) | 0;
    HEAP32[$error >> 2] = $24;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 3;
      break;
    } else {
      label = 39;
      break;
    }
   case 3:
    $27 = _T1_Get_Private_Dict($12, $3) | 0;
    HEAP32[$error >> 2] = $27;
    $28 = ($27 | 0) == 0;
    if ($28) {
      label = 4;
      break;
    } else {
      label = 39;
      break;
    }
   case 4:
    $30 = $loader + 84 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $loader + 88 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = _parse_dict($face, $loader, $31, $33) | 0;
    HEAP32[$error >> 2] = $34;
    $35 = ($34 | 0) == 0;
    if ($35) {
      label = 5;
      break;
    } else {
      label = 39;
      break;
    }
   case 5:
    $37 = $face + 176 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 & -2;
    HEAP8[$37] = $39;
    $40 = $face + 532 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = ($41 | 0) == 0;
    if ($42) {
      label = 23;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $44 = $41 + 416 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = ($45 | 0) == 0;
    if ($46) {
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $48 = $41 + 4 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = ($45 | 0) == ($49 | 0);
    if ($50) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    HEAP32[$44 >> 2] = 0;
    label = 9;
    break;
   case 9:
    $_pr = HEAP32[$40 >> 2] | 0;
    $53 = ($_pr | 0) == 0;
    if ($53) {
      label = 18;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $55 = $_pr | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = ($56 | 0) == 0;
    if ($57) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $59 = $_pr + 4 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = ($60 | 0) == 0;
    if ($61) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    _T1_Done_Blend($face);
    label = 13;
    break;
   case 13:
    $_pr80_pr = HEAP32[$40 >> 2] | 0;
    $63 = ($_pr80_pr | 0) == 0;
    if ($63) {
      label = 23;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $64 = HEAP32[$40 >> 2] | 0;
    $65 = $64 + 4 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $i_0 = 0;
    label = 15;
    break;
   case 15:
    $68 = $i_0 >>> 0 < $66 >>> 0;
    if ($68) {
      label = 16;
      break;
    } else {
      $75 = $64;
      label = 19;
      break;
    }
   case 16:
    $70 = $64 + 88 + ($i_0 * 12 & -1) | 0;
    $71 = HEAP8[$70] | 0;
    $72 = $71 << 24 >> 24 == 0;
    $73 = $i_0 + 1 | 0;
    if ($72) {
      label = 17;
      break;
    } else {
      $i_0 = $73;
      label = 15;
      break;
    }
   case 17:
    _T1_Done_Blend($face);
    label = 18;
    break;
   case 18:
    $_pr82 = HEAP32[$40 >> 2] | 0;
    $75 = $_pr82;
    label = 19;
    break;
   case 19:
    $76 = ($75 | 0) == 0;
    if ($76) {
      label = 23;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $78 = HEAP32[$6 >> 2] | 0;
    $79 = ($78 | 0) == 0;
    if ($79) {
      label = 23;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $81 = HEAP32[$15 >> 2] | 0;
    $82 = _ft_mem_realloc($81, 4, 0, $78, 0, $error) | 0;
    $83 = $82;
    $84 = $face + 548 | 0;
    HEAP32[$84 >> 2] = $83;
    $85 = HEAP32[$error >> 2] | 0;
    $86 = ($85 | 0) == 0;
    if ($86) {
      label = 23;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    HEAP32[$6 >> 2] = 0;
    label = 39;
    break;
   case 23:
    $88 = $loader + 152 | 0;
    $89 = HEAP32[$88 >> 2] | 0;
    $90 = $face + 416 | 0;
    HEAP32[$90 >> 2] = $89;
    $91 = $loader + 328 | 0;
    $92 = HEAP32[$91 >> 2] | 0;
    $93 = ($92 | 0) == 0;
    if ($93) {
      label = 25;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    HEAP32[$91 >> 2] = 0;
    $95 = $loader + 312 | 0;
    $96 = HEAP32[$95 >> 2] | 0;
    $97 = $face + 404 | 0;
    HEAP32[$97 >> 2] = $96;
    $98 = $loader + 316 | 0;
    $99 = HEAP32[$98 >> 2] | 0;
    $100 = $face + 392 | 0;
    HEAP32[$100 >> 2] = $99;
    $101 = $loader + 340 | 0;
    $102 = HEAP32[$101 >> 2] | 0;
    $103 = $face + 408 | 0;
    HEAP32[$103 >> 2] = $102;
    $104 = $loader + 344 | 0;
    $105 = HEAP32[$104 >> 2] | 0;
    $106 = $face + 412 | 0;
    HEAP32[$106 >> 2] = $105;
    label = 25;
    break;
   case 25:
    $108 = $face + 128 | 0;
    $109 = HEAP32[$108 >> 2] | 0;
    $110 = $109 + 52 | 0;
    $111 = HEAP32[$110 >> 2] | 0;
    $112 = ($111 | 0) == 0;
    if ($112) {
      label = 26;
      break;
    } else {
      label = 28;
      break;
    }
   case 26:
    $114 = $loader + 220 | 0;
    $115 = HEAP32[$114 >> 2] | 0;
    $116 = ($115 | 0) == 0;
    if ($116) {
      label = 27;
      break;
    } else {
      label = 28;
      break;
    }
   case 27:
    HEAP32[$error >> 2] = 3;
    label = 28;
    break;
   case 28:
    $119 = $loader + 220 | 0;
    HEAP32[$119 >> 2] = 0;
    $120 = $loader + 208 | 0;
    $121 = HEAP32[$120 >> 2] | 0;
    $122 = $face + 396 | 0;
    HEAP32[$122 >> 2] = $121;
    $123 = $loader + 232 | 0;
    $124 = HEAP32[$123 >> 2] | 0;
    $125 = $face + 424 | 0;
    HEAP32[$125 >> 2] = $124;
    $126 = $loader + 236 | 0;
    $127 = HEAP32[$126 >> 2] | 0;
    $128 = $face + 428 | 0;
    HEAP32[$128 >> 2] = $127;
    $129 = $loader + 156 | 0;
    $130 = HEAP32[$129 >> 2] | 0;
    $131 = $face + 400 | 0;
    HEAP32[$131 >> 2] = $130;
    $132 = $loader + 180 | 0;
    $133 = HEAP32[$132 >> 2] | 0;
    $134 = $face + 420 | 0;
    HEAP32[$134 >> 2] = $133;
    HEAP32[$129 >> 2] = 0;
    HEAP32[$132 >> 2] = 0;
    $135 = $face + 368 | 0;
    $136 = HEAP32[$135 >> 2] | 0;
    $137 = ($136 | 0) == 1;
    if ($137) {
      label = 29;
      break;
    } else {
      label = 39;
      break;
    }
   case 29:
    $138 = $loader + 116 | 0;
    $139 = HEAP32[$138 >> 2] | 0;
    $140 = ($139 | 0) > 0;
    if ($140) {
      label = 30;
      break;
    } else {
      $min_char_0_lcssa = 0;
      $max_char_0_lcssa = 0;
      label = 38;
      break;
    }
   case 30:
    $141 = $face + 384 | 0;
    $142 = $face + 388 | 0;
    $143 = $loader + 124 | 0;
    $min_char_086 = 0;
    $max_char_087 = 0;
    $charcode_088 = 0;
    label = 31;
    break;
   case 31:
    $145 = HEAP32[$141 >> 2] | 0;
    $146 = $145 + ($charcode_088 << 1) | 0;
    HEAP16[$146 >> 1] = 0;
    $147 = HEAP32[$142 >> 2] | 0;
    $148 = $147 + ($charcode_088 << 2) | 0;
    HEAP32[$148 >> 2] = 5320092;
    $149 = HEAP32[$143 >> 2] | 0;
    $150 = $149 + ($charcode_088 << 2) | 0;
    $151 = HEAP32[$150 >> 2] | 0;
    $152 = ($151 | 0) == 0;
    if ($152) {
      $max_char_1 = $max_char_087;
      $min_char_2 = $min_char_086;
      label = 37;
      break;
    } else {
      label = 32;
      break;
    }
   case 32:
    $153 = HEAP32[$90 >> 2] | 0;
    $idx_0 = 0;
    label = 33;
    break;
   case 33:
    $155 = ($idx_0 | 0) < ($153 | 0);
    if ($155) {
      label = 34;
      break;
    } else {
      $max_char_1 = $max_char_087;
      $min_char_2 = $min_char_086;
      label = 37;
      break;
    }
   case 34:
    $157 = HEAP32[$134 >> 2] | 0;
    $158 = $157 + ($idx_0 << 2) | 0;
    $159 = HEAP32[$158 >> 2] | 0;
    $160 = _strcmp($151 | 0, $159 | 0) | 0;
    $161 = ($160 | 0) == 0;
    $162 = $idx_0 + 1 | 0;
    if ($161) {
      label = 35;
      break;
    } else {
      $idx_0 = $162;
      label = 33;
      break;
    }
   case 35:
    $164 = $idx_0 & 65535;
    $165 = HEAP32[$141 >> 2] | 0;
    $166 = $165 + ($charcode_088 << 1) | 0;
    HEAP16[$166 >> 1] = $164;
    $167 = HEAP32[$142 >> 2] | 0;
    $168 = $167 + ($charcode_088 << 2) | 0;
    HEAP32[$168 >> 2] = $159;
    $169 = _strcmp(5320092, $159 | 0) | 0;
    $170 = ($169 | 0) == 0;
    if ($170) {
      $max_char_1 = $max_char_087;
      $min_char_2 = $min_char_086;
      label = 37;
      break;
    } else {
      label = 36;
      break;
    }
   case 36:
    $172 = ($charcode_088 | 0) < ($min_char_086 | 0);
    $charcode_0_min_char_0 = $172 ? $charcode_088 : $min_char_086;
    $173 = ($charcode_088 | 0) < ($max_char_087 | 0);
    $174 = $charcode_088 + 1 | 0;
    $max_char_0_ = $173 ? $max_char_087 : $174;
    $max_char_1 = $max_char_0_;
    $min_char_2 = $charcode_0_min_char_0;
    label = 37;
    break;
   case 37:
    $175 = $charcode_088 + 1 | 0;
    $176 = HEAP32[$138 >> 2] | 0;
    $177 = ($175 | 0) < ($176 | 0);
    if ($177) {
      $min_char_086 = $min_char_2;
      $max_char_087 = $max_char_1;
      $charcode_088 = $175;
      label = 31;
      break;
    } else {
      $min_char_0_lcssa = $min_char_2;
      $max_char_0_lcssa = $max_char_1;
      label = 38;
      break;
    }
   case 38:
    $178 = $face + 376 | 0;
    HEAP32[$178 >> 2] = $min_char_0_lcssa;
    $179 = $face + 380 | 0;
    HEAP32[$179 >> 2] = $max_char_0_lcssa;
    $180 = $loader + 96 | 0;
    $181 = HEAP32[$180 >> 2] | 0;
    $182 = $face + 372 | 0;
    HEAP32[$182 >> 2] = $181;
    label = 39;
    break;
   case 39:
    _t1_done_loader($loader);
    $184 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $184 | 0;
  }
  return 0;
}
function _T1_Compute_Max_Advance($face, $max_advance) {
  $face = $face | 0;
  $max_advance = $max_advance | 0;
  var $decoder = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $glyph_index_020 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 1500 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $decoder = __stackBase__ | 0;
    $1 = $face + 488 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$max_advance >> 2] = 0;
    $3 = $2 + 12 | 0;
    $4 = $3;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $face | 0;
    $9 = $face + 420 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $face + 532 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = FUNCTION_TABLE_iiiiiiiiii[$7 & 1023]($decoder, $8, 0, 0, $10, $12, 0, 0, 520) | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 2;
      break;
    } else {
      $_0 = $13;
      label = 9;
      break;
    }
   case 2:
    $16 = $decoder + 70 | 0;
    HEAP8[$16] = 1;
    $17 = $decoder + 68 | 0;
    HEAP8[$17] = 0;
    $18 = $face + 404 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $decoder + 1364 | 0;
    HEAP32[$20 >> 2] = $19;
    $21 = $face + 408 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $decoder + 1368 | 0;
    HEAP32[$23 >> 2] = $22;
    $24 = $face + 412 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $decoder + 1372 | 0;
    HEAP32[$26 >> 2] = $25;
    $27 = $face + 548 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $decoder + 1488 | 0;
    HEAP32[$29 >> 2] = $28;
    $30 = $face + 544 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $decoder + 1492 | 0;
    HEAP32[$32 >> 2] = $31;
    HEAP32[$max_advance >> 2] = 0;
    $33 = $face + 416 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = ($34 | 0) > 0;
    if ($35) {
      label = 3;
      break;
    } else {
      label = 8;
      break;
    }
   case 3:
    $36 = $decoder + 40 | 0;
    $37 = $decoder + 40 | 0;
    $glyph_index_020 = 0;
    label = 4;
    break;
   case 4:
    $39 = _T1_Parse_Glyph($decoder, $glyph_index_020) | 0;
    $40 = ($glyph_index_020 | 0) == 0;
    if ($40) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $42 = HEAP32[$37 >> 2] | 0;
    $43 = HEAP32[$max_advance >> 2] | 0;
    $44 = ($42 | 0) > ($43 | 0);
    if ($44) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $46 = HEAP32[$36 >> 2] | 0;
    HEAP32[$max_advance >> 2] = $46;
    label = 7;
    break;
   case 7:
    $48 = $glyph_index_020 + 1 | 0;
    $49 = HEAP32[$33 >> 2] | 0;
    $50 = ($48 | 0) < ($49 | 0);
    if ($50) {
      $glyph_index_020 = $48;
      label = 4;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $51 = HEAP32[$4 >> 2] | 0;
    $52 = $51 + 4 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    FUNCTION_TABLE_vi[$53 & 1023]($decoder);
    $_0 = 0;
    label = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _t1_init_loader($loader) {
  $loader = $loader | 0;
  _memset($loader | 0, 0, 376);
  return;
}
function _T1_New_Parser($parser, $stream, $memory, $psaux) {
  $parser = $parser | 0;
  $stream = $stream | 0;
  $memory = $memory | 0;
  $psaux = $psaux | 0;
  var $error = 0, $tag = 0, $size = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $53 = 0, $54 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $_pr = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $71 = 0, $73 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $tag = __stackBase__ + 4 | 0;
    $size = __stackBase__ + 8 | 0;
    $1 = $psaux + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $parser | 0;
    FUNCTION_TABLE_viiii[$4 & 1023]($5, 0, 0, $memory);
    $6 = $parser + 72 | 0;
    HEAP32[$6 >> 2] = $stream;
    $7 = $parser + 80 | 0;
    $8 = $parser + 76 | 0;
    $9 = $parser + 92 | 0;
    $10 = $parser + 93 | 0;
    $11 = $8;
    _memset($11 | 0, 0, 19);
    $12 = _check_type1_format($stream, 5320600, 14) | 0;
    HEAP32[$error >> 2] = $12;
    if (($12 | 0) == 2) {
      label = 2;
      break;
    } else if (($12 | 0) == 0) {
      label = 3;
      break;
    } else {
      $66 = $12;
      label = 15;
      break;
    }
   case 2:
    $14 = _check_type1_format($stream, 5320528, 10) | 0;
    HEAP32[$error >> 2] = $14;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 3;
      break;
    } else {
      label = 16;
      break;
    }
   case 3:
    $17 = _FT_Stream_Seek($stream, 0) | 0;
    HEAP32[$error >> 2] = $17;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 4;
      break;
    } else {
      label = 16;
      break;
    }
   case 4:
    $20 = _read_pfb_tag($stream, $tag, $size) | 0;
    HEAP32[$error >> 2] = $20;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 5;
      break;
    } else {
      label = 16;
      break;
    }
   case 5:
    $23 = HEAP16[$tag >> 1] | 0;
    $24 = $23 << 16 >> 16 == -32767;
    if ($24) {
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $26 = _FT_Stream_Seek($stream, 0) | 0;
    HEAP32[$error >> 2] = $26;
    $27 = ($26 | 0) == 0;
    if ($27) {
      label = 7;
      break;
    } else {
      label = 16;
      break;
    }
   case 7:
    $29 = $stream + 4 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    HEAP32[$size >> 2] = $30;
    label = 9;
    break;
   case 8:
    HEAP8[$9] = 1;
    label = 9;
    break;
   case 9:
    $33 = $stream + 20 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = ($34 | 0) == 0;
    if ($35) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $37 = $stream | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $stream + 8 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $38 + $40 | 0;
    HEAP32[$8 >> 2] = $41;
    $42 = HEAP32[$size >> 2] | 0;
    HEAP32[$7 >> 2] = $42;
    HEAP8[$10] = 1;
    $43 = HEAP32[$size >> 2] | 0;
    $44 = _FT_Stream_Skip($stream, $43) | 0;
    HEAP32[$error >> 2] = $44;
    $45 = ($44 | 0) == 0;
    if ($45) {
      label = 14;
      break;
    } else {
      label = 16;
      break;
    }
   case 11:
    $47 = HEAP32[$size >> 2] | 0;
    $48 = _ft_mem_alloc($memory, $47, $error) | 0;
    HEAP32[$8 >> 2] = $48;
    $49 = HEAP32[$error >> 2] | 0;
    $50 = ($49 | 0) == 0;
    if ($50) {
      label = 12;
      break;
    } else {
      label = 16;
      break;
    }
   case 12:
    $52 = HEAP32[$size >> 2] | 0;
    $53 = _FT_Stream_Read($stream, $48, $52) | 0;
    HEAP32[$error >> 2] = $53;
    $54 = ($53 | 0) == 0;
    if ($54) {
      label = 13;
      break;
    } else {
      label = 16;
      break;
    }
   case 13:
    $56 = HEAP32[$size >> 2] | 0;
    HEAP32[$7 >> 2] = $56;
    label = 14;
    break;
   case 14:
    $58 = HEAP32[$8 >> 2] | 0;
    $59 = $parser + 4 | 0;
    HEAP32[$59 >> 2] = $58;
    $60 = HEAP32[$8 >> 2] | 0;
    $61 = $parser | 0;
    HEAP32[$61 >> 2] = $60;
    $62 = HEAP32[$7 >> 2] | 0;
    $63 = $60 + $62 | 0;
    $64 = $parser + 8 | 0;
    HEAP32[$64 >> 2] = $63;
    $_pr = HEAP32[$error >> 2] | 0;
    $66 = $_pr;
    label = 15;
    break;
   case 15:
    $67 = ($66 | 0) == 0;
    if ($67) {
      label = 18;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $68 = HEAP8[$10] | 0;
    $69 = $68 << 24 >> 24 == 0;
    if ($69) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    $71 = HEAP32[$8 >> 2] | 0;
    _ft_mem_free($memory, $71);
    HEAP32[$8 >> 2] = 0;
    label = 18;
    break;
   case 18:
    $73 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $73 | 0;
  }
  return 0;
}
function _parse_dict($face, $loader, $base, $size) {
  $face = $face | 0;
  $loader = $loader | 0;
  $base = $base | 0;
  $size = $size | 0;
  var $s = 0, $b = 0, $s1 = 0, $b2 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $start_binary_0152 = 0, $have_integer_0150 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $_pr = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $39 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $53 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $75 = 0, $76 = 0, $77 = 0, $79 = 0, $80 = 0, $81 = 0, $or_cond = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $or_cond139 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $or_cond141 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $or_cond142 = 0, $99 = 0, $100 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $or_cond144 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $_off = 0, $116 = 0, $117 = 0, $or_cond145 = 0, $118 = 0, $120 = 0, $keyword_0148 = 0, $121 = 0, $122 = 0, $124 = 0, $125 = 0, $127 = 0, $128 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $138 = 0, $139 = 0, $141 = 0, $142 = 0, $144 = 0, $145 = 0, $147 = 0, $148 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $156 = 0, $157 = 0, $158 = 0, $have_integer_1 = 0, $start_binary_1 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $s = __stackBase__ | 0;
    $b = __stackBase__ + 4 | 0;
    $s1 = __stackBase__ + 8 | 0;
    $b2 = __stackBase__ + 12 | 0;
    $1 = $loader | 0;
    $2 = $loader | 0;
    $3 = $loader | 0;
    HEAP32[$3 >> 2] = $base;
    $4 = $base + $size | 0;
    $5 = $loader + 8 | 0;
    HEAP32[$5 >> 2] = $4;
    $6 = $loader + 12 | 0;
    HEAP32[$6 >> 2] = 0;
    $7 = HEAP32[$5 >> 2] | 0;
    $8 = $loader + 28 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    FUNCTION_TABLE_vi[$9 & 1023]($2);
    $10 = HEAP32[$3 >> 2] | 0;
    $11 = $10 >>> 0 < $7 >>> 0;
    if ($11) {
      label = 2;
      break;
    } else {
      label = 46;
      break;
    }
   case 2:
    $12 = $loader + 372 | 0;
    $13 = $loader + 32 | 0;
    $14 = $loader + 32 | 0;
    $15 = $loader + 372 | 0;
    $16 = $loader + 32 | 0;
    $have_integer_0150 = 0;
    $start_binary_0152 = 0;
    $18 = $10;
    label = 3;
    break;
   case 3:
    $19 = HEAP8[$18] | 0;
    $20 = $19 << 24 >> 24 == 101;
    if ($20) {
      label = 4;
      break;
    } else {
      $33 = $19;
      label = 9;
      break;
    }
   case 4:
    $22 = $18 + 6 | 0;
    $23 = ($22 | 0) == ($7 | 0);
    if ($23) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $25 = $22 >>> 0 < $7 >>> 0;
    if ($25) {
      label = 6;
      break;
    } else {
      label = 8;
      break;
    }
   case 6:
    $27 = $18 + 5 | 0;
    $28 = HEAP8[$27] | 0;
    if (($28 << 24 >> 24 | 0) == 32 | ($28 << 24 >> 24 | 0) == 13 | ($28 << 24 >> 24 | 0) == 10 | ($28 << 24 >> 24 | 0) == 9 | ($28 << 24 >> 24 | 0) == 12 | ($28 << 24 >> 24 | 0) == 0 | ($28 << 24 >> 24 | 0) == 47 | ($28 << 24 >> 24 | 0) == 40 | ($28 << 24 >> 24 | 0) == 41 | ($28 << 24 >> 24 | 0) == 60 | ($28 << 24 >> 24 | 0) == 62 | ($28 << 24 >> 24 | 0) == 91 | ($28 << 24 >> 24 | 0) == 93 | ($28 << 24 >> 24 | 0) == 123 | ($28 << 24 >> 24 | 0) == 125 | ($28 << 24 >> 24 | 0) == 37) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $30 = _strncmp($18 | 0, 5319708, 5) | 0;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 46;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $_pr = HEAP8[$18] | 0;
    $33 = $_pr;
    label = 9;
    break;
   case 9:
    $34 = $33 << 24 >> 24 == 99;
    if ($34) {
      label = 10;
      break;
    } else {
      label = 14;
      break;
    }
   case 10:
    $36 = $18 + 10 | 0;
    $37 = ($36 | 0) == ($7 | 0);
    if ($37) {
      label = 13;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $39 = $36 >>> 0 < $7 >>> 0;
    if ($39) {
      label = 12;
      break;
    } else {
      label = 14;
      break;
    }
   case 12:
    $41 = $18 + 9 | 0;
    $42 = HEAP8[$41] | 0;
    if (($42 << 24 >> 24 | 0) == 32 | ($42 << 24 >> 24 | 0) == 13 | ($42 << 24 >> 24 | 0) == 10 | ($42 << 24 >> 24 | 0) == 9 | ($42 << 24 >> 24 | 0) == 12 | ($42 << 24 >> 24 | 0) == 0 | ($42 << 24 >> 24 | 0) == 47 | ($42 << 24 >> 24 | 0) == 40 | ($42 << 24 >> 24 | 0) == 41 | ($42 << 24 >> 24 | 0) == 60 | ($42 << 24 >> 24 | 0) == 62 | ($42 << 24 >> 24 | 0) == 91 | ($42 << 24 >> 24 | 0) == 93 | ($42 << 24 >> 24 | 0) == 123 | ($42 << 24 >> 24 | 0) == 125 | ($42 << 24 >> 24 | 0) == 37) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    $44 = _strncmp($18 | 0, 5319400, 9) | 0;
    $45 = ($44 | 0) == 0;
    if ($45) {
      label = 46;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $47 = HEAP8[$18] | 0;
    $48 = $47 << 24 >> 24 == 70;
    if ($48) {
      label = 15;
      break;
    } else {
      label = 22;
      break;
    }
   case 15:
    $50 = $18 + 14 | 0;
    $51 = ($50 | 0) == ($7 | 0);
    if ($51) {
      label = 18;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $53 = $50 >>> 0 < $7 >>> 0;
    if ($53) {
      label = 17;
      break;
    } else {
      label = 22;
      break;
    }
   case 17:
    $55 = $18 + 13 | 0;
    $56 = HEAP8[$55] | 0;
    if (($56 << 24 >> 24 | 0) == 32 | ($56 << 24 >> 24 | 0) == 13 | ($56 << 24 >> 24 | 0) == 10 | ($56 << 24 >> 24 | 0) == 9 | ($56 << 24 >> 24 | 0) == 12 | ($56 << 24 >> 24 | 0) == 0 | ($56 << 24 >> 24 | 0) == 47 | ($56 << 24 >> 24 | 0) == 40 | ($56 << 24 >> 24 | 0) == 41 | ($56 << 24 >> 24 | 0) == 60 | ($56 << 24 >> 24 | 0) == 62 | ($56 << 24 >> 24 | 0) == 91 | ($56 << 24 >> 24 | 0) == 93 | ($56 << 24 >> 24 | 0) == 123 | ($56 << 24 >> 24 | 0) == 125 | ($56 << 24 >> 24 | 0) == 37) {
      label = 18;
      break;
    } else {
      label = 22;
      break;
    }
   case 18:
    $58 = _strncmp($18 | 0, 5324824, 13) | 0;
    $59 = ($58 | 0) == 0;
    if ($59) {
      label = 19;
      break;
    } else {
      label = 22;
      break;
    }
   case 19:
    $61 = HEAP32[$12 >> 2] | 0;
    $62 = $61 & 1;
    $63 = ($62 | 0) == 0;
    if ($63) {
      label = 21;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $65 = $61 | 2;
    HEAP32[$12 >> 2] = $65;
    label = 21;
    break;
   case 21:
    $67 = HEAP32[$3 >> 2] | 0;
    $68 = $67 + 13 | 0;
    HEAP32[$3 >> 2] = $68;
    $start_binary_1 = $start_binary_0152;
    $have_integer_1 = $have_integer_0150;
    label = 45;
    break;
   case 22:
    $70 = HEAP8[$18] | 0;
    $71 = $70 & 255;
    $72 = $71 - 48 | 0;
    $73 = $72 >>> 0 < 10;
    if ($73) {
      label = 23;
      break;
    } else {
      label = 24;
      break;
    }
   case 23:
    $75 = HEAP32[$13 >> 2] | 0;
    FUNCTION_TABLE_vi[$75 & 1023]($2);
    $76 = HEAP32[$6 >> 2] | 0;
    $77 = ($76 | 0) == 0;
    if ($77) {
      $start_binary_1 = $18;
      $have_integer_1 = 1;
      label = 45;
      break;
    } else {
      label = 46;
      break;
    }
   case 24:
    $79 = $70 << 24 >> 24 == 82;
    $80 = $18 + 6 | 0;
    $81 = $80 >>> 0 < $7 >>> 0;
    $or_cond = $79 & $81;
    if ($or_cond) {
      label = 25;
      break;
    } else {
      label = 27;
      break;
    }
   case 25:
    $83 = $18 + 1 | 0;
    $84 = HEAP8[$83] | 0;
    $85 = $84 << 24 >> 24 != 68;
    $86 = $have_integer_0150 << 24 >> 24 == 0;
    $or_cond139 = $85 | $86;
    if ($or_cond139) {
      label = 27;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    HEAP32[$3 >> 2] = $start_binary_0152;
    $88 = _read_binary_data($1, $s, $b) | 0;
    $89 = ($88 | 0) == 0;
    if ($89) {
      $_0 = 3;
      label = 47;
      break;
    } else {
      $start_binary_1 = $start_binary_0152;
      $have_integer_1 = 0;
      label = 45;
      break;
    }
   case 27:
    $91 = HEAP8[$18] | 0;
    $92 = $91 << 24 >> 24 == 45;
    $or_cond141 = $92 & $81;
    if ($or_cond141) {
      label = 28;
      break;
    } else {
      label = 30;
      break;
    }
   case 28:
    $94 = $18 + 1 | 0;
    $95 = HEAP8[$94] | 0;
    $96 = $95 << 24 >> 24 != 124;
    $97 = $have_integer_0150 << 24 >> 24 == 0;
    $or_cond142 = $96 | $97;
    if ($or_cond142) {
      label = 30;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    HEAP32[$3 >> 2] = $start_binary_0152;
    $99 = _read_binary_data($1, $s1, $b2) | 0;
    $100 = ($99 | 0) == 0;
    if ($100) {
      $_0 = 3;
      label = 47;
      break;
    } else {
      $start_binary_1 = $start_binary_0152;
      $have_integer_1 = 0;
      label = 45;
      break;
    }
   case 30:
    $102 = HEAP8[$18] | 0;
    $103 = $102 << 24 >> 24 == 47;
    $104 = $18 + 2 | 0;
    $105 = $104 >>> 0 < $7 >>> 0;
    $or_cond144 = $103 & $105;
    if ($or_cond144) {
      label = 31;
      break;
    } else {
      label = 44;
      break;
    }
   case 31:
    $107 = $18 + 1 | 0;
    HEAP32[$3 >> 2] = $107;
    $108 = HEAP32[$14 >> 2] | 0;
    FUNCTION_TABLE_vi[$108 & 1023]($2);
    $109 = HEAP32[$6 >> 2] | 0;
    $110 = ($109 | 0) == 0;
    if ($110) {
      label = 32;
      break;
    } else {
      label = 46;
      break;
    }
   case 32:
    $112 = HEAP32[$3 >> 2] | 0;
    $113 = $112;
    $114 = $107;
    $115 = $113 - $114 | 0;
    $_off = $115 - 1 | 0;
    $116 = $_off >>> 0 < 21;
    $117 = $112 >>> 0 < $7 >>> 0;
    $or_cond145 = $116 & $117;
    if ($or_cond145) {
      label = 33;
      break;
    } else {
      $start_binary_1 = $start_binary_0152;
      $have_integer_1 = 0;
      label = 45;
      break;
    }
   case 33:
    $118 = HEAP8[$107] | 0;
    $keyword_0148 = 5246752;
    $120 = 5324420;
    label = 34;
    break;
   case 34:
    $121 = HEAP8[$120] | 0;
    $122 = $118 << 24 >> 24 == $121 << 24 >> 24;
    if ($122) {
      label = 35;
      break;
    } else {
      label = 43;
      break;
    }
   case 35:
    $124 = _strlen($120 | 0) | 0;
    $125 = ($115 | 0) == ($124 | 0);
    if ($125) {
      label = 36;
      break;
    } else {
      label = 43;
      break;
    }
   case 36:
    $127 = _memcmp($107 | 0, $120 | 0, $115 | 0) | 0;
    $128 = ($127 | 0) == 0;
    if ($128) {
      label = 37;
      break;
    } else {
      label = 43;
      break;
    }
   case 37:
    $130 = HEAP32[$15 >> 2] | 0;
    $131 = $130 & 1;
    $132 = $131 + 1 | 0;
    $133 = $keyword_0148 + 32 | 0;
    $134 = HEAP32[$133 >> 2] | 0;
    $135 = $132 & $134;
    $136 = ($135 | 0) == 0;
    if ($136) {
      $start_binary_1 = $start_binary_0152;
      $have_integer_1 = 0;
      label = 45;
      break;
    } else {
      label = 38;
      break;
    }
   case 38:
    $138 = $130 & 2;
    $139 = ($138 | 0) == 0;
    if ($139) {
      label = 40;
      break;
    } else {
      label = 39;
      break;
    }
   case 39:
    $141 = _strcmp($120 | 0, 5324540) | 0;
    $142 = ($141 | 0) == 0;
    if ($142) {
      label = 40;
      break;
    } else {
      $start_binary_1 = $start_binary_0152;
      $have_integer_1 = 0;
      label = 45;
      break;
    }
   case 40:
    $144 = _t1_load_keyword($face, $loader, $keyword_0148) | 0;
    HEAP32[$6 >> 2] = $144;
    $145 = ($144 | 0) == 0;
    if ($145) {
      $start_binary_1 = $start_binary_0152;
      $have_integer_1 = 0;
      label = 45;
      break;
    } else {
      label = 41;
      break;
    }
   case 41:
    $147 = $144 & 255;
    $148 = ($147 | 0) == 162;
    if ($148) {
      label = 42;
      break;
    } else {
      $_0 = $144;
      label = 47;
      break;
    }
   case 42:
    HEAP32[$6 >> 2] = 0;
    $start_binary_1 = $start_binary_0152;
    $have_integer_1 = 0;
    label = 45;
    break;
   case 43:
    $151 = $keyword_0148 + 36 | 0;
    $152 = $151 | 0;
    $153 = HEAP32[$152 >> 2] | 0;
    $154 = ($153 | 0) == 0;
    if ($154) {
      $start_binary_1 = $start_binary_0152;
      $have_integer_1 = 0;
      label = 45;
      break;
    } else {
      $keyword_0148 = $151;
      $120 = $153;
      label = 34;
      break;
    }
   case 44:
    $156 = HEAP32[$16 >> 2] | 0;
    FUNCTION_TABLE_vi[$156 & 1023]($2);
    $157 = HEAP32[$6 >> 2] | 0;
    $158 = ($157 | 0) == 0;
    if ($158) {
      $start_binary_1 = $start_binary_0152;
      $have_integer_1 = 0;
      label = 45;
      break;
    } else {
      label = 46;
      break;
    }
   case 45:
    $159 = HEAP32[$8 >> 2] | 0;
    FUNCTION_TABLE_vi[$159 & 1023]($2);
    $160 = HEAP32[$3 >> 2] | 0;
    $161 = $160 >>> 0 < $7 >>> 0;
    if ($161) {
      $have_integer_0150 = $have_integer_1;
      $start_binary_0152 = $start_binary_1;
      $18 = $160;
      label = 3;
      break;
    } else {
      label = 46;
      break;
    }
   case 46:
    $162 = HEAP32[$6 >> 2] | 0;
    $_0 = $162;
    label = 47;
    break;
   case 47:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _T1_Get_Private_Dict($parser, $psaux) {
  $parser = $parser | 0;
  $psaux = $psaux | 0;
  var $error = 0, $size = 0, $tag = 0, $len = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $or_cond137 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $or_cond = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $limit_0_ph = 0, $cur_0_ph = 0, $cur_0 = 0, $69 = 0, $70 = 0, $72 = 0, $73 = 0, $75 = 0, $76 = 0, $77 = 0, $79 = 0, $80 = 0, $81 = 0, $83 = 0, $84 = 0, $85 = 0, $87 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $95 = 0, $cur_1132 = 0, $96 = 0, $cur_1133 = 0, $97 = 0, $98 = 0, $100 = 0, $101 = 0, $103 = 0, $104 = 0, $105 = 0, $107 = 0, $cur_1 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $cur_2131 = 0, $120 = 0, $121 = 0, $122 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $140 = 0, $141 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $or_cond114 = 0, $155 = 0, $156 = 0, $or_cond116 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $or_cond118 = 0, $165 = 0, $166 = 0, $or_cond120 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $or_cond122 = 0, $175 = 0, $176 = 0, $or_cond124 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $or_cond126 = 0, $185 = 0, $186 = 0, $or_cond128 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $200 = 0, $202 = 0, $203 = 0, $204 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $228 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $size = __stackBase__ + 4 | 0;
    $tag = __stackBase__ + 8 | 0;
    $len = __stackBase__ + 12 | 0;
    $1 = $parser + 72 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $parser | 0;
    $4 = $parser + 16 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $6 = $parser + 92 | 0;
    $7 = HEAP8[$6] | 0;
    $8 = $7 << 24 >> 24 == 0;
    if ($8) {
      label = 15;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = _FT_Stream_Pos($2) | 0;
    $11 = $parser + 88 | 0;
    HEAP32[$11 >> 2] = 0;
    label = 3;
    break;
   case 3:
    $13 = _read_pfb_tag($2, $tag, $size) | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 4;
      break;
    } else {
      $226 = $13;
      label = 47;
      break;
    }
   case 4:
    $16 = HEAP16[$tag >> 1] | 0;
    $17 = $16 << 16 >> 16 == -32766;
    if ($17) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $19 = HEAP32[$size >> 2] | 0;
    $20 = HEAP32[$11 >> 2] | 0;
    $21 = $20 + $19 | 0;
    HEAP32[$11 >> 2] = $21;
    $22 = HEAP32[$size >> 2] | 0;
    $23 = _FT_Stream_Skip($2, $22) | 0;
    $24 = ($23 | 0) == 0;
    if ($24) {
      label = 3;
      break;
    } else {
      $226 = $23;
      label = 47;
      break;
    }
   case 6:
    HEAP32[$error >> 2] = $13;
    $26 = HEAP32[$11 >> 2] | 0;
    $27 = ($26 | 0) == 0;
    if ($27) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    HEAP32[$error >> 2] = 3;
    label = 48;
    break;
   case 8:
    $30 = _FT_Stream_Seek($2, $10) | 0;
    HEAP32[$error >> 2] = $30;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 9;
      break;
    } else {
      label = 48;
      break;
    }
   case 9:
    $33 = HEAP32[$11 >> 2] | 0;
    $34 = _ft_mem_alloc($5, $33, $error) | 0;
    $35 = $parser + 84 | 0;
    HEAP32[$35 >> 2] = $34;
    $36 = HEAP32[$error >> 2] | 0;
    $37 = ($36 | 0) == 0;
    if ($37) {
      label = 10;
      break;
    } else {
      label = 48;
      break;
    }
   case 10:
    HEAP32[$11 >> 2] = 0;
    $38 = _read_pfb_tag($2, $tag, $size) | 0;
    HEAP32[$error >> 2] = $38;
    $39 = ($38 | 0) == 0;
    $40 = HEAP16[$tag >> 1] | 0;
    $41 = $40 << 16 >> 16 == -32766;
    $or_cond137 = $39 & $41;
    if ($or_cond137) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    HEAP32[$error >> 2] = $53;
    label = 12;
    break;
   case 12:
    HEAP32[$error >> 2] = 0;
    label = 45;
    break;
   case 13:
    $43 = HEAP32[$35 >> 2] | 0;
    $44 = HEAP32[$11 >> 2] | 0;
    $45 = $43 + $44 | 0;
    $46 = HEAP32[$size >> 2] | 0;
    $47 = _FT_Stream_Read($2, $45, $46) | 0;
    $48 = ($47 | 0) == 0;
    if ($48) {
      label = 14;
      break;
    } else {
      label = 46;
      break;
    }
   case 14:
    $50 = HEAP32[$size >> 2] | 0;
    $51 = HEAP32[$11 >> 2] | 0;
    $52 = $51 + $50 | 0;
    HEAP32[$11 >> 2] = $52;
    $53 = _read_pfb_tag($2, $tag, $size) | 0;
    $54 = ($53 | 0) == 0;
    $55 = HEAP16[$tag >> 1] | 0;
    $56 = $55 << 16 >> 16 == -32766;
    $or_cond = $54 & $56;
    if ($or_cond) {
      label = 13;
      break;
    } else {
      label = 11;
      break;
    }
   case 15:
    $58 = $parser + 76 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = $parser + 80 | 0;
    $61 = HEAP32[$60 >> 2] | 0;
    $62 = $59 + $61 | 0;
    $63 = $parser | 0;
    $64 = $parser + 8 | 0;
    $65 = $parser + 32 | 0;
    $66 = $parser + 12 | 0;
    $67 = $parser + 28 | 0;
    $cur_0_ph = $59;
    $limit_0_ph = $62;
    label = 16;
    break;
   case 16:
    $cur_0 = $cur_0_ph;
    label = 17;
    break;
   case 17:
    $69 = HEAP8[$cur_0] | 0;
    $70 = $69 << 24 >> 24 == 101;
    if ($70) {
      label = 18;
      break;
    } else {
      label = 23;
      break;
    }
   case 18:
    $72 = $cur_0 + 9 | 0;
    $73 = $72 >>> 0 < $limit_0_ph >>> 0;
    if ($73) {
      label = 19;
      break;
    } else {
      label = 23;
      break;
    }
   case 19:
    $75 = $cur_0 + 1 | 0;
    $76 = HEAP8[$75] | 0;
    $77 = $76 << 24 >> 24 == 101;
    if ($77) {
      label = 20;
      break;
    } else {
      label = 23;
      break;
    }
   case 20:
    $79 = $cur_0 + 2 | 0;
    $80 = HEAP8[$79] | 0;
    $81 = $80 << 24 >> 24 == 120;
    if ($81) {
      label = 21;
      break;
    } else {
      label = 23;
      break;
    }
   case 21:
    $83 = $cur_0 + 3 | 0;
    $84 = HEAP8[$83] | 0;
    $85 = $84 << 24 >> 24 == 101;
    if ($85) {
      label = 22;
      break;
    } else {
      label = 23;
      break;
    }
   case 22:
    $87 = $cur_0 + 4 | 0;
    $88 = HEAP8[$87] | 0;
    $89 = $88 << 24 >> 24 == 99;
    if ($89) {
      label = 25;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $91 = $cur_0 + 1 | 0;
    $92 = $91 >>> 0 < $limit_0_ph >>> 0;
    if ($92) {
      $cur_0 = $91;
      label = 17;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    HEAP32[$error >> 2] = 3;
    label = 48;
    break;
   case 25:
    $95 = HEAP32[$58 >> 2] | 0;
    HEAP32[$63 >> 2] = $95;
    HEAP32[$64 >> 2] = $72;
    $cur_1132 = HEAP32[$63 >> 2] | 0;
    $96 = $cur_1132 >>> 0 < $72 >>> 0;
    if ($96) {
      $cur_1133 = $cur_1132;
      label = 26;
      break;
    } else {
      label = 30;
      break;
    }
   case 26:
    $97 = HEAP8[$cur_1133] | 0;
    $98 = $97 << 24 >> 24 == 101;
    if ($98) {
      label = 27;
      break;
    } else {
      label = 28;
      break;
    }
   case 27:
    $100 = _strncmp($cur_1133 | 0, 5319708, 5) | 0;
    $101 = ($100 | 0) == 0;
    if ($101) {
      label = 31;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $103 = HEAP32[$65 >> 2] | 0;
    FUNCTION_TABLE_vi[$103 & 1023]($3);
    $104 = HEAP32[$66 >> 2] | 0;
    $105 = ($104 | 0) == 0;
    if ($105) {
      label = 29;
      break;
    } else {
      label = 30;
      break;
    }
   case 29:
    $107 = HEAP32[$67 >> 2] | 0;
    FUNCTION_TABLE_vi[$107 & 1023]($3);
    $cur_1 = HEAP32[$63 >> 2] | 0;
    $108 = $cur_1 >>> 0 < $72 >>> 0;
    if ($108) {
      $cur_1133 = $cur_1;
      label = 26;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    $109 = HEAP32[$58 >> 2] | 0;
    $110 = HEAP32[$60 >> 2] | 0;
    $111 = $109 + $110 | 0;
    $cur_0_ph = $72;
    $limit_0_ph = $111;
    label = 16;
    break;
   case 31:
    $113 = HEAP32[$58 >> 2] | 0;
    $114 = HEAP32[$60 >> 2] | 0;
    $115 = $113 + $114 | 0;
    HEAP32[$64 >> 2] = $115;
    $116 = $parser + 32 | 0;
    $117 = HEAP32[$116 >> 2] | 0;
    FUNCTION_TABLE_vi[$117 & 1023]($3);
    $118 = HEAP32[$63 >> 2] | 0;
    $119 = $118 >>> 0 < $72 >>> 0;
    if ($119) {
      $cur_2131 = $118;
      label = 32;
      break;
    } else {
      label = 34;
      break;
    }
   case 32:
    $120 = HEAP8[$cur_2131] | 0;
    if (($120 << 24 >> 24 | 0) == 32 | ($120 << 24 >> 24 | 0) == 9 | ($120 << 24 >> 24 | 0) == 13 | ($120 << 24 >> 24 | 0) == 10) {
      label = 33;
      break;
    } else {
      label = 35;
      break;
    }
   case 33:
    $121 = $cur_2131 + 1 | 0;
    $122 = $121 >>> 0 < $72 >>> 0;
    if ($122) {
      $cur_2131 = $121;
      label = 32;
      break;
    } else {
      label = 34;
      break;
    }
   case 34:
    HEAP32[$error >> 2] = 3;
    label = 48;
    break;
   case 35:
    $124 = HEAP32[$60 >> 2] | 0;
    $125 = HEAP32[$58 >> 2] | 0;
    $126 = $cur_2131;
    $127 = $125;
    $128 = $127 - $126 | 0;
    $129 = $128 + $124 | 0;
    HEAP32[$size >> 2] = $129;
    $130 = $parser + 93 | 0;
    $131 = HEAP8[$130] | 0;
    $132 = $131 << 24 >> 24 == 0;
    if ($132) {
      label = 38;
      break;
    } else {
      label = 36;
      break;
    }
   case 36:
    $134 = $129 + 1 | 0;
    $135 = _ft_mem_alloc($5, $134, $error) | 0;
    $136 = $parser + 84 | 0;
    HEAP32[$136 >> 2] = $135;
    $137 = HEAP32[$error >> 2] | 0;
    $138 = ($137 | 0) == 0;
    if ($138) {
      label = 37;
      break;
    } else {
      label = 48;
      break;
    }
   case 37:
    $140 = HEAP32[$size >> 2] | 0;
    $141 = $parser + 88 | 0;
    HEAP32[$141 >> 2] = $140;
    label = 39;
    break;
   case 38:
    $143 = $parser + 94 | 0;
    HEAP8[$143] = 1;
    $144 = HEAP32[$58 >> 2] | 0;
    $145 = $parser + 84 | 0;
    HEAP32[$145 >> 2] = $144;
    $146 = HEAP32[$size >> 2] | 0;
    $147 = $parser + 88 | 0;
    HEAP32[$147 >> 2] = $146;
    HEAP32[$58 >> 2] = 0;
    HEAP32[$60 >> 2] = 0;
    label = 39;
    break;
   case 39:
    $149 = HEAP8[$cur_2131] | 0;
    $150 = $149 & 255;
    $151 = $150 - 48 | 0;
    $152 = $151 >>> 0 < 10;
    $153 = $150 - 97 | 0;
    $154 = $153 >>> 0 < 6;
    $or_cond114 = $152 | $154;
    $155 = $150 - 65 | 0;
    $156 = $155 >>> 0 < 6;
    $or_cond116 = $or_cond114 | $156;
    if ($or_cond116) {
      label = 40;
      break;
    } else {
      label = 44;
      break;
    }
   case 40:
    $158 = $cur_2131 + 1 | 0;
    $159 = HEAP8[$158] | 0;
    $160 = $159 & 255;
    $161 = $160 - 48 | 0;
    $162 = $161 >>> 0 < 10;
    $163 = $160 - 97 | 0;
    $164 = $163 >>> 0 < 6;
    $or_cond118 = $162 | $164;
    $165 = $160 - 65 | 0;
    $166 = $165 >>> 0 < 6;
    $or_cond120 = $or_cond118 | $166;
    if ($or_cond120) {
      label = 41;
      break;
    } else {
      label = 44;
      break;
    }
   case 41:
    $168 = $cur_2131 + 2 | 0;
    $169 = HEAP8[$168] | 0;
    $170 = $169 & 255;
    $171 = $170 - 48 | 0;
    $172 = $171 >>> 0 < 10;
    $173 = $170 - 97 | 0;
    $174 = $173 >>> 0 < 6;
    $or_cond122 = $172 | $174;
    $175 = $170 - 65 | 0;
    $176 = $175 >>> 0 < 6;
    $or_cond124 = $or_cond122 | $176;
    if ($or_cond124) {
      label = 42;
      break;
    } else {
      label = 44;
      break;
    }
   case 42:
    $178 = $cur_2131 + 3 | 0;
    $179 = HEAP8[$178] | 0;
    $180 = $179 & 255;
    $181 = $180 - 48 | 0;
    $182 = $181 >>> 0 < 10;
    $183 = $180 - 97 | 0;
    $184 = $183 >>> 0 < 6;
    $or_cond126 = $182 | $184;
    $185 = $180 - 65 | 0;
    $186 = $185 >>> 0 < 6;
    $or_cond128 = $or_cond126 | $186;
    if ($or_cond128) {
      label = 43;
      break;
    } else {
      label = 44;
      break;
    }
   case 43:
    HEAP32[$63 >> 2] = $cur_2131;
    $188 = $psaux + 4 | 0;
    $189 = HEAP32[$188 >> 2] | 0;
    $190 = $189 + 24 | 0;
    $191 = HEAP32[$190 >> 2] | 0;
    $192 = $parser + 84 | 0;
    $193 = HEAP32[$192 >> 2] | 0;
    $194 = $parser + 88 | 0;
    $195 = HEAP32[$194 >> 2] | 0;
    $196 = FUNCTION_TABLE_iiiiii[$191 & 1023]($3, $193, $195, $len, 0) | 0;
    $197 = HEAP32[$len >> 2] | 0;
    HEAP32[$194 >> 2] = $197;
    $198 = HEAP32[$len >> 2] | 0;
    $199 = HEAP32[$192 >> 2] | 0;
    $200 = $199 + $198 | 0;
    HEAP8[$200] = 0;
    label = 45;
    break;
   case 44:
    $202 = $parser + 84 | 0;
    $203 = HEAP32[$202 >> 2] | 0;
    $204 = HEAP32[$size >> 2] | 0;
    _memmove($203 | 0, $cur_2131 | 0, $204 | 0);
    label = 45;
    break;
   case 45:
    $206 = $psaux + 16 | 0;
    $207 = HEAP32[$206 >> 2] | 0;
    $208 = $parser + 84 | 0;
    $209 = HEAP32[$208 >> 2] | 0;
    $210 = $parser + 88 | 0;
    $211 = HEAP32[$210 >> 2] | 0;
    FUNCTION_TABLE_viii[$207 & 1023]($209, $211, -9871);
    $212 = HEAP32[$208 >> 2] | 0;
    HEAP8[$212] = 32;
    $213 = HEAP32[$208 >> 2] | 0;
    $214 = $213 + 1 | 0;
    HEAP8[$214] = 32;
    $215 = HEAP32[$208 >> 2] | 0;
    $216 = $215 + 2 | 0;
    HEAP8[$216] = 32;
    $217 = HEAP32[$208 >> 2] | 0;
    $218 = $217 + 3 | 0;
    HEAP8[$218] = 32;
    $219 = HEAP32[$208 >> 2] | 0;
    $220 = $parser + 4 | 0;
    HEAP32[$220 >> 2] = $219;
    $221 = HEAP32[$208 >> 2] | 0;
    $222 = $parser | 0;
    HEAP32[$222 >> 2] = $221;
    $223 = HEAP32[$210 >> 2] | 0;
    $224 = $221 + $223 | 0;
    $225 = $parser + 8 | 0;
    HEAP32[$225 >> 2] = $224;
    label = 48;
    break;
   case 46:
    HEAP32[$error >> 2] = $47;
    label = 48;
    break;
   case 47:
    HEAP32[$error >> 2] = $226;
    label = 48;
    break;
   case 48:
    $228 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $228 | 0;
  }
  return 0;
}
function _t1_done_loader($loader) {
  $loader = $loader | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $loader | 0;
    $2 = $loader + 148 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $loader + 100 | 0;
    FUNCTION_TABLE_vi[$3 & 1023]($6);
    label = 3;
    break;
   case 3:
    $8 = $loader + 256 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $12 = $loader + 208 | 0;
    FUNCTION_TABLE_vi[$9 & 1023]($12);
    label = 5;
    break;
   case 5:
    $14 = $loader + 204 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $18 = $loader + 156 | 0;
    FUNCTION_TABLE_vi[$15 & 1023]($18);
    label = 7;
    break;
   case 7:
    $20 = $loader + 308 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $24 = $loader + 260 | 0;
    FUNCTION_TABLE_vi[$21 & 1023]($24);
    label = 9;
    break;
   case 9:
    $26 = $loader + 364 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = ($27 | 0) == 0;
    if ($28) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $30 = $loader + 316 | 0;
    FUNCTION_TABLE_vi[$27 & 1023]($30);
    label = 11;
    break;
   case 11:
    _T1_Finalize_Parser($1);
    return;
  }
}
function _T1_Finalize_Parser($parser) {
  $parser = $parser | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $parser | 0;
    $2 = $parser + 16 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $parser + 84 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    _ft_mem_free($3, $5);
    HEAP32[$4 >> 2] = 0;
    $6 = $parser + 93 | 0;
    $7 = HEAP8[$6] | 0;
    $8 = $7 << 24 >> 24 == 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $10 = $parser + 76 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    _ft_mem_free($3, $11);
    HEAP32[$10 >> 2] = 0;
    label = 3;
    break;
   case 3:
    $13 = $parser + 24 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    FUNCTION_TABLE_vi[$14 & 1023]($1);
    return;
  }
}
function _read_pfb_tag($stream, $atag, $asize) {
  $stream = $stream | 0;
  $atag = $atag | 0;
  $asize = $asize | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $_off = 0, $switch = 0, $6 = 0, $7 = 0, $8 = 0, $12 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP16[$atag >> 1] = 0;
    HEAP32[$asize >> 2] = 0;
    $1 = _FT_Stream_ReadShort($stream, $error) | 0;
    $2 = HEAP32[$error >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $_off = $1 + 32767 & 65535;
    $switch = ($_off & 65535) < 2;
    if ($switch) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $6 = _FT_Stream_ReadLongLE($stream, $error) | 0;
    $7 = HEAP32[$error >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    HEAP32[$asize >> 2] = $6;
    label = 5;
    break;
   case 5:
    HEAP16[$atag >> 1] = $1;
    label = 6;
    break;
   case 6:
    $12 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $12 | 0;
  }
  return 0;
}
function _read_binary_data($parser, $size, $base) {
  $parser = $parser | 0;
  $size = $size | 0;
  $base = $base | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $parser | 0;
    $2 = $parser + 8 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $parser + 28 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    FUNCTION_TABLE_vi[$5 & 1023]($1);
    $6 = $parser | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 >>> 0 < $3 >>> 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $10 = HEAP8[$7] | 0;
    $11 = $10 & 255;
    $12 = $11 - 48 | 0;
    $13 = $12 >>> 0 < 10;
    if ($13) {
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 3:
    $15 = $parser + 36 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = FUNCTION_TABLE_ii[$16 & 1023]($1) | 0;
    $18 = $parser + 32 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    FUNCTION_TABLE_vi[$19 & 1023]($1);
    $20 = HEAP32[$6 >> 2] | 0;
    $21 = $20 + 1 | 0;
    HEAP32[$base >> 2] = $21;
    $22 = ($17 | 0) > -1;
    if ($22) {
      label = 4;
      break;
    } else {
      label = 6;
      break;
    }
   case 4:
    $24 = $3;
    $25 = $21;
    $26 = $24 - $25 | 0;
    $27 = ($17 | 0) < ($26 | 0);
    if ($27) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $29 = $17 + 1 | 0;
    $30 = HEAP32[$6 >> 2] | 0;
    $31 = $30 + $29 | 0;
    HEAP32[$6 >> 2] = $31;
    HEAP32[$size >> 2] = $17;
    $32 = $parser + 12 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = ($33 | 0) == 0;
    $35 = $34 & 1;
    $_0 = $35;
    label = 7;
    break;
   case 6:
    $37 = $parser + 12 | 0;
    HEAP32[$37 >> 2] = 3;
    $_0 = 0;
    label = 7;
    break;
   case 7:
    return $_0 | 0;
  }
  return 0;
}
function _t1_load_keyword($face, $loader, $field) {
  $face = $face | 0;
  $loader = $loader | 0;
  $field = $field | 0;
  var $dummy_object = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $49 = 0, $51 = 0, $53 = 0, $54 = 0, $objects_0 = 0, $max_objects_0 = 0, $56 = 0, $_off = 0, $switch = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $dummy_object = __stackBase__ | 0;
    $1 = $face + 532 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $field + 8 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 10;
    if ($5) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $7 = $field + 12 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $face | 0;
    $10 = $loader;
    FUNCTION_TABLE_vii[$8 & 1023]($9, $10);
    $11 = $loader + 12 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $error_0 = $12;
    label = 18;
    break;
   case 3:
    $14 = $field + 4 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    if (($15 | 0) == 3) {
      label = 4;
      break;
    } else if (($15 | 0) == 2) {
      label = 6;
      break;
    } else if (($15 | 0) == 4) {
      label = 7;
      break;
    } else if (($15 | 0) == 5) {
      label = 9;
      break;
    } else if (($15 | 0) == 6) {
      label = 11;
      break;
    } else if (($15 | 0) == 7) {
      label = 12;
      break;
    } else if (($15 | 0) == 8) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 4:
    $17 = $face + 132 | 0;
    $18 = $17;
    HEAP32[$dummy_object >> 2] = $18;
    $19 = ($2 | 0) == 0;
    if ($19) {
      $max_objects_0 = 0;
      $objects_0 = $dummy_object;
      label = 15;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $21 = $2 + 144 | 0;
    $22 = $21;
    $23 = $2 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $max_objects_0 = $24;
    $objects_0 = $22;
    label = 15;
    break;
   case 6:
    $26 = $face + 164 | 0;
    $27 = $26;
    HEAP32[$dummy_object >> 2] = $27;
    $max_objects_0 = 0;
    $objects_0 = $dummy_object;
    label = 15;
    break;
   case 7:
    $29 = $face + 168 | 0;
    $30 = $29;
    HEAP32[$dummy_object >> 2] = $30;
    $31 = ($2 | 0) == 0;
    if ($31) {
      $max_objects_0 = 0;
      $objects_0 = $dummy_object;
      label = 15;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $33 = $2 + 212 | 0;
    $34 = $33;
    $35 = $2 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $max_objects_0 = $36;
    $objects_0 = $34;
    label = 15;
    break;
   case 9:
    $38 = $face + 460 | 0;
    $39 = $38;
    HEAP32[$dummy_object >> 2] = $39;
    $40 = ($2 | 0) == 0;
    if ($40) {
      $max_objects_0 = 0;
      $objects_0 = $dummy_object;
      label = 15;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $42 = $2 + 284 | 0;
    $43 = $42;
    $44 = $2 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $max_objects_0 = $45;
    $objects_0 = $43;
    label = 15;
    break;
   case 11:
    $47 = $loader;
    HEAP32[$dummy_object >> 2] = $47;
    $max_objects_0 = 0;
    $objects_0 = $dummy_object;
    label = 15;
    break;
   case 12:
    $49 = $face;
    HEAP32[$dummy_object >> 2] = $49;
    $max_objects_0 = 0;
    $objects_0 = $dummy_object;
    label = 15;
    break;
   case 13:
    $51 = $2;
    HEAP32[$dummy_object >> 2] = $51;
    $max_objects_0 = 0;
    $objects_0 = $dummy_object;
    label = 15;
    break;
   case 14:
    $53 = $face + 132 | 0;
    $54 = $53;
    HEAP32[$dummy_object >> 2] = $54;
    $max_objects_0 = 0;
    $objects_0 = $dummy_object;
    label = 15;
    break;
   case 15:
    $56 = HEAP32[$3 >> 2] | 0;
    $_off = $56 - 8 | 0;
    $switch = $_off >>> 0 < 2;
    $57 = $loader | 0;
    if ($switch) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    $59 = $loader + 68 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = FUNCTION_TABLE_iiiiii[$60 & 1023]($57, $field, $objects_0, $max_objects_0, 0) | 0;
    $error_0 = $61;
    label = 18;
    break;
   case 17:
    $63 = $loader + 64 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = FUNCTION_TABLE_iiiiii[$64 & 1023]($57, $field, $objects_0, $max_objects_0, 0) | 0;
    $error_0 = $65;
    label = 18;
    break;
   case 18:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _parse_font_matrix($face, $loader) {
  $face = $face | 0;
  $loader = $loader | 0;
  var $temp = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 24 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $temp = __stackBase__ | 0;
    $1 = $loader | 0;
    $2 = $loader + 52 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $temp | 0;
    $5 = FUNCTION_TABLE_iiiii[$3 & 1023]($1, 6, $4, 3) | 0;
    $6 = ($5 | 0) < 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $8 = $loader + 12 | 0;
    HEAP32[$8 >> 2] = 3;
    label = 8;
    break;
   case 3:
    $10 = $temp + 12 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($11 | 0) < 0;
    $13 = -$11 | 0;
    $14 = $12 ? $13 : $11;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $17 = $loader + 12 | 0;
    HEAP32[$17 >> 2] = 3;
    label = 8;
    break;
   case 5:
    $19 = _FT_DivFix(65536e3, $14) | 0;
    $20 = $19 >>> 16;
    $21 = $20 & 65535;
    $22 = $face + 68 | 0;
    HEAP16[$22 >> 1] = $21;
    $23 = ($14 | 0) == 65536;
    if ($23) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $25 = HEAP32[$4 >> 2] | 0;
    $26 = _FT_DivFix($25, $14) | 0;
    HEAP32[$4 >> 2] = $26;
    $27 = $temp + 4 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = _FT_DivFix($28, $14) | 0;
    HEAP32[$27 >> 2] = $29;
    $30 = $temp + 8 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = _FT_DivFix($31, $14) | 0;
    HEAP32[$30 >> 2] = $32;
    $33 = $temp + 16 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = _FT_DivFix($34, $14) | 0;
    HEAP32[$33 >> 2] = $35;
    $36 = $temp + 20 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = _FT_DivFix($37, $14) | 0;
    HEAP32[$36 >> 2] = $38;
    $39 = HEAP32[$10 >> 2] | 0;
    $40 = $39 >> 31;
    $41 = $40 & -131072;
    $42 = $41 | 65536;
    HEAP32[$10 >> 2] = $42;
    label = 7;
    break;
   case 7:
    $44 = HEAP32[$4 >> 2] | 0;
    $45 = $face + 436 | 0;
    HEAP32[$45 >> 2] = $44;
    $46 = $temp + 4 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $face + 444 | 0;
    HEAP32[$48 >> 2] = $47;
    $49 = $temp + 8 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $face + 440 | 0;
    HEAP32[$51 >> 2] = $50;
    $52 = HEAP32[$10 >> 2] | 0;
    $53 = $face + 448 | 0;
    HEAP32[$53 >> 2] = $52;
    $54 = $temp + 16 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = $55 >> 16;
    $57 = $face + 452 | 0;
    HEAP32[$57 >> 2] = $56;
    $58 = $temp + 20 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = $59 >> 16;
    $61 = $face + 456 | 0;
    HEAP32[$61 >> 2] = $60;
    label = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return;
  }
}
function _parse_encoding($face, $loader) {
  $face = $face | 0;
  $loader = $loader | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $or_cond = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $only_immediates_0 = 0, $count_0 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $n_0123 = 0, $60 = 0, $61 = 0, $62 = 0, $exitcond = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $76 = 0, $n_1122 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $83 = 0, $84 = 0, $85 = 0, $87 = 0, $88 = 0, $89 = 0, $91 = 0, $_pr = 0, $93 = 0, $94 = 0, $96 = 0, $98 = 0, $99 = 0, $100 = 0, $or_cond114 = 0, $103 = 0, $104 = 0, $105 = 0, $charcode_0 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $or_cond116 = 0, $112 = 0, $or_cond117 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $135 = 0, $137 = 0, $138 = 0, $139 = 0, $n_2 = 0, $cur_1 = 0, $141 = 0, $142 = 0, $143 = 0, $cur_2 = 0, $144 = 0, $146 = 0, $147 = 0, $149 = 0, $150 = 0, $152 = 0, $154 = 0, $155 = 0, $157 = 0, $158 = 0, $160 = 0, $162 = 0, $163 = 0, $165 = 0, $166 = 0, $168 = 0, $170 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $loader | 0;
    $2 = $loader + 8 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $face + 488 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $loader + 28 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    FUNCTION_TABLE_vi[$7 & 1023]($1);
    $8 = $loader | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 >>> 0 < $3 >>> 0;
    if ($10) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $12 = $loader + 12 | 0;
    HEAP32[$12 >> 2] = 3;
    label = 47;
    break;
   case 3:
    $14 = HEAP8[$9] | 0;
    $15 = $14 & 255;
    $16 = $15 - 48 | 0;
    $17 = $16 >>> 0 < 10;
    $18 = $14 << 24 >> 24 == 91;
    $or_cond = $17 | $18;
    if ($or_cond) {
      label = 4;
      break;
    } else {
      label = 37;
      break;
    }
   case 4:
    $20 = $loader + 100 | 0;
    $21 = $loader + 16 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    if ($18) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $24 = $9 + 1 | 0;
    HEAP32[$8 >> 2] = $24;
    $count_0 = 256;
    $only_immediates_0 = 1;
    label = 7;
    break;
   case 6:
    $26 = $loader + 36 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = FUNCTION_TABLE_ii[$27 & 1023]($1) | 0;
    $count_0 = $28;
    $only_immediates_0 = 0;
    label = 7;
    break;
   case 7:
    $30 = HEAP32[$6 >> 2] | 0;
    FUNCTION_TABLE_vi[$30 & 1023]($1);
    $31 = HEAP32[$8 >> 2] | 0;
    $32 = $31 >>> 0 < $3 >>> 0;
    if ($32) {
      label = 8;
      break;
    } else {
      label = 47;
      break;
    }
   case 8:
    $34 = $face + 372 | 0;
    HEAP32[$34 >> 2] = $count_0;
    $35 = $loader + 96 | 0;
    HEAP32[$35 >> 2] = $count_0;
    $36 = _ft_mem_realloc($22, 2, 0, $count_0, 0, $error) | 0;
    $37 = $36;
    $38 = $face + 384 | 0;
    HEAP32[$38 >> 2] = $37;
    $39 = HEAP32[$error >> 2] | 0;
    $40 = ($39 | 0) == 0;
    if ($40) {
      label = 9;
      break;
    } else {
      label = 13;
      break;
    }
   case 9:
    $42 = _ft_mem_realloc($22, 4, 0, $count_0, 0, $error) | 0;
    $43 = $42;
    $44 = $face + 388 | 0;
    HEAP32[$44 >> 2] = $43;
    $45 = HEAP32[$error >> 2] | 0;
    $46 = ($45 | 0) == 0;
    if ($46) {
      label = 10;
      break;
    } else {
      label = 13;
      break;
    }
   case 10:
    $48 = $5;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = $49 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = FUNCTION_TABLE_iiii[$51 & 1023]($20, $count_0, $22) | 0;
    HEAP32[$error >> 2] = $52;
    $53 = ($52 | 0) == 0;
    if ($53) {
      label = 11;
      break;
    } else {
      label = 13;
      break;
    }
   case 11:
    $54 = ($count_0 | 0) > 0;
    if ($54) {
      label = 12;
      break;
    } else {
      label = 15;
      break;
    }
   case 12:
    $55 = $loader + 144 | 0;
    $n_0123 = 0;
    label = 14;
    break;
   case 13:
    $57 = HEAP32[$error >> 2] | 0;
    $58 = $loader + 12 | 0;
    HEAP32[$58 >> 2] = $57;
    label = 47;
    break;
   case 14:
    $60 = HEAP32[$55 >> 2] | 0;
    $61 = FUNCTION_TABLE_iiiii[$60 & 1023]($20, $n_0123, 5320092, 8) | 0;
    $62 = $n_0123 + 1 | 0;
    $exitcond = ($62 | 0) == ($count_0 | 0);
    if ($exitcond) {
      label = 15;
      break;
    } else {
      $n_0123 = $62;
      label = 14;
      break;
    }
   case 15:
    $63 = HEAP32[$6 >> 2] | 0;
    FUNCTION_TABLE_vi[$63 & 1023]($1);
    $64 = HEAP32[$8 >> 2] | 0;
    $65 = $64 >>> 0 < $3 >>> 0;
    if ($65) {
      label = 16;
      break;
    } else {
      $cur_2 = $9;
      label = 36;
      break;
    }
   case 16:
    $66 = $only_immediates_0 << 24 >> 24 == 0;
    $67 = $loader + 32 | 0;
    $68 = $loader + 12 | 0;
    $69 = $only_immediates_0 << 24 >> 24 != 0;
    $70 = $loader + 32 | 0;
    $71 = $loader + 12 | 0;
    $72 = $loader + 144 | 0;
    $73 = $loader + 124 | 0;
    $74 = $loader + 36 | 0;
    $n_1122 = 0;
    $76 = $64;
    label = 17;
    break;
   case 17:
    $77 = HEAP8[$76] | 0;
    $78 = $77 << 24 >> 24 == 100;
    if ($78) {
      label = 18;
      break;
    } else {
      $93 = $77;
      label = 23;
      break;
    }
   case 18:
    $80 = $76 + 3 | 0;
    $81 = $80 >>> 0 < $3 >>> 0;
    if ($81) {
      label = 19;
      break;
    } else {
      label = 22;
      break;
    }
   case 19:
    $83 = $76 + 1 | 0;
    $84 = HEAP8[$83] | 0;
    $85 = $84 << 24 >> 24 == 101;
    if ($85) {
      label = 20;
      break;
    } else {
      label = 22;
      break;
    }
   case 20:
    $87 = $76 + 2 | 0;
    $88 = HEAP8[$87] | 0;
    $89 = $88 << 24 >> 24 == 102;
    if ($89) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    $91 = HEAP8[$80] | 0;
    if (($91 << 24 >> 24 | 0) == 32 | ($91 << 24 >> 24 | 0) == 13 | ($91 << 24 >> 24 | 0) == 10 | ($91 << 24 >> 24 | 0) == 9 | ($91 << 24 >> 24 | 0) == 12 | ($91 << 24 >> 24 | 0) == 0 | ($91 << 24 >> 24 | 0) == 47 | ($91 << 24 >> 24 | 0) == 40 | ($91 << 24 >> 24 | 0) == 41 | ($91 << 24 >> 24 | 0) == 60 | ($91 << 24 >> 24 | 0) == 62 | ($91 << 24 >> 24 | 0) == 91 | ($91 << 24 >> 24 | 0) == 93 | ($91 << 24 >> 24 | 0) == 123 | ($91 << 24 >> 24 | 0) == 125 | ($91 << 24 >> 24 | 0) == 37) {
      $cur_2 = $80;
      label = 36;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $_pr = HEAP8[$76] | 0;
    $93 = $_pr;
    label = 23;
    break;
   case 23:
    $94 = $93 << 24 >> 24 == 93;
    if ($94) {
      label = 24;
      break;
    } else {
      label = 25;
      break;
    }
   case 24:
    $96 = $76 + 1 | 0;
    $cur_2 = $96;
    label = 36;
    break;
   case 25:
    $98 = $93 & 255;
    $99 = $98 - 48 | 0;
    $100 = $99 >>> 0 > 9;
    $or_cond114 = $100 & $66;
    if ($or_cond114) {
      label = 34;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    if ($69) {
      $charcode_0 = $n_1122;
      label = 28;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $103 = HEAP32[$74 >> 2] | 0;
    $104 = FUNCTION_TABLE_ii[$103 & 1023]($1) | 0;
    $105 = HEAP32[$6 >> 2] | 0;
    FUNCTION_TABLE_vi[$105 & 1023]($1);
    $charcode_0 = $104;
    label = 28;
    break;
   case 28:
    $107 = HEAP32[$8 >> 2] | 0;
    $108 = HEAP8[$107] | 0;
    $109 = $108 << 24 >> 24 == 47;
    $110 = $107 + 2 | 0;
    $111 = $110 >>> 0 < $3 >>> 0;
    $or_cond116 = $109 & $111;
    $112 = ($n_1122 | 0) < ($count_0 | 0);
    $or_cond117 = $or_cond116 & $112;
    if ($or_cond117) {
      label = 29;
      break;
    } else {
      label = 32;
      break;
    }
   case 29:
    $114 = $107 + 1 | 0;
    HEAP32[$8 >> 2] = $114;
    $115 = HEAP32[$70 >> 2] | 0;
    FUNCTION_TABLE_vi[$115 & 1023]($1);
    $116 = HEAP32[$71 >> 2] | 0;
    $117 = ($116 | 0) == 0;
    if ($117) {
      label = 30;
      break;
    } else {
      label = 47;
      break;
    }
   case 30:
    $119 = HEAP32[$8 >> 2] | 0;
    $120 = $119;
    $121 = $114;
    $122 = $120 - $121 | 0;
    $123 = HEAP32[$72 >> 2] | 0;
    $124 = $122 + 1 | 0;
    $125 = FUNCTION_TABLE_iiiii[$123 & 1023]($20, $charcode_0, $114, $124) | 0;
    HEAP32[$71 >> 2] = $125;
    $126 = ($125 | 0) == 0;
    if ($126) {
      label = 31;
      break;
    } else {
      label = 47;
      break;
    }
   case 31:
    $128 = HEAP32[$73 >> 2] | 0;
    $129 = $128 + ($charcode_0 << 2) | 0;
    $130 = HEAP32[$129 >> 2] | 0;
    $131 = $130 + $122 | 0;
    HEAP8[$131] = 0;
    $132 = $n_1122 + 1 | 0;
    $cur_1 = $114;
    $n_2 = $132;
    label = 35;
    break;
   case 32:
    if ($69) {
      label = 33;
      break;
    } else {
      $cur_1 = $107;
      $n_2 = $n_1122;
      label = 35;
      break;
    }
   case 33:
    $135 = $loader + 12 | 0;
    HEAP32[$135 >> 2] = 2;
    label = 47;
    break;
   case 34:
    $137 = HEAP32[$67 >> 2] | 0;
    FUNCTION_TABLE_vi[$137 & 1023]($1);
    $138 = HEAP32[$68 >> 2] | 0;
    $139 = ($138 | 0) == 0;
    if ($139) {
      $cur_1 = $76;
      $n_2 = $n_1122;
      label = 35;
      break;
    } else {
      label = 47;
      break;
    }
   case 35:
    $141 = HEAP32[$6 >> 2] | 0;
    FUNCTION_TABLE_vi[$141 & 1023]($1);
    $142 = HEAP32[$8 >> 2] | 0;
    $143 = $142 >>> 0 < $3 >>> 0;
    if ($143) {
      $n_1122 = $n_2;
      $76 = $142;
      label = 17;
      break;
    } else {
      $cur_2 = $cur_1;
      label = 36;
      break;
    }
   case 36:
    $144 = $face + 368 | 0;
    HEAP32[$144 >> 2] = 1;
    HEAP32[$8 >> 2] = $cur_2;
    label = 47;
    break;
   case 37:
    $146 = $9 + 17 | 0;
    $147 = $146 >>> 0 < $3 >>> 0;
    if ($147) {
      label = 38;
      break;
    } else {
      label = 40;
      break;
    }
   case 38:
    $149 = _strncmp($9 | 0, 5320804, 16) | 0;
    $150 = ($149 | 0) == 0;
    if ($150) {
      label = 39;
      break;
    } else {
      label = 40;
      break;
    }
   case 39:
    $152 = $face + 368 | 0;
    HEAP32[$152 >> 2] = 2;
    label = 47;
    break;
   case 40:
    $154 = $9 + 15 | 0;
    $155 = $154 >>> 0 < $3 >>> 0;
    if ($155) {
      label = 41;
      break;
    } else {
      label = 43;
      break;
    }
   case 41:
    $157 = _strncmp($9 | 0, 5320752, 14) | 0;
    $158 = ($157 | 0) == 0;
    if ($158) {
      label = 42;
      break;
    } else {
      label = 43;
      break;
    }
   case 42:
    $160 = $face + 368 | 0;
    HEAP32[$160 >> 2] = 4;
    label = 47;
    break;
   case 43:
    $162 = $9 + 18 | 0;
    $163 = $162 >>> 0 < $3 >>> 0;
    if ($163) {
      label = 44;
      break;
    } else {
      label = 46;
      break;
    }
   case 44:
    $165 = _strncmp($9 | 0, 5320668, 17) | 0;
    $166 = ($165 | 0) == 0;
    if ($166) {
      label = 45;
      break;
    } else {
      label = 46;
      break;
    }
   case 45:
    $168 = $face + 368 | 0;
    HEAP32[$168 >> 2] = 3;
    label = 47;
    break;
   case 46:
    $170 = $loader + 12 | 0;
    HEAP32[$170 >> 2] = 162;
    label = 47;
    break;
   case 47:
    STACKTOP = __stackBase__;
    return;
  }
}
function _parse_subrs($face, $loader) {
  $face = $face | 0;
  $loader = $loader | 0;
  var $error = 0, $size = 0, $base = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $84 = 0, $85 = 0, $87 = 0, $88 = 0, $91 = 0, $92 = 0, $93 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $_pr = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $117 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $size = __stackBase__ + 4 | 0;
    $base = __stackBase__ + 8 | 0;
    $1 = $loader | 0;
    $2 = $loader + 316 | 0;
    $3 = $loader | 0;
    $4 = $loader + 16 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $face + 488 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $loader + 28 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    FUNCTION_TABLE_vi[$9 & 1023]($3);
    $10 = $loader | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $loader + 8 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $11 >>> 0 < $13 >>> 0;
    if ($14) {
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $16 = HEAP8[$11] | 0;
    $17 = $16 << 24 >> 24 == 91;
    if ($17) {
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 3:
    $19 = $loader + 32 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    FUNCTION_TABLE_vi[$20 & 1023]($3);
    $21 = HEAP32[$8 >> 2] | 0;
    FUNCTION_TABLE_vi[$21 & 1023]($3);
    $22 = HEAP32[$10 >> 2] | 0;
    $23 = HEAP32[$12 >> 2] | 0;
    $24 = $22 >>> 0 < $23 >>> 0;
    if ($24) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $26 = HEAP8[$22] | 0;
    $27 = $26 << 24 >> 24 == 93;
    if ($27) {
      label = 27;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $29 = $loader + 12 | 0;
    HEAP32[$29 >> 2] = 3;
    label = 27;
    break;
   case 6:
    $31 = $loader + 36 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = FUNCTION_TABLE_ii[$32 & 1023]($3) | 0;
    $34 = $loader + 32 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    FUNCTION_TABLE_vi[$35 & 1023]($3);
    $36 = $loader + 12 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = ($37 | 0) == 0;
    if ($38) {
      label = 7;
      break;
    } else {
      label = 27;
      break;
    }
   case 7:
    $40 = HEAP32[$8 >> 2] | 0;
    FUNCTION_TABLE_vi[$40 & 1023]($3);
    $41 = $loader + 312 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = ($42 | 0) == 0;
    if ($43) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $45 = $7;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $46 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = FUNCTION_TABLE_iiii[$48 & 1023]($2, $33, $5) | 0;
    HEAP32[$error >> 2] = $49;
    $50 = ($49 | 0) == 0;
    if ($50) {
      label = 9;
      break;
    } else {
      label = 26;
      break;
    }
   case 9:
    $51 = HEAP32[$10 >> 2] | 0;
    $52 = _strncmp($51 | 0, 5320932, 3) | 0;
    $53 = ($52 | 0) == 0;
    if ($53) {
      label = 10;
      break;
    } else {
      label = 24;
      break;
    }
   case 10:
    $54 = $face + 172 | 0;
    $55 = $7 + 16 | 0;
    $56 = $55;
    $57 = $loader + 360 | 0;
    $58 = $loader + 360 | 0;
    label = 11;
    break;
   case 11:
    $60 = HEAP32[$34 >> 2] | 0;
    FUNCTION_TABLE_vi[$60 & 1023]($3);
    $61 = HEAP32[$31 >> 2] | 0;
    $62 = FUNCTION_TABLE_ii[$61 & 1023]($3) | 0;
    $63 = _read_binary_data($1, $size, $base) | 0;
    $64 = ($63 | 0) == 0;
    if ($64) {
      label = 27;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $66 = HEAP32[$34 >> 2] | 0;
    FUNCTION_TABLE_vi[$66 & 1023]($3);
    $67 = HEAP32[$36 >> 2] | 0;
    $68 = ($67 | 0) == 0;
    if ($68) {
      label = 13;
      break;
    } else {
      label = 27;
      break;
    }
   case 13:
    $70 = HEAP32[$8 >> 2] | 0;
    FUNCTION_TABLE_vi[$70 & 1023]($3);
    $71 = HEAP32[$10 >> 2] | 0;
    $72 = _strncmp($71 | 0, 5320868, 3) | 0;
    $73 = ($72 | 0) == 0;
    if ($73) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $75 = HEAP32[$34 >> 2] | 0;
    FUNCTION_TABLE_vi[$75 & 1023]($3);
    $76 = HEAP32[$8 >> 2] | 0;
    FUNCTION_TABLE_vi[$76 & 1023]($3);
    label = 15;
    break;
   case 15:
    $78 = HEAP32[$41 >> 2] | 0;
    $79 = ($78 | 0) == 0;
    if ($79) {
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $80 = HEAP32[$10 >> 2] | 0;
    $81 = _strncmp($80 | 0, 5320932, 3) | 0;
    $82 = ($81 | 0) == 0;
    if ($82) {
      label = 11;
      break;
    } else {
      label = 24;
      break;
    }
   case 17:
    $84 = HEAP32[$54 >> 2] | 0;
    $85 = ($84 | 0) > -1;
    if ($85) {
      label = 18;
      break;
    } else {
      label = 22;
      break;
    }
   case 18:
    $87 = HEAP32[$size >> 2] | 0;
    $88 = ($87 | 0) < ($84 | 0);
    if ($88) {
      label = 19;
      break;
    } else {
      label = 20;
      break;
    }
   case 19:
    HEAP32[$error >> 2] = 3;
    label = 26;
    break;
   case 20:
    $91 = _ft_mem_alloc($5, $87, $error) | 0;
    $92 = HEAP32[$error >> 2] | 0;
    $93 = ($92 | 0) == 0;
    if ($93) {
      label = 21;
      break;
    } else {
      label = 26;
      break;
    }
   case 21:
    $95 = HEAP32[$base >> 2] | 0;
    $96 = HEAP32[$size >> 2] | 0;
    _memcpy($91 | 0, $95 | 0, $96 | 0);
    $97 = HEAP32[$56 >> 2] | 0;
    $98 = HEAP32[$size >> 2] | 0;
    FUNCTION_TABLE_viii[$97 & 1023]($91, $98, 4330);
    $99 = HEAP32[$54 >> 2] | 0;
    $100 = HEAP32[$size >> 2] | 0;
    $101 = $100 - $99 | 0;
    HEAP32[$size >> 2] = $101;
    $102 = HEAP32[$57 >> 2] | 0;
    $103 = HEAP32[$54 >> 2] | 0;
    $104 = $91 + $103 | 0;
    $105 = FUNCTION_TABLE_iiiii[$102 & 1023]($2, $62, $104, $101) | 0;
    HEAP32[$error >> 2] = $105;
    _ft_mem_free($5, $91);
    $_pr = HEAP32[$error >> 2] | 0;
    $112 = $_pr;
    label = 23;
    break;
   case 22:
    $107 = HEAP32[$58 >> 2] | 0;
    $108 = HEAP32[$base >> 2] | 0;
    $109 = HEAP32[$size >> 2] | 0;
    $110 = FUNCTION_TABLE_iiiii[$107 & 1023]($2, $62, $108, $109) | 0;
    HEAP32[$error >> 2] = $110;
    $112 = $110;
    label = 23;
    break;
   case 23:
    $113 = ($112 | 0) == 0;
    if ($113) {
      label = 16;
      break;
    } else {
      label = 26;
      break;
    }
   case 24:
    $114 = HEAP32[$41 >> 2] | 0;
    $115 = ($114 | 0) == 0;
    if ($115) {
      label = 25;
      break;
    } else {
      label = 27;
      break;
    }
   case 25:
    HEAP32[$41 >> 2] = $33;
    label = 27;
    break;
   case 26:
    $117 = HEAP32[$error >> 2] | 0;
    HEAP32[$36 >> 2] = $117;
    label = 27;
    break;
   case 27:
    STACKTOP = __stackBase__;
    return;
  }
}
function _parse_private($face, $loader) {
  $face = $face | 0;
  $loader = $loader | 0;
  var $1 = 0;
  $1 = $loader + 372 | 0;
  HEAP32[$1 >> 2] = HEAP32[$1 >> 2] | 1;
  return;
}
function _parse_charstrings($face, $loader) {
  $face = $face | 0;
  $loader = $loader | 0;
  var $error = 0, $size = 0, $base = 0, $notdef_glyph = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $notdef_index_0_ph = 0, $notdef_found_0_ph = 0, $n_0_ph = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $64 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $71 = 0, $73 = 0, $74 = 0, $75 = 0, $or_cond = 0, $_pr = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $82 = 0, $84 = 0, $85 = 0, $86 = 0, $88 = 0, $89 = 0, $90 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $98 = 0, $99 = 0, $102 = 0, $103 = 0, $104 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $n_0_notdef_index_0 = 0, $_notdef_found_0 = 0, $notdef_index_1 = 0, $notdef_found_1 = 0, $130 = 0, $131 = 0, $132 = 0, $or_cond195 = 0, $134 = 0, $135 = 0, $138 = 0, $139 = 0, $140 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $_pr149 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $159 = 0, $160 = 0, $161 = 0, $cond = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $197 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $207 = 0, $208 = 0, $209 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $218 = 0, $219 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $229 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $239 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $249 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $301 = 0, $302 = 0, $303 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 20 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $size = __stackBase__ + 4 | 0;
    $base = __stackBase__ + 8 | 0;
    $notdef_glyph = __stackBase__ + 12 | 0;
    $1 = $loader | 0;
    $2 = $loader + 208 | 0;
    $3 = $loader + 156 | 0;
    $4 = $loader + 260 | 0;
    $5 = $loader | 0;
    $6 = $loader + 16 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $face + 488 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $loader + 8 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $loader + 36 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = FUNCTION_TABLE_ii[$13 & 1023]($5) | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 54;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $17 = $loader + 12 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 3;
      break;
    } else {
      label = 54;
      break;
    }
   case 3:
    $21 = $loader + 152 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = ($22 | 0) == 0;
    if ($23) {
      label = 4;
      break;
    } else {
      label = 7;
      break;
    }
   case 4:
    $25 = $9;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $26 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $14 + 6 | 0;
    $30 = FUNCTION_TABLE_iiii[$28 & 1023]($2, $29, $7) | 0;
    HEAP32[$error >> 2] = $30;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 5;
      break;
    } else {
      label = 53;
      break;
    }
   case 5:
    $33 = HEAP32[$25 >> 2] | 0;
    $34 = $33 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = FUNCTION_TABLE_iiii[$35 & 1023]($3, $29, $7) | 0;
    HEAP32[$error >> 2] = $36;
    $37 = ($36 | 0) == 0;
    if ($37) {
      label = 6;
      break;
    } else {
      label = 53;
      break;
    }
   case 6:
    $39 = HEAP32[$25 >> 2] | 0;
    $40 = $39 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = FUNCTION_TABLE_iiii[$41 & 1023]($4, 4, $7) | 0;
    HEAP32[$error >> 2] = $42;
    $43 = ($42 | 0) == 0;
    if ($43) {
      label = 7;
      break;
    } else {
      label = 53;
      break;
    }
   case 7:
    $44 = $loader + 28 | 0;
    $45 = $loader | 0;
    $46 = $loader + 32 | 0;
    $47 = $loader + 200 | 0;
    $48 = $loader + 180 | 0;
    $49 = $face + 172 | 0;
    $50 = $14 + 5 | 0;
    $51 = $9 + 16 | 0;
    $52 = $51;
    $53 = $loader + 252 | 0;
    $54 = $loader + 252 | 0;
    $n_0_ph = 0;
    $notdef_found_0_ph = 0;
    $notdef_index_0_ph = 0;
    label = 8;
    break;
   case 8:
    $55 = HEAP32[$44 >> 2] | 0;
    FUNCTION_TABLE_vi[$55 & 1023]($5);
    $56 = HEAP32[$45 >> 2] | 0;
    $57 = $56 >>> 0 < $11 >>> 0;
    if ($57) {
      label = 9;
      break;
    } else {
      label = 36;
      break;
    }
   case 9:
    $58 = ($n_0_ph | 0) == 0;
    $60 = $56;
    label = 10;
    break;
   case 10:
    $61 = $60 + 3 | 0;
    $62 = $61 >>> 0 < $11 >>> 0;
    if ($62) {
      label = 11;
      break;
    } else {
      label = 19;
      break;
    }
   case 11:
    $64 = HEAP8[$61] | 0;
    if (($64 << 24 >> 24 | 0) == 32 | ($64 << 24 >> 24 | 0) == 13 | ($64 << 24 >> 24 | 0) == 10 | ($64 << 24 >> 24 | 0) == 9 | ($64 << 24 >> 24 | 0) == 12 | ($64 << 24 >> 24 | 0) == 0 | ($64 << 24 >> 24 | 0) == 47 | ($64 << 24 >> 24 | 0) == 40 | ($64 << 24 >> 24 | 0) == 41 | ($64 << 24 >> 24 | 0) == 60 | ($64 << 24 >> 24 | 0) == 62 | ($64 << 24 >> 24 | 0) == 91 | ($64 << 24 >> 24 | 0) == 93 | ($64 << 24 >> 24 | 0) == 123 | ($64 << 24 >> 24 | 0) == 125 | ($64 << 24 >> 24 | 0) == 37) {
      label = 12;
      break;
    } else {
      label = 19;
      break;
    }
   case 12:
    $66 = HEAP8[$60] | 0;
    $67 = $66 << 24 >> 24 == 100;
    if ($67) {
      label = 13;
      break;
    } else {
      $77 = $66;
      label = 16;
      break;
    }
   case 13:
    $69 = $60 + 1 | 0;
    $70 = HEAP8[$69] | 0;
    $71 = $70 << 24 >> 24 == 101;
    if ($71) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $73 = $60 + 2 | 0;
    $74 = HEAP8[$73] | 0;
    $75 = $74 << 24 >> 24 != 102;
    $or_cond = $75 | $58;
    if ($or_cond) {
      label = 15;
      break;
    } else {
      label = 36;
      break;
    }
   case 15:
    $_pr = HEAP8[$60] | 0;
    $77 = $_pr;
    label = 16;
    break;
   case 16:
    $78 = $77 << 24 >> 24 == 101;
    if ($78) {
      label = 17;
      break;
    } else {
      label = 19;
      break;
    }
   case 17:
    $80 = $60 + 1 | 0;
    $81 = HEAP8[$80] | 0;
    $82 = $81 << 24 >> 24 == 110;
    if ($82) {
      label = 18;
      break;
    } else {
      label = 19;
      break;
    }
   case 18:
    $84 = $60 + 2 | 0;
    $85 = HEAP8[$84] | 0;
    $86 = $85 << 24 >> 24 == 100;
    if ($86) {
      label = 36;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $88 = HEAP32[$46 >> 2] | 0;
    FUNCTION_TABLE_vi[$88 & 1023]($5);
    $89 = HEAP32[$17 >> 2] | 0;
    $90 = ($89 | 0) == 0;
    if ($90) {
      label = 20;
      break;
    } else {
      label = 54;
      break;
    }
   case 20:
    $92 = HEAP8[$60] | 0;
    $93 = $92 << 24 >> 24 == 47;
    if ($93) {
      label = 22;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $94 = HEAP32[$44 >> 2] | 0;
    FUNCTION_TABLE_vi[$94 & 1023]($5);
    $95 = HEAP32[$45 >> 2] | 0;
    $96 = $95 >>> 0 < $11 >>> 0;
    if ($96) {
      $60 = $95;
      label = 10;
      break;
    } else {
      label = 36;
      break;
    }
   case 22:
    $98 = $60 + 1 | 0;
    $99 = $98 >>> 0 < $11 >>> 0;
    if ($99) {
      label = 24;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    HEAP32[$error >> 2] = 3;
    label = 53;
    break;
   case 24:
    $102 = HEAP32[$45 >> 2] | 0;
    $103 = _read_binary_data($1, $size, $base) | 0;
    $104 = ($103 | 0) == 0;
    if ($104) {
      label = 54;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $106 = $98;
    $107 = $102;
    $108 = $107 - $106 | 0;
    $109 = HEAP32[$21 >> 2] | 0;
    $110 = ($109 | 0) == 0;
    if ($110) {
      label = 26;
      break;
    } else {
      label = 21;
      break;
    }
   case 26:
    $112 = HEAP32[$47 >> 2] | 0;
    $113 = $108 + 1 | 0;
    $114 = FUNCTION_TABLE_iiiii[$112 & 1023]($3, $n_0_ph, $98, $113) | 0;
    HEAP32[$error >> 2] = $114;
    $115 = ($114 | 0) == 0;
    if ($115) {
      label = 27;
      break;
    } else {
      label = 53;
      break;
    }
   case 27:
    $117 = HEAP32[$48 >> 2] | 0;
    $118 = $117 + ($n_0_ph << 2) | 0;
    $119 = HEAP32[$118 >> 2] | 0;
    $120 = $119 + $108 | 0;
    HEAP8[$120] = 0;
    $121 = HEAP8[$98] | 0;
    $122 = $121 << 24 >> 24 == 46;
    if ($122) {
      label = 28;
      break;
    } else {
      $notdef_found_1 = $notdef_found_0_ph;
      $notdef_index_1 = $notdef_index_0_ph;
      label = 29;
      break;
    }
   case 28:
    $124 = HEAP32[$48 >> 2] | 0;
    $125 = $124 + ($n_0_ph << 2) | 0;
    $126 = HEAP32[$125 >> 2] | 0;
    $127 = _strcmp(5320092, $126 | 0) | 0;
    $128 = ($127 | 0) == 0;
    $n_0_notdef_index_0 = $128 ? $n_0_ph : $notdef_index_0_ph;
    $_notdef_found_0 = $128 ? 1 : $notdef_found_0_ph;
    $notdef_found_1 = $_notdef_found_0;
    $notdef_index_1 = $n_0_notdef_index_0;
    label = 29;
    break;
   case 29:
    $130 = HEAP32[$49 >> 2] | 0;
    $131 = ($130 | 0) > -1;
    $132 = ($n_0_ph | 0) < ($50 | 0);
    $or_cond195 = $131 & $132;
    if ($or_cond195) {
      label = 30;
      break;
    } else {
      label = 34;
      break;
    }
   case 30:
    $134 = HEAP32[$size >> 2] | 0;
    $135 = ($134 | 0) > ($130 | 0);
    if ($135) {
      label = 32;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    HEAP32[$error >> 2] = 3;
    label = 53;
    break;
   case 32:
    $138 = _ft_mem_alloc($7, $134, $error) | 0;
    $139 = HEAP32[$error >> 2] | 0;
    $140 = ($139 | 0) == 0;
    if ($140) {
      label = 33;
      break;
    } else {
      label = 53;
      break;
    }
   case 33:
    $142 = HEAP32[$base >> 2] | 0;
    $143 = HEAP32[$size >> 2] | 0;
    _memcpy($138 | 0, $142 | 0, $143 | 0);
    $144 = HEAP32[$52 >> 2] | 0;
    $145 = HEAP32[$size >> 2] | 0;
    FUNCTION_TABLE_viii[$144 & 1023]($138, $145, 4330);
    $146 = HEAP32[$49 >> 2] | 0;
    $147 = HEAP32[$size >> 2] | 0;
    $148 = $147 - $146 | 0;
    HEAP32[$size >> 2] = $148;
    $149 = HEAP32[$53 >> 2] | 0;
    $150 = HEAP32[$49 >> 2] | 0;
    $151 = $138 + $150 | 0;
    $152 = FUNCTION_TABLE_iiiii[$149 & 1023]($2, $n_0_ph, $151, $148) | 0;
    HEAP32[$error >> 2] = $152;
    _ft_mem_free($7, $138);
    $_pr149 = HEAP32[$error >> 2] | 0;
    $159 = $_pr149;
    label = 35;
    break;
   case 34:
    $154 = HEAP32[$54 >> 2] | 0;
    $155 = HEAP32[$base >> 2] | 0;
    $156 = HEAP32[$size >> 2] | 0;
    $157 = FUNCTION_TABLE_iiiii[$154 & 1023]($2, $n_0_ph, $155, $156) | 0;
    HEAP32[$error >> 2] = $157;
    $159 = $157;
    label = 35;
    break;
   case 35:
    $160 = ($159 | 0) == 0;
    $161 = $n_0_ph + 1 | 0;
    if ($160) {
      $n_0_ph = $161;
      $notdef_found_0_ph = $notdef_found_1;
      $notdef_index_0_ph = $notdef_index_1;
      label = 8;
      break;
    } else {
      label = 53;
      break;
    }
   case 36:
    HEAP32[$21 >> 2] = $n_0_ph;
    $cond = $notdef_found_0_ph << 24 >> 24 == 0;
    if ($cond) {
      label = 46;
      break;
    } else {
      label = 37;
      break;
    }
   case 37:
    $163 = $loader + 180 | 0;
    $164 = HEAP32[$163 >> 2] | 0;
    $165 = HEAP32[$164 >> 2] | 0;
    $166 = _strcmp(5320092, $165 | 0) | 0;
    $167 = ($166 | 0) == 0;
    if ($167) {
      label = 54;
      break;
    } else {
      label = 38;
      break;
    }
   case 38:
    $169 = $loader + 304 | 0;
    $170 = HEAP32[$169 >> 2] | 0;
    $171 = $loader + 184 | 0;
    $172 = HEAP32[$171 >> 2] | 0;
    $173 = HEAP32[$172 >> 2] | 0;
    $174 = FUNCTION_TABLE_iiiii[$170 & 1023]($4, 0, $165, $173) | 0;
    HEAP32[$error >> 2] = $174;
    $175 = ($174 | 0) == 0;
    if ($175) {
      label = 39;
      break;
    } else {
      label = 53;
      break;
    }
   case 39:
    $177 = HEAP32[$169 >> 2] | 0;
    $178 = $loader + 232 | 0;
    $179 = HEAP32[$178 >> 2] | 0;
    $180 = HEAP32[$179 >> 2] | 0;
    $181 = $loader + 236 | 0;
    $182 = HEAP32[$181 >> 2] | 0;
    $183 = HEAP32[$182 >> 2] | 0;
    $184 = FUNCTION_TABLE_iiiii[$177 & 1023]($4, 1, $180, $183) | 0;
    HEAP32[$error >> 2] = $184;
    $185 = ($184 | 0) == 0;
    if ($185) {
      label = 40;
      break;
    } else {
      label = 53;
      break;
    }
   case 40:
    $187 = HEAP32[$169 >> 2] | 0;
    $188 = HEAP32[$163 >> 2] | 0;
    $189 = $188 + ($notdef_index_0_ph << 2) | 0;
    $190 = HEAP32[$189 >> 2] | 0;
    $191 = HEAP32[$171 >> 2] | 0;
    $192 = $191 + ($notdef_index_0_ph << 2) | 0;
    $193 = HEAP32[$192 >> 2] | 0;
    $194 = FUNCTION_TABLE_iiiii[$187 & 1023]($4, 2, $190, $193) | 0;
    HEAP32[$error >> 2] = $194;
    $195 = ($194 | 0) == 0;
    if ($195) {
      label = 41;
      break;
    } else {
      label = 53;
      break;
    }
   case 41:
    $197 = HEAP32[$169 >> 2] | 0;
    $198 = HEAP32[$178 >> 2] | 0;
    $199 = $198 + ($notdef_index_0_ph << 2) | 0;
    $200 = HEAP32[$199 >> 2] | 0;
    $201 = HEAP32[$181 >> 2] | 0;
    $202 = $201 + ($notdef_index_0_ph << 2) | 0;
    $203 = HEAP32[$202 >> 2] | 0;
    $204 = FUNCTION_TABLE_iiiii[$197 & 1023]($4, 3, $200, $203) | 0;
    HEAP32[$error >> 2] = $204;
    $205 = ($204 | 0) == 0;
    if ($205) {
      label = 42;
      break;
    } else {
      label = 53;
      break;
    }
   case 42:
    $207 = $loader + 200 | 0;
    $208 = HEAP32[$207 >> 2] | 0;
    $209 = $loader + 284 | 0;
    $210 = HEAP32[$209 >> 2] | 0;
    $211 = HEAP32[$210 >> 2] | 0;
    $212 = $loader + 288 | 0;
    $213 = HEAP32[$212 >> 2] | 0;
    $214 = HEAP32[$213 >> 2] | 0;
    $215 = FUNCTION_TABLE_iiiii[$208 & 1023]($3, $notdef_index_0_ph, $211, $214) | 0;
    HEAP32[$error >> 2] = $215;
    $216 = ($215 | 0) == 0;
    if ($216) {
      label = 43;
      break;
    } else {
      label = 53;
      break;
    }
   case 43:
    $218 = $loader + 252 | 0;
    $219 = HEAP32[$218 >> 2] | 0;
    $220 = HEAP32[$209 >> 2] | 0;
    $221 = $220 + 4 | 0;
    $222 = HEAP32[$221 >> 2] | 0;
    $223 = HEAP32[$212 >> 2] | 0;
    $224 = $223 + 4 | 0;
    $225 = HEAP32[$224 >> 2] | 0;
    $226 = FUNCTION_TABLE_iiiii[$219 & 1023]($2, $notdef_index_0_ph, $222, $225) | 0;
    HEAP32[$error >> 2] = $226;
    $227 = ($226 | 0) == 0;
    if ($227) {
      label = 44;
      break;
    } else {
      label = 53;
      break;
    }
   case 44:
    $229 = HEAP32[$207 >> 2] | 0;
    $230 = HEAP32[$209 >> 2] | 0;
    $231 = $230 + 8 | 0;
    $232 = HEAP32[$231 >> 2] | 0;
    $233 = HEAP32[$212 >> 2] | 0;
    $234 = $233 + 8 | 0;
    $235 = HEAP32[$234 >> 2] | 0;
    $236 = FUNCTION_TABLE_iiiii[$229 & 1023]($3, 0, $232, $235) | 0;
    HEAP32[$error >> 2] = $236;
    $237 = ($236 | 0) == 0;
    if ($237) {
      label = 45;
      break;
    } else {
      label = 53;
      break;
    }
   case 45:
    $239 = HEAP32[$218 >> 2] | 0;
    $240 = HEAP32[$209 >> 2] | 0;
    $241 = $240 + 12 | 0;
    $242 = HEAP32[$241 >> 2] | 0;
    $243 = HEAP32[$212 >> 2] | 0;
    $244 = $243 + 12 | 0;
    $245 = HEAP32[$244 >> 2] | 0;
    $246 = FUNCTION_TABLE_iiiii[$239 & 1023]($2, 0, $242, $245) | 0;
    HEAP32[$error >> 2] = $246;
    $247 = ($246 | 0) == 0;
    if ($247) {
      label = 54;
      break;
    } else {
      label = 53;
      break;
    }
   case 46:
    $249 = $notdef_glyph | 0;
    _memcpy($249 | 0, 5251016, 5);
    $250 = $loader + 304 | 0;
    $251 = HEAP32[$250 >> 2] | 0;
    $252 = $loader + 180 | 0;
    $253 = HEAP32[$252 >> 2] | 0;
    $254 = HEAP32[$253 >> 2] | 0;
    $255 = $loader + 184 | 0;
    $256 = HEAP32[$255 >> 2] | 0;
    $257 = HEAP32[$256 >> 2] | 0;
    $258 = FUNCTION_TABLE_iiiii[$251 & 1023]($4, 0, $254, $257) | 0;
    HEAP32[$error >> 2] = $258;
    $259 = ($258 | 0) == 0;
    if ($259) {
      label = 47;
      break;
    } else {
      label = 53;
      break;
    }
   case 47:
    $261 = HEAP32[$250 >> 2] | 0;
    $262 = $loader + 232 | 0;
    $263 = HEAP32[$262 >> 2] | 0;
    $264 = HEAP32[$263 >> 2] | 0;
    $265 = $loader + 236 | 0;
    $266 = HEAP32[$265 >> 2] | 0;
    $267 = HEAP32[$266 >> 2] | 0;
    $268 = FUNCTION_TABLE_iiiii[$261 & 1023]($4, 1, $264, $267) | 0;
    HEAP32[$error >> 2] = $268;
    $269 = ($268 | 0) == 0;
    if ($269) {
      label = 48;
      break;
    } else {
      label = 53;
      break;
    }
   case 48:
    $271 = $loader + 200 | 0;
    $272 = HEAP32[$271 >> 2] | 0;
    $273 = FUNCTION_TABLE_iiiii[$272 & 1023]($3, 0, 5320092, 8) | 0;
    HEAP32[$error >> 2] = $273;
    $274 = ($273 | 0) == 0;
    if ($274) {
      label = 49;
      break;
    } else {
      label = 53;
      break;
    }
   case 49:
    $276 = $loader + 252 | 0;
    $277 = HEAP32[$276 >> 2] | 0;
    $278 = FUNCTION_TABLE_iiiii[$277 & 1023]($2, 0, $249, 5) | 0;
    HEAP32[$error >> 2] = $278;
    $279 = ($278 | 0) == 0;
    if ($279) {
      label = 50;
      break;
    } else {
      label = 53;
      break;
    }
   case 50:
    $281 = HEAP32[$271 >> 2] | 0;
    $282 = $loader + 284 | 0;
    $283 = HEAP32[$282 >> 2] | 0;
    $284 = HEAP32[$283 >> 2] | 0;
    $285 = $loader + 288 | 0;
    $286 = HEAP32[$285 >> 2] | 0;
    $287 = HEAP32[$286 >> 2] | 0;
    $288 = FUNCTION_TABLE_iiiii[$281 & 1023]($3, $n_0_ph, $284, $287) | 0;
    HEAP32[$error >> 2] = $288;
    $289 = ($288 | 0) == 0;
    if ($289) {
      label = 51;
      break;
    } else {
      label = 53;
      break;
    }
   case 51:
    $291 = HEAP32[$276 >> 2] | 0;
    $292 = HEAP32[$282 >> 2] | 0;
    $293 = $292 + 4 | 0;
    $294 = HEAP32[$293 >> 2] | 0;
    $295 = HEAP32[$285 >> 2] | 0;
    $296 = $295 + 4 | 0;
    $297 = HEAP32[$296 >> 2] | 0;
    $298 = FUNCTION_TABLE_iiiii[$291 & 1023]($2, $n_0_ph, $294, $297) | 0;
    HEAP32[$error >> 2] = $298;
    $299 = ($298 | 0) == 0;
    if ($299) {
      label = 52;
      break;
    } else {
      label = 53;
      break;
    }
   case 52:
    $301 = HEAP32[$21 >> 2] | 0;
    $302 = $301 + 1 | 0;
    HEAP32[$21 >> 2] = $302;
    label = 54;
    break;
   case 53:
    $303 = HEAP32[$error >> 2] | 0;
    HEAP32[$17 >> 2] = $303;
    label = 54;
    break;
   case 54:
    STACKTOP = __stackBase__;
    return;
  }
}
function _parse_blend_design_positions($face, $loader) {
  $face = $face | 0;
  $loader = $loader | 0;
  var $design_tokens = 0, $num_designs = 0, $axis_tokens = 0, $n_axis = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $or_cond = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $num_axis_035 = 0, $n_034 = 0, $blend_033 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $_off = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $38 = 0, $blend_1 = 0, $num_axis_1 = 0, $40 = 0, $41 = 0, $42 = 0, $axis_032 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $error_2 = 0, $58 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 248 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $design_tokens = __stackBase__ | 0;
    $num_designs = __stackBase__ + 192 | 0;
    $axis_tokens = __stackBase__ + 196 | 0;
    $n_axis = __stackBase__ + 244 | 0;
    $1 = $loader | 0;
    $2 = $loader + 60 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $design_tokens | 0;
    FUNCTION_TABLE_viiii[$3 & 1023]($1, $4, 16, $num_designs);
    $5 = HEAP32[$num_designs >> 2] | 0;
    $6 = ($5 | 0) < 0;
    if ($6) {
      $error_2 = 162;
      label = 15;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = ($5 | 0) == 0;
    $9 = ($5 | 0) > 16;
    $or_cond = $8 | $9;
    if ($or_cond) {
      $error_2 = 3;
      label = 15;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = $loader | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $loader + 8 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $face + 532 | 0;
    $16 = HEAP32[$num_designs >> 2] | 0;
    $17 = ($16 | 0) > 0;
    if ($17) {
      label = 4;
      break;
    } else {
      label = 14;
      break;
    }
   case 4:
    $18 = HEAP32[$15 >> 2] | 0;
    $19 = $axis_tokens | 0;
    $20 = $loader + 40 | 0;
    $blend_033 = $18;
    $n_034 = 0;
    $num_axis_035 = 0;
    label = 5;
    break;
   case 5:
    $22 = $design_tokens + ($n_034 * 12 & -1) | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    HEAP32[$11 >> 2] = $23;
    $24 = $design_tokens + ($n_034 * 12 & -1) + 4 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    HEAP32[$13 >> 2] = $25;
    $26 = HEAP32[$2 >> 2] | 0;
    FUNCTION_TABLE_viiii[$26 & 1023]($1, $19, 4, $n_axis);
    $27 = ($n_034 | 0) == 0;
    $28 = HEAP32[$n_axis >> 2] | 0;
    if ($27) {
      label = 6;
      break;
    } else {
      label = 9;
      break;
    }
   case 6:
    $_off = $28 - 1 | 0;
    $30 = $_off >>> 0 > 3;
    if ($30) {
      $error_2 = 3;
      label = 15;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $32 = HEAP32[$num_designs >> 2] | 0;
    $33 = _t1_allocate_blend($face, $32, $28) | 0;
    $34 = ($33 | 0) == 0;
    if ($34) {
      label = 8;
      break;
    } else {
      $error_2 = $33;
      label = 15;
      break;
    }
   case 8:
    $36 = HEAP32[$15 >> 2] | 0;
    $num_axis_1 = $28;
    $blend_1 = $36;
    label = 10;
    break;
   case 9:
    $38 = ($28 | 0) == ($num_axis_035 | 0);
    if ($38) {
      $num_axis_1 = $num_axis_035;
      $blend_1 = $blend_033;
      label = 10;
      break;
    } else {
      $error_2 = 3;
      label = 15;
      break;
    }
   case 10:
    $40 = HEAP32[$n_axis >> 2] | 0;
    $41 = ($40 | 0) > 0;
    if ($41) {
      label = 11;
      break;
    } else {
      label = 13;
      break;
    }
   case 11:
    $42 = $blend_1 + 24 + ($n_034 << 2) | 0;
    $axis_032 = 0;
    label = 12;
    break;
   case 12:
    $44 = $axis_tokens + ($axis_032 * 12 & -1) | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    HEAP32[$11 >> 2] = $45;
    $46 = $axis_tokens + ($axis_032 * 12 & -1) + 4 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    HEAP32[$13 >> 2] = $47;
    $48 = HEAP32[$20 >> 2] | 0;
    $49 = FUNCTION_TABLE_iii[$48 & 1023]($1, 0) | 0;
    $50 = HEAP32[$42 >> 2] | 0;
    $51 = $50 + ($axis_032 << 2) | 0;
    HEAP32[$51 >> 2] = $49;
    $52 = $axis_032 + 1 | 0;
    $53 = HEAP32[$n_axis >> 2] | 0;
    $54 = ($52 | 0) < ($53 | 0);
    if ($54) {
      $axis_032 = $52;
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $55 = $n_034 + 1 | 0;
    $56 = HEAP32[$num_designs >> 2] | 0;
    $57 = ($55 | 0) < ($56 | 0);
    if ($57) {
      $blend_033 = $blend_1;
      $n_034 = $55;
      $num_axis_035 = $num_axis_1;
      label = 5;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    HEAP32[$11 >> 2] = $12;
    HEAP32[$13 >> 2] = $14;
    $error_2 = 0;
    label = 15;
    break;
   case 15:
    $58 = $loader + 12 | 0;
    HEAP32[$58 >> 2] = $error_2;
    STACKTOP = __stackBase__;
    return;
  }
}
function _parse_blend_design_map($face, $loader) {
  $face = $face | 0;
  $loader = $loader | 0;
  var $error = 0, $axis_tokens = 0, $num_axis = 0, $point_tokens = 0, $num_points = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $11 = 0, $12 = 0, $or_cond = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $n_038 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $_off = 0, $36 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $p_037 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 300 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $axis_tokens = __stackBase__ + 4 | 0;
    $num_axis = __stackBase__ + 52 | 0;
    $point_tokens = __stackBase__ + 56 | 0;
    $num_points = __stackBase__ + 296 | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $loader | 0;
    $4 = $loader + 60 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $axis_tokens | 0;
    FUNCTION_TABLE_viiii[$5 & 1023]($3, $6, 4, $num_axis);
    $7 = HEAP32[$num_axis >> 2] | 0;
    $8 = ($7 | 0) < 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    HEAP32[$error >> 2] = 162;
    label = 15;
    break;
   case 3:
    $11 = ($7 | 0) == 0;
    $12 = ($7 | 0) > 4;
    $or_cond = $11 | $12;
    if ($or_cond) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    HEAP32[$error >> 2] = 3;
    label = 15;
    break;
   case 5:
    $15 = $loader | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $loader + 8 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = _t1_allocate_blend($face, 0, $7) | 0;
    HEAP32[$error >> 2] = $19;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 6;
      break;
    } else {
      label = 15;
      break;
    }
   case 6:
    $22 = $face + 532 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = HEAP32[$num_axis >> 2] | 0;
    $25 = ($24 | 0) > 0;
    if ($25) {
      label = 7;
      break;
    } else {
      label = 14;
      break;
    }
   case 7:
    $26 = $point_tokens | 0;
    $27 = $loader + 36 | 0;
    $28 = $loader + 40 | 0;
    $n_038 = 0;
    label = 8;
    break;
   case 8:
    $30 = $axis_tokens + ($n_038 * 12 & -1) | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    HEAP32[$15 >> 2] = $31;
    $32 = $axis_tokens + ($n_038 * 12 & -1) + 4 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    HEAP32[$17 >> 2] = $33;
    $34 = HEAP32[$4 >> 2] | 0;
    FUNCTION_TABLE_viiii[$34 & 1023]($3, $26, 20, $num_points);
    $35 = HEAP32[$num_points >> 2] | 0;
    $_off = $35 - 1 | 0;
    $36 = $_off >>> 0 > 19;
    if ($36) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    HEAP32[$error >> 2] = 3;
    label = 15;
    break;
   case 10:
    $39 = $35 << 1;
    $40 = _ft_mem_realloc($2, 4, 0, $39, 0, $error) | 0;
    $41 = $40;
    $42 = $23 + 88 + ($n_038 * 12 & -1) + 4 | 0;
    HEAP32[$42 >> 2] = $41;
    $43 = HEAP32[$error >> 2] | 0;
    $44 = ($43 | 0) == 0;
    if ($44) {
      label = 11;
      break;
    } else {
      label = 15;
      break;
    }
   case 11:
    $46 = HEAP32[$num_points >> 2] | 0;
    $47 = $41 + ($46 << 2) | 0;
    $48 = $23 + 88 + ($n_038 * 12 & -1) + 8 | 0;
    HEAP32[$48 >> 2] = $47;
    $49 = HEAP32[$num_points >> 2] | 0;
    $50 = $49 & 255;
    $51 = $23 + 88 + ($n_038 * 12 & -1) | 0;
    HEAP8[$51] = $50;
    $52 = HEAP32[$num_points >> 2] | 0;
    $53 = ($52 | 0) > 0;
    if ($53) {
      $p_037 = 0;
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $54 = $point_tokens + ($p_037 * 12 & -1) | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = $55 + 1 | 0;
    HEAP32[$15 >> 2] = $56;
    $57 = $point_tokens + ($p_037 * 12 & -1) + 4 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = $58 - 1 | 0;
    HEAP32[$17 >> 2] = $59;
    $60 = HEAP32[$27 >> 2] | 0;
    $61 = FUNCTION_TABLE_ii[$60 & 1023]($3) | 0;
    $62 = HEAP32[$42 >> 2] | 0;
    $63 = $62 + ($p_037 << 2) | 0;
    HEAP32[$63 >> 2] = $61;
    $64 = HEAP32[$28 >> 2] | 0;
    $65 = FUNCTION_TABLE_iii[$64 & 1023]($3, 0) | 0;
    $66 = HEAP32[$48 >> 2] | 0;
    $67 = $66 + ($p_037 << 2) | 0;
    HEAP32[$67 >> 2] = $65;
    $68 = $p_037 + 1 | 0;
    $69 = HEAP32[$num_points >> 2] | 0;
    $70 = ($68 | 0) < ($69 | 0);
    if ($70) {
      $p_037 = $68;
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $71 = $n_038 + 1 | 0;
    $72 = HEAP32[$num_axis >> 2] | 0;
    $73 = ($71 | 0) < ($72 | 0);
    if ($73) {
      $n_038 = $71;
      label = 8;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    HEAP32[$15 >> 2] = $16;
    HEAP32[$17 >> 2] = $18;
    label = 15;
    break;
   case 15:
    $74 = HEAP32[$error >> 2] | 0;
    $75 = $loader + 12 | 0;
    HEAP32[$75 >> 2] = $74;
    STACKTOP = __stackBase__;
    return;
  }
}
function _parse_blend_axis_types($face, $loader) {
  $face = $face | 0;
  $loader = $loader | 0;
  var $axis_tokens = 0, $num_axis = 0, $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $9 = 0, $10 = 0, $or_cond = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $n_020 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 56 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $axis_tokens = __stackBase__ | 0;
    $num_axis = __stackBase__ + 48 | 0;
    $error = __stackBase__ + 52 | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $loader | 0;
    $2 = $loader + 60 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $axis_tokens | 0;
    FUNCTION_TABLE_viiii[$3 & 1023]($1, $4, 4, $num_axis);
    $5 = HEAP32[$num_axis >> 2] | 0;
    $6 = ($5 | 0) < 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    HEAP32[$error >> 2] = 162;
    label = 13;
    break;
   case 3:
    $9 = ($5 | 0) == 0;
    $10 = ($5 | 0) > 4;
    $or_cond = $9 | $10;
    if ($or_cond) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    HEAP32[$error >> 2] = 3;
    label = 13;
    break;
   case 5:
    $13 = _t1_allocate_blend($face, 0, $5) | 0;
    HEAP32[$error >> 2] = $13;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 6;
      break;
    } else {
      label = 13;
      break;
    }
   case 6:
    $16 = $face + 532 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $face + 100 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = HEAP32[$num_axis >> 2] | 0;
    $21 = ($20 | 0) > 0;
    if ($21) {
      $n_020 = 0;
      label = 7;
      break;
    } else {
      label = 13;
      break;
    }
   case 7:
    $22 = $axis_tokens + ($n_020 * 12 & -1) | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = HEAP8[$23] | 0;
    $25 = $24 << 24 >> 24 == 47;
    if ($25) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $27 = $23 + 1 | 0;
    HEAP32[$22 >> 2] = $27;
    label = 9;
    break;
   case 9:
    $29 = $axis_tokens + ($n_020 * 12 & -1) + 4 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = HEAP32[$22 >> 2] | 0;
    $32 = $30;
    $33 = $31;
    $34 = $32 - $33 | 0;
    $35 = ($30 | 0) == ($31 | 0);
    if ($35) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    HEAP32[$error >> 2] = 3;
    label = 13;
    break;
   case 11:
    $38 = $34 + 1 | 0;
    $39 = _ft_mem_alloc($19, $38, $error) | 0;
    $40 = $17 + 8 + ($n_020 << 2) | 0;
    HEAP32[$40 >> 2] = $39;
    $41 = HEAP32[$error >> 2] | 0;
    $42 = ($41 | 0) == 0;
    if ($42) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $44 = HEAP32[$22 >> 2] | 0;
    _memcpy($39 | 0, $44 | 0, $34 | 0);
    $45 = $39 + $34 | 0;
    HEAP8[$45] = 0;
    $46 = $n_020 + 1 | 0;
    $47 = HEAP32[$num_axis >> 2] | 0;
    $48 = ($46 | 0) < ($47 | 0);
    if ($48) {
      $n_020 = $46;
      label = 7;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $49 = HEAP32[$error >> 2] | 0;
    $50 = $loader + 12 | 0;
    HEAP32[$50 >> 2] = $49;
    STACKTOP = __stackBase__;
    return;
  }
}
function _parse_weight_vector($face, $loader) {
  $face = $face | 0;
  $loader = $loader | 0;
  var $design_tokens = 0, $num_designs = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $or_cond = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0, $blend_0 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $n_025 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $error_1 = 0, $51 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 196 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $design_tokens = __stackBase__ | 0;
    $num_designs = __stackBase__ + 192 | 0;
    $1 = $face + 532 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $loader | 0;
    $4 = $loader + 60 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $design_tokens | 0;
    FUNCTION_TABLE_viiii[$5 & 1023]($3, $6, 16, $num_designs);
    $7 = HEAP32[$num_designs >> 2] | 0;
    $8 = ($7 | 0) < 0;
    if ($8) {
      $error_1 = 162;
      label = 12;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = ($7 | 0) == 0;
    $11 = ($7 | 0) > 16;
    $or_cond = $10 | $11;
    if ($or_cond) {
      $error_1 = 3;
      label = 12;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $13 = ($2 | 0) == 0;
    if ($13) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $15 = $2 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    $19 = HEAP32[$num_designs >> 2] | 0;
    $20 = _t1_allocate_blend($face, $19, 0) | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 6;
      break;
    } else {
      $error_1 = $20;
      label = 12;
      break;
    }
   case 6:
    $23 = HEAP32[$1 >> 2] | 0;
    $blend_0 = $23;
    label = 8;
    break;
   case 7:
    $25 = ($16 | 0) == ($7 | 0);
    if ($25) {
      $blend_0 = $2;
      label = 8;
      break;
    } else {
      $error_1 = 3;
      label = 12;
      break;
    }
   case 8:
    $27 = $loader | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $loader + 8 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = HEAP32[$num_designs >> 2] | 0;
    $32 = ($31 | 0) > 0;
    if ($32) {
      label = 9;
      break;
    } else {
      label = 11;
      break;
    }
   case 9:
    $33 = $loader + 40 | 0;
    $34 = $blend_0 + 136 | 0;
    $35 = $blend_0 + 140 | 0;
    $n_025 = 0;
    label = 10;
    break;
   case 10:
    $37 = $design_tokens + ($n_025 * 12 & -1) | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    HEAP32[$27 >> 2] = $38;
    $39 = $design_tokens + ($n_025 * 12 & -1) + 4 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    HEAP32[$29 >> 2] = $40;
    $41 = HEAP32[$33 >> 2] | 0;
    $42 = FUNCTION_TABLE_iii[$41 & 1023]($3, 0) | 0;
    $43 = HEAP32[$34 >> 2] | 0;
    $44 = $43 + ($n_025 << 2) | 0;
    HEAP32[$44 >> 2] = $42;
    $45 = HEAP32[$35 >> 2] | 0;
    $46 = $45 + ($n_025 << 2) | 0;
    HEAP32[$46 >> 2] = $42;
    $47 = $n_025 + 1 | 0;
    $48 = HEAP32[$num_designs >> 2] | 0;
    $49 = ($47 | 0) < ($48 | 0);
    if ($49) {
      $n_025 = $47;
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    HEAP32[$27 >> 2] = $28;
    HEAP32[$29 >> 2] = $30;
    $error_1 = 0;
    label = 12;
    break;
   case 12:
    $51 = $loader + 12 | 0;
    HEAP32[$51 >> 2] = $error_1;
    STACKTOP = __stackBase__;
    return;
  }
}
function _parse_buildchar($face, $loader) {
  $face = $face | 0;
  $loader = $loader | 0;
  HEAP32[$face + 544 >> 2] = FUNCTION_TABLE_iiiii[HEAP32[$loader + 52 >> 2] & 1023]($loader | 0, 0, 0, 0) | 0;
  return;
}
function _t1_ps_has_glyph_names($face) {
  $face = $face | 0;
  return 1;
}
function _cid_driver_init($driver) {
  $driver = $driver | 0;
  return 0;
}
function _cid_driver_done($driver) {
  $driver = $driver | 0;
  return;
}
function _T1_Get_Multi_Master($face, $master) {
  $face = $face | 0;
  $master = $master | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $n_017 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 532 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      $error_0 = 6;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 + 4 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $master | 0;
    HEAP32[$7 >> 2] = $6;
    $8 = $2 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $master + 4 | 0;
    HEAP32[$10 >> 2] = $9;
    $11 = HEAP32[$5 >> 2] | 0;
    $12 = ($11 | 0) == 0;
    if ($12) {
      $error_0 = 0;
      label = 4;
      break;
    } else {
      $n_017 = 0;
      label = 3;
      break;
    }
   case 3:
    $13 = $2 + 8 + ($n_017 << 2) | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $master + 8 + ($n_017 * 12 & -1) | 0;
    HEAP32[$15 >> 2] = $14;
    $16 = $2 + 88 + ($n_017 * 12 & -1) + 4 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $master + 8 + ($n_017 * 12 & -1) + 4 | 0;
    HEAP32[$19 >> 2] = $18;
    $20 = $2 + 88 + ($n_017 * 12 & -1) | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $21 & 255;
    $23 = $22 - 1 | 0;
    $24 = HEAP32[$16 >> 2] | 0;
    $25 = $24 + ($23 << 2) | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $master + 8 + ($n_017 * 12 & -1) + 8 | 0;
    HEAP32[$27 >> 2] = $26;
    $28 = $n_017 + 1 | 0;
    $29 = HEAP32[$5 >> 2] | 0;
    $30 = $28 >>> 0 < $29 >>> 0;
    if ($30) {
      $n_017 = $28;
      label = 3;
      break;
    } else {
      $error_0 = 0;
      label = 4;
      break;
    }
   case 4:
    return $error_0 | 0;
  }
  return 0;
}
function _mm_weights_unmap($weights, $axiscoords, $axis_count) {
  $weights = $weights | 0;
  $axiscoords = $axiscoords | 0;
  $axis_count = $axis_count | 0;
  var $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    if (($axis_count | 0) == 1) {
      label = 2;
      break;
    } else if (($axis_count | 0) == 2) {
      label = 3;
      break;
    } else if (($axis_count | 0) == 3) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 2:
    $2 = $weights + 4 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    HEAP32[$axiscoords >> 2] = $3;
    label = 6;
    break;
   case 3:
    $5 = $weights + 12 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $weights + 4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 + $6 | 0;
    HEAP32[$axiscoords >> 2] = $9;
    $10 = HEAP32[$5 >> 2] | 0;
    $11 = $weights + 8 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + $10 | 0;
    $14 = $axiscoords + 4 | 0;
    HEAP32[$14 >> 2] = $13;
    label = 6;
    break;
   case 4:
    $16 = $weights + 28 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $weights + 20 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $19 + $17 | 0;
    $21 = $weights + 12 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $20 + $22 | 0;
    $24 = $weights + 4 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $23 + $25 | 0;
    HEAP32[$axiscoords >> 2] = $26;
    $27 = HEAP32[$16 >> 2] | 0;
    $28 = $weights + 24 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $29 + $27 | 0;
    $31 = HEAP32[$21 >> 2] | 0;
    $32 = $30 + $31 | 0;
    $33 = $weights + 8 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $32 + $34 | 0;
    $36 = $axiscoords + 4 | 0;
    HEAP32[$36 >> 2] = $35;
    $37 = HEAP32[$16 >> 2] | 0;
    $38 = HEAP32[$28 >> 2] | 0;
    $39 = $38 + $37 | 0;
    $40 = HEAP32[$18 >> 2] | 0;
    $41 = $39 + $40 | 0;
    $42 = $weights + 16 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $41 + $43 | 0;
    $45 = $axiscoords + 8 | 0;
    HEAP32[$45 >> 2] = $44;
    label = 6;
    break;
   case 5:
    $47 = $weights + 60 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $weights + 52 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $50 + $48 | 0;
    $52 = $weights + 44 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $51 + $53 | 0;
    $55 = $weights + 36 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = $54 + $56 | 0;
    $58 = $weights + 28 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = $57 + $59 | 0;
    $61 = $weights + 20 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = $60 + $62 | 0;
    $64 = $weights + 12 | 0;
    $65 = HEAP32[$64 >> 2] | 0;
    $66 = $63 + $65 | 0;
    $67 = $weights + 4 | 0;
    $68 = HEAP32[$67 >> 2] | 0;
    $69 = $66 + $68 | 0;
    HEAP32[$axiscoords >> 2] = $69;
    $70 = HEAP32[$47 >> 2] | 0;
    $71 = $weights + 56 | 0;
    $72 = HEAP32[$71 >> 2] | 0;
    $73 = $72 + $70 | 0;
    $74 = HEAP32[$52 >> 2] | 0;
    $75 = $73 + $74 | 0;
    $76 = $weights + 40 | 0;
    $77 = HEAP32[$76 >> 2] | 0;
    $78 = $75 + $77 | 0;
    $79 = HEAP32[$58 >> 2] | 0;
    $80 = $78 + $79 | 0;
    $81 = $weights + 24 | 0;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = $80 + $82 | 0;
    $84 = HEAP32[$64 >> 2] | 0;
    $85 = $83 + $84 | 0;
    $86 = $weights + 8 | 0;
    $87 = HEAP32[$86 >> 2] | 0;
    $88 = $85 + $87 | 0;
    $89 = $axiscoords + 4 | 0;
    HEAP32[$89 >> 2] = $88;
    $90 = HEAP32[$47 >> 2] | 0;
    $91 = HEAP32[$71 >> 2] | 0;
    $92 = $91 + $90 | 0;
    $93 = HEAP32[$49 >> 2] | 0;
    $94 = $92 + $93 | 0;
    $95 = $weights + 48 | 0;
    $96 = HEAP32[$95 >> 2] | 0;
    $97 = $94 + $96 | 0;
    $98 = HEAP32[$58 >> 2] | 0;
    $99 = $97 + $98 | 0;
    $100 = HEAP32[$81 >> 2] | 0;
    $101 = $99 + $100 | 0;
    $102 = HEAP32[$61 >> 2] | 0;
    $103 = $101 + $102 | 0;
    $104 = $weights + 16 | 0;
    $105 = HEAP32[$104 >> 2] | 0;
    $106 = $103 + $105 | 0;
    $107 = $axiscoords + 8 | 0;
    HEAP32[$107 >> 2] = $106;
    $108 = HEAP32[$47 >> 2] | 0;
    $109 = HEAP32[$71 >> 2] | 0;
    $110 = $109 + $108 | 0;
    $111 = HEAP32[$49 >> 2] | 0;
    $112 = $110 + $111 | 0;
    $113 = HEAP32[$95 >> 2] | 0;
    $114 = $112 + $113 | 0;
    $115 = HEAP32[$52 >> 2] | 0;
    $116 = $114 + $115 | 0;
    $117 = HEAP32[$76 >> 2] | 0;
    $118 = $116 + $117 | 0;
    $119 = HEAP32[$55 >> 2] | 0;
    $120 = $118 + $119 | 0;
    $121 = $weights + 32 | 0;
    $122 = HEAP32[$121 >> 2] | 0;
    $123 = $120 + $122 | 0;
    $124 = $axiscoords + 12 | 0;
    HEAP32[$124 >> 2] = $123;
    label = 6;
    break;
   case 6:
    return;
  }
}
function _t1_ps_get_font_extra($face, $afont_extra) {
  $face = $face | 0;
  $afont_extra = $afont_extra | 0;
  HEAP16[$afont_extra >> 1] = HEAP16[$face + 164 >> 1] | 0;
  return 0;
}
function _t1_get_ps_name($face) {
  $face = $face | 0;
  return HEAP32[$face + 364 >> 2] | 0;
}
function _t1_allocate_blend($face, $num_designs, $num_axis) {
  $face = $face | 0;
  $num_designs = $num_designs | 0;
  $num_axis = $num_axis | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $blend_0 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $nn_070 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $71 = 0, $73 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $or_cond = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $or_cond68 = 0, $88 = 0, $89 = 0, $90 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $or_cond72 = 0, $n_069 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $exitcond = 0, $103 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $3 = $face + 532 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $blend_0 = $4;
      label = 4;
      break;
    }
   case 2:
    $7 = _ft_mem_alloc($2, 420, $error) | 0;
    $8 = $7;
    $9 = HEAP32[$error >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 3;
      break;
    } else {
      label = 21;
      break;
    }
   case 3:
    $12 = $7 + 416 | 0;
    $13 = $12;
    HEAP32[$13 >> 2] = 0;
    HEAP32[$3 >> 2] = $8;
    $blend_0 = $8;
    label = 4;
    break;
   case 4:
    $15 = ($num_designs | 0) == 0;
    if ($15) {
      label = 14;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = $blend_0 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 6;
      break;
    } else {
      label = 13;
      break;
    }
   case 6:
    $21 = _ft_mem_realloc($2, 32, 0, $num_designs, 0, $error) | 0;
    $22 = $21;
    $23 = $blend_0 + 148 | 0;
    HEAP32[$23 >> 2] = $22;
    $24 = HEAP32[$error >> 2] | 0;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 7;
      break;
    } else {
      label = 21;
      break;
    }
   case 7:
    $27 = _ft_mem_realloc($2, 196, 0, $num_designs, 0, $error) | 0;
    $28 = $27;
    $29 = $blend_0 + 216 | 0;
    HEAP32[$29 >> 2] = $28;
    $30 = HEAP32[$error >> 2] | 0;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 8;
      break;
    } else {
      label = 21;
      break;
    }
   case 8:
    $33 = _ft_mem_realloc($2, 16, 0, $num_designs, 0, $error) | 0;
    $34 = $33;
    $35 = $blend_0 + 288 | 0;
    HEAP32[$35 >> 2] = $34;
    $36 = HEAP32[$error >> 2] | 0;
    $37 = ($36 | 0) == 0;
    if ($37) {
      label = 9;
      break;
    } else {
      label = 21;
      break;
    }
   case 9:
    $39 = $num_designs << 1;
    $40 = _ft_mem_realloc($2, 4, 0, $39, 0, $error) | 0;
    $41 = $40;
    $42 = $blend_0 + 136 | 0;
    HEAP32[$42 >> 2] = $41;
    $43 = HEAP32[$error >> 2] | 0;
    $44 = ($43 | 0) == 0;
    if ($44) {
      label = 10;
      break;
    } else {
      label = 21;
      break;
    }
   case 10:
    $46 = $41 + ($num_designs << 2) | 0;
    $47 = $blend_0 + 140 | 0;
    HEAP32[$47 >> 2] = $46;
    $48 = $face + 132 | 0;
    $49 = $blend_0 + 144 | 0;
    HEAP32[$49 >> 2] = $48;
    $50 = $face + 168 | 0;
    $51 = $blend_0 + 212 | 0;
    HEAP32[$51 >> 2] = $50;
    $52 = $face + 460 | 0;
    $53 = $blend_0 + 284 | 0;
    HEAP32[$53 >> 2] = $52;
    $54 = $num_designs >>> 0 < 2;
    if ($54) {
      label = 12;
      break;
    } else {
      $nn_070 = 2;
      label = 11;
      break;
    }
   case 11:
    $55 = $nn_070 - 1 | 0;
    $56 = $blend_0 + 212 + ($55 << 2) | 0;
    $57 = HEAP32[$56 >> 2] | 0;
    $58 = $57 + 196 | 0;
    $59 = $blend_0 + 212 + ($nn_070 << 2) | 0;
    HEAP32[$59 >> 2] = $58;
    $60 = $blend_0 + 144 + ($55 << 2) | 0;
    $61 = HEAP32[$60 >> 2] | 0;
    $62 = $61 + 32 | 0;
    $63 = $blend_0 + 144 + ($nn_070 << 2) | 0;
    HEAP32[$63 >> 2] = $62;
    $64 = $blend_0 + 284 + ($55 << 2) | 0;
    $65 = HEAP32[$64 >> 2] | 0;
    $66 = $65 + 16 | 0;
    $67 = $blend_0 + 284 + ($nn_070 << 2) | 0;
    HEAP32[$67 >> 2] = $66;
    $68 = $nn_070 + 1 | 0;
    $69 = $68 >>> 0 > $num_designs >>> 0;
    if ($69) {
      label = 12;
      break;
    } else {
      $nn_070 = $68;
      label = 11;
      break;
    }
   case 12:
    HEAP32[$17 >> 2] = $num_designs;
    label = 14;
    break;
   case 13:
    $71 = ($18 | 0) == ($num_designs | 0);
    if ($71) {
      label = 14;
      break;
    } else {
      label = 22;
      break;
    }
   case 14:
    $73 = ($num_axis | 0) == 0;
    if ($73) {
      label = 17;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $75 = $blend_0 + 4 | 0;
    $76 = HEAP32[$75 >> 2] | 0;
    $77 = ($76 | 0) == 0;
    $78 = ($76 | 0) == ($num_axis | 0);
    $or_cond = $77 | $78;
    if ($or_cond) {
      label = 16;
      break;
    } else {
      label = 22;
      break;
    }
   case 16:
    HEAP32[$75 >> 2] = $num_axis;
    label = 17;
    break;
   case 17:
    $81 = $blend_0 | 0;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = $blend_0 + 4 | 0;
    $84 = HEAP32[$83 >> 2] | 0;
    $85 = ($82 | 0) == 0;
    $86 = ($84 | 0) == 0;
    $or_cond68 = $85 | $86;
    if ($or_cond68) {
      label = 21;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $88 = $blend_0 + 24 | 0;
    $89 = HEAP32[$88 >> 2] | 0;
    $90 = ($89 | 0) == 0;
    if ($90) {
      label = 19;
      break;
    } else {
      label = 21;
      break;
    }
   case 19:
    $92 = Math_imul($84, $82);
    $93 = _ft_mem_realloc($2, 4, 0, $92, 0, $error) | 0;
    $94 = $93;
    HEAP32[$88 >> 2] = $94;
    $95 = HEAP32[$error >> 2] | 0;
    $96 = ($95 | 0) == 0;
    $97 = $82 >>> 0 > 1;
    $or_cond72 = $96 & $97;
    if ($or_cond72) {
      $n_069 = 1;
      label = 20;
      break;
    } else {
      label = 21;
      break;
    }
   case 20:
    $98 = HEAP32[$88 >> 2] | 0;
    $99 = Math_imul($n_069, $84);
    $100 = $98 + ($99 << 2) | 0;
    $101 = $blend_0 + 24 + ($n_069 << 2) | 0;
    HEAP32[$101 >> 2] = $100;
    $102 = $n_069 + 1 | 0;
    $exitcond = ($102 | 0) == ($82 | 0);
    if ($exitcond) {
      label = 21;
      break;
    } else {
      $n_069 = $102;
      label = 20;
      break;
    }
   case 21:
    $103 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $103 | 0;
   case 22:
    HEAP32[$error >> 2] = 3;
    label = 21;
    break;
  }
  return 0;
}
function _check_type1_format($stream, $header_string, $header_length) {
  $stream = $stream | 0;
  $header_string = $header_string | 0;
  $header_length = $header_length | 0;
  var $tag = 0, $dummy = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $_ = 0, $error_1 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $tag = __stackBase__ | 0;
    $dummy = __stackBase__ + 4 | 0;
    $1 = _FT_Stream_Seek($stream, 0) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $error_1 = $1;
      label = 7;
      break;
    }
   case 2:
    $4 = _read_pfb_tag($stream, $tag, $dummy) | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 3;
      break;
    } else {
      $error_1 = $4;
      label = 7;
      break;
    }
   case 3:
    $7 = HEAP16[$tag >> 1] | 0;
    $8 = $7 << 16 >> 16 == -32767;
    if ($8) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $10 = _FT_Stream_Seek($stream, 0) | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 5;
      break;
    } else {
      $error_1 = $10;
      label = 7;
      break;
    }
   case 5:
    $13 = _FT_Stream_EnterFrame($stream, $header_length) | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 6;
      break;
    } else {
      $error_1 = $13;
      label = 7;
      break;
    }
   case 6:
    $16 = $stream + 32 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = _memcmp($17 | 0, $header_string | 0, $header_length | 0) | 0;
    $19 = ($18 | 0) == 0;
    $_ = $19 ? 0 : 2;
    _FT_Stream_ExitFrame($stream);
    $error_1 = $_;
    label = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return $error_1 | 0;
  }
  return 0;
}
function _T1_Set_MM_Design($face, $num_coords, $coords) {
  $face = $face | 0;
  $num_coords = $num_coords | 0;
  $coords = $coords | 0;
  var $final_blends = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n_037 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $p_0 = 0, $before_0 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $after_0 = 0, $32 = 0, $34 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $the_blend_0 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 64 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $final_blends = __stackBase__ | 0;
    $1 = $face + 532 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      $error_0 = 6;
      label = 16;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 + 4 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == ($num_coords | 0);
    if ($7) {
      label = 3;
      break;
    } else {
      $error_0 = 6;
      label = 16;
      break;
    }
   case 3:
    $8 = HEAP32[$5 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 15;
      break;
    } else {
      $n_037 = 0;
      label = 4;
      break;
    }
   case 4:
    $10 = $coords + ($n_037 << 2) | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $2 + 88 + ($n_037 * 12 & -1) + 4 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $2 + 88 + ($n_037 * 12 & -1) + 8 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $2 + 88 + ($n_037 * 12 & -1) | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 & 255;
    $before_0 = -1;
    $p_0 = 0;
    label = 5;
    break;
   case 5:
    $20 = $p_0 >>> 0 < $18 >>> 0;
    if ($20) {
      label = 6;
      break;
    } else {
      $after_0 = -1;
      label = 9;
      break;
    }
   case 6:
    $22 = $13 + ($p_0 << 2) | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = ($11 | 0) == ($23 | 0);
    if ($24) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $26 = $15 + ($p_0 << 2) | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $the_blend_0 = $27;
    label = 14;
    break;
   case 8:
    $29 = ($11 | 0) < ($23 | 0);
    $30 = $p_0 + 1 | 0;
    if ($29) {
      $after_0 = $p_0;
      label = 9;
      break;
    } else {
      $before_0 = $p_0;
      $p_0 = $30;
      label = 5;
      break;
    }
   case 9:
    $32 = ($before_0 | 0) < 0;
    if ($32) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $34 = HEAP32[$15 >> 2] | 0;
    $the_blend_0 = $34;
    label = 14;
    break;
   case 11:
    $36 = ($after_0 | 0) < 0;
    if ($36) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $38 = HEAP8[$16] | 0;
    $39 = $38 & 255;
    $40 = $39 - 1 | 0;
    $41 = $15 + ($40 << 2) | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $the_blend_0 = $42;
    label = 14;
    break;
   case 13:
    $44 = $13 + ($before_0 << 2) | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = $11 - $45 | 0;
    $47 = $15 + ($after_0 << 2) | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $15 + ($before_0 << 2) | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $48 - $50 | 0;
    $52 = $13 + ($after_0 << 2) | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $53 - $45 | 0;
    $55 = _FT_MulDiv($46, $51, $54) | 0;
    $the_blend_0 = $55;
    label = 14;
    break;
   case 14:
    $57 = $final_blends + ($n_037 << 2) | 0;
    HEAP32[$57 >> 2] = $the_blend_0;
    $58 = $n_037 + 1 | 0;
    $59 = HEAP32[$5 >> 2] | 0;
    $60 = $58 >>> 0 < $59 >>> 0;
    if ($60) {
      $n_037 = $58;
      label = 4;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $61 = $final_blends | 0;
    $62 = _T1_Set_MM_Blend($face, $num_coords, $61) | 0;
    $error_0 = $62;
    label = 16;
    break;
   case 16:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _T1_Set_MM_Blend($face, $num_coords, $coords) {
  $face = $face | 0;
  $num_coords = $num_coords | 0;
  $coords = $coords | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $n_020 = 0, $12 = 0, $13 = 0, $14 = 0, $result_018 = 0, $m_017 = 0, $16 = 0, $17 = 0, $18 = 0, $_ = 0, $19 = 0, $factor_1 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $_factor_1 = 0, $24 = 0, $25 = 0, $26 = 0, $result_0_lcssa = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 532 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      $error_0 = 6;
      label = 9;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 + 4 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == ($num_coords | 0);
    if ($7) {
      label = 3;
      break;
    } else {
      $error_0 = 6;
      label = 9;
      break;
    }
   case 3:
    $8 = $2 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      $error_0 = 0;
      label = 9;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $11 = $2 + 136 | 0;
    $n_020 = 0;
    label = 5;
    break;
   case 5:
    $12 = HEAP32[$5 >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      $result_0_lcssa = 65536;
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $14 = HEAP32[$5 >> 2] | 0;
    $m_017 = 0;
    $result_018 = 65536;
    label = 7;
    break;
   case 7:
    $16 = $coords + ($m_017 << 2) | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($17 | 0) < 0;
    $_ = $18 ? 0 : $17;
    $19 = ($_ | 0) > 65536;
    $factor_1 = $19 ? 65536 : $_;
    $20 = 1 << $m_017;
    $21 = $20 & $n_020;
    $22 = ($21 | 0) == 0;
    $23 = 65536 - $factor_1 | 0;
    $_factor_1 = $22 ? $23 : $factor_1;
    $24 = _FT_MulFix($result_018, $_factor_1) | 0;
    $25 = $m_017 + 1 | 0;
    $26 = $25 >>> 0 < $14 >>> 0;
    if ($26) {
      $m_017 = $25;
      $result_018 = $24;
      label = 7;
      break;
    } else {
      $result_0_lcssa = $24;
      label = 8;
      break;
    }
   case 8:
    $27 = HEAP32[$11 >> 2] | 0;
    $28 = $27 + ($n_020 << 2) | 0;
    HEAP32[$28 >> 2] = $result_0_lcssa;
    $29 = $n_020 + 1 | 0;
    $30 = HEAP32[$8 >> 2] | 0;
    $31 = $29 >>> 0 < $30 >>> 0;
    if ($31) {
      $n_020 = $29;
      label = 5;
      break;
    } else {
      $error_0 = 0;
      label = 9;
      break;
    }
   case 9:
    return $error_0 | 0;
  }
  return 0;
}
function _T1_Get_MM_Var($face, $master) {
  $face = $face | 0;
  $master = $master | 0;
  var $mmaster = 0, $error = 0, $axiscoords = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $i_049 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $69 = 0, $70 = 0, $72 = 0, $74 = 0, $75 = 0, $77 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $i_148 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $104 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 76 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $mmaster = __stackBase__ | 0;
    $error = __stackBase__ + 56 | 0;
    $axiscoords = __stackBase__ + 60 | 0;
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 532 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = _T1_Get_Multi_Master($face, $mmaster) | 0;
    HEAP32[$error >> 2] = $5;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 17;
      break;
    }
   case 2:
    $8 = $mmaster | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 * 24 & -1;
    $11 = $10 + 20 | 0;
    $12 = _ft_mem_alloc($2, $11, $error) | 0;
    $13 = $12;
    $14 = HEAP32[$error >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 3;
      break;
    } else {
      label = 17;
      break;
    }
   case 3:
    $17 = HEAP32[$8 >> 2] | 0;
    $18 = $12;
    HEAP32[$18 >> 2] = $17;
    $19 = $mmaster + 4 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $12 + 4 | 0;
    $22 = $21;
    HEAP32[$22 >> 2] = $20;
    $23 = $12 + 8 | 0;
    $24 = $23;
    HEAP32[$24 >> 2] = -1;
    $25 = $12 + 20 | 0;
    $26 = $25;
    $27 = $12 + 12 | 0;
    $28 = $27;
    HEAP32[$28 >> 2] = $26;
    $29 = $12 + 16 | 0;
    $30 = $29;
    HEAP32[$30 >> 2] = 0;
    $31 = HEAP32[$8 >> 2] | 0;
    $32 = ($31 | 0) == 0;
    if ($32) {
      label = 12;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $33 = HEAP32[$8 >> 2] | 0;
    $i_049 = 0;
    label = 5;
    break;
   case 5:
    $35 = $mmaster + 8 + ($i_049 * 12 & -1) | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = HEAP32[$28 >> 2] | 0;
    $38 = $37 + ($i_049 * 24 & -1) | 0;
    HEAP32[$38 >> 2] = $36;
    $39 = $mmaster + 8 + ($i_049 * 12 & -1) + 4 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $40 << 16;
    $42 = HEAP32[$28 >> 2] | 0;
    $43 = $42 + ($i_049 * 24 & -1) + 4 | 0;
    HEAP32[$43 >> 2] = $41;
    $44 = $mmaster + 8 + ($i_049 * 12 & -1) + 8 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = $45 << 16;
    $47 = HEAP32[$28 >> 2] | 0;
    $48 = $47 + ($i_049 * 24 & -1) + 12 | 0;
    HEAP32[$48 >> 2] = $46;
    $49 = HEAP32[$28 >> 2] | 0;
    $50 = $49 + ($i_049 * 24 & -1) + 4 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = $49 + ($i_049 * 24 & -1) + 12 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $53 + $51 | 0;
    $55 = ($54 | 0) / 2 & -1;
    $56 = $49 + ($i_049 * 24 & -1) + 8 | 0;
    HEAP32[$56 >> 2] = $55;
    $57 = HEAP32[$28 >> 2] | 0;
    $58 = $57 + ($i_049 * 24 & -1) + 20 | 0;
    HEAP32[$58 >> 2] = -1;
    $59 = HEAP32[$28 >> 2] | 0;
    $60 = $59 + ($i_049 * 24 & -1) + 16 | 0;
    HEAP32[$60 >> 2] = -1;
    $61 = HEAP32[$28 >> 2] | 0;
    $62 = $61 + ($i_049 * 24 & -1) | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = _strcmp($63 | 0, 5324012) | 0;
    $65 = ($64 | 0) == 0;
    if ($65) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $67 = $61 + ($i_049 * 24 & -1) + 16 | 0;
    HEAP32[$67 >> 2] = 2003265652;
    label = 11;
    break;
   case 7:
    $69 = _strcmp($63 | 0, 5320124) | 0;
    $70 = ($69 | 0) == 0;
    if ($70) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $72 = $61 + ($i_049 * 24 & -1) + 16 | 0;
    HEAP32[$72 >> 2] = 2003072104;
    label = 11;
    break;
   case 9:
    $74 = _strcmp($63 | 0, 5320076) | 0;
    $75 = ($74 | 0) == 0;
    if ($75) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $77 = $61 + ($i_049 * 24 & -1) + 16 | 0;
    HEAP32[$77 >> 2] = 1869640570;
    label = 11;
    break;
   case 11:
    $79 = $i_049 + 1 | 0;
    $80 = $79 >>> 0 < $33 >>> 0;
    if ($80) {
      $i_049 = $79;
      label = 5;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $81 = $4 | 0;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = $4 + 4 | 0;
    $84 = HEAP32[$83 >> 2] | 0;
    $85 = 1 << $84;
    $86 = ($82 | 0) == ($85 | 0);
    if ($86) {
      label = 13;
      break;
    } else {
      label = 16;
      break;
    }
   case 13:
    $88 = $4 + 140 | 0;
    $89 = HEAP32[$88 >> 2] | 0;
    $90 = $axiscoords | 0;
    _mm_weights_unmap($89, $90, $84);
    $91 = HEAP32[$8 >> 2] | 0;
    $92 = ($91 | 0) == 0;
    if ($92) {
      label = 16;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $93 = HEAP32[$8 >> 2] | 0;
    $i_148 = 0;
    label = 15;
    break;
   case 15:
    $95 = $4 + 88 + ($i_148 * 12 & -1) | 0;
    $96 = $axiscoords + ($i_148 << 2) | 0;
    $97 = HEAP32[$96 >> 2] | 0;
    $98 = _mm_axis_unmap($95, $97) | 0;
    $99 = HEAP32[$28 >> 2] | 0;
    $100 = $99 + ($i_148 * 24 & -1) + 8 | 0;
    HEAP32[$100 >> 2] = $98;
    $101 = $i_148 + 1 | 0;
    $102 = $101 >>> 0 < $93 >>> 0;
    if ($102) {
      $i_148 = $101;
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    HEAP32[$master >> 2] = $13;
    label = 17;
    break;
   case 17:
    $104 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $104 | 0;
  }
  return 0;
}
function _T1_Set_Var_Design($face, $num_coords, $coords) {
  $face = $face | 0;
  $num_coords = $num_coords | 0;
  $coords = $coords | 0;
  var $lcoords = 0, $1 = 0, $2 = 0, $or_cond = 0, $3 = 0, $i_010 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $10 = 0, $11 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $lcoords = __stackBase__ | 0;
    $1 = $num_coords >>> 0 < 5;
    $2 = ($num_coords | 0) != 0;
    $or_cond = $1 & $2;
    if ($or_cond) {
      label = 2;
      break;
    } else {
      $error_0 = 6;
      label = 5;
      break;
    }
   case 2:
    $3 = ($num_coords | 0) == 0;
    if ($3) {
      label = 4;
      break;
    } else {
      $i_010 = 0;
      label = 3;
      break;
    }
   case 3:
    $4 = $coords + ($i_010 << 2) | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = _FT_RoundFix($5) | 0;
    $7 = $6 >> 16;
    $8 = $lcoords + ($i_010 << 2) | 0;
    HEAP32[$8 >> 2] = $7;
    $9 = $i_010 + 1 | 0;
    $exitcond = ($9 | 0) == ($num_coords | 0);
    if ($exitcond) {
      label = 4;
      break;
    } else {
      $i_010 = $9;
      label = 3;
      break;
    }
   case 4:
    $10 = $lcoords | 0;
    $11 = _T1_Set_MM_Design($face, $num_coords, $10) | 0;
    $error_0 = $11;
    label = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _mm_axis_unmap($axismap, $ncv) {
  $axismap = $axismap | 0;
  $ncv = $ncv | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $j_0 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $axismap + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = ($3 | 0) < ($ncv | 0);
    if ($4) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $5 = $axismap | 0;
    $6 = HEAP8[$5] | 0;
    $7 = $6 & 255;
    $j_0 = 1;
    label = 4;
    break;
   case 3:
    $9 = $axismap + 4 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 << 16;
    $_0 = $12;
    label = 8;
    break;
   case 4:
    $14 = ($j_0 | 0) < ($7 | 0);
    if ($14) {
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    $16 = HEAP32[$1 >> 2] | 0;
    $17 = $16 + ($j_0 << 2) | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = ($18 | 0) < ($ncv | 0);
    $20 = $j_0 + 1 | 0;
    if ($19) {
      $j_0 = $20;
      label = 4;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $22 = $j_0 - 1 | 0;
    $23 = $16 + ($22 << 2) | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $ncv - $24 | 0;
    $26 = $18 - $24 | 0;
    $27 = _FT_MulDiv($25, 65536, $26) | 0;
    $28 = $axismap + 4 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $29 + ($22 << 2) | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $31 << 16;
    $33 = $29 + ($j_0 << 2) | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $34 - $31 | 0;
    $36 = _FT_MulDiv($27, $35, 1) | 0;
    $37 = $36 + $32 | 0;
    $_0 = $37;
    label = 8;
    break;
   case 7:
    $39 = $7 - 1 | 0;
    $40 = $axismap + 4 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = $41 + ($39 << 2) | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $43 << 16;
    $_0 = $44;
    label = 8;
    break;
   case 8:
    return $_0 | 0;
  }
  return 0;
}
function _T1_Get_Track_Kerning($face, $ptsize, $degree, $kerning) {
  $face = $face | 0;
  $ptsize = $ptsize | 0;
  $degree = $degree | 0;
  $kerning = $kerning | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $i_023 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 492 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      $_0 = 6;
      label = 11;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $2 + 32 | 0;
    $5 = $4;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) > 0;
    if ($7) {
      label = 3;
      break;
    } else {
      $_0 = 0;
      label = 11;
      break;
    }
   case 3:
    $8 = $2 + 28 | 0;
    $i_023 = 0;
    label = 4;
    break;
   case 4:
    $10 = HEAP32[$8 >> 2] | 0;
    $11 = $10;
    $12 = $11 + ($i_023 * 20 & -1) | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = ($13 | 0) == ($degree | 0);
    if ($14) {
      label = 5;
      break;
    } else {
      label = 10;
      break;
    }
   case 5:
    $16 = $11 + ($i_023 * 20 & -1) + 4 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($17 | 0) > ($ptsize | 0);
    if ($18) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $20 = $11 + ($i_023 * 20 & -1) + 8 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    HEAP32[$kerning >> 2] = $21;
    label = 10;
    break;
   case 7:
    $23 = $11 + ($i_023 * 20 & -1) + 12 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = ($24 | 0) < ($ptsize | 0);
    if ($25) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $27 = $11 + ($i_023 * 20 & -1) + 16 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    HEAP32[$kerning >> 2] = $28;
    label = 10;
    break;
   case 9:
    $30 = $ptsize - $17 | 0;
    $31 = $11 + ($i_023 * 20 & -1) + 16 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $11 + ($i_023 * 20 & -1) + 8 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $32 - $34 | 0;
    $36 = $24 - $17 | 0;
    $37 = _FT_MulDiv($30, $35, $36) | 0;
    $38 = HEAP32[$33 >> 2] | 0;
    $39 = $38 + $37 | 0;
    HEAP32[$kerning >> 2] = $39;
    label = 10;
    break;
   case 10:
    $41 = $i_023 + 1 | 0;
    $42 = HEAP32[$5 >> 2] | 0;
    $43 = ($41 | 0) < ($42 | 0);
    if ($43) {
      $i_023 = $41;
      label = 4;
      break;
    } else {
      $_0 = 0;
      label = 11;
      break;
    }
   case 11:
    return $_0 | 0;
  }
  return 0;
}
function _t1_ps_get_font_info($face, $afont_info) {
  $face = $face | 0;
  $afont_info = $afont_info | 0;
  _memcpy($afont_info | 0, $face + 132 | 0, 32);
  return 0;
}
function _t1_ps_get_font_private($face, $afont_private) {
  $face = $face | 0;
  $afont_private = $afont_private | 0;
  _memcpy($afont_private | 0, $face + 168 | 0, 196);
  return 0;
}
function _t1_get_glyph_name212($face, $glyph_index, $buffer, $buffer_max) {
  $face = $face | 0;
  $glyph_index = $glyph_index | 0;
  $buffer = $buffer | 0;
  $buffer_max = $buffer_max | 0;
  _ft_mem_strcpyn($buffer, HEAP32[(HEAP32[$face + 420 >> 2] | 0) + ($glyph_index << 2) >> 2] | 0, $buffer_max);
  return 0;
}
function _t1_get_name_index($face, $glyph_name) {
  $face = $face | 0;
  $glyph_name = $glyph_name | 0;
  var $1 = 0, $2 = 0, $3 = 0, $i_0 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 420 | 0;
    $2 = $face + 416 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $i_0 = 0;
    label = 2;
    break;
   case 2:
    $5 = ($i_0 | 0) < ($3 | 0);
    if ($5) {
      label = 3;
      break;
    } else {
      $_0 = 0;
      label = 4;
      break;
    }
   case 3:
    $7 = HEAP32[$1 >> 2] | 0;
    $8 = $7 + ($i_0 << 2) | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = _strcmp($glyph_name | 0, $9 | 0) | 0;
    $11 = ($10 | 0) == 0;
    $12 = $i_0 + 1 | 0;
    if ($11) {
      $_0 = $i_0;
      label = 4;
      break;
    } else {
      $i_0 = $12;
      label = 2;
      break;
    }
   case 4:
    return $_0 | 0;
  }
  return 0;
}
function _cid_slot_done($slot) {
  $slot = $slot | 0;
  HEAP32[(HEAP32[$slot + 156 >> 2] | 0) + 36 >> 2] = 0;
  return;
}
function _cid_get_interface($module, $cid_interface) {
  $module = $module | 0;
  $cid_interface = $cid_interface | 0;
  return _ft_service_list_lookup(5312088, $cid_interface) | 0;
}
function _cid_face_init($stream, $cidface, $face_index, $num_params, $params) {
  $stream = $stream | 0;
  $cidface = $cidface | 0;
  $face_index = $face_index | 0;
  $num_params = $num_params | 0;
  $params = $params | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $_c = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $_c83 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $or_cond = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $family_0_ph92 = 0, $full_0_ph91 = 0, $67 = 0, $family_087 = 0, $68 = 0, $69 = 0, $71 = 0, $family_0_ph_be = 0, $full_0_ph_be = 0, $72 = 0, $73 = 0, $77 = 0, $78 = 0, $79 = 0, $82 = 0, $83 = 0, $84 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $97 = 0, $98 = 0, $100 = 0, $101 = 0, $103 = 0, $104 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $sext = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $151 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cidface;
    $2 = $cidface | 0;
    HEAP32[$2 >> 2] = 1;
    $3 = $cidface + 136 | 0;
    $4 = $3;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $8 = $cidface + 96 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 + 4 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11;
    $13 = _FT_Get_Module_Interface($12, 5323412) | 0;
    $_c = $13;
    HEAP32[$3 >> 2] = $_c;
    label = 3;
    break;
   case 3:
    $15 = $cidface + 320 | 0;
    $16 = $15;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $20 = $cidface + 96 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $21 + 4 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $23;
    $25 = _FT_Get_Module_Interface($24, 5324408) | 0;
    $_c83 = $25;
    HEAP32[$15 >> 2] = $_c83;
    label = 5;
    break;
   case 5:
    $27 = _FT_Stream_Seek($stream, 0) | 0;
    $28 = ($27 | 0) == 0;
    if ($28) {
      label = 6;
      break;
    } else {
      $error_0 = $27;
      label = 34;
      break;
    }
   case 6:
    $30 = _cid_face_open($1, $face_index) | 0;
    $31 = ($30 | 0) != 0;
    $32 = ($face_index | 0) < 0;
    $or_cond = $31 | $32;
    if ($or_cond) {
      $error_0 = $30;
      label = 34;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $34 = ($face_index | 0) == 0;
    if ($34) {
      label = 8;
      break;
    } else {
      $error_0 = 6;
      label = 34;
      break;
    }
   case 8:
    $36 = $cidface + 140 | 0;
    $37 = $36 + 24 | 0;
    $38 = $37;
    $39 = $36 + 156 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $cidface + 16 | 0;
    HEAP32[$41 >> 2] = $40;
    $42 = $cidface + 36 | 0;
    HEAP32[$42 >> 2] = 0;
    $43 = $cidface + 4 | 0;
    HEAP32[$43 >> 2] = $face_index;
    $44 = $cidface + 8 | 0;
    HEAP32[$44 >> 2] = 2065;
    $45 = $36 + 48 | 0;
    $46 = $45;
    $47 = HEAP8[$46] | 0;
    $48 = $47 << 24 >> 24 == 0;
    if ($48) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    HEAP32[$44 >> 2] = 2069;
    label = 10;
    break;
   case 10:
    $51 = $36 + 36 | 0;
    $52 = $51;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $cidface + 20 | 0;
    HEAP32[$54 >> 2] = $53;
    $55 = $cidface + 24 | 0;
    HEAP32[$55 >> 2] = 5322588;
    $56 = HEAP32[$54 >> 2] | 0;
    $57 = ($56 | 0) == 0;
    if ($57) {
      label = 21;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $59 = $36 + 32 | 0;
    $60 = $59;
    $61 = HEAP32[$60 >> 2] | 0;
    $62 = ($61 | 0) == 0;
    if ($62) {
      label = 23;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $63 = HEAP8[$61] | 0;
    $64 = $63 << 24 >> 24 == 0;
    if ($64) {
      label = 23;
      break;
    } else {
      $full_0_ph91 = $61;
      $family_0_ph92 = $56;
      $65 = $63;
      label = 13;
      break;
    }
   case 13:
    $family_087 = $family_0_ph92;
    $67 = $65;
    label = 14;
    break;
   case 14:
    $68 = HEAP8[$family_087] | 0;
    $69 = $67 << 24 >> 24 == $68 << 24 >> 24;
    if ($69) {
      label = 15;
      break;
    } else {
      label = 17;
      break;
    }
   case 15:
    $71 = $family_087 + 1 | 0;
    $family_0_ph_be = $71;
    label = 16;
    break;
   case 16:
    $full_0_ph_be = $full_0_ph91 + 1 | 0;
    $72 = HEAP8[$full_0_ph_be] | 0;
    $73 = $72 << 24 >> 24 == 0;
    if ($73) {
      label = 23;
      break;
    } else {
      $full_0_ph91 = $full_0_ph_be;
      $family_0_ph92 = $family_0_ph_be;
      $65 = $72;
      label = 13;
      break;
    }
   case 17:
    if (($67 << 24 >> 24 | 0) == 32 | ($67 << 24 >> 24 | 0) == 45) {
      $family_0_ph_be = $family_087;
      label = 16;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    if (($68 << 24 >> 24 | 0) == 32 | ($68 << 24 >> 24 | 0) == 45) {
      label = 19;
      break;
    } else if (($68 << 24 >> 24 | 0) == 0) {
      label = 20;
      break;
    } else {
      label = 23;
      break;
    }
   case 19:
    $77 = $family_087 + 1 | 0;
    $78 = HEAP8[$full_0_ph91] | 0;
    $79 = $78 << 24 >> 24 == 0;
    if ($79) {
      label = 23;
      break;
    } else {
      $family_087 = $77;
      $67 = $78;
      label = 14;
      break;
    }
   case 20:
    HEAP32[$55 >> 2] = $full_0_ph91;
    label = 23;
    break;
   case 21:
    $82 = $36;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = ($83 | 0) == 0;
    if ($84) {
      label = 23;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    HEAP32[$54 >> 2] = $83;
    label = 23;
    break;
   case 23:
    $86 = $cidface + 12 | 0;
    HEAP32[$86 >> 2] = 0;
    $87 = $36 + 44 | 0;
    $88 = HEAP32[$87 >> 2] | 0;
    $89 = ($88 | 0) == 0;
    if ($89) {
      label = 25;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    HEAP32[$86 >> 2] = 1;
    label = 25;
    break;
   case 25:
    $92 = $36 + 40 | 0;
    $93 = $92;
    $94 = HEAP32[$93 >> 2] | 0;
    $95 = ($94 | 0) == 0;
    if ($95) {
      label = 29;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $97 = _strcmp($94 | 0, 5321940) | 0;
    $98 = ($97 | 0) == 0;
    if ($98) {
      label = 28;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $100 = _strcmp($94 | 0, 5321280) | 0;
    $101 = ($100 | 0) == 0;
    if ($101) {
      label = 28;
      break;
    } else {
      label = 29;
      break;
    }
   case 28:
    $103 = HEAP32[$86 >> 2] | 0;
    $104 = $103 | 2;
    HEAP32[$86 >> 2] = $104;
    label = 29;
    break;
   case 29:
    $106 = $cidface + 28 | 0;
    HEAP32[$106 >> 2] = 0;
    $107 = $cidface + 32 | 0;
    HEAP32[$107 >> 2] = 0;
    $108 = $36 + 56 | 0;
    $109 = HEAP32[$108 >> 2] | 0;
    $110 = $109 >> 16;
    $111 = $cidface + 52 | 0;
    HEAP32[$111 >> 2] = $110;
    $112 = $36 + 60 | 0;
    $113 = HEAP32[$112 >> 2] | 0;
    $114 = $113 >> 16;
    $115 = $cidface + 56 | 0;
    HEAP32[$115 >> 2] = $114;
    $116 = $36 + 64 | 0;
    $117 = HEAP32[$116 >> 2] | 0;
    $118 = $117 + 65535 | 0;
    $119 = $118 >> 16;
    $120 = $cidface + 60 | 0;
    HEAP32[$120 >> 2] = $119;
    $121 = $36 + 68 | 0;
    $122 = HEAP32[$121 >> 2] | 0;
    $123 = $122 + 65535 | 0;
    $124 = $123 >> 16;
    $125 = $cidface + 64 | 0;
    HEAP32[$125 >> 2] = $124;
    $126 = $cidface + 68 | 0;
    $127 = HEAP16[$126 >> 1] | 0;
    $128 = $127 << 16 >> 16 == 0;
    if ($128) {
      label = 30;
      break;
    } else {
      label = 31;
      break;
    }
   case 30:
    HEAP16[$126 >> 1] = 1e3;
    label = 31;
    break;
   case 31:
    $131 = HEAP32[$125 >> 2] | 0;
    $132 = $131 & 65535;
    $133 = $cidface + 70 | 0;
    HEAP16[$133 >> 1] = $132;
    $134 = HEAP32[$115 >> 2] | 0;
    $135 = $134 & 65535;
    $136 = $cidface + 72 | 0;
    HEAP16[$136 >> 1] = $135;
    $137 = HEAP16[$126 >> 1] | 0;
    $138 = $137 & 65535;
    $139 = $138 * 12 & -1;
    $140 = ($139 >>> 0) / 10 >>> 0;
    $141 = $140 & 65535;
    $142 = $cidface + 74 | 0;
    HEAP16[$142 >> 1] = $141;
    $sext = $140 << 16;
    $143 = $sext >> 16;
    $144 = HEAP16[$133 >> 1] | 0;
    $145 = $144 << 16 >> 16;
    $146 = HEAP16[$136 >> 1] | 0;
    $147 = $146 << 16 >> 16;
    $148 = $145 - $147 | 0;
    $149 = ($143 | 0) < ($148 | 0);
    if ($149) {
      label = 32;
      break;
    } else {
      label = 33;
      break;
    }
   case 32:
    $151 = $148 & 65535;
    HEAP16[$142 >> 1] = $151;
    label = 33;
    break;
   case 33:
    $153 = $38 + 26 | 0;
    $154 = HEAP16[$153 >> 1] | 0;
    $155 = $cidface + 80 | 0;
    HEAP16[$155 >> 1] = $154;
    $156 = $36 + 52 | 0;
    $157 = $156;
    $158 = HEAP16[$157 >> 1] | 0;
    $159 = $cidface + 82 | 0;
    HEAP16[$159 >> 1] = $158;
    $error_0 = $30;
    label = 34;
    break;
   case 34:
    return $error_0 | 0;
  }
  return 0;
}
function _cid_face_done($cidface) {
  $cidface = $cidface | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $n_051 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $_lcssa = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($cidface | 0) == 0;
    if ($1) {
      label = 9;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $cidface + 140 | 0;
    $4 = $3 + 24 | 0;
    $5 = $cidface + 100 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $cidface + 316 | 0;
    $8 = $7;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 8;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = $3 + 160 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($12 | 0) > 0;
    $14 = HEAP32[$8 >> 2] | 0;
    if ($13) {
      $n_051 = 0;
      $15 = $14;
      label = 4;
      break;
    } else {
      $_lcssa = $14;
      label = 7;
      break;
    }
   case 4:
    $16 = $15 + ($n_051 << 3) + 4 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $20 = HEAP32[$17 >> 2] | 0;
    _ft_mem_free($6, $20);
    $21 = HEAP32[$16 >> 2] | 0;
    HEAP32[$21 >> 2] = 0;
    $22 = HEAP32[$16 >> 2] | 0;
    $23 = $22;
    _ft_mem_free($6, $23);
    HEAP32[$16 >> 2] = 0;
    label = 6;
    break;
   case 6:
    $25 = $n_051 + 1 | 0;
    $26 = HEAP32[$11 >> 2] | 0;
    $27 = ($25 | 0) < ($26 | 0);
    $28 = HEAP32[$8 >> 2] | 0;
    if ($27) {
      $n_051 = $25;
      $15 = $28;
      label = 4;
      break;
    } else {
      $_lcssa = $28;
      label = 7;
      break;
    }
   case 7:
    $29 = $_lcssa;
    _ft_mem_free($6, $29);
    $30 = $7 | 0;
    HEAP32[$30 >> 2] = 0;
    label = 8;
    break;
   case 8:
    $32 = $4;
    $33 = HEAP32[$32 >> 2] | 0;
    _ft_mem_free($6, $33);
    HEAP32[$4 >> 2] = 0;
    $34 = $3 + 28 | 0;
    $35 = $34;
    $36 = HEAP32[$35 >> 2] | 0;
    _ft_mem_free($6, $36);
    HEAP32[$34 >> 2] = 0;
    $37 = $3 + 32 | 0;
    $38 = $37;
    $39 = HEAP32[$38 >> 2] | 0;
    _ft_mem_free($6, $39);
    HEAP32[$37 >> 2] = 0;
    $40 = $3 + 36 | 0;
    $41 = $40;
    $42 = HEAP32[$41 >> 2] | 0;
    _ft_mem_free($6, $42);
    HEAP32[$40 >> 2] = 0;
    $43 = $3 + 40 | 0;
    $44 = $43;
    $45 = HEAP32[$44 >> 2] | 0;
    _ft_mem_free($6, $45);
    HEAP32[$43 >> 2] = 0;
    $46 = $3 + 164 | 0;
    $47 = $46;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = $48;
    _ft_mem_free($6, $49);
    HEAP32[$46 >> 2] = 0;
    $50 = $3 + 160 | 0;
    HEAP32[$50 >> 2] = 0;
    $51 = $3;
    $52 = HEAP32[$51 >> 2] | 0;
    _ft_mem_free($6, $52);
    HEAP32[$3 >> 2] = 0;
    $53 = $3 + 12 | 0;
    $54 = $53;
    $55 = HEAP32[$54 >> 2] | 0;
    _ft_mem_free($6, $55);
    HEAP32[$53 >> 2] = 0;
    $56 = $3 + 16 | 0;
    $57 = $56;
    $58 = HEAP32[$57 >> 2] | 0;
    _ft_mem_free($6, $58);
    HEAP32[$56 >> 2] = 0;
    $59 = $cidface + 20 | 0;
    HEAP32[$59 >> 2] = 0;
    $60 = $cidface + 24 | 0;
    HEAP32[$60 >> 2] = 0;
    $61 = $cidface + 324 | 0;
    $62 = $61;
    $63 = HEAP32[$62 >> 2] | 0;
    _ft_mem_free($6, $63);
    HEAP32[$61 >> 2] = 0;
    $64 = $cidface + 328 | 0;
    $65 = $64;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = $66;
    _ft_mem_free($6, $67);
    HEAP32[$64 >> 2] = 0;
    label = 9;
    break;
   case 9:
    return;
  }
}
function _cid_size_init($cidsize) {
  $cidsize = $cidsize | 0;
  var $globals = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $globals = __stackBase__ | 0;
    $1 = $cidsize;
    $2 = _cid_size_get_globals_funcs($1) | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      $error_0 = 0;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $cidsize | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + 140 | 0;
    $8 = $7 + 164 | 0;
    $9 = $8;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $6 + 4 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $10 + ($12 * 252 & -1) | 0;
    $14 = $2 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $6 + 100 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = FUNCTION_TABLE_iiii[$15 & 1023]($17, $13, $globals) | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 3;
      break;
    } else {
      $error_0 = $18;
      label = 4;
      break;
    }
   case 3:
    $21 = HEAP32[$globals >> 2] | 0;
    $22 = $21;
    $23 = $cidsize + 40 | 0;
    HEAP32[$23 >> 2] = $22;
    $error_0 = 0;
    label = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _cid_size_done($cidsize) {
  $cidsize = $cidsize | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cidsize + 40 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $cidsize;
    $6 = _cid_size_get_globals_funcs($5) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = $6 + 8 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = HEAP32[$1 >> 2] | 0;
    $12 = $11;
    FUNCTION_TABLE_vi[$10 & 1023]($12);
    label = 4;
    break;
   case 4:
    HEAP32[$1 >> 2] = 0;
    label = 5;
    break;
   case 5:
    return;
  }
}
function _cid_slot_init($slot) {
  $slot = $slot | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $slot + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 320 | 0;
    $4 = $3;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $2 + 96 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 + 4 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11;
    $13 = _FT_Get_Module($12, 5324408) | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $16 = $13;
    $17 = $5 + 4 | 0;
    $18 = $17;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = FUNCTION_TABLE_ii[$19 & 1023]($16) | 0;
    $21 = $20;
    $22 = $slot + 156 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $23 + 36 | 0;
    HEAP32[$24 >> 2] = $21;
    label = 4;
    break;
   case 4:
    return 0;
  }
  return 0;
}
function _cid_slot_load_glyph($cidglyph, $cidsize, $glyph_index, $load_flags) {
  $cidglyph = $cidglyph | 0;
  $cidsize = $cidsize | 0;
  $glyph_index = $glyph_index | 0;
  $load_flags = $load_flags | 0;
  var $decoder = 0, $font_matrix = 0, $cbox = 0, $advance = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $load_flags_ = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $_c = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $_c78 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $_lobit = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $font_offset_sroa_0_0__idx28 = 0, $font_offset_sroa_0_0_copyload29 = 0, $font_offset_sroa_1_4__idx32 = 0, $font_offset_sroa_1_4_copyload33 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $font_offset_sroa_0_0__idx = 0, $font_offset_sroa_1_4__idx31 = 0, $76 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $104 = 0, $105 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $123 = 0, $124 = 0, $125 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $vec_080 = 0, $n_079 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $165 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 1540 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $decoder = __stackBase__ | 0;
    $font_matrix = __stackBase__ + 1500 | 0;
    $cbox = __stackBase__ + 1516 | 0;
    $advance = __stackBase__ + 1532 | 0;
    $1 = $cidglyph + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 136 | 0;
    $4 = $3;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $2 + 16 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 >>> 0 > $glyph_index >>> 0;
    if ($8) {
      label = 2;
      break;
    } else {
      $error_0 = 6;
      label = 19;
      break;
    }
   case 2:
    $10 = $load_flags & 1024;
    $11 = ($10 | 0) == 0;
    $12 = $load_flags | 3;
    $load_flags_ = $11 ? $load_flags : $12;
    $13 = $cidsize + 16 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $cidglyph + 164 | 0;
    $16 = $15;
    $_c = $14;
    HEAP32[$15 >> 2] = $_c;
    $17 = $cidsize + 20 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $cidglyph + 168 | 0;
    $20 = $19;
    $_c78 = $18;
    HEAP32[$19 >> 2] = $_c78;
    $21 = $cidglyph + 108 | 0;
    $22 = $cidglyph + 110 | 0;
    HEAP16[$22 >> 1] = 0;
    $23 = $21 | 0;
    HEAP16[$23 >> 1] = 0;
    $24 = $load_flags_ & 1;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 3;
      break;
    } else {
      $30 = 0;
      label = 4;
      break;
    }
   case 3:
    $27 = $load_flags_ & 2;
    $28 = ($27 | 0) == 0;
    $30 = $28;
    label = 4;
    break;
   case 4:
    $31 = $30 & 1;
    $32 = $cidglyph + 72 | 0;
    HEAP32[$32 >> 2] = 1869968492;
    $33 = $5 + 12 | 0;
    $34 = $33;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $35 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = HEAP32[$1 >> 2] | 0;
    $39 = $load_flags_ >>> 16;
    $40 = $39 & 15;
    $41 = FUNCTION_TABLE_iiiiiiiiii[$37 & 1023]($decoder, $38, $cidsize, $cidglyph, 0, 0, $31, $40, 328) | 0;
    $42 = ($41 | 0) == 0;
    if ($42) {
      label = 5;
      break;
    } else {
      $error_0 = $41;
      label = 19;
      break;
    }
   case 5:
    $44 = $load_flags_ & 1024;
    $_lobit = $44 >>> 10;
    $45 = $_lobit & 255;
    $46 = $decoder + 69 | 0;
    HEAP8[$46] = $45;
    $47 = _cid_load_glyph($decoder, $glyph_index) | 0;
    $48 = ($47 | 0) == 0;
    if ($48) {
      label = 6;
      break;
    } else {
      $error_0 = $47;
      label = 19;
      break;
    }
   case 6:
    $50 = ($44 | 0) == 0;
    $51 = $decoder + 1376 | 0;
    $52 = $font_matrix;
    $53 = $51;
    _memcpy($52 | 0, $53 | 0, 16);
    $font_offset_sroa_0_0__idx28 = $decoder + 1392 | 0;
    $font_offset_sroa_0_0_copyload29 = HEAP32[$font_offset_sroa_0_0__idx28 >> 2] | 0;
    $font_offset_sroa_1_4__idx32 = $decoder + 1396 | 0;
    $font_offset_sroa_1_4_copyload33 = HEAP32[$font_offset_sroa_1_4__idx32 >> 2] | 0;
    $54 = HEAP32[$34 >> 2] | 0;
    $55 = $54 + 4 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    FUNCTION_TABLE_vi[$56 & 1023]($decoder);
    $57 = $cidglyph + 124 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = $58 & 1;
    $60 = $59 | 4;
    HEAP32[$57 >> 2] = $60;
    if ($50) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $62 = $cidglyph + 156 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = $decoder + 32 | 0;
    $65 = HEAP32[$64 >> 2] | 0;
    $66 = _FT_RoundFix($65) | 0;
    $67 = $66 >> 16;
    $68 = $cidglyph + 32 | 0;
    HEAP32[$68 >> 2] = $67;
    $69 = $decoder + 40 | 0;
    $70 = HEAP32[$69 >> 2] | 0;
    $71 = _FT_RoundFix($70) | 0;
    $72 = $71 >> 16;
    $73 = $cidglyph + 40 | 0;
    HEAP32[$73 >> 2] = $72;
    $74 = $63 + 12 | 0;
    $75 = $74;
    _memcpy($75 | 0, $52 | 0, 16);
    $font_offset_sroa_0_0__idx = $63 + 28 | 0;
    HEAP32[$font_offset_sroa_0_0__idx >> 2] = $font_offset_sroa_0_0_copyload29;
    $font_offset_sroa_1_4__idx31 = $63 + 32 | 0;
    HEAP32[$font_offset_sroa_1_4__idx31 >> 2] = $font_offset_sroa_1_4_copyload33;
    $76 = $63 + 8 | 0;
    HEAP8[$76] = 1;
    $error_0 = $47;
    label = 19;
    break;
   case 8:
    $78 = $cidglyph + 24 | 0;
    $79 = $decoder + 40 | 0;
    $80 = HEAP32[$79 >> 2] | 0;
    $81 = _FT_RoundFix($80) | 0;
    $82 = $81 >> 16;
    $83 = $cidglyph + 40 | 0;
    HEAP32[$83 >> 2] = $82;
    $84 = HEAP32[$79 >> 2] | 0;
    $85 = _FT_RoundFix($84) | 0;
    $86 = $85 >> 16;
    $87 = $cidglyph + 56 | 0;
    HEAP32[$87 >> 2] = $86;
    $88 = $cidglyph + 156 | 0;
    $89 = HEAP32[$88 >> 2] | 0;
    $90 = $89 + 8 | 0;
    HEAP8[$90] = 0;
    $91 = $2 + 140 | 0;
    $92 = $91 + 68 | 0;
    $93 = HEAP32[$92 >> 2] | 0;
    $94 = $91 + 60 | 0;
    $95 = HEAP32[$94 >> 2] | 0;
    $96 = $93 - $95 | 0;
    $97 = $96 >> 16;
    $98 = $cidglyph + 52 | 0;
    HEAP32[$98 >> 2] = $97;
    $99 = $cidglyph + 60 | 0;
    HEAP32[$99 >> 2] = $97;
    HEAP32[$32 >> 2] = 1869968492;
    $100 = $cidsize + 14 | 0;
    $101 = HEAP16[$100 >> 1] | 0;
    $102 = ($101 & 65535) < 24;
    if ($102) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $104 = HEAP32[$57 >> 2] | 0;
    $105 = $104 | 256;
    HEAP32[$57 >> 2] = $105;
    label = 10;
    break;
   case 10:
    _FT_Outline_Transform($21, $font_matrix);
    _FT_Outline_Translate($21, $font_offset_sroa_0_0_copyload29, $font_offset_sroa_1_4_copyload33);
    $107 = HEAP32[$83 >> 2] | 0;
    $108 = $advance | 0;
    HEAP32[$108 >> 2] = $107;
    $109 = $advance + 4 | 0;
    HEAP32[$109 >> 2] = 0;
    _FT_Vector_Transform($advance, $font_matrix);
    $110 = HEAP32[$108 >> 2] | 0;
    $111 = $110 + $font_offset_sroa_0_0_copyload29 | 0;
    HEAP32[$83 >> 2] = $111;
    HEAP32[$108 >> 2] = 0;
    $112 = HEAP32[$98 >> 2] | 0;
    HEAP32[$109 >> 2] = $112;
    _FT_Vector_Transform($advance, $font_matrix);
    $113 = HEAP32[$109 >> 2] | 0;
    $114 = $113 + $font_offset_sroa_1_4_copyload33 | 0;
    HEAP32[$98 >> 2] = $114;
    if ($25) {
      label = 11;
      break;
    } else {
      label = 17;
      break;
    }
   case 11:
    $116 = $decoder + 16 | 0;
    $117 = HEAP32[$116 >> 2] | 0;
    $118 = $117 + 4 | 0;
    $119 = HEAP32[$118 >> 2] | 0;
    $120 = HEAP32[$16 >> 2] | 0;
    $121 = HEAP32[$20 >> 2] | 0;
    if ($30) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $123 = $decoder + 72 | 0;
    $124 = HEAP32[$123 >> 2] | 0;
    $125 = ($124 | 0) == 0;
    if ($125) {
      label = 13;
      break;
    } else {
      label = 16;
      break;
    }
   case 13:
    $127 = $117 + 2 | 0;
    $128 = HEAP16[$127 >> 1] | 0;
    $129 = $128 << 16 >> 16 > 0;
    if ($129) {
      label = 14;
      break;
    } else {
      label = 16;
      break;
    }
   case 14:
    $130 = $128 << 16 >> 16;
    $n_079 = $130;
    $vec_080 = $119;
    label = 15;
    break;
   case 15:
    $132 = $vec_080 | 0;
    $133 = HEAP32[$132 >> 2] | 0;
    $134 = _FT_MulFix($133, $120) | 0;
    HEAP32[$132 >> 2] = $134;
    $135 = $vec_080 + 4 | 0;
    $136 = HEAP32[$135 >> 2] | 0;
    $137 = _FT_MulFix($136, $121) | 0;
    HEAP32[$135 >> 2] = $137;
    $138 = $n_079 - 1 | 0;
    $139 = $vec_080 + 8 | 0;
    $140 = ($138 | 0) > 0;
    if ($140) {
      $n_079 = $138;
      $vec_080 = $139;
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $141 = HEAP32[$83 >> 2] | 0;
    $142 = _FT_MulFix($141, $120) | 0;
    HEAP32[$83 >> 2] = $142;
    $143 = HEAP32[$98 >> 2] | 0;
    $144 = _FT_MulFix($143, $121) | 0;
    HEAP32[$98 >> 2] = $144;
    label = 17;
    break;
   case 17:
    _FT_Outline_Get_CBox($21, $cbox);
    $146 = $cbox + 8 | 0;
    $147 = HEAP32[$146 >> 2] | 0;
    $148 = $cbox | 0;
    $149 = HEAP32[$148 >> 2] | 0;
    $150 = $147 - $149 | 0;
    $151 = $78 | 0;
    HEAP32[$151 >> 2] = $150;
    $152 = $cbox + 12 | 0;
    $153 = HEAP32[$152 >> 2] | 0;
    $154 = $cbox + 4 | 0;
    $155 = HEAP32[$154 >> 2] | 0;
    $156 = $153 - $155 | 0;
    $157 = $cidglyph + 28 | 0;
    HEAP32[$157 >> 2] = $156;
    $158 = HEAP32[$148 >> 2] | 0;
    $159 = $cidglyph + 32 | 0;
    HEAP32[$159 >> 2] = $158;
    $160 = HEAP32[$152 >> 2] | 0;
    $161 = $cidglyph + 36 | 0;
    HEAP32[$161 >> 2] = $160;
    $162 = $load_flags_ & 16;
    $163 = ($162 | 0) == 0;
    if ($163) {
      $error_0 = $47;
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $165 = HEAP32[$98 >> 2] | 0;
    _ft_synthesize_vertical_metrics($78, $165);
    $error_0 = $47;
    label = 19;
    break;
   case 19:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _cid_size_request($size, $req) {
  $size = $size | 0;
  $req = $req | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    _FT_Request_Metrics($3, $req);
    $4 = $size;
    $5 = _cid_size_get_globals_funcs($4) | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $5 + 4 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $size + 40 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11;
    $13 = $size + 16 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $size + 20 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = FUNCTION_TABLE_iiiiii[$9 & 1023]($12, $14, $16, 0, 0) | 0;
    label = 3;
    break;
   case 3:
    return 0;
  }
  return 0;
}
function _cid_get_offset($start, $offsize) {
  $start = $start | 0;
  $offsize = $offsize | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $p_09 = 0, $result_08 = 0, $_07 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $scevgep = 0, $p_0_lcssa = 0, $result_0_lcssa = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$start >> 2] | 0;
    $2 = $offsize << 24 >> 24 == 0;
    if ($2) {
      $result_0_lcssa = 0;
      $p_0_lcssa = $1;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $offsize - 1 & 255;
    $4 = $3 & 255;
    $5 = $4 + 1 | 0;
    $_07 = $offsize;
    $result_08 = 0;
    $p_09 = $1;
    label = 3;
    break;
   case 3:
    $7 = $result_08 << 8;
    $8 = $p_09 + 1 | 0;
    $9 = HEAP8[$p_09] | 0;
    $10 = $9 & 255;
    $11 = $10 | $7;
    $12 = $_07 - 1 & 255;
    $13 = $12 << 24 >> 24 == 0;
    if ($13) {
      label = 4;
      break;
    } else {
      $_07 = $12;
      $result_08 = $11;
      $p_09 = $8;
      label = 3;
      break;
    }
   case 4:
    $scevgep = $1 + $5 | 0;
    $result_0_lcssa = $11;
    $p_0_lcssa = $scevgep;
    label = 5;
    break;
   case 5:
    HEAP32[$start >> 2] = $p_0_lcssa;
    return $result_0_lcssa | 0;
  }
  return 0;
}
function _cid_load_glyph($decoder, $glyph_index) {
  $decoder = $decoder | 0;
  $glyph_index = $glyph_index | 0;
  var $p = 0, $error = 0, $glyph_data = 0, $metrics = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $glyph_length_0 = 0, $charstring_0 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $71 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $93 = 0, $95 = 0, $96 = 0, $97 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $glyph_length_1 = 0, $charstring_1 = 0, $fd_select_0 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $ld$0$0 = 0, $125$0 = 0, $ld$1$1 = 0, $125$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $_ = 0, $131 = 0, $132 = 0, $133 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $_not = 0, $_not71 = 0, $brmerge = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $177 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 32 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $p = __stackBase__ | 0;
    $error = __stackBase__ + 4 | 0;
    $glyph_data = __stackBase__ + 8 | 0;
    $metrics = __stackBase__ + 16 | 0;
    $1 = $decoder + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 140 | 0;
    $4 = $2 + 328 | 0;
    $5 = $4;
    $6 = HEAP32[$5 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $7 = $2 + 100 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $2 + 136 | 0;
    $10 = $9;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $2 + 128 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 + 52 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = ($15 | 0) != 0;
    if ($16) {
      label = 2;
      break;
    } else {
      label = 7;
      break;
    }
   case 2:
    $18 = $15 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $19 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $15 + 4 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = FUNCTION_TABLE_iiii[$21 & 1023]($23, $glyph_index, $glyph_data) | 0;
    HEAP32[$error >> 2] = $24;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 3;
      break;
    } else {
      label = 19;
      break;
    }
   case 3:
    $27 = $glyph_data | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    HEAP32[$p >> 2] = $28;
    $29 = $3 + 148 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $30 & 255;
    $32 = _cid_get_offset($p, $31) | 0;
    $33 = $glyph_data + 4 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = ($34 | 0) == 0;
    if ($35) {
      $charstring_0 = 0;
      $glyph_length_0 = 0;
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $37 = HEAP32[$29 >> 2] | 0;
    $38 = $34 - $37 | 0;
    $39 = _ft_mem_alloc($8, $38, $error) | 0;
    $40 = HEAP32[$error >> 2] | 0;
    $41 = ($40 | 0) == 0;
    if ($41) {
      label = 5;
      break;
    } else {
      $charstring_0 = $39;
      $glyph_length_0 = $38;
      label = 6;
      break;
    }
   case 5:
    $43 = HEAP32[$27 >> 2] | 0;
    $44 = HEAP32[$29 >> 2] | 0;
    $45 = $43 + $44 | 0;
    _memcpy($39 | 0, $45 | 0, $38 | 0);
    $charstring_0 = $39;
    $glyph_length_0 = $38;
    label = 6;
    break;
   case 6:
    $47 = HEAP32[$18 >> 2] | 0;
    $48 = $47 + 4 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = HEAP32[$22 >> 2] | 0;
    FUNCTION_TABLE_vii[$49 & 1023]($50, $glyph_data);
    $51 = HEAP32[$error >> 2] | 0;
    $52 = ($51 | 0) == 0;
    if ($52) {
      $fd_select_0 = $32;
      $charstring_1 = $charstring_0;
      $glyph_length_1 = $glyph_length_0;
      label = 14;
      break;
    } else {
      label = 19;
      break;
    }
   case 7:
    $54 = $3 + 148 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = $3 + 152 | 0;
    $57 = HEAP32[$56 >> 2] | 0;
    $58 = $57 + $55 | 0;
    $59 = $3 + 168 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = $3 + 144 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = $62 + $60 | 0;
    $64 = Math_imul($58, $glyph_index);
    $65 = $63 + $64 | 0;
    $66 = _FT_Stream_Seek($6, $65) | 0;
    HEAP32[$error >> 2] = $66;
    $67 = ($66 | 0) == 0;
    if ($67) {
      label = 8;
      break;
    } else {
      label = 19;
      break;
    }
   case 8:
    $69 = $58 << 1;
    $70 = _FT_Stream_EnterFrame($6, $69) | 0;
    HEAP32[$error >> 2] = $70;
    $71 = ($70 | 0) == 0;
    if ($71) {
      label = 9;
      break;
    } else {
      label = 19;
      break;
    }
   case 9:
    $73 = $6 + 32 | 0;
    $74 = HEAP32[$73 >> 2] | 0;
    HEAP32[$p >> 2] = $74;
    $75 = HEAP32[$54 >> 2] | 0;
    $76 = $75 & 255;
    $77 = _cid_get_offset($p, $76) | 0;
    $78 = HEAP32[$56 >> 2] | 0;
    $79 = $78 & 255;
    $80 = _cid_get_offset($p, $79) | 0;
    $81 = HEAP32[$54 >> 2] | 0;
    $82 = HEAP32[$p >> 2] | 0;
    $83 = $82 + $81 | 0;
    HEAP32[$p >> 2] = $83;
    $84 = HEAP32[$56 >> 2] | 0;
    $85 = $84 & 255;
    $86 = _cid_get_offset($p, $85) | 0;
    $87 = $86 - $80 | 0;
    _FT_Stream_ExitFrame($6);
    $88 = $3 + 160 | 0;
    $89 = HEAP32[$88 >> 2] | 0;
    $90 = $77 >>> 0 < $89 >>> 0;
    if ($90) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    HEAP32[$error >> 2] = 9;
    label = 19;
    break;
   case 11:
    $93 = ($86 | 0) == ($80 | 0);
    if ($93) {
      label = 19;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $95 = _ft_mem_alloc($8, $87, $error) | 0;
    $96 = HEAP32[$error >> 2] | 0;
    $97 = ($96 | 0) == 0;
    if ($97) {
      label = 13;
      break;
    } else {
      label = 19;
      break;
    }
   case 13:
    $99 = HEAP32[$59 >> 2] | 0;
    $100 = $99 + $80 | 0;
    $101 = _FT_Stream_ReadAt($6, $100, $95, $87) | 0;
    HEAP32[$error >> 2] = $101;
    $102 = ($101 | 0) == 0;
    if ($102) {
      $fd_select_0 = $77;
      $charstring_1 = $95;
      $glyph_length_1 = $87;
      label = 14;
      break;
    } else {
      label = 19;
      break;
    }
   case 14:
    $104 = $2 + 316 | 0;
    $105 = $104;
    $106 = HEAP32[$105 >> 2] | 0;
    $107 = $106 + ($fd_select_0 << 3) | 0;
    $108 = HEAP32[$107 >> 2] | 0;
    $109 = $decoder + 1364 | 0;
    HEAP32[$109 >> 2] = $108;
    $110 = $106 + ($fd_select_0 << 3) + 4 | 0;
    $111 = HEAP32[$110 >> 2] | 0;
    $112 = $decoder + 1368 | 0;
    HEAP32[$112 >> 2] = $111;
    $113 = $decoder + 1372 | 0;
    HEAP32[$113 >> 2] = 0;
    $114 = $3 + 164 | 0;
    $115 = $114;
    $116 = HEAP32[$115 >> 2] | 0;
    $117 = $decoder + 1376 | 0;
    $118 = $116 + ($fd_select_0 * 252 & -1) + 216 | 0;
    $119 = $117;
    $120 = $118;
    _memcpy($119 | 0, $120 | 0, 16);
    $121 = $decoder + 1392 | 0;
    $122 = $116 + ($fd_select_0 * 252 & -1) + 232 | 0;
    $123 = $122;
    $124 = $121;
    $ld$0$0 = $123 | 0;
    $125$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $123 + 4 | 0;
    $125$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $124 | 0;
    HEAP32[$st$2$0 >> 2] = $125$0;
    $st$3$1 = $124 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $125$1;
    $126 = $116 + ($fd_select_0 * 252 & -1) + 4 | 0;
    $127 = HEAP32[$126 >> 2] | 0;
    $128 = $decoder + 1360 | 0;
    HEAP32[$128 >> 2] = $127;
    $129 = ($127 | 0) > -1;
    $_ = $129 ? $127 : 0;
    if ($129) {
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 15:
    $131 = $11 + 16 | 0;
    $132 = $131;
    $133 = HEAP32[$132 >> 2] | 0;
    FUNCTION_TABLE_viii[$133 & 1023]($charstring_1, $glyph_length_1, 4330);
    label = 16;
    break;
   case 16:
    $135 = $decoder + 1484 | 0;
    $136 = HEAP32[$135 >> 2] | 0;
    $137 = $charstring_1 + $_ | 0;
    $138 = $glyph_length_1 - $_ | 0;
    $139 = FUNCTION_TABLE_iiii[$136 & 1023]($decoder, $137, $138) | 0;
    HEAP32[$error >> 2] = $139;
    _ft_mem_free($8, $charstring_1);
    $140 = HEAP32[$error >> 2] | 0;
    $_not = ($140 | 0) != 0;
    $_not71 = $16 ^ 1;
    $brmerge = $_not | $_not71;
    if ($brmerge) {
      label = 19;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $142 = $15 | 0;
    $143 = HEAP32[$142 >> 2] | 0;
    $144 = $143 + 8 | 0;
    $145 = HEAP32[$144 >> 2] | 0;
    $146 = ($145 | 0) == 0;
    if ($146) {
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $148 = $decoder + 32 | 0;
    $149 = HEAP32[$148 >> 2] | 0;
    $150 = _FT_RoundFix($149) | 0;
    $151 = $150 >> 16;
    $152 = $metrics | 0;
    HEAP32[$152 >> 2] = $151;
    $153 = $metrics + 4 | 0;
    HEAP32[$153 >> 2] = 0;
    $154 = $decoder + 40 | 0;
    $155 = HEAP32[$154 >> 2] | 0;
    $156 = _FT_RoundFix($155) | 0;
    $157 = $156 >> 16;
    $158 = $metrics + 8 | 0;
    HEAP32[$158 >> 2] = $157;
    $159 = $decoder + 44 | 0;
    $160 = HEAP32[$159 >> 2] | 0;
    $161 = _FT_RoundFix($160) | 0;
    $162 = $161 >> 16;
    $163 = $metrics + 12 | 0;
    HEAP32[$163 >> 2] = $162;
    $164 = HEAP32[$142 >> 2] | 0;
    $165 = $164 + 8 | 0;
    $166 = HEAP32[$165 >> 2] | 0;
    $167 = $15 + 4 | 0;
    $168 = HEAP32[$167 >> 2] | 0;
    $169 = FUNCTION_TABLE_iiiii[$166 & 1023]($168, $glyph_index, 0, $metrics) | 0;
    HEAP32[$error >> 2] = $169;
    $170 = HEAP32[$152 >> 2] | 0;
    $171 = $170 << 16;
    HEAP32[$148 >> 2] = $171;
    $172 = HEAP32[$158 >> 2] | 0;
    $173 = $172 << 16;
    HEAP32[$154 >> 2] = $173;
    $174 = HEAP32[$163 >> 2] | 0;
    $175 = $174 << 16;
    HEAP32[$159 >> 2] = $175;
    label = 19;
    break;
   case 19:
    $177 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $177 | 0;
  }
  return 0;
}
function _cid_size_get_globals_funcs($size) {
  $size = $size | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $or_cond = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 320 | 0;
    $4 = $3;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $2 + 96 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 + 4 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9;
    $11 = _FT_Get_Module($10, 5324408) | 0;
    $12 = $11;
    $13 = ($11 | 0) == 0;
    $14 = ($5 | 0) == 0;
    $or_cond = $13 | $14;
    if ($or_cond) {
      $22 = 0;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $16 = $5;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      $22 = 0;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $20 = FUNCTION_TABLE_ii[$17 & 1023]($12) | 0;
    $22 = $20;
    label = 4;
    break;
   case 4:
    return $22 | 0;
  }
  return 0;
}
function _cid_face_open($face, $face_index) {
  $face = $face | 0;
  $face_index = $face_index | 0;
  var $loader = 0, $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $or_cond = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $55 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 108 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $loader = __stackBase__ | 0;
    $error = __stackBase__ + 104 | 0;
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    _t1_init_loader281($loader);
    $3 = $loader | 0;
    $4 = $face + 104 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = HEAP32[$1 >> 2] | 0;
    $7 = $face + 136 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8;
    $10 = _cid_parser_new($3, $5, $6, $9) | 0;
    HEAP32[$error >> 2] = $10;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 2;
      break;
    } else {
      label = 10;
      break;
    }
   case 2:
    $13 = $loader + 76 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $loader + 80 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = _cid_parse_dict($face, $loader, $14, $16) | 0;
    HEAP32[$error >> 2] = $17;
    $18 = ($17 | 0) != 0;
    $19 = ($face_index | 0) < 0;
    $or_cond = $18 | $19;
    if ($or_cond) {
      label = 10;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $21 = _ft_mem_alloc($2, 40, $error) | 0;
    $22 = $21;
    $23 = $face + 328 | 0;
    HEAP32[$23 >> 2] = $22;
    $24 = HEAP32[$error >> 2] | 0;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 4;
      break;
    } else {
      label = 10;
      break;
    }
   case 4:
    $27 = $loader + 88 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 8;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $31 = _ft_mem_alloc($2, $28, $error) | 0;
    $32 = $face + 324 | 0;
    HEAP32[$32 >> 2] = $31;
    $33 = HEAP32[$error >> 2] | 0;
    $34 = ($33 | 0) == 0;
    if ($34) {
      label = 6;
      break;
    } else {
      label = 10;
      break;
    }
   case 6:
    $36 = HEAP32[$27 >> 2] | 0;
    $37 = $loader + 84 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = _cid_hex_to_binary($31, $36, $38, $face) | 0;
    $40 = ($39 | 0) == 0;
    if ($40) {
      label = 7;
      break;
    } else {
      label = 10;
      break;
    }
   case 7:
    $42 = HEAP32[$23 >> 2] | 0;
    $43 = HEAP32[$32 >> 2] | 0;
    $44 = HEAP32[$27 >> 2] | 0;
    _FT_Stream_OpenMemory($42, $43, $44);
    $45 = $face + 308 | 0;
    HEAP32[$45 >> 2] = 0;
    label = 9;
    break;
   case 8:
    $47 = HEAP32[$4 >> 2] | 0;
    $48 = $47;
    _memcpy($21 | 0, $48 | 0, 40);
    $49 = $loader + 84 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $face + 308 | 0;
    HEAP32[$51 >> 2] = $50;
    label = 9;
    break;
   case 9:
    $53 = _cid_read_subrs($face) | 0;
    HEAP32[$error >> 2] = $53;
    label = 10;
    break;
   case 10:
    _t1_done_loader282($loader);
    $55 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $55 | 0;
  }
  return 0;
}
function _t1_init_loader281($loader) {
  $loader = $loader | 0;
  _memset($loader | 0, 0, 104);
  return;
}
function _cid_parser_new($parser, $stream, $memory, $psaux) {
  $parser = $parser | 0;
  $stream = $stream | 0;
  $memory = $memory | 0;
  $psaux = $psaux | 0;
  var $buffer = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $_ = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $p_095 = 0, $read_len_094 = 0, $offset_092 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $49 = 0, $_sum = 0, $51 = 0, $52 = 0, $p_188 = 0, $53 = 0, $54 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $p_1_lcssa = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $_pn = 0, $offset_1 = 0, $78 = 0, $79 = 0, $80 = 0, $82 = 0, $83 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $cur_0105 = 0, $95 = 0, $cur_0108 = 0, $arg2_0107 = 0, $arg1_0106 = 0, $96 = 0, $97 = 0, $99 = 0, $100 = 0, $102 = 0, $103 = 0, $105 = 0, $106 = 0, $108 = 0, $109 = 0, $111 = 0, $112 = 0, $113 = 0, $115 = 0, $116 = 0, $118 = 0, $119 = 0, $cur_0 = 0, $120 = 0, $121 = 0, $122 = 0, $error_1 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 268 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $buffer = __stackBase__ | 0;
    $1 = $parser;
    _memset($1 | 0, 0, 100);
    $2 = $psaux + 4 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $parser | 0;
    FUNCTION_TABLE_viiii[$5 & 1023]($6, 0, 0, $memory);
    $7 = $parser + 72 | 0;
    HEAP32[$7 >> 2] = $stream;
    $8 = _FT_Stream_Pos($stream) | 0;
    $9 = _FT_Stream_EnterFrame($stream, 31) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 2;
      break;
    } else {
      $error_1 = $9;
      label = 30;
      break;
    }
   case 2:
    $12 = $stream + 32 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = _strncmp($13 | 0, 5320900, 31) | 0;
    $15 = ($14 | 0) == 0;
    $_ = $15 ? $9 : 2;
    _FT_Stream_ExitFrame($stream);
    $16 = ($_ | 0) == 0;
    if ($16) {
      label = 3;
      break;
    } else {
      $error_1 = $_;
      label = 30;
      break;
    }
   case 3:
    $17 = $buffer | 0;
    $18 = $stream + 4 | 0;
    $19 = $buffer + 10 | 0;
    $20 = $buffer;
    $21 = 10 - $20 | 0;
    $22 = $parser + 76 | 0;
    $23 = $parser + 84 | 0;
    $24 = $parser + 80 | 0;
    $25 = $parser + 4 | 0;
    $26 = $parser | 0;
    $27 = $parser + 8 | 0;
    $28 = $parser + 96 | 0;
    $29 = $parser + 32 | 0;
    $30 = $parser + 28 | 0;
    $31 = $parser + 12 | 0;
    $32 = $buffer;
    $33 = 7 - $32 | 0;
    label = 4;
    break;
   case 4:
    $35 = HEAP32[$18 >> 2] | 0;
    $36 = _FT_Stream_Pos($stream) | 0;
    $37 = ($35 | 0) == ($36 | 0);
    if ($37) {
      $error_1 = 2;
      label = 30;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $38 = $35 - $36 | 0;
    $39 = _FT_Stream_Pos($stream) | 0;
    $offset_092 = $39;
    $read_len_094 = 266;
    $p_095 = $17;
    $41 = $38;
    label = 6;
    break;
   case 6:
    $42 = ($read_len_094 | 0) < ($41 | 0);
    $43 = $42 ? $read_len_094 : $41;
    $44 = _FT_Stream_Read($stream, $p_095, $43) | 0;
    $45 = ($44 | 0) == 0;
    if ($45) {
      label = 7;
      break;
    } else {
      $error_1 = $44;
      label = 30;
      break;
    }
   case 7:
    $47 = ($43 | 0) < 256;
    if ($47) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $49 = $p_095 + $43 | 0;
    HEAP8[$49] = 0;
    label = 9;
    break;
   case 9:
    $_sum = $43 - 10 | 0;
    $51 = $p_095 + $_sum | 0;
    $52 = $17 >>> 0 < $51 >>> 0;
    if ($52) {
      $p_188 = $17;
      label = 10;
      break;
    } else {
      $p_1_lcssa = $17;
      label = 17;
      break;
    }
   case 10:
    $53 = HEAP8[$p_188] | 0;
    $54 = $53 << 24 >> 24 == 83;
    if ($54) {
      label = 11;
      break;
    } else {
      label = 13;
      break;
    }
   case 11:
    $56 = _strncmp($p_188 | 0, 5320856, 9) | 0;
    $57 = ($56 | 0) == 0;
    if ($57) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $59 = $p_188;
    $60 = $21 + $59 | 0;
    $_pn = $60;
    label = 18;
    break;
   case 13:
    $62 = $p_188 + 1 | 0;
    $63 = HEAP8[$62] | 0;
    $64 = $63 << 24 >> 24 == 115;
    if ($64) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $66 = _strncmp($p_188 | 0, 5320796, 6) | 0;
    $67 = ($66 | 0) == 0;
    if ($67) {
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $68 = $62 >>> 0 < $51 >>> 0;
    if ($68) {
      $p_188 = $62;
      label = 10;
      break;
    } else {
      $p_1_lcssa = $62;
      label = 17;
      break;
    }
   case 16:
    $70 = $p_188;
    $71 = $33 + $70 | 0;
    $_pn = $71;
    label = 18;
    break;
   case 17:
    _memmove($17 | 0, $p_1_lcssa | 0, 10);
    $72 = $offset_092 + 256 | 0;
    $73 = HEAP32[$18 >> 2] | 0;
    $74 = _FT_Stream_Pos($stream) | 0;
    $75 = $73 - $74 | 0;
    $76 = ($73 | 0) == ($74 | 0);
    if ($76) {
      $error_1 = 2;
      label = 30;
      break;
    } else {
      $offset_092 = $72;
      $read_len_094 = 256;
      $p_095 = $19;
      $41 = $75;
      label = 6;
      break;
    }
   case 18:
    $offset_1 = $_pn + $offset_092 | 0;
    $78 = $offset_1 - $8 | 0;
    $79 = _FT_Stream_Seek($stream, $8) | 0;
    $80 = ($79 | 0) == 0;
    if ($80) {
      label = 19;
      break;
    } else {
      $error_1 = $79;
      label = 30;
      break;
    }
   case 19:
    $82 = _FT_Stream_ExtractFrame($stream, $78, $22) | 0;
    $83 = ($82 | 0) == 0;
    if ($83) {
      label = 20;
      break;
    } else {
      $error_1 = $82;
      label = 30;
      break;
    }
   case 20:
    HEAP32[$23 >> 2] = $offset_1;
    HEAP32[$24 >> 2] = $78;
    $85 = HEAP32[$22 >> 2] | 0;
    HEAP32[$25 >> 2] = $85;
    $86 = HEAP32[$22 >> 2] | 0;
    HEAP32[$26 >> 2] = $86;
    $87 = $86 + $78 | 0;
    HEAP32[$27 >> 2] = $87;
    HEAP32[$28 >> 2] = -1;
    $88 = HEAP32[$26 >> 2] | 0;
    $89 = HEAP32[$29 >> 2] | 0;
    FUNCTION_TABLE_vi[$89 & 1023]($6);
    $90 = HEAP32[$30 >> 2] | 0;
    FUNCTION_TABLE_vi[$90 & 1023]($6);
    $91 = HEAP32[$26 >> 2] | 0;
    $92 = HEAP32[$29 >> 2] | 0;
    FUNCTION_TABLE_vi[$92 & 1023]($6);
    $93 = HEAP32[$30 >> 2] | 0;
    FUNCTION_TABLE_vi[$93 & 1023]($6);
    $94 = HEAP32[$27 >> 2] | 0;
    $cur_0105 = HEAP32[$26 >> 2] | 0;
    $95 = $cur_0105 >>> 0 < $94 >>> 0;
    if ($95) {
      $arg1_0106 = $88;
      $arg2_0107 = $91;
      $cur_0108 = $cur_0105;
      label = 21;
      break;
    } else {
      label = 29;
      break;
    }
   case 21:
    $96 = HEAP32[$31 >> 2] | 0;
    $97 = ($96 | 0) == 0;
    if ($97) {
      label = 22;
      break;
    } else {
      $error_1 = $96;
      label = 30;
      break;
    }
   case 22:
    $99 = HEAP8[$cur_0108] | 0;
    $100 = $99 << 24 >> 24 == 83;
    if ($100) {
      label = 23;
      break;
    } else {
      label = 26;
      break;
    }
   case 23:
    $102 = _strncmp($cur_0108 | 0, 5320856, 9) | 0;
    $103 = ($102 | 0) == 0;
    if ($103) {
      label = 24;
      break;
    } else {
      label = 26;
      break;
    }
   case 24:
    $105 = _strncmp($arg1_0106 | 0, 5320744, 5) | 0;
    $106 = ($105 | 0) == 0;
    if ($106) {
      label = 25;
      break;
    } else {
      $error_1 = $82;
      label = 30;
      break;
    }
   case 25:
    $108 = _atoi($arg2_0107 | 0) | 0;
    $109 = $parser + 88 | 0;
    HEAP32[$109 >> 2] = $108;
    $error_1 = $82;
    label = 30;
    break;
   case 26:
    $111 = $cur_0108 + 1 | 0;
    $112 = HEAP8[$111] | 0;
    $113 = $112 << 24 >> 24 == 115;
    if ($113) {
      label = 27;
      break;
    } else {
      label = 28;
      break;
    }
   case 27:
    $115 = _strncmp($cur_0108 | 0, 5320796, 6) | 0;
    $116 = ($115 | 0) == 0;
    if ($116) {
      $error_1 = 2;
      label = 30;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $118 = HEAP32[$29 >> 2] | 0;
    FUNCTION_TABLE_vi[$118 & 1023]($6);
    $119 = HEAP32[$30 >> 2] | 0;
    FUNCTION_TABLE_vi[$119 & 1023]($6);
    $cur_0 = HEAP32[$26 >> 2] | 0;
    $120 = $cur_0 >>> 0 < $94 >>> 0;
    if ($120) {
      $arg1_0106 = $arg2_0107;
      $arg2_0107 = $cur_0108;
      $cur_0108 = $cur_0;
      label = 21;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    _FT_Stream_ReleaseFrame($stream, $22);
    $121 = _FT_Stream_Seek($stream, $offset_1) | 0;
    $122 = ($121 | 0) == 0;
    if ($122) {
      label = 4;
      break;
    } else {
      $error_1 = $121;
      label = 30;
      break;
    }
   case 30:
    STACKTOP = __stackBase__;
    return $error_1 | 0;
  }
  return 0;
}
function _cid_parse_dict($face, $loader, $base, $size) {
  $face = $face | 0;
  $loader = $loader | 0;
  $base = $base | 0;
  $size = $size | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_sum60 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $cur_0 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $newlimit_0_ph = 0, $15 = 0, $cur_163 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $exitcond = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $or_cond = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $_off = 0, $48 = 0, $49 = 0, $51 = 0, $keyword_067 = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $n_0 = 0, $57 = 0, $_sum = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $74 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $loader | 0;
    $2 = $loader | 0;
    HEAP32[$2 >> 2] = $base;
    $3 = $base + $size | 0;
    $4 = $loader + 8 | 0;
    HEAP32[$4 >> 2] = $3;
    $5 = $loader + 12 | 0;
    HEAP32[$5 >> 2] = 0;
    $6 = $loader + 28 | 0;
    $_sum60 = $size - 18 | 0;
    $7 = $base + $_sum60 | 0;
    $8 = $loader + 32 | 0;
    $9 = $face + 300 | 0;
    $10 = $loader + 96 | 0;
    $cur_0 = $base;
    label = 2;
    break;
   case 2:
    HEAP32[$2 >> 2] = $cur_0;
    $11 = HEAP32[$6 >> 2] | 0;
    FUNCTION_TABLE_vi[$11 & 1023]($1);
    $12 = HEAP32[$2 >> 2] | 0;
    $13 = $12 >>> 0 < $3 >>> 0;
    $14 = $12 - 17 | 0;
    $newlimit_0_ph = $13 ? $14 : $7;
    $15 = $cur_0 >>> 0 < $newlimit_0_ph >>> 0;
    if ($15) {
      $cur_163 = $cur_0;
      label = 3;
      break;
    } else {
      label = 8;
      break;
    }
   case 3:
    $16 = HEAP8[$cur_163] | 0;
    $17 = $16 << 24 >> 24 == 37;
    if ($17) {
      label = 4;
      break;
    } else {
      label = 7;
      break;
    }
   case 4:
    $19 = _strncmp($cur_163 | 0, 5320580, 17) | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    $22 = HEAP32[$9 >> 2] | 0;
    $23 = ($22 | 0) > 0;
    if ($23) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $25 = HEAP32[$10 >> 2] | 0;
    $26 = $25 + 1 | 0;
    HEAP32[$10 >> 2] = $26;
    label = 7;
    break;
   case 7:
    $28 = $cur_163 + 1 | 0;
    $exitcond = ($28 | 0) == ($newlimit_0_ph | 0);
    if ($exitcond) {
      label = 8;
      break;
    } else {
      $cur_163 = $28;
      label = 3;
      break;
    }
   case 8:
    $29 = HEAP32[$2 >> 2] | 0;
    $30 = $29 >>> 0 < $3 >>> 0;
    if ($30) {
      label = 9;
      break;
    } else {
      label = 21;
      break;
    }
   case 9:
    $32 = HEAP32[$8 >> 2] | 0;
    FUNCTION_TABLE_vi[$32 & 1023]($1);
    $33 = HEAP32[$2 >> 2] | 0;
    $34 = $33 >>> 0 < $3 >>> 0;
    if ($34) {
      label = 10;
      break;
    } else {
      label = 21;
      break;
    }
   case 10:
    $36 = HEAP32[$5 >> 2] | 0;
    $37 = ($36 | 0) == 0;
    if ($37) {
      label = 11;
      break;
    } else {
      label = 21;
      break;
    }
   case 11:
    $39 = HEAP8[$29] | 0;
    $40 = $39 << 24 >> 24 == 47;
    $41 = $29 + 2 | 0;
    $42 = $41 >>> 0 < $3 >>> 0;
    $or_cond = $40 & $42;
    if ($or_cond) {
      label = 12;
      break;
    } else {
      label = 20;
      break;
    }
   case 12:
    $44 = $29 + 1 | 0;
    $45 = $33;
    $46 = $44;
    $47 = $45 - $46 | 0;
    $_off = $47 - 1 | 0;
    $48 = $_off >>> 0 < 21;
    if ($48) {
      label = 13;
      break;
    } else {
      label = 20;
      break;
    }
   case 13:
    $49 = HEAP8[$44] | 0;
    $keyword_067 = 5312160;
    $51 = 5320064;
    label = 14;
    break;
   case 14:
    $52 = HEAP8[$51] | 0;
    $53 = $49 << 24 >> 24 == $52 << 24 >> 24;
    if ($53) {
      label = 15;
      break;
    } else {
      label = 19;
      break;
    }
   case 15:
    $55 = _strlen($51 | 0) | 0;
    $56 = ($47 | 0) == ($55 | 0);
    if ($56) {
      $n_0 = 1;
      label = 16;
      break;
    } else {
      label = 19;
      break;
    }
   case 16:
    $57 = ($n_0 | 0) < ($47 | 0);
    if ($57) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    $_sum = $n_0 + 1 | 0;
    $59 = $29 + $_sum | 0;
    $60 = HEAP8[$59] | 0;
    $61 = $51 + $n_0 | 0;
    $62 = HEAP8[$61] | 0;
    $63 = $60 << 24 >> 24 == $62 << 24 >> 24;
    $64 = $n_0 + 1 | 0;
    if ($63) {
      $n_0 = $64;
      label = 16;
      break;
    } else {
      label = 19;
      break;
    }
   case 18:
    $66 = _cid_load_keyword($face, $loader, $keyword_067) | 0;
    HEAP32[$5 >> 2] = $66;
    $67 = ($66 | 0) == 0;
    if ($67) {
      label = 20;
      break;
    } else {
      $_0 = $66;
      label = 22;
      break;
    }
   case 19:
    $68 = $keyword_067 + 36 | 0;
    $69 = $68 | 0;
    $70 = HEAP32[$69 >> 2] | 0;
    $71 = ($70 | 0) == 0;
    if ($71) {
      label = 20;
      break;
    } else {
      $keyword_067 = $68;
      $51 = $70;
      label = 14;
      break;
    }
   case 20:
    $72 = HEAP32[$2 >> 2] | 0;
    $cur_0 = $72;
    label = 2;
    break;
   case 21:
    $74 = HEAP32[$5 >> 2] | 0;
    $_0 = $74;
    label = 22;
    break;
   case 22:
    return $_0 | 0;
  }
  return 0;
}
function _cid_hex_to_binary($data, $data_len, $offset, $face) {
  $data = $data | 0;
  $data_len = $data_len | 0;
  $offset = $offset | 0;
  $face = $face | 0;
  var $buffer = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p_0_ph56 = 0, $upper_nibble_0_ph55 = 0, $plimit_0_ph54 = 0, $d_0_ph53 = 0, $p_051 = 0, $plimit_050 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $_sum = 0, $24 = 0, $plimit_1 = 0, $p_1 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $_off = 0, $33 = 0, $35 = 0, $_off37 = 0, $37 = 0, $39 = 0, $42 = 0, $val_0 = 0, $done_1 = 0, $43 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $d_1 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 256 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $buffer = __stackBase__ | 0;
    $1 = $face + 104 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _FT_Stream_Seek($2, $offset) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 2;
      break;
    } else {
      $error_0 = $3;
      label = 22;
      break;
    }
   case 2:
    $6 = $data + $data_len | 0;
    $7 = $buffer | 0;
    $8 = ($data_len | 0) > 0;
    if ($8) {
      label = 3;
      break;
    } else {
      $error_0 = 0;
      label = 22;
      break;
    }
   case 3:
    $9 = $2 + 4 | 0;
    $d_0_ph53 = $data;
    $plimit_0_ph54 = $7;
    $upper_nibble_0_ph55 = 1;
    $p_0_ph56 = $7;
    label = 4;
    break;
   case 4:
    $plimit_050 = $plimit_0_ph54;
    $p_051 = $p_0_ph56;
    label = 5;
    break;
   case 5:
    $11 = $p_051 >>> 0 < $plimit_050 >>> 0;
    if ($11) {
      $p_1 = $p_051;
      $plimit_1 = $plimit_050;
      label = 9;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $13 = _FT_Stream_Pos($2) | 0;
    $14 = HEAP32[$9 >> 2] | 0;
    $15 = $14 - $13 | 0;
    $16 = ($14 | 0) == ($13 | 0);
    if ($16) {
      $error_0 = 160;
      label = 22;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $18 = $15 >>> 0 < 256;
    $19 = $18 ? $15 : 256;
    $20 = _FT_Stream_Read($2, $7, $19) | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 8;
      break;
    } else {
      $error_0 = $20;
      label = 22;
      break;
    }
   case 8:
    $23 = _FT_Stream_Pos($2) | 0;
    $_sum = $23 - $13 | 0;
    $24 = $buffer + $_sum | 0;
    $p_1 = $7;
    $plimit_1 = $24;
    label = 9;
    break;
   case 9:
    $26 = HEAP8[$p_1] | 0;
    $27 = $26 & 255;
    $28 = $27 - 48 | 0;
    $29 = $28 >>> 0 < 10;
    if ($29) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $31 = $26 - 48 & 255;
    $done_1 = 0;
    $val_0 = $31;
    label = 17;
    break;
   case 11:
    $_off = $26 - 97 & 255;
    $33 = ($_off & 255) < 6;
    if ($33) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $35 = $26 - 97 & 255;
    $done_1 = 0;
    $val_0 = $35;
    label = 17;
    break;
   case 13:
    $_off37 = $26 - 65 & 255;
    $37 = ($_off37 & 255) < 6;
    if ($37) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $39 = $26 - 55 & 255;
    $done_1 = 0;
    $val_0 = $39;
    label = 17;
    break;
   case 15:
    if (($26 << 24 >> 24 | 0) == 32 | ($26 << 24 >> 24 | 0) == 9 | ($26 << 24 >> 24 | 0) == 13 | ($26 << 24 >> 24 | 0) == 10 | ($26 << 24 >> 24 | 0) == 12 | ($26 << 24 >> 24 | 0) == 0) {
      label = 16;
      break;
    } else if (($26 << 24 >> 24 | 0) == 62) {
      $done_1 = 1;
      $val_0 = 0;
      label = 17;
      break;
    } else {
      $error_0 = 160;
      label = 22;
      break;
    }
   case 16:
    $42 = $p_1 + 1 | 0;
    $plimit_050 = $plimit_1;
    $p_051 = $42;
    label = 5;
    break;
   case 17:
    $43 = $upper_nibble_0_ph55 << 24 >> 24 == 0;
    if ($43) {
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $45 = $val_0 << 4;
    HEAP8[$d_0_ph53] = $45;
    $d_1 = $d_0_ph53;
    label = 20;
    break;
   case 19:
    $47 = HEAP8[$d_0_ph53] | 0;
    $48 = $47 + $val_0 & 255;
    HEAP8[$d_0_ph53] = $48;
    $49 = $d_0_ph53 + 1 | 0;
    $d_1 = $49;
    label = 20;
    break;
   case 20:
    $51 = $done_1 << 24 >> 24 == 0;
    if ($51) {
      label = 21;
      break;
    } else {
      $error_0 = 0;
      label = 22;
      break;
    }
   case 21:
    $52 = 1 - $upper_nibble_0_ph55 & 255;
    $53 = $p_1 + 1 | 0;
    $54 = $d_1 >>> 0 < $6 >>> 0;
    if ($54) {
      $d_0_ph53 = $d_1;
      $plimit_0_ph54 = $plimit_1;
      $upper_nibble_0_ph55 = $52;
      $p_0_ph56 = $53;
      label = 4;
      break;
    } else {
      $error_0 = 0;
      label = 22;
      break;
    }
   case 22:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _T42_Driver_Done($driver) {
  $driver = $driver | 0;
  return;
}
function _cid_get_is_cid($face, $is_cid) {
  $face = $face | 0;
  $is_cid = $is_cid | 0;
  var $1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($is_cid | 0) == 0;
    if ($1) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    HEAP8[$is_cid] = 1;
    label = 3;
    break;
   case 3:
    return 0;
  }
  return 0;
}
function _cid_get_cid_from_glyph_index($face, $glyph_index, $cid) {
  $face = $face | 0;
  $glyph_index = $glyph_index | 0;
  $cid = $cid | 0;
  var $1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($cid | 0) == 0;
    if ($1) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    HEAP32[$cid >> 2] = $glyph_index;
    label = 3;
    break;
   case 3:
    return 0;
  }
  return 0;
}
function _cid_get_ros($face, $registry, $ordering, $supplement) {
  $face = $face | 0;
  $registry = $registry | 0;
  $ordering = $ordering | 0;
  $supplement = $supplement | 0;
  var $1 = 0, $3 = 0, $4 = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $13 = 0, $14 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($registry | 0) == 0;
    if ($1) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 152 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    HEAP32[$registry >> 2] = $4;
    label = 3;
    break;
   case 3:
    $6 = ($ordering | 0) == 0;
    if ($6) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $8 = $face + 156 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    HEAP32[$ordering >> 2] = $9;
    label = 5;
    break;
   case 5:
    $11 = ($supplement | 0) == 0;
    if ($11) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $13 = $face + 160 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    HEAP32[$supplement >> 2] = $14;
    label = 7;
    break;
   case 7:
    return 0;
  }
  return 0;
}
function _cid_ps_get_font_extra($face, $afont_extra) {
  $face = $face | 0;
  $afont_extra = $afont_extra | 0;
  HEAP16[$afont_extra >> 1] = HEAP16[$face + 312 >> 1] | 0;
  return 0;
}
function _cid_get_postscript_name($face) {
  $face = $face | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $_ = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 140 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = HEAP8[$2] | 0;
    $6 = $5 << 24 >> 24 == 47;
    $7 = $2 + 1 | 0;
    $_ = $6 ? $7 : $2;
    return $_ | 0;
   case 3:
    return $2 | 0;
  }
  return 0;
}
function _cid_read_subrs($face) {
  $face = $face | 0;
  var $error = 0, $p = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $n_099 = 0, $subr_098 = 0, $max_offsets_097 = 0, $offsets_096 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $offsets_1 = 0, $max_offsets_1 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $count_085 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $count_187 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $or_cond = 0, $count_291 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $exitcond = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $offsets_2 = 0, $116 = 0, $117 = 0, $offsets_3 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $n_184 = 0, $125 = 0, $126 = 0, $127 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $_lcssa = 0, $144 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $p = __stackBase__ + 4 | 0;
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 328 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $face + 136 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $face + 300 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = _ft_mem_realloc($2, 8, 0, $8, 0, $error) | 0;
    $10 = $9;
    $11 = $face + 316 | 0;
    HEAP32[$11 >> 2] = $10;
    $12 = HEAP32[$error >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 2;
      break;
    } else {
      $offsets_2 = 0;
      label = 19;
      break;
    }
   case 2:
    $14 = HEAP32[$7 >> 2] | 0;
    $15 = ($14 | 0) > 0;
    if ($15) {
      label = 3;
      break;
    } else {
      $offsets_2 = 0;
      label = 19;
      break;
    }
   case 3:
    $16 = $face + 304 | 0;
    $17 = $face + 308 | 0;
    $18 = $4 + 32 | 0;
    $19 = $6 + 16 | 0;
    $20 = $19;
    $offsets_096 = 0;
    $max_offsets_097 = 0;
    $subr_098 = $10;
    $n_099 = 0;
    label = 4;
    break;
   case 4:
    $22 = HEAP32[$16 >> 2] | 0;
    $23 = $22 + ($n_099 * 252 & -1) + 4 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $22 + ($n_099 * 252 & -1) + 240 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $26 + 1 | 0;
    $28 = $27 >>> 0 > $max_offsets_097 >>> 0;
    if ($28) {
      label = 5;
      break;
    } else {
      $max_offsets_1 = $max_offsets_097;
      $offsets_1 = $offsets_096;
      label = 6;
      break;
    }
   case 5:
    $30 = $26 + 4 | 0;
    $31 = $30 & -4;
    $32 = $offsets_096;
    $33 = _ft_mem_realloc($2, 4, $max_offsets_097, $31, $32, $error) | 0;
    $34 = $33;
    $35 = HEAP32[$error >> 2] | 0;
    $36 = ($35 | 0) == 0;
    if ($36) {
      $max_offsets_1 = $31;
      $offsets_1 = $34;
      label = 6;
      break;
    } else {
      $offsets_3 = $34;
      label = 20;
      break;
    }
   case 6:
    $38 = HEAP32[$17 >> 2] | 0;
    $39 = $22 + ($n_099 * 252 & -1) + 244 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $40 + $38 | 0;
    $42 = _FT_Stream_Seek($4, $41) | 0;
    HEAP32[$error >> 2] = $42;
    $43 = ($42 | 0) == 0;
    if ($43) {
      label = 7;
      break;
    } else {
      $offsets_3 = $offsets_1;
      label = 20;
      break;
    }
   case 7:
    $45 = $22 + ($n_099 * 252 & -1) + 248 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = Math_imul($46, $27);
    $48 = _FT_Stream_EnterFrame($4, $47) | 0;
    HEAP32[$error >> 2] = $48;
    $49 = ($48 | 0) == 0;
    if ($49) {
      label = 8;
      break;
    } else {
      $offsets_3 = $offsets_1;
      label = 20;
      break;
    }
   case 8:
    $51 = HEAP32[$18 >> 2] | 0;
    HEAP32[$p >> 2] = $51;
    $count_085 = 0;
    label = 9;
    break;
   case 9:
    $53 = HEAP32[$45 >> 2] | 0;
    $54 = $53 & 255;
    $55 = _cid_get_offset($p, $54) | 0;
    $56 = $offsets_1 + ($count_085 << 2) | 0;
    HEAP32[$56 >> 2] = $55;
    $57 = $count_085 + 1 | 0;
    $58 = $57 >>> 0 > $26 >>> 0;
    if ($58) {
      label = 10;
      break;
    } else {
      $count_085 = $57;
      label = 9;
      break;
    }
   case 10:
    _FT_Stream_ExitFrame($4);
    $60 = $offsets_1 + ($26 << 2) | 0;
    $61 = HEAP32[$60 >> 2] | 0;
    $62 = HEAP32[$offsets_1 >> 2] | 0;
    $63 = $61 - $62 | 0;
    $64 = _ft_mem_realloc($2, 4, 0, $27, 0, $error) | 0;
    $65 = $64;
    $66 = $subr_098 + 4 | 0;
    HEAP32[$66 >> 2] = $65;
    $67 = HEAP32[$error >> 2] | 0;
    $68 = ($67 | 0) == 0;
    if ($68) {
      label = 11;
      break;
    } else {
      $offsets_3 = $offsets_1;
      label = 20;
      break;
    }
   case 11:
    $70 = _ft_mem_alloc($2, $63, $error) | 0;
    $71 = HEAP32[$66 >> 2] | 0;
    HEAP32[$71 >> 2] = $70;
    $72 = HEAP32[$error >> 2] | 0;
    $73 = ($72 | 0) == 0;
    if ($73) {
      label = 12;
      break;
    } else {
      $offsets_3 = $offsets_1;
      label = 20;
      break;
    }
   case 12:
    $75 = HEAP32[$17 >> 2] | 0;
    $76 = HEAP32[$offsets_1 >> 2] | 0;
    $77 = $76 + $75 | 0;
    $78 = _FT_Stream_Seek($4, $77) | 0;
    HEAP32[$error >> 2] = $78;
    $79 = ($78 | 0) == 0;
    if ($79) {
      label = 13;
      break;
    } else {
      $offsets_3 = $offsets_1;
      label = 20;
      break;
    }
   case 13:
    $81 = HEAP32[$66 >> 2] | 0;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = _FT_Stream_Read($4, $82, $63) | 0;
    HEAP32[$error >> 2] = $83;
    $84 = ($83 | 0) == 0;
    if ($84) {
      label = 14;
      break;
    } else {
      $offsets_3 = $offsets_1;
      label = 20;
      break;
    }
   case 14:
    $85 = ($26 | 0) == 0;
    if ($85) {
      label = 16;
      break;
    } else {
      $count_187 = 1;
      label = 15;
      break;
    }
   case 15:
    $86 = $offsets_1 + ($count_187 << 2) | 0;
    $87 = HEAP32[$86 >> 2] | 0;
    $88 = $count_187 - 1 | 0;
    $89 = $offsets_1 + ($88 << 2) | 0;
    $90 = HEAP32[$89 >> 2] | 0;
    $91 = $87 - $90 | 0;
    $92 = HEAP32[$66 >> 2] | 0;
    $93 = $92 + ($88 << 2) | 0;
    $94 = HEAP32[$93 >> 2] | 0;
    $95 = $94 + $91 | 0;
    $96 = $92 + ($count_187 << 2) | 0;
    HEAP32[$96 >> 2] = $95;
    $97 = $count_187 + 1 | 0;
    $98 = $97 >>> 0 > $26 >>> 0;
    if ($98) {
      label = 16;
      break;
    } else {
      $count_187 = $97;
      label = 15;
      break;
    }
   case 16:
    $99 = ($24 | 0) < 0;
    $100 = ($26 | 0) == 0;
    $or_cond = $99 | $100;
    if ($or_cond) {
      label = 18;
      break;
    } else {
      $count_291 = 0;
      label = 17;
      break;
    }
   case 17:
    $101 = $count_291 + 1 | 0;
    $102 = $offsets_1 + ($101 << 2) | 0;
    $103 = HEAP32[$102 >> 2] | 0;
    $104 = $offsets_1 + ($count_291 << 2) | 0;
    $105 = HEAP32[$104 >> 2] | 0;
    $106 = $103 - $105 | 0;
    $107 = HEAP32[$20 >> 2] | 0;
    $108 = HEAP32[$66 >> 2] | 0;
    $109 = $108 + ($count_291 << 2) | 0;
    $110 = HEAP32[$109 >> 2] | 0;
    FUNCTION_TABLE_viii[$107 & 1023]($110, $106, 4330);
    $exitcond = ($101 | 0) == ($26 | 0);
    if ($exitcond) {
      label = 18;
      break;
    } else {
      $count_291 = $101;
      label = 17;
      break;
    }
   case 18:
    $111 = $subr_098 | 0;
    HEAP32[$111 >> 2] = $26;
    $112 = $n_099 + 1 | 0;
    $113 = $subr_098 + 8 | 0;
    $114 = HEAP32[$7 >> 2] | 0;
    $115 = ($112 | 0) < ($114 | 0);
    if ($115) {
      $offsets_096 = $offsets_1;
      $max_offsets_097 = $max_offsets_1;
      $subr_098 = $113;
      $n_099 = $112;
      label = 4;
      break;
    } else {
      $offsets_2 = $offsets_1;
      label = 19;
      break;
    }
   case 19:
    $116 = $offsets_2;
    _ft_mem_free($2, $116);
    $117 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $117 | 0;
   case 20:
    $119 = HEAP32[$11 >> 2] | 0;
    $120 = ($119 | 0) == 0;
    if ($120) {
      $offsets_2 = $offsets_3;
      label = 19;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $121 = HEAP32[$7 >> 2] | 0;
    $122 = ($121 | 0) > 0;
    $123 = HEAP32[$11 >> 2] | 0;
    if ($122) {
      $n_184 = 0;
      $124 = $123;
      label = 22;
      break;
    } else {
      $_lcssa = $123;
      label = 25;
      break;
    }
   case 22:
    $125 = $124 + ($n_184 << 3) + 4 | 0;
    $126 = HEAP32[$125 >> 2] | 0;
    $127 = ($126 | 0) == 0;
    if ($127) {
      label = 24;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $129 = HEAP32[$126 >> 2] | 0;
    _ft_mem_free($2, $129);
    $130 = HEAP32[$11 >> 2] | 0;
    $131 = $130 + ($n_184 << 3) + 4 | 0;
    $132 = HEAP32[$131 >> 2] | 0;
    HEAP32[$132 >> 2] = 0;
    label = 24;
    break;
   case 24:
    $134 = HEAP32[$11 >> 2] | 0;
    $135 = $134 + ($n_184 << 3) + 4 | 0;
    $136 = HEAP32[$135 >> 2] | 0;
    $137 = $136;
    _ft_mem_free($2, $137);
    $138 = HEAP32[$11 >> 2] | 0;
    $139 = $138 + ($n_184 << 3) + 4 | 0;
    HEAP32[$139 >> 2] = 0;
    $140 = $n_184 + 1 | 0;
    $141 = HEAP32[$7 >> 2] | 0;
    $142 = ($140 | 0) < ($141 | 0);
    $143 = HEAP32[$11 >> 2] | 0;
    if ($142) {
      $n_184 = $140;
      $124 = $143;
      label = 22;
      break;
    } else {
      $_lcssa = $143;
      label = 25;
      break;
    }
   case 25:
    $144 = $_lcssa;
    _ft_mem_free($2, $144);
    HEAP32[$11 >> 2] = 0;
    $offsets_2 = $offsets_3;
    label = 19;
    break;
  }
  return 0;
}
function _t1_done_loader282($loader) {
  $loader = $loader | 0;
  _cid_parser_done($loader | 0);
  return;
}
function _cid_parser_done($parser) {
  $parser = $parser | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $parser + 76 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $parser + 72 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    _FT_Stream_ReleaseFrame($6, $1);
    label = 3;
    break;
   case 3:
    $8 = $parser | 0;
    $9 = $parser + 24 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    FUNCTION_TABLE_vi[$10 & 1023]($8);
    return;
  }
}
function _cid_load_keyword($face, $loader, $keyword) {
  $face = $face | 0;
  $loader = $loader | 0;
  $keyword = $keyword | 0;
  var $dummy_object = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $16 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $object_0 = 0, $36 = 0, $_off = 0, $switch = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $dummy_object = __stackBase__ | 0;
    $1 = $face + 140 | 0;
    $2 = $keyword + 8 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = ($3 | 0) == 10;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $6 = $keyword + 12 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $face | 0;
    $9 = $loader;
    FUNCTION_TABLE_vii[$7 & 1023]($8, $9);
    $10 = $loader + 12 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $error_0 = $11;
    label = 13;
    break;
   case 3:
    $13 = $keyword + 4 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    if (($14 | 0) == 0) {
      label = 4;
      break;
    } else if (($14 | 0) == 3) {
      label = 5;
      break;
    } else if (($14 | 0) == 2) {
      label = 6;
      break;
    } else if (($14 | 0) == 5) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 4:
    $16 = $1;
    $object_0 = $16;
    label = 10;
    break;
   case 5:
    $18 = $face + 164 | 0;
    $19 = $18;
    $object_0 = $19;
    label = 10;
    break;
   case 6:
    $21 = $face + 312 | 0;
    $22 = $21;
    $object_0 = $22;
    label = 10;
    break;
   case 7:
    $24 = $face + 196 | 0;
    $25 = $24;
    $object_0 = $25;
    label = 10;
    break;
   case 8:
    $27 = $loader + 96 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = ($28 | 0) < 0;
    if ($29) {
      $error_0 = 160;
      label = 13;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $31 = $face + 304 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $32 + ($28 * 252 & -1) | 0;
    $34 = $33;
    $object_0 = $34;
    label = 10;
    break;
   case 10:
    HEAP32[$dummy_object >> 2] = $object_0;
    $36 = HEAP32[$2 >> 2] | 0;
    $_off = $36 - 8 | 0;
    $switch = $_off >>> 0 < 2;
    $37 = $loader | 0;
    if ($switch) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $39 = $loader + 68 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = FUNCTION_TABLE_iiiiii[$40 & 1023]($37, $keyword, $dummy_object, 0, 0) | 0;
    $error_0 = $41;
    label = 13;
    break;
   case 12:
    $43 = $loader + 64 | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    $45 = FUNCTION_TABLE_iiiiii[$44 & 1023]($37, $keyword, $dummy_object, 0, 0) | 0;
    $error_0 = $45;
    label = 13;
    break;
   case 13:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _parse_fd_array($face, $parser) {
  $face = $face | 0;
  $parser = $parser | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $n_011 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $3 = $parser | 0;
    $4 = $parser + 36 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = FUNCTION_TABLE_ii[$5 & 1023]($3) | 0;
    $7 = $face + 304 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 2:
    $11 = _ft_mem_realloc($2, 252, 0, $6, 0, $error) | 0;
    $12 = $11;
    HEAP32[$7 >> 2] = $12;
    $13 = HEAP32[$error >> 2] | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $16 = $face + 300 | 0;
    HEAP32[$16 >> 2] = $6;
    $17 = ($6 | 0) > 0;
    if ($17) {
      $n_011 = 0;
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $18 = HEAP32[$7 >> 2] | 0;
    $19 = $18 + ($n_011 * 252 & -1) + 4 | 0;
    HEAP32[$19 >> 2] = 4;
    $20 = $n_011 + 1 | 0;
    $21 = HEAP32[$16 >> 2] | 0;
    $22 = ($20 | 0) < ($21 | 0);
    if ($22) {
      $n_011 = $20;
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $23 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $23 | 0;
  }
  return 0;
}
function _parse_font_matrix283($face, $parser) {
  $face = $face | 0;
  $parser = $parser | 0;
  var $temp = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 24 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $temp = __stackBase__ | 0;
    $1 = $parser + 96 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) > -1;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 2:
    $5 = $face + 304 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $parser | 0;
    $8 = $parser + 52 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $temp | 0;
    $11 = FUNCTION_TABLE_iiiii[$9 & 1023]($7, 6, $10, 3) | 0;
    $12 = $temp + 12 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = ($13 | 0) < 0;
    $15 = -$13 | 0;
    $16 = $14 ? $15 : $13;
    $17 = _FT_DivFix($16, 1e3) | 0;
    $18 = _FT_DivFix(65536, $17) | 0;
    $19 = $18 & 65535;
    $20 = $face + 68 | 0;
    HEAP16[$20 >> 1] = $19;
    $21 = ($16 | 0) == 65536;
    if ($21) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $23 = HEAP32[$10 >> 2] | 0;
    $24 = _FT_DivFix($23, $16) | 0;
    HEAP32[$10 >> 2] = $24;
    $25 = $temp + 4 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = _FT_DivFix($26, $16) | 0;
    HEAP32[$25 >> 2] = $27;
    $28 = $temp + 8 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = _FT_DivFix($29, $16) | 0;
    HEAP32[$28 >> 2] = $30;
    $31 = $temp + 16 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = _FT_DivFix($32, $16) | 0;
    HEAP32[$31 >> 2] = $33;
    $34 = $temp + 20 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = _FT_DivFix($35, $16) | 0;
    HEAP32[$34 >> 2] = $36;
    HEAP32[$12 >> 2] = 65536;
    label = 4;
    break;
   case 4:
    $38 = HEAP32[$10 >> 2] | 0;
    $39 = $6 + ($2 * 252 & -1) + 216 | 0;
    HEAP32[$39 >> 2] = $38;
    $40 = $temp + 4 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = $6 + ($2 * 252 & -1) + 224 | 0;
    HEAP32[$42 >> 2] = $41;
    $43 = $temp + 8 | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    $45 = $6 + ($2 * 252 & -1) + 220 | 0;
    HEAP32[$45 >> 2] = $44;
    $46 = HEAP32[$12 >> 2] | 0;
    $47 = $6 + ($2 * 252 & -1) + 228 | 0;
    HEAP32[$47 >> 2] = $46;
    $48 = $temp + 16 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = $49 >> 16;
    $51 = $6 + ($2 * 252 & -1) + 232 | 0;
    HEAP32[$51 >> 2] = $50;
    $52 = $temp + 20 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $53 >> 16;
    $55 = $6 + ($2 * 252 & -1) + 236 | 0;
    HEAP32[$55 >> 2] = $54;
    label = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return 0;
  }
  return 0;
}
function _parse_expansion_factor($face, $parser) {
  $face = $face | 0;
  $parser = $parser | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $parser + 96 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) > -1;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $5 = $face + 304 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $parser | 0;
    $8 = $parser + 40 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = FUNCTION_TABLE_iii[$9 & 1023]($7, 0) | 0;
    $11 = $6 + ($2 * 252 & -1) + 208 | 0;
    HEAP32[$11 >> 2] = $10;
    $12 = $6 + ($2 * 252 & -1) + 180 | 0;
    HEAP32[$12 >> 2] = $10;
    label = 3;
    break;
   case 3:
    return 0;
  }
  return 0;
}
function _cid_ps_get_font_info($face, $afont_info) {
  $face = $face | 0;
  $afont_info = $afont_info | 0;
  _memcpy($afont_info | 0, ($face + 140 | 0) + 24 | 0, 32);
  return 0;
}
function _T42_Driver_Init($driver) {
  $driver = $driver | 0;
  HEAP32[$driver + 40 >> 2] = HEAP32[_FT_Get_Module(HEAP32[$driver + 4 >> 2] | 0, 5322292) >> 2] | 0;
  return 0;
}
function _T42_Get_Interface($driver, $t42_interface) {
  $driver = $driver | 0;
  $t42_interface = $t42_interface | 0;
  return _ft_service_list_lookup(5245136, $t42_interface) | 0;
}
function _T42_Face_Init($stream, $face, $face_index, $num_params, $params) {
  $stream = $stream | 0;
  $face = $face | 0;
  $face_index = $face_index | 0;
  $num_params = $num_params | 0;
  $params = $params | 0;
  var $args = 0, $charmap = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $or_cond93 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $family_0_ph103 = 0, $full_0_ph102 = 0, $48 = 0, $family_098 = 0, $49 = 0, $50 = 0, $52 = 0, $family_0_ph_be = 0, $full_0_ph_be = 0, $53 = 0, $54 = 0, $58 = 0, $59 = 0, $60 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $144 = 0, $145 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $153 = 0, $154 = 0, $156 = 0, $157 = 0, $or_cond94 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $172 = 0, $173 = 0, $175 = 0, $177 = 0, $179 = 0, $clazz_0_in = 0, $clazz_0 = 0, $182 = 0, $184 = 0, $185 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 44 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $args = __stackBase__ | 0;
    $charmap = __stackBase__ + 32 | 0;
    $1 = $face | 0;
    $2 = $face + 500 | 0;
    HEAP32[$2 >> 2] = 0;
    $3 = $face | 0;
    HEAP32[$3 >> 2] = 1;
    $4 = $face + 96 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5;
    $7 = _ft_module_get_service($6, 5324324) | 0;
    $8 = $face + 484 | 0;
    HEAP32[$8 >> 2] = $7;
    $9 = HEAP32[$4 >> 2] | 0;
    $10 = $9 + 4 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11;
    $13 = _FT_Get_Module_Interface($12, 5323356) | 0;
    $14 = $face + 488 | 0;
    HEAP32[$14 >> 2] = $13;
    $15 = _T42_Open_Face($face) | 0;
    $16 = ($15 | 0) != 0;
    $17 = ($face_index | 0) < 0;
    $or_cond93 = $16 | $17;
    if ($or_cond93) {
      $error_0 = $15;
      label = 36;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $19 = ($face_index | 0) > 0;
    if ($19) {
      $error_0 = 6;
      label = 36;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $21 = $face + 416 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $face + 16 | 0;
    HEAP32[$23 >> 2] = $22;
    $24 = $face + 36 | 0;
    HEAP32[$24 >> 2] = 0;
    $25 = $face + 4 | 0;
    HEAP32[$25 >> 2] = 0;
    $26 = $face + 8 | 0;
    HEAP32[$26 >> 2] = 529;
    $27 = $face + 156 | 0;
    $28 = HEAP8[$27] | 0;
    $29 = $28 << 24 >> 24 == 0;
    if ($29) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    HEAP32[$26 >> 2] = 533;
    label = 5;
    break;
   case 5:
    $32 = HEAP32[$26 >> 2] | 0;
    $33 = $32 | 2048;
    HEAP32[$26 >> 2] = $33;
    $34 = $face + 144 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $face + 20 | 0;
    HEAP32[$36 >> 2] = $35;
    $37 = $face + 24 | 0;
    HEAP32[$37 >> 2] = 5322532;
    $38 = HEAP32[$36 >> 2] | 0;
    $39 = ($38 | 0) == 0;
    if ($39) {
      label = 16;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $41 = $face + 140 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = ($42 | 0) == 0;
    if ($43) {
      label = 18;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $44 = HEAP8[$42] | 0;
    $45 = $44 << 24 >> 24 == 0;
    if ($45) {
      label = 18;
      break;
    } else {
      $full_0_ph102 = $42;
      $family_0_ph103 = $38;
      $46 = $44;
      label = 8;
      break;
    }
   case 8:
    $family_098 = $family_0_ph103;
    $48 = $46;
    label = 9;
    break;
   case 9:
    $49 = HEAP8[$family_098] | 0;
    $50 = $48 << 24 >> 24 == $49 << 24 >> 24;
    if ($50) {
      label = 10;
      break;
    } else {
      label = 12;
      break;
    }
   case 10:
    $52 = $family_098 + 1 | 0;
    $family_0_ph_be = $52;
    label = 11;
    break;
   case 11:
    $full_0_ph_be = $full_0_ph102 + 1 | 0;
    $53 = HEAP8[$full_0_ph_be] | 0;
    $54 = $53 << 24 >> 24 == 0;
    if ($54) {
      label = 18;
      break;
    } else {
      $full_0_ph102 = $full_0_ph_be;
      $family_0_ph103 = $family_0_ph_be;
      $46 = $53;
      label = 8;
      break;
    }
   case 12:
    if (($48 << 24 >> 24 | 0) == 32 | ($48 << 24 >> 24 | 0) == 45) {
      $family_0_ph_be = $family_098;
      label = 11;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    if (($49 << 24 >> 24 | 0) == 32 | ($49 << 24 >> 24 | 0) == 45) {
      label = 14;
      break;
    } else if (($49 << 24 >> 24 | 0) == 0) {
      label = 15;
      break;
    } else {
      label = 18;
      break;
    }
   case 14:
    $58 = $family_098 + 1 | 0;
    $59 = HEAP8[$full_0_ph102] | 0;
    $60 = $59 << 24 >> 24 == 0;
    if ($60) {
      label = 18;
      break;
    } else {
      $family_098 = $58;
      $48 = $59;
      label = 9;
      break;
    }
   case 15:
    HEAP32[$37 >> 2] = $full_0_ph102;
    label = 18;
    break;
   case 16:
    $63 = $face + 364 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = ($64 | 0) == 0;
    if ($65) {
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    HEAP32[$36 >> 2] = $64;
    label = 18;
    break;
   case 18:
    $67 = $face + 28 | 0;
    HEAP32[$67 >> 2] = 0;
    $68 = $face + 32 | 0;
    HEAP32[$68 >> 2] = 0;
    $69 = $args | 0;
    HEAP32[$69 >> 2] = 1;
    $70 = $face + 492 | 0;
    $71 = HEAP32[$70 >> 2] | 0;
    $72 = $args + 4 | 0;
    HEAP32[$72 >> 2] = $71;
    $73 = $face + 496 | 0;
    $74 = HEAP32[$73 >> 2] | 0;
    $75 = $args + 8 | 0;
    HEAP32[$75 >> 2] = $74;
    $76 = ($num_params | 0) == 0;
    if ($76) {
      label = 20;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $78 = HEAP32[$69 >> 2] | 0;
    $79 = $78 | 16;
    HEAP32[$69 >> 2] = $79;
    $80 = $args + 24 | 0;
    HEAP32[$80 >> 2] = $num_params;
    $81 = $args + 28 | 0;
    HEAP32[$81 >> 2] = $params;
    label = 20;
    break;
   case 20:
    $83 = HEAP32[$4 >> 2] | 0;
    $84 = $83 + 4 | 0;
    $85 = HEAP32[$84 >> 2] | 0;
    $86 = $85;
    $87 = $args;
    $88 = $2;
    $89 = _FT_Open_Face($86, $87, 0, $88) | 0;
    $90 = ($89 | 0) == 0;
    if ($90) {
      label = 21;
      break;
    } else {
      $error_0 = $89;
      label = 36;
      break;
    }
   case 21:
    $92 = HEAP32[$2 >> 2] | 0;
    $93 = $92 + 88 | 0;
    $94 = HEAP32[$93 >> 2] | 0;
    $95 = $94;
    $96 = _FT_Done_Size($95) | 0;
    $97 = $face + 52 | 0;
    $98 = HEAP32[$2 >> 2] | 0;
    $99 = $98 + 52 | 0;
    $100 = $97;
    $101 = $99;
    _memcpy($100 | 0, $101 | 0, 16);
    $102 = HEAP32[$2 >> 2] | 0;
    $103 = $102 + 68 | 0;
    $104 = HEAP16[$103 >> 1] | 0;
    $105 = $face + 68 | 0;
    HEAP16[$105 >> 1] = $104;
    $106 = HEAP32[$2 >> 2] | 0;
    $107 = $106 + 70 | 0;
    $108 = HEAP16[$107 >> 1] | 0;
    $109 = $face + 70 | 0;
    HEAP16[$109 >> 1] = $108;
    $110 = HEAP32[$2 >> 2] | 0;
    $111 = $110 + 72 | 0;
    $112 = HEAP16[$111 >> 1] | 0;
    $113 = $face + 72 | 0;
    HEAP16[$113 >> 1] = $112;
    $114 = HEAP32[$2 >> 2] | 0;
    $115 = $114 + 74 | 0;
    $116 = HEAP16[$115 >> 1] | 0;
    $117 = $face + 74 | 0;
    HEAP16[$117 >> 1] = $116;
    $118 = HEAP32[$2 >> 2] | 0;
    $119 = $118 + 76 | 0;
    $120 = HEAP16[$119 >> 1] | 0;
    $121 = $face + 76 | 0;
    HEAP16[$121 >> 1] = $120;
    $122 = HEAP32[$2 >> 2] | 0;
    $123 = $122 + 78 | 0;
    $124 = HEAP16[$123 >> 1] | 0;
    $125 = $face + 78 | 0;
    HEAP16[$125 >> 1] = $124;
    $126 = $face + 158 | 0;
    $127 = HEAP16[$126 >> 1] | 0;
    $128 = $face + 80 | 0;
    HEAP16[$128 >> 1] = $127;
    $129 = $face + 160 | 0;
    $130 = HEAP16[$129 >> 1] | 0;
    $131 = $face + 82 | 0;
    HEAP16[$131 >> 1] = $130;
    $132 = $face + 12 | 0;
    HEAP32[$132 >> 2] = 0;
    $133 = $face + 152 | 0;
    $134 = HEAP32[$133 >> 2] | 0;
    $135 = ($134 | 0) == 0;
    if ($135) {
      label = 23;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    HEAP32[$132 >> 2] = 1;
    label = 23;
    break;
   case 23:
    $138 = HEAP32[$2 >> 2] | 0;
    $139 = $138 + 12 | 0;
    $140 = HEAP32[$139 >> 2] | 0;
    $141 = $140 & 2;
    $142 = ($141 | 0) == 0;
    if ($142) {
      label = 25;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $144 = HEAP32[$132 >> 2] | 0;
    $145 = $144 | 2;
    HEAP32[$132 >> 2] = $145;
    label = 25;
    break;
   case 25:
    $147 = HEAP32[$2 >> 2] | 0;
    $148 = $147 + 8 | 0;
    $149 = HEAP32[$148 >> 2] | 0;
    $150 = $149 & 32;
    $151 = ($150 | 0) == 0;
    if ($151) {
      label = 27;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $153 = HEAP32[$26 >> 2] | 0;
    $154 = $153 | 32;
    HEAP32[$26 >> 2] = $154;
    label = 27;
    break;
   case 27:
    $156 = ($7 | 0) == 0;
    $157 = ($13 | 0) == 0;
    $or_cond94 = $156 | $157;
    if ($or_cond94) {
      $error_0 = $89;
      label = 36;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $159 = $13 + 20 | 0;
    $160 = $159;
    $161 = HEAP32[$160 >> 2] | 0;
    $162 = $charmap | 0;
    HEAP32[$162 >> 2] = $1;
    $163 = $charmap + 8 | 0;
    HEAP16[$163 >> 1] = 3;
    $164 = $charmap + 10 | 0;
    HEAP16[$164 >> 1] = 1;
    $165 = $charmap + 4 | 0;
    HEAP32[$165 >> 2] = 1970170211;
    $166 = $161 + 12 | 0;
    $167 = HEAP32[$166 >> 2] | 0;
    $168 = $167;
    $169 = $charmap;
    $170 = _FT_CMap_New($168, 0, $169, 0) | 0;
    if (($170 | 0) == 163 | ($170 | 0) == 0) {
      label = 29;
      break;
    } else {
      $error_0 = $170;
      label = 36;
      break;
    }
   case 29:
    HEAP16[$163 >> 1] = 7;
    $172 = $face + 368 | 0;
    $173 = HEAP32[$172 >> 2] | 0;
    if (($173 | 0) == 2) {
      label = 30;
      break;
    } else if (($173 | 0) == 4) {
      label = 31;
      break;
    } else if (($173 | 0) == 1) {
      label = 32;
      break;
    } else if (($173 | 0) == 3) {
      label = 33;
      break;
    } else {
      $error_0 = 0;
      label = 36;
      break;
    }
   case 30:
    HEAP32[$165 >> 2] = 1094995778;
    HEAP16[$164 >> 1] = 0;
    $175 = $161 | 0;
    $clazz_0_in = $175;
    label = 34;
    break;
   case 31:
    HEAP32[$165 >> 2] = 1094992453;
    HEAP16[$164 >> 1] = 1;
    $177 = $161 + 4 | 0;
    $clazz_0_in = $177;
    label = 34;
    break;
   case 32:
    HEAP32[$165 >> 2] = 1094992451;
    HEAP16[$164 >> 1] = 2;
    $179 = $161 + 8 | 0;
    $clazz_0_in = $179;
    label = 34;
    break;
   case 33:
    HEAP32[$165 >> 2] = 1818326065;
    HEAP16[$164 >> 1] = 3;
    $clazz_0_in = $166;
    label = 34;
    break;
   case 34:
    $clazz_0 = HEAP32[$clazz_0_in >> 2] | 0;
    $182 = ($clazz_0 | 0) == 0;
    if ($182) {
      $error_0 = 0;
      label = 36;
      break;
    } else {
      label = 35;
      break;
    }
   case 35:
    $184 = $clazz_0;
    $185 = _FT_CMap_New($184, 0, $169, 0) | 0;
    $error_0 = $185;
    label = 36;
    break;
   case 36:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _T42_Face_Done($face) {
  $face = $face | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($face | 0) == 0;
    if ($1) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 100 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $face + 500 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = $6;
    $10 = _FT_Done_Face($9) | 0;
    label = 4;
    break;
   case 4:
    $12 = $face + 132 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    _ft_mem_free($4, $13);
    HEAP32[$12 >> 2] = 0;
    $14 = $face + 136 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    _ft_mem_free($4, $15);
    HEAP32[$14 >> 2] = 0;
    $16 = $face + 140 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    _ft_mem_free($4, $17);
    HEAP32[$16 >> 2] = 0;
    $18 = $face + 144 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    _ft_mem_free($4, $19);
    HEAP32[$18 >> 2] = 0;
    $20 = $face + 148 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    _ft_mem_free($4, $21);
    HEAP32[$20 >> 2] = 0;
    $22 = $face + 428 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $23;
    _ft_mem_free($4, $24);
    HEAP32[$22 >> 2] = 0;
    $25 = $face + 424 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $26;
    _ft_mem_free($4, $27);
    HEAP32[$25 >> 2] = 0;
    $28 = $face + 420 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $29;
    _ft_mem_free($4, $30);
    HEAP32[$28 >> 2] = 0;
    $31 = $face + 396 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    _ft_mem_free($4, $32);
    HEAP32[$31 >> 2] = 0;
    $33 = $face + 400 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    _ft_mem_free($4, $34);
    HEAP32[$33 >> 2] = 0;
    $35 = $face + 384 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $36;
    _ft_mem_free($4, $37);
    HEAP32[$35 >> 2] = 0;
    $38 = $face + 388 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = $39;
    _ft_mem_free($4, $40);
    HEAP32[$38 >> 2] = 0;
    $41 = $face + 364 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    _ft_mem_free($4, $42);
    HEAP32[$41 >> 2] = 0;
    $43 = $face + 492 | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    _ft_mem_free($4, $44);
    HEAP32[$43 >> 2] = 0;
    $45 = $face + 556 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $46;
    _ft_mem_free($4, $47);
    HEAP32[$45 >> 2] = 0;
    $48 = $face + 552 | 0;
    HEAP32[$48 >> 2] = 0;
    $49 = $face + 20 | 0;
    HEAP32[$49 >> 2] = 0;
    $50 = $face + 24 | 0;
    HEAP32[$50 >> 2] = 0;
    label = 5;
    break;
   case 5:
    return;
  }
}
function _T42_Size_Init($size) {
  $size = $size | 0;
  var $ttsize = 0, $7 = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  $ttsize = __stackBase__ | 0;
  $7 = _FT_New_Size(HEAP32[(HEAP32[$size >> 2] | 0) + 500 >> 2] | 0, $ttsize) | 0;
  HEAP32[$size + 44 >> 2] = HEAP32[$ttsize >> 2] | 0;
  _FT_Activate_Size(HEAP32[$ttsize >> 2] | 0);
  STACKTOP = __stackBase__;
  return $7 | 0;
}
function _T42_Size_Done($size) {
  $size = $size | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 500 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 108 | 0;
    $6 = $5;
    $7 = $size + 44 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8;
    $10 = _FT_List_Find($6, $9) | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $13 = $8;
    $14 = _FT_Done_Size($13) | 0;
    HEAP32[$7 >> 2] = 0;
    label = 3;
    break;
   case 3:
    return;
  }
}
function _T42_GlyphSlot_Init($slot) {
  $slot = $slot | 0;
  var $ttslot = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $ttslot = __stackBase__ | 0;
    $1 = $slot + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 84 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    $6 = $2 + 500 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    if ($5) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $9 = $7 + 84 | 0;
    $10 = $9;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $slot + 160 | 0;
    HEAP32[$12 >> 2] = $11;
    $error_0 = 0;
    label = 4;
    break;
   case 3:
    $14 = $7;
    $15 = $ttslot;
    $16 = _FT_New_GlyphSlot($14, $15) | 0;
    $17 = HEAP32[$ttslot >> 2] | 0;
    $18 = $slot + 160 | 0;
    HEAP32[$18 >> 2] = $17;
    $error_0 = $16;
    label = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _T42_GlyphSlot_Done($slot) {
  $slot = $slot | 0;
  _FT_Done_GlyphSlot(HEAP32[$slot + 160 >> 2] | 0);
  return;
}
function _T42_GlyphSlot_Load($glyph, $size, $glyph_index, $load_flags) {
  $glyph = $glyph | 0;
  $size = $size | 0;
  $glyph_index = $glyph_index | 0;
  $load_flags = $load_flags | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $glyph + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 96 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 40 | 0;
    $6 = $5;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $glyph + 160 | 0;
    $9 = $8;
    $10 = HEAP32[$9 >> 2] | 0;
    _t42_glyphslot_clear($10);
    $11 = $7 + 80 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = HEAP32[$9 >> 2] | 0;
    $14 = $size + 44 | 0;
    $15 = $14;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $load_flags | 8;
    $18 = FUNCTION_TABLE_iiiii[$12 & 1023]($13, $16, $glyph_index, $17) | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $21 = $glyph + 24 | 0;
    $22 = HEAP32[$9 >> 2] | 0;
    $23 = $22 + 24 | 0;
    $24 = $21;
    $25 = $23;
    _memcpy($24 | 0, $25 | 0, 32);
    $26 = HEAP32[$9 >> 2] | 0;
    $27 = $26 + 56 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $glyph + 56 | 0;
    HEAP32[$29 >> 2] = $28;
    $30 = HEAP32[$9 >> 2] | 0;
    $31 = $30 + 60 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $glyph + 60 | 0;
    HEAP32[$33 >> 2] = $32;
    $34 = HEAP32[$9 >> 2] | 0;
    $35 = $34 + 72 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $glyph + 72 | 0;
    HEAP32[$37 >> 2] = $36;
    $38 = $glyph + 108 | 0;
    $39 = HEAP32[$9 >> 2] | 0;
    $40 = $39 + 108 | 0;
    $41 = $38;
    $42 = $40;
    _memcpy($41 | 0, $42 | 0, 20);
    $43 = $glyph + 76 | 0;
    $44 = HEAP32[$9 >> 2] | 0;
    $45 = $44 + 76 | 0;
    $46 = $43;
    $47 = $45;
    _memcpy($46 | 0, $47 | 0, 24);
    $48 = HEAP32[$9 >> 2] | 0;
    $49 = $48 + 100 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $glyph + 100 | 0;
    HEAP32[$51 >> 2] = $50;
    $52 = HEAP32[$9 >> 2] | 0;
    $53 = $52 + 104 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = $glyph + 104 | 0;
    HEAP32[$55 >> 2] = $54;
    $56 = HEAP32[$9 >> 2] | 0;
    $57 = $56 + 128 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = $glyph + 128 | 0;
    HEAP32[$59 >> 2] = $58;
    $60 = HEAP32[$9 >> 2] | 0;
    $61 = $60 + 132 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = $glyph + 132 | 0;
    HEAP32[$63 >> 2] = $62;
    $64 = HEAP32[$9 >> 2] | 0;
    $65 = $64 + 136 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = $glyph + 136 | 0;
    HEAP32[$67 >> 2] = $66;
    $68 = HEAP32[$9 >> 2] | 0;
    $69 = $68 + 140 | 0;
    $70 = HEAP32[$69 >> 2] | 0;
    $71 = $glyph + 140 | 0;
    HEAP32[$71 >> 2] = $70;
    label = 3;
    break;
   case 3:
    return $18 | 0;
  }
  return 0;
}
function _T42_Size_Request($size, $req) {
  $size = $size | 0;
  $req = $req | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $size + 44 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4;
    $6 = _FT_Activate_Size($5) | 0;
    $7 = $2 + 500 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8;
    $10 = _FT_Request_Size($9, $req) | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $13 = $size + 12 | 0;
    $14 = HEAP32[$7 >> 2] | 0;
    $15 = $14 + 88 | 0;
    $16 = $15;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $17 + 12 | 0;
    $19 = $13;
    $20 = $18;
    _memcpy($19 | 0, $20 | 0, 28);
    label = 3;
    break;
   case 3:
    return $10 | 0;
  }
  return 0;
}
function _T42_Size_Select($size, $strike_index) {
  $size = $size | 0;
  $strike_index = $strike_index | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $size + 44 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4;
    $6 = _FT_Activate_Size($5) | 0;
    $7 = $2 + 500 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8;
    $10 = _FT_Select_Size($9, $strike_index) | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $13 = $size + 12 | 0;
    $14 = HEAP32[$7 >> 2] | 0;
    $15 = $14 + 88 | 0;
    $16 = $15;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $17 + 12 | 0;
    $19 = $13;
    $20 = $18;
    _memcpy($19 | 0, $20 | 0, 28);
    label = 3;
    break;
   case 3:
    return $10 | 0;
  }
  return 0;
}
function _t42_glyphslot_clear($slot) {
  $slot = $slot | 0;
  _ft_glyphslot_free_bitmap($slot);
  HEAP32[$slot + 152 >> 2] = 0;
  _memset($slot + 24 | 0, 0, 40);
  _memset($slot + 72 | 0, 0, 72);
  return;
}
function _T42_Open_Face($face) {
  $face = $face | 0;
  var $loader = 0, $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $charcode_047 = 0, $max_char_046 = 0, $min_char_045 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $idx_0 = 0, $72 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $89 = 0, $charcode_0_min_char_0 = 0, $90 = 0, $91 = 0, $max_char_0_ = 0, $min_char_2 = 0, $max_char_1 = 0, $92 = 0, $93 = 0, $94 = 0, $max_char_0_lcssa = 0, $min_char_0_lcssa = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $101 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 308 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $loader = __stackBase__ | 0;
    $error = __stackBase__ + 304 | 0;
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 488 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    _t42_loader_init($loader);
    $5 = _ft_mem_alloc($2, 12, $error) | 0;
    $6 = $face + 492 | 0;
    HEAP32[$6 >> 2] = $5;
    $7 = HEAP32[$error >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 19;
      break;
    }
   case 2:
    $10 = $loader | 0;
    $11 = $4;
    $12 = $face + 104 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = _t42_parser_init($10, $13, $2, $11) | 0;
    HEAP32[$error >> 2] = $14;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 3;
      break;
    } else {
      label = 19;
      break;
    }
   case 3:
    $17 = $loader + 76 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $loader + 80 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = _t42_parse_dict($face, $loader, $18, $20) | 0;
    HEAP32[$error >> 2] = $21;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 4;
      break;
    } else {
      label = 19;
      break;
    }
   case 4:
    $24 = $face + 433 | 0;
    $25 = HEAP8[$24] | 0;
    $26 = $25 << 24 >> 24 == 42;
    if ($26) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    HEAP32[$error >> 2] = 2;
    label = 19;
    break;
   case 6:
    $29 = $loader + 144 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $face + 416 | 0;
    HEAP32[$31 >> 2] = $30;
    $32 = $loader + 212 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = ($33 | 0) == 0;
    if ($34) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    HEAP32[$error >> 2] = 3;
    label = 8;
    break;
   case 8:
    HEAP32[$32 >> 2] = 0;
    $37 = $loader + 200 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $face + 396 | 0;
    HEAP32[$39 >> 2] = $38;
    $40 = $loader + 224 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = $face + 424 | 0;
    HEAP32[$42 >> 2] = $41;
    $43 = $loader + 228 | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    $45 = $face + 428 | 0;
    HEAP32[$45 >> 2] = $44;
    $46 = $loader + 148 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $face + 400 | 0;
    HEAP32[$48 >> 2] = $47;
    $49 = $loader + 172 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $face + 420 | 0;
    HEAP32[$51 >> 2] = $50;
    HEAP32[$46 >> 2] = 0;
    HEAP32[$49 >> 2] = 0;
    $52 = $face + 368 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = ($53 | 0) == 1;
    if ($54) {
      label = 9;
      break;
    } else {
      label = 19;
      break;
    }
   case 9:
    $55 = $loader + 108 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = ($56 | 0) > 0;
    if ($57) {
      label = 10;
      break;
    } else {
      $min_char_0_lcssa = 0;
      $max_char_0_lcssa = 0;
      label = 18;
      break;
    }
   case 10:
    $58 = $face + 384 | 0;
    $59 = $face + 388 | 0;
    $60 = $loader + 116 | 0;
    $min_char_045 = 0;
    $max_char_046 = 0;
    $charcode_047 = 0;
    label = 11;
    break;
   case 11:
    $62 = HEAP32[$58 >> 2] | 0;
    $63 = $62 + ($charcode_047 << 1) | 0;
    HEAP16[$63 >> 1] = 0;
    $64 = HEAP32[$59 >> 2] | 0;
    $65 = $64 + ($charcode_047 << 2) | 0;
    HEAP32[$65 >> 2] = 5321904;
    $66 = HEAP32[$60 >> 2] | 0;
    $67 = $66 + ($charcode_047 << 2) | 0;
    $68 = HEAP32[$67 >> 2] | 0;
    $69 = ($68 | 0) == 0;
    if ($69) {
      $max_char_1 = $max_char_046;
      $min_char_2 = $min_char_045;
      label = 17;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $70 = HEAP32[$31 >> 2] | 0;
    $idx_0 = 0;
    label = 13;
    break;
   case 13:
    $72 = ($idx_0 | 0) < ($70 | 0);
    if ($72) {
      label = 14;
      break;
    } else {
      $max_char_1 = $max_char_046;
      $min_char_2 = $min_char_045;
      label = 17;
      break;
    }
   case 14:
    $74 = HEAP32[$51 >> 2] | 0;
    $75 = $74 + ($idx_0 << 2) | 0;
    $76 = HEAP32[$75 >> 2] | 0;
    $77 = _strcmp($68 | 0, $76 | 0) | 0;
    $78 = ($77 | 0) == 0;
    $79 = $idx_0 + 1 | 0;
    if ($78) {
      label = 15;
      break;
    } else {
      $idx_0 = $79;
      label = 13;
      break;
    }
   case 15:
    $81 = $idx_0 & 65535;
    $82 = HEAP32[$58 >> 2] | 0;
    $83 = $82 + ($charcode_047 << 1) | 0;
    HEAP16[$83 >> 1] = $81;
    $84 = HEAP32[$59 >> 2] | 0;
    $85 = $84 + ($charcode_047 << 2) | 0;
    HEAP32[$85 >> 2] = $76;
    $86 = _strcmp(5321904, $76 | 0) | 0;
    $87 = ($86 | 0) == 0;
    if ($87) {
      $max_char_1 = $max_char_046;
      $min_char_2 = $min_char_045;
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $89 = ($charcode_047 | 0) < ($min_char_045 | 0);
    $charcode_0_min_char_0 = $89 ? $charcode_047 : $min_char_045;
    $90 = ($charcode_047 | 0) < ($max_char_046 | 0);
    $91 = $charcode_047 + 1 | 0;
    $max_char_0_ = $90 ? $max_char_046 : $91;
    $max_char_1 = $max_char_0_;
    $min_char_2 = $charcode_0_min_char_0;
    label = 17;
    break;
   case 17:
    $92 = $charcode_047 + 1 | 0;
    $93 = HEAP32[$55 >> 2] | 0;
    $94 = ($92 | 0) < ($93 | 0);
    if ($94) {
      $min_char_045 = $min_char_2;
      $max_char_046 = $max_char_1;
      $charcode_047 = $92;
      label = 11;
      break;
    } else {
      $min_char_0_lcssa = $min_char_2;
      $max_char_0_lcssa = $max_char_1;
      label = 18;
      break;
    }
   case 18:
    $95 = $face + 376 | 0;
    HEAP32[$95 >> 2] = $min_char_0_lcssa;
    $96 = $face + 380 | 0;
    HEAP32[$96 >> 2] = $max_char_0_lcssa;
    $97 = $loader + 88 | 0;
    $98 = HEAP32[$97 >> 2] | 0;
    $99 = $face + 372 | 0;
    HEAP32[$99 >> 2] = $98;
    label = 19;
    break;
   case 19:
    _t42_loader_done($loader);
    $101 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $101 | 0;
  }
  return 0;
}
function _t42_loader_init($loader) {
  $loader = $loader | 0;
  _memset($loader | 0, 0, 304);
  return;
}
function _t42_parser_init($parser, $stream, $memory, $psaux) {
  $parser = $parser | 0;
  $stream = $stream | 0;
  $memory = $memory | 0;
  $psaux = $psaux | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $_pr = 0, $57 = 0, $58 = 0, $59 = 0, $61 = 0, $63 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $psaux + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $parser | 0;
    FUNCTION_TABLE_viiii[$4 & 1023]($5, 0, 0, $memory);
    $6 = $parser + 72 | 0;
    HEAP32[$6 >> 2] = $stream;
    $7 = $parser + 80 | 0;
    HEAP32[$7 >> 2] = 0;
    $8 = $parser + 76 | 0;
    HEAP32[$8 >> 2] = 0;
    $9 = $parser + 84 | 0;
    HEAP8[$9] = 0;
    $10 = _FT_Stream_Seek($stream, 0) | 0;
    HEAP32[$error >> 2] = $10;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 2;
      break;
    } else {
      label = 13;
      break;
    }
   case 2:
    $13 = _FT_Stream_EnterFrame($stream, 17) | 0;
    HEAP32[$error >> 2] = $13;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 3;
      break;
    } else {
      label = 13;
      break;
    }
   case 3:
    $16 = $stream + 32 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = _memcmp($17 | 0, 5322820, 17) | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    HEAP32[$error >> 2] = 2;
    label = 5;
    break;
   case 5:
    _FT_Stream_ExitFrame($stream);
    $22 = HEAP32[$error >> 2] | 0;
    $23 = ($22 | 0) == 0;
    if ($23) {
      label = 6;
      break;
    } else {
      label = 13;
      break;
    }
   case 6:
    $25 = _FT_Stream_Seek($stream, 0) | 0;
    HEAP32[$error >> 2] = $25;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 7;
      break;
    } else {
      label = 13;
      break;
    }
   case 7:
    $28 = $stream + 4 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $stream + 20 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = ($31 | 0) == 0;
    if ($32) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $34 = $stream | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $stream + 8 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $35 + $37 | 0;
    HEAP32[$8 >> 2] = $38;
    HEAP32[$7 >> 2] = $29;
    HEAP8[$9] = 1;
    $39 = _FT_Stream_Skip($stream, $29) | 0;
    HEAP32[$error >> 2] = $39;
    $40 = ($39 | 0) == 0;
    if ($40) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 9:
    $42 = _ft_mem_alloc($memory, $29, $error) | 0;
    HEAP32[$8 >> 2] = $42;
    $43 = HEAP32[$error >> 2] | 0;
    $44 = ($43 | 0) == 0;
    if ($44) {
      label = 10;
      break;
    } else {
      label = 13;
      break;
    }
   case 10:
    $46 = _FT_Stream_Read($stream, $42, $29) | 0;
    HEAP32[$error >> 2] = $46;
    $47 = ($46 | 0) == 0;
    if ($47) {
      label = 11;
      break;
    } else {
      label = 13;
      break;
    }
   case 11:
    HEAP32[$7 >> 2] = $29;
    label = 12;
    break;
   case 12:
    $50 = HEAP32[$8 >> 2] | 0;
    $51 = $parser + 4 | 0;
    HEAP32[$51 >> 2] = $50;
    $52 = HEAP32[$8 >> 2] | 0;
    $53 = $parser | 0;
    HEAP32[$53 >> 2] = $52;
    $54 = HEAP32[$7 >> 2] | 0;
    $55 = $52 + $54 | 0;
    $56 = $parser + 8 | 0;
    HEAP32[$56 >> 2] = $55;
    $_pr = HEAP32[$error >> 2] | 0;
    $57 = ($_pr | 0) == 0;
    if ($57) {
      label = 15;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $58 = HEAP8[$9] | 0;
    $59 = $58 << 24 >> 24 == 0;
    if ($59) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $61 = HEAP32[$8 >> 2] | 0;
    _ft_mem_free($memory, $61);
    HEAP32[$8 >> 2] = 0;
    label = 15;
    break;
   case 15:
    $63 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $63 | 0;
  }
  return 0;
}
function _t42_parse_dict($face, $loader, $base, $size) {
  $face = $face | 0;
  $loader = $loader | 0;
  $base = $base | 0;
  $size = $size | 0;
  var $token = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $or_cond = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $cur_087 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $or_cond78 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $cur2_0 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $or_cond80 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $_off = 0, $67 = 0, $68 = 0, $or_cond81 = 0, $i_082 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $74 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $81 = 0, $82 = 0, $84 = 0, $85 = 0, $87 = 0, $88 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $token = __stackBase__ | 0;
    $1 = $loader | 0;
    $2 = $loader | 0;
    HEAP32[$2 >> 2] = $base;
    $3 = $base + $size | 0;
    $4 = $loader + 8 | 0;
    HEAP32[$4 >> 2] = $3;
    $5 = $loader + 12 | 0;
    HEAP32[$5 >> 2] = 0;
    $6 = HEAP32[$4 >> 2] | 0;
    $7 = $loader + 28 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    FUNCTION_TABLE_vi[$8 & 1023]($1);
    $9 = HEAP32[$2 >> 2] | 0;
    $10 = $9 >>> 0 < $6 >>> 0;
    if ($10) {
      label = 2;
      break;
    } else {
      label = 24;
      break;
    }
   case 2:
    $11 = $loader + 32 | 0;
    $12 = $loader + 56 | 0;
    $13 = $token + 8 | 0;
    $14 = $loader + 32 | 0;
    $15 = $loader + 32 | 0;
    $17 = $9;
    label = 3;
    break;
   case 3:
    $18 = HEAP8[$17] | 0;
    $19 = $18 << 24 >> 24 == 70;
    $20 = $17 + 25 | 0;
    $21 = $20 >>> 0 < $6 >>> 0;
    $or_cond = $19 & $21;
    if ($or_cond) {
      label = 4;
      break;
    } else {
      label = 13;
      break;
    }
   case 4:
    $23 = _strncmp($17 | 0, 5321240, 13) | 0;
    $24 = ($23 | 0) == 0;
    if ($24) {
      label = 5;
      break;
    } else {
      label = 13;
      break;
    }
   case 5:
    $26 = HEAP32[$11 >> 2] | 0;
    FUNCTION_TABLE_vi[$26 & 1023]($1);
    $27 = HEAP32[$7 >> 2] | 0;
    FUNCTION_TABLE_vi[$27 & 1023]($1);
    $28 = HEAP32[$2 >> 2] | 0;
    $29 = $28 >>> 0 < $6 >>> 0;
    if ($29) {
      $cur_087 = $28;
      label = 6;
      break;
    } else {
      $cur2_0 = $28;
      label = 12;
      break;
    }
   case 6:
    $30 = HEAP8[$cur_087] | 0;
    $31 = $30 << 24 >> 24 == 107;
    $32 = $cur_087 + 5 | 0;
    $33 = $32 >>> 0 < $6 >>> 0;
    $or_cond78 = $31 & $33;
    if ($or_cond78) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $35 = _strncmp($cur_087 | 0, 5320548, 5) | 0;
    $36 = ($35 | 0) == 0;
    if ($36) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $38 = HEAP32[$11 >> 2] | 0;
    FUNCTION_TABLE_vi[$38 & 1023]($1);
    $39 = HEAP32[$5 >> 2] | 0;
    $40 = ($39 | 0) == 0;
    if ($40) {
      label = 9;
      break;
    } else {
      label = 24;
      break;
    }
   case 9:
    $42 = HEAP32[$7 >> 2] | 0;
    FUNCTION_TABLE_vi[$42 & 1023]($1);
    $43 = HEAP32[$2 >> 2] | 0;
    $44 = $43 >>> 0 < $6 >>> 0;
    if ($44) {
      $cur_087 = $43;
      label = 6;
      break;
    } else {
      $cur2_0 = $28;
      label = 12;
      break;
    }
   case 10:
    $46 = HEAP32[$11 >> 2] | 0;
    FUNCTION_TABLE_vi[$46 & 1023]($1);
    $47 = HEAP32[$12 >> 2] | 0;
    FUNCTION_TABLE_vii[$47 & 1023]($1, $token);
    $48 = HEAP32[$13 >> 2] | 0;
    $49 = ($48 | 0) == 3;
    if ($49) {
      label = 11;
      break;
    } else {
      $cur2_0 = $28;
      label = 12;
      break;
    }
   case 11:
    $51 = HEAP32[$2 >> 2] | 0;
    $cur2_0 = $51;
    label = 12;
    break;
   case 12:
    HEAP32[$2 >> 2] = $cur2_0;
    label = 23;
    break;
   case 13:
    $53 = HEAP8[$17] | 0;
    $54 = $53 << 24 >> 24 == 47;
    $55 = $17 + 2 | 0;
    $56 = $55 >>> 0 < $6 >>> 0;
    $or_cond80 = $54 & $56;
    if ($or_cond80) {
      label = 14;
      break;
    } else {
      label = 22;
      break;
    }
   case 14:
    $58 = $17 + 1 | 0;
    HEAP32[$2 >> 2] = $58;
    $59 = HEAP32[$14 >> 2] | 0;
    FUNCTION_TABLE_vi[$59 & 1023]($1);
    $60 = HEAP32[$5 >> 2] | 0;
    $61 = ($60 | 0) == 0;
    if ($61) {
      label = 15;
      break;
    } else {
      label = 24;
      break;
    }
   case 15:
    $63 = HEAP32[$2 >> 2] | 0;
    $64 = $63;
    $65 = $58;
    $66 = $64 - $65 | 0;
    $_off = $66 - 1 | 0;
    $67 = $_off >>> 0 < 21;
    $68 = $63 >>> 0 < $6 >>> 0;
    $or_cond81 = $67 & $68;
    if ($or_cond81) {
      $i_082 = 0;
      label = 16;
      break;
    } else {
      label = 23;
      break;
    }
   case 16:
    $69 = 5245204 + ($i_082 * 36 & -1) | 0;
    $70 = $69 | 0;
    $71 = HEAP32[$70 >> 2] | 0;
    $72 = ($71 | 0) == 0;
    if ($72) {
      label = 21;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $74 = HEAP8[$58] | 0;
    $75 = HEAP8[$71] | 0;
    $76 = $74 << 24 >> 24 == $75 << 24 >> 24;
    if ($76) {
      label = 18;
      break;
    } else {
      label = 21;
      break;
    }
   case 18:
    $78 = _strlen($71 | 0) | 0;
    $79 = ($66 | 0) == ($78 | 0);
    if ($79) {
      label = 19;
      break;
    } else {
      label = 21;
      break;
    }
   case 19:
    $81 = _memcmp($58 | 0, $71 | 0, $66 | 0) | 0;
    $82 = ($81 | 0) == 0;
    if ($82) {
      label = 20;
      break;
    } else {
      label = 21;
      break;
    }
   case 20:
    $84 = _t42_load_keyword($face, $loader, $69) | 0;
    HEAP32[$5 >> 2] = $84;
    $85 = ($84 | 0) == 0;
    if ($85) {
      label = 23;
      break;
    } else {
      $_0 = $84;
      label = 25;
      break;
    }
   case 21:
    $87 = $i_082 + 1 | 0;
    $88 = ($87 | 0) < 20;
    if ($88) {
      $i_082 = $87;
      label = 16;
      break;
    } else {
      label = 23;
      break;
    }
   case 22:
    $90 = HEAP32[$15 >> 2] | 0;
    FUNCTION_TABLE_vi[$90 & 1023]($1);
    $91 = HEAP32[$5 >> 2] | 0;
    $92 = ($91 | 0) == 0;
    if ($92) {
      label = 23;
      break;
    } else {
      label = 24;
      break;
    }
   case 23:
    $93 = HEAP32[$7 >> 2] | 0;
    FUNCTION_TABLE_vi[$93 & 1023]($1);
    $94 = HEAP32[$2 >> 2] | 0;
    $95 = $94 >>> 0 < $6 >>> 0;
    if ($95) {
      $17 = $94;
      label = 3;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $96 = HEAP32[$5 >> 2] | 0;
    $_0 = $96;
    label = 25;
    break;
   case 25:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _t42_loader_done($loader) {
  $loader = $loader | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $loader | 0;
    $2 = $loader + 140 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $loader + 92 | 0;
    FUNCTION_TABLE_vi[$3 & 1023]($6);
    label = 3;
    break;
   case 3:
    $8 = $loader + 248 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $12 = $loader + 200 | 0;
    FUNCTION_TABLE_vi[$9 & 1023]($12);
    label = 5;
    break;
   case 5:
    $14 = $loader + 196 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $18 = $loader + 148 | 0;
    FUNCTION_TABLE_vi[$15 & 1023]($18);
    label = 7;
    break;
   case 7:
    $20 = $loader + 300 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $24 = $loader + 252 | 0;
    FUNCTION_TABLE_vi[$21 & 1023]($24);
    label = 9;
    break;
   case 9:
    _t42_parser_done($1);
    return;
  }
}
function _t42_parser_done($parser) {
  $parser = $parser | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $parser | 0;
    $2 = $parser + 84 | 0;
    $3 = HEAP8[$2] | 0;
    $4 = $3 << 24 >> 24 == 0;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $6 = $parser + 16 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $parser + 76 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    _ft_mem_free($7, $9);
    HEAP32[$8 >> 2] = 0;
    label = 3;
    break;
   case 3:
    $11 = $parser + 24 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    FUNCTION_TABLE_vi[$12 & 1023]($1);
    return;
  }
}
function _t42_load_keyword($face, $loader, $field) {
  $face = $face | 0;
  $loader = $loader | 0;
  $field = $field | 0;
  var $dummy_object = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $_off = 0, $switch = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $dummy_object = __stackBase__ | 0;
    $1 = $field + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 10;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $5 = $field + 12 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $face | 0;
    $8 = $loader;
    FUNCTION_TABLE_vii[$6 & 1023]($7, $8);
    $9 = $loader + 12 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $error_0 = $10;
    label = 11;
    break;
   case 3:
    $12 = $field + 4 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    if (($13 | 0) == 3) {
      label = 4;
      break;
    } else if (($13 | 0) == 2) {
      label = 5;
      break;
    } else if (($13 | 0) == 5) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 4:
    $15 = $face + 132 | 0;
    $16 = $15;
    HEAP32[$dummy_object >> 2] = $16;
    label = 8;
    break;
   case 5:
    $18 = $face + 164 | 0;
    $19 = $18;
    HEAP32[$dummy_object >> 2] = $19;
    label = 8;
    break;
   case 6:
    $21 = $face + 460 | 0;
    $22 = $21;
    HEAP32[$dummy_object >> 2] = $22;
    label = 8;
    break;
   case 7:
    $24 = $face + 132 | 0;
    $25 = $24;
    HEAP32[$dummy_object >> 2] = $25;
    label = 8;
    break;
   case 8:
    $27 = HEAP32[$1 >> 2] | 0;
    $_off = $27 - 8 | 0;
    $switch = $_off >>> 0 < 2;
    $28 = $loader | 0;
    if ($switch) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $30 = $loader + 68 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = FUNCTION_TABLE_iiiiii[$31 & 1023]($28, $field, $dummy_object, 0, 0) | 0;
    $error_0 = $32;
    label = 11;
    break;
   case 10:
    $34 = $loader + 64 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = FUNCTION_TABLE_iiiiii[$35 & 1023]($28, $field, $dummy_object, 0, 0) | 0;
    $error_0 = $36;
    label = 11;
    break;
   case 11:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _t42_parse_font_matrix($face, $loader) {
  $face = $face | 0;
  $loader = $loader | 0;
  var $temp = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 24 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $temp = __stackBase__ | 0;
    $1 = $loader | 0;
    $2 = $loader + 52 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $temp | 0;
    $5 = FUNCTION_TABLE_iiiii[$3 & 1023]($1, 6, $4, 3) | 0;
    $6 = $temp + 12 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = ($7 | 0) < 0;
    $9 = -$7 | 0;
    $10 = $8 ? $9 : $7;
    $11 = _FT_DivFix(65536e3, $10) | 0;
    $12 = $11 >>> 16;
    $13 = $12 & 65535;
    $14 = $face + 68 | 0;
    HEAP16[$14 >> 1] = $13;
    $15 = ($10 | 0) == 65536;
    if ($15) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $17 = HEAP32[$4 >> 2] | 0;
    $18 = _FT_DivFix($17, $10) | 0;
    HEAP32[$4 >> 2] = $18;
    $19 = $temp + 4 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = _FT_DivFix($20, $10) | 0;
    HEAP32[$19 >> 2] = $21;
    $22 = $temp + 8 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = _FT_DivFix($23, $10) | 0;
    HEAP32[$22 >> 2] = $24;
    $25 = $temp + 16 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = _FT_DivFix($26, $10) | 0;
    HEAP32[$25 >> 2] = $27;
    $28 = $temp + 20 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = _FT_DivFix($29, $10) | 0;
    HEAP32[$28 >> 2] = $30;
    HEAP32[$6 >> 2] = 65536;
    label = 3;
    break;
   case 3:
    $32 = HEAP32[$4 >> 2] | 0;
    $33 = $face + 436 | 0;
    HEAP32[$33 >> 2] = $32;
    $34 = $temp + 4 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $face + 444 | 0;
    HEAP32[$36 >> 2] = $35;
    $37 = $temp + 8 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $face + 440 | 0;
    HEAP32[$39 >> 2] = $38;
    $40 = HEAP32[$6 >> 2] | 0;
    $41 = $face + 448 | 0;
    HEAP32[$41 >> 2] = $40;
    $42 = $temp + 16 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $43 >> 16;
    $45 = $face + 452 | 0;
    HEAP32[$45 >> 2] = $44;
    $46 = $temp + 20 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $47 >> 16;
    $49 = $face + 456 | 0;
    HEAP32[$49 >> 2] = $48;
    STACKTOP = __stackBase__;
    return;
  }
}
function _t42_parse_encoding($face, $loader) {
  $face = $face | 0;
  $loader = $loader | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $or_cond = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $only_immediates_0 = 0, $count_0 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $n_0105 = 0, $60 = 0, $61 = 0, $62 = 0, $exitcond = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $75 = 0, $n_1104 = 0, $76 = 0, $77 = 0, $79 = 0, $80 = 0, $82 = 0, $83 = 0, $84 = 0, $86 = 0, $87 = 0, $88 = 0, $90 = 0, $91 = 0, $92 = 0, $_pr = 0, $94 = 0, $95 = 0, $97 = 0, $99 = 0, $100 = 0, $101 = 0, $or_cond97 = 0, $104 = 0, $105 = 0, $106 = 0, $charcode_0 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $or_cond99 = 0, $113 = 0, $or_cond100 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $135 = 0, $136 = 0, $137 = 0, $n_2 = 0, $cur_1 = 0, $139 = 0, $140 = 0, $141 = 0, $cur_2 = 0, $142 = 0, $144 = 0, $145 = 0, $147 = 0, $148 = 0, $150 = 0, $152 = 0, $153 = 0, $155 = 0, $156 = 0, $158 = 0, $160 = 0, $161 = 0, $163 = 0, $164 = 0, $166 = 0, $168 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $loader | 0;
    $2 = $loader + 8 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $face + 488 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $loader + 28 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    FUNCTION_TABLE_vi[$7 & 1023]($1);
    $8 = $loader | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 >>> 0 < $3 >>> 0;
    if ($10) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $12 = $loader + 12 | 0;
    HEAP32[$12 >> 2] = 3;
    label = 45;
    break;
   case 3:
    $14 = HEAP8[$9] | 0;
    $15 = $14 & 255;
    $16 = $15 - 48 | 0;
    $17 = $16 >>> 0 < 10;
    $18 = $14 << 24 >> 24 == 91;
    $or_cond = $17 | $18;
    if ($or_cond) {
      label = 4;
      break;
    } else {
      label = 35;
      break;
    }
   case 4:
    $20 = $loader + 92 | 0;
    $21 = $loader + 16 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    if ($18) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $24 = $9 + 1 | 0;
    HEAP32[$8 >> 2] = $24;
    $count_0 = 256;
    $only_immediates_0 = 1;
    label = 7;
    break;
   case 6:
    $26 = $loader + 36 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = FUNCTION_TABLE_ii[$27 & 1023]($1) | 0;
    $count_0 = $28;
    $only_immediates_0 = 0;
    label = 7;
    break;
   case 7:
    $30 = HEAP32[$6 >> 2] | 0;
    FUNCTION_TABLE_vi[$30 & 1023]($1);
    $31 = HEAP32[$8 >> 2] | 0;
    $32 = $31 >>> 0 < $3 >>> 0;
    if ($32) {
      label = 8;
      break;
    } else {
      label = 45;
      break;
    }
   case 8:
    $34 = $face + 372 | 0;
    HEAP32[$34 >> 2] = $count_0;
    $35 = $loader + 88 | 0;
    HEAP32[$35 >> 2] = $count_0;
    $36 = _ft_mem_realloc($22, 2, 0, $count_0, 0, $error) | 0;
    $37 = $36;
    $38 = $face + 384 | 0;
    HEAP32[$38 >> 2] = $37;
    $39 = HEAP32[$error >> 2] | 0;
    $40 = ($39 | 0) == 0;
    if ($40) {
      label = 9;
      break;
    } else {
      label = 13;
      break;
    }
   case 9:
    $42 = _ft_mem_realloc($22, 4, 0, $count_0, 0, $error) | 0;
    $43 = $42;
    $44 = $face + 388 | 0;
    HEAP32[$44 >> 2] = $43;
    $45 = HEAP32[$error >> 2] | 0;
    $46 = ($45 | 0) == 0;
    if ($46) {
      label = 10;
      break;
    } else {
      label = 13;
      break;
    }
   case 10:
    $48 = $5;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = $49 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = FUNCTION_TABLE_iiii[$51 & 1023]($20, $count_0, $22) | 0;
    HEAP32[$error >> 2] = $52;
    $53 = ($52 | 0) == 0;
    if ($53) {
      label = 11;
      break;
    } else {
      label = 13;
      break;
    }
   case 11:
    $54 = ($count_0 | 0) == 0;
    if ($54) {
      label = 15;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $55 = $loader + 136 | 0;
    $n_0105 = 0;
    label = 14;
    break;
   case 13:
    $57 = HEAP32[$error >> 2] | 0;
    $58 = $loader + 12 | 0;
    HEAP32[$58 >> 2] = $57;
    label = 45;
    break;
   case 14:
    $60 = HEAP32[$55 >> 2] | 0;
    $61 = FUNCTION_TABLE_iiiii[$60 & 1023]($20, $n_0105, 5321904, 8) | 0;
    $62 = $n_0105 + 1 | 0;
    $exitcond = ($62 | 0) == ($count_0 | 0);
    if ($exitcond) {
      label = 15;
      break;
    } else {
      $n_0105 = $62;
      label = 14;
      break;
    }
   case 15:
    $63 = HEAP32[$6 >> 2] | 0;
    FUNCTION_TABLE_vi[$63 & 1023]($1);
    $64 = HEAP32[$8 >> 2] | 0;
    $65 = $64 >>> 0 < $3 >>> 0;
    if ($65) {
      label = 16;
      break;
    } else {
      $cur_2 = $9;
      label = 34;
      break;
    }
   case 16:
    $66 = $only_immediates_0 << 24 >> 24 == 0;
    $67 = $loader + 32 | 0;
    $68 = $loader + 12 | 0;
    $69 = $loader + 36 | 0;
    $70 = $loader + 32 | 0;
    $71 = $loader + 12 | 0;
    $72 = $loader + 136 | 0;
    $73 = $loader + 116 | 0;
    $n_1104 = 0;
    $75 = $64;
    label = 17;
    break;
   case 17:
    $76 = HEAP8[$75] | 0;
    $77 = $76 << 24 >> 24 == 100;
    if ($77) {
      label = 18;
      break;
    } else {
      $94 = $76;
      label = 23;
      break;
    }
   case 18:
    $79 = $75 + 3 | 0;
    $80 = $79 >>> 0 < $3 >>> 0;
    if ($80) {
      label = 19;
      break;
    } else {
      label = 22;
      break;
    }
   case 19:
    $82 = $75 + 1 | 0;
    $83 = HEAP8[$82] | 0;
    $84 = $83 << 24 >> 24 == 101;
    if ($84) {
      label = 20;
      break;
    } else {
      label = 22;
      break;
    }
   case 20:
    $86 = $75 + 2 | 0;
    $87 = HEAP8[$86] | 0;
    $88 = $87 << 24 >> 24 == 102;
    if ($88) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    $90 = HEAP8[$79] | 0;
    $91 = _t42_is_space($90) | 0;
    $92 = ($91 | 0) == 0;
    if ($92) {
      label = 22;
      break;
    } else {
      $cur_2 = $79;
      label = 34;
      break;
    }
   case 22:
    $_pr = HEAP8[$75] | 0;
    $94 = $_pr;
    label = 23;
    break;
   case 23:
    $95 = $94 << 24 >> 24 == 93;
    if ($95) {
      label = 24;
      break;
    } else {
      label = 25;
      break;
    }
   case 24:
    $97 = $75 + 1 | 0;
    $cur_2 = $97;
    label = 34;
    break;
   case 25:
    $99 = $94 & 255;
    $100 = $99 - 48 | 0;
    $101 = $100 >>> 0 > 9;
    $or_cond97 = $101 & $66;
    if ($or_cond97) {
      label = 32;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    if ($66) {
      label = 27;
      break;
    } else {
      $charcode_0 = $n_1104;
      label = 28;
      break;
    }
   case 27:
    $104 = HEAP32[$69 >> 2] | 0;
    $105 = FUNCTION_TABLE_ii[$104 & 1023]($1) | 0;
    $106 = HEAP32[$6 >> 2] | 0;
    FUNCTION_TABLE_vi[$106 & 1023]($1);
    $charcode_0 = $105;
    label = 28;
    break;
   case 28:
    $108 = HEAP32[$8 >> 2] | 0;
    $109 = HEAP8[$108] | 0;
    $110 = $109 << 24 >> 24 == 47;
    $111 = $108 + 2 | 0;
    $112 = $111 >>> 0 < $3 >>> 0;
    $or_cond99 = $110 & $112;
    $113 = $n_1104 >>> 0 < $count_0 >>> 0;
    $or_cond100 = $or_cond99 & $113;
    if ($or_cond100) {
      label = 29;
      break;
    } else {
      $cur_1 = $108;
      $n_2 = $n_1104;
      label = 33;
      break;
    }
   case 29:
    $115 = $108 + 1 | 0;
    HEAP32[$8 >> 2] = $115;
    $116 = HEAP32[$70 >> 2] | 0;
    FUNCTION_TABLE_vi[$116 & 1023]($1);
    $117 = HEAP32[$71 >> 2] | 0;
    $118 = ($117 | 0) == 0;
    if ($118) {
      label = 30;
      break;
    } else {
      label = 45;
      break;
    }
   case 30:
    $120 = HEAP32[$8 >> 2] | 0;
    $121 = $120;
    $122 = $115;
    $123 = $121 - $122 | 0;
    $124 = HEAP32[$72 >> 2] | 0;
    $125 = $123 + 1 | 0;
    $126 = FUNCTION_TABLE_iiiii[$124 & 1023]($20, $charcode_0, $115, $125) | 0;
    HEAP32[$71 >> 2] = $126;
    $127 = ($126 | 0) == 0;
    if ($127) {
      label = 31;
      break;
    } else {
      label = 45;
      break;
    }
   case 31:
    $129 = HEAP32[$73 >> 2] | 0;
    $130 = $129 + ($charcode_0 << 2) | 0;
    $131 = HEAP32[$130 >> 2] | 0;
    $132 = $131 + $123 | 0;
    HEAP8[$132] = 0;
    $133 = $n_1104 + 1 | 0;
    $cur_1 = $115;
    $n_2 = $133;
    label = 33;
    break;
   case 32:
    $135 = HEAP32[$67 >> 2] | 0;
    FUNCTION_TABLE_vi[$135 & 1023]($1);
    $136 = HEAP32[$68 >> 2] | 0;
    $137 = ($136 | 0) == 0;
    if ($137) {
      $cur_1 = $75;
      $n_2 = $n_1104;
      label = 33;
      break;
    } else {
      label = 45;
      break;
    }
   case 33:
    $139 = HEAP32[$6 >> 2] | 0;
    FUNCTION_TABLE_vi[$139 & 1023]($1);
    $140 = HEAP32[$8 >> 2] | 0;
    $141 = $140 >>> 0 < $3 >>> 0;
    if ($141) {
      $n_1104 = $n_2;
      $75 = $140;
      label = 17;
      break;
    } else {
      $cur_2 = $cur_1;
      label = 34;
      break;
    }
   case 34:
    $142 = $face + 368 | 0;
    HEAP32[$142 >> 2] = 1;
    HEAP32[$8 >> 2] = $cur_2;
    label = 45;
    break;
   case 35:
    $144 = $9 + 17 | 0;
    $145 = $144 >>> 0 < $3 >>> 0;
    if ($145) {
      label = 36;
      break;
    } else {
      label = 38;
      break;
    }
   case 36:
    $147 = _strncmp($9 | 0, 5323032, 16) | 0;
    $148 = ($147 | 0) == 0;
    if ($148) {
      label = 37;
      break;
    } else {
      label = 38;
      break;
    }
   case 37:
    $150 = $face + 368 | 0;
    HEAP32[$150 >> 2] = 2;
    label = 45;
    break;
   case 38:
    $152 = $9 + 15 | 0;
    $153 = $152 >>> 0 < $3 >>> 0;
    if ($153) {
      label = 39;
      break;
    } else {
      label = 41;
      break;
    }
   case 39:
    $155 = _strncmp($9 | 0, 5322964, 14) | 0;
    $156 = ($155 | 0) == 0;
    if ($156) {
      label = 40;
      break;
    } else {
      label = 41;
      break;
    }
   case 40:
    $158 = $face + 368 | 0;
    HEAP32[$158 >> 2] = 4;
    label = 45;
    break;
   case 41:
    $160 = $9 + 18 | 0;
    $161 = $160 >>> 0 < $3 >>> 0;
    if ($161) {
      label = 42;
      break;
    } else {
      label = 44;
      break;
    }
   case 42:
    $163 = _strncmp($9 | 0, 5322892, 17) | 0;
    $164 = ($163 | 0) == 0;
    if ($164) {
      label = 43;
      break;
    } else {
      label = 44;
      break;
    }
   case 43:
    $166 = $face + 368 | 0;
    HEAP32[$166 >> 2] = 3;
    label = 45;
    break;
   case 44:
    $168 = $loader + 12 | 0;
    HEAP32[$168 >> 2] = 3;
    label = 45;
    break;
   case 45:
    STACKTOP = __stackBase__;
    return;
  }
}
function _t42_parse_charstrings($face, $loader) {
  $face = $face | 0;
  $loader = $loader | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $count_0153 = 0, $42 = 0, $44 = 0, $46 = 0, $count_1 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $n_0_ph = 0, $notdef_index_0_ph = 0, $notdef_found_0_ph = 0, $87 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $94 = 0, $95 = 0, $97 = 0, $98 = 0, $99 = 0, $101 = 0, $102 = 0, $103 = 0, $105 = 0, $106 = 0, $107 = 0, $_pr = 0, $109 = 0, $110 = 0, $112 = 0, $113 = 0, $114 = 0, $116 = 0, $117 = 0, $119 = 0, $120 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $n_0_notdef_index_0 = 0, $_notdef_found_0 = 0, $notdef_index_1 = 0, $notdef_found_1 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $n_1 = 0, $notdef_index_2 = 0, $notdef_found_2 = 0, $166 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $200 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $210 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $220 = 0, $221 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $230 = 0, $231 = 0, $232 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $240 = 0, $241 = 0, $242 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $250 = 0, $251 = 0, $252 = 0, $error_0 = 0, $253 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $loader + 200 | 0;
    $2 = $loader + 148 | 0;
    $3 = $loader + 252 | 0;
    $4 = $loader | 0;
    $5 = $loader + 16 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $face + 488 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $loader + 8 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $loader + 28 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    FUNCTION_TABLE_vi[$12 & 1023]($4);
    $13 = $loader | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 >>> 0 < $10 >>> 0;
    if ($15) {
      label = 2;
      break;
    } else {
      $error_0 = 3;
      label = 45;
      break;
    }
   case 2:
    $17 = HEAP8[$14] | 0;
    $18 = $17 & 255;
    $19 = $18 - 48 | 0;
    $20 = $19 >>> 0 < 10;
    if ($20) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $22 = $loader + 36 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = FUNCTION_TABLE_ii[$23 & 1023]($4) | 0;
    $25 = $loader + 144 | 0;
    HEAP32[$25 >> 2] = $24;
    $26 = $loader + 12 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = ($27 | 0) == 0;
    if ($28) {
      label = 12;
      break;
    } else {
      label = 46;
      break;
    }
   case 4:
    $30 = $17 << 24 >> 24 == 60;
    if ($30) {
      label = 5;
      break;
    } else {
      $error_0 = 3;
      label = 45;
      break;
    }
   case 5:
    $32 = $loader + 32 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    FUNCTION_TABLE_vi[$33 & 1023]($4);
    $34 = $loader + 12 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = ($35 | 0) == 0;
    if ($36) {
      label = 6;
      break;
    } else {
      label = 46;
      break;
    }
   case 6:
    $38 = HEAP32[$11 >> 2] | 0;
    FUNCTION_TABLE_vi[$38 & 1023]($4);
    $39 = HEAP32[$13 >> 2] | 0;
    $40 = $39 >>> 0 < $10 >>> 0;
    if ($40) {
      $count_0153 = 0;
      $41 = $39;
      label = 7;
      break;
    } else {
      label = 12;
      break;
    }
   case 7:
    $42 = HEAP8[$41] | 0;
    if (($42 << 24 >> 24 | 0) == 47) {
      label = 8;
      break;
    } else if (($42 << 24 >> 24 | 0) == 62) {
      label = 9;
      break;
    } else {
      $count_1 = $count_0153;
      label = 10;
      break;
    }
   case 8:
    $44 = $count_0153 + 1 | 0;
    $count_1 = $44;
    label = 10;
    break;
   case 9:
    $46 = $loader + 144 | 0;
    HEAP32[$46 >> 2] = $count_0153;
    HEAP32[$13 >> 2] = $39;
    label = 12;
    break;
   case 10:
    $48 = HEAP32[$32 >> 2] | 0;
    FUNCTION_TABLE_vi[$48 & 1023]($4);
    $49 = HEAP32[$34 >> 2] | 0;
    $50 = ($49 | 0) == 0;
    if ($50) {
      label = 11;
      break;
    } else {
      label = 46;
      break;
    }
   case 11:
    $52 = HEAP32[$11 >> 2] | 0;
    FUNCTION_TABLE_vi[$52 & 1023]($4);
    $53 = HEAP32[$13 >> 2] | 0;
    $54 = $53 >>> 0 < $10 >>> 0;
    if ($54) {
      $count_0153 = $count_1;
      $41 = $53;
      label = 7;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $55 = HEAP32[$13 >> 2] | 0;
    $56 = $55 >>> 0 < $10 >>> 0;
    if ($56) {
      label = 13;
      break;
    } else {
      $error_0 = 3;
      label = 45;
      break;
    }
   case 13:
    $58 = $8;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = $59 | 0;
    $61 = HEAP32[$60 >> 2] | 0;
    $62 = $loader + 144 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = FUNCTION_TABLE_iiii[$61 & 1023]($1, $63, $6) | 0;
    $65 = ($64 | 0) == 0;
    if ($65) {
      label = 14;
      break;
    } else {
      $error_0 = $64;
      label = 45;
      break;
    }
   case 14:
    $67 = HEAP32[$58 >> 2] | 0;
    $68 = $67 | 0;
    $69 = HEAP32[$68 >> 2] | 0;
    $70 = HEAP32[$62 >> 2] | 0;
    $71 = FUNCTION_TABLE_iiii[$69 & 1023]($2, $70, $6) | 0;
    $72 = ($71 | 0) == 0;
    if ($72) {
      label = 15;
      break;
    } else {
      $error_0 = $71;
      label = 45;
      break;
    }
   case 15:
    $74 = HEAP32[$58 >> 2] | 0;
    $75 = $74 | 0;
    $76 = HEAP32[$75 >> 2] | 0;
    $77 = FUNCTION_TABLE_iiii[$76 & 1023]($3, 4, $6) | 0;
    $78 = ($77 | 0) == 0;
    if ($78) {
      label = 16;
      break;
    } else {
      $error_0 = $77;
      label = 45;
      break;
    }
   case 16:
    $79 = $loader + 32 | 0;
    $80 = $loader + 12 | 0;
    $81 = $loader + 192 | 0;
    $82 = $loader + 172 | 0;
    $83 = $loader + 36 | 0;
    $84 = $loader + 244 | 0;
    $85 = $loader + 224 | 0;
    $notdef_found_0_ph = 0;
    $notdef_index_0_ph = 0;
    $n_0_ph = 0;
    label = 17;
    break;
   case 17:
    label = 18;
    break;
   case 18:
    $87 = HEAP32[$11 >> 2] | 0;
    FUNCTION_TABLE_vi[$87 & 1023]($4);
    $88 = HEAP32[$13 >> 2] | 0;
    $89 = $88 >>> 0 < $10 >>> 0;
    if ($89) {
      label = 19;
      break;
    } else {
      $notdef_found_2 = $notdef_found_0_ph;
      $notdef_index_2 = $notdef_index_0_ph;
      $n_1 = $n_0_ph;
      label = 35;
      break;
    }
   case 19:
    $91 = HEAP8[$88] | 0;
    $92 = $91 << 24 >> 24 == 101;
    if ($92) {
      label = 20;
      break;
    } else {
      $109 = $91;
      label = 25;
      break;
    }
   case 20:
    $94 = $88 + 3 | 0;
    $95 = $94 >>> 0 < $10 >>> 0;
    if ($95) {
      label = 21;
      break;
    } else {
      label = 24;
      break;
    }
   case 21:
    $97 = $88 + 1 | 0;
    $98 = HEAP8[$97] | 0;
    $99 = $98 << 24 >> 24 == 110;
    if ($99) {
      label = 22;
      break;
    } else {
      label = 24;
      break;
    }
   case 22:
    $101 = $88 + 2 | 0;
    $102 = HEAP8[$101] | 0;
    $103 = $102 << 24 >> 24 == 100;
    if ($103) {
      label = 23;
      break;
    } else {
      label = 24;
      break;
    }
   case 23:
    $105 = HEAP8[$94] | 0;
    $106 = _t42_is_space($105) | 0;
    $107 = ($106 | 0) == 0;
    if ($107) {
      label = 24;
      break;
    } else {
      $notdef_found_2 = $notdef_found_0_ph;
      $notdef_index_2 = $notdef_index_0_ph;
      $n_1 = $n_0_ph;
      label = 35;
      break;
    }
   case 24:
    $_pr = HEAP8[$88] | 0;
    $109 = $_pr;
    label = 25;
    break;
   case 25:
    $110 = $109 << 24 >> 24 == 62;
    if ($110) {
      $notdef_found_2 = $notdef_found_0_ph;
      $notdef_index_2 = $notdef_index_0_ph;
      $n_1 = $n_0_ph;
      label = 35;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $112 = HEAP32[$79 >> 2] | 0;
    FUNCTION_TABLE_vi[$112 & 1023]($4);
    $113 = HEAP32[$80 >> 2] | 0;
    $114 = ($113 | 0) == 0;
    if ($114) {
      label = 27;
      break;
    } else {
      label = 46;
      break;
    }
   case 27:
    $116 = HEAP8[$88] | 0;
    $117 = $116 << 24 >> 24 == 47;
    if ($117) {
      label = 28;
      break;
    } else {
      label = 18;
      break;
    }
   case 28:
    $119 = $88 + 1 | 0;
    $120 = $119 >>> 0 < $10 >>> 0;
    if ($120) {
      label = 29;
      break;
    } else {
      $error_0 = 3;
      label = 45;
      break;
    }
   case 29:
    $122 = HEAP32[$13 >> 2] | 0;
    $123 = $122;
    $124 = $119;
    $125 = $123 - $124 | 0;
    $126 = HEAP32[$81 >> 2] | 0;
    $127 = $125 + 1 | 0;
    $128 = FUNCTION_TABLE_iiiii[$126 & 1023]($2, $n_0_ph, $119, $127) | 0;
    $129 = ($128 | 0) == 0;
    if ($129) {
      label = 30;
      break;
    } else {
      $error_0 = $128;
      label = 45;
      break;
    }
   case 30:
    $131 = HEAP32[$82 >> 2] | 0;
    $132 = $131 + ($n_0_ph << 2) | 0;
    $133 = HEAP32[$132 >> 2] | 0;
    $134 = $133 + $125 | 0;
    HEAP8[$134] = 0;
    $135 = HEAP8[$119] | 0;
    $136 = $135 << 24 >> 24 == 46;
    if ($136) {
      label = 31;
      break;
    } else {
      $notdef_found_1 = $notdef_found_0_ph;
      $notdef_index_1 = $notdef_index_0_ph;
      label = 32;
      break;
    }
   case 31:
    $138 = HEAP32[$82 >> 2] | 0;
    $139 = $138 + ($n_0_ph << 2) | 0;
    $140 = HEAP32[$139 >> 2] | 0;
    $141 = _strcmp(5321904, $140 | 0) | 0;
    $142 = ($141 | 0) == 0;
    $n_0_notdef_index_0 = $142 ? $n_0_ph : $notdef_index_0_ph;
    $_notdef_found_0 = $142 ? 1 : $notdef_found_0_ph;
    $notdef_found_1 = $_notdef_found_0;
    $notdef_index_1 = $n_0_notdef_index_0;
    label = 32;
    break;
   case 32:
    $144 = HEAP32[$11 >> 2] | 0;
    FUNCTION_TABLE_vi[$144 & 1023]($4);
    $145 = HEAP32[$13 >> 2] | 0;
    $146 = HEAP32[$83 >> 2] | 0;
    $147 = FUNCTION_TABLE_ii[$146 & 1023]($4) | 0;
    $148 = HEAP32[$13 >> 2] | 0;
    $149 = $148 >>> 0 < $10 >>> 0;
    if ($149) {
      label = 33;
      break;
    } else {
      $error_0 = 3;
      label = 45;
      break;
    }
   case 33:
    $151 = $148;
    $152 = $145;
    $153 = $151 - $152 | 0;
    $154 = HEAP32[$84 >> 2] | 0;
    $155 = $153 + 1 | 0;
    $156 = FUNCTION_TABLE_iiiii[$154 & 1023]($1, $n_0_ph, $145, $155) | 0;
    $157 = ($156 | 0) == 0;
    if ($157) {
      label = 34;
      break;
    } else {
      $error_0 = $156;
      label = 45;
      break;
    }
   case 34:
    $159 = HEAP32[$85 >> 2] | 0;
    $160 = $159 + ($n_0_ph << 2) | 0;
    $161 = HEAP32[$160 >> 2] | 0;
    $162 = $161 + $153 | 0;
    HEAP8[$162] = 0;
    $163 = $n_0_ph + 1 | 0;
    $164 = HEAP32[$62 >> 2] | 0;
    $165 = $163 >>> 0 < $164 >>> 0;
    if ($165) {
      $notdef_found_0_ph = $notdef_found_1;
      $notdef_index_0_ph = $notdef_index_1;
      $n_0_ph = $163;
      label = 17;
      break;
    } else {
      $notdef_found_2 = $notdef_found_1;
      $notdef_index_2 = $notdef_index_1;
      $n_1 = $163;
      label = 35;
      break;
    }
   case 35:
    HEAP32[$62 >> 2] = $n_1;
    $166 = $notdef_found_2 << 24 >> 24 == 0;
    if ($166) {
      $error_0 = 3;
      label = 45;
      break;
    } else {
      label = 36;
      break;
    }
   case 36:
    $168 = $loader + 172 | 0;
    $169 = HEAP32[$168 >> 2] | 0;
    $170 = HEAP32[$169 >> 2] | 0;
    $171 = _strcmp(5321904, $170 | 0) | 0;
    $172 = ($171 | 0) == 0;
    if ($172) {
      label = 46;
      break;
    } else {
      label = 37;
      break;
    }
   case 37:
    $174 = $loader + 296 | 0;
    $175 = HEAP32[$174 >> 2] | 0;
    $176 = $loader + 176 | 0;
    $177 = HEAP32[$176 >> 2] | 0;
    $178 = HEAP32[$177 >> 2] | 0;
    $179 = FUNCTION_TABLE_iiiii[$175 & 1023]($3, 0, $170, $178) | 0;
    $180 = ($179 | 0) == 0;
    if ($180) {
      label = 38;
      break;
    } else {
      $error_0 = $179;
      label = 45;
      break;
    }
   case 38:
    $182 = HEAP32[$174 >> 2] | 0;
    $183 = $loader + 224 | 0;
    $184 = HEAP32[$183 >> 2] | 0;
    $185 = HEAP32[$184 >> 2] | 0;
    $186 = $loader + 228 | 0;
    $187 = HEAP32[$186 >> 2] | 0;
    $188 = HEAP32[$187 >> 2] | 0;
    $189 = FUNCTION_TABLE_iiiii[$182 & 1023]($3, 1, $185, $188) | 0;
    $190 = ($189 | 0) == 0;
    if ($190) {
      label = 39;
      break;
    } else {
      $error_0 = $189;
      label = 45;
      break;
    }
   case 39:
    $192 = HEAP32[$174 >> 2] | 0;
    $193 = HEAP32[$168 >> 2] | 0;
    $194 = $193 + ($notdef_index_2 << 2) | 0;
    $195 = HEAP32[$194 >> 2] | 0;
    $196 = HEAP32[$176 >> 2] | 0;
    $197 = $196 + ($notdef_index_2 << 2) | 0;
    $198 = HEAP32[$197 >> 2] | 0;
    $199 = FUNCTION_TABLE_iiiii[$192 & 1023]($3, 2, $195, $198) | 0;
    $200 = ($199 | 0) == 0;
    if ($200) {
      label = 40;
      break;
    } else {
      $error_0 = $199;
      label = 45;
      break;
    }
   case 40:
    $202 = HEAP32[$174 >> 2] | 0;
    $203 = HEAP32[$183 >> 2] | 0;
    $204 = $203 + ($notdef_index_2 << 2) | 0;
    $205 = HEAP32[$204 >> 2] | 0;
    $206 = HEAP32[$186 >> 2] | 0;
    $207 = $206 + ($notdef_index_2 << 2) | 0;
    $208 = HEAP32[$207 >> 2] | 0;
    $209 = FUNCTION_TABLE_iiiii[$202 & 1023]($3, 3, $205, $208) | 0;
    $210 = ($209 | 0) == 0;
    if ($210) {
      label = 41;
      break;
    } else {
      $error_0 = $209;
      label = 45;
      break;
    }
   case 41:
    $212 = $loader + 192 | 0;
    $213 = HEAP32[$212 >> 2] | 0;
    $214 = $loader + 276 | 0;
    $215 = HEAP32[$214 >> 2] | 0;
    $216 = HEAP32[$215 >> 2] | 0;
    $217 = $loader + 280 | 0;
    $218 = HEAP32[$217 >> 2] | 0;
    $219 = HEAP32[$218 >> 2] | 0;
    $220 = FUNCTION_TABLE_iiiii[$213 & 1023]($2, $notdef_index_2, $216, $219) | 0;
    $221 = ($220 | 0) == 0;
    if ($221) {
      label = 42;
      break;
    } else {
      $error_0 = $220;
      label = 45;
      break;
    }
   case 42:
    $223 = $loader + 244 | 0;
    $224 = HEAP32[$223 >> 2] | 0;
    $225 = HEAP32[$214 >> 2] | 0;
    $226 = $225 + 4 | 0;
    $227 = HEAP32[$226 >> 2] | 0;
    $228 = HEAP32[$217 >> 2] | 0;
    $229 = $228 + 4 | 0;
    $230 = HEAP32[$229 >> 2] | 0;
    $231 = FUNCTION_TABLE_iiiii[$224 & 1023]($1, $notdef_index_2, $227, $230) | 0;
    $232 = ($231 | 0) == 0;
    if ($232) {
      label = 43;
      break;
    } else {
      $error_0 = $231;
      label = 45;
      break;
    }
   case 43:
    $234 = HEAP32[$212 >> 2] | 0;
    $235 = HEAP32[$214 >> 2] | 0;
    $236 = $235 + 8 | 0;
    $237 = HEAP32[$236 >> 2] | 0;
    $238 = HEAP32[$217 >> 2] | 0;
    $239 = $238 + 8 | 0;
    $240 = HEAP32[$239 >> 2] | 0;
    $241 = FUNCTION_TABLE_iiiii[$234 & 1023]($2, 0, $237, $240) | 0;
    $242 = ($241 | 0) == 0;
    if ($242) {
      label = 44;
      break;
    } else {
      $error_0 = $241;
      label = 45;
      break;
    }
   case 44:
    $244 = HEAP32[$223 >> 2] | 0;
    $245 = HEAP32[$214 >> 2] | 0;
    $246 = $245 + 12 | 0;
    $247 = HEAP32[$246 >> 2] | 0;
    $248 = HEAP32[$217 >> 2] | 0;
    $249 = $248 + 12 | 0;
    $250 = HEAP32[$249 >> 2] | 0;
    $251 = FUNCTION_TABLE_iiiii[$244 & 1023]($1, 0, $247, $250) | 0;
    $252 = ($251 | 0) == 0;
    if ($252) {
      label = 46;
      break;
    } else {
      $error_0 = $251;
      label = 45;
      break;
    }
   case 45:
    $253 = $loader + 12 | 0;
    HEAP32[$253 >> 2] = $error_0;
    label = 46;
    break;
   case 46:
    return;
  }
}
function _t42_is_space($c) {
  $c = $c | 0;
  var $2 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    if (($c << 24 >> 24 | 0) == 32 | ($c << 24 >> 24 | 0) == 9 | ($c << 24 >> 24 | 0) == 13 | ($c << 24 >> 24 | 0) == 10 | ($c << 24 >> 24 | 0) == 12 | ($c << 24 >> 24 | 0) == 0) {
      $2 = 1;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $2 = 0;
    label = 3;
    break;
   case 3:
    return $2 | 0;
  }
  return 0;
}
function _t42_ps_has_glyph_names($face) {
  $face = $face | 0;
  return 1;
}
function _t42_ps_get_font_extra($face, $afont_extra) {
  $face = $face | 0;
  $afont_extra = $afont_extra | 0;
  HEAP16[$afont_extra >> 1] = HEAP16[$face + 164 >> 1] | 0;
  return 0;
}
function _t42_get_ps_font_name($face) {
  $face = $face | 0;
  return HEAP32[$face + 364 >> 2] | 0;
}
function _t42_parse_sfnts($face, $loader) {
  $face = $face | 0;
  $loader = $loader | 0;
  var $error = 0, $real_size = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $num_tables_0167 = 0, $count_0166 = 0, $status_0165 = 0, $allocated_0164 = 0, $string_buf_0163 = 0, $old_string_size_0162 = 0, $string_size_0161 = 0, $ttf_size_0160 = 0, $36 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $65 = 0, $66 = 0, $67 = 0, $70 = 0, $71 = 0, $72 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $81 = 0, $82 = 0, $string_size_1 = 0, $old_string_size_1 = 0, $string_buf_1 = 0, $allocated_1 = 0, $84 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $92 = 0, $93 = 0, $_string_size_1 = 0, $string_size_2 = 0, $95 = 0, $96 = 0, $num_tables_1110 = 0, $count_1108 = 0, $status_1107 = 0, $n_0104 = 0, $ttf_size_1103 = 0, $99 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $ttf_size_2 = 0, $num_tables_2 = 0, $122 = 0, $123 = 0, $124 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $i_093 = 0, $ttf_size_392 = 0, $132 = 0, $_sum88 = 0, $_sum = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $_sum89 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $_sum90 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $_sum91 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $exitcond = 0, $ttf_size_3_lcssa = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $ttf_size_4 = 0, $num_tables_3 = 0, $163 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $ttf_size_5 = 0, $status_4 = 0, $count_2 = 0, $num_tables_4 = 0, $172 = 0, $173 = 0, $num_tables_1_lcssa = 0, $count_1_lcssa = 0, $status_1_lcssa = 0, $ttf_size_1_lcssa = 0, $174 = 0, $175 = 0, $176 = 0, $allocated_0_lcssa = 0, $string_buf_0_lcssa = 0, $string_buf_2 = 0, $allocated_2 = 0, $177 = 0, $178 = 0, $string_buf_3 = 0, $allocated_3 = 0, $179 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $real_size = __stackBase__ + 4 | 0;
    $1 = $loader | 0;
    $2 = $loader + 16 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $loader + 8 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $loader + 28 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    FUNCTION_TABLE_vi[$7 & 1023]($1);
    $8 = $loader | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 >>> 0 < $5 >>> 0;
    if ($10) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $12 = $9 + 1 | 0;
    HEAP32[$8 >> 2] = $12;
    $13 = HEAP8[$9] | 0;
    $14 = $13 << 24 >> 24 == 91;
    if ($14) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    HEAP32[$error >> 2] = 3;
    $allocated_2 = 0;
    $string_buf_2 = 0;
    label = 43;
    break;
   case 4:
    $17 = HEAP32[$6 >> 2] | 0;
    FUNCTION_TABLE_vi[$17 & 1023]($1);
    $18 = HEAP32[$8 >> 2] | 0;
    $19 = $18 >>> 0 < $5 >>> 0;
    if ($19) {
      label = 5;
      break;
    } else {
      $string_buf_0_lcssa = 0;
      $allocated_0_lcssa = 0;
      label = 42;
      break;
    }
   case 5:
    $20 = $loader + 36 | 0;
    $21 = $loader + 32 | 0;
    $22 = $loader + 12 | 0;
    $23 = $5;
    $24 = $face + 492 | 0;
    $25 = $face + 492 | 0;
    $26 = $face + 492 | 0;
    $27 = $face + 496 | 0;
    $28 = $face + 492 | 0;
    $29 = $face + 492 | 0;
    $30 = $face + 492 | 0;
    $31 = $loader + 32 | 0;
    $32 = $loader + 12 | 0;
    $33 = $loader + 44 | 0;
    $ttf_size_0160 = 0;
    $string_size_0161 = 0;
    $old_string_size_0162 = 0;
    $string_buf_0163 = 0;
    $allocated_0164 = 0;
    $status_0165 = 0;
    $count_0166 = 0;
    $num_tables_0167 = 0;
    $35 = $18;
    label = 6;
    break;
   case 6:
    $36 = HEAP8[$35] | 0;
    if (($36 << 24 >> 24 | 0) == 93) {
      label = 7;
      break;
    } else if (($36 << 24 >> 24 | 0) == 60) {
      label = 8;
      break;
    } else {
      label = 11;
      break;
    }
   case 7:
    $38 = $35 + 1 | 0;
    HEAP32[$8 >> 2] = $38;
    $allocated_3 = $allocated_0164;
    $string_buf_3 = $string_buf_0163;
    label = 44;
    break;
   case 8:
    $40 = HEAP32[$31 >> 2] | 0;
    FUNCTION_TABLE_vi[$40 & 1023]($1);
    $41 = HEAP32[$32 >> 2] | 0;
    $42 = ($41 | 0) == 0;
    if ($42) {
      label = 9;
      break;
    } else {
      $allocated_3 = $allocated_0164;
      $string_buf_3 = $string_buf_0163;
      label = 44;
      break;
    }
   case 9:
    $44 = HEAP32[$8 >> 2] | 0;
    $45 = $44;
    $46 = $35;
    $47 = $46 ^ -1;
    $48 = $45 + $47 | 0;
    $49 = ($48 | 0) / 2 & -1;
    $50 = _ft_mem_realloc($3, 1, $old_string_size_0162, $49, $string_buf_0163, $error) | 0;
    $51 = HEAP32[$error >> 2] | 0;
    $52 = ($51 | 0) == 0;
    if ($52) {
      label = 10;
      break;
    } else {
      $allocated_2 = $allocated_0164;
      $string_buf_2 = $50;
      label = 43;
      break;
    }
   case 10:
    HEAP32[$8 >> 2] = $35;
    $54 = HEAP32[$33 >> 2] | 0;
    $55 = FUNCTION_TABLE_iiiiii[$54 & 1023]($1, $50, $49, $real_size, 1) | 0;
    $56 = HEAP32[$real_size >> 2] | 0;
    $allocated_1 = 1;
    $string_buf_1 = $50;
    $old_string_size_1 = $49;
    $string_size_1 = $56;
    label = 20;
    break;
   case 11:
    $58 = $36 & 255;
    $59 = $58 - 48 | 0;
    $60 = $59 >>> 0 < 10;
    if ($60) {
      label = 12;
      break;
    } else {
      $allocated_1 = $allocated_0164;
      $string_buf_1 = $string_buf_0163;
      $old_string_size_1 = $old_string_size_0162;
      $string_size_1 = $string_size_0161;
      label = 20;
      break;
    }
   case 12:
    $62 = $allocated_0164 << 24 >> 24 == 0;
    if ($62) {
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    HEAP32[$error >> 2] = 3;
    $allocated_2 = $allocated_0164;
    $string_buf_2 = $string_buf_0163;
    label = 43;
    break;
   case 14:
    $65 = HEAP32[$20 >> 2] | 0;
    $66 = FUNCTION_TABLE_ii[$65 & 1023]($1) | 0;
    $67 = ($66 | 0) < 0;
    if ($67) {
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 15:
    HEAP32[$error >> 2] = 3;
    $allocated_2 = 0;
    $string_buf_2 = $string_buf_0163;
    label = 43;
    break;
   case 16:
    $70 = HEAP32[$21 >> 2] | 0;
    FUNCTION_TABLE_vi[$70 & 1023]($1);
    $71 = HEAP32[$22 >> 2] | 0;
    $72 = ($71 | 0) == 0;
    if ($72) {
      label = 17;
      break;
    } else {
      label = 46;
      break;
    }
   case 17:
    $74 = HEAP32[$8 >> 2] | 0;
    $75 = $74 + 1 | 0;
    $76 = $74;
    $77 = $23 - $76 | 0;
    $78 = ($77 | 0) < ($66 | 0);
    if ($78) {
      label = 18;
      break;
    } else {
      label = 19;
      break;
    }
   case 18:
    HEAP32[$error >> 2] = 3;
    $allocated_2 = $allocated_0164;
    $string_buf_2 = $75;
    label = 43;
    break;
   case 19:
    $81 = $66 + 1 | 0;
    $82 = $74 + $81 | 0;
    HEAP32[$8 >> 2] = $82;
    $allocated_1 = $allocated_0164;
    $string_buf_1 = $75;
    $old_string_size_1 = $old_string_size_0162;
    $string_size_1 = $66;
    label = 20;
    break;
   case 20:
    $84 = ($string_buf_1 | 0) == 0;
    if ($84) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    HEAP32[$error >> 2] = 3;
    $allocated_2 = $allocated_1;
    $string_buf_2 = 0;
    label = 43;
    break;
   case 22:
    $87 = $string_size_1 - 1 | 0;
    $88 = $string_buf_1 + $87 | 0;
    $89 = HEAP8[$88] | 0;
    $90 = $89 << 24 >> 24 == 0;
    if ($90) {
      label = 23;
      break;
    } else {
      $string_size_2 = $string_size_1;
      label = 24;
      break;
    }
   case 23:
    $92 = ($string_size_1 | 0) % 2;
    $93 = ($92 | 0) == 1;
    $_string_size_1 = $93 ? $87 : $string_size_1;
    $string_size_2 = $_string_size_1;
    label = 24;
    break;
   case 24:
    $95 = ($string_size_2 | 0) == 0;
    if ($95) {
      label = 26;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $96 = ($string_size_2 | 0) > 0;
    if ($96) {
      $ttf_size_1103 = $ttf_size_0160;
      $n_0104 = 0;
      $status_1107 = $status_0165;
      $count_1108 = $count_0166;
      $num_tables_1110 = $num_tables_0167;
      label = 27;
      break;
    } else {
      $ttf_size_1_lcssa = $ttf_size_0160;
      $status_1_lcssa = $status_0165;
      $count_1_lcssa = $count_0166;
      $num_tables_1_lcssa = $num_tables_0167;
      label = 41;
      break;
    }
   case 26:
    HEAP32[$error >> 2] = 3;
    $allocated_2 = $allocated_1;
    $string_buf_2 = $string_buf_1;
    label = 43;
    break;
   case 27:
    if (($status_1107 | 0) == 0) {
      label = 28;
      break;
    } else if (($status_1107 | 0) == 1) {
      $num_tables_2 = $num_tables_1110;
      $ttf_size_2 = $ttf_size_1103;
      label = 31;
      break;
    } else if (($status_1107 | 0) == 2) {
      $num_tables_3 = $num_tables_1110;
      $ttf_size_4 = $ttf_size_1103;
      label = 37;
      break;
    } else {
      $num_tables_4 = $num_tables_1110;
      $count_2 = $count_1108;
      $status_4 = $status_1107;
      $ttf_size_5 = $ttf_size_1103;
      label = 40;
      break;
    }
   case 28:
    $99 = $count_1108 >>> 0 < 12;
    if ($99) {
      label = 29;
      break;
    } else {
      label = 30;
      break;
    }
   case 29:
    $101 = $string_buf_1 + $n_0104 | 0;
    $102 = HEAP8[$101] | 0;
    $103 = $count_1108 + 1 | 0;
    $104 = HEAP32[$24 >> 2] | 0;
    $105 = $104 + $count_1108 | 0;
    HEAP8[$105] = $102;
    $num_tables_4 = $num_tables_1110;
    $count_2 = $103;
    $status_4 = $status_1107;
    $ttf_size_5 = $ttf_size_1103;
    label = 40;
    break;
   case 30:
    $107 = HEAP32[$25 >> 2] | 0;
    $108 = $107 + 4 | 0;
    $109 = HEAP8[$108] | 0;
    $110 = $109 & 255;
    $111 = $110 << 4;
    $112 = $107 + 5 | 0;
    $113 = HEAP8[$112] | 0;
    $114 = $113 & 255;
    $115 = $111 + $114 | 0;
    $116 = $115 << 4;
    $117 = $116 | 12;
    $118 = _ft_mem_realloc($3, 1, 12, $117, $107, $error) | 0;
    HEAP32[$25 >> 2] = $118;
    $119 = HEAP32[$error >> 2] | 0;
    $120 = ($119 | 0) == 0;
    if ($120) {
      $num_tables_2 = $115;
      $ttf_size_2 = $117;
      label = 31;
      break;
    } else {
      $allocated_2 = $allocated_1;
      $string_buf_2 = $string_buf_1;
      label = 43;
      break;
    }
   case 31:
    $122 = $count_1108 >>> 0 < $ttf_size_2 >>> 0;
    if ($122) {
      label = 34;
      break;
    } else {
      label = 32;
      break;
    }
   case 32:
    $123 = ($num_tables_2 | 0) > 0;
    if ($123) {
      label = 33;
      break;
    } else {
      $ttf_size_3_lcssa = $ttf_size_2;
      label = 36;
      break;
    }
   case 33:
    $124 = HEAP32[$29 >> 2] | 0;
    $ttf_size_392 = $ttf_size_2;
    $i_093 = 0;
    label = 35;
    break;
   case 34:
    $126 = $string_buf_1 + $n_0104 | 0;
    $127 = HEAP8[$126] | 0;
    $128 = $count_1108 + 1 | 0;
    $129 = HEAP32[$26 >> 2] | 0;
    $130 = $129 + $count_1108 | 0;
    HEAP8[$130] = $127;
    $num_tables_4 = $num_tables_2;
    $count_2 = $128;
    $status_4 = 1;
    $ttf_size_5 = $ttf_size_2;
    label = 40;
    break;
   case 35:
    $132 = $i_093 << 4;
    $_sum88 = $132 | 12;
    $_sum = $_sum88 + 12 | 0;
    $133 = $124 + $_sum | 0;
    $134 = HEAP8[$133] | 0;
    $135 = $134 & 255;
    $136 = $135 << 24;
    $_sum89 = $_sum88 + 13 | 0;
    $137 = $124 + $_sum89 | 0;
    $138 = HEAP8[$137] | 0;
    $139 = $138 & 255;
    $140 = $139 << 16;
    $141 = $140 | $136;
    $_sum90 = $_sum88 + 14 | 0;
    $142 = $124 + $_sum90 | 0;
    $143 = HEAP8[$142] | 0;
    $144 = $143 & 255;
    $145 = $144 << 8;
    $146 = $141 | $145;
    $_sum91 = $_sum88 + 15 | 0;
    $147 = $124 + $_sum91 | 0;
    $148 = HEAP8[$147] | 0;
    $149 = $148 & 255;
    $150 = $146 | $149;
    $151 = $150 + 3 | 0;
    $152 = $151 & -4;
    $153 = $152 + $ttf_size_392 | 0;
    $154 = $i_093 + 1 | 0;
    $exitcond = ($154 | 0) == ($num_tables_2 | 0);
    if ($exitcond) {
      $ttf_size_3_lcssa = $153;
      label = 36;
      break;
    } else {
      $ttf_size_392 = $153;
      $i_093 = $154;
      label = 35;
      break;
    }
   case 36:
    HEAP32[$27 >> 2] = $ttf_size_3_lcssa;
    $155 = $num_tables_2 << 4;
    $156 = $155 | 12;
    $157 = $ttf_size_3_lcssa + 1 | 0;
    $158 = HEAP32[$28 >> 2] | 0;
    $159 = _ft_mem_realloc($3, 1, $156, $157, $158, $error) | 0;
    HEAP32[$28 >> 2] = $159;
    $160 = HEAP32[$error >> 2] | 0;
    $161 = ($160 | 0) == 0;
    if ($161) {
      $num_tables_3 = $num_tables_2;
      $ttf_size_4 = $ttf_size_3_lcssa;
      label = 37;
      break;
    } else {
      $allocated_2 = $allocated_1;
      $string_buf_2 = $string_buf_1;
      label = 43;
      break;
    }
   case 37:
    $163 = $count_1108 >>> 0 < $ttf_size_4 >>> 0;
    if ($163) {
      label = 39;
      break;
    } else {
      label = 38;
      break;
    }
   case 38:
    HEAP32[$error >> 2] = 3;
    $allocated_2 = $allocated_1;
    $string_buf_2 = $string_buf_1;
    label = 43;
    break;
   case 39:
    $166 = $string_buf_1 + $n_0104 | 0;
    $167 = HEAP8[$166] | 0;
    $168 = $count_1108 + 1 | 0;
    $169 = HEAP32[$30 >> 2] | 0;
    $170 = $169 + $count_1108 | 0;
    HEAP8[$170] = $167;
    $num_tables_4 = $num_tables_3;
    $count_2 = $168;
    $status_4 = 2;
    $ttf_size_5 = $ttf_size_4;
    label = 40;
    break;
   case 40:
    $172 = $n_0104 + 1 | 0;
    $173 = ($172 | 0) < ($string_size_2 | 0);
    if ($173) {
      $ttf_size_1103 = $ttf_size_5;
      $n_0104 = $172;
      $status_1107 = $status_4;
      $count_1108 = $count_2;
      $num_tables_1110 = $num_tables_4;
      label = 27;
      break;
    } else {
      $ttf_size_1_lcssa = $ttf_size_5;
      $status_1_lcssa = $status_4;
      $count_1_lcssa = $count_2;
      $num_tables_1_lcssa = $num_tables_4;
      label = 41;
      break;
    }
   case 41:
    $174 = HEAP32[$6 >> 2] | 0;
    FUNCTION_TABLE_vi[$174 & 1023]($1);
    $175 = HEAP32[$8 >> 2] | 0;
    $176 = $175 >>> 0 < $5 >>> 0;
    if ($176) {
      $ttf_size_0160 = $ttf_size_1_lcssa;
      $string_size_0161 = $string_size_2;
      $old_string_size_0162 = $old_string_size_1;
      $string_buf_0163 = $string_buf_1;
      $allocated_0164 = $allocated_1;
      $status_0165 = $status_1_lcssa;
      $count_0166 = $count_1_lcssa;
      $num_tables_0167 = $num_tables_1_lcssa;
      $35 = $175;
      label = 6;
      break;
    } else {
      $string_buf_0_lcssa = $string_buf_1;
      $allocated_0_lcssa = $allocated_1;
      label = 42;
      break;
    }
   case 42:
    HEAP32[$error >> 2] = 3;
    $allocated_2 = $allocated_0_lcssa;
    $string_buf_2 = $string_buf_0_lcssa;
    label = 43;
    break;
   case 43:
    $177 = HEAP32[$error >> 2] | 0;
    $178 = $loader + 12 | 0;
    HEAP32[$178 >> 2] = $177;
    $allocated_3 = $allocated_2;
    $string_buf_3 = $string_buf_2;
    label = 44;
    break;
   case 44:
    $179 = $allocated_3 << 24 >> 24 == 0;
    if ($179) {
      label = 46;
      break;
    } else {
      label = 45;
      break;
    }
   case 45:
    _ft_mem_free($3, $string_buf_3);
    label = 46;
    break;
   case 46:
    STACKTOP = __stackBase__;
    return;
  }
}
function _t42_ps_get_font_info($face, $afont_info) {
  $face = $face | 0;
  $afont_info = $afont_info | 0;
  _memcpy($afont_info | 0, $face + 132 | 0, 32);
  return 0;
}
function _t42_ps_get_font_private($face, $afont_private) {
  $face = $face | 0;
  $afont_private = $afont_private | 0;
  _memcpy($afont_private | 0, $face + 168 | 0, 196);
  return 0;
}
function _t42_get_glyph_name($face, $glyph_index, $buffer, $buffer_max) {
  $face = $face | 0;
  $glyph_index = $glyph_index | 0;
  $buffer = $buffer | 0;
  $buffer_max = $buffer_max | 0;
  _ft_mem_strcpyn($buffer, HEAP32[(HEAP32[$face + 420 >> 2] | 0) + ($glyph_index << 2) >> 2] | 0, $buffer_max);
  return 0;
}
function _t42_get_name_index($face, $glyph_name) {
  $face = $face | 0;
  $glyph_name = $glyph_name | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $i_011 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 416 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) > 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 7;
      break;
    }
   case 2:
    $4 = $face + 420 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = HEAP8[$glyph_name] | 0;
    $i_011 = 0;
    label = 3;
    break;
   case 3:
    $8 = $5 + ($i_011 << 2) | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = HEAP8[$9] | 0;
    $11 = $6 << 24 >> 24 == $10 << 24 >> 24;
    if ($11) {
      label = 4;
      break;
    } else {
      label = 6;
      break;
    }
   case 4:
    $13 = _strcmp($glyph_name | 0, $9 | 0) | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $16 = $face + 424 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $17 + ($i_011 << 2) | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = _atoi($19 | 0) | 0;
    $_0 = $20;
    label = 7;
    break;
   case 6:
    $22 = $i_011 + 1 | 0;
    $23 = HEAP32[$1 >> 2] | 0;
    $24 = ($22 | 0) < ($23 | 0);
    if ($24) {
      $i_011 = $22;
      label = 3;
      break;
    } else {
      $_0 = 0;
      label = 7;
      break;
    }
   case 7:
    return $_0 | 0;
  }
  return 0;
}
function _winfnt_get_service($driver, $service_id) {
  $driver = $driver | 0;
  $service_id = $service_id | 0;
  return _ft_service_list_lookup(5243080, $service_id) | 0;
}
function _FNT_Face_Init($stream, $face, $face_index, $num_params, $params) {
  $stream = $stream | 0;
  $face = $face | 0;
  $face_index = $face_index | 0;
  $num_params = $num_params | 0;
  $params = $params | 0;
  var $error = 0, $charmap = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $or_cond = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $_pr = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $96 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $$etemp$0$0 = 0, $$etemp$0$1 = 0, $st$1$0 = 0, $st$2$1 = 0, $108 = 0, $109 = 0, $110 = 0, $112 = 0, $114 = 0, $115 = 0, $116 = 0, $118 = 0, $119 = 0, $120 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $177 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $charmap = __stackBase__ + 4 | 0;
    $1 = $face | 0;
    $2 = $face + 100 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = _fnt_face_get_dll_font($face, $face_index) | 0;
    HEAP32[$error >> 2] = $4;
    $5 = ($4 | 0) == 0;
    $6 = ($face_index | 0) < 0;
    $or_cond = $5 & $6;
    if ($or_cond) {
      label = 34;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = ($4 | 0) == 2;
    if ($8) {
      label = 3;
      break;
    } else {
      label = 8;
      break;
    }
   case 3:
    $10 = _ft_mem_alloc($3, 172, $error) | 0;
    $11 = $10;
    $12 = $face + 132 | 0;
    HEAP32[$12 >> 2] = $11;
    $13 = HEAP32[$error >> 2] | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 4;
      break;
    } else {
      label = 34;
      break;
    }
   case 4:
    $16 = $face | 0;
    HEAP32[$16 >> 2] = 1;
    $17 = HEAP32[$12 >> 2] | 0;
    $18 = $17 | 0;
    HEAP32[$18 >> 2] = 0;
    $19 = $stream + 4 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $17 + 164 | 0;
    HEAP32[$21 >> 2] = $20;
    $22 = _fnt_font_load($17, $stream) | 0;
    HEAP32[$error >> 2] = $22;
    $23 = ($22 | 0) == 0;
    if ($23) {
      label = 5;
      break;
    } else {
      label = 33;
      break;
    }
   case 5:
    $25 = ($face_index | 0) > 0;
    if ($25) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    HEAP32[$error >> 2] = 6;
    label = 33;
    break;
   case 7:
    if ($6) {
      label = 34;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $_pr = HEAP32[$error >> 2] | 0;
    $29 = ($_pr | 0) == 0;
    if ($29) {
      label = 9;
      break;
    } else {
      label = 33;
      break;
    }
   case 9:
    $31 = $face + 132 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $face + 4 | 0;
    HEAP32[$33 >> 2] = $face_index;
    $34 = $face + 8 | 0;
    HEAP32[$34 >> 2] = 18;
    $35 = $32 + 100 | 0;
    $36 = HEAP16[$35 >> 1] | 0;
    $37 = $32 + 102 | 0;
    $38 = HEAP16[$37 >> 1] | 0;
    $39 = $36 << 16 >> 16 == $38 << 16 >> 16;
    if ($39) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    HEAP32[$34 >> 2] = 22;
    label = 11;
    break;
   case 11:
    $42 = $32 + 86 | 0;
    $43 = HEAP8[$42] | 0;
    $44 = $43 << 24 >> 24 == 0;
    if ($44) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $46 = $face + 12 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $47 | 1;
    HEAP32[$46 >> 2] = $48;
    label = 13;
    break;
   case 13:
    $50 = $32 + 90 | 0;
    $51 = HEAP16[$50 >> 1] | 0;
    $52 = ($51 & 65535) > 799;
    if ($52) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $54 = $face + 12 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = $55 | 2;
    HEAP32[$54 >> 2] = $56;
    label = 15;
    break;
   case 15:
    $58 = _ft_mem_realloc($3, 16, 0, 1, 0, $error) | 0;
    $59 = $58;
    $60 = $face + 32 | 0;
    HEAP32[$60 >> 2] = $59;
    $61 = HEAP32[$error >> 2] | 0;
    $62 = ($61 | 0) == 0;
    if ($62) {
      label = 16;
      break;
    } else {
      label = 33;
      break;
    }
   case 16:
    $64 = $face + 28 | 0;
    HEAP32[$64 >> 2] = 1;
    $65 = HEAP32[$60 >> 2] | 0;
    $66 = HEAP16[$35 >> 1] | 0;
    $67 = $65 + 2 | 0;
    HEAP16[$67 >> 1] = $66;
    $68 = $32 + 96 | 0;
    $69 = HEAP16[$68 >> 1] | 0;
    $70 = $32 + 84 | 0;
    $71 = HEAP16[$70 >> 1] | 0;
    $72 = $71 + $69 & 65535;
    $73 = $65 | 0;
    HEAP16[$73 >> 1] = $72;
    $74 = $32 + 74 | 0;
    $75 = HEAP16[$74 >> 1] | 0;
    $76 = $75 & 65535;
    $77 = $76 << 6;
    $78 = $65 + 4 | 0;
    HEAP32[$78 >> 2] = $77;
    $79 = $32 + 78 | 0;
    $80 = HEAP16[$79 >> 1] | 0;
    $81 = $80 << 16 >> 16 == 0;
    $82 = $32 + 76 | 0;
    $83 = HEAP16[$82 >> 1] | 0;
    $84 = $83 << 16 >> 16 == 0;
    $85 = $83 & 65535;
    $86 = $84 ? 72 : $85;
    $87 = _FT_MulDiv($77, $86, 72) | 0;
    $88 = $65 + 12 | 0;
    $89 = $87 + 32 | 0;
    $90 = $89 & -64;
    HEAP32[$88 >> 2] = $90;
    $91 = HEAP16[$68 >> 1] | 0;
    $92 = $91 & 65535;
    $93 = $92 << 6;
    $94 = ($90 | 0) > ($93 | 0);
    if ($94) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    HEAP32[$88 >> 2] = $93;
    $96 = _FT_MulDiv($93, 72, $86) | 0;
    HEAP32[$78 >> 2] = $96;
    label = 18;
    break;
   case 18:
    $98 = HEAP32[$78 >> 2] | 0;
    $99 = $80 & 65535;
    $100 = $81 ? 72 : $99;
    $101 = _FT_MulDiv($98, $100, 72) | 0;
    $102 = $65 + 8 | 0;
    $103 = $101 + 32 | 0;
    $104 = $103 & -64;
    HEAP32[$102 >> 2] = $104;
    $105 = $charmap + 4 | 0;
    $106 = $charmap | 0;
    $107 = $105;
    $$etemp$0$0 = 0;
    $$etemp$0$1 = 0;
    $st$1$0 = $107 | 0;
    HEAP32[$st$1$0 >> 2] = $$etemp$0$0;
    $st$2$1 = $107 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $$etemp$0$1;
    HEAP32[$106 >> 2] = $1;
    $108 = $32 + 92 | 0;
    $109 = HEAP8[$108] | 0;
    $110 = $109 << 24 >> 24 == 77;
    if ($110) {
      label = 19;
      break;
    } else {
      label = 20;
      break;
    }
   case 19:
    $112 = $charmap + 8 | 0;
    HEAP32[$105 >> 2] = 1634889070;
    HEAP16[$112 >> 1] = 1;
    label = 20;
    break;
   case 20:
    $114 = $charmap;
    $115 = _FT_CMap_New(5312012, 0, $114, 0) | 0;
    HEAP32[$error >> 2] = $115;
    $116 = ($115 | 0) == 0;
    if ($116) {
      label = 21;
      break;
    } else {
      label = 33;
      break;
    }
   case 21:
    $118 = $face + 36 | 0;
    $119 = HEAP32[$118 >> 2] | 0;
    $120 = ($119 | 0) == 0;
    if ($120) {
      label = 23;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $122 = $face + 40 | 0;
    $123 = HEAP32[$122 >> 2] | 0;
    $124 = HEAP32[$123 >> 2] | 0;
    $125 = $face + 92 | 0;
    HEAP32[$125 >> 2] = $124;
    label = 23;
    break;
   case 23:
    $127 = $32 + 105 | 0;
    $128 = HEAP8[$127] | 0;
    $129 = $128 & 255;
    $130 = $32 + 104 | 0;
    $131 = HEAP8[$130] | 0;
    $132 = $131 & 255;
    $133 = $129 + 2 | 0;
    $134 = $133 - $132 | 0;
    $135 = $face + 16 | 0;
    HEAP32[$135 >> 2] = $134;
    $136 = $32 + 116 | 0;
    $137 = HEAP32[$136 >> 2] | 0;
    $138 = $32 + 8 | 0;
    $139 = HEAP32[$138 >> 2] | 0;
    $140 = $137 >>> 0 < $139 >>> 0;
    if ($140) {
      label = 25;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    HEAP32[$error >> 2] = 3;
    label = 33;
    break;
   case 25:
    $143 = $139 - $137 | 0;
    $144 = $143 + 1 | 0;
    $145 = _ft_mem_alloc($3, $144, $error) | 0;
    $146 = $32 + 168 | 0;
    HEAP32[$146 >> 2] = $145;
    $147 = HEAP32[$error >> 2] | 0;
    $148 = ($147 | 0) == 0;
    if ($148) {
      label = 26;
      break;
    } else {
      label = 33;
      break;
    }
   case 26:
    $150 = $32 + 160 | 0;
    $151 = HEAP32[$150 >> 2] | 0;
    $152 = HEAP32[$136 >> 2] | 0;
    $153 = $151 + $152 | 0;
    _memcpy($145 | 0, $153 | 0, $143 | 0);
    $154 = HEAP32[$146 >> 2] | 0;
    $155 = $154 + $143 | 0;
    HEAP8[$155] = 0;
    $156 = HEAP32[$146 >> 2] | 0;
    $157 = _strlen($156 | 0) | 0;
    $158 = $157 + 1 | 0;
    $159 = _ft_mem_realloc($3, 1, $143, $158, $156, $error) | 0;
    HEAP32[$146 >> 2] = $159;
    $160 = HEAP32[$error >> 2] | 0;
    $161 = ($160 | 0) == 0;
    if ($161) {
      label = 27;
      break;
    } else {
      label = 33;
      break;
    }
   case 27:
    $163 = $face + 20 | 0;
    HEAP32[$163 >> 2] = $159;
    $164 = $face + 24 | 0;
    HEAP32[$164 >> 2] = 5324280;
    $165 = $face + 12 | 0;
    $166 = HEAP32[$165 >> 2] | 0;
    $167 = $166 & 2;
    $168 = ($167 | 0) == 0;
    $169 = $166 & 1;
    $170 = ($169 | 0) != 0;
    if ($168) {
      label = 31;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    if ($170) {
      label = 29;
      break;
    } else {
      label = 30;
      break;
    }
   case 29:
    HEAP32[$164 >> 2] = 5323308;
    label = 34;
    break;
   case 30:
    HEAP32[$164 >> 2] = 5322480;
    label = 34;
    break;
   case 31:
    if ($170) {
      label = 32;
      break;
    } else {
      label = 34;
      break;
    }
   case 32:
    HEAP32[$164 >> 2] = 5321860;
    label = 34;
    break;
   case 33:
    _FNT_Face_Done($face);
    label = 34;
    break;
   case 34:
    $177 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $177 | 0;
  }
  return 0;
}
function _FNT_Face_Done($face) {
  $face = $face | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($face | 0) == 0;
    if ($1) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $face + 100 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    _fnt_font_done($face);
    $5 = $face + 32 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6;
    _ft_mem_free($4, $7);
    HEAP32[$5 >> 2] = 0;
    $8 = $face + 28 | 0;
    HEAP32[$8 >> 2] = 0;
    label = 3;
    break;
   case 3:
    return;
  }
}
function _FNT_Load_Glyph($slot, $size, $glyph_index, $load_flags) {
  $slot = $slot | 0;
  $size = $size | 0;
  $glyph_index = $glyph_index | 0;
  $load_flags = $load_flags | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $16 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $_0 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $_sum = 0, $32 = 0, $_sum6869 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $_sum74 = 0, $42 = 0, $_sum75 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $_sum76 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $_sum77 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $_sum72 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $offset_0 = 0, $70 = 0, $71 = 0, $72 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $column_082 = 0, $pitch_081 = 0, $p_080 = 0, $102 = 0, $103 = 0, $104 = 0, $write_079 = 0, $p_178 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $p_1_lcssa = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $139 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    HEAP32[$error >> 2] = 6;
    label = 22;
    break;
   case 3:
    $6 = $2 + 132 | 0;
    $7 = $6;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $11 = $2 + 16 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 >>> 0 > $glyph_index >>> 0;
    if ($13) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    HEAP32[$error >> 2] = 6;
    label = 22;
    break;
   case 6:
    $16 = ($glyph_index | 0) == 0;
    if ($16) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $18 = $glyph_index - 1 | 0;
    $_0 = $18;
    label = 9;
    break;
   case 8:
    $20 = $8 + 106 | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $21 & 255;
    $_0 = $22;
    label = 9;
    break;
   case 9:
    $24 = $8 + 4 | 0;
    $25 = HEAP16[$24 >> 1] | 0;
    $26 = $25 << 16 >> 16 == 768;
    $27 = $26 ? 6 : 4;
    $28 = $8 + 160 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $26 ? 148 : 118;
    $31 = Math_imul($27, $_0);
    $_sum = $31 + $30 | 0;
    $32 = $29 + $_sum | 0;
    $_sum6869 = $_sum | 1;
    $33 = $29 + $_sum6869 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $35 << 8;
    $37 = HEAP8[$32] | 0;
    $38 = $37 & 255;
    $39 = $36 | $38;
    $40 = $39 << 16 >> 16;
    $41 = $slot + 80 | 0;
    HEAP32[$41 >> 2] = $40;
    $_sum74 = $_sum + 2 | 0;
    $42 = $29 + $_sum74 | 0;
    if ($26) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $_sum75 = $_sum + 5 | 0;
    $44 = $29 + $_sum75 | 0;
    $45 = HEAP8[$44] | 0;
    $46 = $45 & 255;
    $47 = $46 << 24;
    $_sum76 = $_sum + 4 | 0;
    $48 = $29 + $_sum76 | 0;
    $49 = HEAP8[$48] | 0;
    $50 = $49 & 255;
    $51 = $50 << 16;
    $52 = $51 | $47;
    $_sum77 = $_sum + 3 | 0;
    $53 = $29 + $_sum77 | 0;
    $54 = HEAP8[$53] | 0;
    $55 = $54 & 255;
    $56 = $55 << 8;
    $57 = $52 | $56;
    $58 = HEAP8[$42] | 0;
    $59 = $58 & 255;
    $60 = $57 | $59;
    $offset_0 = $60;
    label = 12;
    break;
   case 11:
    $_sum72 = $_sum + 3 | 0;
    $62 = $29 + $_sum72 | 0;
    $63 = HEAP8[$62] | 0;
    $64 = $63 & 255;
    $65 = $64 << 8;
    $66 = HEAP8[$42] | 0;
    $67 = $66 & 255;
    $68 = $65 | $67;
    $offset_0 = $68;
    label = 12;
    break;
   case 12:
    $70 = $8 + 8 | 0;
    $71 = HEAP32[$70 >> 2] | 0;
    $72 = $offset_0 >>> 0 < $71 >>> 0;
    if ($72) {
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    HEAP32[$error >> 2] = 3;
    label = 22;
    break;
   case 14:
    $75 = HEAP32[$28 >> 2] | 0;
    $76 = $slot + 4 | 0;
    $77 = HEAP32[$76 >> 2] | 0;
    $78 = $77 + 100 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = HEAP32[$41 >> 2] | 0;
    $81 = $80 + 7 | 0;
    $82 = $81 >> 3;
    $83 = $slot + 84 | 0;
    HEAP32[$83 >> 2] = $82;
    $84 = $8 + 96 | 0;
    $85 = HEAP16[$84 >> 1] | 0;
    $86 = $85 & 65535;
    $87 = $slot + 76 | 0;
    HEAP32[$87 >> 2] = $86;
    $88 = $slot + 94 | 0;
    HEAP8[$88] = 1;
    $89 = HEAP32[$87 >> 2] | 0;
    $90 = Math_imul($82, $89);
    $91 = $90 + $offset_0 | 0;
    $92 = HEAP32[$70 >> 2] | 0;
    $93 = $91 >>> 0 < $92 >>> 0;
    if ($93) {
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    HEAP32[$error >> 2] = 3;
    label = 22;
    break;
   case 16:
    $96 = _ft_mem_realloc($79, $89, 0, $82, 0, $error) | 0;
    $97 = $slot + 88 | 0;
    HEAP32[$97 >> 2] = $96;
    $98 = HEAP32[$error >> 2] | 0;
    $99 = ($98 | 0) == 0;
    if ($99) {
      label = 17;
      break;
    } else {
      label = 22;
      break;
    }
   case 17:
    $100 = $75 + $offset_0 | 0;
    $101 = ($82 | 0) > 0;
    if ($101) {
      $p_080 = $100;
      $pitch_081 = $82;
      $column_082 = $96;
      label = 18;
      break;
    } else {
      label = 21;
      break;
    }
   case 18:
    $102 = HEAP32[$87 >> 2] | 0;
    $103 = $p_080 + $102 | 0;
    $104 = ($102 | 0) > 0;
    if ($104) {
      $p_178 = $p_080;
      $write_079 = $column_082;
      label = 19;
      break;
    } else {
      $p_1_lcssa = $p_080;
      label = 20;
      break;
    }
   case 19:
    $105 = HEAP8[$p_178] | 0;
    HEAP8[$write_079] = $105;
    $106 = $p_178 + 1 | 0;
    $107 = HEAP32[$83 >> 2] | 0;
    $108 = $write_079 + $107 | 0;
    $109 = $106 >>> 0 < $103 >>> 0;
    if ($109) {
      $p_178 = $106;
      $write_079 = $108;
      label = 19;
      break;
    } else {
      $p_1_lcssa = $106;
      label = 20;
      break;
    }
   case 20:
    $110 = $pitch_081 - 1 | 0;
    $111 = $column_082 + 1 | 0;
    $112 = ($110 | 0) > 0;
    if ($112) {
      $p_080 = $p_1_lcssa;
      $pitch_081 = $110;
      $column_082 = $111;
      label = 18;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $113 = $slot + 156 | 0;
    $114 = HEAP32[$113 >> 2] | 0;
    $115 = $114 + 4 | 0;
    HEAP32[$115 >> 2] = 1;
    $116 = $slot + 100 | 0;
    HEAP32[$116 >> 2] = 0;
    $117 = $8 + 80 | 0;
    $118 = HEAP16[$117 >> 1] | 0;
    $119 = $118 & 65535;
    $120 = $slot + 104 | 0;
    HEAP32[$120 >> 2] = $119;
    $121 = $slot + 72 | 0;
    HEAP32[$121 >> 2] = 1651078259;
    $122 = HEAP32[$41 >> 2] | 0;
    $123 = $122 << 6;
    $124 = $slot + 24 | 0;
    $125 = $124 | 0;
    HEAP32[$125 >> 2] = $123;
    $126 = HEAP32[$87 >> 2] | 0;
    $127 = $126 << 6;
    $128 = $slot + 28 | 0;
    HEAP32[$128 >> 2] = $127;
    $129 = HEAP32[$41 >> 2] | 0;
    $130 = $129 << 6;
    $131 = $slot + 40 | 0;
    HEAP32[$131 >> 2] = $130;
    $132 = $slot + 32 | 0;
    HEAP32[$132 >> 2] = 0;
    $133 = HEAP32[$120 >> 2] | 0;
    $134 = $133 << 6;
    $135 = $slot + 36 | 0;
    HEAP32[$135 >> 2] = $134;
    $136 = HEAP32[$87 >> 2] | 0;
    $137 = $136 << 6;
    _ft_synthesize_vertical_metrics($124, $137);
    label = 22;
    break;
   case 22:
    $139 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $139 | 0;
  }
  return 0;
}
function _FNT_Size_Request($size, $req) {
  $size = $size | 0;
  $req = $req | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $_sink12 = 0, $33 = 0, $_ = 0, $35 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 132 | 0;
    $4 = $3;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $2 + 32 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $req + 16 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    $11 = $req + 8 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    if ($10) {
      $18 = $12;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $14 = Math_imul($12, $9);
    $15 = $14 + 36 | 0;
    $16 = ($15 | 0) / 72 & -1;
    $18 = $16;
    label = 3;
    break;
   case 3:
    $19 = $18 + 32 | 0;
    $20 = $19 >> 6;
    $21 = $req | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    if (($22 | 0) == 0) {
      label = 4;
      break;
    } else if (($22 | 0) == 1) {
      label = 5;
      break;
    } else {
      $_0 = 7;
      label = 8;
      break;
    }
   case 4:
    $24 = $7 + 12 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $25 + 32 | 0;
    $27 = $26 >> 6;
    $_sink12 = $27;
    label = 6;
    break;
   case 5:
    $29 = $5 + 96 | 0;
    $30 = HEAP16[$29 >> 1] | 0;
    $31 = $30 & 65535;
    $_sink12 = $31;
    label = 6;
    break;
   case 6:
    $33 = ($20 | 0) == ($_sink12 | 0);
    $_ = $33 ? 0 : 23;
    if ($33) {
      label = 7;
      break;
    } else {
      $_0 = $_;
      label = 8;
      break;
    }
   case 7:
    $35 = _FNT_Size_Select($size) | 0;
    $_0 = 0;
    label = 8;
    break;
   case 8:
    return $_0 | 0;
  }
  return 0;
}
function _FNT_Size_Select($size) {
  $size = $size | 0;
  var $2 = 0, $5 = 0, $7 = 0;
  $2 = HEAP32[$size >> 2] | 0;
  $5 = HEAP32[$2 + 132 >> 2] | 0;
  _FT_Select_Metrics($2, 0);
  $7 = $5 + 80 | 0;
  HEAP32[$size + 24 >> 2] = (HEAPU16[$7 >> 1] | 0) << 6;
  HEAP32[$size + 28 >> 2] = (HEAPU16[$7 >> 1] | 0) - (HEAPU16[$5 + 96 >> 1] | 0) << 6;
  HEAP32[$size + 36 >> 2] = (HEAPU16[$5 + 102 >> 1] | 0) << 6;
  return 0;
}
function _fnt_font_done($face) {
  $face = $face | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $14 = 0, $15 = 0, $16 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 104 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $face + 132 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = $6 + 160 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    _FT_Stream_ReleaseFrame($4, $9);
    label = 4;
    break;
   case 4:
    $14 = $6 + 168 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    _ft_mem_free($2, $15);
    HEAP32[$14 >> 2] = 0;
    $16 = $6;
    _ft_mem_free($2, $16);
    HEAP32[$5 >> 2] = 0;
    label = 5;
    break;
   case 5:
    return;
  }
}
function _fnt_face_get_dll_font($face, $face_index) {
  $face = $face | 0;
  $face_index = $face_index | 0;
  var $error = 0, $mz_header = 0, $ne_header = 0, $pe32_header = 0, $pe32_section = 0, $root_dir = 0, $name_dir = 0, $lang_dir = 0, $dir_entry1 = 0, $dir_entry2 = 0, $dir_entry3 = 0, $data_entry = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $font_offset_0 = 0, $font_count_0 = 0, $75 = 0, $76 = 0, $or_cond = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $86 = 0, $87 = 0, $90 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $102 = 0, $103 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $127 = 0, $128 = 0, $129 = 0, $131 = 0, $132 = 0, $133 = 0, $135 = 0, $136 = 0, $137 = 0, $139 = 0, $140 = 0, $141 = 0, $143 = 0, $144 = 0, $145 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $i_0 = 0, $156 = 0, $158 = 0, $159 = 0, $161 = 0, $162 = 0, $163 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $171 = 0, $172 = 0, $173 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $211 = 0, $i_189 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $217 = 0, $218 = 0, $220 = 0, $221 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $229 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $246 = 0, $j_084 = 0, $247 = 0, $248 = 0, $249 = 0, $250 = 0, $252 = 0, $253 = 0, $255 = 0, $256 = 0, $259 = 0, $260 = 0, $261 = 0, $262 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $281 = 0, $k_080 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $287 = 0, $288 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $298 = 0, $299 = 0, $301 = 0, $302 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $309 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $320 = 0, $321 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $337 = 0, $_pr = 0, $340 = 0, $341 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 144 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $mz_header = __stackBase__ + 4 | 0;
    $ne_header = __stackBase__ + 8 | 0;
    $pe32_header = __stackBase__ + 16 | 0;
    $pe32_section = __stackBase__ + 36 | 0;
    $root_dir = __stackBase__ + 56 | 0;
    $name_dir = __stackBase__ + 72 | 0;
    $lang_dir = __stackBase__ + 88 | 0;
    $dir_entry1 = __stackBase__ + 104 | 0;
    $dir_entry2 = __stackBase__ + 112 | 0;
    $dir_entry3 = __stackBase__ + 120 | 0;
    $data_entry = __stackBase__ + 128 | 0;
    $1 = $face + 104 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 100 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $face + 132 | 0;
    HEAP32[$5 >> 2] = 0;
    $6 = _FT_Stream_Seek($2, 0) | 0;
    HEAP32[$error >> 2] = $6;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 2;
      break;
    } else {
      label = 77;
      break;
    }
   case 2:
    $9 = $mz_header;
    $10 = _FT_Stream_ReadFields($2, 5243060, $9) | 0;
    HEAP32[$error >> 2] = $10;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 3;
      break;
    } else {
      label = 77;
      break;
    }
   case 3:
    HEAP32[$error >> 2] = 2;
    $13 = $mz_header | 0;
    $14 = HEAP16[$13 >> 1] | 0;
    $15 = $14 << 16 >> 16 == 23117;
    if ($15) {
      label = 4;
      break;
    } else {
      label = 76;
      break;
    }
   case 4:
    $17 = $mz_header + 2 | 0;
    $18 = HEAP16[$17 >> 1] | 0;
    $19 = $18 & 65535;
    $20 = _FT_Stream_Seek($2, $19) | 0;
    HEAP32[$error >> 2] = $20;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 5;
      break;
    } else {
      label = 77;
      break;
    }
   case 5:
    $23 = $ne_header;
    $24 = _FT_Stream_ReadFields($2, 5243036, $23) | 0;
    HEAP32[$error >> 2] = $24;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 6;
      break;
    } else {
      label = 77;
      break;
    }
   case 6:
    HEAP32[$error >> 2] = 2;
    $27 = $ne_header | 0;
    $28 = HEAP16[$27 >> 1] | 0;
    if (($28 << 16 >> 16 | 0) == 17742) {
      label = 7;
      break;
    } else if (($28 << 16 >> 16 | 0) == 17744) {
      label = 25;
      break;
    } else {
      label = 71;
      break;
    }
   case 7:
    $30 = HEAP16[$17 >> 1] | 0;
    $31 = $30 & 65535;
    $32 = $ne_header + 2 | 0;
    $33 = HEAP16[$32 >> 1] | 0;
    $34 = $33 & 65535;
    $35 = $34 + $31 | 0;
    $36 = _FT_Stream_Seek($2, $35) | 0;
    HEAP32[$error >> 2] = $36;
    $37 = ($36 | 0) == 0;
    if ($37) {
      label = 8;
      break;
    } else {
      label = 77;
      break;
    }
   case 8:
    $39 = $ne_header + 4 | 0;
    $40 = HEAP16[$39 >> 1] | 0;
    $41 = $40 & 65535;
    $42 = HEAP16[$32 >> 1] | 0;
    $43 = $42 & 65535;
    $44 = $41 - $43 | 0;
    $45 = _FT_Stream_EnterFrame($2, $44) | 0;
    HEAP32[$error >> 2] = $45;
    $46 = ($45 | 0) == 0;
    if ($46) {
      label = 9;
      break;
    } else {
      label = 77;
      break;
    }
   case 9:
    $48 = _FT_Stream_GetShortLE($2) | 0;
    $49 = _FT_Stream_GetShortLE($2) | 0;
    $50 = $49 << 16 >> 16 == 0;
    if ($50) {
      $font_count_0 = 0;
      $font_offset_0 = 0;
      label = 14;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $51 = $2 + 32 | 0;
    $53 = $49;
    label = 11;
    break;
   case 11:
    $54 = _FT_Stream_GetShortLE($2) | 0;
    $55 = $53 << 16 >> 16 == -32760;
    if ($55) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $57 = _FT_Stream_Pos($2) | 0;
    $58 = $2 + 32 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = $2 + 36 | 0;
    $61 = HEAP32[$60 >> 2] | 0;
    $62 = $59;
    $63 = $61;
    $64 = $57 + 4 | 0;
    $65 = $64 + $62 | 0;
    $66 = $65 - $63 | 0;
    $font_count_0 = $54;
    $font_offset_0 = $66;
    label = 14;
    break;
   case 13:
    $68 = $54 & 65535;
    $69 = $68 * 12 & -1;
    $70 = $69 + 4 | 0;
    $71 = HEAP32[$51 >> 2] | 0;
    $72 = $71 + $70 | 0;
    HEAP32[$51 >> 2] = $72;
    $73 = _FT_Stream_GetShortLE($2) | 0;
    $74 = $73 << 16 >> 16 == 0;
    if ($74) {
      $font_count_0 = 0;
      $font_offset_0 = 0;
      label = 14;
      break;
    } else {
      $53 = $73;
      label = 11;
      break;
    }
   case 14:
    _FT_Stream_ExitFrame($2);
    $75 = $font_count_0 << 16 >> 16 == 0;
    $76 = ($font_offset_0 | 0) == 0;
    $or_cond = $75 | $76;
    if ($or_cond) {
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 15:
    HEAP32[$error >> 2] = 3;
    label = 77;
    break;
   case 16:
    $79 = $font_count_0 & 65535;
    $80 = $79 * 118 & -1;
    $81 = $2 + 4 | 0;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = $80 >>> 0 > $82 >>> 0;
    if ($83) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    HEAP32[$error >> 2] = 3;
    label = 77;
    break;
   case 18:
    $86 = $face | 0;
    HEAP32[$86 >> 2] = $79;
    $87 = ($79 | 0) > ($face_index | 0);
    if ($87) {
      label = 20;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    HEAP32[$error >> 2] = 6;
    label = 77;
    break;
   case 20:
    $90 = ($face_index | 0) < 0;
    if ($90) {
      label = 77;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $92 = _ft_mem_alloc($4, 172, $error) | 0;
    $93 = $92;
    HEAP32[$5 >> 2] = $93;
    $94 = HEAP32[$error >> 2] | 0;
    $95 = ($94 | 0) == 0;
    if ($95) {
      label = 22;
      break;
    } else {
      label = 77;
      break;
    }
   case 22:
    $97 = $face_index * 12 & -1;
    $98 = $font_offset_0 + $97 | 0;
    $99 = _FT_Stream_Seek($2, $98) | 0;
    HEAP32[$error >> 2] = $99;
    $100 = ($99 | 0) == 0;
    if ($100) {
      label = 23;
      break;
    } else {
      label = 76;
      break;
    }
   case 23:
    $102 = _FT_Stream_EnterFrame($2, 12) | 0;
    HEAP32[$error >> 2] = $102;
    $103 = ($102 | 0) == 0;
    if ($103) {
      label = 24;
      break;
    } else {
      label = 76;
      break;
    }
   case 24:
    $105 = _FT_Stream_GetShortLE($2) | 0;
    $106 = $105 & 65535;
    $107 = $48 & 65535;
    $108 = $106 << $107;
    $109 = HEAP32[$5 >> 2] | 0;
    $110 = $109 | 0;
    HEAP32[$110 >> 2] = $108;
    $111 = _FT_Stream_GetShortLE($2) | 0;
    $112 = $111 & 65535;
    $113 = $112 << $107;
    $114 = HEAP32[$5 >> 2] | 0;
    $115 = $114 + 164 | 0;
    HEAP32[$115 >> 2] = $113;
    $116 = $2 + 32 | 0;
    $117 = HEAP32[$116 >> 2] | 0;
    $118 = $117 + 8 | 0;
    HEAP32[$116 >> 2] = $118;
    _FT_Stream_ExitFrame($2);
    $119 = HEAP32[$5 >> 2] | 0;
    $120 = _fnt_font_load($119, $2) | 0;
    HEAP32[$error >> 2] = $120;
    label = 71;
    break;
   case 25:
    $122 = HEAP16[$17 >> 1] | 0;
    $123 = $122 & 65535;
    $124 = _FT_Stream_Seek($2, $123) | 0;
    HEAP32[$error >> 2] = $124;
    $125 = ($124 | 0) == 0;
    if ($125) {
      label = 26;
      break;
    } else {
      label = 77;
      break;
    }
   case 26:
    $127 = $pe32_header;
    $128 = _FT_Stream_ReadFields($2, 5242984, $127) | 0;
    HEAP32[$error >> 2] = $128;
    $129 = ($128 | 0) == 0;
    if ($129) {
      label = 27;
      break;
    } else {
      label = 77;
      break;
    }
   case 27:
    $131 = $pe32_header | 0;
    $132 = HEAP32[$131 >> 2] | 0;
    $133 = ($132 | 0) == 17744;
    if ($133) {
      label = 28;
      break;
    } else {
      label = 31;
      break;
    }
   case 28:
    $135 = $pe32_header + 4 | 0;
    $136 = HEAP16[$135 >> 1] | 0;
    $137 = $136 << 16 >> 16 == 332;
    if ($137) {
      label = 29;
      break;
    } else {
      label = 31;
      break;
    }
   case 29:
    $139 = $pe32_header + 8 | 0;
    $140 = HEAP16[$139 >> 1] | 0;
    $141 = $140 << 16 >> 16 == 224;
    if ($141) {
      label = 30;
      break;
    } else {
      label = 31;
      break;
    }
   case 30:
    $143 = $pe32_header + 10 | 0;
    $144 = HEAP16[$143 >> 1] | 0;
    $145 = $144 << 16 >> 16 == 267;
    if ($145) {
      label = 32;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    HEAP32[$error >> 2] = 3;
    label = 77;
    break;
   case 32:
    $148 = $face | 0;
    HEAP32[$148 >> 2] = 0;
    $149 = $pe32_header + 6 | 0;
    $150 = HEAP16[$149 >> 1] | 0;
    $151 = $pe32_section | 0;
    $152 = $pe32_header + 12 | 0;
    $153 = HEAP32[$152 >> 2] | 0;
    $154 = $pe32_section + 8 | 0;
    $i_0 = 0;
    label = 33;
    break;
   case 33:
    $156 = ($i_0 & 65535) < ($150 & 65535);
    if ($156) {
      label = 34;
      break;
    } else {
      label = 36;
      break;
    }
   case 34:
    $158 = _FT_Stream_ReadFields($2, 5242952, $151) | 0;
    HEAP32[$error >> 2] = $158;
    $159 = ($158 | 0) == 0;
    if ($159) {
      label = 35;
      break;
    } else {
      label = 77;
      break;
    }
   case 35:
    $161 = HEAP32[$154 >> 2] | 0;
    $162 = ($153 | 0) == ($161 | 0);
    $163 = $i_0 + 1 & 65535;
    if ($162) {
      label = 37;
      break;
    } else {
      $i_0 = $163;
      label = 33;
      break;
    }
   case 36:
    HEAP32[$error >> 2] = 3;
    label = 77;
    break;
   case 37:
    $166 = $pe32_section + 16 | 0;
    $167 = HEAP32[$166 >> 2] | 0;
    $168 = _FT_Stream_Seek($2, $167) | 0;
    HEAP32[$error >> 2] = $168;
    $169 = ($168 | 0) == 0;
    if ($169) {
      label = 38;
      break;
    } else {
      label = 77;
      break;
    }
   case 38:
    $171 = $root_dir;
    $172 = _FT_Stream_ReadFields($2, 5242880, $171) | 0;
    HEAP32[$error >> 2] = $172;
    $173 = ($172 | 0) == 0;
    if ($173) {
      label = 39;
      break;
    } else {
      label = 77;
      break;
    }
   case 39:
    $175 = HEAP32[$166 >> 2] | 0;
    $176 = $root_dir + 12 | 0;
    $177 = HEAP16[$176 >> 1] | 0;
    $178 = $177 & 65535;
    $179 = $root_dir + 14 | 0;
    $180 = HEAP16[$179 >> 1] | 0;
    $181 = $180 & 65535;
    $182 = $181 + $178 | 0;
    $183 = ($182 | 0) > 0;
    if ($183) {
      label = 40;
      break;
    } else {
      label = 71;
      break;
    }
   case 40:
    $184 = $175 + 16 | 0;
    $185 = $dir_entry1;
    $186 = $dir_entry1 + 4 | 0;
    $187 = HEAP32[$166 >> 2] | 0;
    $188 = $name_dir;
    $189 = $name_dir + 12 | 0;
    $190 = $name_dir + 14 | 0;
    $191 = HEAP16[$176 >> 1] | 0;
    $192 = $191 & 65535;
    $193 = HEAP16[$179 >> 1] | 0;
    $194 = $193 & 65535;
    $195 = $194 + $192 | 0;
    $196 = $dir_entry2;
    $197 = $dir_entry2 + 4 | 0;
    $198 = HEAP32[$166 >> 2] | 0;
    $199 = $lang_dir;
    $200 = $lang_dir + 12 | 0;
    $201 = $lang_dir + 14 | 0;
    $202 = $dir_entry3;
    $203 = $dir_entry1 | 0;
    $204 = $dir_entry3 + 4 | 0;
    $205 = $data_entry;
    $206 = HEAP32[$166 >> 2] | 0;
    $207 = $data_entry | 0;
    $208 = HEAP32[$154 >> 2] | 0;
    $209 = $data_entry + 4 | 0;
    $i_189 = 0;
    $211 = 0;
    label = 41;
    break;
   case 41:
    $212 = $211 << 3;
    $213 = $184 + $212 | 0;
    $214 = _FT_Stream_Seek($2, $213) | 0;
    HEAP32[$error >> 2] = $214;
    $215 = ($214 | 0) == 0;
    if ($215) {
      label = 42;
      break;
    } else {
      label = 77;
      break;
    }
   case 42:
    $217 = _FT_Stream_ReadFields($2, 5242912, $185) | 0;
    HEAP32[$error >> 2] = $217;
    $218 = ($217 | 0) == 0;
    if ($218) {
      label = 43;
      break;
    } else {
      label = 77;
      break;
    }
   case 43:
    $220 = HEAP32[$186 >> 2] | 0;
    $221 = ($220 | 0) < 0;
    if ($221) {
      label = 45;
      break;
    } else {
      label = 44;
      break;
    }
   case 44:
    HEAP32[$error >> 2] = 3;
    label = 77;
    break;
   case 45:
    $224 = $220 & 2147483647;
    HEAP32[$186 >> 2] = $224;
    $225 = $187 + $224 | 0;
    $226 = _FT_Stream_Seek($2, $225) | 0;
    HEAP32[$error >> 2] = $226;
    $227 = ($226 | 0) == 0;
    if ($227) {
      label = 46;
      break;
    } else {
      label = 77;
      break;
    }
   case 46:
    $229 = _FT_Stream_ReadFields($2, 5242880, $188) | 0;
    HEAP32[$error >> 2] = $229;
    $230 = ($229 | 0) == 0;
    if ($230) {
      label = 47;
      break;
    } else {
      label = 77;
      break;
    }
   case 47:
    $231 = HEAP16[$189 >> 1] | 0;
    $232 = $231 & 65535;
    $233 = HEAP16[$190 >> 1] | 0;
    $234 = $233 & 65535;
    $235 = $234 + $232 | 0;
    $236 = ($235 | 0) > 0;
    if ($236) {
      label = 48;
      break;
    } else {
      label = 70;
      break;
    }
   case 48:
    $237 = $225 + 16 | 0;
    $238 = HEAP16[$189 >> 1] | 0;
    $239 = $238 & 65535;
    $240 = HEAP16[$190 >> 1] | 0;
    $241 = $240 & 65535;
    $242 = $241 + $239 | 0;
    $243 = HEAP32[$203 >> 2] | 0;
    $244 = ($243 | 0) == 8;
    $j_084 = 0;
    $246 = 0;
    label = 49;
    break;
   case 49:
    $247 = $246 << 3;
    $248 = $237 + $247 | 0;
    $249 = _FT_Stream_Seek($2, $248) | 0;
    HEAP32[$error >> 2] = $249;
    $250 = ($249 | 0) == 0;
    if ($250) {
      label = 50;
      break;
    } else {
      label = 77;
      break;
    }
   case 50:
    $252 = _FT_Stream_ReadFields($2, 5242912, $196) | 0;
    HEAP32[$error >> 2] = $252;
    $253 = ($252 | 0) == 0;
    if ($253) {
      label = 51;
      break;
    } else {
      label = 77;
      break;
    }
   case 51:
    $255 = HEAP32[$197 >> 2] | 0;
    $256 = ($255 | 0) < 0;
    if ($256) {
      label = 53;
      break;
    } else {
      label = 52;
      break;
    }
   case 52:
    HEAP32[$error >> 2] = 3;
    label = 77;
    break;
   case 53:
    $259 = $255 & 2147483647;
    HEAP32[$197 >> 2] = $259;
    $260 = $198 + $259 | 0;
    $261 = _FT_Stream_Seek($2, $260) | 0;
    HEAP32[$error >> 2] = $261;
    $262 = ($261 | 0) == 0;
    if ($262) {
      label = 54;
      break;
    } else {
      label = 77;
      break;
    }
   case 54:
    $264 = _FT_Stream_ReadFields($2, 5242880, $199) | 0;
    HEAP32[$error >> 2] = $264;
    $265 = ($264 | 0) == 0;
    if ($265) {
      label = 55;
      break;
    } else {
      label = 77;
      break;
    }
   case 55:
    $266 = HEAP16[$200 >> 1] | 0;
    $267 = $266 & 65535;
    $268 = HEAP16[$201 >> 1] | 0;
    $269 = $268 & 65535;
    $270 = $269 + $267 | 0;
    $271 = ($270 | 0) > 0;
    if ($271) {
      label = 56;
      break;
    } else {
      label = 69;
      break;
    }
   case 56:
    $272 = $260 + 16 | 0;
    $273 = HEAP32[$197 >> 2] | 0;
    $274 = ($273 | 0) < 0;
    $275 = HEAP16[$200 >> 1] | 0;
    $276 = $275 & 65535;
    $277 = HEAP16[$201 >> 1] | 0;
    $278 = $277 & 65535;
    $279 = $278 + $276 | 0;
    $k_080 = 0;
    $281 = 0;
    label = 57;
    break;
   case 57:
    $282 = $281 << 3;
    $283 = $272 + $282 | 0;
    $284 = _FT_Stream_Seek($2, $283) | 0;
    HEAP32[$error >> 2] = $284;
    $285 = ($284 | 0) == 0;
    if ($285) {
      label = 58;
      break;
    } else {
      label = 77;
      break;
    }
   case 58:
    $287 = _FT_Stream_ReadFields($2, 5242912, $202) | 0;
    HEAP32[$error >> 2] = $287;
    $288 = ($287 | 0) == 0;
    if ($288) {
      label = 59;
      break;
    } else {
      label = 77;
      break;
    }
   case 59:
    if ($274) {
      label = 60;
      break;
    } else {
      label = 61;
      break;
    }
   case 60:
    HEAP32[$error >> 2] = 3;
    label = 77;
    break;
   case 61:
    if ($244) {
      label = 62;
      break;
    } else {
      label = 68;
      break;
    }
   case 62:
    $293 = HEAP32[$204 >> 2] | 0;
    $294 = $293 + $175 | 0;
    $295 = _FT_Stream_Seek($2, $294) | 0;
    HEAP32[$error >> 2] = $295;
    $296 = ($295 | 0) == 0;
    if ($296) {
      label = 63;
      break;
    } else {
      label = 77;
      break;
    }
   case 63:
    $298 = _FT_Stream_ReadFields($2, 5242928, $205) | 0;
    HEAP32[$error >> 2] = $298;
    $299 = ($298 | 0) == 0;
    if ($299) {
      label = 64;
      break;
    } else {
      label = 77;
      break;
    }
   case 64:
    $301 = HEAP32[$148 >> 2] | 0;
    $302 = ($301 | 0) == ($face_index | 0);
    if ($302) {
      label = 65;
      break;
    } else {
      label = 67;
      break;
    }
   case 65:
    $304 = _ft_mem_alloc($4, 172, $error) | 0;
    $305 = $304;
    HEAP32[$5 >> 2] = $305;
    $306 = HEAP32[$error >> 2] | 0;
    $307 = ($306 | 0) == 0;
    if ($307) {
      label = 66;
      break;
    } else {
      label = 77;
      break;
    }
   case 66:
    $309 = HEAP32[$207 >> 2] | 0;
    $310 = $309 + $206 | 0;
    $311 = $310 - $208 | 0;
    $312 = $304;
    HEAP32[$312 >> 2] = $311;
    $313 = HEAP32[$209 >> 2] | 0;
    $314 = HEAP32[$5 >> 2] | 0;
    $315 = $314 + 164 | 0;
    HEAP32[$315 >> 2] = $313;
    $316 = HEAP32[$5 >> 2] | 0;
    $317 = _fnt_font_load($316, $2) | 0;
    HEAP32[$error >> 2] = $317;
    $318 = ($317 | 0) == 0;
    if ($318) {
      label = 67;
      break;
    } else {
      label = 76;
      break;
    }
   case 67:
    $320 = HEAP32[$148 >> 2] | 0;
    $321 = $320 + 1 | 0;
    HEAP32[$148 >> 2] = $321;
    label = 68;
    break;
   case 68:
    $323 = $k_080 + 1 & 65535;
    $324 = $323 & 65535;
    $325 = ($324 | 0) < ($279 | 0);
    if ($325) {
      $k_080 = $323;
      $281 = $324;
      label = 57;
      break;
    } else {
      label = 69;
      break;
    }
   case 69:
    $326 = $j_084 + 1 & 65535;
    $327 = $326 & 65535;
    $328 = ($327 | 0) < ($242 | 0);
    if ($328) {
      $j_084 = $326;
      $246 = $327;
      label = 49;
      break;
    } else {
      label = 70;
      break;
    }
   case 70:
    $329 = $i_189 + 1 & 65535;
    $330 = $329 & 65535;
    $331 = ($330 | 0) < ($195 | 0);
    if ($331) {
      $i_189 = $329;
      $211 = $330;
      label = 41;
      break;
    } else {
      label = 71;
      break;
    }
   case 71:
    $332 = $face | 0;
    $333 = HEAP32[$332 >> 2] | 0;
    $334 = ($333 | 0) == 0;
    if ($334) {
      label = 72;
      break;
    } else {
      label = 73;
      break;
    }
   case 72:
    HEAP32[$error >> 2] = 3;
    label = 77;
    break;
   case 73:
    $337 = ($333 | 0) > ($face_index | 0);
    if ($337) {
      label = 75;
      break;
    } else {
      label = 74;
      break;
    }
   case 74:
    HEAP32[$error >> 2] = 6;
    label = 77;
    break;
   case 75:
    $_pr = HEAP32[$error >> 2] | 0;
    $340 = ($_pr | 0) == 0;
    if ($340) {
      label = 77;
      break;
    } else {
      label = 76;
      break;
    }
   case 76:
    _fnt_font_done($face);
    label = 77;
    break;
   case 77:
    $341 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $341 | 0;
  }
  return 0;
}
function _fnt_font_load($font, $stream) {
  $font = $font | 0;
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $font + 4 | 0;
    $2 = $font | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = _FT_Stream_Seek($stream, $3) | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $error_0 = $4;
      label = 10;
      break;
    }
   case 2:
    $7 = $1;
    $8 = _FT_Stream_ReadFields($stream, 5243108, $7) | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 3;
      break;
    } else {
      $error_0 = $8;
      label = 10;
      break;
    }
   case 3:
    $11 = $1 | 0;
    $12 = HEAP16[$11 >> 1] | 0;
    if (($12 << 16 >> 16 | 0) == 512 | ($12 << 16 >> 16 | 0) == 768) {
      label = 4;
      break;
    } else {
      $error_0 = 2;
      label = 10;
      break;
    }
   case 4:
    $14 = $12 << 16 >> 16 == 768;
    $15 = $14 ? 148 : 118;
    $16 = $font + 8 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $17 >>> 0 < $15 >>> 0;
    if ($18) {
      $error_0 = 2;
      label = 10;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $20 = $12 << 16 >> 16 == 512;
    if ($20) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $22 = $font + 132 | 0;
    $23 = $22;
    _memset($23 | 0, 0, 12);
    label = 7;
    break;
   case 7:
    $25 = $font + 72 | 0;
    $26 = HEAP16[$25 >> 1] | 0;
    $27 = $26 & 1;
    $28 = $27 << 16 >> 16 == 0;
    if ($28) {
      label = 8;
      break;
    } else {
      $error_0 = 2;
      label = 10;
      break;
    }
   case 8:
    $30 = HEAP32[$2 >> 2] | 0;
    $31 = _FT_Stream_Seek($stream, $30) | 0;
    $32 = ($31 | 0) == 0;
    if ($32) {
      label = 9;
      break;
    } else {
      $error_0 = $31;
      label = 10;
      break;
    }
   case 9:
    $34 = HEAP32[$16 >> 2] | 0;
    $35 = $font + 160 | 0;
    $36 = _FT_Stream_ExtractFrame($stream, $34, $35) | 0;
    $error_0 = $36;
    label = 10;
    break;
   case 10:
    return $error_0 | 0;
  }
  return 0;
}
function _af_dummy_hints_apply($hints, $outline) {
  $hints = $hints | 0;
  $outline = $outline | 0;
  return 0;
}
function _fnt_cmap_init($cmap) {
  $cmap = $cmap | 0;
  var $5 = 0, $8 = 0;
  $5 = HEAP32[(HEAP32[$cmap >> 2] | 0) + 132 >> 2] | 0;
  $8 = HEAPU8[$5 + 104 | 0] | 0;
  HEAP32[$cmap + 16 >> 2] = $8;
  HEAP32[$cmap + 20 >> 2] = (1 - $8 | 0) + (HEAPU8[$5 + 105 | 0] | 0) | 0;
  return 0;
}
function _fnt_cmap_char_index($cmap, $char_code) {
  $cmap = $cmap | 0;
  $char_code = $char_code | 0;
  var $3 = 0;
  $3 = $char_code - (HEAP32[$cmap + 16 >> 2] | 0) | 0;
  return ($3 >>> 0 < (HEAP32[$cmap + 20 >> 2] | 0) >>> 0 ? $3 + 1 | 0 : 0) | 0;
}
function _fnt_cmap_char_next($cmap, $pchar_code) {
  $cmap = $cmap | 0;
  $pchar_code = $pchar_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $_ = 0, $_10 = 0, $gindex_0 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$pchar_code >> 2] | 0;
    $2 = $1 + 1 | 0;
    $3 = $cmap + 16 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 >>> 0 > $4 >>> 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $result_0 = $4;
      $gindex_0 = 1;
      label = 3;
      break;
    }
   case 2:
    $7 = $2 - $4 | 0;
    $8 = $cmap + 20 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $7 >>> 0 < $9 >>> 0;
    $11 = $7 + 1 | 0;
    $_ = $10 ? $11 : 0;
    $_10 = $10 ? $2 : 0;
    $result_0 = $_10;
    $gindex_0 = $_;
    label = 3;
    break;
   case 3:
    HEAP32[$pchar_code >> 2] = $result_0;
    return $gindex_0 | 0;
  }
  return 0;
}
function _winfnt_get_header($face, $aheader) {
  $face = $face | 0;
  $aheader = $aheader | 0;
  _memcpy($aheader | 0, (HEAP32[$face + 132 >> 2] | 0) + 4 | 0, 156);
  return 0;
}
function _af_dummy_hints_init($hints, $metrics) {
  $hints = $hints | 0;
  $metrics = $metrics | 0;
  _af_glyph_hints_rescale($hints, $metrics);
  return 0;
}
function _af_latin_metrics_init($metrics, $face) {
  $metrics = $metrics | 0;
  $face = $face | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $error_0 = 0, $ee_0 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $18 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 92 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 68 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 & 65535;
    $6 = $metrics + 36 | 0;
    HEAP32[$6 >> 2] = $5;
    $ee_0 = 0;
    $error_0 = 0;
    label = 2;
    break;
   case 2:
    $8 = ($ee_0 | 0) == 4;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $10 = 5318624 + ($ee_0 << 2) | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = _FT_Select_Charmap($face, $11) | 0;
    $13 = ($12 | 0) == 0;
    $14 = $ee_0 + 1 | 0;
    if ($13) {
      label = 5;
      break;
    } else {
      $ee_0 = $14;
      $error_0 = $12;
      label = 2;
      break;
    }
   case 4:
    $16 = ($error_0 | 0) == 0;
    if ($16) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    _af_latin_metrics_init_widths($metrics, $face, 111);
    _af_latin_metrics_init_blues($metrics, $face);
    _af_latin_metrics_check_digits($metrics, $face);
    label = 6;
    break;
   case 6:
    $18 = _FT_Set_Charmap($face, $2) | 0;
    return 0;
  }
  return 0;
}
function _af_latin_metrics_scale($metrics, $scaler) {
  $metrics = $metrics | 0;
  $scaler = $scaler | 0;
  HEAP32[$metrics + 24 >> 2] = HEAP32[$scaler + 20 >> 2] | 0;
  HEAP32[$metrics + 4 >> 2] = HEAP32[$scaler >> 2] | 0;
  _af_latin_metrics_scale_dim($metrics, $scaler, 0);
  _af_latin_metrics_scale_dim($metrics, $scaler, 1);
  return;
}
function _af_latin_hints_init($hints, $metrics) {
  $hints = $hints | 0;
  $metrics = $metrics | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $_off = 0, $21 = 0, $_ = 0, $22 = 0, $or_cond3 = 0, $23 = 0, $other_flags_1 = 0, $24 = 0, $25 = 0, $other_flags_1_ = 0, $26 = 0, $other_flags_3 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $scaler_flags_0 = 0, $35 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $metrics + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $metrics | 0;
    _af_glyph_hints_rescale($hints, $3);
    $4 = $metrics + 40 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $hints + 4 | 0;
    HEAP32[$6 >> 2] = $5;
    $7 = $metrics + 44 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $hints + 8 | 0;
    HEAP32[$9 >> 2] = $8;
    $10 = $metrics + 436 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $hints + 12 | 0;
    HEAP32[$12 >> 2] = $11;
    $13 = $metrics + 440 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $hints + 16 | 0;
    HEAP32[$15 >> 2] = $14;
    $16 = $metrics + 24 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $hints + 104 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = ($17 | 0) == 2;
    $_off = $17 - 2 | 0;
    $21 = $_off >>> 0 < 2;
    $_ = $21 & 1;
    $22 = ($17 | 0) == 4;
    $or_cond3 = $20 | $22;
    $23 = $_ | 2;
    $other_flags_1 = $or_cond3 ? $23 : $_;
    $24 = ($17 | 0) == 1;
    $25 = $other_flags_1 | 4;
    $other_flags_1_ = $24 ? $other_flags_1 : $25;
    $26 = $other_flags_1_ | 8;
    $other_flags_3 = $20 ? $26 : $other_flags_1_;
    if ($24) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $28 = $2 + 12 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $29 & 1;
    $31 = ($30 | 0) == 0;
    if ($31) {
      $scaler_flags_0 = $19;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $33 = $19 | 1;
    $scaler_flags_0 = $33;
    label = 4;
    break;
   case 4:
    HEAP32[$18 >> 2] = $scaler_flags_0;
    $35 = $hints + 108 | 0;
    HEAP32[$35 >> 2] = $other_flags_3;
    return 0;
  }
  return 0;
}
function _af_latin_hints_apply($hints, $outline, $metrics) {
  $hints = $hints | 0;
  $outline = $outline | 0;
  $metrics = $metrics | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $dim_026 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $30 = 0, $exitcond = 0, $error_2 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _af_glyph_hints_reload($hints, $outline) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $error_2 = $1;
      label = 14;
      break;
    }
   case 2:
    $4 = $hints + 104 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 & 1;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $9 = _af_latin_hints_detect_features($hints, 0) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      $error_2 = $9;
      label = 14;
      break;
    }
   case 4:
    $12 = HEAP32[$4 >> 2] | 0;
    $13 = $12 & 2;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 5;
      break;
    } else {
      $dim_026 = 0;
      label = 7;
      break;
    }
   case 5:
    $16 = _af_latin_hints_detect_features($hints, 1) | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 6;
      break;
    } else {
      $error_2 = $16;
      label = 14;
      break;
    }
   case 6:
    _af_latin_hints_compute_blue_edges($hints, $metrics);
    $dim_026 = 0;
    label = 7;
    break;
   case 7:
    if (($dim_026 | 0) == 0) {
      label = 8;
      break;
    } else if (($dim_026 | 0) == 1) {
      label = 10;
      break;
    } else {
      label = 12;
      break;
    }
   case 8:
    $20 = HEAP32[$4 >> 2] | 0;
    $21 = $20 & 1;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 11;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $23 = $dim_026 + 1 | 0;
    $dim_026 = $23;
    label = 7;
    break;
   case 10:
    $25 = HEAP32[$4 >> 2] | 0;
    $26 = $25 & 2;
    $27 = ($26 | 0) == 0;
    if ($27) {
      label = 11;
      break;
    } else {
      label = 13;
      break;
    }
   case 11:
    _af_latin_hint_edges($hints, $dim_026);
    _af_glyph_hints_align_edge_points($hints, $dim_026);
    _af_glyph_hints_align_strong_points($hints, $dim_026);
    _af_glyph_hints_align_weak_points($hints, $dim_026);
    label = 12;
    break;
   case 12:
    $30 = $dim_026 + 1 | 0;
    $exitcond = ($30 | 0) == 2;
    if ($exitcond) {
      label = 13;
      break;
    } else {
      $dim_026 = $30;
      label = 7;
      break;
    }
   case 13:
    _af_glyph_hints_save($hints, $outline);
    $error_2 = 0;
    label = 14;
    break;
   case 14:
    return $error_2 | 0;
  }
  return 0;
}
function _af_cjk_metrics_init($metrics, $face) {
  $metrics = $metrics | 0;
  $face = $face | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $12 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 92 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 68 | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $5 = $4 & 65535;
    $6 = $metrics + 36 | 0;
    HEAP32[$6 >> 2] = $5;
    $7 = _FT_Select_Charmap($face, 1970170211) | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = 0;
    label = 4;
    break;
   case 3:
    _af_latin_metrics_init_widths($metrics, $face, 3e4);
    _af_latin_metrics_check_digits($metrics, $face);
    label = 4;
    break;
   case 4:
    $12 = _FT_Set_Charmap($face, $2) | 0;
    return 0;
  }
  return 0;
}
function _af_cjk_metrics_scale($metrics, $scaler) {
  $metrics = $metrics | 0;
  $scaler = $scaler | 0;
  _memcpy($metrics + 4 | 0, $scaler | 0, 28);
  _af_cjk_metrics_scale_dim($metrics, $scaler, 0);
  _af_cjk_metrics_scale_dim($metrics, $scaler, 1);
  return;
}
function _af_cjk_hints_init($hints, $metrics) {
  $hints = $hints | 0;
  $metrics = $metrics | 0;
  var $15 = 0, $16 = 0, $18 = 0, $_ = 0, $other_flags_1 = 0, $other_flags_1_ = 0;
  _af_glyph_hints_rescale($hints, $metrics | 0);
  HEAP32[$hints + 4 >> 2] = HEAP32[$metrics + 40 >> 2] | 0;
  HEAP32[$hints + 8 >> 2] = HEAP32[$metrics + 44 >> 2] | 0;
  HEAP32[$hints + 12 >> 2] = HEAP32[$metrics + 436 >> 2] | 0;
  HEAP32[$hints + 16 >> 2] = HEAP32[$metrics + 440 >> 2] | 0;
  $15 = HEAP32[$metrics + 24 >> 2] | 0;
  $16 = $hints + 104 | 0;
  $18 = ($15 | 0) == 2;
  $_ = ($15 - 2 | 0) >>> 0 < 2 & 1;
  $other_flags_1 = $18 | ($15 | 0) == 4 ? $_ | 2 : $_;
  $other_flags_1_ = ($15 | 0) == 1 ? $other_flags_1 : $other_flags_1 | 4;
  HEAP32[$16 >> 2] = HEAP32[$16 >> 2] | 4;
  HEAP32[$hints + 108 >> 2] = $18 ? $other_flags_1_ | 8 : $other_flags_1_;
  return 0;
}
function _af_cjk_hints_apply($hints, $outline, $metrics) {
  $hints = $hints | 0;
  $outline = $outline | 0;
  $metrics = $metrics | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $dim_025 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $29 = 0, $exitcond = 0, $error_2 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _af_glyph_hints_reload($hints, $outline) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $error_2 = $1;
      label = 13;
      break;
    }
   case 2:
    $4 = $hints + 104 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 & 1;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $9 = _af_cjk_hints_detect_features($hints, 0) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 4;
      break;
    } else {
      $error_2 = $9;
      label = 13;
      break;
    }
   case 4:
    $12 = HEAP32[$4 >> 2] | 0;
    $13 = $12 & 2;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 5;
      break;
    } else {
      $dim_025 = 0;
      label = 6;
      break;
    }
   case 5:
    $16 = _af_cjk_hints_detect_features($hints, 1) | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      $dim_025 = 0;
      label = 6;
      break;
    } else {
      $error_2 = $16;
      label = 13;
      break;
    }
   case 6:
    if (($dim_025 | 0) == 0) {
      label = 7;
      break;
    } else if (($dim_025 | 0) == 1) {
      label = 9;
      break;
    } else {
      label = 11;
      break;
    }
   case 7:
    $19 = HEAP32[$4 >> 2] | 0;
    $20 = $19 & 1;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $22 = $dim_025 + 1 | 0;
    $dim_025 = $22;
    label = 6;
    break;
   case 9:
    $24 = HEAP32[$4 >> 2] | 0;
    $25 = $24 & 2;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 10;
      break;
    } else {
      label = 12;
      break;
    }
   case 10:
    _af_cjk_hint_edges($hints, $dim_025);
    _af_cjk_align_edge_points($hints, $dim_025);
    _af_glyph_hints_align_strong_points($hints, $dim_025);
    _af_glyph_hints_align_weak_points($hints, $dim_025);
    label = 11;
    break;
   case 11:
    $29 = $dim_025 + 1 | 0;
    $exitcond = ($29 | 0) == 2;
    if ($exitcond) {
      label = 12;
      break;
    } else {
      $dim_025 = $29;
      label = 6;
      break;
    }
   case 12:
    _af_glyph_hints_save($hints, $outline);
    $error_2 = 0;
    label = 13;
    break;
   case 13:
    return $error_2 | 0;
  }
  return 0;
}
function _af_indic_metrics_init($metrics, $face) {
  $metrics = $metrics | 0;
  $face = $face | 0;
  _af_cjk_metrics_init($metrics, $face);
  return 0;
}
function _af_indic_metrics_scale($metrics, $scaler) {
  $metrics = $metrics | 0;
  $scaler = $scaler | 0;
  _af_cjk_metrics_scale($metrics, $scaler);
  return;
}
function _af_indic_hints_init($hints, $metrics) {
  $hints = $hints | 0;
  $metrics = $metrics | 0;
  _af_cjk_hints_init($hints, $metrics);
  return 0;
}
function _af_indic_hints_apply($hints, $outline, $metrics) {
  $hints = $hints | 0;
  $outline = $outline | 0;
  $metrics = $metrics | 0;
  return _af_cjk_hints_apply($hints, $outline, $metrics) | 0;
}
function _af_autofitter_load_glyph($module, $slot, $size, $glyph_index, $load_flags) {
  $module = $module | 0;
  $slot = $slot | 0;
  $size = $size | 0;
  $glyph_index = $glyph_index | 0;
  $load_flags = $load_flags | 0;
  return _af_loader_load_glyph($module + 20 | 0, HEAP32[$slot + 4 >> 2] | 0, $glyph_index, $load_flags) | 0;
}
function _af_autofitter_init($module) {
  $module = $module | 0;
  return _af_loader_init($module + 20 | 0, HEAP32[HEAP32[$module + 4 >> 2] >> 2] | 0) | 0;
}
function _af_autofitter_done($module) {
  $module = $module | 0;
  _af_loader_done($module + 20 | 0);
  return;
}
function _af_loader_done($loader) {
  $loader = $loader | 0;
  var $4 = 0;
  _af_glyph_hints_done($loader + 12 | 0);
  HEAP32[$loader >> 2] = 0;
  HEAP32[$loader + 4 >> 2] = 0;
  $4 = $loader + 8 | 0;
  _FT_GlyphLoader_Done(HEAP32[$4 >> 2] | 0);
  HEAP32[$4 >> 2] = 0;
  return;
}
function _af_glyph_hints_done($hints) {
  $hints = $hints | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($hints | 0) == 0;
    if ($1) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $hints | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $6 = $hints + 48 | 0;
    HEAP32[$6 >> 2] = 0;
    $7 = $hints + 52 | 0;
    HEAP32[$7 >> 2] = 0;
    $8 = $hints + 56 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 | 0;
    _ft_mem_free($4, $10);
    HEAP32[$8 >> 2] = 0;
    $11 = $hints + 60 | 0;
    HEAP32[$11 >> 2] = 0;
    $12 = $hints + 64 | 0;
    HEAP32[$12 >> 2] = 0;
    $13 = $hints + 68 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14;
    _ft_mem_free($4, $15);
    HEAP32[$13 >> 2] = 0;
    $16 = $hints + 76 | 0;
    HEAP32[$16 >> 2] = 0;
    $17 = $hints + 80 | 0;
    HEAP32[$17 >> 2] = 0;
    $18 = $hints + 84 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $19 | 0;
    _ft_mem_free($4, $20);
    HEAP32[$18 >> 2] = 0;
    $21 = $hints + 88 | 0;
    HEAP32[$21 >> 2] = 0;
    $22 = $hints + 92 | 0;
    HEAP32[$22 >> 2] = 0;
    $23 = $hints + 96 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24;
    _ft_mem_free($4, $25);
    HEAP32[$23 >> 2] = 0;
    $26 = $hints + 44 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $27;
    _ft_mem_free($4, $28);
    HEAP32[$26 >> 2] = 0;
    $29 = $hints + 36 | 0;
    HEAP32[$29 >> 2] = 0;
    $30 = $hints + 40 | 0;
    HEAP32[$30 >> 2] = 0;
    $31 = $hints + 32 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $32;
    _ft_mem_free($4, $33);
    HEAP32[$31 >> 2] = 0;
    $34 = $hints + 28 | 0;
    HEAP32[$34 >> 2] = 0;
    $35 = $hints + 24 | 0;
    HEAP32[$35 >> 2] = 0;
    HEAP32[$3 >> 2] = 0;
    label = 4;
    break;
   case 4:
    return;
  }
}
function _af_loader_init($loader, $memory) {
  $loader = $loader | 0;
  $memory = $memory | 0;
  _memset($loader | 0, 0, 184);
  _af_glyph_hints_init($loader + 12 | 0, $memory);
  return _FT_GlyphLoader_New($memory, $loader + 8 | 0) | 0;
}
function _af_glyph_hints_init($hints, $memory) {
  $hints = $hints | 0;
  $memory = $memory | 0;
  _memset($hints | 0, 0, 124);
  HEAP32[$hints >> 2] = $memory;
  return;
}
function _af_loader_load_glyph($loader, $face, $gindex, $load_flags) {
  $loader = $loader | 0;
  $face = $face | 0;
  $gindex = $gindex | 0;
  $load_flags = $load_flags | 0;
  var $scaler = 0, $metrics = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 32 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $scaler = __stackBase__ | 0;
    $metrics = __stackBase__ + 28 | 0;
    $1 = $face + 88 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      $_0 = 6;
      label = 10;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $scaler;
    _memset($5 | 0, 0, 28);
    $6 = $scaler | 0;
    HEAP32[$6 >> 2] = $face;
    $7 = $2 + 16 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $scaler + 4 | 0;
    HEAP32[$9 >> 2] = $8;
    $10 = $scaler + 12 | 0;
    HEAP32[$10 >> 2] = 0;
    $11 = $2 + 20 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $scaler + 8 | 0;
    HEAP32[$13 >> 2] = $12;
    $14 = $scaler + 16 | 0;
    HEAP32[$14 >> 2] = 0;
    $15 = $load_flags >>> 16;
    $16 = $15 & 15;
    $17 = $scaler + 20 | 0;
    HEAP32[$17 >> 2] = $16;
    $18 = $scaler + 24 | 0;
    HEAP32[$18 >> 2] = 0;
    $19 = _af_loader_reset($loader, $face) | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 3;
      break;
    } else {
      $_0 = $19;
      label = 10;
      break;
    }
   case 3:
    $22 = $loader + 4 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = _af_face_globals_get_metrics($23, $gindex, $metrics) | 0;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 4;
      break;
    } else {
      $_0 = $24;
      label = 10;
      break;
    }
   case 4:
    $27 = HEAP32[$metrics >> 2] | 0;
    $28 = $loader + 136 | 0;
    HEAP32[$28 >> 2] = $27;
    $29 = HEAP32[$metrics >> 2] | 0;
    $30 = $29 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $31 + 16 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = ($33 | 0) == 0;
    if ($34) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    FUNCTION_TABLE_vii[$33 & 1023]($29, $scaler);
    label = 7;
    break;
   case 6:
    $37 = $29 + 4 | 0;
    $38 = $37;
    _memcpy($38 | 0, $5 | 0, 28);
    label = 7;
    break;
   case 7:
    $40 = $load_flags & -2054;
    $41 = $40 | 2049;
    $42 = HEAP32[$metrics >> 2] | 0;
    $43 = $42 | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    $45 = $44 + 24 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = ($46 | 0) == 0;
    if ($47) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $49 = $loader + 12 | 0;
    $50 = FUNCTION_TABLE_iii[$46 & 1023]($49, $42) | 0;
    $51 = ($50 | 0) == 0;
    if ($51) {
      label = 9;
      break;
    } else {
      $_0 = $50;
      label = 10;
      break;
    }
   case 9:
    $53 = _af_loader_load_g($loader, $scaler, $gindex, $41, 0) | 0;
    $_0 = $53;
    label = 10;
    break;
   case 10:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _af_loader_reset($loader, $face) {
  $loader = $loader | 0;
  $face = $face | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $loader | 0;
    HEAP32[$1 >> 2] = $face;
    $2 = $face + 116 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3;
    $5 = $loader + 4 | 0;
    HEAP32[$5 >> 2] = $4;
    $6 = $loader + 8 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    _FT_GlyphLoader_Rewind($7);
    $8 = HEAP32[$5 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 2;
      break;
    } else {
      $error_0 = 0;
      label = 4;
      break;
    }
   case 2:
    $11 = _af_face_globals_new($face, $5) | 0;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 3;
      break;
    } else {
      $error_0 = $11;
      label = 4;
      break;
    }
   case 3:
    $14 = HEAP32[$5 >> 2] | 0;
    $15 = $14;
    HEAP32[$2 >> 2] = $15;
    $16 = $face + 120 | 0;
    HEAP32[$16 >> 2] = 46;
    $error_0 = 0;
    label = 4;
    break;
   case 4:
    return $error_0 | 0;
  }
  return 0;
}
function _af_face_globals_get_metrics($globals, $gindex, $ametrics) {
  $globals = $globals | 0;
  $gindex = $gindex | 0;
  $ametrics = $ametrics | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $46 = 0, $47 = 0, $metrics_0 = 0, $49 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $globals + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 >>> 0 > $gindex >>> 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    HEAP32[$error >> 2] = 6;
    $metrics_0 = 0;
    label = 11;
    break;
   case 3:
    $6 = $globals + 8 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 + $gindex | 0;
    $9 = HEAP8[$8] | 0;
    $10 = $9 & 255;
    $11 = $10 & 127;
    $12 = 5318356 + ($11 << 2) | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $globals + 12 + ($15 << 2) | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 4;
      break;
    } else {
      $metrics_0 = $17;
      label = 11;
      break;
    }
   case 4:
    $20 = $globals | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $21 + 100 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $13 + 8 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = _ft_mem_alloc($23, $25, $error) | 0;
    $27 = $26;
    $28 = HEAP32[$error >> 2] | 0;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 5;
      break;
    } else {
      $metrics_0 = $27;
      label = 11;
      break;
    }
   case 5:
    $31 = $26;
    HEAP32[$31 >> 2] = $13;
    $32 = $13 + 12 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = ($33 | 0) == 0;
    if ($34) {
      label = 10;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $36 = HEAP32[$20 >> 2] | 0;
    $37 = FUNCTION_TABLE_iii[$33 & 1023]($27, $36) | 0;
    HEAP32[$error >> 2] = $37;
    $38 = ($37 | 0) == 0;
    if ($38) {
      label = 10;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $40 = $13 + 20 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = ($41 | 0) == 0;
    if ($42) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    FUNCTION_TABLE_vi[$41 & 1023]($27);
    label = 9;
    break;
   case 9:
    _ft_mem_free($23, $26);
    $metrics_0 = 0;
    label = 11;
    break;
   case 10:
    $46 = HEAP32[$14 >> 2] | 0;
    $47 = $globals + 12 + ($46 << 2) | 0;
    HEAP32[$47 >> 2] = $27;
    $metrics_0 = $27;
    label = 11;
    break;
   case 11:
    HEAP32[$ametrics >> 2] = $metrics_0;
    $49 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $49 | 0;
  }
  return 0;
}
function _af_face_globals_is_digit($globals, $gindex) {
  $globals = $globals | 0;
  $gindex = $gindex | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $globals + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 >>> 0 > $gindex >>> 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $_0 = 0;
      label = 3;
      break;
    }
   case 2:
    $5 = $globals + 8 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + $gindex | 0;
    $8 = HEAP8[$7] | 0;
    $9 = $8 & -128;
    $_0 = $9;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _af_loader_load_g($loader, $scaler, $glyph_index, $load_flags, $depth) {
  $loader = $loader | 0;
  $scaler = $scaler | 0;
  $glyph_index = $glyph_index | 0;
  $load_flags = $load_flags | 0;
  $depth = $depth | 0;
  var $inverse = 0, $dummy = 0, $bbox = 0, $vvector = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $ld$0$0 = 0, $28$0 = 0, $ld$1$1 = 0, $28$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $71 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $149 = 0, $150 = 0, $151 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $_sum231 = 0, $157 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $pp1x_uh_0 = 0, $178 = 0, $179 = 0, $_ = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $or_cond = 0, $188 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $or_cond232 = 0, $195 = 0, $197 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $202 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $217 = 0, $218 = 0, $219 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $237 = 0, $238 = 0, $239 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $270 = 0, $271 = 0, $272 = 0, $nn_0238 = 0, $274 = 0, $_sum = 0, $ld$4$0 = 0, $275$0 = 0, $ld$5$1 = 0, $275$1 = 0, $ld$6$0 = 0, $276$0 = 0, $ld$7$1 = 0, $276$1 = 0, $277 = 0, $278 = 0, $279 = 0, $280 = 0, $281 = 0, $282 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $st$8$0 = 0, $st$9$1 = 0, $st$10$0 = 0, $st$11$1 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $298 = 0, $299 = 0, $300 = 0, $301 = 0, $302 = 0, $cur_0234 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $310 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $or_cond233 = 0, $318 = 0, $319 = 0, $_sum229 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $y_0 = 0, $x_0 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $350 = 0, $error_1 = 0, $351 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $376 = 0, $377 = 0, $379 = 0, $380 = 0, $381 = 0, $383 = 0, $384 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $431 = 0, $432 = 0, $433 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $441 = 0, $442 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $449 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $460 = 0, $461 = 0, $462 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $error_2 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 60 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $inverse = __stackBase__ | 0;
    $dummy = __stackBase__ + 16 | 0;
    $bbox = __stackBase__ + 36 | 0;
    $vvector = __stackBase__ + 52 | 0;
    $1 = $loader | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $loader + 8 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $loader + 136 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $loader + 12 | 0;
    $8 = $2 + 84 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 + 156 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = _FT_Load_Glyph($2, $glyph_index, $load_flags) | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 2;
      break;
    } else {
      $error_2 = $12;
      label = 54;
      break;
    }
   case 2:
    $15 = $11 + 8 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $loader + 140 | 0;
    HEAP8[$17] = $16;
    $18 = $16 << 24 >> 24 == 0;
    if ($18) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $20 = $loader + 144 | 0;
    $21 = $11 + 12 | 0;
    $22 = $20;
    $23 = $21;
    _memcpy($22 | 0, $23 | 0, 16);
    $24 = $loader + 160 | 0;
    $25 = $11 + 28 | 0;
    $26 = $25;
    $27 = $24;
    $ld$0$0 = $26 | 0;
    $28$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $26 + 4 | 0;
    $28$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $27 | 0;
    HEAP32[$st$2$0 >> 2] = $28$0;
    $st$3$1 = $27 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $28$1;
    $29 = $inverse;
    _memcpy($29 | 0, $22 | 0, 16);
    $30 = _FT_Matrix_Invert($inverse) | 0;
    _FT_Vector_Transform($24, $inverse);
    label = 4;
    break;
   case 4:
    $32 = $9 + 40 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $9 + 56 | 0;
    HEAP32[$34 >> 2] = $33;
    $35 = $9 + 52 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $9 + 60 | 0;
    HEAP32[$37 >> 2] = $36;
    $38 = $9 + 72 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    if (($39 | 0) == 1869968492) {
      label = 5;
      break;
    } else if (($39 | 0) == 1668246896) {
      label = 26;
      break;
    } else {
      $error_1 = 7;
      label = 41;
      break;
    }
   case 5:
    $41 = HEAP8[$17] | 0;
    $42 = $41 << 24 >> 24 == 0;
    if ($42) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $44 = $9 + 108 | 0;
    $45 = $loader + 160 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $loader + 164 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    _FT_Outline_Translate($44, $46, $48);
    label = 7;
    break;
   case 7:
    $50 = $9 + 108 | 0;
    $51 = $9 + 110 | 0;
    $52 = HEAP16[$51 >> 1] | 0;
    $53 = $52 << 16 >> 16;
    $54 = $53 + 4 | 0;
    $55 = ($54 | 0) == 0;
    if ($55) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $57 = $4 + 22 | 0;
    $58 = HEAP16[$57 >> 1] | 0;
    $59 = $58 << 16 >> 16;
    $60 = $4 + 58 | 0;
    $61 = HEAP16[$60 >> 1] | 0;
    $62 = $61 << 16 >> 16;
    $63 = $59 + $54 | 0;
    $64 = $63 + $62 | 0;
    $65 = $4 + 4 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = $64 >>> 0 > $66 >>> 0;
    if ($67) {
      label = 11;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $69 = $50 | 0;
    $70 = HEAP16[$69 >> 1] | 0;
    $71 = $70 << 16 >> 16 == 0;
    if ($71) {
      label = 12;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $73 = $70 << 16 >> 16;
    $74 = $4 + 20 | 0;
    $75 = HEAP16[$74 >> 1] | 0;
    $76 = $75 << 16 >> 16;
    $77 = $4 + 56 | 0;
    $78 = HEAP16[$77 >> 1] | 0;
    $79 = $78 << 16 >> 16;
    $80 = $76 + $73 | 0;
    $81 = $80 + $79 | 0;
    $82 = $4 + 8 | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = $81 >>> 0 > $83 >>> 0;
    if ($84) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $86 = HEAP16[$51 >> 1] | 0;
    $87 = $86 << 16 >> 16;
    $88 = $87 + 4 | 0;
    $89 = $50 | 0;
    $90 = HEAP16[$89 >> 1] | 0;
    $91 = $90 << 16 >> 16;
    $92 = _FT_GlyphLoader_CheckPoints($4, $88, $91) | 0;
    $93 = ($92 | 0) == 0;
    if ($93) {
      label = 12;
      break;
    } else {
      $error_2 = $92;
      label = 54;
      break;
    }
   case 12:
    $94 = $4 + 56 | 0;
    $95 = $4 + 60 | 0;
    $96 = HEAP32[$95 >> 2] | 0;
    $97 = $96;
    $98 = $9 + 112 | 0;
    $99 = HEAP32[$98 >> 2] | 0;
    $100 = $99;
    $101 = HEAP16[$51 >> 1] | 0;
    $102 = $101 << 16 >> 16;
    $103 = $102 << 3;
    _memcpy($97 | 0, $100 | 0, $103 | 0);
    $104 = $4 + 68 | 0;
    $105 = HEAP32[$104 >> 2] | 0;
    $106 = $105;
    $107 = $9 + 120 | 0;
    $108 = HEAP32[$107 >> 2] | 0;
    $109 = $108;
    $110 = $50 | 0;
    $111 = HEAP16[$110 >> 1] | 0;
    $112 = $111 << 16 >> 16;
    $113 = $112 << 1;
    _memcpy($106 | 0, $109 | 0, $113 | 0);
    $114 = $4 + 64 | 0;
    $115 = HEAP32[$114 >> 2] | 0;
    $116 = $9 + 116 | 0;
    $117 = HEAP32[$116 >> 2] | 0;
    $118 = HEAP16[$51 >> 1] | 0;
    $119 = $118 << 16 >> 16;
    _memcpy($115 | 0, $117 | 0, $119 | 0);
    $120 = HEAP16[$51 >> 1] | 0;
    $121 = $4 + 58 | 0;
    HEAP16[$121 >> 1] = $120;
    $122 = HEAP16[$110 >> 1] | 0;
    $123 = $94 | 0;
    HEAP16[$123 >> 1] = $122;
    $124 = $loader + 20 | 0;
    $125 = HEAP32[$124 >> 2] | 0;
    $126 = $loader + 168 | 0;
    HEAP32[$126 >> 2] = $125;
    $127 = $loader + 28 | 0;
    $128 = HEAP32[$127 >> 2] | 0;
    $129 = $loader + 172 | 0;
    HEAP32[$129 >> 2] = $128;
    $130 = HEAP32[$32 >> 2] | 0;
    $131 = $loader + 16 | 0;
    $132 = HEAP32[$131 >> 2] | 0;
    $133 = _FT_MulFix($130, $132) | 0;
    $134 = HEAP32[$124 >> 2] | 0;
    $135 = $134 + $133 | 0;
    $136 = $loader + 176 | 0;
    HEAP32[$136 >> 2] = $135;
    $137 = HEAP32[$127 >> 2] | 0;
    $138 = $loader + 180 | 0;
    HEAP32[$138 >> 2] = $137;
    $139 = HEAP16[$51 >> 1] | 0;
    $140 = $139 << 16 >> 16 == 0;
    if ($140) {
      $error_1 = 0;
      label = 41;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $142 = $6 | 0;
    $143 = HEAP32[$142 >> 2] | 0;
    $144 = $143 + 28 | 0;
    $145 = HEAP32[$144 >> 2] | 0;
    $146 = ($145 | 0) == 0;
    if ($146) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    FUNCTION_TABLE_viii[$145 & 1023]($7, $94, $6);
    label = 15;
    break;
   case 15:
    $149 = $scaler + 20 | 0;
    $150 = HEAP32[$149 >> 2] | 0;
    $151 = ($150 | 0) == 1;
    if ($151) {
      label = 24;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $153 = $loader + 80 | 0;
    $154 = HEAP32[$153 >> 2] | 0;
    $155 = $loader + 72 | 0;
    $156 = HEAP32[$155 >> 2] | 0;
    $_sum231 = $156 - 1 | 0;
    $157 = ($156 | 0) > 1;
    if ($157) {
      label = 17;
      break;
    } else {
      label = 23;
      break;
    }
   case 17:
    $159 = $loader + 116 | 0;
    $160 = HEAP32[$159 >> 2] | 0;
    $161 = $160 & 4;
    $162 = ($161 | 0) == 0;
    if ($162) {
      label = 18;
      break;
    } else {
      label = 23;
      break;
    }
   case 18:
    $164 = HEAP32[$136 >> 2] | 0;
    $165 = $154 + ($_sum231 * 48 & -1) + 4 | 0;
    $166 = HEAP32[$165 >> 2] | 0;
    $167 = $164 - $166 | 0;
    $168 = $154 + 4 | 0;
    $169 = HEAP32[$168 >> 2] | 0;
    $170 = $154 + 8 | 0;
    $171 = HEAP32[$170 >> 2] | 0;
    $172 = $171 - $169 | 0;
    $173 = $154 + ($_sum231 * 48 & -1) + 8 | 0;
    $174 = HEAP32[$173 >> 2] | 0;
    $175 = $174 + $167 | 0;
    $176 = ($169 | 0) < 24;
    $177 = $172 - 8 | 0;
    $pp1x_uh_0 = $176 ? $177 : $172;
    $178 = ($167 | 0) < 24;
    $179 = $175 + 8 | 0;
    $_ = $178 ? $179 : $175;
    $180 = $pp1x_uh_0 + 32 | 0;
    $181 = $180 & -64;
    HEAP32[$126 >> 2] = $181;
    $182 = $_ + 32 | 0;
    $183 = $182 & -64;
    HEAP32[$136 >> 2] = $183;
    $184 = HEAP32[$126 >> 2] | 0;
    $185 = ($184 | 0) >= ($171 | 0);
    $186 = ($169 | 0) > 0;
    $or_cond = $185 & $186;
    if ($or_cond) {
      label = 19;
      break;
    } else {
      label = 20;
      break;
    }
   case 19:
    $188 = $184 - 64 | 0;
    HEAP32[$126 >> 2] = $188;
    label = 20;
    break;
   case 20:
    $190 = HEAP32[$136 >> 2] | 0;
    $191 = HEAP32[$173 >> 2] | 0;
    $192 = ($190 | 0) <= ($191 | 0);
    $193 = ($167 | 0) > 0;
    $or_cond232 = $192 & $193;
    if ($or_cond232) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    $195 = $190 + 64 | 0;
    HEAP32[$136 >> 2] = $195;
    label = 22;
    break;
   case 22:
    $197 = HEAP32[$126 >> 2] | 0;
    $198 = $197 - $pp1x_uh_0 | 0;
    $199 = $9 + 144 | 0;
    HEAP32[$199 >> 2] = $198;
    $200 = HEAP32[$136 >> 2] | 0;
    $201 = $200 - $_ | 0;
    $202 = $9 + 148 | 0;
    HEAP32[$202 >> 2] = $201;
    label = 25;
    break;
   case 23:
    $204 = HEAP32[$126 >> 2] | 0;
    $205 = HEAP32[$136 >> 2] | 0;
    $206 = $204 + 32 | 0;
    $207 = $206 & -64;
    HEAP32[$126 >> 2] = $207;
    $208 = $205 + 32 | 0;
    $209 = $208 & -64;
    HEAP32[$136 >> 2] = $209;
    $210 = HEAP32[$126 >> 2] | 0;
    $211 = $210 - $204 | 0;
    $212 = $9 + 144 | 0;
    HEAP32[$212 >> 2] = $211;
    $213 = HEAP32[$136 >> 2] | 0;
    $214 = $213 - $205 | 0;
    $215 = $9 + 148 | 0;
    HEAP32[$215 >> 2] = $214;
    label = 25;
    break;
   case 24:
    $217 = HEAP32[$126 >> 2] | 0;
    $218 = HEAP32[$136 >> 2] | 0;
    $219 = $loader + 128 | 0;
    $220 = HEAP32[$219 >> 2] | 0;
    $221 = $217 + 32 | 0;
    $222 = $221 + $220 | 0;
    $223 = $222 & -64;
    HEAP32[$126 >> 2] = $223;
    $224 = $loader + 132 | 0;
    $225 = HEAP32[$224 >> 2] | 0;
    $226 = $218 + 32 | 0;
    $227 = $226 + $225 | 0;
    $228 = $227 & -64;
    HEAP32[$136 >> 2] = $228;
    $229 = HEAP32[$126 >> 2] | 0;
    $230 = $229 - $217 | 0;
    $231 = $9 + 144 | 0;
    HEAP32[$231 >> 2] = $230;
    $232 = HEAP32[$136 >> 2] | 0;
    $233 = $232 - $218 | 0;
    $234 = $9 + 148 | 0;
    HEAP32[$234 >> 2] = $233;
    label = 25;
    break;
   case 25:
    _FT_GlyphLoader_Add($4);
    $error_1 = 0;
    label = 41;
    break;
   case 26:
    $237 = $9 + 128 | 0;
    $238 = HEAP32[$237 >> 2] | 0;
    $239 = $4 + 20 | 0;
    $240 = $4 + 22 | 0;
    $241 = HEAP16[$240 >> 1] | 0;
    $242 = $241 << 16 >> 16;
    $243 = _FT_GlyphLoader_CheckSubGlyphs($4, $238) | 0;
    $244 = ($243 | 0) == 0;
    if ($244) {
      label = 27;
      break;
    } else {
      $error_2 = $243;
      label = 54;
      break;
    }
   case 27:
    $246 = $4 + 88 | 0;
    $247 = HEAP32[$246 >> 2] | 0;
    $248 = $247;
    $249 = $9 + 132 | 0;
    $250 = HEAP32[$249 >> 2] | 0;
    $251 = $250;
    $252 = $238 << 5;
    _memcpy($248 | 0, $251 | 0, $252 | 0);
    $253 = $4 + 84 | 0;
    HEAP32[$253 >> 2] = $238;
    $254 = $4 + 48 | 0;
    $255 = HEAP32[$254 >> 2] | 0;
    $256 = ($238 | 0) == 0;
    if ($256) {
      $error_1 = 0;
      label = 41;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $257 = $4 + 52 | 0;
    $258 = $loader + 168 | 0;
    $259 = $258;
    $260 = $loader + 176 | 0;
    $261 = $260;
    $262 = $depth + 1 | 0;
    $263 = $4 + 24 | 0;
    $264 = $dummy;
    $265 = $239;
    $266 = $dummy + 4 | 0;
    $267 = $dummy + 2 | 0;
    $268 = $loader + 16 | 0;
    $269 = $loader + 20 | 0;
    $270 = $loader + 24 | 0;
    $271 = $loader + 28 | 0;
    $272 = $4 + 24 | 0;
    $nn_0238 = 0;
    label = 29;
    break;
   case 29:
    $274 = HEAP32[$257 >> 2] | 0;
    $_sum = $nn_0238 + $255 | 0;
    $ld$4$0 = $259 | 0;
    $275$0 = HEAP32[$ld$4$0 >> 2] | 0;
    $ld$5$1 = $259 + 4 | 0;
    $275$1 = HEAP32[$ld$5$1 >> 2] | 0;
    $ld$6$0 = $261 | 0;
    $276$0 = HEAP32[$ld$6$0 >> 2] | 0;
    $ld$7$1 = $261 + 4 | 0;
    $276$1 = HEAP32[$ld$7$1 >> 2] | 0;
    $277 = HEAP16[$240 >> 1] | 0;
    $278 = $277 << 16 >> 16;
    $279 = $274 + ($_sum << 5) | 0;
    $280 = HEAP32[$279 >> 2] | 0;
    $281 = _af_loader_load_g($loader, $scaler, $280, $load_flags, $262) | 0;
    $282 = ($281 | 0) == 0;
    if ($282) {
      label = 30;
      break;
    } else {
      $error_2 = $281;
      label = 54;
      break;
    }
   case 30:
    $284 = HEAP32[$257 >> 2] | 0;
    $285 = $284 + ($_sum << 5) + 4 | 0;
    $286 = HEAP16[$285 >> 1] | 0;
    $287 = $286 & 512;
    $288 = $287 << 16 >> 16 == 0;
    if ($288) {
      label = 31;
      break;
    } else {
      label = 32;
      break;
    }
   case 31:
    $st$8$0 = $259 | 0;
    HEAP32[$st$8$0 >> 2] = $275$0;
    $st$9$1 = $259 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $275$1;
    $st$10$0 = $261 | 0;
    HEAP32[$st$10$0 >> 2] = $276$0;
    $st$11$1 = $261 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $276$1;
    label = 32;
    break;
   case 32:
    $291 = HEAP16[$240 >> 1] | 0;
    $292 = $291 << 16 >> 16;
    $293 = $292 - $278 | 0;
    $294 = HEAP16[$285 >> 1] | 0;
    $295 = $294 & 200;
    $296 = $295 << 16 >> 16 == 0;
    if ($296) {
      label = 36;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    $298 = HEAP32[$272 >> 2] | 0;
    $299 = $298 + ($292 << 3) | 0;
    $300 = $277 << 16 >> 16 < $291 << 16 >> 16;
    if ($300) {
      label = 34;
      break;
    } else {
      label = 36;
      break;
    }
   case 34:
    $301 = $298 + ($278 << 3) | 0;
    $302 = $284 + ($_sum << 5) + 16 | 0;
    $cur_0234 = $301;
    label = 35;
    break;
   case 35:
    _FT_Vector_Transform($cur_0234, $302);
    $304 = $cur_0234 + 8 | 0;
    $305 = $304 >>> 0 < $299 >>> 0;
    if ($305) {
      $cur_0234 = $304;
      label = 35;
      break;
    } else {
      label = 36;
      break;
    }
   case 36:
    $306 = HEAP16[$285 >> 1] | 0;
    $307 = $306 & 2;
    $308 = $307 << 16 >> 16 == 0;
    $309 = $284 + ($_sum << 5) + 8 | 0;
    $310 = HEAP32[$309 >> 2] | 0;
    if ($308) {
      label = 37;
      break;
    } else {
      label = 39;
      break;
    }
   case 37:
    $312 = $284 + ($_sum << 5) + 12 | 0;
    $313 = HEAP32[$312 >> 2] | 0;
    $314 = $310 + $242 | 0;
    $315 = $314 >>> 0 < $278 >>> 0;
    $316 = $313 >>> 0 < $293 >>> 0;
    $or_cond233 = $315 & $316;
    if ($or_cond233) {
      label = 38;
      break;
    } else {
      $error_2 = 21;
      label = 54;
      break;
    }
   case 38:
    $318 = HEAP32[$263 >> 2] | 0;
    $319 = $278 + $242 | 0;
    $_sum229 = $319 + $313 | 0;
    $320 = $318 + ($314 << 3) | 0;
    $321 = HEAP32[$320 >> 2] | 0;
    $322 = $318 + ($_sum229 << 3) | 0;
    $323 = HEAP32[$322 >> 2] | 0;
    $324 = $321 - $323 | 0;
    $325 = $318 + ($314 << 3) + 4 | 0;
    $326 = HEAP32[$325 >> 2] | 0;
    $327 = $318 + ($_sum229 << 3) + 4 | 0;
    $328 = HEAP32[$327 >> 2] | 0;
    $329 = $326 - $328 | 0;
    $x_0 = $324;
    $y_0 = $329;
    label = 40;
    break;
   case 39:
    $331 = HEAP32[$268 >> 2] | 0;
    $332 = _FT_MulFix($310, $331) | 0;
    $333 = HEAP32[$269 >> 2] | 0;
    $334 = $284 + ($_sum << 5) + 12 | 0;
    $335 = HEAP32[$334 >> 2] | 0;
    $336 = HEAP32[$270 >> 2] | 0;
    $337 = _FT_MulFix($335, $336) | 0;
    $338 = HEAP32[$271 >> 2] | 0;
    $339 = $332 + 32 | 0;
    $340 = $339 + $333 | 0;
    $341 = $340 & -64;
    $342 = $337 + 32 | 0;
    $343 = $342 + $338 | 0;
    $344 = $343 & -64;
    $x_0 = $341;
    $y_0 = $344;
    label = 40;
    break;
   case 40:
    _memcpy($264 | 0, $265 | 0, 20);
    $346 = HEAP32[$266 >> 2] | 0;
    $347 = $346 + ($278 << 3) | 0;
    HEAP32[$266 >> 2] = $347;
    $348 = $293 & 65535;
    HEAP16[$267 >> 1] = $348;
    _FT_Outline_Translate($dummy, $x_0, $y_0);
    $349 = $nn_0238 + 1 | 0;
    $350 = $349 >>> 0 < $238 >>> 0;
    if ($350) {
      $nn_0238 = $349;
      label = 29;
      break;
    } else {
      $error_1 = $281;
      label = 41;
      break;
    }
   case 41:
    $351 = ($depth | 0) == 0;
    if ($351) {
      label = 42;
      break;
    } else {
      $error_2 = $error_1;
      label = 54;
      break;
    }
   case 42:
    $353 = $9 + 44 | 0;
    $354 = HEAP32[$353 >> 2] | 0;
    $355 = $9 + 32 | 0;
    $356 = HEAP32[$355 >> 2] | 0;
    $357 = $354 - $356 | 0;
    $358 = $vvector | 0;
    HEAP32[$358 >> 2] = $357;
    $359 = $9 + 48 | 0;
    $360 = HEAP32[$359 >> 2] | 0;
    $361 = $9 + 36 | 0;
    $362 = HEAP32[$361 >> 2] | 0;
    $363 = $360 - $362 | 0;
    $364 = $vvector + 4 | 0;
    HEAP32[$364 >> 2] = $363;
    $365 = HEAP32[$358 >> 2] | 0;
    $366 = $6 + 8 | 0;
    $367 = HEAP32[$366 >> 2] | 0;
    $368 = _FT_MulFix($365, $367) | 0;
    HEAP32[$358 >> 2] = $368;
    $369 = HEAP32[$364 >> 2] | 0;
    $370 = $6 + 12 | 0;
    $371 = HEAP32[$370 >> 2] | 0;
    $372 = _FT_MulFix($369, $371) | 0;
    HEAP32[$364 >> 2] = $372;
    $373 = HEAP8[$17] | 0;
    $374 = $373 << 24 >> 24 == 0;
    if ($374) {
      label = 44;
      break;
    } else {
      label = 43;
      break;
    }
   case 43:
    $376 = $4 + 20 | 0;
    $377 = $loader + 144 | 0;
    _FT_Outline_Transform($376, $377);
    _FT_Vector_Transform($vvector, $377);
    label = 44;
    break;
   case 44:
    $379 = $loader + 168 | 0;
    $380 = HEAP32[$379 >> 2] | 0;
    $381 = ($380 | 0) == 0;
    if ($381) {
      label = 46;
      break;
    } else {
      label = 45;
      break;
    }
   case 45:
    $383 = $4 + 20 | 0;
    $384 = -$380 | 0;
    _FT_Outline_Translate($383, $384, 0);
    label = 46;
    break;
   case 46:
    $386 = $4 + 20 | 0;
    _FT_Outline_Get_CBox($386, $bbox);
    $387 = $bbox | 0;
    $388 = HEAP32[$387 >> 2] | 0;
    $389 = $388 & -64;
    HEAP32[$387 >> 2] = $389;
    $390 = $bbox + 4 | 0;
    $391 = HEAP32[$390 >> 2] | 0;
    $392 = $391 & -64;
    HEAP32[$390 >> 2] = $392;
    $393 = $bbox + 8 | 0;
    $394 = HEAP32[$393 >> 2] | 0;
    $395 = $394 + 63 | 0;
    $396 = $395 & -64;
    HEAP32[$393 >> 2] = $396;
    $397 = $bbox + 12 | 0;
    $398 = HEAP32[$397 >> 2] | 0;
    $399 = $398 + 63 | 0;
    $400 = $399 & -64;
    HEAP32[$397 >> 2] = $400;
    $401 = HEAP32[$393 >> 2] | 0;
    $402 = HEAP32[$387 >> 2] | 0;
    $403 = $401 - $402 | 0;
    $404 = $9 + 24 | 0;
    HEAP32[$404 >> 2] = $403;
    $405 = HEAP32[$397 >> 2] | 0;
    $406 = HEAP32[$390 >> 2] | 0;
    $407 = $405 - $406 | 0;
    $408 = $9 + 28 | 0;
    HEAP32[$408 >> 2] = $407;
    $409 = HEAP32[$387 >> 2] | 0;
    HEAP32[$355 >> 2] = $409;
    $410 = HEAP32[$397 >> 2] | 0;
    HEAP32[$361 >> 2] = $410;
    $411 = HEAP32[$387 >> 2] | 0;
    $412 = HEAP32[$358 >> 2] | 0;
    $413 = $412 + $411 | 0;
    $414 = $413 & -64;
    HEAP32[$353 >> 2] = $414;
    $415 = HEAP32[$397 >> 2] | 0;
    $416 = HEAP32[$364 >> 2] | 0;
    $417 = $416 + $415 | 0;
    $418 = $417 & -64;
    HEAP32[$359 >> 2] = $418;
    $419 = $9 + 4 | 0;
    $420 = HEAP32[$419 >> 2] | 0;
    $421 = $420 + 8 | 0;
    $422 = HEAP32[$421 >> 2] | 0;
    $423 = $422 & 4;
    $424 = ($423 | 0) == 0;
    if ($424) {
      label = 47;
      break;
    } else {
      label = 49;
      break;
    }
   case 47:
    $426 = $loader + 4 | 0;
    $427 = HEAP32[$426 >> 2] | 0;
    $428 = _af_face_globals_is_digit($427, $glyph_index) | 0;
    $429 = $428 << 24 >> 24 == 0;
    if ($429) {
      label = 50;
      break;
    } else {
      label = 48;
      break;
    }
   case 48:
    $431 = $6 + 32 | 0;
    $432 = HEAP8[$431] | 0;
    $433 = $432 << 24 >> 24 == 0;
    if ($433) {
      label = 50;
      break;
    } else {
      label = 49;
      break;
    }
   case 49:
    $435 = HEAP32[$32 >> 2] | 0;
    $436 = HEAP32[$366 >> 2] | 0;
    $437 = _FT_MulFix($435, $436) | 0;
    HEAP32[$32 >> 2] = $437;
    $438 = $9 + 144 | 0;
    HEAP32[$438 >> 2] = 0;
    $439 = $9 + 148 | 0;
    HEAP32[$439 >> 2] = 0;
    label = 52;
    break;
   case 50:
    $441 = HEAP32[$32 >> 2] | 0;
    $442 = ($441 | 0) == 0;
    if ($442) {
      label = 52;
      break;
    } else {
      label = 51;
      break;
    }
   case 51:
    $444 = $loader + 176 | 0;
    $445 = HEAP32[$444 >> 2] | 0;
    $446 = HEAP32[$379 >> 2] | 0;
    $447 = $445 - $446 | 0;
    HEAP32[$32 >> 2] = $447;
    label = 52;
    break;
   case 52:
    $449 = HEAP32[$35 >> 2] | 0;
    $450 = HEAP32[$370 >> 2] | 0;
    $451 = _FT_MulFix($449, $450) | 0;
    HEAP32[$35 >> 2] = $451;
    $452 = HEAP32[$32 >> 2] | 0;
    $453 = $452 + 32 | 0;
    $454 = $453 & -64;
    HEAP32[$32 >> 2] = $454;
    $455 = HEAP32[$35 >> 2] | 0;
    $456 = $455 + 32 | 0;
    $457 = $456 & -64;
    HEAP32[$35 >> 2] = $457;
    $458 = $11 | 0;
    $459 = HEAP32[$458 >> 2] | 0;
    _FT_GlyphLoader_Rewind($459);
    $460 = HEAP32[$458 >> 2] | 0;
    $461 = _FT_GlyphLoader_CopyPoints($460, $4) | 0;
    $462 = ($461 | 0) == 0;
    if ($462) {
      label = 53;
      break;
    } else {
      $error_2 = $461;
      label = 54;
      break;
    }
   case 53:
    $464 = $9 + 108 | 0;
    $465 = HEAP32[$458 >> 2] | 0;
    $466 = $465 + 20 | 0;
    $467 = $464;
    $468 = $466;
    _memcpy($467 | 0, $468 | 0, 20);
    HEAP32[$38 >> 2] = 1869968492;
    $error_2 = 0;
    label = 54;
    break;
   case 54:
    STACKTOP = __stackBase__;
    return $error_2 | 0;
  }
  return 0;
}
function _af_face_globals_new($face, $aglobals) {
  $face = $face | 0;
  $aglobals = $aglobals | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $globals_0 = 0, $22 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $face + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $face + 16 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 28 | 0;
    $6 = _ft_mem_alloc($2, $5, $error) | 0;
    $7 = $6;
    $8 = HEAP32[$error >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 2;
      break;
    } else {
      $globals_0 = $7;
      label = 4;
      break;
    }
   case 2:
    $11 = $6;
    HEAP32[$11 >> 2] = $face;
    $12 = HEAP32[$3 >> 2] | 0;
    $13 = $6 + 4 | 0;
    $14 = $13;
    HEAP32[$14 >> 2] = $12;
    $15 = $6 + 28 | 0;
    $16 = $6 + 8 | 0;
    $17 = $16;
    HEAP32[$17 >> 2] = $15;
    $18 = _af_face_globals_compute_script_coverage($7) | 0;
    HEAP32[$error >> 2] = $18;
    $19 = ($18 | 0) == 0;
    if ($19) {
      $globals_0 = $7;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    _af_face_globals_free($7);
    $globals_0 = 0;
    label = 4;
    break;
   case 4:
    HEAP32[$aglobals >> 2] = $globals_0;
    $22 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $22 | 0;
  }
  return 0;
}
function _af_face_globals_free($globals) {
  $globals = $globals | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($globals | 0) == 0;
    if ($1) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $globals | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 100 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $globals + 12 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = $8;
    _ft_mem_free($6, $11);
    HEAP32[$7 >> 2] = 0;
    label = 4;
    break;
   case 4:
    $13 = $globals + 16 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    return;
   case 6:
    $18 = $14;
    _ft_mem_free($6, $18);
    HEAP32[$13 >> 2] = 0;
    label = 7;
    break;
   case 7:
    $20 = $globals + 20 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $24 = $21;
    _ft_mem_free($6, $24);
    HEAP32[$20 >> 2] = 0;
    label = 9;
    break;
   case 9:
    $26 = $globals + 24 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = ($27 | 0) == 0;
    if ($28) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $30 = $27;
    _ft_mem_free($6, $30);
    HEAP32[$26 >> 2] = 0;
    label = 11;
    break;
   case 11:
    $32 = $globals + 4 | 0;
    HEAP32[$32 >> 2] = 0;
    $33 = $globals + 8 | 0;
    HEAP32[$33 >> 2] = 0;
    HEAP32[$3 >> 2] = 0;
    $34 = $globals;
    _ft_mem_free($6, $34);
    label = 5;
    break;
  }
}
function _af_face_globals_compute_script_coverage($globals) {
  $globals = $globals | 0;
  var $gindex = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $ss_049 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $range_046 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $i_040 = 0, $58 = 0, $59 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $66 = 0, $68 = 0, $exitcond = 0, $error_0 = 0, $69 = 0, $70 = 0, $nn_039 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $76 = 0, $77 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $gindex = __stackBase__ | 0;
    $1 = $globals | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 92 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $globals + 8 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $globals + 4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    _memset($6 | 0, 127, $8 | 0);
    $9 = _FT_Select_Charmap($2, 1970170211) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      $ss_049 = 0;
      label = 2;
      break;
    } else {
      $error_0 = 0;
      label = 21;
      break;
    }
   case 2:
    $11 = 5318356 + ($ss_049 << 2) | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + 4 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 16;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $16 = $14 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 16;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $19 = $ss_049 & 255;
    $20 = $ss_049 & 255;
    $range_046 = $14;
    $22 = $17;
    label = 5;
    break;
   case 5:
    $23 = _FT_Get_Char_Index($2, $22) | 0;
    HEAP32[$gindex >> 2] = $23;
    $24 = ($23 | 0) == 0;
    if ($24) {
      label = 9;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $26 = HEAP32[$7 >> 2] | 0;
    $27 = $23 >>> 0 < $26 >>> 0;
    if ($27) {
      label = 7;
      break;
    } else {
      label = 9;
      break;
    }
   case 7:
    $29 = $6 + $23 | 0;
    $30 = HEAP8[$29] | 0;
    $31 = $30 << 24 >> 24 == 127;
    if ($31) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    HEAP8[$29] = $19;
    label = 9;
    break;
   case 9:
    $33 = $range_046 + 4 | 0;
    $34 = _FT_Get_Next_Char($2, $22, $gindex) | 0;
    $35 = HEAP32[$gindex >> 2] | 0;
    $36 = ($35 | 0) == 0;
    if ($36) {
      label = 15;
      break;
    } else {
      $38 = $34;
      $37 = $35;
      label = 10;
      break;
    }
   case 10:
    $39 = HEAP32[$33 >> 2] | 0;
    $40 = $38 >>> 0 > $39 >>> 0;
    if ($40) {
      label = 15;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $42 = HEAP32[$7 >> 2] | 0;
    $43 = $37 >>> 0 < $42 >>> 0;
    if ($43) {
      label = 12;
      break;
    } else {
      label = 14;
      break;
    }
   case 12:
    $45 = $6 + $37 | 0;
    $46 = HEAP8[$45] | 0;
    $47 = $46 << 24 >> 24 == 127;
    if ($47) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    HEAP8[$45] = $20;
    label = 14;
    break;
   case 14:
    $49 = _FT_Get_Next_Char($2, $38, $gindex) | 0;
    $50 = HEAP32[$gindex >> 2] | 0;
    $51 = ($50 | 0) == 0;
    if ($51) {
      label = 15;
      break;
    } else {
      $38 = $49;
      $37 = $50;
      label = 10;
      break;
    }
   case 15:
    $52 = $range_046 + 8 | 0;
    $53 = $52 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = ($54 | 0) == 0;
    if ($55) {
      label = 16;
      break;
    } else {
      $range_046 = $52;
      $22 = $54;
      label = 5;
      break;
    }
   case 16:
    $56 = $ss_049 + 1 | 0;
    $57 = ($56 | 0) == 4;
    if ($57) {
      $i_040 = 48;
      label = 17;
      break;
    } else {
      $ss_049 = $56;
      label = 2;
      break;
    }
   case 17:
    $58 = _FT_Get_Char_Index($2, $i_040) | 0;
    $59 = ($58 | 0) == 0;
    if ($59) {
      label = 20;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $61 = HEAP32[$7 >> 2] | 0;
    $62 = $58 >>> 0 < $61 >>> 0;
    if ($62) {
      label = 19;
      break;
    } else {
      label = 20;
      break;
    }
   case 19:
    $64 = $6 + $58 | 0;
    $65 = HEAP8[$64] | 0;
    $66 = $65 | -128;
    HEAP8[$64] = $66;
    label = 20;
    break;
   case 20:
    $68 = $i_040 + 1 | 0;
    $exitcond = ($68 | 0) == 58;
    if ($exitcond) {
      $error_0 = $9;
      label = 21;
      break;
    } else {
      $i_040 = $68;
      label = 17;
      break;
    }
   case 21:
    $69 = HEAP32[$7 >> 2] | 0;
    $70 = ($69 | 0) > 0;
    if ($70) {
      $nn_039 = 0;
      label = 22;
      break;
    } else {
      label = 25;
      break;
    }
   case 22:
    $71 = $6 + $nn_039 | 0;
    $72 = HEAP8[$71] | 0;
    $73 = $72 & 127;
    $74 = $73 << 24 >> 24 == 127;
    if ($74) {
      label = 23;
      break;
    } else {
      label = 24;
      break;
    }
   case 23:
    $76 = $72 & -128;
    $77 = $76 | 2;
    HEAP8[$71] = $77;
    label = 24;
    break;
   case 24:
    $79 = $nn_039 + 1 | 0;
    $80 = HEAP32[$7 >> 2] | 0;
    $81 = ($79 | 0) < ($80 | 0);
    if ($81) {
      $nn_039 = $79;
      label = 22;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $82 = _FT_Set_Charmap($2, $4) | 0;
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _af_cjk_align_edge_points($hints, $dim) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $not_ = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $edge_033 = 0, $20 = 0, $21 = 0, $22 = 0, $seg_0 = 0, $23 = 0, $24 = 0, $point_0_in = 0, $point_0 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $seg_1 = 0, $52 = 0, $53 = 0, $point1_0_in = 0, $point1_0 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 48 + ($dim * 28 & -1) + 20 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $hints + 48 + ($dim * 28 & -1) + 12 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + ($4 * 48 & -1) | 0;
    $6 = ($dim | 0) == 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $8 = $hints + 108 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 & 1;
    $not_ = ($10 | 0) != 0;
    $18 = $not_;
    label = 5;
    break;
   case 3:
    $12 = ($dim | 0) == 1;
    if ($12) {
      label = 4;
      break;
    } else {
      $18 = 0;
      label = 5;
      break;
    }
   case 4:
    $14 = $hints + 108 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15 & 2;
    $17 = ($16 | 0) != 0;
    $18 = $17;
    label = 5;
    break;
   case 5:
    $19 = ($4 | 0) > 0;
    if ($19) {
      $edge_033 = $2;
      label = 6;
      break;
    } else {
      label = 21;
      break;
    }
   case 6:
    $20 = $edge_033 + 40 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $edge_033 + 8 | 0;
    if ($18) {
      $seg_0 = $21;
      label = 7;
      break;
    } else {
      label = 13;
      break;
    }
   case 7:
    $23 = $seg_0 + 40 | 0;
    $24 = $seg_0 + 44 | 0;
    $point_0_in = $23;
    label = 8;
    break;
   case 8:
    $point_0 = HEAP32[$point_0_in >> 2] | 0;
    $26 = HEAP32[$22 >> 2] | 0;
    if ($6) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $28 = $point_0 + 16 | 0;
    HEAP32[$28 >> 2] = $26;
    $29 = $point_0 | 0;
    $30 = HEAP16[$29 >> 1] | 0;
    $31 = $30 | 64;
    HEAP16[$29 >> 1] = $31;
    label = 11;
    break;
   case 10:
    $33 = $point_0 + 20 | 0;
    HEAP32[$33 >> 2] = $26;
    $34 = $point_0 | 0;
    $35 = HEAP16[$34 >> 1] | 0;
    $36 = $35 | 128;
    HEAP16[$34 >> 1] = $36;
    label = 11;
    break;
   case 11:
    $38 = HEAP32[$24 >> 2] | 0;
    $39 = ($point_0 | 0) == ($38 | 0);
    $40 = $point_0 + 32 | 0;
    if ($39) {
      label = 12;
      break;
    } else {
      $point_0_in = $40;
      label = 8;
      break;
    }
   case 12:
    $42 = $seg_0 + 16 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = HEAP32[$20 >> 2] | 0;
    $45 = ($43 | 0) == ($44 | 0);
    if ($45) {
      label = 20;
      break;
    } else {
      $seg_0 = $43;
      label = 7;
      break;
    }
   case 13:
    $47 = HEAP32[$22 >> 2] | 0;
    $48 = $edge_033 + 4 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = $47 - $49 | 0;
    $seg_1 = $21;
    label = 14;
    break;
   case 14:
    $52 = $seg_1 + 40 | 0;
    $53 = $seg_1 + 44 | 0;
    $point1_0_in = $52;
    label = 15;
    break;
   case 15:
    $point1_0 = HEAP32[$point1_0_in >> 2] | 0;
    if ($6) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    $56 = $point1_0 + 16 | 0;
    $57 = HEAP32[$56 >> 2] | 0;
    $58 = $57 + $50 | 0;
    HEAP32[$56 >> 2] = $58;
    $59 = $point1_0 | 0;
    $60 = HEAP16[$59 >> 1] | 0;
    $61 = $60 | 64;
    HEAP16[$59 >> 1] = $61;
    label = 18;
    break;
   case 17:
    $63 = $point1_0 + 20 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = $64 + $50 | 0;
    HEAP32[$63 >> 2] = $65;
    $66 = $point1_0 | 0;
    $67 = HEAP16[$66 >> 1] | 0;
    $68 = $67 | 128;
    HEAP16[$66 >> 1] = $68;
    label = 18;
    break;
   case 18:
    $70 = HEAP32[$53 >> 2] | 0;
    $71 = ($point1_0 | 0) == ($70 | 0);
    $72 = $point1_0 + 32 | 0;
    if ($71) {
      label = 19;
      break;
    } else {
      $point1_0_in = $72;
      label = 15;
      break;
    }
   case 19:
    $74 = $seg_1 + 16 | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    $76 = HEAP32[$20 >> 2] | 0;
    $77 = ($75 | 0) == ($76 | 0);
    if ($77) {
      label = 20;
      break;
    } else {
      $seg_1 = $75;
      label = 14;
      break;
    }
   case 20:
    $78 = $edge_033 + 48 | 0;
    $79 = $78 >>> 0 < $5 >>> 0;
    if ($79) {
      $edge_033 = $78;
      label = 6;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    return;
  }
}
function _af_glyph_hints_reload($hints, $outline) {
  $hints = $hints | 0;
  $outline = $outline | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $point_0138 = 0, $vec_0137 = 0, $contour_index_0136 = 0, $prev_0135 = 0, $end_0134 = 0, $tag_0133 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $105 = 0, $107 = 0, $109 = 0, $111 = 0, $112 = 0, $113 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $end_1 = 0, $prev_1 = 0, $contour_index_1 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $idx_0131 = 0, $end1_0130 = 0, $contour_0129 = 0, $sext123 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $point_1128 = 0, $in_dir_0127 = 0, $in_y_0126 = 0, $in_x_0125 = 0, $first_0124 = 0, $146 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $first_1 = 0, $in_x_1 = 0, $in_y_1 = 0, $in_dir_1 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $193 = 0, $194 = 0, $sext = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $201 = 0, $203 = 0, $204 = 0, $206 = 0, $207 = 0, $209 = 0, $210 = 0, $211 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $hints + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $hints + 12 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $hints + 8 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $hints + 16 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $hints | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $hints + 28 | 0;
    HEAP32[$11 >> 2] = 0;
    $12 = $hints + 40 | 0;
    HEAP32[$12 >> 2] = 0;
    $13 = $hints + 48 | 0;
    HEAP32[$13 >> 2] = 0;
    $14 = $hints + 60 | 0;
    HEAP32[$14 >> 2] = 0;
    $15 = $hints + 76 | 0;
    HEAP32[$15 >> 2] = 0;
    $16 = $hints + 88 | 0;
    HEAP32[$16 >> 2] = 0;
    $17 = $outline | 0;
    $18 = HEAP16[$17 >> 1] | 0;
    $19 = $18 << 16 >> 16;
    $20 = $hints + 36 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $19 >>> 0 > $21 >>> 0;
    if ($22) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $24 = $19 + 3 | 0;
    $25 = $24 & -4;
    $26 = $hints + 44 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $27;
    $29 = _ft_mem_realloc($10, 4, $21, $25, $28, $error) | 0;
    $30 = $29;
    HEAP32[$26 >> 2] = $30;
    $31 = HEAP32[$error >> 2] | 0;
    $32 = ($31 | 0) == 0;
    if ($32) {
      label = 3;
      break;
    } else {
      label = 33;
      break;
    }
   case 3:
    HEAP32[$20 >> 2] = $25;
    label = 4;
    break;
   case 4:
    $35 = $outline + 2 | 0;
    $36 = HEAP16[$35 >> 1] | 0;
    $37 = $36 << 16 >> 16;
    $38 = $37 + 2 | 0;
    $39 = $hints + 24 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $38 >>> 0 > $40 >>> 0;
    if ($41) {
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    $43 = $37 + 11 | 0;
    $44 = $43 & -8;
    $45 = $hints + 32 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $46;
    $48 = _ft_mem_realloc($10, 40, $40, $44, $47, $error) | 0;
    $49 = $48;
    HEAP32[$45 >> 2] = $49;
    $50 = HEAP32[$error >> 2] | 0;
    $51 = ($50 | 0) == 0;
    if ($51) {
      label = 6;
      break;
    } else {
      label = 33;
      break;
    }
   case 6:
    HEAP32[$39 >> 2] = $44;
    label = 7;
    break;
   case 7:
    $54 = HEAP16[$35 >> 1] | 0;
    $55 = $54 << 16 >> 16;
    HEAP32[$11 >> 2] = $55;
    $56 = HEAP16[$17 >> 1] | 0;
    $57 = $56 << 16 >> 16;
    HEAP32[$12 >> 2] = $57;
    $58 = $hints + 72 | 0;
    HEAP32[$58 >> 2] = 2;
    $59 = $hints + 100 | 0;
    HEAP32[$59 >> 2] = -1;
    $60 = _FT_Outline_Get_Orientation($outline) | 0;
    $61 = ($60 | 0) == 1;
    if ($61) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    HEAP32[$58 >> 2] = -2;
    HEAP32[$59 >> 2] = 1;
    label = 9;
    break;
   case 9:
    HEAP32[$1 >> 2] = $2;
    HEAP32[$3 >> 2] = $4;
    HEAP32[$5 >> 2] = $6;
    HEAP32[$7 >> 2] = $8;
    $64 = $hints + 116 | 0;
    HEAP32[$64 >> 2] = 0;
    $65 = $hints + 120 | 0;
    HEAP32[$65 >> 2] = 0;
    $66 = $hints + 32 | 0;
    $67 = HEAP32[$66 >> 2] | 0;
    $68 = HEAP32[$11 >> 2] | 0;
    $69 = ($68 | 0) == 0;
    if ($69) {
      label = 33;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $71 = $67 + ($68 * 40 & -1) | 0;
    $72 = $outline + 12 | 0;
    $73 = HEAP32[$72 >> 2] | 0;
    $74 = HEAP16[$73 >> 1] | 0;
    $75 = $74 << 16 >> 16;
    $76 = $67 + ($75 * 40 & -1) | 0;
    $77 = ($68 | 0) > 0;
    if ($77) {
      label = 11;
      break;
    } else {
      label = 20;
      break;
    }
   case 11:
    $78 = $outline + 8 | 0;
    $79 = $outline + 4 | 0;
    $80 = HEAP32[$78 >> 2] | 0;
    $81 = HEAP32[$79 >> 2] | 0;
    $tag_0133 = $80;
    $end_0134 = $76;
    $prev_0135 = $76;
    $contour_index_0136 = 0;
    $vec_0137 = $81;
    $point_0138 = $67;
    label = 12;
    break;
   case 12:
    $83 = $vec_0137 | 0;
    $84 = HEAP32[$83 >> 2] | 0;
    $85 = $84 & 65535;
    $86 = $point_0138 + 12 | 0;
    HEAP16[$86 >> 1] = $85;
    $87 = $vec_0137 + 4 | 0;
    $88 = HEAP32[$87 >> 2] | 0;
    $89 = $88 & 65535;
    $90 = $point_0138 + 14 | 0;
    HEAP16[$90 >> 1] = $89;
    $91 = HEAP32[$83 >> 2] | 0;
    $92 = _FT_MulFix($91, $2) | 0;
    $93 = $92 + $6 | 0;
    $94 = $point_0138 + 16 | 0;
    HEAP32[$94 >> 2] = $93;
    $95 = $point_0138 + 4 | 0;
    HEAP32[$95 >> 2] = $93;
    $96 = HEAP32[$87 >> 2] | 0;
    $97 = _FT_MulFix($96, $4) | 0;
    $98 = $97 + $8 | 0;
    $99 = $point_0138 + 20 | 0;
    HEAP32[$99 >> 2] = $98;
    $100 = $point_0138 + 8 | 0;
    HEAP32[$100 >> 2] = $98;
    $101 = HEAP8[$tag_0133] | 0;
    $102 = $101 & 255;
    $103 = $102 & 3;
    if (($103 | 0) == 0) {
      label = 13;
      break;
    } else if (($103 | 0) == 2) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 13:
    $105 = $point_0138 | 0;
    HEAP16[$105 >> 1] = 1;
    label = 16;
    break;
   case 14:
    $107 = $point_0138 | 0;
    HEAP16[$107 >> 1] = 2;
    label = 16;
    break;
   case 15:
    $109 = $point_0138 | 0;
    HEAP16[$109 >> 1] = 0;
    label = 16;
    break;
   case 16:
    $111 = $point_0138 + 36 | 0;
    HEAP32[$111 >> 2] = $prev_0135;
    $112 = $prev_0135 + 32 | 0;
    HEAP32[$112 >> 2] = $point_0138;
    $113 = ($point_0138 | 0) == ($end_0134 | 0);
    if ($113) {
      label = 17;
      break;
    } else {
      $contour_index_1 = $contour_index_0136;
      $prev_1 = $point_0138;
      $end_1 = $end_0134;
      label = 19;
      break;
    }
   case 17:
    $115 = $contour_index_0136 + 1 | 0;
    $116 = HEAP16[$17 >> 1] | 0;
    $117 = $116 << 16 >> 16;
    $118 = ($115 | 0) < ($117 | 0);
    if ($118) {
      label = 18;
      break;
    } else {
      $contour_index_1 = $115;
      $prev_1 = $point_0138;
      $end_1 = $end_0134;
      label = 19;
      break;
    }
   case 18:
    $120 = HEAP32[$72 >> 2] | 0;
    $121 = $120 + ($115 << 1) | 0;
    $122 = HEAP16[$121 >> 1] | 0;
    $123 = $122 << 16 >> 16;
    $124 = $67 + ($123 * 40 & -1) | 0;
    $contour_index_1 = $115;
    $prev_1 = $124;
    $end_1 = $124;
    label = 19;
    break;
   case 19:
    $126 = $point_0138 + 40 | 0;
    $127 = $vec_0137 + 8 | 0;
    $128 = $tag_0133 + 1 | 0;
    $129 = $126 >>> 0 < $71 >>> 0;
    if ($129) {
      $tag_0133 = $128;
      $end_0134 = $end_1;
      $prev_0135 = $prev_1;
      $contour_index_0136 = $contour_index_1;
      $vec_0137 = $127;
      $point_0138 = $126;
      label = 12;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $130 = $hints + 44 | 0;
    $131 = HEAP32[$130 >> 2] | 0;
    $132 = HEAP32[$12 >> 2] | 0;
    $133 = $131 + ($132 << 2) | 0;
    $134 = ($132 | 0) > 0;
    if ($134) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    $135 = HEAP32[$72 >> 2] | 0;
    $contour_0129 = $131;
    $end1_0130 = $135;
    $idx_0131 = 0;
    label = 23;
    break;
   case 22:
    $136 = ($68 | 0) > 0;
    if ($136) {
      $first_0124 = $67;
      $in_x_0125 = 0;
      $in_y_0126 = 0;
      $in_dir_0127 = 4;
      $point_1128 = $67;
      label = 24;
      break;
    } else {
      label = 33;
      break;
    }
   case 23:
    $sext123 = $idx_0131 << 16;
    $138 = $sext123 >> 16;
    $139 = $67 + ($138 * 40 & -1) | 0;
    HEAP32[$contour_0129 >> 2] = $139;
    $140 = HEAP16[$end1_0130 >> 1] | 0;
    $141 = $140 << 16 >> 16;
    $142 = $141 + 1 | 0;
    $143 = $contour_0129 + 4 | 0;
    $144 = $end1_0130 + 2 | 0;
    $145 = $143 >>> 0 < $133 >>> 0;
    if ($145) {
      $contour_0129 = $143;
      $end1_0130 = $144;
      $idx_0131 = $142;
      label = 23;
      break;
    } else {
      label = 22;
      break;
    }
   case 24:
    $146 = ($point_1128 | 0) == ($first_0124 | 0);
    if ($146) {
      label = 25;
      break;
    } else {
      $in_dir_1 = $in_dir_0127;
      $in_y_1 = $in_y_0126;
      $in_x_1 = $in_x_0125;
      $first_1 = $first_0124;
      label = 26;
      break;
    }
   case 25:
    $148 = $first_0124 + 36 | 0;
    $149 = HEAP32[$148 >> 2] | 0;
    $150 = $first_0124 + 12 | 0;
    $151 = HEAP16[$150 >> 1] | 0;
    $152 = $151 << 16 >> 16;
    $153 = $149 + 12 | 0;
    $154 = HEAP16[$153 >> 1] | 0;
    $155 = $154 << 16 >> 16;
    $156 = $152 - $155 | 0;
    $157 = $first_0124 + 14 | 0;
    $158 = HEAP16[$157 >> 1] | 0;
    $159 = $158 << 16 >> 16;
    $160 = $149 + 14 | 0;
    $161 = HEAP16[$160 >> 1] | 0;
    $162 = $161 << 16 >> 16;
    $163 = $159 - $162 | 0;
    $164 = _af_direction_compute($156, $163) | 0;
    $165 = $149 + 40 | 0;
    $in_dir_1 = $164;
    $in_y_1 = $163;
    $in_x_1 = $156;
    $first_1 = $165;
    label = 26;
    break;
   case 26:
    $167 = $in_dir_1 & 255;
    $168 = $point_1128 + 2 | 0;
    HEAP8[$168] = $167;
    $169 = $point_1128 + 32 | 0;
    $170 = HEAP32[$169 >> 2] | 0;
    $171 = $170 + 12 | 0;
    $172 = HEAP16[$171 >> 1] | 0;
    $173 = $172 << 16 >> 16;
    $174 = $point_1128 + 12 | 0;
    $175 = HEAP16[$174 >> 1] | 0;
    $176 = $175 << 16 >> 16;
    $177 = $173 - $176 | 0;
    $178 = $170 + 14 | 0;
    $179 = HEAP16[$178 >> 1] | 0;
    $180 = $179 << 16 >> 16;
    $181 = $point_1128 + 14 | 0;
    $182 = HEAP16[$181 >> 1] | 0;
    $183 = $182 << 16 >> 16;
    $184 = $180 - $183 | 0;
    $185 = _af_direction_compute($177, $184) | 0;
    $186 = $185 & 255;
    $187 = $point_1128 + 3 | 0;
    HEAP8[$187] = $186;
    $188 = $point_1128 | 0;
    $189 = HEAP16[$188 >> 1] | 0;
    $190 = $189 & 3;
    $191 = $190 << 16 >> 16 == 0;
    if ($191) {
      label = 28;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $193 = HEAP16[$188 >> 1] | 0;
    $194 = $193 | 256;
    HEAP16[$188 >> 1] = $194;
    label = 32;
    break;
   case 28:
    $sext = $185 << 24;
    $196 = $sext >> 24;
    $197 = HEAP8[$168] | 0;
    $198 = $197 << 24 >> 24;
    $199 = ($196 | 0) == ($198 | 0);
    if ($199) {
      label = 29;
      break;
    } else {
      label = 31;
      break;
    }
   case 29:
    $201 = ($196 | 0) == 4;
    if ($201) {
      label = 30;
      break;
    } else {
      label = 27;
      break;
    }
   case 30:
    $203 = _ft_corner_is_flat($in_x_1, $in_y_1, $177, $184) | 0;
    $204 = ($203 | 0) == 0;
    if ($204) {
      label = 32;
      break;
    } else {
      label = 27;
      break;
    }
   case 31:
    $206 = -$196 | 0;
    $207 = ($198 | 0) == ($206 | 0);
    if ($207) {
      label = 27;
      break;
    } else {
      label = 32;
      break;
    }
   case 32:
    $209 = $point_1128 + 40 | 0;
    $210 = $209 >>> 0 < $71 >>> 0;
    if ($210) {
      $first_0124 = $first_1;
      $in_x_0125 = $177;
      $in_y_0126 = $184;
      $in_dir_0127 = $185;
      $point_1128 = $209;
      label = 24;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    $211 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $211 | 0;
  }
  return 0;
}
function _af_cjk_hints_detect_features($hints, $dim) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  var $1 = 0, $2 = 0, $4 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _af_cjk_hints_compute_segments($hints, $dim) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $error_0 = $1;
      label = 3;
      break;
    }
   case 2:
    _af_cjk_hints_link_segments($hints, $dim);
    $4 = _af_cjk_hints_compute_edges($hints, $dim) | 0;
    $error_0 = $4;
    label = 3;
    break;
   case 3:
    return $error_0 | 0;
  }
  return 0;
}
function _af_cjk_hint_edges($hints, $dim) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $edge_0128 = 0, $anchor_0127 = 0, $delta_0126 = 0, $skipped_0125 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $20 = 0, $22 = 0, $23 = 0, $25 = 0, $or_cond108 = 0, $27 = 0, $29 = 0, $delta_1 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $skipped_1 = 0, $delta_2 = 0, $anchor_1 = 0, $37 = 0, $38 = 0, $skipped_0_lcssa = 0, $_idx = 0, $39 = 0, $41 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $edge1_0 = 0, $edge21_0 = 0, $edge3_0 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $span_0 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $or_cond = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $89 = 0, $90 = 0, $91 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $107 = 0, $108 = 0, $109 = 0, $111 = 0, $112 = 0, $edge_1123 = 0, $skipped_2122 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $118 = 0, $119 = 0, $120 = 0, $122 = 0, $123 = 0, $124 = 0, $skipped_3 = 0, $126 = 0, $127 = 0, $skipped_2_lcssa = 0, $128 = 0, $129 = 0, $or_cond141 = 0, $edge_2119 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $before_0 = 0, $134 = 0, $135 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $after_0 = 0, $141 = 0, $142 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $brmerge = 0, $149 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $163 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $178 = 0, $179 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 48 + ($dim * 28 & -1) + 20 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $hints + 48 + ($dim * 28 & -1) + 12 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + ($4 * 48 & -1) | 0;
    $6 = ($4 | 0) > 0;
    if ($6) {
      label = 2;
      break;
    } else {
      $skipped_0_lcssa = 0;
      label = 13;
      break;
    }
   case 2:
    $7 = ($dim | 0) != 1;
    $skipped_0125 = 0;
    $delta_0126 = 0;
    $anchor_0127 = 0;
    $edge_0128 = $2;
    label = 3;
    break;
   case 3:
    $9 = $edge_0128 + 12 | 0;
    $10 = HEAP8[$9] | 0;
    $11 = $10 & 4;
    $12 = $11 << 24 >> 24 == 0;
    if ($12) {
      label = 4;
      break;
    } else {
      $anchor_1 = $anchor_0127;
      $delta_2 = $delta_0126;
      $skipped_1 = $skipped_0125;
      label = 12;
      break;
    }
   case 4:
    $14 = $edge_0128 + 24 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $18 = $skipped_0125 + 1 | 0;
    $anchor_1 = $anchor_0127;
    $delta_2 = $delta_0126;
    $skipped_1 = $18;
    label = 12;
    break;
   case 6:
    $20 = $15 >>> 0 < $edge_0128 >>> 0;
    if ($20) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    _af_cjk_align_linked_edge($hints, $dim, $15, $edge_0128);
    $22 = HEAP8[$9] | 0;
    $23 = $22 | 4;
    HEAP8[$9] = $23;
    $anchor_1 = $anchor_0127;
    $delta_2 = $delta_0126;
    $skipped_1 = $skipped_0125;
    label = 12;
    break;
   case 8:
    $25 = ($anchor_0127 | 0) == 0;
    $or_cond108 = $7 & $25;
    if ($or_cond108) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $27 = _af_hint_normal_stem($hints, $edge_0128, $15, 0, 0) | 0;
    $delta_1 = $27;
    label = 11;
    break;
   case 10:
    $29 = _af_hint_normal_stem($hints, $edge_0128, $15, $delta_0126, $dim) | 0;
    $delta_1 = $delta_0126;
    label = 11;
    break;
   case 11:
    $31 = HEAP8[$9] | 0;
    $32 = $31 | 4;
    HEAP8[$9] = $32;
    $33 = $15 + 12 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 | 4;
    HEAP8[$33] = $35;
    $anchor_1 = $edge_0128;
    $delta_2 = $delta_1;
    $skipped_1 = $skipped_0125;
    label = 12;
    break;
   case 12:
    $37 = $edge_0128 + 48 | 0;
    $38 = $37 >>> 0 < $5 >>> 0;
    if ($38) {
      $skipped_0125 = $skipped_1;
      $delta_0126 = $delta_2;
      $anchor_0127 = $anchor_1;
      $edge_0128 = $37;
      label = 3;
      break;
    } else {
      $skipped_0_lcssa = $skipped_1;
      label = 13;
      break;
    }
   case 13:
    $_idx = $4 * 48 & -1;
    $39 = ($dim | 0) == 0;
    if ($39) {
      label = 14;
      break;
    } else {
      label = 26;
      break;
    }
   case 14:
    $41 = ($_idx | 0) == 576;
    if (($_idx | 0) == 288) {
      label = 15;
      break;
    } else if (($_idx | 0) == 576) {
      label = 16;
      break;
    } else {
      label = 26;
      break;
    }
   case 15:
    $43 = $2 + 96 | 0;
    $44 = $2 + 192 | 0;
    $edge3_0 = $44;
    $edge21_0 = $43;
    $edge1_0 = $2;
    label = 17;
    break;
   case 16:
    $46 = $2 + 48 | 0;
    $47 = $2 + 240 | 0;
    $48 = $2 + 432 | 0;
    $edge3_0 = $48;
    $edge21_0 = $47;
    $edge1_0 = $46;
    label = 17;
    break;
   case 17:
    $50 = $edge21_0 + 4 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = $edge1_0 + 4 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $51 - $53 | 0;
    $55 = $edge3_0 + 4 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = $51 - $56 | 0;
    $58 = $57 + $54 | 0;
    $59 = ($58 | 0) < 0;
    $60 = -$58 | 0;
    $span_0 = $59 ? $60 : $58;
    $61 = $edge1_0 + 24 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = $edge1_0 + 48 | 0;
    $64 = ($62 | 0) == ($63 | 0);
    if ($64) {
      label = 18;
      break;
    } else {
      label = 26;
      break;
    }
   case 18:
    $66 = $edge21_0 + 24 | 0;
    $67 = HEAP32[$66 >> 2] | 0;
    $68 = $edge21_0 + 48 | 0;
    $69 = ($67 | 0) == ($68 | 0);
    if ($69) {
      label = 19;
      break;
    } else {
      label = 26;
      break;
    }
   case 19:
    $71 = $edge3_0 + 24 | 0;
    $72 = HEAP32[$71 >> 2] | 0;
    $73 = $edge3_0 + 48 | 0;
    $74 = ($72 | 0) == ($73 | 0);
    $75 = ($span_0 | 0) < 8;
    $or_cond = $74 & $75;
    if ($or_cond) {
      label = 20;
      break;
    } else {
      label = 26;
      break;
    }
   case 20:
    $77 = $edge3_0 + 8 | 0;
    $78 = HEAP32[$77 >> 2] | 0;
    $79 = $edge21_0 + 8 | 0;
    $80 = HEAP32[$79 >> 2] | 0;
    $81 = $80 << 1;
    $82 = $edge1_0 + 8 | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = $81 - $83 | 0;
    $85 = $78 - $84 | 0;
    HEAP32[$77 >> 2] = $84;
    $86 = HEAP32[$71 >> 2] | 0;
    $87 = ($86 | 0) == 0;
    if ($87) {
      label = 22;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $89 = $86 + 8 | 0;
    $90 = HEAP32[$89 >> 2] | 0;
    $91 = $90 - $85 | 0;
    HEAP32[$89 >> 2] = $91;
    label = 22;
    break;
   case 22:
    if ($41) {
      label = 23;
      break;
    } else {
      label = 24;
      break;
    }
   case 23:
    $94 = $2 + 392 | 0;
    $95 = HEAP32[$94 >> 2] | 0;
    $96 = $95 - $85 | 0;
    HEAP32[$94 >> 2] = $96;
    $97 = $2 + 536 | 0;
    $98 = HEAP32[$97 >> 2] | 0;
    $99 = $98 - $85 | 0;
    HEAP32[$97 >> 2] = $99;
    label = 24;
    break;
   case 24:
    $101 = $edge3_0 + 12 | 0;
    $102 = HEAP8[$101] | 0;
    $103 = $102 | 4;
    HEAP8[$101] = $103;
    $104 = HEAP32[$71 >> 2] | 0;
    $105 = ($104 | 0) == 0;
    if ($105) {
      label = 26;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $107 = $104 + 12 | 0;
    $108 = HEAP8[$107] | 0;
    $109 = $108 | 4;
    HEAP8[$107] = $109;
    label = 26;
    break;
   case 26:
    $111 = ($skipped_0_lcssa | 0) == 0;
    if ($111) {
      label = 47;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $112 = ($4 | 0) > 0;
    if ($112) {
      $skipped_2122 = $skipped_0_lcssa;
      $edge_1123 = $2;
      label = 28;
      break;
    } else {
      $skipped_2_lcssa = $skipped_0_lcssa;
      label = 32;
      break;
    }
   case 28:
    $113 = $edge_1123 + 12 | 0;
    $114 = HEAP8[$113] | 0;
    $115 = $114 & 4;
    $116 = $115 << 24 >> 24 == 0;
    if ($116) {
      label = 29;
      break;
    } else {
      $skipped_3 = $skipped_2122;
      label = 31;
      break;
    }
   case 29:
    $118 = $edge_1123 + 28 | 0;
    $119 = HEAP32[$118 >> 2] | 0;
    $120 = ($119 | 0) == 0;
    if ($120) {
      $skipped_3 = $skipped_2122;
      label = 31;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    _af_cjk_align_serif_edge($119, $edge_1123);
    $122 = HEAP8[$113] | 0;
    $123 = $122 | 4;
    HEAP8[$113] = $123;
    $124 = $skipped_2122 - 1 | 0;
    $skipped_3 = $124;
    label = 31;
    break;
   case 31:
    $126 = $edge_1123 + 48 | 0;
    $127 = $126 >>> 0 < $5 >>> 0;
    if ($127) {
      $skipped_2122 = $skipped_3;
      $edge_1123 = $126;
      label = 28;
      break;
    } else {
      $skipped_2_lcssa = $skipped_3;
      label = 32;
      break;
    }
   case 32:
    $128 = ($skipped_2_lcssa | 0) != 0;
    $129 = ($4 | 0) > 0;
    $or_cond141 = $128 & $129;
    if ($or_cond141) {
      $edge_2119 = $2;
      label = 33;
      break;
    } else {
      label = 47;
      break;
    }
   case 33:
    $130 = $edge_2119 + 12 | 0;
    $131 = HEAP8[$130] | 0;
    $132 = $131 & 4;
    $133 = $132 << 24 >> 24 == 0;
    if ($133) {
      $before_0 = $edge_2119;
      label = 34;
      break;
    } else {
      label = 46;
      break;
    }
   case 34:
    $134 = $before_0 - 48 | 0;
    $135 = $134 >>> 0 >= $2 >>> 0;
    if ($135) {
      label = 35;
      break;
    } else {
      $after_0 = $edge_2119;
      label = 36;
      break;
    }
   case 35:
    $137 = $before_0 - 48 + 12 | 0;
    $138 = HEAP8[$137] | 0;
    $139 = $138 & 4;
    $140 = $139 << 24 >> 24 == 0;
    if ($140) {
      $before_0 = $134;
      label = 34;
      break;
    } else {
      $after_0 = $edge_2119;
      label = 36;
      break;
    }
   case 36:
    $141 = $after_0 + 48 | 0;
    $142 = $141 >>> 0 < $5 >>> 0;
    if ($142) {
      label = 37;
      break;
    } else {
      label = 38;
      break;
    }
   case 37:
    $144 = $after_0 + 60 | 0;
    $145 = HEAP8[$144] | 0;
    $146 = $145 & 4;
    $147 = $146 << 24 >> 24 == 0;
    if ($147) {
      $after_0 = $141;
      label = 36;
      break;
    } else {
      label = 39;
      break;
    }
   case 38:
    $brmerge = $135 | $142;
    if ($brmerge) {
      label = 39;
      break;
    } else {
      label = 46;
      break;
    }
   case 39:
    $149 = $134 >>> 0 < $2 >>> 0;
    if ($149) {
      label = 40;
      break;
    } else {
      label = 41;
      break;
    }
   case 40:
    _af_cjk_align_serif_edge($141, $edge_2119);
    label = 46;
    break;
   case 41:
    if ($142) {
      label = 43;
      break;
    } else {
      label = 42;
      break;
    }
   case 42:
    _af_cjk_align_serif_edge($134, $edge_2119);
    label = 46;
    break;
   case 43:
    $154 = $141 | 0;
    $155 = HEAP16[$154 >> 1] | 0;
    $156 = $134 | 0;
    $157 = HEAP16[$156 >> 1] | 0;
    $158 = $157 << 16 >> 16;
    $159 = $155 << 16 >> 16 == $157 << 16 >> 16;
    $160 = $before_0 - 48 + 8 | 0;
    $161 = HEAP32[$160 >> 2] | 0;
    if ($159) {
      label = 44;
      break;
    } else {
      label = 45;
      break;
    }
   case 44:
    $163 = $edge_2119 + 8 | 0;
    HEAP32[$163 >> 2] = $161;
    label = 46;
    break;
   case 45:
    $165 = $155 << 16 >> 16;
    $166 = $edge_2119 | 0;
    $167 = HEAP16[$166 >> 1] | 0;
    $168 = $167 << 16 >> 16;
    $169 = $168 - $158 | 0;
    $170 = $after_0 + 56 | 0;
    $171 = HEAP32[$170 >> 2] | 0;
    $172 = $171 - $161 | 0;
    $173 = $165 - $158 | 0;
    $174 = _FT_MulDiv($169, $172, $173) | 0;
    $175 = $174 + $161 | 0;
    $176 = $edge_2119 + 8 | 0;
    HEAP32[$176 >> 2] = $175;
    label = 46;
    break;
   case 46:
    $178 = $edge_2119 + 48 | 0;
    $179 = $178 >>> 0 < $5 >>> 0;
    if ($179) {
      $edge_2119 = $178;
      label = 33;
      break;
    } else {
      label = 47;
      break;
    }
   case 47:
    return;
  }
}
function _af_glyph_hints_save($hints, $outline) {
  $hints = $hints | 0;
  $outline = $outline | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $tag_016 = 0, $vec_015 = 0, $point_014 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $25 = 0, $26 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 32 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $hints + 28 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + ($4 * 40 & -1) | 0;
    $6 = ($4 | 0) > 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 9;
      break;
    }
   case 2:
    $7 = $outline + 8 | 0;
    $8 = $outline + 4 | 0;
    $9 = HEAP32[$7 >> 2] | 0;
    $10 = HEAP32[$8 >> 2] | 0;
    $point_014 = $2;
    $vec_015 = $10;
    $tag_016 = $9;
    label = 3;
    break;
   case 3:
    $12 = $point_014 + 16 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $vec_015 | 0;
    HEAP32[$14 >> 2] = $13;
    $15 = $point_014 + 20 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $vec_015 + 4 | 0;
    HEAP32[$17 >> 2] = $16;
    $18 = $point_014 | 0;
    $19 = HEAP16[$18 >> 1] | 0;
    $20 = $19 & 65535;
    $21 = $20 & 1;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    HEAP8[$tag_016] = 0;
    label = 8;
    break;
   case 5:
    $25 = $20 & 2;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    HEAP8[$tag_016] = 2;
    label = 8;
    break;
   case 7:
    HEAP8[$tag_016] = 1;
    label = 8;
    break;
   case 8:
    $30 = $point_014 + 40 | 0;
    $31 = $vec_015 + 8 | 0;
    $32 = $tag_016 + 1 | 0;
    $33 = $30 >>> 0 < $5 >>> 0;
    if ($33) {
      $point_014 = $30;
      $vec_015 = $31;
      $tag_016 = $32;
      label = 3;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    return;
  }
}
function _af_iup_shift($p1, $p2, $ref) {
  $p1 = $p1 | 0;
  $p2 = $p2 | 0;
  $ref = $ref | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $p_115 = 0, $8 = 0, $p_019 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $p_117 = 0, $ref_pn16 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $p_1 = 0, $19 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $ref + 24 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $ref + 28 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 - $4 | 0;
    $6 = ($2 | 0) == ($4 | 0);
    if ($6) {
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $p1 >>> 0 < $ref >>> 0;
    if ($7) {
      $p_019 = $p1;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $p_115 = $ref + 40 | 0;
    $8 = $p_115 >>> 0 > $p2 >>> 0;
    if ($8) {
      label = 6;
      break;
    } else {
      $ref_pn16 = $ref;
      $p_117 = $p_115;
      label = 5;
      break;
    }
   case 4:
    $9 = $p_019 + 28 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10 + $5 | 0;
    $12 = $p_019 + 24 | 0;
    HEAP32[$12 >> 2] = $11;
    $13 = $p_019 + 40 | 0;
    $14 = $13 >>> 0 < $ref >>> 0;
    if ($14) {
      $p_019 = $13;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 5:
    $15 = $ref_pn16 + 68 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $16 + $5 | 0;
    $18 = $ref_pn16 + 64 | 0;
    HEAP32[$18 >> 2] = $17;
    $p_1 = $p_117 + 40 | 0;
    $19 = $p_1 >>> 0 > $p2 >>> 0;
    if ($19) {
      label = 6;
      break;
    } else {
      $ref_pn16 = $p_117;
      $p_117 = $p_1;
      label = 5;
      break;
    }
   case 6:
    return;
  }
}
function _af_cjk_align_serif_edge($base, $serif) {
  $base = $base | 0;
  $serif = $serif | 0;
  HEAP32[$serif + 8 >> 2] = ((HEAP32[$serif + 4 >> 2] | 0) + (HEAP32[$base + 8 >> 2] | 0) | 0) - (HEAP32[$base + 4 >> 2] | 0) | 0;
  return;
}
function _af_glyph_hints_align_strong_points($hints, $dim) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $_ = 0, $11 = 0, $12 = 0, $or_cond81 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $_sum = 0, $17 = 0, $18 = 0, $19 = 0, $_idx = 0, $20 = 0, $21 = 0, $point_076 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $or_cond = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $ou_0_in = 0, $u_0_in_in = 0, $u_0_in = 0, $u_0 = 0, $ou_0 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $nn_0 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $max_0 = 0, $72 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $min_0_ph = 0, $max_0_ph = 0, $83 = 0, $84 = 0, $min_1 = 0, $_sum66 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $u_1 = 0, $115 = 0, $117 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $124 = 0, $125 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 32 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $hints + 28 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + ($4 * 40 & -1) | 0;
    $6 = $hints + 48 + ($dim * 28 & -1) + 20 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $hints + 48 + ($dim * 28 & -1) + 12 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($dim | 0) == 0;
    $_ = $10 ? 64 : 128;
    $11 = ($9 | 0) > 0;
    $12 = ($4 | 0) > 0;
    $or_cond81 = $11 & $12;
    if ($or_cond81) {
      label = 2;
      break;
    } else {
      label = 29;
      break;
    }
   case 2:
    $13 = ($dim | 0) == 1;
    $14 = $7 | 0;
    $15 = $7 + 8 | 0;
    $16 = $7 + 4 | 0;
    $_sum = $9 - 1 | 0;
    $17 = $7 + ($_sum * 48 & -1) | 0;
    $18 = $7 + ($_sum * 48 & -1) + 8 | 0;
    $19 = $7 + ($_sum * 48 & -1) + 4 | 0;
    $_idx = $9 * 48 & -1;
    $20 = ($_idx | 0) / 48 & -1;
    $21 = ($_idx | 0) < 432;
    $point_076 = $2;
    label = 3;
    break;
   case 3:
    $23 = $point_076 | 0;
    $24 = HEAP16[$23 >> 1] | 0;
    $25 = $24 & 65535;
    $26 = $25 & $_;
    $27 = ($26 | 0) != 0;
    $28 = $25 & 768;
    $29 = ($28 | 0) == 256;
    $or_cond = $27 | $29;
    if ($or_cond) {
      label = 28;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    if ($13) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $32 = $point_076 + 14 | 0;
    $33 = $point_076 + 8 | 0;
    $u_0_in_in = $32;
    $ou_0_in = $33;
    label = 7;
    break;
   case 6:
    $35 = $point_076 + 12 | 0;
    $36 = $point_076 + 4 | 0;
    $u_0_in_in = $35;
    $ou_0_in = $36;
    label = 7;
    break;
   case 7:
    $u_0_in = HEAP16[$u_0_in_in >> 1] | 0;
    $u_0 = $u_0_in << 16 >> 16;
    $ou_0 = HEAP32[$ou_0_in >> 2] | 0;
    $38 = HEAP16[$14 >> 1] | 0;
    $39 = $38 << 16 >> 16;
    $40 = $39 - $u_0 | 0;
    $41 = ($40 | 0) > -1;
    if ($41) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $43 = HEAP32[$15 >> 2] | 0;
    $44 = HEAP32[$16 >> 2] | 0;
    $45 = $43 + $ou_0 | 0;
    $46 = $45 - $44 | 0;
    $u_1 = $46;
    label = 24;
    break;
   case 9:
    $48 = HEAP16[$17 >> 1] | 0;
    $49 = $48 << 16 >> 16;
    $50 = $u_0 - $49 | 0;
    $51 = ($50 | 0) > -1;
    if ($51) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $53 = HEAP32[$18 >> 2] | 0;
    $54 = HEAP32[$19 >> 2] | 0;
    $55 = $53 + $ou_0 | 0;
    $56 = $55 - $54 | 0;
    $u_1 = $56;
    label = 24;
    break;
   case 11:
    if ($21) {
      $nn_0 = 0;
      label = 12;
      break;
    } else {
      $max_0_ph = $20;
      $min_0_ph = 0;
      label = 19;
      break;
    }
   case 12:
    $58 = ($nn_0 | 0) < ($20 | 0);
    if ($58) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    $60 = $7 + ($nn_0 * 48 & -1) | 0;
    $61 = HEAP16[$60 >> 1] | 0;
    $62 = $61 << 16 >> 16 < $u_0_in << 16 >> 16;
    $63 = $nn_0 + 1 | 0;
    if ($62) {
      $nn_0 = $63;
      label = 12;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $65 = $7 + ($nn_0 * 48 & -1) | 0;
    $66 = HEAP16[$65 >> 1] | 0;
    $67 = $66 << 16 >> 16 == $u_0_in << 16 >> 16;
    if ($67) {
      label = 15;
      break;
    } else {
      $min_1 = $nn_0;
      label = 21;
      break;
    }
   case 15:
    $69 = $7 + ($nn_0 * 48 & -1) + 8 | 0;
    $70 = HEAP32[$69 >> 2] | 0;
    $u_1 = $70;
    label = 24;
    break;
   case 16:
    $72 = ($min_0_ph | 0) < ($max_0 | 0);
    if ($72) {
      label = 17;
      break;
    } else {
      $min_1 = $min_0_ph;
      label = 21;
      break;
    }
   case 17:
    $74 = $max_0 + $min_0_ph | 0;
    $75 = $74 >> 1;
    $76 = $7 + ($75 * 48 & -1) | 0;
    $77 = HEAP16[$76 >> 1] | 0;
    $78 = $u_0_in << 16 >> 16 < $77 << 16 >> 16;
    if ($78) {
      $max_0 = $75;
      label = 16;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $80 = $u_0_in << 16 >> 16 > $77 << 16 >> 16;
    $81 = $75 + 1 | 0;
    if ($80) {
      $max_0_ph = $max_0;
      $min_0_ph = $81;
      label = 19;
      break;
    } else {
      label = 20;
      break;
    }
   case 19:
    $max_0 = $max_0_ph;
    label = 16;
    break;
   case 20:
    $83 = $7 + ($75 * 48 & -1) + 8 | 0;
    $84 = HEAP32[$83 >> 2] | 0;
    $u_1 = $84;
    label = 24;
    break;
   case 21:
    $_sum66 = $min_1 - 1 | 0;
    $85 = $7 + ($_sum66 * 48 & -1) | 0;
    $86 = $7 + ($_sum66 * 48 & -1) + 16 | 0;
    $87 = HEAP32[$86 >> 2] | 0;
    $88 = ($87 | 0) == 0;
    if ($88) {
      label = 22;
      break;
    } else {
      label = 23;
      break;
    }
   case 22:
    $90 = $7 + ($min_1 * 48 & -1) + 8 | 0;
    $91 = HEAP32[$90 >> 2] | 0;
    $92 = $7 + ($_sum66 * 48 & -1) + 8 | 0;
    $93 = HEAP32[$92 >> 2] | 0;
    $94 = $91 - $93 | 0;
    $95 = $7 + ($min_1 * 48 & -1) | 0;
    $96 = HEAP16[$95 >> 1] | 0;
    $97 = $96 << 16 >> 16;
    $98 = $85 | 0;
    $99 = HEAP16[$98 >> 1] | 0;
    $100 = $99 << 16 >> 16;
    $101 = $97 - $100 | 0;
    $102 = _FT_DivFix($94, $101) | 0;
    HEAP32[$86 >> 2] = $102;
    label = 23;
    break;
   case 23:
    $104 = $7 + ($_sum66 * 48 & -1) + 8 | 0;
    $105 = HEAP32[$104 >> 2] | 0;
    $106 = $85 | 0;
    $107 = HEAP16[$106 >> 1] | 0;
    $108 = $107 << 16 >> 16;
    $109 = $u_0 - $108 | 0;
    $110 = HEAP32[$86 >> 2] | 0;
    $111 = _FT_MulFix($109, $110) | 0;
    $112 = $111 + $105 | 0;
    $u_1 = $112;
    label = 24;
    break;
   case 24:
    if ($10) {
      label = 25;
      break;
    } else {
      label = 26;
      break;
    }
   case 25:
    $115 = $point_076 + 16 | 0;
    HEAP32[$115 >> 2] = $u_1;
    label = 27;
    break;
   case 26:
    $117 = $point_076 + 20 | 0;
    HEAP32[$117 >> 2] = $u_1;
    label = 27;
    break;
   case 27:
    $119 = HEAP16[$23 >> 1] | 0;
    $120 = $119 & 65535;
    $121 = $120 | $_;
    $122 = $121 & 65535;
    HEAP16[$23 >> 1] = $122;
    label = 28;
    break;
   case 28:
    $124 = $point_076 + 40 | 0;
    $125 = $124 >>> 0 < $5 >>> 0;
    if ($125) {
      $point_076 = $124;
      label = 3;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    return;
  }
}
function _af_glyph_hints_align_weak_points($hints, $dim) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $point_084 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $point_188 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $touch_flag_0 = 0, $29 = 0, $contour_080 = 0, $30 = 0, $31 = 0, $32 = 0, $point_2 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $point_3 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $_ph = 0, $point_4 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $61 = 0, $63 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $point_570 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $point_673 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 32 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $hints + 28 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + ($4 * 40 & -1) | 0;
    $6 = $hints + 44 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $hints + 40 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $7 + ($9 << 2) | 0;
    $11 = ($dim | 0) == 0;
    $12 = ($4 | 0) > 0;
    if ($11) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    if ($12) {
      $point_188 = $2;
      label = 5;
      break;
    } else {
      $touch_flag_0 = 128;
      label = 6;
      break;
    }
   case 3:
    if ($12) {
      $point_084 = $2;
      label = 4;
      break;
    } else {
      $touch_flag_0 = 64;
      label = 6;
      break;
    }
   case 4:
    $13 = $point_084 + 16 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $point_084 + 24 | 0;
    HEAP32[$15 >> 2] = $14;
    $16 = $point_084 + 4 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $point_084 + 28 | 0;
    HEAP32[$18 >> 2] = $17;
    $19 = $point_084 + 40 | 0;
    $20 = $19 >>> 0 < $5 >>> 0;
    if ($20) {
      $point_084 = $19;
      label = 4;
      break;
    } else {
      $touch_flag_0 = 64;
      label = 6;
      break;
    }
   case 5:
    $21 = $point_188 + 20 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $point_188 + 24 | 0;
    HEAP32[$23 >> 2] = $22;
    $24 = $point_188 + 8 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $point_188 + 28 | 0;
    HEAP32[$26 >> 2] = $25;
    $27 = $point_188 + 40 | 0;
    $28 = $27 >>> 0 < $5 >>> 0;
    if ($28) {
      $point_188 = $27;
      label = 5;
      break;
    } else {
      $touch_flag_0 = 128;
      label = 6;
      break;
    }
   case 6:
    $29 = ($9 | 0) > 0;
    if ($29) {
      $contour_080 = $7;
      label = 7;
      break;
    } else {
      label = 24;
      break;
    }
   case 7:
    $30 = HEAP32[$contour_080 >> 2] | 0;
    $31 = $30 + 36 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $point_2 = $30;
    label = 8;
    break;
   case 8:
    $34 = $point_2 >>> 0 > $32 >>> 0;
    if ($34) {
      label = 23;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $36 = $point_2 | 0;
    $37 = HEAP16[$36 >> 1] | 0;
    $38 = $37 & 65535;
    $39 = $38 & $touch_flag_0;
    $40 = ($39 | 0) == 0;
    $41 = $point_2 + 40 | 0;
    if ($40) {
      $point_2 = $41;
      label = 8;
      break;
    } else {
      $point_3 = $point_2;
      label = 10;
      break;
    }
   case 10:
    $42 = $point_3 >>> 0 < $32 >>> 0;
    if ($42) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $43 = $point_3 + 40 | 0;
    $_ph = $43;
    label = 13;
    break;
   case 12:
    $45 = $point_3 + 40 | 0;
    $46 = HEAP16[$45 >> 1] | 0;
    $47 = $46 & 65535;
    $48 = $47 & $touch_flag_0;
    $49 = ($48 | 0) == 0;
    $50 = $point_3 + 40 | 0;
    if ($49) {
      $_ph = $50;
      label = 13;
      break;
    } else {
      $point_3 = $50;
      label = 10;
      break;
    }
   case 13:
    $point_4 = $_ph;
    label = 14;
    break;
   case 14:
    $52 = $point_4 >>> 0 > $32 >>> 0;
    if ($52) {
      label = 17;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $54 = $point_4 | 0;
    $55 = HEAP16[$54 >> 1] | 0;
    $56 = $55 & 65535;
    $57 = $56 & $touch_flag_0;
    $58 = ($57 | 0) == 0;
    $59 = $point_4 + 40 | 0;
    if ($58) {
      $point_4 = $59;
      label = 14;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $61 = $point_4 - 40 | 0;
    _af_iup_interp($_ph, $61, $point_3, $point_4);
    $point_3 = $point_4;
    label = 10;
    break;
   case 17:
    $63 = ($point_3 | 0) == ($point_2 | 0);
    if ($63) {
      label = 18;
      break;
    } else {
      label = 19;
      break;
    }
   case 18:
    _af_iup_shift($30, $32, $point_2);
    label = 23;
    break;
   case 19:
    if ($42) {
      label = 20;
      break;
    } else {
      label = 21;
      break;
    }
   case 20:
    _af_iup_interp($_ph, $32, $point_3, $point_2);
    label = 21;
    break;
   case 21:
    $68 = $point_2 >>> 0 > $2 >>> 0;
    if ($68) {
      label = 22;
      break;
    } else {
      label = 23;
      break;
    }
   case 22:
    $70 = $point_2 - 40 | 0;
    _af_iup_interp($30, $70, $point_3, $point_2);
    label = 23;
    break;
   case 23:
    $71 = $contour_080 + 4 | 0;
    $72 = $71 >>> 0 < $10 >>> 0;
    if ($72) {
      $contour_080 = $71;
      label = 7;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $73 = ($4 | 0) > 0;
    if ($11) {
      label = 26;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    if ($73) {
      $point_673 = $2;
      label = 28;
      break;
    } else {
      label = 29;
      break;
    }
   case 26:
    if ($73) {
      $point_570 = $2;
      label = 27;
      break;
    } else {
      label = 29;
      break;
    }
   case 27:
    $74 = $point_570 + 24 | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    $76 = $point_570 + 16 | 0;
    HEAP32[$76 >> 2] = $75;
    $77 = $point_570 + 40 | 0;
    $78 = $77 >>> 0 < $5 >>> 0;
    if ($78) {
      $point_570 = $77;
      label = 27;
      break;
    } else {
      label = 29;
      break;
    }
   case 28:
    $79 = $point_673 + 24 | 0;
    $80 = HEAP32[$79 >> 2] | 0;
    $81 = $point_673 + 20 | 0;
    HEAP32[$81 >> 2] = $80;
    $82 = $point_673 + 40 | 0;
    $83 = $82 >>> 0 < $5 >>> 0;
    if ($83) {
      $point_673 = $82;
      label = 28;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    return;
  }
}
function _af_iup_interp($p1, $p2, $ref1, $ref2) {
  $p1 = $p1 | 0;
  $p2 = $p2 | 0;
  $ref1 = $ref1 | 0;
  $ref2 = $ref2 | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $p_062 = 0, $15 = 0, $16 = 0, $17 = 0, $_ = 0, $u_0 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $p_165 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $33 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $u_1 = 0, $44 = 0, $45 = 0, $46 = 0, $p_269 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $54 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $u_2 = 0, $65 = 0, $66 = 0, $67 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $ref1 + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $ref2 + 28 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $ref1 + 24 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 - $2 | 0;
    $8 = $ref2 + 24 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 - $4 | 0;
    $11 = $p1 >>> 0 > $p2 >>> 0;
    if ($11) {
      label = 22;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $13 = ($2 | 0) == ($4 | 0);
    if ($13) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $14 = $p1 >>> 0 > $p2 >>> 0;
    if ($14) {
      label = 22;
      break;
    } else {
      $p_062 = $p1;
      label = 4;
      break;
    }
   case 4:
    $15 = $p_062 + 28 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($16 | 0) > ($2 | 0);
    $_ = $17 ? $10 : $7;
    $u_0 = $_ + $16 | 0;
    $18 = $p_062 + 24 | 0;
    HEAP32[$18 >> 2] = $u_0;
    $19 = $p_062 + 40 | 0;
    $20 = $19 >>> 0 > $p2 >>> 0;
    if ($20) {
      label = 22;
      break;
    } else {
      $p_062 = $19;
      label = 4;
      break;
    }
   case 5:
    $22 = ($2 | 0) < ($4 | 0);
    $23 = $p1 >>> 0 > $p2 >>> 0;
    if ($22) {
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    if ($23) {
      label = 22;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $24 = $4 - $2 | 0;
    $p_269 = $p1;
    label = 16;
    break;
   case 8:
    if ($23) {
      label = 22;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $25 = $4 - $2 | 0;
    $p_165 = $p1;
    label = 10;
    break;
   case 10:
    $27 = $p_165 + 28 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = ($28 | 0) > ($2 | 0);
    if ($29) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $31 = $28 + $7 | 0;
    $u_1 = $31;
    label = 15;
    break;
   case 12:
    $33 = ($28 | 0) < ($4 | 0);
    if ($33) {
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $35 = $28 + $10 | 0;
    $u_1 = $35;
    label = 15;
    break;
   case 14:
    $37 = HEAP32[$5 >> 2] | 0;
    $38 = $28 - $2 | 0;
    $39 = HEAP32[$8 >> 2] | 0;
    $40 = $39 - $37 | 0;
    $41 = _FT_MulDiv($38, $40, $25) | 0;
    $42 = $41 + $37 | 0;
    $u_1 = $42;
    label = 15;
    break;
   case 15:
    $44 = $p_165 + 24 | 0;
    HEAP32[$44 >> 2] = $u_1;
    $45 = $p_165 + 40 | 0;
    $46 = $45 >>> 0 > $p2 >>> 0;
    if ($46) {
      label = 22;
      break;
    } else {
      $p_165 = $45;
      label = 10;
      break;
    }
   case 16:
    $48 = $p_269 + 28 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = ($49 | 0) > ($4 | 0);
    if ($50) {
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $52 = $49 + $10 | 0;
    $u_2 = $52;
    label = 21;
    break;
   case 18:
    $54 = ($49 | 0) < ($2 | 0);
    if ($54) {
      label = 20;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $56 = $49 + $7 | 0;
    $u_2 = $56;
    label = 21;
    break;
   case 20:
    $58 = HEAP32[$5 >> 2] | 0;
    $59 = $49 - $2 | 0;
    $60 = HEAP32[$8 >> 2] | 0;
    $61 = $60 - $58 | 0;
    $62 = _FT_MulDiv($59, $61, $24) | 0;
    $63 = $62 + $58 | 0;
    $u_2 = $63;
    label = 21;
    break;
   case 21:
    $65 = $p_269 + 24 | 0;
    HEAP32[$65 >> 2] = $u_2;
    $66 = $p_269 + 40 | 0;
    $67 = $66 >>> 0 > $p2 >>> 0;
    if ($67) {
      label = 22;
      break;
    } else {
      $p_269 = $66;
      label = 16;
      break;
    }
   case 22:
    return;
  }
}
function _af_cjk_align_linked_edge($hints, $dim, $base_edge, $stem_edge) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  $base_edge = $base_edge | 0;
  $stem_edge = $stem_edge | 0;
  var $6 = 0;
  $6 = _af_cjk_compute_stem_width($hints, $dim, (HEAP32[$stem_edge + 4 >> 2] | 0) - (HEAP32[$base_edge + 4 >> 2] | 0) | 0) | 0;
  HEAP32[$stem_edge + 8 >> 2] = (HEAP32[$base_edge + 8 >> 2] | 0) + $6 | 0;
  return;
}
function _af_hint_normal_stem($hints, $edge, $edge2, $anchor, $dim) {
  $hints = $hints | 0;
  $edge = $edge | 0;
  $edge2 = $edge2 | 0;
  $anchor = $anchor | 0;
  $dim = $dim | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $_ = 0, $18 = 0, $_76 = 0, $threshold_0 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $_neg = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $or_cond = 0, $38 = 0, $40 = 0, $42 = 0, $43 = 0, $_82 = 0, $45 = 0, $47 = 0, $48 = 0, $or_cond77 = 0, $49 = 0, $or_cond78 = 0, $50 = 0, $or_cond79 = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $or_cond80 = 0, $58 = 0, $offset_0 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $u_off1_0 = 0, $66 = 0, $67 = 0, $_81 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $_81_u_off1_0 = 0, $delta_0 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $82 = 0, $_delta_0 = 0, $delta_1 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $89 = 0, $90 = 0, $91 = 0, $93 = 0, $94 = 0, $95 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 108 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 & 4;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 2;
      break;
    } else {
      $threshold_0 = 64;
      label = 6;
      break;
    }
   case 2:
    $6 = $edge + 12 | 0;
    $7 = HEAP8[$6] | 0;
    $8 = $7 & 1;
    $9 = $8 << 24 >> 24 == 0;
    if ($9) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = $edge2 + 12 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $12 & 1;
    $14 = $13 << 24 >> 24 == 0;
    if ($14) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $16 = ($dim | 0) == 1;
    $_ = $16 ? 55 : 49;
    $threshold_0 = $_;
    label = 6;
    break;
   case 5:
    $18 = ($dim | 0) == 1;
    $_76 = $18 ? 61 : 59;
    $threshold_0 = $_76;
    label = 6;
    break;
   case 6:
    $20 = $edge2 + 4 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $edge + 4 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $21 - $23 | 0;
    $25 = _af_cjk_compute_stem_width($hints, $dim, $24) | 0;
    $26 = $23 + $21 | 0;
    $27 = ($26 | 0) / 2 & -1;
    $28 = $27 + $anchor | 0;
    $_neg = ($25 | 0) / -2 & -1;
    $29 = $28 + $_neg | 0;
    $30 = $29 + $25 | 0;
    $31 = $29 & 63;
    $32 = $30 & 63;
    $33 = 64 - $31 | 0;
    $34 = 64 - $32 | 0;
    $35 = ($31 | 0) == 0;
    $36 = ($32 | 0) == 0;
    $or_cond = $35 | $36;
    if ($or_cond) {
      $delta_0 = 0;
      label = 16;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $38 = ($25 | 0) > ($threshold_0 | 0);
    if ($38) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $40 = ($32 | 0) < ($25 | 0);
    if ($40) {
      label = 9;
      break;
    } else {
      $delta_0 = 0;
      label = 16;
      break;
    }
   case 9:
    $42 = $33 >>> 0 > $32 >>> 0;
    $43 = -$32 | 0;
    $_82 = $42 ? $43 : $33;
    $delta_0 = $_82;
    label = 16;
    break;
   case 10:
    $45 = $threshold_0 >>> 0 < 64;
    if ($45) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $47 = $31 >>> 0 < $threshold_0 >>> 0;
    $48 = $33 >>> 0 < $threshold_0 >>> 0;
    $or_cond77 = $47 & $48;
    $49 = $32 >>> 0 < $threshold_0 >>> 0;
    $or_cond78 = $or_cond77 & $49;
    $50 = $34 >>> 0 < $threshold_0 >>> 0;
    $or_cond79 = $or_cond78 & $50;
    if ($or_cond79) {
      label = 12;
      break;
    } else {
      $delta_0 = 0;
      label = 16;
      break;
    }
   case 12:
    $52 = ($25 | 0) % 64;
    $53 = ($52 | 0) < 32;
    if ($53) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    $55 = ($33 | 0) > ($52 | 0);
    $56 = ($32 | 0) > ($52 | 0);
    $or_cond80 = $55 & $56;
    if ($or_cond80) {
      $offset_0 = $52;
      label = 15;
      break;
    } else {
      $delta_0 = 0;
      label = 16;
      break;
    }
   case 14:
    $58 = 64 - $threshold_0 | 0;
    $offset_0 = $58;
    label = 15;
    break;
   case 15:
    $60 = $threshold_0 - $33 | 0;
    $61 = $33 - $offset_0 | 0;
    $62 = $threshold_0 - $32 | 0;
    $63 = $32 - $offset_0 | 0;
    $64 = ($60 | 0) > ($61 | 0);
    $65 = -$60 | 0;
    $u_off1_0 = $64 ? $61 : $65;
    $66 = ($63 | 0) > ($62 | 0);
    $67 = -$63 | 0;
    $_81 = $66 ? $62 : $67;
    $68 = ($u_off1_0 | 0) < 0;
    $69 = -$u_off1_0 | 0;
    $70 = $68 ? $69 : $u_off1_0;
    $71 = ($_81 | 0) < 0;
    $72 = -$_81 | 0;
    $73 = $71 ? $72 : $_81;
    $74 = ($70 | 0) > ($73 | 0);
    $_81_u_off1_0 = $74 ? $_81 : $u_off1_0;
    $delta_0 = $_81_u_off1_0;
    label = 16;
    break;
   case 16:
    $76 = HEAP32[$1 >> 2] | 0;
    $77 = $76 & 4;
    $78 = ($77 | 0) == 0;
    if ($78) {
      label = 17;
      break;
    } else {
      $delta_1 = $delta_0;
      label = 19;
      break;
    }
   case 17:
    $80 = ($delta_0 | 0) > 14;
    if ($80) {
      $delta_1 = 14;
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $82 = ($delta_0 | 0) < -14;
    $_delta_0 = $82 ? -14 : $delta_0;
    $delta_1 = $_delta_0;
    label = 19;
    break;
   case 19:
    $84 = $delta_1 + $29 | 0;
    $85 = HEAP32[$22 >> 2] | 0;
    $86 = HEAP32[$20 >> 2] | 0;
    $87 = ($85 | 0) < ($86 | 0);
    if ($87) {
      label = 20;
      break;
    } else {
      label = 21;
      break;
    }
   case 20:
    $89 = $edge + 8 | 0;
    HEAP32[$89 >> 2] = $84;
    $90 = $84 + $25 | 0;
    $91 = $edge2 + 8 | 0;
    HEAP32[$91 >> 2] = $90;
    label = 22;
    break;
   case 21:
    $93 = $84 + $25 | 0;
    $94 = $edge + 8 | 0;
    HEAP32[$94 >> 2] = $93;
    $95 = $edge2 + 8 | 0;
    HEAP32[$95 >> 2] = $84;
    label = 22;
    break;
   case 22:
    return $delta_1 | 0;
  }
  return 0;
}
function _af_cjk_compute_stem_width($hints, $dim, $width) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  $width = $width | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $_width = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $_1 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $48 = 0, $_off = 0, $50 = 0, $51 = 0, $__width = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $69 = 0, $70 = 0, $72 = 0, $74 = 0, $75 = 0, $77 = 0, $79 = 0, $80 = 0, $82 = 0, $83 = 0, $dist_1 = 0, $85 = 0, $86 = 0, $dist_2 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 112 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 40 | 0;
    $4 = $3;
    $5 = ($dim | 0) == 1;
    $6 = $hints + 108 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 & 4;
    $9 = ($8 | 0) == 0;
    if ($9) {
      $_0 = $width;
      label = 27;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $11 = ($width | 0) < 0;
    $12 = -$width | 0;
    $_width = $11 ? $12 : $width;
    if ($5) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $14 = $7 & 2;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 5;
      break;
    } else {
      label = 15;
      break;
    }
   case 4:
    $16 = HEAP32[$6 >> 2] | 0;
    $17 = $16 & 1;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 5;
      break;
    } else {
      label = 15;
      break;
    }
   case 5:
    $20 = $4 + ($dim * 396 & -1) + 8 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $24 = $4 + ($dim * 396 & -1) + 16 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $_width - $25 | 0;
    $27 = ($26 | 0) < 0;
    $28 = -$26 | 0;
    $29 = $27 ? $28 : $26;
    $30 = ($29 | 0) < 40;
    if ($30) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $32 = ($25 | 0) < 48;
    $_1 = $32 ? 48 : $25;
    $dist_1 = $_1;
    label = 26;
    break;
   case 8:
    $34 = ($_width | 0) < 54;
    if ($34) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $36 = 54 - $_width | 0;
    $37 = ($36 | 0) / 2 & -1;
    $38 = $37 + $_width | 0;
    $dist_1 = $38;
    label = 26;
    break;
   case 10:
    $40 = ($_width | 0) < 192;
    if ($40) {
      label = 11;
      break;
    } else {
      $dist_1 = $_width;
      label = 26;
      break;
    }
   case 11:
    $42 = $_width & 63;
    $43 = $_width & -64;
    $44 = $42 >>> 0 < 10;
    if ($44) {
      $dist_1 = $_width;
      label = 26;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $46 = $42 >>> 0 < 22;
    if ($46) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    $48 = $43 | 10;
    $dist_1 = $48;
    label = 26;
    break;
   case 14:
    $_off = $42 - 42 | 0;
    $50 = $_off >>> 0 < 12;
    $51 = $43 | 54;
    $__width = $50 ? $51 : $_width;
    $dist_1 = $__width;
    label = 26;
    break;
   case 15:
    $53 = $4 + ($dim * 396 & -1) + 12 | 0;
    $54 = $4 + ($dim * 396 & -1) + 8 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = _af_cjk_snap_width($53, $55, $_width) | 0;
    if ($5) {
      label = 16;
      break;
    } else {
      label = 18;
      break;
    }
   case 16:
    $58 = ($56 | 0) > 63;
    if ($58) {
      label = 17;
      break;
    } else {
      $dist_1 = 64;
      label = 26;
      break;
    }
   case 17:
    $60 = $56 + 16 | 0;
    $61 = $60 & -64;
    $dist_1 = $61;
    label = 26;
    break;
   case 18:
    $63 = HEAP32[$6 >> 2] | 0;
    $64 = $63 & 8;
    $65 = ($64 | 0) == 0;
    if ($65) {
      label = 21;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $67 = ($56 | 0) < 64;
    if ($67) {
      $dist_1 = 64;
      label = 26;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $69 = $56 + 32 | 0;
    $70 = $69 & -64;
    $dist_1 = $70;
    label = 26;
    break;
   case 21:
    $72 = ($56 | 0) < 48;
    if ($72) {
      label = 22;
      break;
    } else {
      label = 23;
      break;
    }
   case 22:
    $74 = $56 + 64 | 0;
    $75 = $74 >> 1;
    $dist_1 = $75;
    label = 26;
    break;
   case 23:
    $77 = ($56 | 0) < 128;
    if ($77) {
      label = 24;
      break;
    } else {
      label = 25;
      break;
    }
   case 24:
    $79 = $56 + 22 | 0;
    $80 = $79 & -64;
    $dist_1 = $80;
    label = 26;
    break;
   case 25:
    $82 = $56 + 32 | 0;
    $83 = $82 & -64;
    $dist_1 = $83;
    label = 26;
    break;
   case 26:
    $85 = ($width | 0) > -1;
    $86 = -$dist_1 | 0;
    $dist_2 = $85 ? $dist_1 : $86;
    $_0 = $dist_2;
    label = 27;
    break;
   case 27:
    return $_0 | 0;
  }
  return 0;
}
function _af_cjk_snap_width($widths, $count, $width) {
  $widths = $widths | 0;
  $count = $count | 0;
  $width = $width | 0;
  var $1 = 0, $2 = 0, $3 = 0, $n_019 = 0, $reference_018 = 0, $best_017 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_ = 0, $9 = 0, $best_1 = 0, $reference_1 = 0, $10 = 0, $exitcond = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $reference_0_lcssa20 = 0, $16 = 0, $17 = 0, $reference_0_width = 0, $19 = 0, $20 = 0, $reference_0_width16 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($count | 0) > 0;
    if ($1) {
      $best_017 = 98;
      $reference_018 = $width;
      $n_019 = 0;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $2 = $width + 32 | 0;
    $3 = $2 & -64;
    $reference_0_lcssa20 = $width;
    $15 = $3;
    label = 5;
    break;
   case 3:
    $4 = $widths + ($n_019 * 12 & -1) + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $width - $5 | 0;
    $7 = ($6 | 0) < 0;
    $8 = -$6 | 0;
    $_ = $7 ? $8 : $6;
    $9 = ($_ | 0) < ($best_017 | 0);
    $best_1 = $9 ? $_ : $best_017;
    $reference_1 = $9 ? $5 : $reference_018;
    $10 = $n_019 + 1 | 0;
    $exitcond = ($10 | 0) == ($count | 0);
    if ($exitcond) {
      label = 4;
      break;
    } else {
      $best_017 = $best_1;
      $reference_018 = $reference_1;
      $n_019 = $10;
      label = 3;
      break;
    }
   case 4:
    $11 = $reference_1 + 32 | 0;
    $12 = $11 & -64;
    $13 = ($reference_1 | 0) > ($width | 0);
    if ($13) {
      label = 6;
      break;
    } else {
      $reference_0_lcssa20 = $reference_1;
      $15 = $12;
      label = 5;
      break;
    }
   case 5:
    $16 = $15 | 48;
    $17 = ($16 | 0) > ($width | 0);
    $reference_0_width = $17 ? $reference_0_lcssa20 : $width;
    return $reference_0_width | 0;
   case 6:
    $19 = $12 - 48 | 0;
    $20 = ($19 | 0) < ($width | 0);
    $reference_0_width16 = $20 ? $reference_1 : $width;
    return $reference_0_width16 | 0;
  }
  return 0;
}
function _af_cjk_hints_compute_segments($hints, $dim) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $seg_021 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $f0_020 = 0, $pt_019 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 48 + ($dim * 28 & -1) + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $hints + 48 + ($dim * 28 & -1) | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + ($4 * 52 & -1) | 0;
    $6 = _af_latin_hints_compute_segments($hints, $dim) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 2;
      break;
    } else {
      $_0 = $6;
      label = 10;
      break;
    }
   case 2:
    $8 = ($4 | 0) > 0;
    if ($8) {
      $seg_021 = $2;
      label = 3;
      break;
    } else {
      $_0 = 0;
      label = 10;
      break;
    }
   case 3:
    $9 = $seg_021 + 40 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $seg_021 + 44 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $10 | 0;
    $14 = HEAP16[$13 >> 1] | 0;
    $15 = $seg_021 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 & -2;
    HEAP8[$15] = $17;
    $18 = ($10 | 0) == ($12 | 0);
    if ($18) {
      label = 9;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $19 = $14 & 65535;
    $20 = $19 & 3;
    $pt_019 = $10;
    $f0_020 = $20;
    label = 5;
    break;
   case 5:
    $22 = $pt_019 + 32 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $23 | 0;
    $25 = HEAP16[$24 >> 1] | 0;
    $26 = $25 & 65535;
    $27 = $26 & 3;
    $28 = $27 | $f0_020;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 9;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $31 = ($23 | 0) == ($12 | 0);
    if ($31) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $32 = ($23 | 0) == ($12 | 0);
    if ($32) {
      label = 9;
      break;
    } else {
      $pt_019 = $23;
      $f0_020 = $27;
      label = 5;
      break;
    }
   case 8:
    $34 = HEAP8[$15] | 0;
    $35 = $34 | 1;
    HEAP8[$15] = $35;
    label = 7;
    break;
   case 9:
    $36 = $seg_021 + 52 | 0;
    $37 = $36 >>> 0 < $5 >>> 0;
    if ($37) {
      $seg_021 = $36;
      label = 3;
      break;
    } else {
      $_0 = 0;
      label = 10;
      break;
    }
   case 10:
    return $_0 | 0;
  }
  return 0;
}
function _af_cjk_hints_link_segments($hints, $dim) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $_in = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $seg1_0142 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $seg2_0139 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $_ = 0, $min_0 = 0, $63 = 0, $64 = 0, $65 = 0, $max_0_in = 0, $max_0 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $74 = 0, $75 = 0, $77 = 0, $78 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $86 = 0, $87 = 0, $89 = 0, $90 = 0, $91 = 0, $93 = 0, $94 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $seg1_1133 = 0, $101 = 0, $102 = 0, $103 = 0, $105 = 0, $106 = 0, $107 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $seg2_1128 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $or_cond = 0, $126 = 0, $127 = 0, $128 = 0, $130 = 0, $131 = 0, $132 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $139 = 0, $140 = 0, $or_cond119 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $or_cond121 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $seg_0124 = 0, $154 = 0, $155 = 0, $156 = 0, $158 = 0, $160 = 0, $162 = 0, $164 = 0, $165 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $seg1_2122 = 0, $171 = 0, $172 = 0, $173 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $182 = 0, $183 = 0, $184 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $191 = 0, $192 = 0, $194 = 0, $195 = 0, $197 = 0, $198 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 48 + ($dim * 28 & -1) + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $hints + 48 + ($dim * 28 & -1) | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + ($4 * 52 & -1) | 0;
    $6 = $hints + 48 + ($dim * 28 & -1) + 24 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $hints + 112 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 + 36 | 0;
    $11 = $10;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 << 3;
    $14 = ($13 | 0) / 2048 & -1;
    $15 = ($dim | 0) == 0;
    $16 = $hints + 4 | 0;
    $17 = $hints + 12 | 0;
    $_in = $15 ? $16 : $17;
    $18 = HEAP32[$_in >> 2] | 0;
    $19 = _FT_DivFix(192, $18) | 0;
    $20 = ($4 | 0) > 0;
    if ($20) {
      $seg1_0142 = $2;
      label = 3;
      break;
    } else {
      label = 48;
      break;
    }
   case 2:
    $21 = ($4 | 0) > 0;
    if ($21) {
      $seg1_1133 = $2;
      label = 21;
      break;
    } else {
      label = 48;
      break;
    }
   case 3:
    $22 = $seg1_0142 + 40 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $seg1_0142 + 44 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = ($23 | 0) == ($25 | 0);
    if ($26) {
      label = 19;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $28 = $seg1_0142 + 1 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $29 << 24 >> 24;
    $31 = ($30 | 0) == ($7 | 0);
    if ($31) {
      label = 5;
      break;
    } else {
      label = 19;
      break;
    }
   case 5:
    $32 = $seg1_0142 + 2 | 0;
    $33 = $seg1_0142 + 4 | 0;
    $34 = $seg1_0142 + 6 | 0;
    $35 = $seg1_0142 + 32 | 0;
    $36 = $seg1_0142 + 36 | 0;
    $37 = $seg1_0142 + 20 | 0;
    $38 = $seg1_0142 + 36 | 0;
    $seg2_0139 = $2;
    label = 6;
    break;
   case 6:
    $40 = ($seg2_0139 | 0) == ($seg1_0142 | 0);
    if ($40) {
      label = 18;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $42 = HEAP8[$28] | 0;
    $43 = $42 << 24 >> 24;
    $44 = $seg2_0139 + 1 | 0;
    $45 = HEAP8[$44] | 0;
    $46 = $45 << 24 >> 24;
    $47 = -$46 | 0;
    $48 = ($43 | 0) == ($47 | 0);
    if ($48) {
      label = 8;
      break;
    } else {
      label = 18;
      break;
    }
   case 8:
    $50 = $seg2_0139 + 2 | 0;
    $51 = HEAP16[$50 >> 1] | 0;
    $52 = $51 << 16 >> 16;
    $53 = HEAP16[$32 >> 1] | 0;
    $54 = $53 << 16 >> 16;
    $55 = $52 - $54 | 0;
    $56 = ($55 | 0) < 0;
    if ($56) {
      label = 18;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $58 = HEAP16[$33 >> 1] | 0;
    $59 = HEAP16[$34 >> 1] | 0;
    $60 = $seg2_0139 + 4 | 0;
    $61 = HEAP16[$60 >> 1] | 0;
    $62 = $58 << 16 >> 16 < $61 << 16 >> 16;
    $_ = $62 ? $61 : $58;
    $min_0 = $_ << 16 >> 16;
    $63 = $seg2_0139 + 6 | 0;
    $64 = HEAP16[$63 >> 1] | 0;
    $65 = $59 << 16 >> 16 > $64 << 16 >> 16;
    $max_0_in = $65 ? $64 : $59;
    $max_0 = $max_0_in << 16 >> 16;
    $66 = $max_0 - $min_0 | 0;
    $67 = ($66 | 0) < ($14 | 0);
    if ($67) {
      label = 18;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $69 = $55 << 3;
    $70 = HEAP32[$35 >> 2] | 0;
    $71 = $70 * 9 & -1;
    $72 = ($69 | 0) < ($71 | 0);
    if ($72) {
      label = 11;
      break;
    } else {
      label = 14;
      break;
    }
   case 11:
    $74 = $70 * 7 & -1;
    $75 = ($69 | 0) < ($74 | 0);
    if ($75) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $77 = HEAP32[$38 >> 2] | 0;
    $78 = ($77 | 0) < ($66 | 0);
    if ($78) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    HEAP32[$35 >> 2] = $55;
    HEAP32[$36 >> 2] = $66;
    HEAP32[$37 >> 2] = $seg2_0139;
    label = 14;
    break;
   case 14:
    $81 = $seg2_0139 + 32 | 0;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = $82 * 9 & -1;
    $84 = ($69 | 0) < ($83 | 0);
    if ($84) {
      label = 15;
      break;
    } else {
      label = 18;
      break;
    }
   case 15:
    $86 = $82 * 7 & -1;
    $87 = ($69 | 0) < ($86 | 0);
    if ($87) {
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $89 = $seg2_0139 + 36 | 0;
    $90 = HEAP32[$89 >> 2] | 0;
    $91 = ($90 | 0) < ($66 | 0);
    if ($91) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    HEAP32[$81 >> 2] = $55;
    $93 = $seg2_0139 + 36 | 0;
    HEAP32[$93 >> 2] = $66;
    $94 = $seg2_0139 + 20 | 0;
    HEAP32[$94 >> 2] = $seg1_0142;
    label = 18;
    break;
   case 18:
    $96 = $seg2_0139 + 52 | 0;
    $97 = $96 >>> 0 < $5 >>> 0;
    if ($97) {
      $seg2_0139 = $96;
      label = 6;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $98 = $seg1_0142 + 52 | 0;
    $99 = $98 >>> 0 < $5 >>> 0;
    if ($99) {
      $seg1_0142 = $98;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 20:
    $100 = ($4 | 0) > 0;
    if ($100) {
      $seg1_2122 = $2;
      label = 41;
      break;
    } else {
      label = 48;
      break;
    }
   case 21:
    $101 = $seg1_1133 + 20 | 0;
    $102 = HEAP32[$101 >> 2] | 0;
    $103 = ($102 | 0) == 0;
    if ($103) {
      label = 40;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $105 = $102 + 20 | 0;
    $106 = HEAP32[$105 >> 2] | 0;
    $107 = ($106 | 0) == ($seg1_1133 | 0);
    if ($107) {
      label = 23;
      break;
    } else {
      label = 40;
      break;
    }
   case 23:
    $109 = $102 + 2 | 0;
    $110 = HEAP16[$109 >> 1] | 0;
    $111 = $seg1_1133 + 2 | 0;
    $112 = HEAP16[$111 >> 1] | 0;
    $113 = $110 << 16 >> 16 > $112 << 16 >> 16;
    if ($113) {
      label = 24;
      break;
    } else {
      label = 40;
      break;
    }
   case 24:
    $115 = $seg1_1133 + 32 | 0;
    $116 = HEAP32[$115 >> 2] | 0;
    $117 = ($116 | 0) < ($19 | 0);
    if ($117) {
      label = 25;
      break;
    } else {
      label = 40;
      break;
    }
   case 25:
    $118 = $seg1_1133 + 36 | 0;
    $seg2_1128 = $2;
    label = 26;
    break;
   case 26:
    $120 = $seg2_1128 + 2 | 0;
    $121 = HEAP16[$120 >> 1] | 0;
    $122 = HEAP16[$111 >> 1] | 0;
    $123 = $121 << 16 >> 16 > $122 << 16 >> 16;
    $124 = ($seg1_1133 | 0) == ($seg2_1128 | 0);
    $or_cond = $123 | $124;
    if ($or_cond) {
      label = 39;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $126 = $seg2_1128 + 20 | 0;
    $127 = HEAP32[$126 >> 2] | 0;
    $128 = ($127 | 0) == 0;
    if ($128) {
      label = 39;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $130 = $127 + 20 | 0;
    $131 = HEAP32[$130 >> 2] | 0;
    $132 = ($131 | 0) == ($seg2_1128 | 0);
    if ($132) {
      label = 29;
      break;
    } else {
      label = 39;
      break;
    }
   case 29:
    $134 = $127 + 2 | 0;
    $135 = HEAP16[$134 >> 1] | 0;
    $136 = HEAP16[$109 >> 1] | 0;
    $137 = $135 << 16 >> 16 < $136 << 16 >> 16;
    if ($137) {
      label = 39;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    $139 = $122 << 16 >> 16 == $121 << 16 >> 16;
    $140 = $136 << 16 >> 16 == $135 << 16 >> 16;
    $or_cond119 = $139 & $140;
    if ($or_cond119) {
      label = 39;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    $142 = $seg2_1128 + 32 | 0;
    $143 = HEAP32[$142 >> 2] | 0;
    $144 = HEAP32[$115 >> 2] | 0;
    $145 = ($143 | 0) > ($144 | 0);
    $146 = $144 << 2;
    $147 = ($146 | 0) > ($143 | 0);
    $or_cond121 = $145 & $147;
    if ($or_cond121) {
      label = 32;
      break;
    } else {
      label = 39;
      break;
    }
   case 32:
    $149 = HEAP32[$118 >> 2] | 0;
    $150 = $seg2_1128 + 36 | 0;
    $151 = HEAP32[$150 >> 2] | 0;
    $152 = $151 * 3 & -1;
    $153 = ($149 | 0) < ($152 | 0);
    if ($153) {
      label = 38;
      break;
    } else {
      $seg_0124 = $2;
      label = 33;
      break;
    }
   case 33:
    $154 = $seg_0124 + 20 | 0;
    $155 = HEAP32[$154 >> 2] | 0;
    $156 = ($155 | 0) == ($seg2_1128 | 0);
    if ($156) {
      label = 34;
      break;
    } else {
      label = 35;
      break;
    }
   case 34:
    HEAP32[$154 >> 2] = 0;
    $158 = $seg_0124 + 24 | 0;
    HEAP32[$158 >> 2] = $102;
    label = 37;
    break;
   case 35:
    $160 = ($155 | 0) == ($127 | 0);
    if ($160) {
      label = 36;
      break;
    } else {
      label = 37;
      break;
    }
   case 36:
    HEAP32[$154 >> 2] = 0;
    $162 = $seg_0124 + 24 | 0;
    HEAP32[$162 >> 2] = $seg1_1133;
    label = 37;
    break;
   case 37:
    $164 = $seg_0124 + 52 | 0;
    $165 = $164 >>> 0 < $5 >>> 0;
    if ($165) {
      $seg_0124 = $164;
      label = 33;
      break;
    } else {
      label = 39;
      break;
    }
   case 38:
    HEAP32[$105 >> 2] = 0;
    HEAP32[$101 >> 2] = 0;
    label = 40;
    break;
   case 39:
    $167 = $seg2_1128 + 52 | 0;
    $168 = $167 >>> 0 < $5 >>> 0;
    if ($168) {
      $seg2_1128 = $167;
      label = 26;
      break;
    } else {
      label = 40;
      break;
    }
   case 40:
    $169 = $seg1_1133 + 52 | 0;
    $170 = $169 >>> 0 < $5 >>> 0;
    if ($170) {
      $seg1_1133 = $169;
      label = 21;
      break;
    } else {
      label = 20;
      break;
    }
   case 41:
    $171 = $seg1_2122 + 20 | 0;
    $172 = HEAP32[$171 >> 2] | 0;
    $173 = ($172 | 0) == 0;
    if ($173) {
      label = 47;
      break;
    } else {
      label = 42;
      break;
    }
   case 42:
    $175 = $172 + 28 | 0;
    $176 = HEAP32[$175 >> 2] | 0;
    $177 = $176 + 1 | 0;
    HEAP32[$175 >> 2] = $177;
    $178 = $172 + 20 | 0;
    $179 = HEAP32[$178 >> 2] | 0;
    $180 = ($179 | 0) == ($seg1_2122 | 0);
    if ($180) {
      label = 47;
      break;
    } else {
      label = 43;
      break;
    }
   case 43:
    HEAP32[$171 >> 2] = 0;
    $182 = $172 + 32 | 0;
    $183 = HEAP32[$182 >> 2] | 0;
    $184 = ($183 | 0) < ($19 | 0);
    if ($184) {
      label = 45;
      break;
    } else {
      label = 44;
      break;
    }
   case 44:
    $186 = $seg1_2122 + 32 | 0;
    $187 = HEAP32[$186 >> 2] | 0;
    $188 = $183 << 2;
    $189 = ($187 | 0) < ($188 | 0);
    if ($189) {
      label = 45;
      break;
    } else {
      label = 46;
      break;
    }
   case 45:
    $191 = HEAP32[$178 >> 2] | 0;
    $192 = $seg1_2122 + 24 | 0;
    HEAP32[$192 >> 2] = $191;
    label = 47;
    break;
   case 46:
    $194 = HEAP32[$175 >> 2] | 0;
    $195 = $194 - 1 | 0;
    HEAP32[$175 >> 2] = $195;
    label = 47;
    break;
   case 47:
    $197 = $seg1_2122 + 52 | 0;
    $198 = $197 >>> 0 < $5 >>> 0;
    if ($198) {
      $seg1_2122 = $197;
      label = 41;
      break;
    } else {
      label = 48;
      break;
    }
   case 48:
    return;
  }
}
function _af_cjk_hints_compute_edges($hints, $dim) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  var $edge1 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $_in = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $edge_distance_threshold_0 = 0, $25 = 0, $26 = 0, $seg_0123 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $found_0120 = 0, $best_0119 = 0, $ee_0118 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $dist_0 = 0, $49 = 0, $50 = 0, $or_cond = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $seg1_0 = 0, $dist2_0 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $dist2_1 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $dist2_2 = 0, $79 = 0, $best_1 = 0, $found_1 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $edge2_0115 = 0, $130 = 0, $131 = 0, $132 = 0, $seg_1 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $edge2_1112 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $is_round_0 = 0, $is_straight_0 = 0, $seg_2 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $is_round_1 = 0, $152 = 0, $153 = 0, $is_straight_1 = 0, $154 = 0, $155 = 0, $156 = 0, $158 = 0, $159 = 0, $160 = 0, $162 = 0, $163 = 0, $164 = 0, $_not = 0, $brmerge = 0, $_ = 0, $_109 = 0, $seg2_0 = 0, $edge23_0 = 0, $166 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $edge_delta_0 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $188 = 0, $189 = 0, $191 = 0, $192 = 0, $edge23_1 = 0, $195 = 0, $196 = 0, $197 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $205 = 0, $206 = 0, $207 = 0, $or_cond110 = 0, $208 = 0, $_111 = 0, $209 = 0, $210 = 0, $211 = 0, $213 = 0, $214 = 0, $215 = 0, $218 = 0, $219 = 0, $error_2 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $edge1 = __stackBase__ | 0;
    $1 = $hints + 48 + ($dim * 28 & -1) | 0;
    $2 = $hints | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $hints + 112 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 + 40 | 0;
    $7 = $6;
    $8 = $hints + 48 + ($dim * 28 & -1) + 8 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $1 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $9 + ($11 * 52 & -1) | 0;
    $13 = $hints + 48 + ($dim * 28 & -1) + 12 | 0;
    HEAP32[$13 >> 2] = 0;
    $14 = ($dim | 0) == 0;
    $15 = $hints + 4 | 0;
    $16 = $hints + 12 | 0;
    $_in = $14 ? $15 : $16;
    $17 = HEAP32[$_in >> 2] | 0;
    $18 = $7 + ($dim * 396 & -1) + 204 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = _FT_MulFix($19, $17) | 0;
    $21 = ($20 | 0) > 16;
    if ($21) {
      label = 2;
      break;
    } else {
      $edge_distance_threshold_0 = $19;
      label = 3;
      break;
    }
   case 2:
    $23 = _FT_DivFix(16, $17) | 0;
    $edge_distance_threshold_0 = $23;
    label = 3;
    break;
   case 3:
    $25 = ($11 | 0) > 0;
    if ($25) {
      label = 4;
      break;
    } else {
      label = 22;
      break;
    }
   case 4:
    $26 = $hints + 48 + ($dim * 28 & -1) + 20 | 0;
    $seg_0123 = $9;
    label = 5;
    break;
   case 5:
    $27 = HEAP32[$13 >> 2] | 0;
    $28 = ($27 | 0) > 0;
    if ($28) {
      label = 6;
      break;
    } else {
      label = 18;
      break;
    }
   case 6:
    $29 = HEAP32[$26 >> 2] | 0;
    $30 = $seg_0123 + 1 | 0;
    $31 = HEAP8[$30] | 0;
    $32 = $seg_0123 + 2 | 0;
    $33 = $seg_0123 + 20 | 0;
    $34 = HEAP32[$13 >> 2] | 0;
    $ee_0118 = 0;
    $best_0119 = 65535;
    $found_0120 = 0;
    label = 7;
    break;
   case 7:
    $36 = $29 + ($ee_0118 * 48 & -1) | 0;
    $37 = $29 + ($ee_0118 * 48 & -1) + 13 | 0;
    $38 = HEAP8[$37] | 0;
    $39 = $38 << 24 >> 24 == $31 << 24 >> 24;
    if ($39) {
      label = 8;
      break;
    } else {
      $found_1 = $found_0120;
      $best_1 = $best_0119;
      label = 16;
      break;
    }
   case 8:
    $41 = HEAP16[$32 >> 1] | 0;
    $42 = $41 << 16 >> 16;
    $43 = $36 | 0;
    $44 = HEAP16[$43 >> 1] | 0;
    $45 = $44 << 16 >> 16;
    $46 = $42 - $45 | 0;
    $47 = ($46 | 0) < 0;
    $48 = -$46 | 0;
    $dist_0 = $47 ? $48 : $46;
    $49 = ($dist_0 | 0) < ($edge_distance_threshold_0 | 0);
    $50 = ($dist_0 | 0) < ($best_0119 | 0);
    $or_cond = $49 & $50;
    if ($or_cond) {
      label = 9;
      break;
    } else {
      $found_1 = $found_0120;
      $best_1 = $best_0119;
      label = 16;
      break;
    }
   case 9:
    $52 = HEAP32[$33 >> 2] | 0;
    $53 = ($52 | 0) == 0;
    if ($53) {
      label = 15;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $55 = $29 + ($ee_0118 * 48 & -1) + 40 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = $52 + 2 | 0;
    $dist2_0 = 0;
    $seg1_0 = $56;
    label = 11;
    break;
   case 11:
    $59 = $seg1_0 + 20 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = ($60 | 0) == 0;
    if ($61) {
      $dist2_1 = $dist2_0;
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $63 = HEAP16[$57 >> 1] | 0;
    $64 = $63 << 16 >> 16;
    $65 = $60 + 2 | 0;
    $66 = HEAP16[$65 >> 1] | 0;
    $67 = $66 << 16 >> 16;
    $68 = $63 << 16 >> 16 > $66 << 16 >> 16;
    $69 = $64 - $67 | 0;
    $70 = $67 - $64 | 0;
    $71 = $68 ? $69 : $70;
    $72 = ($71 | 0) < ($edge_distance_threshold_0 | 0);
    if ($72) {
      $dist2_1 = $71;
      label = 13;
      break;
    } else {
      $dist2_2 = $71;
      label = 14;
      break;
    }
   case 13:
    $74 = $seg1_0 + 16 | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    $76 = HEAP32[$55 >> 2] | 0;
    $77 = ($75 | 0) == ($76 | 0);
    if ($77) {
      $dist2_2 = $dist2_1;
      label = 14;
      break;
    } else {
      $dist2_0 = $dist2_1;
      $seg1_0 = $75;
      label = 11;
      break;
    }
   case 14:
    $79 = ($dist2_2 | 0) < ($edge_distance_threshold_0 | 0);
    if ($79) {
      label = 15;
      break;
    } else {
      $found_1 = $found_0120;
      $best_1 = $best_0119;
      label = 16;
      break;
    }
   case 15:
    $found_1 = $36;
    $best_1 = $dist_0;
    label = 16;
    break;
   case 16:
    $82 = $ee_0118 + 1 | 0;
    $83 = ($82 | 0) < ($34 | 0);
    if ($83) {
      $ee_0118 = $82;
      $best_0119 = $best_1;
      $found_0120 = $found_1;
      label = 7;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $84 = ($found_1 | 0) == 0;
    if ($84) {
      label = 18;
      break;
    } else {
      label = 20;
      break;
    }
   case 18:
    $85 = $seg_0123 + 2 | 0;
    $86 = HEAP16[$85 >> 1] | 0;
    $87 = $86 << 16 >> 16;
    $88 = $seg_0123 + 1 | 0;
    $89 = HEAP8[$88] | 0;
    $90 = $89 << 24 >> 24;
    $91 = _af_axis_hints_new_edge($1, $87, $90, $3, $edge1) | 0;
    $92 = ($91 | 0) == 0;
    if ($92) {
      label = 19;
      break;
    } else {
      $error_2 = $91;
      label = 43;
      break;
    }
   case 19:
    $94 = HEAP32[$edge1 >> 2] | 0;
    $95 = $94;
    _memset($95 | 0, 0, 48);
    $96 = HEAP32[$edge1 >> 2] | 0;
    $97 = $96 + 40 | 0;
    HEAP32[$97 >> 2] = $seg_0123;
    $98 = HEAP32[$edge1 >> 2] | 0;
    $99 = $98 + 44 | 0;
    HEAP32[$99 >> 2] = $seg_0123;
    $100 = HEAP16[$85 >> 1] | 0;
    $101 = HEAP32[$edge1 >> 2] | 0;
    $102 = $101 | 0;
    HEAP16[$102 >> 1] = $100;
    $103 = HEAP16[$85 >> 1] | 0;
    $104 = $103 << 16 >> 16;
    $105 = _FT_MulFix($104, $17) | 0;
    $106 = HEAP32[$edge1 >> 2] | 0;
    $107 = $106 + 8 | 0;
    HEAP32[$107 >> 2] = $105;
    $108 = HEAP32[$edge1 >> 2] | 0;
    $109 = $108 + 4 | 0;
    HEAP32[$109 >> 2] = $105;
    $110 = $seg_0123 + 16 | 0;
    HEAP32[$110 >> 2] = $seg_0123;
    $111 = HEAP8[$88] | 0;
    $112 = HEAP32[$edge1 >> 2] | 0;
    $113 = $112 + 13 | 0;
    HEAP8[$113] = $111;
    label = 21;
    break;
   case 20:
    $115 = $found_1 + 40 | 0;
    $116 = HEAP32[$115 >> 2] | 0;
    $117 = $seg_0123 + 16 | 0;
    HEAP32[$117 >> 2] = $116;
    $118 = $found_1 + 44 | 0;
    $119 = HEAP32[$118 >> 2] | 0;
    $120 = $119 + 16 | 0;
    HEAP32[$120 >> 2] = $seg_0123;
    HEAP32[$118 >> 2] = $seg_0123;
    label = 21;
    break;
   case 21:
    $122 = $seg_0123 + 52 | 0;
    $123 = $122 >>> 0 < $12 >>> 0;
    if ($123) {
      $seg_0123 = $122;
      label = 5;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $124 = $hints + 48 + ($dim * 28 & -1) + 20 | 0;
    $125 = HEAP32[$124 >> 2] | 0;
    $126 = HEAP32[$13 >> 2] | 0;
    $127 = $125 + ($126 * 48 & -1) | 0;
    $128 = ($126 | 0) > 0;
    if ($128) {
      $edge2_0115 = $125;
      label = 24;
      break;
    } else {
      $error_2 = 0;
      label = 43;
      break;
    }
   case 23:
    $129 = ($126 | 0) > 0;
    if ($129) {
      $edge2_1112 = $125;
      label = 27;
      break;
    } else {
      $error_2 = 0;
      label = 43;
      break;
    }
   case 24:
    $130 = $edge2_0115 + 40 | 0;
    $131 = HEAP32[$130 >> 2] | 0;
    $132 = ($131 | 0) == 0;
    if ($132) {
      label = 26;
      break;
    } else {
      $seg_1 = $131;
      label = 25;
      break;
    }
   case 25:
    $133 = $seg_1 + 12 | 0;
    HEAP32[$133 >> 2] = $edge2_0115;
    $134 = $seg_1 + 16 | 0;
    $135 = HEAP32[$134 >> 2] | 0;
    $136 = HEAP32[$130 >> 2] | 0;
    $137 = ($135 | 0) == ($136 | 0);
    if ($137) {
      label = 26;
      break;
    } else {
      $seg_1 = $135;
      label = 25;
      break;
    }
   case 26:
    $138 = $edge2_0115 + 48 | 0;
    $139 = $138 >>> 0 < $127 >>> 0;
    if ($139) {
      $edge2_0115 = $138;
      label = 24;
      break;
    } else {
      label = 23;
      break;
    }
   case 27:
    $140 = $edge2_1112 + 40 | 0;
    $141 = HEAP32[$140 >> 2] | 0;
    $142 = $edge2_1112 + 24 | 0;
    $143 = $edge2_1112 + 28 | 0;
    $144 = $edge2_1112 | 0;
    $seg_2 = $141;
    $is_straight_0 = 0;
    $is_round_0 = 0;
    label = 28;
    break;
   case 28:
    $146 = $seg_2 | 0;
    $147 = HEAP8[$146] | 0;
    $148 = $147 & 1;
    $149 = $148 ^ 1;
    $150 = $149 & 255;
    $151 = $150 ^ 1;
    $is_round_1 = $151 + $is_round_0 | 0;
    $152 = $148 ^ 1;
    $153 = $152 & 255;
    $is_straight_1 = $153 + $is_straight_0 | 0;
    $154 = $seg_2 + 24 | 0;
    $155 = HEAP32[$154 >> 2] | 0;
    $156 = ($155 | 0) == 0;
    if ($156) {
      $162 = 0;
      label = 30;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    $158 = $155 + 12 | 0;
    $159 = HEAP32[$158 >> 2] | 0;
    $160 = ($159 | 0) != ($edge2_1112 | 0);
    $162 = $160;
    label = 30;
    break;
   case 30:
    $163 = $seg_2 + 20 | 0;
    $164 = HEAP32[$163 >> 2] | 0;
    $_not = ($164 | 0) != 0;
    $brmerge = $_not | $162;
    if ($brmerge) {
      label = 31;
      break;
    } else {
      label = 38;
      break;
    }
   case 31:
    $_ = $162 ? $143 : $142;
    $_109 = $162 ? $154 : $163;
    $seg2_0 = HEAP32[$_109 >> 2] | 0;
    $edge23_0 = HEAP32[$_ >> 2] | 0;
    $166 = ($edge23_0 | 0) == 0;
    if ($166) {
      label = 34;
      break;
    } else {
      label = 32;
      break;
    }
   case 32:
    $168 = HEAP16[$144 >> 1] | 0;
    $169 = $168 << 16 >> 16;
    $170 = $edge23_0 | 0;
    $171 = HEAP16[$170 >> 1] | 0;
    $172 = $171 << 16 >> 16;
    $173 = $169 - $172 | 0;
    $174 = ($173 | 0) < 0;
    $175 = -$173 | 0;
    $edge_delta_0 = $174 ? $175 : $173;
    $176 = $seg_2 + 2 | 0;
    $177 = HEAP16[$176 >> 1] | 0;
    $178 = $177 << 16 >> 16;
    $179 = $seg2_0 + 2 | 0;
    $180 = HEAP16[$179 >> 1] | 0;
    $181 = $180 << 16 >> 16;
    $182 = $177 << 16 >> 16 > $180 << 16 >> 16;
    $183 = $178 - $181 | 0;
    $184 = $181 - $178 | 0;
    $185 = $182 ? $183 : $184;
    $186 = ($185 | 0) < ($edge_delta_0 | 0);
    if ($186) {
      label = 33;
      break;
    } else {
      $edge23_1 = $edge23_0;
      label = 35;
      break;
    }
   case 33:
    $188 = $seg2_0 + 12 | 0;
    $189 = HEAP32[$188 >> 2] | 0;
    $edge23_1 = $189;
    label = 35;
    break;
   case 34:
    $191 = $seg2_0 + 12 | 0;
    $192 = HEAP32[$191 >> 2] | 0;
    $edge23_1 = $192;
    label = 35;
    break;
   case 35:
    if ($162) {
      label = 36;
      break;
    } else {
      label = 37;
      break;
    }
   case 36:
    HEAP32[$143 >> 2] = $edge23_1;
    $195 = $edge23_1 + 12 | 0;
    $196 = HEAP8[$195] | 0;
    $197 = $196 | 2;
    HEAP8[$195] = $197;
    label = 38;
    break;
   case 37:
    HEAP32[$142 >> 2] = $edge23_1;
    label = 38;
    break;
   case 38:
    $200 = $seg_2 + 16 | 0;
    $201 = HEAP32[$200 >> 2] | 0;
    $202 = HEAP32[$140 >> 2] | 0;
    $203 = ($201 | 0) == ($202 | 0);
    if ($203) {
      label = 39;
      break;
    } else {
      $seg_2 = $201;
      $is_straight_0 = $is_straight_1;
      $is_round_0 = $is_round_1;
      label = 28;
      break;
    }
   case 39:
    $205 = $edge2_1112 + 12 | 0;
    $206 = ($is_round_1 | 0) < 1;
    $207 = ($is_round_1 | 0) < ($is_straight_1 | 0);
    $or_cond110 = $206 | $207;
    $208 = $or_cond110 & 1;
    $_111 = $208 ^ 1;
    HEAP8[$205] = $_111;
    $209 = $edge2_1112 + 28 | 0;
    $210 = HEAP32[$209 >> 2] | 0;
    $211 = ($210 | 0) == 0;
    if ($211) {
      label = 42;
      break;
    } else {
      label = 40;
      break;
    }
   case 40:
    $213 = $edge2_1112 + 24 | 0;
    $214 = HEAP32[$213 >> 2] | 0;
    $215 = ($214 | 0) == 0;
    if ($215) {
      label = 42;
      break;
    } else {
      label = 41;
      break;
    }
   case 41:
    HEAP32[$209 >> 2] = 0;
    label = 42;
    break;
   case 42:
    $218 = $edge2_1112 + 48 | 0;
    $219 = $218 >>> 0 < $127 >>> 0;
    if ($219) {
      $edge2_1112 = $218;
      label = 27;
      break;
    } else {
      $error_2 = 0;
      label = 43;
      break;
    }
   case 43:
    STACKTOP = __stackBase__;
    return $error_2 | 0;
  }
  return 0;
}
function _af_axis_hints_new_edge($axis, $fpos, $dir, $memory, $aedge) {
  $axis = $axis | 0;
  $fpos = $fpos | 0;
  $dir = $dir | 0;
  $memory = $memory | 0;
  $aedge = $aedge | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $or_cond = 0, $new_max_0 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $_pr = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $edge_037 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $edge_0_lcssa = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $edge_1 = 0, $52 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $axis + 12 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $axis + 16 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) < ($4 | 0);
    if ($5) {
      $24 = $2;
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = ($4 | 0) > 44739241;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    HEAP32[$error >> 2] = 64;
    $edge_1 = 0;
    label = 12;
    break;
   case 4:
    $10 = $4 >> 2;
    $11 = $10 + 4 | 0;
    $12 = $11 + $4 | 0;
    $13 = ($11 | 0) < 0;
    $14 = ($12 | 0) > 44739242;
    $or_cond = $13 | $14;
    $new_max_0 = $or_cond ? 44739242 : $12;
    $15 = $axis + 20 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $16;
    $18 = _ft_mem_realloc($memory, 48, $4, $new_max_0, $17, $error) | 0;
    $19 = $18;
    HEAP32[$15 >> 2] = $19;
    $20 = HEAP32[$error >> 2] | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 5;
      break;
    } else {
      $edge_1 = 0;
      label = 12;
      break;
    }
   case 5:
    HEAP32[$3 >> 2] = $new_max_0;
    $_pr = HEAP32[$1 >> 2] | 0;
    $24 = $_pr;
    label = 6;
    break;
   case 6:
    $25 = $axis + 20 | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $26 + ($24 * 48 & -1) | 0;
    $28 = $axis + 24 | 0;
    $29 = ($24 | 0) > 0;
    if ($29) {
      $edge_037 = $27;
      label = 7;
      break;
    } else {
      $edge_0_lcssa = $27;
      label = 11;
      break;
    }
   case 7:
    $30 = $edge_037 - 48 | 0;
    $31 = $30 | 0;
    $32 = HEAP16[$31 >> 1] | 0;
    $33 = $32 << 16 >> 16;
    $34 = ($33 | 0) < ($fpos | 0);
    if ($34) {
      $edge_0_lcssa = $edge_037;
      label = 11;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $36 = ($33 | 0) == ($fpos | 0);
    if ($36) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $38 = HEAP32[$28 >> 2] | 0;
    $39 = ($38 | 0) == ($dir | 0);
    if ($39) {
      $edge_0_lcssa = $edge_037;
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $41 = $edge_037;
    $42 = $30;
    _memcpy($41 | 0, $42 | 0, 48);
    $43 = $30 >>> 0 > $26 >>> 0;
    if ($43) {
      $edge_037 = $30;
      label = 7;
      break;
    } else {
      $edge_0_lcssa = $30;
      label = 11;
      break;
    }
   case 11:
    $44 = HEAP32[$1 >> 2] | 0;
    $45 = $44 + 1 | 0;
    HEAP32[$1 >> 2] = $45;
    $46 = $edge_0_lcssa;
    _memset($46 | 0, 0, 48);
    $47 = $fpos & 65535;
    $48 = $edge_0_lcssa | 0;
    HEAP16[$48 >> 1] = $47;
    $49 = $dir & 255;
    $50 = $edge_0_lcssa + 13 | 0;
    HEAP8[$50] = $49;
    $edge_1 = $edge_0_lcssa;
    label = 12;
    break;
   case 12:
    HEAP32[$aedge >> 2] = $edge_1;
    $52 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $52 | 0;
  }
  return 0;
}
function _af_direction_compute($dx, $dy) {
  $dx = $dx | 0;
  $dy = $dy | 0;
  var $1 = 0, $2 = 0, $3 = 0, $dy_ = 0, $dx_dy = 0, $_ = 0, $dx_dy15 = 0, $dy_dx = 0, $_16 = 0, $ll_0 = 0, $ss_0 = 0, $dir_0 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $dir_0_ = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($dy | 0) < ($dx | 0);
    $2 = -$dx | 0;
    $3 = ($dy | 0) >= ($2 | 0);
    if ($1) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $dy_ = $3 ? $dy : $2;
    $dx_dy = $3 ? $dx : $dy;
    $_ = $3 ? 2 : -1;
    $dir_0 = $_;
    $ss_0 = $dx_dy;
    $ll_0 = $dy_;
    label = 4;
    break;
   case 3:
    $dx_dy15 = $3 ? $dx : $dy;
    $dy_dx = $3 ? $dy : $dx;
    $_16 = $3 ? 1 : -2;
    $dir_0 = $_16;
    $ss_0 = $dy_dx;
    $ll_0 = $dx_dy15;
    label = 4;
    break;
   case 4:
    $7 = $ss_0 * 14 & -1;
    $8 = ($ll_0 | 0) < 0;
    $9 = -$ll_0 | 0;
    $10 = $8 ? $9 : $ll_0;
    $11 = ($7 | 0) < 0;
    $12 = -$7 | 0;
    $13 = $11 ? $12 : $7;
    $14 = ($10 | 0) > ($13 | 0);
    $dir_0_ = $14 ? $dir_0 : 4;
    return $dir_0_ | 0;
  }
  return 0;
}
function _af_glyph_hints_rescale($hints, $metrics) {
  $hints = $hints | 0;
  $metrics = $metrics | 0;
  HEAP32[$hints + 112 >> 2] = $metrics;
  HEAP32[$hints + 104 >> 2] = HEAP32[$metrics + 28 >> 2] | 0;
  return;
}
function _af_cjk_metrics_scale_dim($metrics, $scaler, $dim) {
  $metrics = $metrics | 0;
  $scaler = $scaler | 0;
  $dim = $dim | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $metrics + 40 + ($dim * 396 & -1) | 0;
    $2 = ($dim | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $4 = $scaler + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $1 | 0;
    HEAP32[$6 >> 2] = $5;
    $7 = $scaler + 12 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $metrics + 40 + ($dim * 396 & -1) + 4 | 0;
    HEAP32[$9 >> 2] = $8;
    label = 4;
    break;
   case 3:
    $11 = $scaler + 8 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $1 | 0;
    HEAP32[$13 >> 2] = $12;
    $14 = $scaler + 16 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $metrics + 40 + ($dim * 396 & -1) + 4 | 0;
    HEAP32[$16 >> 2] = $15;
    label = 4;
    break;
   case 4:
    return;
  }
}
function _af_latin_hints_link_segments($hints, $dim) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $_off = 0, $13 = 0, $_ = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $seg1_060 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $seg2_058 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $min_0_in = 0, $min_0 = 0, $58 = 0, $59 = 0, $60 = 0, $_55 = 0, $max_0 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $_54 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $72 = 0, $73 = 0, $74 = 0, $76 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $seg1_156 = 0, $82 = 0, $83 = 0, $84 = 0, $86 = 0, $87 = 0, $88 = 0, $90 = 0, $91 = 0, $93 = 0, $94 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 48 + ($dim * 28 & -1) + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $hints + 48 + ($dim * 28 & -1) | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + ($4 * 52 & -1) | 0;
    $6 = $hints + 112 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 + 36 | 0;
    $9 = $8;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10 << 3;
    $12 = ($11 | 0) / 2048 & -1;
    $_off = $11 + 2047 | 0;
    $13 = $_off >>> 0 < 4095;
    $_ = $13 ? 1 : $12;
    $14 = $10 * 6e3 & -1;
    $15 = ($14 | 0) / 2048 & -1;
    $16 = ($4 | 0) > 0;
    if ($16) {
      label = 2;
      break;
    } else {
      label = 20;
      break;
    }
   case 2:
    $17 = $hints + 48 + ($dim * 28 & -1) + 24 | 0;
    $seg1_060 = $2;
    label = 4;
    break;
   case 3:
    $18 = ($4 | 0) > 0;
    if ($18) {
      $seg1_156 = $2;
      label = 16;
      break;
    } else {
      label = 20;
      break;
    }
   case 4:
    $20 = $seg1_060 + 1 | 0;
    $21 = HEAP8[$20] | 0;
    $22 = $21 << 24 >> 24;
    $23 = HEAP32[$17 >> 2] | 0;
    $24 = ($22 | 0) == ($23 | 0);
    if ($24) {
      label = 5;
      break;
    } else {
      label = 15;
      break;
    }
   case 5:
    $26 = $seg1_060 + 40 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $seg1_060 + 44 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = ($27 | 0) == ($29 | 0);
    if ($30) {
      label = 15;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $31 = $seg1_060 + 2 | 0;
    $32 = $seg1_060 + 4 | 0;
    $33 = $seg1_060 + 6 | 0;
    $34 = $seg1_060 + 32 | 0;
    $35 = $seg1_060 + 20 | 0;
    $seg2_058 = $2;
    label = 7;
    break;
   case 7:
    $37 = HEAP8[$20] | 0;
    $38 = $37 << 24 >> 24;
    $39 = $seg2_058 + 1 | 0;
    $40 = HEAP8[$39] | 0;
    $41 = $40 << 24 >> 24;
    $42 = -$41 | 0;
    $43 = ($38 | 0) == ($42 | 0);
    if ($43) {
      label = 8;
      break;
    } else {
      label = 14;
      break;
    }
   case 8:
    $45 = $seg2_058 + 2 | 0;
    $46 = HEAP16[$45 >> 1] | 0;
    $47 = HEAP16[$31 >> 1] | 0;
    $48 = $46 << 16 >> 16 > $47 << 16 >> 16;
    if ($48) {
      label = 9;
      break;
    } else {
      label = 14;
      break;
    }
   case 9:
    $50 = $46 << 16 >> 16;
    $51 = $47 << 16 >> 16;
    $52 = $50 - $51 | 0;
    $53 = HEAP16[$32 >> 1] | 0;
    $54 = HEAP16[$33 >> 1] | 0;
    $55 = $seg2_058 + 4 | 0;
    $56 = HEAP16[$55 >> 1] | 0;
    $57 = $53 << 16 >> 16 < $56 << 16 >> 16;
    $min_0_in = $57 ? $56 : $53;
    $min_0 = $min_0_in << 16 >> 16;
    $58 = $seg2_058 + 6 | 0;
    $59 = HEAP16[$58 >> 1] | 0;
    $60 = $54 << 16 >> 16 > $59 << 16 >> 16;
    $_55 = $60 ? $59 : $54;
    $max_0 = $_55 << 16 >> 16;
    $61 = $max_0 - $min_0 | 0;
    $62 = ($61 | 0) < ($_ | 0);
    if ($62) {
      label = 14;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $64 = -$52 | 0;
    $65 = ($52 | 0) < 0;
    $_54 = $65 ? $64 : $52;
    $66 = ($15 | 0) / ($61 | 0) & -1;
    $67 = $66 + $_54 | 0;
    $68 = HEAP32[$34 >> 2] | 0;
    $69 = ($67 | 0) < ($68 | 0);
    if ($69) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    HEAP32[$34 >> 2] = $67;
    HEAP32[$35 >> 2] = $seg2_058;
    label = 12;
    break;
   case 12:
    $72 = $seg2_058 + 32 | 0;
    $73 = HEAP32[$72 >> 2] | 0;
    $74 = ($67 | 0) < ($73 | 0);
    if ($74) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    HEAP32[$72 >> 2] = $67;
    $76 = $seg2_058 + 20 | 0;
    HEAP32[$76 >> 2] = $seg1_060;
    label = 14;
    break;
   case 14:
    $78 = $seg2_058 + 52 | 0;
    $79 = $78 >>> 0 < $5 >>> 0;
    if ($79) {
      $seg2_058 = $78;
      label = 7;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $80 = $seg1_060 + 52 | 0;
    $81 = $80 >>> 0 < $5 >>> 0;
    if ($81) {
      $seg1_060 = $80;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 16:
    $82 = $seg1_156 + 20 | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = ($83 | 0) == 0;
    if ($84) {
      label = 19;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $86 = $83 + 20 | 0;
    $87 = HEAP32[$86 >> 2] | 0;
    $88 = ($87 | 0) == ($seg1_156 | 0);
    if ($88) {
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    HEAP32[$82 >> 2] = 0;
    $90 = HEAP32[$86 >> 2] | 0;
    $91 = $seg1_156 + 24 | 0;
    HEAP32[$91 >> 2] = $90;
    label = 19;
    break;
   case 19:
    $93 = $seg1_156 + 52 | 0;
    $94 = $93 >>> 0 < $5 >>> 0;
    if ($94) {
      $seg1_156 = $93;
      label = 16;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    return;
  }
}
function _af_latin_hints_compute_segments($hints, $dim) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  var $segment = 0, $seg0_sroa_1 = 0, $seg0_sroa_3 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $seg0_sroa_1_0_idx = 0, $seg0_sroa_3_0_cast = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $point_0116 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $point1_0120 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $contour_0112 = 0, $segment_dir_0111 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $point3_0 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $73 = 0, $74 = 0, $76 = 0, $point3_1 = 0, $on_edge_0 = 0, $min_pos_0 = 0, $max_pos_0 = 0, $passed_0 = 0, $point3_2 = 0, $segment_dir_1 = 0, $78 = 0, $80 = 0, $81 = 0, $82 = 0, $_min_pos_0 = 0, $83 = 0, $max_pos_1 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $or_cond = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $108 = 0, $109 = 0, $110 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $_ = 0, $120 = 0, $max_pos_2 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $on_edge_1 = 0, $min_pos_3 = 0, $max_pos_3 = 0, $134 = 0, $136 = 0, $passed_1 = 0, $138 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $148 = 0, $149 = 0, $151 = 0, $seg0_sroa_0_0__idx = 0, $seg0_sroa_1_1__idx = 0, $seg0_sroa_2_32__idx84 = 0, $seg0_sroa_3_36__idx = 0, $seg0_sroa_3_36__cast = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $on_edge_2 = 0, $min_pos_4 = 0, $max_pos_4 = 0, $segment_dir_2 = 0, $163 = 0, $164 = 0, $segment_dir_3 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $segment_promoted = 0, $173 = 0, $storemerge102 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $190 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $210 = 0, $211 = 0, $212 = 0, $214 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $220 = 0, $221 = 0, $222 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $238 = 0, $239 = 0, $error_4 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 52 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $segment = __stackBase__ | 0;
    $seg0_sroa_1 = __stackBase__ + 4 | 0;
    $seg0_sroa_3 = __stackBase__ + 36 | 0;
    $1 = $hints + 48 + ($dim * 28 & -1) | 0;
    $2 = $hints | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    HEAP32[$segment >> 2] = 0;
    $4 = $hints + 44 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $hints + 40 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $5 + ($7 << 2) | 0;
    $seg0_sroa_1_0_idx = $seg0_sroa_1 | 0;
    _memset($seg0_sroa_1_0_idx | 0, 0, 31);
    $seg0_sroa_3_0_cast = $seg0_sroa_3;
    _memset($seg0_sroa_3_0_cast | 0, 0, 16);
    $9 = $hints + 48 + ($dim * 28 & -1) + 24 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($10 | 0) < 0;
    $12 = -$10 | 0;
    $13 = $11 ? $12 : $10;
    $14 = $1 | 0;
    HEAP32[$14 >> 2] = 0;
    $15 = ($dim | 0) == 0;
    $16 = $hints + 32 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $hints + 28 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $17 + ($19 * 40 & -1) | 0;
    $21 = ($19 | 0) > 0;
    if ($15) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    if ($21) {
      $point1_0120 = $17;
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    if ($21) {
      $point_0116 = $17;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $22 = ($7 | 0) > 0;
    if ($22) {
      $segment_dir_0111 = $13;
      $contour_0112 = $5;
      label = 7;
      break;
    } else {
      label = 27;
      break;
    }
   case 5:
    $23 = $point_0116 + 12 | 0;
    $24 = HEAP16[$23 >> 1] | 0;
    $25 = $24 << 16 >> 16;
    $26 = $point_0116 + 24 | 0;
    HEAP32[$26 >> 2] = $25;
    $27 = $point_0116 + 14 | 0;
    $28 = HEAP16[$27 >> 1] | 0;
    $29 = $28 << 16 >> 16;
    $30 = $point_0116 + 28 | 0;
    HEAP32[$30 >> 2] = $29;
    $31 = $point_0116 + 40 | 0;
    $32 = $31 >>> 0 < $20 >>> 0;
    if ($32) {
      $point_0116 = $31;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 6:
    $33 = $point1_0120 + 14 | 0;
    $34 = HEAP16[$33 >> 1] | 0;
    $35 = $34 << 16 >> 16;
    $36 = $point1_0120 + 24 | 0;
    HEAP32[$36 >> 2] = $35;
    $37 = $point1_0120 + 12 | 0;
    $38 = HEAP16[$37 >> 1] | 0;
    $39 = $38 << 16 >> 16;
    $40 = $point1_0120 + 28 | 0;
    HEAP32[$40 >> 2] = $39;
    $41 = $point1_0120 + 40 | 0;
    $42 = $41 >>> 0 < $20 >>> 0;
    if ($42) {
      $point1_0120 = $41;
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 7:
    $43 = HEAP32[$contour_0112 >> 2] | 0;
    $44 = $43 + 36 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = ($43 | 0) == ($45 | 0);
    if ($46) {
      $segment_dir_3 = $segment_dir_0111;
      label = 26;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $48 = $45 + 3 | 0;
    $49 = HEAP8[$48] | 0;
    $50 = $49 << 24 >> 24;
    $51 = $49 << 24 >> 24 < 0;
    $52 = -$50 | 0;
    $53 = $51 ? $52 : $50;
    $54 = ($53 | 0) == ($13 | 0);
    if ($54) {
      label = 9;
      break;
    } else {
      $point3_1 = $43;
      label = 13;
      break;
    }
   case 9:
    $56 = $43 + 3 | 0;
    $57 = HEAP8[$56] | 0;
    $58 = $57 << 24 >> 24;
    $59 = $57 << 24 >> 24 < 0;
    $60 = -$58 | 0;
    $61 = $59 ? $60 : $58;
    $62 = ($61 | 0) == ($13 | 0);
    if ($62) {
      $point3_0 = $43;
      label = 10;
      break;
    } else {
      $point3_1 = $43;
      label = 13;
      break;
    }
   case 10:
    $63 = $point3_0 + 36 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = $64 + 3 | 0;
    $66 = HEAP8[$65] | 0;
    $67 = $66 << 24 >> 24;
    $68 = $66 << 24 >> 24 < 0;
    $69 = -$67 | 0;
    $70 = $68 ? $69 : $67;
    $71 = ($70 | 0) == ($13 | 0);
    if ($71) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $73 = $64 + 32 | 0;
    $74 = HEAP32[$73 >> 2] | 0;
    $point3_1 = $74;
    label = 13;
    break;
   case 12:
    $76 = ($64 | 0) == ($43 | 0);
    if ($76) {
      $point3_1 = $64;
      label = 13;
      break;
    } else {
      $point3_0 = $64;
      label = 10;
      break;
    }
   case 13:
    $segment_dir_1 = $segment_dir_0111;
    $point3_2 = $point3_1;
    $passed_0 = 0;
    $max_pos_0 = -32e3;
    $min_pos_0 = 32e3;
    $on_edge_0 = 0;
    label = 14;
    break;
   case 14:
    $78 = ($on_edge_0 | 0) == 0;
    if ($78) {
      $max_pos_3 = $max_pos_0;
      $min_pos_3 = $min_pos_0;
      $on_edge_1 = 0;
      label = 19;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $80 = $point3_2 + 24 | 0;
    $81 = HEAP32[$80 >> 2] | 0;
    $82 = ($81 | 0) < ($min_pos_0 | 0);
    $_min_pos_0 = $82 ? $81 : $min_pos_0;
    $83 = ($81 | 0) > ($max_pos_0 | 0);
    $max_pos_1 = $83 ? $81 : $max_pos_0;
    $84 = $point3_2 + 3 | 0;
    $85 = HEAP8[$84] | 0;
    $86 = $85 << 24 >> 24;
    $87 = ($86 | 0) != ($segment_dir_1 | 0);
    $88 = ($point3_2 | 0) == ($point3_1 | 0);
    $or_cond = $87 | $88;
    if ($or_cond) {
      label = 16;
      break;
    } else {
      $max_pos_3 = $max_pos_1;
      $min_pos_3 = $_min_pos_0;
      $on_edge_1 = $on_edge_0;
      label = 19;
      break;
    }
   case 16:
    $90 = HEAP32[$segment >> 2] | 0;
    $91 = $90 + 44 | 0;
    HEAP32[$91 >> 2] = $point3_2;
    $92 = $_min_pos_0 + $max_pos_1 | 0;
    $93 = $92 >>> 1;
    $94 = $93 & 65535;
    $95 = HEAP32[$segment >> 2] | 0;
    $96 = $95 + 2 | 0;
    HEAP16[$96 >> 1] = $94;
    $97 = HEAP32[$segment >> 2] | 0;
    $98 = $97 + 40 | 0;
    $99 = HEAP32[$98 >> 2] | 0;
    $100 = $99 | 0;
    $101 = HEAP16[$100 >> 1] | 0;
    $102 = $point3_2 | 0;
    $103 = HEAP16[$102 >> 1] | 0;
    $104 = $103 | $101;
    $105 = $104 & 3;
    $106 = $105 << 16 >> 16 == 0;
    if ($106) {
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $108 = $97 | 0;
    $109 = HEAP8[$108] | 0;
    $110 = $109 | 1;
    HEAP8[$108] = $110;
    label = 18;
    break;
   case 18:
    $112 = $point3_2 + 28 | 0;
    $113 = HEAP32[$112 >> 2] | 0;
    $114 = HEAP32[$segment >> 2] | 0;
    $115 = $114 + 40 | 0;
    $116 = HEAP32[$115 >> 2] | 0;
    $117 = $116 + 28 | 0;
    $118 = HEAP32[$117 >> 2] | 0;
    $119 = ($118 | 0) < ($113 | 0);
    $_ = $119 ? $118 : $113;
    $120 = ($118 | 0) > ($113 | 0);
    $max_pos_2 = $120 ? $118 : $113;
    $121 = $_ & 65535;
    $122 = $114 + 4 | 0;
    HEAP16[$122 >> 1] = $121;
    $123 = $max_pos_2 & 65535;
    $124 = HEAP32[$segment >> 2] | 0;
    $125 = $124 + 6 | 0;
    HEAP16[$125 >> 1] = $123;
    $126 = HEAP32[$segment >> 2] | 0;
    $127 = $126 + 6 | 0;
    $128 = HEAP16[$127 >> 1] | 0;
    $129 = $126 + 4 | 0;
    $130 = HEAP16[$129 >> 1] | 0;
    $131 = $128 - $130 & 65535;
    $132 = $126 + 8 | 0;
    HEAP16[$132 >> 1] = $131;
    HEAP32[$segment >> 2] = 0;
    $max_pos_3 = $max_pos_2;
    $min_pos_3 = $_;
    $on_edge_1 = 0;
    label = 19;
    break;
   case 19:
    $134 = ($point3_2 | 0) == ($point3_1 | 0);
    if ($134) {
      label = 20;
      break;
    } else {
      $passed_1 = $passed_0;
      label = 21;
      break;
    }
   case 20:
    $136 = $passed_0 << 24 >> 24 == 0;
    if ($136) {
      $passed_1 = 1;
      label = 21;
      break;
    } else {
      $segment_dir_3 = $segment_dir_1;
      label = 26;
      break;
    }
   case 21:
    $138 = ($on_edge_1 | 0) == 0;
    if ($138) {
      label = 22;
      break;
    } else {
      $segment_dir_2 = $segment_dir_1;
      $max_pos_4 = $max_pos_3;
      $min_pos_4 = $min_pos_3;
      $on_edge_2 = $on_edge_1;
      label = 25;
      break;
    }
   case 22:
    $140 = $point3_2 + 3 | 0;
    $141 = HEAP8[$140] | 0;
    $142 = $141 << 24 >> 24;
    $143 = $141 << 24 >> 24 < 0;
    $144 = -$142 | 0;
    $145 = $143 ? $144 : $142;
    $146 = ($145 | 0) == ($13 | 0);
    if ($146) {
      label = 23;
      break;
    } else {
      $segment_dir_2 = $segment_dir_1;
      $max_pos_4 = $max_pos_3;
      $min_pos_4 = $min_pos_3;
      $on_edge_2 = 0;
      label = 25;
      break;
    }
   case 23:
    $148 = _af_axis_hints_new_segment($1, $3, $segment) | 0;
    $149 = ($148 | 0) == 0;
    if ($149) {
      label = 24;
      break;
    } else {
      $error_4 = $148;
      label = 41;
      break;
    }
   case 24:
    $151 = HEAP32[$segment >> 2] | 0;
    $seg0_sroa_0_0__idx = $151 | 0;
    HEAP8[$seg0_sroa_0_0__idx] = 0;
    $seg0_sroa_1_1__idx = $151 + 1 | 0;
    _memcpy($seg0_sroa_1_1__idx | 0, $seg0_sroa_1_0_idx | 0, 31);
    $seg0_sroa_2_32__idx84 = $151 + 32 | 0;
    HEAP32[$seg0_sroa_2_32__idx84 >> 2] = 32e3;
    $seg0_sroa_3_36__idx = $151 + 36 | 0;
    $seg0_sroa_3_36__cast = $seg0_sroa_3_36__idx;
    _memcpy($seg0_sroa_3_36__cast | 0, $seg0_sroa_3_0_cast | 0, 16);
    $152 = HEAP32[$segment >> 2] | 0;
    $153 = $152 + 1 | 0;
    HEAP8[$153] = $141;
    $154 = $point3_2 + 24 | 0;
    $155 = HEAP32[$154 >> 2] | 0;
    $156 = HEAP32[$segment >> 2] | 0;
    $157 = $156 + 40 | 0;
    HEAP32[$157 >> 2] = $point3_2;
    $158 = HEAP32[$segment >> 2] | 0;
    $159 = $158 + 44 | 0;
    HEAP32[$159 >> 2] = $point3_2;
    $160 = HEAP32[$segment >> 2] | 0;
    $161 = $160 + 48 | 0;
    HEAP32[$161 >> 2] = $contour_0112;
    $segment_dir_2 = $142;
    $max_pos_4 = $155;
    $min_pos_4 = $155;
    $on_edge_2 = 1;
    label = 25;
    break;
   case 25:
    $163 = $point3_2 + 32 | 0;
    $164 = HEAP32[$163 >> 2] | 0;
    $segment_dir_1 = $segment_dir_2;
    $point3_2 = $164;
    $passed_0 = $passed_1;
    $max_pos_0 = $max_pos_4;
    $min_pos_0 = $min_pos_4;
    $on_edge_0 = $on_edge_2;
    label = 14;
    break;
   case 26:
    $165 = $contour_0112 + 4 | 0;
    $166 = $165 >>> 0 < $8 >>> 0;
    if ($166) {
      $segment_dir_0111 = $segment_dir_3;
      $contour_0112 = $165;
      label = 7;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $167 = $hints + 48 + ($dim * 28 & -1) + 8 | 0;
    $168 = HEAP32[$167 >> 2] | 0;
    $169 = HEAP32[$14 >> 2] | 0;
    $170 = $168 + ($169 * 52 & -1) | 0;
    HEAP32[$segment >> 2] = $168;
    $171 = ($169 | 0) > 0;
    if ($171) {
      label = 28;
      break;
    } else {
      $error_4 = 0;
      label = 41;
      break;
    }
   case 28:
    $segment_promoted = HEAP32[$segment >> 2] | 0;
    $storemerge102 = $168;
    $173 = $segment_promoted;
    label = 29;
    break;
   case 29:
    $174 = $storemerge102 + 40 | 0;
    $175 = HEAP32[$174 >> 2] | 0;
    $176 = $storemerge102 + 44 | 0;
    $177 = HEAP32[$176 >> 2] | 0;
    $178 = $175 + 28 | 0;
    $179 = HEAP32[$178 >> 2] | 0;
    $180 = $177 + 28 | 0;
    $181 = HEAP32[$180 >> 2] | 0;
    $182 = ($175 | 0) == ($177 | 0);
    if ($182) {
      label = 39;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    $184 = ($179 | 0) < ($181 | 0);
    $185 = $175 + 36 | 0;
    $186 = HEAP32[$185 >> 2] | 0;
    $187 = $186 + 28 | 0;
    $188 = HEAP32[$187 >> 2] | 0;
    if ($184) {
      label = 31;
      break;
    } else {
      label = 35;
      break;
    }
   case 31:
    $190 = ($188 | 0) < ($179 | 0);
    if ($190) {
      label = 32;
      break;
    } else {
      label = 33;
      break;
    }
   case 32:
    $192 = $storemerge102 + 8 | 0;
    $193 = HEAP16[$192 >> 1] | 0;
    $194 = $193 & 65535;
    $195 = $179 - $188 | 0;
    $196 = $195 >>> 1;
    $197 = $194 + $196 | 0;
    $198 = $197 & 65535;
    HEAP16[$192 >> 1] = $198;
    label = 33;
    break;
   case 33:
    $200 = $177 + 32 | 0;
    $201 = HEAP32[$200 >> 2] | 0;
    $202 = $201 + 28 | 0;
    $203 = HEAP32[$202 >> 2] | 0;
    $204 = ($203 | 0) > ($181 | 0);
    if ($204) {
      label = 34;
      break;
    } else {
      label = 39;
      break;
    }
   case 34:
    $206 = $173 + 8 | 0;
    $207 = HEAP16[$206 >> 1] | 0;
    $208 = $207 & 65535;
    $209 = $203 - $181 | 0;
    $210 = $209 >>> 1;
    $211 = $208 + $210 | 0;
    $212 = $211 & 65535;
    HEAP16[$206 >> 1] = $212;
    label = 39;
    break;
   case 35:
    $214 = ($188 | 0) > ($179 | 0);
    if ($214) {
      label = 36;
      break;
    } else {
      label = 37;
      break;
    }
   case 36:
    $216 = $storemerge102 + 8 | 0;
    $217 = HEAP16[$216 >> 1] | 0;
    $218 = $217 & 65535;
    $219 = $188 - $179 | 0;
    $220 = $219 >>> 1;
    $221 = $218 + $220 | 0;
    $222 = $221 & 65535;
    HEAP16[$216 >> 1] = $222;
    label = 37;
    break;
   case 37:
    $224 = $177 + 32 | 0;
    $225 = HEAP32[$224 >> 2] | 0;
    $226 = $225 + 28 | 0;
    $227 = HEAP32[$226 >> 2] | 0;
    $228 = ($227 | 0) < ($181 | 0);
    if ($228) {
      label = 38;
      break;
    } else {
      label = 39;
      break;
    }
   case 38:
    $230 = $173 + 8 | 0;
    $231 = HEAP16[$230 >> 1] | 0;
    $232 = $231 & 65535;
    $233 = $181 - $227 | 0;
    $234 = $233 >>> 1;
    $235 = $232 + $234 | 0;
    $236 = $235 & 65535;
    HEAP16[$230 >> 1] = $236;
    label = 39;
    break;
   case 39:
    $238 = $173 + 52 | 0;
    $239 = $238 >>> 0 < $170 >>> 0;
    if ($239) {
      $storemerge102 = $238;
      $173 = $238;
      label = 29;
      break;
    } else {
      label = 40;
      break;
    }
   case 40:
    HEAP32[$segment >> 2] = $238;
    $error_4 = 0;
    label = 41;
    break;
   case 41:
    STACKTOP = __stackBase__;
    return $error_4 | 0;
  }
  return 0;
}
function _af_axis_hints_new_segment($axis, $memory, $asegment) {
  $axis = $axis | 0;
  $memory = $memory | 0;
  $asegment = $asegment | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $or_cond = 0, $new_max_0 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $segment_0 = 0, $30 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $axis | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $axis + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) < ($4 | 0);
    if ($5) {
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = ($4 | 0) > 41297761;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    HEAP32[$error >> 2] = 64;
    $segment_0 = 0;
    label = 7;
    break;
   case 4:
    $10 = $4 >> 2;
    $11 = $10 + 4 | 0;
    $12 = $11 + $4 | 0;
    $13 = ($11 | 0) < 0;
    $14 = ($12 | 0) > 41297762;
    $or_cond = $13 | $14;
    $new_max_0 = $or_cond ? 41297762 : $12;
    $15 = $axis + 8 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $16 | 0;
    $18 = _ft_mem_realloc($memory, 52, $4, $new_max_0, $17, $error) | 0;
    $19 = $18;
    HEAP32[$15 >> 2] = $19;
    $20 = HEAP32[$error >> 2] | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 5;
      break;
    } else {
      $segment_0 = 0;
      label = 7;
      break;
    }
   case 5:
    HEAP32[$3 >> 2] = $new_max_0;
    label = 6;
    break;
   case 6:
    $24 = $axis + 8 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = HEAP32[$1 >> 2] | 0;
    $27 = $26 + 1 | 0;
    HEAP32[$1 >> 2] = $27;
    $28 = $25 + ($26 * 52 & -1) | 0;
    $segment_0 = $28;
    label = 7;
    break;
   case 7:
    HEAP32[$asegment >> 2] = $segment_0;
    $30 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $30 | 0;
  }
  return 0;
}
function _af_latin_metrics_init_widths($metrics, $face, $charcode) {
  $metrics = $metrics | 0;
  $face = $face | 0;
  $charcode = $charcode | 0;
  var $hints = 0, $dummy = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $dim_056 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $num_widths_054 = 0, $seg_053 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $or_cond = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $61 = 0, $62 = 0, $dist_0 = 0, $63 = 0, $64 = 0, $num_widths_1 = 0, $66 = 0, $67 = 0, $num_widths_0_lcssa = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $81 = 0, $82 = 0, $83 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $94 = 0, $95 = 0, $97 = 0, $98 = 0, $99 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 956 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $hints = __stackBase__ | 0;
    $dummy = __stackBase__ + 124 | 0;
    $1 = $hints | 0;
    $2 = $face + 100 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    _af_glyph_hints_init($1, $3);
    $4 = $metrics + 48 | 0;
    HEAP32[$4 >> 2] = 0;
    $5 = $metrics + 444 | 0;
    HEAP32[$5 >> 2] = 0;
    $6 = _FT_Get_Char_Index($face, $charcode) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 13;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = _FT_Load_Glyph($face, $6, 1) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 3;
      break;
    } else {
      label = 13;
      break;
    }
   case 3:
    $12 = $face + 84 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 + 110 | 0;
    $15 = HEAP16[$14 >> 1] | 0;
    $16 = $15 << 16 >> 16 < 1;
    if ($16) {
      label = 13;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $18 = $dummy;
    _memset($18 | 0, 0, 832);
    $19 = $metrics + 36 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $dummy + 36 | 0;
    HEAP32[$21 >> 2] = $20;
    $22 = $dummy + 12 | 0;
    HEAP32[$22 >> 2] = 65536;
    $23 = $dummy + 8 | 0;
    HEAP32[$23 >> 2] = 65536;
    $24 = $dummy + 20 | 0;
    HEAP32[$24 >> 2] = 0;
    $25 = $dummy + 16 | 0;
    HEAP32[$25 >> 2] = 0;
    $26 = $dummy + 4 | 0;
    HEAP32[$26 >> 2] = $face;
    $27 = $dummy + 24 | 0;
    HEAP32[$27 >> 2] = 0;
    $28 = $dummy + 28 | 0;
    HEAP32[$28 >> 2] = 0;
    $29 = $dummy | 0;
    _af_glyph_hints_rescale($1, $29);
    $30 = HEAP32[$12 >> 2] | 0;
    $31 = $30 + 108 | 0;
    $32 = _af_glyph_hints_reload($1, $31) | 0;
    $33 = ($32 | 0) == 0;
    if ($33) {
      $dim_056 = 0;
      label = 5;
      break;
    } else {
      label = 13;
      break;
    }
   case 5:
    $34 = _af_latin_hints_compute_segments($1, $dim_056) | 0;
    $35 = ($34 | 0) == 0;
    if ($35) {
      label = 6;
      break;
    } else {
      label = 13;
      break;
    }
   case 6:
    _af_latin_hints_link_segments($1, $dim_056);
    $37 = $hints + 48 + ($dim_056 * 28 & -1) + 8 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $hints + 48 + ($dim_056 * 28 & -1) | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $38 + ($40 * 52 & -1) | 0;
    $42 = ($40 | 0) > 0;
    if ($42) {
      $seg_053 = $38;
      $num_widths_054 = 0;
      label = 7;
      break;
    } else {
      $num_widths_0_lcssa = 0;
      label = 12;
      break;
    }
   case 7:
    $43 = $seg_053 + 20 | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    $45 = ($44 | 0) == 0;
    if ($45) {
      $num_widths_1 = $num_widths_054;
      label = 11;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $47 = $44 + 20 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = ($48 | 0) == ($seg_053 | 0);
    $50 = $44 >>> 0 > $seg_053 >>> 0;
    $or_cond = $49 & $50;
    if ($or_cond) {
      label = 9;
      break;
    } else {
      $num_widths_1 = $num_widths_054;
      label = 11;
      break;
    }
   case 9:
    $52 = $seg_053 + 2 | 0;
    $53 = HEAP16[$52 >> 1] | 0;
    $54 = $53 << 16 >> 16;
    $55 = $44 + 2 | 0;
    $56 = HEAP16[$55 >> 1] | 0;
    $57 = $56 << 16 >> 16;
    $58 = $54 - $57 | 0;
    $59 = $num_widths_054 >>> 0 < 16;
    if ($59) {
      label = 10;
      break;
    } else {
      $num_widths_1 = $num_widths_054;
      label = 11;
      break;
    }
   case 10:
    $61 = -$58 | 0;
    $62 = ($58 | 0) < 0;
    $dist_0 = $62 ? $61 : $58;
    $63 = $num_widths_054 + 1 | 0;
    $64 = $metrics + 40 + ($dim_056 * 396 & -1) + 12 + ($num_widths_054 * 12 & -1) | 0;
    HEAP32[$64 >> 2] = $dist_0;
    $num_widths_1 = $63;
    label = 11;
    break;
   case 11:
    $66 = $seg_053 + 52 | 0;
    $67 = $66 >>> 0 < $41 >>> 0;
    if ($67) {
      $seg_053 = $66;
      $num_widths_054 = $num_widths_1;
      label = 7;
      break;
    } else {
      $num_widths_0_lcssa = $num_widths_1;
      label = 12;
      break;
    }
   case 12:
    $68 = $metrics + 40 + ($dim_056 * 396 & -1) + 12 | 0;
    _af_sort_widths($num_widths_0_lcssa, $68);
    $69 = $metrics + 40 + ($dim_056 * 396 & -1) + 8 | 0;
    HEAP32[$69 >> 2] = $num_widths_0_lcssa;
    $70 = $dim_056 + 1 | 0;
    $71 = ($70 | 0) < 2;
    if ($71) {
      $dim_056 = $70;
      label = 5;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $73 = $metrics + 36 | 0;
    $74 = $metrics + 48 | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    $76 = ($75 | 0) == 0;
    if ($76) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $78 = $metrics + 52 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $85 = $79;
    label = 16;
    break;
   case 15:
    $81 = HEAP32[$73 >> 2] | 0;
    $82 = $81 * 50 & -1;
    $83 = ($82 | 0) / 2048 & -1;
    $85 = $83;
    label = 16;
    break;
   case 16:
    $86 = ($85 | 0) / 5 & -1;
    $87 = $metrics + 244 | 0;
    HEAP32[$87 >> 2] = $86;
    $88 = $metrics + 248 | 0;
    HEAP32[$88 >> 2] = $85;
    $89 = $metrics + 252 | 0;
    HEAP8[$89] = 0;
    $90 = $metrics + 444 | 0;
    $91 = HEAP32[$90 >> 2] | 0;
    $92 = ($91 | 0) == 0;
    if ($92) {
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $94 = $metrics + 448 | 0;
    $95 = HEAP32[$94 >> 2] | 0;
    $101 = $95;
    label = 19;
    break;
   case 18:
    $97 = HEAP32[$73 >> 2] | 0;
    $98 = $97 * 50 & -1;
    $99 = ($98 | 0) / 2048 & -1;
    $101 = $99;
    label = 19;
    break;
   case 19:
    $102 = ($101 | 0) / 5 & -1;
    $103 = $metrics + 640 | 0;
    HEAP32[$103 >> 2] = $102;
    $104 = $metrics + 644 | 0;
    HEAP32[$104 >> 2] = $101;
    $105 = $metrics + 648 | 0;
    HEAP8[$105] = 0;
    _af_glyph_hints_done($1);
    STACKTOP = __stackBase__;
    return;
  }
}
function _af_latin_metrics_check_digits($metrics, $face) {
  $metrics = $metrics | 0;
  $face = $face | 0;
  var $advance = 0, $i_08 = 0, $old_advance_07 = 0, $started_06 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $started_1 = 0, $old_advance_1 = 0, $13 = 0, $14 = 0, $same_width_0 = 0, $16 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $advance = __stackBase__ | 0;
    $started_06 = 0;
    $old_advance_07 = 0;
    $i_08 = 48;
    label = 2;
    break;
   case 2:
    $2 = _FT_Get_Char_Index($face, $i_08) | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      $old_advance_1 = $old_advance_07;
      $started_1 = $started_06;
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $5 = _FT_Get_Advance($face, $2, 2051, $advance) | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 4;
      break;
    } else {
      $old_advance_1 = $old_advance_07;
      $started_1 = $started_06;
      label = 6;
      break;
    }
   case 4:
    $8 = $started_06 << 24 >> 24 == 0;
    $9 = HEAP32[$advance >> 2] | 0;
    if ($8) {
      $old_advance_1 = $9;
      $started_1 = 1;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $11 = ($9 | 0) == ($old_advance_07 | 0);
    if ($11) {
      $old_advance_1 = $old_advance_07;
      $started_1 = $started_06;
      label = 6;
      break;
    } else {
      $same_width_0 = 0;
      label = 7;
      break;
    }
   case 6:
    $13 = $i_08 + 1 | 0;
    $14 = $13 >>> 0 < 58;
    if ($14) {
      $started_06 = $started_1;
      $old_advance_07 = $old_advance_1;
      $i_08 = $13;
      label = 2;
      break;
    } else {
      $same_width_0 = 1;
      label = 7;
      break;
    }
   case 7:
    $16 = $metrics + 32 | 0;
    HEAP8[$16] = $same_width_0;
    STACKTOP = __stackBase__;
    return;
  }
}
function _af_sort_widths($count, $table) {
  $count = $count | 0;
  $table = $table | 0;
  var $swap = 0, $1 = 0, $2 = 0, $i_017 = 0, $j_016 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $exitcond = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $swap = __stackBase__ | 0;
    $1 = $count >>> 0 > 1;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 7;
      break;
    }
   case 2:
    $2 = $swap;
    $i_017 = 1;
    label = 3;
    break;
   case 3:
    $j_016 = $i_017;
    label = 4;
    break;
   case 4:
    $4 = $table + ($j_016 * 12 & -1) | 0;
    $5 = $4 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $j_016 - 1 | 0;
    $8 = $table + ($7 * 12 & -1) | 0;
    $9 = $8 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($6 | 0) > ($10 | 0);
    if ($11) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $13 = $4;
    _memcpy($2 | 0, $13 | 0, 12);
    $14 = $8;
    _memcpy($13 | 0, $14 | 0, 12);
    _memcpy($14 | 0, $2 | 0, 12);
    $15 = ($7 | 0) == 0;
    if ($15) {
      label = 6;
      break;
    } else {
      $j_016 = $7;
      label = 4;
      break;
    }
   case 6:
    $16 = $i_017 + 1 | 0;
    $exitcond = ($16 | 0) == ($count | 0);
    if ($exitcond) {
      label = 7;
      break;
    } else {
      $i_017 = $16;
      label = 3;
      break;
    }
   case 7:
    STACKTOP = __stackBase__;
    return;
  }
}
function _af_latin_hints_detect_features($hints, $dim) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  var $1 = 0, $2 = 0, $4 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _af_latin_hints_compute_segments($hints, $dim) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $error_0 = $1;
      label = 3;
      break;
    }
   case 2:
    _af_latin_hints_link_segments($hints, $dim);
    $4 = _af_latin_hints_compute_edges($hints, $dim) | 0;
    $error_0 = $4;
    label = 3;
    break;
   case 3:
    return $error_0 | 0;
  }
  return 0;
}
function _af_glyph_hints_align_edge_points($hints, $dim) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $seg_024 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $point_0_in = 0, $point_0 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $seg_128 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $point2_0_in = 0, $point2_0 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 48 + ($dim * 28 & -1) + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $hints + 48 + ($dim * 28 & -1) | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + ($4 * 52 & -1) | 0;
    $6 = ($dim | 0) == 0;
    $7 = ($4 | 0) > 0;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    if ($7) {
      $seg_128 = $2;
      label = 8;
      break;
    } else {
      label = 12;
      break;
    }
   case 3:
    if ($7) {
      $seg_024 = $2;
      label = 4;
      break;
    } else {
      label = 12;
      break;
    }
   case 4:
    $8 = $seg_024 + 12 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $12 = $seg_024 + 40 | 0;
    $13 = $seg_024 + 44 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $9 + 8 | 0;
    $point_0_in = $12;
    label = 6;
    break;
   case 6:
    $point_0 = HEAP32[$point_0_in >> 2] | 0;
    $17 = HEAP32[$15 >> 2] | 0;
    $18 = $point_0 + 16 | 0;
    HEAP32[$18 >> 2] = $17;
    $19 = $point_0 | 0;
    $20 = HEAP16[$19 >> 1] | 0;
    $21 = $20 | 64;
    HEAP16[$19 >> 1] = $21;
    $22 = ($point_0 | 0) == ($14 | 0);
    $23 = $point_0 + 32 | 0;
    if ($22) {
      label = 7;
      break;
    } else {
      $point_0_in = $23;
      label = 6;
      break;
    }
   case 7:
    $24 = $seg_024 + 52 | 0;
    $25 = $24 >>> 0 < $5 >>> 0;
    if ($25) {
      $seg_024 = $24;
      label = 4;
      break;
    } else {
      label = 12;
      break;
    }
   case 8:
    $26 = $seg_128 + 12 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = ($27 | 0) == 0;
    if ($28) {
      label = 11;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $30 = $seg_128 + 40 | 0;
    $31 = $seg_128 + 44 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $27 + 8 | 0;
    $point2_0_in = $30;
    label = 10;
    break;
   case 10:
    $point2_0 = HEAP32[$point2_0_in >> 2] | 0;
    $35 = HEAP32[$33 >> 2] | 0;
    $36 = $point2_0 + 20 | 0;
    HEAP32[$36 >> 2] = $35;
    $37 = $point2_0 | 0;
    $38 = HEAP16[$37 >> 1] | 0;
    $39 = $38 | 128;
    HEAP16[$37 >> 1] = $39;
    $40 = ($point2_0 | 0) == ($32 | 0);
    $41 = $point2_0 + 32 | 0;
    if ($40) {
      label = 11;
      break;
    } else {
      $point2_0_in = $41;
      label = 10;
      break;
    }
   case 11:
    $42 = $seg_128 + 52 | 0;
    $43 = $42 >>> 0 < $5 >>> 0;
    if ($43) {
      $seg_128 = $42;
      label = 8;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    return;
  }
}
function _af_latin_hints_compute_blue_edges($hints, $metrics) {
  $hints = $hints | 0;
  $metrics = $metrics | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $edge_043 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $_ = 0, $16 = 0, $17 = 0, $18 = 0, $bb_042 = 0, $best_blue_041 = 0, $best_dist_140 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $dist_0 = 0, $42 = 0, $43 = 0, $_best_dist_1 = 0, $_best_blue_0 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $or_cond = 0, $49 = 0, $50 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $dist_1 = 0, $58 = 0, $59 = 0, $__best_dist_1 = 0, $__best_blue_0 = 0, $best_dist_3 = 0, $best_blue_2 = 0, $61 = 0, $exitcond = 0, $63 = 0, $65 = 0, $67 = 0, $68 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 96 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $hints + 88 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + ($4 * 48 & -1) | 0;
    $6 = $metrics + 436 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = ($4 | 0) > 0;
    if ($8) {
      label = 2;
      break;
    } else {
      label = 13;
      break;
    }
   case 2:
    $9 = $metrics + 36 | 0;
    $10 = $hints + 100 | 0;
    $edge_043 = $2;
    label = 3;
    break;
   case 3:
    $12 = HEAP32[$9 >> 2] | 0;
    $13 = ($12 >>> 0) / 40 >>> 0;
    $14 = _FT_MulFix($13, $7) | 0;
    $15 = ($14 | 0) > 32;
    $_ = $15 ? 32 : $14;
    $16 = $edge_043 + 13 | 0;
    $17 = $edge_043 | 0;
    $18 = $edge_043 + 12 | 0;
    $best_dist_140 = $_;
    $best_blue_041 = 0;
    $bb_042 = 0;
    label = 4;
    break;
   case 4:
    $20 = $metrics + 656 + ($bb_042 * 28 & -1) | 0;
    $21 = $metrics + 656 + ($bb_042 * 28 & -1) + 24 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22 & 1;
    $24 = ($23 | 0) == 0;
    if ($24) {
      $best_blue_2 = $best_blue_041;
      $best_dist_3 = $best_dist_140;
      label = 9;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $26 = HEAP8[$16] | 0;
    $27 = $26 << 24 >> 24;
    $28 = HEAP32[$10 >> 2] | 0;
    $29 = ($27 | 0) == ($28 | 0);
    $30 = $22 & 2;
    $31 = ($30 | 0) != 0;
    $32 = $29 ^ $31;
    if ($32) {
      label = 6;
      break;
    } else {
      $best_blue_2 = $best_blue_041;
      $best_dist_3 = $best_dist_140;
      label = 9;
      break;
    }
   case 6:
    $34 = HEAP16[$17 >> 1] | 0;
    $35 = $34 << 16 >> 16;
    $36 = $20 | 0;
    $37 = $20 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $35 - $38 | 0;
    $40 = ($39 | 0) < 0;
    $41 = -$39 | 0;
    $dist_0 = $40 ? $41 : $39;
    $42 = _FT_MulFix($dist_0, $7) | 0;
    $43 = ($42 | 0) < ($best_dist_140 | 0);
    $_best_dist_1 = $43 ? $42 : $best_dist_140;
    $_best_blue_0 = $43 ? $36 : $best_blue_041;
    $44 = HEAP8[$18] | 0;
    $45 = $44 & 1;
    $46 = $45 << 24 >> 24 == 0;
    $47 = ($42 | 0) == 0;
    $or_cond = $46 | $47;
    if ($or_cond) {
      $best_blue_2 = $_best_blue_0;
      $best_dist_3 = $_best_dist_1;
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $49 = ($35 | 0) < ($38 | 0);
    $50 = $49 ^ $31;
    if ($50) {
      label = 8;
      break;
    } else {
      $best_blue_2 = $_best_blue_0;
      $best_dist_3 = $_best_dist_1;
      label = 9;
      break;
    }
   case 8:
    $52 = $metrics + 656 + ($bb_042 * 28 & -1) + 12 | 0;
    $53 = $52 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = $35 - $54 | 0;
    $56 = ($55 | 0) < 0;
    $57 = -$55 | 0;
    $dist_1 = $56 ? $57 : $55;
    $58 = _FT_MulFix($dist_1, $7) | 0;
    $59 = ($58 | 0) < ($_best_dist_1 | 0);
    $__best_dist_1 = $59 ? $58 : $_best_dist_1;
    $__best_blue_0 = $59 ? $52 : $_best_blue_0;
    $best_blue_2 = $__best_blue_0;
    $best_dist_3 = $__best_dist_1;
    label = 9;
    break;
   case 9:
    $61 = $bb_042 + 1 | 0;
    $exitcond = ($61 | 0) == 6;
    if ($exitcond) {
      label = 10;
      break;
    } else {
      $best_dist_140 = $best_dist_3;
      $best_blue_041 = $best_blue_2;
      $bb_042 = $61;
      label = 4;
      break;
    }
   case 10:
    $63 = ($best_blue_2 | 0) == 0;
    if ($63) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $65 = $edge_043 + 20 | 0;
    HEAP32[$65 >> 2] = $best_blue_2;
    label = 12;
    break;
   case 12:
    $67 = $edge_043 + 48 | 0;
    $68 = $67 >>> 0 < $5 >>> 0;
    if ($68) {
      $edge_043 = $67;
      label = 3;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    return;
  }
}
function _af_latin_hint_edges($hints, $dim) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $anchor_3_ph = 0, $8 = 0, $edge_0263 = 0, $anchor_0262 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $_edge_0 = 0, $_ = 0, $_236 = 0, $edge2_0 = 0, $edge1_0 = 0, $blue_0 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $edge_0_anchor_0 = 0, $anchor_1 = 0, $45 = 0, $46 = 0, $edge_1257 = 0, $anchor_3256 = 0, $has_serifs_0255 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $_238 = 0, $_237 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $error1_0 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $_239 = 0, $92 = 0, $cur_pos1_0 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $99 = 0, $100 = 0, $101 = 0, $103 = 0, $104 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $131 = 0, $133 = 0, $134 = 0, $135 = 0, $_240 = 0, $_241 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $delta1_0 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $_242 = 0, $144 = 0, $cur_pos15_0 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $delta1_1 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $delta2_1 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $has_serifs_1 = 0, $anchor_4 = 0, $185 = 0, $186 = 0, $anchor_3_lcssa = 0, $has_serifs_0_lcssa = 0, $_idx = 0, $187 = 0, $189 = 0, $191 = 0, $192 = 0, $194 = 0, $195 = 0, $196 = 0, $edge18_0 = 0, $edge29_0 = 0, $edge3_0 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $span_0 = 0, $209 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $220 = 0, $221 = 0, $222 = 0, $224 = 0, $225 = 0, $226 = 0, $229 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $240 = 0, $242 = 0, $243 = 0, $244 = 0, $246 = 0, $247 = 0, $or_cond = 0, $248 = 0, $or_cond278 = 0, $edge_2251 = 0, $anchor_5250 = 0, $249 = 0, $250 = 0, $251 = 0, $252 = 0, $254 = 0, $255 = 0, $256 = 0, $258 = 0, $259 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $delta10_0 = 0, $265 = 0, $267 = 0, $268 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $edge_2_pn = 0, $before_0 = 0, $275 = 0, $277 = 0, $278 = 0, $279 = 0, $280 = 0, $edge_2_pn235 = 0, $after_0 = 0, $281 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $288 = 0, $or_cond243 = 0, $brmerge_demorgan = 0, $289 = 0, $or_cond244 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $299 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $320 = 0, $321 = 0, $anchor_6 = 0, $323 = 0, $324 = 0, $325 = 0, $327 = 0, $328 = 0, $329 = 0, $330 = 0, $331 = 0, $334 = 0, $335 = 0, $337 = 0, $338 = 0, $339 = 0, $340 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $anchor_7 = 0, $349 = 0, $350 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 48 + ($dim * 28 & -1) + 20 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $hints + 48 + ($dim * 28 & -1) + 12 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + ($4 * 48 & -1) | 0;
    $6 = ($dim | 0) == 1;
    if ($6) {
      label = 2;
      break;
    } else {
      $anchor_3_ph = 0;
      label = 3;
      break;
    }
   case 2:
    $7 = ($4 | 0) > 0;
    if ($7) {
      $anchor_0262 = 0;
      $edge_0263 = $2;
      label = 4;
      break;
    } else {
      label = 68;
      break;
    }
   case 3:
    $8 = ($4 | 0) > 0;
    if ($8) {
      $has_serifs_0255 = 0;
      $anchor_3256 = $anchor_3_ph;
      $edge_1257 = $2;
      label = 14;
      break;
    } else {
      $has_serifs_0_lcssa = 0;
      $anchor_3_lcssa = $anchor_3_ph;
      label = 33;
      break;
    }
   case 4:
    $9 = $edge_0263 + 12 | 0;
    $10 = HEAP8[$9] | 0;
    $11 = $10 & 4;
    $12 = $11 << 24 >> 24 == 0;
    if ($12) {
      label = 5;
      break;
    } else {
      $anchor_1 = $anchor_0262;
      label = 13;
      break;
    }
   case 5:
    $14 = $edge_0263 + 20 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $edge_0263 + 24 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($15 | 0) == 0;
    if ($18) {
      label = 6;
      break;
    } else {
      $blue_0 = $15;
      $edge1_0 = $edge_0263;
      $edge2_0 = $17;
      label = 8;
      break;
    }
   case 6:
    $20 = ($17 | 0) == 0;
    if ($20) {
      $anchor_1 = $anchor_0262;
      label = 13;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $22 = $17 + 20 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = ($23 | 0) == 0;
    $_edge_0 = $24 ? $17 : $edge_0263;
    $_ = $24 ? 0 : $17;
    $_236 = $24 ? $15 : $23;
    $blue_0 = $_236;
    $edge1_0 = $_;
    $edge2_0 = $_edge_0;
    label = 8;
    break;
   case 8:
    $26 = ($edge1_0 | 0) == 0;
    if ($26) {
      $anchor_1 = $anchor_0262;
      label = 13;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $28 = $blue_0 + 8 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $edge1_0 + 8 | 0;
    HEAP32[$30 >> 2] = $29;
    $31 = $edge1_0 + 12 | 0;
    $32 = HEAP8[$31] | 0;
    $33 = $32 | 4;
    HEAP8[$31] = $33;
    $34 = ($edge2_0 | 0) == 0;
    if ($34) {
      label = 12;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $36 = $edge2_0 + 20 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = ($37 | 0) == 0;
    if ($38) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    _af_latin_align_linked_edge($hints, $dim, $edge1_0, $edge2_0);
    $40 = $edge2_0 + 12 | 0;
    $41 = HEAP8[$40] | 0;
    $42 = $41 | 4;
    HEAP8[$40] = $42;
    label = 12;
    break;
   case 12:
    $44 = ($anchor_0262 | 0) == 0;
    $edge_0_anchor_0 = $44 ? $edge_0263 : $anchor_0262;
    $anchor_1 = $edge_0_anchor_0;
    label = 13;
    break;
   case 13:
    $45 = $edge_0263 + 48 | 0;
    $46 = $45 >>> 0 < $5 >>> 0;
    if ($46) {
      $anchor_0262 = $anchor_1;
      $edge_0263 = $45;
      label = 4;
      break;
    } else {
      $anchor_3_ph = $anchor_1;
      label = 3;
      break;
    }
   case 14:
    $47 = $edge_1257 + 12 | 0;
    $48 = HEAP8[$47] | 0;
    $49 = $48 & 255;
    $50 = $49 & 4;
    $51 = ($50 | 0) == 0;
    if ($51) {
      label = 15;
      break;
    } else {
      $anchor_4 = $anchor_3256;
      $has_serifs_1 = $has_serifs_0255;
      label = 32;
      break;
    }
   case 15:
    $53 = $edge_1257 + 24 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = ($54 | 0) == 0;
    if ($55) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    $57 = $has_serifs_0255 + 1 | 0;
    $anchor_4 = $anchor_3256;
    $has_serifs_1 = $57;
    label = 32;
    break;
   case 17:
    $59 = $54 + 20 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = ($60 | 0) == 0;
    if ($61) {
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    _af_latin_align_linked_edge($hints, $dim, $54, $edge_1257);
    $63 = HEAP8[$47] | 0;
    $64 = $63 | 4;
    HEAP8[$47] = $64;
    $anchor_4 = $anchor_3256;
    $has_serifs_1 = $has_serifs_0255;
    label = 32;
    break;
   case 19:
    $66 = ($anchor_3256 | 0) == 0;
    if ($66) {
      label = 20;
      break;
    } else {
      label = 24;
      break;
    }
   case 20:
    $68 = $54 + 4 | 0;
    $69 = HEAP32[$68 >> 2] | 0;
    $70 = $edge_1257 + 4 | 0;
    $71 = HEAP32[$70 >> 2] | 0;
    $72 = $69 - $71 | 0;
    $73 = $54 + 12 | 0;
    $74 = HEAP8[$73] | 0;
    $75 = $74 & 255;
    $76 = _af_latin_compute_stem_width($hints, $dim, $72, $49, $75) | 0;
    $77 = ($76 | 0) < 65;
    $78 = ($76 | 0) < 96;
    if ($78) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    $_238 = $77 ? 32 : 26;
    $_237 = $77 ? 32 : 38;
    $80 = $72 >> 1;
    $81 = $80 + $71 | 0;
    $82 = $81 + 32 | 0;
    $83 = $82 & -64;
    $84 = $83 - $_237 | 0;
    $85 = $81 - $84 | 0;
    $86 = ($85 | 0) < 0;
    $87 = -$85 | 0;
    $error1_0 = $86 ? $87 : $85;
    $88 = $83 | $_238;
    $89 = $81 - $88 | 0;
    $90 = ($89 | 0) < 0;
    $91 = -$89 | 0;
    $_239 = $90 ? $91 : $89;
    $92 = ($error1_0 | 0) < ($_239 | 0);
    $cur_pos1_0 = $92 ? $84 : $88;
    $93 = ($76 | 0) / 2 & -1;
    $94 = $cur_pos1_0 - $93 | 0;
    $95 = $edge_1257 + 8 | 0;
    HEAP32[$95 >> 2] = $94;
    $96 = $94 + $76 | 0;
    $97 = $54 + 8 | 0;
    HEAP32[$97 >> 2] = $96;
    label = 23;
    break;
   case 22:
    $99 = $71 + 32 | 0;
    $100 = $99 & -64;
    $101 = $edge_1257 + 8 | 0;
    HEAP32[$101 >> 2] = $100;
    label = 23;
    break;
   case 23:
    $103 = HEAP8[$47] | 0;
    $104 = $103 | 4;
    HEAP8[$47] = $104;
    _af_latin_align_linked_edge($hints, $dim, $edge_1257, $54);
    $anchor_4 = $edge_1257;
    $has_serifs_1 = $has_serifs_0255;
    label = 32;
    break;
   case 24:
    $106 = $anchor_3256 + 8 | 0;
    $107 = HEAP32[$106 >> 2] | 0;
    $108 = $edge_1257 + 4 | 0;
    $109 = HEAP32[$108 >> 2] | 0;
    $110 = $anchor_3256 + 4 | 0;
    $111 = HEAP32[$110 >> 2] | 0;
    $112 = $109 - $111 | 0;
    $113 = $112 + $107 | 0;
    $114 = $54 + 4 | 0;
    $115 = HEAP32[$114 >> 2] | 0;
    $116 = $115 - $109 | 0;
    $117 = $116 >> 1;
    $118 = $117 + $113 | 0;
    $119 = $54 + 12 | 0;
    $120 = HEAP8[$119] | 0;
    $121 = $120 & 255;
    $122 = _af_latin_compute_stem_width($hints, $dim, $116, $49, $121) | 0;
    $123 = $121 & 4;
    $124 = ($123 | 0) == 0;
    if ($124) {
      label = 26;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $126 = $54 + 8 | 0;
    $127 = HEAP32[$126 >> 2] | 0;
    $128 = $127 - $122 | 0;
    $129 = $edge_1257 + 8 | 0;
    HEAP32[$129 >> 2] = $128;
    label = 29;
    break;
   case 26:
    $131 = ($122 | 0) < 96;
    if ($131) {
      label = 27;
      break;
    } else {
      label = 28;
      break;
    }
   case 27:
    $133 = $118 + 32 | 0;
    $134 = $133 & -64;
    $135 = ($122 | 0) < 65;
    $_240 = $135 ? 32 : 38;
    $_241 = $135 ? 32 : 26;
    $136 = $134 - $_240 | 0;
    $137 = $118 - $136 | 0;
    $138 = ($137 | 0) < 0;
    $139 = -$137 | 0;
    $delta1_0 = $138 ? $139 : $137;
    $140 = $134 | $_241;
    $141 = $118 - $140 | 0;
    $142 = ($141 | 0) < 0;
    $143 = -$141 | 0;
    $_242 = $142 ? $143 : $141;
    $144 = ($delta1_0 | 0) < ($_242 | 0);
    $cur_pos15_0 = $144 ? $136 : $140;
    $145 = ($122 | 0) / 2 & -1;
    $146 = $cur_pos15_0 - $145 | 0;
    $147 = $edge_1257 + 8 | 0;
    HEAP32[$147 >> 2] = $146;
    $148 = $145 + $cur_pos15_0 | 0;
    $149 = $54 + 8 | 0;
    HEAP32[$149 >> 2] = $148;
    label = 29;
    break;
   case 28:
    $151 = $113 + 32 | 0;
    $152 = $151 & -64;
    $153 = $122 >> 1;
    $154 = $152 + $153 | 0;
    $155 = $154 - $118 | 0;
    $156 = ($155 | 0) < 0;
    $157 = -$155 | 0;
    $delta1_1 = $156 ? $157 : $155;
    $158 = $116 + 32 | 0;
    $159 = $158 + $113 | 0;
    $160 = $159 & -64;
    $161 = $160 - $122 | 0;
    $162 = $153 - $118 | 0;
    $163 = $162 + $161 | 0;
    $164 = ($163 | 0) < 0;
    $165 = -$163 | 0;
    $delta2_1 = $164 ? $165 : $163;
    $166 = ($delta1_1 | 0) < ($delta2_1 | 0);
    $167 = $166 ? $152 : $161;
    $168 = $edge_1257 + 8 | 0;
    HEAP32[$168 >> 2] = $167;
    $169 = $167 + $122 | 0;
    $170 = $54 + 8 | 0;
    HEAP32[$170 >> 2] = $169;
    label = 29;
    break;
   case 29:
    $172 = HEAP8[$47] | 0;
    $173 = $172 | 4;
    HEAP8[$47] = $173;
    $174 = HEAP8[$119] | 0;
    $175 = $174 | 4;
    HEAP8[$119] = $175;
    $176 = $edge_1257 >>> 0 > $2 >>> 0;
    if ($176) {
      label = 30;
      break;
    } else {
      $anchor_4 = $anchor_3256;
      $has_serifs_1 = $has_serifs_0255;
      label = 32;
      break;
    }
   case 30:
    $178 = $edge_1257 + 8 | 0;
    $179 = HEAP32[$178 >> 2] | 0;
    $180 = $edge_1257 - 48 + 8 | 0;
    $181 = HEAP32[$180 >> 2] | 0;
    $182 = ($179 | 0) < ($181 | 0);
    if ($182) {
      label = 31;
      break;
    } else {
      $anchor_4 = $anchor_3256;
      $has_serifs_1 = $has_serifs_0255;
      label = 32;
      break;
    }
   case 31:
    HEAP32[$178 >> 2] = $181;
    $anchor_4 = $anchor_3256;
    $has_serifs_1 = $has_serifs_0255;
    label = 32;
    break;
   case 32:
    $185 = $edge_1257 + 48 | 0;
    $186 = $185 >>> 0 < $5 >>> 0;
    if ($186) {
      $has_serifs_0255 = $has_serifs_1;
      $anchor_3256 = $anchor_4;
      $edge_1257 = $185;
      label = 14;
      break;
    } else {
      $has_serifs_0_lcssa = $has_serifs_1;
      $anchor_3_lcssa = $anchor_4;
      label = 33;
      break;
    }
   case 33:
    $_idx = $4 * 48 & -1;
    $187 = ($dim | 0) == 0;
    if ($187) {
      label = 34;
      break;
    } else {
      label = 44;
      break;
    }
   case 34:
    $189 = ($_idx | 0) == 576;
    if (($_idx | 0) == 288) {
      label = 35;
      break;
    } else if (($_idx | 0) == 576) {
      label = 36;
      break;
    } else {
      label = 44;
      break;
    }
   case 35:
    $191 = $2 + 96 | 0;
    $192 = $2 + 192 | 0;
    $edge3_0 = $192;
    $edge29_0 = $191;
    $edge18_0 = $2;
    label = 37;
    break;
   case 36:
    $194 = $2 + 48 | 0;
    $195 = $2 + 240 | 0;
    $196 = $2 + 432 | 0;
    $edge3_0 = $196;
    $edge29_0 = $195;
    $edge18_0 = $194;
    label = 37;
    break;
   case 37:
    $198 = $edge29_0 + 4 | 0;
    $199 = HEAP32[$198 >> 2] | 0;
    $200 = $edge18_0 + 4 | 0;
    $201 = HEAP32[$200 >> 2] | 0;
    $202 = $199 - $201 | 0;
    $203 = $edge3_0 + 4 | 0;
    $204 = HEAP32[$203 >> 2] | 0;
    $205 = $199 - $204 | 0;
    $206 = $205 + $202 | 0;
    $207 = ($206 | 0) < 0;
    $208 = -$206 | 0;
    $span_0 = $207 ? $208 : $206;
    $209 = ($span_0 | 0) < 8;
    if ($209) {
      label = 38;
      break;
    } else {
      label = 44;
      break;
    }
   case 38:
    $211 = $edge3_0 + 8 | 0;
    $212 = HEAP32[$211 >> 2] | 0;
    $213 = $edge29_0 + 8 | 0;
    $214 = HEAP32[$213 >> 2] | 0;
    $215 = $214 << 1;
    $216 = $edge18_0 + 8 | 0;
    $217 = HEAP32[$216 >> 2] | 0;
    $218 = $215 - $217 | 0;
    $219 = $212 - $218 | 0;
    HEAP32[$211 >> 2] = $218;
    $220 = $edge3_0 + 24 | 0;
    $221 = HEAP32[$220 >> 2] | 0;
    $222 = ($221 | 0) == 0;
    if ($222) {
      label = 40;
      break;
    } else {
      label = 39;
      break;
    }
   case 39:
    $224 = $221 + 8 | 0;
    $225 = HEAP32[$224 >> 2] | 0;
    $226 = $225 - $219 | 0;
    HEAP32[$224 >> 2] = $226;
    label = 40;
    break;
   case 40:
    if ($189) {
      label = 41;
      break;
    } else {
      label = 42;
      break;
    }
   case 41:
    $229 = $2 + 392 | 0;
    $230 = HEAP32[$229 >> 2] | 0;
    $231 = $230 - $219 | 0;
    HEAP32[$229 >> 2] = $231;
    $232 = $2 + 536 | 0;
    $233 = HEAP32[$232 >> 2] | 0;
    $234 = $233 - $219 | 0;
    HEAP32[$232 >> 2] = $234;
    label = 42;
    break;
   case 42:
    $236 = $edge3_0 + 12 | 0;
    $237 = HEAP8[$236] | 0;
    $238 = $237 | 4;
    HEAP8[$236] = $238;
    $239 = HEAP32[$220 >> 2] | 0;
    $240 = ($239 | 0) == 0;
    if ($240) {
      label = 44;
      break;
    } else {
      label = 43;
      break;
    }
   case 43:
    $242 = $239 + 12 | 0;
    $243 = HEAP8[$242] | 0;
    $244 = $243 | 4;
    HEAP8[$242] = $244;
    label = 44;
    break;
   case 44:
    $246 = ($has_serifs_0_lcssa | 0) != 0;
    $247 = ($anchor_3_lcssa | 0) == 0;
    $or_cond = $246 | $247;
    $248 = ($4 | 0) > 0;
    $or_cond278 = $or_cond & $248;
    if ($or_cond278) {
      $anchor_5250 = $anchor_3_lcssa;
      $edge_2251 = $2;
      label = 45;
      break;
    } else {
      label = 68;
      break;
    }
   case 45:
    $249 = $edge_2251 + 12 | 0;
    $250 = HEAP8[$249] | 0;
    $251 = $250 & 4;
    $252 = $251 << 24 >> 24 == 0;
    if ($252) {
      label = 46;
      break;
    } else {
      $anchor_7 = $anchor_5250;
      label = 67;
      break;
    }
   case 46:
    $254 = $edge_2251 + 28 | 0;
    $255 = HEAP32[$254 >> 2] | 0;
    $256 = ($255 | 0) == 0;
    if ($256) {
      label = 49;
      break;
    } else {
      label = 47;
      break;
    }
   case 47:
    $258 = $255 + 4 | 0;
    $259 = HEAP32[$258 >> 2] | 0;
    $260 = $edge_2251 + 4 | 0;
    $261 = HEAP32[$260 >> 2] | 0;
    $262 = $259 - $261 | 0;
    $263 = ($262 | 0) < 0;
    $264 = -$262 | 0;
    $delta10_0 = $263 ? $264 : $262;
    $265 = ($delta10_0 | 0) < 80;
    if ($265) {
      label = 48;
      break;
    } else {
      label = 49;
      break;
    }
   case 48:
    $267 = HEAP32[$254 >> 2] | 0;
    _af_latin_align_serif_edge($267, $edge_2251);
    $anchor_6 = $anchor_5250;
    label = 60;
    break;
   case 49:
    $268 = ($anchor_5250 | 0) == 0;
    if ($268) {
      label = 50;
      break;
    } else {
      $edge_2_pn = $edge_2251;
      label = 51;
      break;
    }
   case 50:
    $270 = $edge_2251 + 4 | 0;
    $271 = HEAP32[$270 >> 2] | 0;
    $272 = $271 + 32 | 0;
    $273 = $272 & -64;
    $274 = $edge_2251 + 8 | 0;
    HEAP32[$274 >> 2] = $273;
    $anchor_6 = $edge_2251;
    label = 60;
    break;
   case 51:
    $before_0 = $edge_2_pn - 48 | 0;
    $275 = $before_0 >>> 0 >= $2 >>> 0;
    if ($275) {
      label = 52;
      break;
    } else {
      $edge_2_pn235 = $edge_2251;
      label = 53;
      break;
    }
   case 52:
    $277 = $edge_2_pn - 48 + 12 | 0;
    $278 = HEAP8[$277] | 0;
    $279 = $278 & 4;
    $280 = $279 << 24 >> 24 == 0;
    if ($280) {
      $edge_2_pn = $before_0;
      label = 51;
      break;
    } else {
      $edge_2_pn235 = $edge_2251;
      label = 53;
      break;
    }
   case 53:
    $after_0 = $edge_2_pn235 + 48 | 0;
    $281 = $after_0 >>> 0 < $5 >>> 0;
    if ($281) {
      label = 54;
      break;
    } else {
      label = 59;
      break;
    }
   case 54:
    $283 = $edge_2_pn235 + 60 | 0;
    $284 = HEAP8[$283] | 0;
    $285 = $284 & 4;
    $286 = $285 << 24 >> 24 == 0;
    if ($286) {
      $edge_2_pn235 = $after_0;
      label = 53;
      break;
    } else {
      label = 55;
      break;
    }
   case 55:
    $288 = $before_0 >>> 0 < $edge_2251 >>> 0;
    $or_cond243 = $275 & $288;
    $brmerge_demorgan = $or_cond243 & $281;
    $289 = $after_0 >>> 0 > $edge_2251 >>> 0;
    $or_cond244 = $brmerge_demorgan & $289;
    if ($or_cond244) {
      label = 56;
      break;
    } else {
      label = 59;
      break;
    }
   case 56:
    $291 = $edge_2_pn235 + 52 | 0;
    $292 = HEAP32[$291 >> 2] | 0;
    $293 = $edge_2_pn - 48 + 4 | 0;
    $294 = HEAP32[$293 >> 2] | 0;
    $295 = ($292 | 0) == ($294 | 0);
    $296 = $edge_2_pn - 48 + 8 | 0;
    $297 = HEAP32[$296 >> 2] | 0;
    if ($295) {
      label = 57;
      break;
    } else {
      label = 58;
      break;
    }
   case 57:
    $299 = $edge_2251 + 8 | 0;
    HEAP32[$299 >> 2] = $297;
    $anchor_6 = $anchor_5250;
    label = 60;
    break;
   case 58:
    $301 = $edge_2251 + 4 | 0;
    $302 = HEAP32[$301 >> 2] | 0;
    $303 = $302 - $294 | 0;
    $304 = $edge_2_pn235 + 56 | 0;
    $305 = HEAP32[$304 >> 2] | 0;
    $306 = $305 - $297 | 0;
    $307 = $292 - $294 | 0;
    $308 = _FT_MulDiv($303, $306, $307) | 0;
    $309 = $308 + $297 | 0;
    $310 = $edge_2251 + 8 | 0;
    HEAP32[$310 >> 2] = $309;
    $anchor_6 = $anchor_5250;
    label = 60;
    break;
   case 59:
    $311 = $anchor_5250 + 8 | 0;
    $312 = HEAP32[$311 >> 2] | 0;
    $313 = $edge_2251 + 4 | 0;
    $314 = HEAP32[$313 >> 2] | 0;
    $315 = $anchor_5250 + 4 | 0;
    $316 = HEAP32[$315 >> 2] | 0;
    $317 = $314 + 16 | 0;
    $318 = $317 - $316 | 0;
    $319 = $318 & -32;
    $320 = $319 + $312 | 0;
    $321 = $edge_2251 + 8 | 0;
    HEAP32[$321 >> 2] = $320;
    $anchor_6 = $anchor_5250;
    label = 60;
    break;
   case 60:
    $323 = HEAP8[$249] | 0;
    $324 = $323 | 4;
    HEAP8[$249] = $324;
    $325 = $edge_2251 >>> 0 > $2 >>> 0;
    if ($325) {
      label = 61;
      break;
    } else {
      label = 63;
      break;
    }
   case 61:
    $327 = $edge_2251 + 8 | 0;
    $328 = HEAP32[$327 >> 2] | 0;
    $329 = $edge_2251 - 48 + 8 | 0;
    $330 = HEAP32[$329 >> 2] | 0;
    $331 = ($328 | 0) < ($330 | 0);
    if ($331) {
      label = 62;
      break;
    } else {
      label = 63;
      break;
    }
   case 62:
    HEAP32[$327 >> 2] = $330;
    label = 63;
    break;
   case 63:
    $334 = $edge_2251 + 48 | 0;
    $335 = $334 >>> 0 < $5 >>> 0;
    if ($335) {
      label = 64;
      break;
    } else {
      $anchor_7 = $anchor_6;
      label = 67;
      break;
    }
   case 64:
    $337 = $edge_2251 + 60 | 0;
    $338 = HEAP8[$337] | 0;
    $339 = $338 & 4;
    $340 = $339 << 24 >> 24 == 0;
    if ($340) {
      $anchor_7 = $anchor_6;
      label = 67;
      break;
    } else {
      label = 65;
      break;
    }
   case 65:
    $342 = $edge_2251 + 8 | 0;
    $343 = HEAP32[$342 >> 2] | 0;
    $344 = $edge_2251 + 56 | 0;
    $345 = HEAP32[$344 >> 2] | 0;
    $346 = ($343 | 0) > ($345 | 0);
    if ($346) {
      label = 66;
      break;
    } else {
      $anchor_7 = $anchor_6;
      label = 67;
      break;
    }
   case 66:
    HEAP32[$342 >> 2] = $345;
    $anchor_7 = $anchor_6;
    label = 67;
    break;
   case 67:
    $349 = $edge_2251 + 48 | 0;
    $350 = $349 >>> 0 < $5 >>> 0;
    if ($350) {
      $anchor_5250 = $anchor_7;
      $edge_2251 = $349;
      label = 45;
      break;
    } else {
      label = 68;
      break;
    }
   case 68:
    return;
  }
}
function _af_latin_align_linked_edge($hints, $dim, $base_edge, $stem_edge) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  $base_edge = $base_edge | 0;
  $stem_edge = $stem_edge | 0;
  var $12 = 0;
  $12 = _af_latin_compute_stem_width($hints, $dim, (HEAP32[$stem_edge + 4 >> 2] | 0) - (HEAP32[$base_edge + 4 >> 2] | 0) | 0, HEAPU8[$base_edge + 12 | 0] | 0, HEAPU8[$stem_edge + 12 | 0] | 0) | 0;
  HEAP32[$stem_edge + 8 >> 2] = (HEAP32[$base_edge + 8 >> 2] | 0) + $12 | 0;
  return;
}
function _af_latin_compute_stem_width($hints, $dim, $width, $base_flags, $stem_flags) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  $width = $width | 0;
  $base_flags = $base_flags | 0;
  $stem_flags = $stem_flags | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $_width = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $_not58 = 0, $brmerge_not = 0, $25 = 0, $or_cond = 0, $26 = 0, $27 = 0, $29 = 0, $__width = 0, $31 = 0, $__width54 = 0, $dist_1 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $_55 = 0, $42 = 0, $44 = 0, $_56 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $54 = 0, $56 = 0, $57 = 0, $_dist_1 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $69 = 0, $70 = 0, $72 = 0, $73 = 0, $74 = 0, $76 = 0, $78 = 0, $79 = 0, $81 = 0, $83 = 0, $84 = 0, $86 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $_57 = 0, $93 = 0, $95 = 0, $97 = 0, $98 = 0, $100 = 0, $101 = 0, $dist_2 = 0, $103 = 0, $104 = 0, $dist_3 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $hints + 112 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 40 | 0;
    $4 = $3;
    $5 = ($dim | 0) == 1;
    $6 = $hints + 108 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7 & 4;
    $9 = ($8 | 0) == 0;
    if ($9) {
      $_0 = $width;
      label = 33;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $11 = $4 + ($dim * 396 & -1) + 212 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $12 << 24 >> 24 == 0;
    if ($13) {
      label = 3;
      break;
    } else {
      $_0 = $width;
      label = 33;
      break;
    }
   case 3:
    $15 = ($width | 0) < 0;
    $16 = -$width | 0;
    $_width = $15 ? $16 : $width;
    if ($5) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $18 = $7 & 2;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 6;
      break;
    } else {
      label = 19;
      break;
    }
   case 5:
    $20 = HEAP32[$6 >> 2] | 0;
    $21 = $20 & 1;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 7;
      break;
    } else {
      label = 19;
      break;
    }
   case 6:
    $24 = $stem_flags & 2;
    $_not58 = ($24 | 0) != 0;
    $brmerge_not = $5 & $_not58;
    $25 = ($_width | 0) < 192;
    $or_cond = $brmerge_not & $25;
    if ($or_cond) {
      $dist_2 = $_width;
      label = 32;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $26 = $base_flags & 1;
    $27 = ($26 | 0) == 0;
    if ($27) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $29 = ($_width | 0) < 80;
    $__width = $29 ? 64 : $_width;
    $dist_1 = $__width;
    label = 10;
    break;
   case 9:
    $31 = ($_width | 0) < 56;
    $__width54 = $31 ? 56 : $_width;
    $dist_1 = $__width54;
    label = 10;
    break;
   case 10:
    $33 = $4 + ($dim * 396 & -1) + 8 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = ($34 | 0) == 0;
    if ($35) {
      $dist_2 = $dist_1;
      label = 32;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $37 = $4 + ($dim * 396 & -1) + 16 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $dist_1 - $38 | 0;
    $40 = ($39 | 0) < 0;
    $41 = -$39 | 0;
    $_55 = $40 ? $41 : $39;
    $42 = ($_55 | 0) < 40;
    if ($42) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $44 = ($38 | 0) < 48;
    $_56 = $44 ? 48 : $38;
    $dist_2 = $_56;
    label = 32;
    break;
   case 13:
    $46 = ($dist_1 | 0) < 192;
    if ($46) {
      label = 14;
      break;
    } else {
      label = 18;
      break;
    }
   case 14:
    $48 = $dist_1 & 63;
    $49 = $dist_1 & -64;
    $50 = $48 >>> 0 < 10;
    if ($50) {
      $dist_2 = $dist_1;
      label = 32;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $52 = $48 >>> 0 < 32;
    if ($52) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    $54 = $49 | 10;
    $dist_2 = $54;
    label = 32;
    break;
   case 17:
    $56 = $48 >>> 0 < 54;
    $57 = $49 | 54;
    $_dist_1 = $56 ? $57 : $dist_1;
    $dist_2 = $_dist_1;
    label = 32;
    break;
   case 18:
    $59 = $dist_1 + 32 | 0;
    $60 = $59 & -64;
    $dist_2 = $60;
    label = 32;
    break;
   case 19:
    $62 = $4 + ($dim * 396 & -1) + 12 | 0;
    $63 = $4 + ($dim * 396 & -1) + 8 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = _af_latin_snap_width($62, $64, $_width) | 0;
    if ($5) {
      label = 20;
      break;
    } else {
      label = 22;
      break;
    }
   case 20:
    $67 = ($65 | 0) > 63;
    if ($67) {
      label = 21;
      break;
    } else {
      $dist_2 = 64;
      label = 32;
      break;
    }
   case 21:
    $69 = $65 + 16 | 0;
    $70 = $69 & -64;
    $dist_2 = $70;
    label = 32;
    break;
   case 22:
    $72 = HEAP32[$6 >> 2] | 0;
    $73 = $72 & 8;
    $74 = ($73 | 0) == 0;
    if ($74) {
      label = 25;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $76 = ($65 | 0) < 64;
    if ($76) {
      $dist_2 = 64;
      label = 32;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $78 = $65 + 32 | 0;
    $79 = $78 & -64;
    $dist_2 = $79;
    label = 32;
    break;
   case 25:
    $81 = ($65 | 0) < 48;
    if ($81) {
      label = 26;
      break;
    } else {
      label = 27;
      break;
    }
   case 26:
    $83 = $65 + 64 | 0;
    $84 = $83 >> 1;
    $dist_2 = $84;
    label = 32;
    break;
   case 27:
    $86 = ($65 | 0) < 128;
    if ($86) {
      label = 28;
      break;
    } else {
      label = 31;
      break;
    }
   case 28:
    $88 = $65 + 22 | 0;
    $89 = $88 & -64;
    $90 = $89 - $_width | 0;
    $91 = ($90 | 0) < 0;
    $92 = -$90 | 0;
    $_57 = $91 ? $92 : $90;
    $93 = ($_57 | 0) > 15;
    if ($93) {
      label = 29;
      break;
    } else {
      $dist_2 = $89;
      label = 32;
      break;
    }
   case 29:
    $95 = ($_width | 0) < 48;
    if ($95) {
      label = 30;
      break;
    } else {
      $dist_2 = $_width;
      label = 32;
      break;
    }
   case 30:
    $97 = $_width + 64 | 0;
    $98 = $97 >> 1;
    $dist_2 = $98;
    label = 32;
    break;
   case 31:
    $100 = $65 + 32 | 0;
    $101 = $100 & -64;
    $dist_2 = $101;
    label = 32;
    break;
   case 32:
    $103 = ($width | 0) > -1;
    $104 = -$dist_2 | 0;
    $dist_3 = $103 ? $dist_2 : $104;
    $_0 = $dist_3;
    label = 33;
    break;
   case 33:
    return $_0 | 0;
  }
  return 0;
}
function _af_latin_align_serif_edge($base, $serif) {
  $base = $base | 0;
  $serif = $serif | 0;
  HEAP32[$serif + 8 >> 2] = ((HEAP32[$serif + 4 >> 2] | 0) + (HEAP32[$base + 8 >> 2] | 0) | 0) - (HEAP32[$base + 4 >> 2] | 0) | 0;
  return;
}
function _af_latin_snap_width($widths, $count, $width) {
  $widths = $widths | 0;
  $count = $count | 0;
  $width = $width | 0;
  var $1 = 0, $2 = 0, $3 = 0, $n_019 = 0, $reference_018 = 0, $best_017 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_ = 0, $9 = 0, $best_1 = 0, $reference_1 = 0, $10 = 0, $exitcond = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $reference_0_lcssa20 = 0, $16 = 0, $17 = 0, $reference_0_width = 0, $19 = 0, $20 = 0, $reference_0_width16 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($count | 0) > 0;
    if ($1) {
      $best_017 = 98;
      $reference_018 = $width;
      $n_019 = 0;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $2 = $width + 32 | 0;
    $3 = $2 & -64;
    $reference_0_lcssa20 = $width;
    $15 = $3;
    label = 5;
    break;
   case 3:
    $4 = $widths + ($n_019 * 12 & -1) + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $width - $5 | 0;
    $7 = ($6 | 0) < 0;
    $8 = -$6 | 0;
    $_ = $7 ? $8 : $6;
    $9 = ($_ | 0) < ($best_017 | 0);
    $best_1 = $9 ? $_ : $best_017;
    $reference_1 = $9 ? $5 : $reference_018;
    $10 = $n_019 + 1 | 0;
    $exitcond = ($10 | 0) == ($count | 0);
    if ($exitcond) {
      label = 4;
      break;
    } else {
      $best_017 = $best_1;
      $reference_018 = $reference_1;
      $n_019 = $10;
      label = 3;
      break;
    }
   case 4:
    $11 = $reference_1 + 32 | 0;
    $12 = $11 & -64;
    $13 = ($reference_1 | 0) > ($width | 0);
    if ($13) {
      label = 6;
      break;
    } else {
      $reference_0_lcssa20 = $reference_1;
      $15 = $12;
      label = 5;
      break;
    }
   case 5:
    $16 = $15 | 48;
    $17 = ($16 | 0) > ($width | 0);
    $reference_0_width = $17 ? $reference_0_lcssa20 : $width;
    return $reference_0_width | 0;
   case 6:
    $19 = $12 - 48 | 0;
    $20 = ($19 | 0) < ($width | 0);
    $reference_0_width16 = $20 ? $reference_1 : $width;
    return $reference_0_width16 | 0;
  }
  return 0;
}
function _af_sort_pos($count, $table) {
  $count = $count | 0;
  $table = $table | 0;
  var $1 = 0, $i_017 = 0, $j_016 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $exitcond = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $count >>> 0 > 1;
    if ($1) {
      $i_017 = 1;
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $j_016 = $i_017;
    label = 3;
    break;
   case 3:
    $3 = $table + ($j_016 << 2) | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $j_016 - 1 | 0;
    $6 = $table + ($5 << 2) | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = ($4 | 0) > ($7 | 0);
    if ($8) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    HEAP32[$3 >> 2] = $7;
    HEAP32[$6 >> 2] = $4;
    $10 = ($5 | 0) == 0;
    if ($10) {
      label = 5;
      break;
    } else {
      $j_016 = $5;
      label = 3;
      break;
    }
   case 5:
    $11 = $i_017 + 1 | 0;
    $exitcond = ($11 | 0) == ($count | 0);
    if ($exitcond) {
      label = 6;
      break;
    } else {
      $i_017 = $11;
      label = 2;
      break;
    }
   case 6:
    return;
  }
}
function _bdf_cmap_init($bdfcmap, $init_data) {
  $bdfcmap = $bdfcmap | 0;
  $init_data = $init_data | 0;
  var $2 = 0;
  $2 = HEAP32[$bdfcmap >> 2] | 0;
  HEAP32[$bdfcmap + 16 >> 2] = HEAP32[(HEAP32[$2 + 140 >> 2] | 0) + 52 >> 2] | 0;
  HEAP32[$bdfcmap + 20 >> 2] = HEAP32[$2 + 144 >> 2] | 0;
  return 0;
}
function _af_latin_hints_compute_edges($hints, $dim) {
  $hints = $hints | 0;
  $dim = $dim | 0;
  var $edge1 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $_in = 0, $17 = 0, $19 = 0, $20 = 0, $segment_length_threshold_0 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $_ = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $seg_0120 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $ee_0116 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $dist_0 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $edge2_0111 = 0, $114 = 0, $115 = 0, $116 = 0, $seg_1 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $edge2_1108 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $seg_2 = 0, $is_round_0 = 0, $is_straight_0 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $is_round_1 = 0, $136 = 0, $137 = 0, $is_straight_1 = 0, $138 = 0, $139 = 0, $140 = 0, $142 = 0, $143 = 0, $144 = 0, $not_ = 0, $_104 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $151 = 0, $152 = 0, $_not = 0, $brmerge = 0, $_105 = 0, $_106 = 0, $seg2_0 = 0, $edge23_0 = 0, $155 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $edge_delta_0 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $seg_delta_0 = 0, $174 = 0, $176 = 0, $177 = 0, $179 = 0, $180 = 0, $edge23_1 = 0, $183 = 0, $184 = 0, $185 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $193 = 0, $194 = 0, $195 = 0, $or_cond = 0, $196 = 0, $_107 = 0, $197 = 0, $198 = 0, $199 = 0, $201 = 0, $202 = 0, $203 = 0, $206 = 0, $207 = 0, $error_2 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $edge1 = __stackBase__ | 0;
    $1 = $hints + 48 + ($dim * 28 & -1) | 0;
    $2 = $hints | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $hints + 112 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 + 40 | 0;
    $7 = $6;
    $8 = $hints + 48 + ($dim * 28 & -1) + 8 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $1 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $9 + ($11 * 52 & -1) | 0;
    $13 = $hints + 48 + ($dim * 28 & -1) + 12 | 0;
    HEAP32[$13 >> 2] = 0;
    $14 = ($dim | 0) == 0;
    $15 = $hints + 4 | 0;
    $16 = $hints + 12 | 0;
    $_in = $14 ? $15 : $16;
    $17 = HEAP32[$_in >> 2] | 0;
    if ($14) {
      label = 2;
      break;
    } else {
      $segment_length_threshold_0 = 0;
      label = 3;
      break;
    }
   case 2:
    $19 = HEAP32[$16 >> 2] | 0;
    $20 = _FT_DivFix(64, $19) | 0;
    $segment_length_threshold_0 = $20;
    label = 3;
    break;
   case 3:
    $22 = $7 + ($dim * 396 & -1) + 204 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = _FT_MulFix($23, $17) | 0;
    $25 = ($24 | 0) > 16;
    $_ = $25 ? 16 : $24;
    $26 = _FT_DivFix($_, $17) | 0;
    $27 = ($11 | 0) > 0;
    if ($27) {
      label = 4;
      break;
    } else {
      label = 18;
      break;
    }
   case 4:
    $28 = $segment_length_threshold_0 * 3 & -1;
    $29 = $hints + 48 + ($dim * 28 & -1) + 20 | 0;
    $seg_0120 = $9;
    label = 5;
    break;
   case 5:
    $31 = $seg_0120 + 8 | 0;
    $32 = HEAP16[$31 >> 1] | 0;
    $33 = $32 << 16 >> 16;
    $34 = ($33 | 0) < ($segment_length_threshold_0 | 0);
    if ($34) {
      label = 17;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $36 = $seg_0120 + 24 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = ($37 | 0) == 0;
    if ($38) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $40 = $33 << 1;
    $41 = ($40 | 0) < ($28 | 0);
    if ($41) {
      label = 17;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $42 = HEAP32[$13 >> 2] | 0;
    $43 = ($42 | 0) > 0;
    if ($43) {
      label = 9;
      break;
    } else {
      label = 14;
      break;
    }
   case 9:
    $44 = HEAP32[$29 >> 2] | 0;
    $45 = $seg_0120 + 2 | 0;
    $46 = HEAP16[$45 >> 1] | 0;
    $47 = $46 << 16 >> 16;
    $48 = $seg_0120 + 1 | 0;
    $ee_0116 = 0;
    label = 10;
    break;
   case 10:
    $50 = $44 + ($ee_0116 * 48 & -1) | 0;
    $51 = $50 | 0;
    $52 = HEAP16[$51 >> 1] | 0;
    $53 = $52 << 16 >> 16;
    $54 = $47 - $53 | 0;
    $55 = ($54 | 0) < 0;
    $56 = -$54 | 0;
    $dist_0 = $55 ? $56 : $54;
    $57 = ($dist_0 | 0) < ($26 | 0);
    if ($57) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $59 = $44 + ($ee_0116 * 48 & -1) + 13 | 0;
    $60 = HEAP8[$59] | 0;
    $61 = HEAP8[$48] | 0;
    $62 = $60 << 24 >> 24 == $61 << 24 >> 24;
    if ($62) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $64 = $ee_0116 + 1 | 0;
    $65 = HEAP32[$13 >> 2] | 0;
    $66 = ($64 | 0) < ($65 | 0);
    if ($66) {
      $ee_0116 = $64;
      label = 10;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    $68 = ($50 | 0) == 0;
    if ($68) {
      label = 14;
      break;
    } else {
      label = 16;
      break;
    }
   case 14:
    $69 = $seg_0120 + 2 | 0;
    $70 = HEAP16[$69 >> 1] | 0;
    $71 = $70 << 16 >> 16;
    $72 = $seg_0120 + 1 | 0;
    $73 = HEAP8[$72] | 0;
    $74 = $73 << 24 >> 24;
    $75 = _af_axis_hints_new_edge($1, $71, $74, $3, $edge1) | 0;
    $76 = ($75 | 0) == 0;
    if ($76) {
      label = 15;
      break;
    } else {
      $error_2 = $75;
      label = 41;
      break;
    }
   case 15:
    $78 = HEAP32[$edge1 >> 2] | 0;
    $79 = $78;
    _memset($79 | 0, 0, 48);
    $80 = HEAP32[$edge1 >> 2] | 0;
    $81 = $80 + 40 | 0;
    HEAP32[$81 >> 2] = $seg_0120;
    $82 = HEAP32[$edge1 >> 2] | 0;
    $83 = $82 + 44 | 0;
    HEAP32[$83 >> 2] = $seg_0120;
    $84 = HEAP16[$69 >> 1] | 0;
    $85 = HEAP32[$edge1 >> 2] | 0;
    $86 = $85 | 0;
    HEAP16[$86 >> 1] = $84;
    $87 = HEAP8[$72] | 0;
    $88 = HEAP32[$edge1 >> 2] | 0;
    $89 = $88 + 13 | 0;
    HEAP8[$89] = $87;
    $90 = HEAP16[$69 >> 1] | 0;
    $91 = $90 << 16 >> 16;
    $92 = _FT_MulFix($91, $17) | 0;
    $93 = HEAP32[$edge1 >> 2] | 0;
    $94 = $93 + 8 | 0;
    HEAP32[$94 >> 2] = $92;
    $95 = HEAP32[$edge1 >> 2] | 0;
    $96 = $95 + 4 | 0;
    HEAP32[$96 >> 2] = $92;
    $97 = $seg_0120 + 16 | 0;
    HEAP32[$97 >> 2] = $seg_0120;
    label = 17;
    break;
   case 16:
    $99 = $44 + ($ee_0116 * 48 & -1) + 40 | 0;
    $100 = HEAP32[$99 >> 2] | 0;
    $101 = $seg_0120 + 16 | 0;
    HEAP32[$101 >> 2] = $100;
    $102 = $44 + ($ee_0116 * 48 & -1) + 44 | 0;
    $103 = HEAP32[$102 >> 2] | 0;
    $104 = $103 + 16 | 0;
    HEAP32[$104 >> 2] = $seg_0120;
    HEAP32[$102 >> 2] = $seg_0120;
    label = 17;
    break;
   case 17:
    $106 = $seg_0120 + 52 | 0;
    $107 = $106 >>> 0 < $12 >>> 0;
    if ($107) {
      $seg_0120 = $106;
      label = 5;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $108 = $hints + 48 + ($dim * 28 & -1) + 20 | 0;
    $109 = HEAP32[$108 >> 2] | 0;
    $110 = HEAP32[$13 >> 2] | 0;
    $111 = $109 + ($110 * 48 & -1) | 0;
    $112 = ($110 | 0) > 0;
    if ($112) {
      $edge2_0111 = $109;
      label = 20;
      break;
    } else {
      $error_2 = 0;
      label = 41;
      break;
    }
   case 19:
    $113 = ($110 | 0) > 0;
    if ($113) {
      $edge2_1108 = $109;
      label = 23;
      break;
    } else {
      $error_2 = 0;
      label = 41;
      break;
    }
   case 20:
    $114 = $edge2_0111 + 40 | 0;
    $115 = HEAP32[$114 >> 2] | 0;
    $116 = ($115 | 0) == 0;
    if ($116) {
      label = 22;
      break;
    } else {
      $seg_1 = $115;
      label = 21;
      break;
    }
   case 21:
    $117 = $seg_1 + 12 | 0;
    HEAP32[$117 >> 2] = $edge2_0111;
    $118 = $seg_1 + 16 | 0;
    $119 = HEAP32[$118 >> 2] | 0;
    $120 = HEAP32[$114 >> 2] | 0;
    $121 = ($119 | 0) == ($120 | 0);
    if ($121) {
      label = 22;
      break;
    } else {
      $seg_1 = $119;
      label = 21;
      break;
    }
   case 22:
    $122 = $edge2_0111 + 48 | 0;
    $123 = $122 >>> 0 < $111 >>> 0;
    if ($123) {
      $edge2_0111 = $122;
      label = 20;
      break;
    } else {
      label = 19;
      break;
    }
   case 23:
    $124 = $edge2_1108 + 40 | 0;
    $125 = HEAP32[$124 >> 2] | 0;
    $126 = $edge2_1108 + 24 | 0;
    $127 = $edge2_1108 + 28 | 0;
    $128 = $edge2_1108 | 0;
    $is_straight_0 = 0;
    $is_round_0 = 0;
    $seg_2 = $125;
    label = 24;
    break;
   case 24:
    $130 = $seg_2 | 0;
    $131 = HEAP8[$130] | 0;
    $132 = $131 & 1;
    $133 = $132 ^ 1;
    $134 = $133 & 255;
    $135 = $134 ^ 1;
    $is_round_1 = $135 + $is_round_0 | 0;
    $136 = $132 ^ 1;
    $137 = $136 & 255;
    $is_straight_1 = $137 + $is_straight_0 | 0;
    $138 = $seg_2 + 24 | 0;
    $139 = HEAP32[$138 >> 2] | 0;
    $140 = ($139 | 0) == 0;
    if ($140) {
      $146 = 0;
      label = 26;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $142 = $139 + 12 | 0;
    $143 = HEAP32[$142 >> 2] | 0;
    $144 = ($143 | 0) != ($edge2_1108 | 0);
    $not_ = ($143 | 0) != 0;
    $_104 = $144 & $not_;
    $146 = $_104;
    label = 26;
    break;
   case 26:
    $147 = $seg_2 + 20 | 0;
    $148 = HEAP32[$147 >> 2] | 0;
    $149 = ($148 | 0) == 0;
    if ($149) {
      label = 28;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $151 = $148 + 12 | 0;
    $152 = HEAP32[$151 >> 2] | 0;
    $_not = ($152 | 0) != 0;
    $brmerge = $_not | $146;
    if ($brmerge) {
      label = 29;
      break;
    } else {
      label = 36;
      break;
    }
   case 28:
    if ($146) {
      label = 29;
      break;
    } else {
      label = 36;
      break;
    }
   case 29:
    $_105 = $146 ? $127 : $126;
    $_106 = $146 ? $138 : $147;
    $seg2_0 = HEAP32[$_106 >> 2] | 0;
    $edge23_0 = HEAP32[$_105 >> 2] | 0;
    $155 = ($edge23_0 | 0) == 0;
    if ($155) {
      label = 32;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    $157 = HEAP16[$128 >> 1] | 0;
    $158 = $157 << 16 >> 16;
    $159 = $edge23_0 | 0;
    $160 = HEAP16[$159 >> 1] | 0;
    $161 = $160 << 16 >> 16;
    $162 = $158 - $161 | 0;
    $163 = ($162 | 0) < 0;
    $164 = -$162 | 0;
    $edge_delta_0 = $163 ? $164 : $162;
    $165 = $seg_2 + 2 | 0;
    $166 = HEAP16[$165 >> 1] | 0;
    $167 = $166 << 16 >> 16;
    $168 = $seg2_0 + 2 | 0;
    $169 = HEAP16[$168 >> 1] | 0;
    $170 = $169 << 16 >> 16;
    $171 = $167 - $170 | 0;
    $172 = ($171 | 0) < 0;
    $173 = -$171 | 0;
    $seg_delta_0 = $172 ? $173 : $171;
    $174 = ($seg_delta_0 | 0) < ($edge_delta_0 | 0);
    if ($174) {
      label = 31;
      break;
    } else {
      $edge23_1 = $edge23_0;
      label = 33;
      break;
    }
   case 31:
    $176 = $seg2_0 + 12 | 0;
    $177 = HEAP32[$176 >> 2] | 0;
    $edge23_1 = $177;
    label = 33;
    break;
   case 32:
    $179 = $seg2_0 + 12 | 0;
    $180 = HEAP32[$179 >> 2] | 0;
    $edge23_1 = $180;
    label = 33;
    break;
   case 33:
    if ($146) {
      label = 34;
      break;
    } else {
      label = 35;
      break;
    }
   case 34:
    HEAP32[$127 >> 2] = $edge23_1;
    $183 = $edge23_1 + 12 | 0;
    $184 = HEAP8[$183] | 0;
    $185 = $184 | 2;
    HEAP8[$183] = $185;
    label = 36;
    break;
   case 35:
    HEAP32[$126 >> 2] = $edge23_1;
    label = 36;
    break;
   case 36:
    $188 = $seg_2 + 16 | 0;
    $189 = HEAP32[$188 >> 2] | 0;
    $190 = HEAP32[$124 >> 2] | 0;
    $191 = ($189 | 0) == ($190 | 0);
    if ($191) {
      label = 37;
      break;
    } else {
      $is_straight_0 = $is_straight_1;
      $is_round_0 = $is_round_1;
      $seg_2 = $189;
      label = 24;
      break;
    }
   case 37:
    $193 = $edge2_1108 + 12 | 0;
    $194 = ($is_round_1 | 0) < 1;
    $195 = ($is_round_1 | 0) < ($is_straight_1 | 0);
    $or_cond = $194 | $195;
    $196 = $or_cond & 1;
    $_107 = $196 ^ 1;
    HEAP8[$193] = $_107;
    $197 = $edge2_1108 + 28 | 0;
    $198 = HEAP32[$197 >> 2] | 0;
    $199 = ($198 | 0) == 0;
    if ($199) {
      label = 40;
      break;
    } else {
      label = 38;
      break;
    }
   case 38:
    $201 = $edge2_1108 + 24 | 0;
    $202 = HEAP32[$201 >> 2] | 0;
    $203 = ($202 | 0) == 0;
    if ($203) {
      label = 40;
      break;
    } else {
      label = 39;
      break;
    }
   case 39:
    HEAP32[$197 >> 2] = 0;
    label = 40;
    break;
   case 40:
    $206 = $edge2_1108 + 48 | 0;
    $207 = $206 >>> 0 < $111 >>> 0;
    if ($207) {
      $edge2_1108 = $206;
      label = 23;
      break;
    } else {
      $error_2 = 0;
      label = 41;
      break;
    }
   case 41:
    STACKTOP = __stackBase__;
    return $error_2 | 0;
  }
  return 0;
}
function _af_latin_metrics_scale_dim($metrics, $scaler, $dim) {
  $metrics = $metrics | 0;
  $scaler = $scaler | 0;
  $dim = $dim | 0;
  var $1 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $delta_0_in = 0, $scale_0_in = 0, $scale_0 = 0, $delta_0 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $nn_0 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $or_cond = 0, $42 = 0, $scale_1 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $nn_186 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $nn_284 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $_off = 0, $91 = 0, $93 = 0, $94 = 0, $95 = 0, $_ = 0, $96 = 0, $97 = 0, $99 = 0, $101 = 0, $102 = 0, $104 = 0, $105 = 0, $delta2_1 = 0, $107 = 0, $delta2_2 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $115 = 0, $116 = 0, $117 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($dim | 0) == 0;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = $scaler + 4 | 0;
    $4 = $scaler + 12 | 0;
    $scale_0_in = $3;
    $delta_0_in = $4;
    label = 4;
    break;
   case 3:
    $6 = $scaler + 8 | 0;
    $7 = $scaler + 16 | 0;
    $scale_0_in = $6;
    $delta_0_in = $7;
    label = 4;
    break;
   case 4:
    $scale_0 = HEAP32[$scale_0_in >> 2] | 0;
    $delta_0 = HEAP32[$delta_0_in >> 2] | 0;
    $9 = $metrics + 40 + ($dim * 396 & -1) + 388 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($10 | 0) == ($scale_0 | 0);
    if ($11) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $13 = $metrics + 40 + ($dim * 396 & -1) + 392 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($14 | 0) == ($delta_0 | 0);
    if ($15) {
      label = 26;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    HEAP32[$9 >> 2] = $scale_0;
    $17 = $metrics + 40 + ($dim * 396 & -1) + 392 | 0;
    HEAP32[$17 >> 2] = $delta_0;
    $18 = $metrics + 652 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $nn_0 = 0;
    label = 7;
    break;
   case 7:
    $21 = $nn_0 >>> 0 < $19 >>> 0;
    if ($21) {
      label = 8;
      break;
    } else {
      $scale_1 = $scale_0;
      label = 12;
      break;
    }
   case 8:
    $23 = $metrics + 656 + ($nn_0 * 28 & -1) + 24 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24 & 4;
    $26 = ($25 | 0) == 0;
    $27 = $nn_0 + 1 | 0;
    if ($26) {
      $nn_0 = $27;
      label = 7;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $29 = $metrics + 656 + ($nn_0 * 28 & -1) | 0;
    $30 = ($29 | 0) == 0;
    if ($30) {
      $scale_1 = $scale_0;
      label = 12;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $32 = $metrics + 656 + ($nn_0 * 28 & -1) + 12 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $scaler + 8 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = _FT_MulFix($33, $35) | 0;
    $37 = $36 + 40 | 0;
    $38 = $37 & -64;
    $39 = ($36 | 0) != ($38 | 0);
    $40 = ($dim | 0) == 1;
    $or_cond = $39 & $40;
    if ($or_cond) {
      label = 11;
      break;
    } else {
      $scale_1 = $scale_0;
      label = 12;
      break;
    }
   case 11:
    $42 = _FT_MulDiv($scale_0, $38, $36) | 0;
    $scale_1 = $42;
    label = 12;
    break;
   case 12:
    $43 = $metrics + 40 + ($dim * 396 & -1) | 0;
    HEAP32[$43 >> 2] = $scale_1;
    $44 = $metrics + 40 + ($dim * 396 & -1) + 4 | 0;
    HEAP32[$44 >> 2] = $delta_0;
    if ($1) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    $46 = $metrics + 8 | 0;
    HEAP32[$46 >> 2] = $scale_1;
    $47 = $metrics + 16 | 0;
    HEAP32[$47 >> 2] = $delta_0;
    label = 15;
    break;
   case 14:
    $49 = $metrics + 12 | 0;
    HEAP32[$49 >> 2] = $scale_1;
    $50 = $metrics + 20 | 0;
    HEAP32[$50 >> 2] = $delta_0;
    label = 15;
    break;
   case 15:
    $51 = $metrics + 40 + ($dim * 396 & -1) + 8 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = ($52 | 0) == 0;
    if ($53) {
      label = 17;
      break;
    } else {
      $nn_186 = 0;
      label = 16;
      break;
    }
   case 16:
    $54 = $metrics + 40 + ($dim * 396 & -1) + 12 + ($nn_186 * 12 & -1) | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = _FT_MulFix($55, $scale_1) | 0;
    $57 = $metrics + 40 + ($dim * 396 & -1) + 12 + ($nn_186 * 12 & -1) + 4 | 0;
    HEAP32[$57 >> 2] = $56;
    $58 = $metrics + 40 + ($dim * 396 & -1) + 12 + ($nn_186 * 12 & -1) + 8 | 0;
    HEAP32[$58 >> 2] = $56;
    $59 = $nn_186 + 1 | 0;
    $60 = HEAP32[$51 >> 2] | 0;
    $61 = $59 >>> 0 < $60 >>> 0;
    if ($61) {
      $nn_186 = $59;
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $62 = $metrics + 40 + ($dim * 396 & -1) + 208 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = _FT_MulFix($63, $scale_1) | 0;
    $65 = ($64 | 0) < 40;
    $66 = $65 & 1;
    $67 = $metrics + 40 + ($dim * 396 & -1) + 212 | 0;
    HEAP8[$67] = $66;
    $68 = ($dim | 0) == 1;
    if ($68) {
      label = 18;
      break;
    } else {
      label = 26;
      break;
    }
   case 18:
    $69 = $metrics + 40 + ($dim * 396 & -1) + 216 | 0;
    $70 = HEAP32[$69 >> 2] | 0;
    $71 = ($70 | 0) == 0;
    if ($71) {
      label = 26;
      break;
    } else {
      $nn_284 = 0;
      label = 19;
      break;
    }
   case 19:
    $72 = $metrics + 40 + ($dim * 396 & -1) + 220 + ($nn_284 * 28 & -1) | 0;
    $73 = HEAP32[$72 >> 2] | 0;
    $74 = _FT_MulFix($73, $scale_1) | 0;
    $75 = $74 + $delta_0 | 0;
    $76 = $metrics + 40 + ($dim * 396 & -1) + 220 + ($nn_284 * 28 & -1) + 4 | 0;
    HEAP32[$76 >> 2] = $75;
    $77 = $metrics + 40 + ($dim * 396 & -1) + 220 + ($nn_284 * 28 & -1) + 8 | 0;
    HEAP32[$77 >> 2] = $75;
    $78 = $metrics + 40 + ($dim * 396 & -1) + 220 + ($nn_284 * 28 & -1) + 12 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = _FT_MulFix($79, $scale_1) | 0;
    $81 = $80 + $delta_0 | 0;
    $82 = $metrics + 40 + ($dim * 396 & -1) + 220 + ($nn_284 * 28 & -1) + 16 | 0;
    HEAP32[$82 >> 2] = $81;
    $83 = $metrics + 40 + ($dim * 396 & -1) + 220 + ($nn_284 * 28 & -1) + 20 | 0;
    HEAP32[$83 >> 2] = $81;
    $84 = $metrics + 40 + ($dim * 396 & -1) + 220 + ($nn_284 * 28 & -1) + 24 | 0;
    $85 = HEAP32[$84 >> 2] | 0;
    $86 = $85 & -2;
    HEAP32[$84 >> 2] = $86;
    $87 = HEAP32[$72 >> 2] | 0;
    $88 = HEAP32[$78 >> 2] | 0;
    $89 = $87 - $88 | 0;
    $90 = _FT_MulFix($89, $scale_1) | 0;
    $_off = $90 + 48 | 0;
    $91 = $_off >>> 0 < 97;
    if ($91) {
      label = 20;
      break;
    } else {
      label = 25;
      break;
    }
   case 20:
    $93 = $88 - $87 | 0;
    $94 = ($93 | 0) < 0;
    $95 = -$93 | 0;
    $_ = $94 ? $95 : $93;
    $96 = _FT_MulFix($_, $scale_1) | 0;
    $97 = ($96 | 0) < 32;
    if ($97) {
      $delta2_1 = 0;
      label = 24;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $99 = ($96 | 0) < 64;
    if ($99) {
      label = 22;
      break;
    } else {
      label = 23;
      break;
    }
   case 22:
    $101 = $96 + 16 | 0;
    $102 = $101 & -32;
    $delta2_1 = $102;
    label = 24;
    break;
   case 23:
    $104 = $96 + 32 | 0;
    $105 = $104 & -64;
    $delta2_1 = $105;
    label = 24;
    break;
   case 24:
    $107 = -$delta2_1 | 0;
    $delta2_2 = $94 ? $107 : $delta2_1;
    $108 = HEAP32[$76 >> 2] | 0;
    $109 = $108 + 32 | 0;
    $110 = $109 & -64;
    HEAP32[$77 >> 2] = $110;
    $111 = $110 + $delta2_2 | 0;
    HEAP32[$83 >> 2] = $111;
    $112 = HEAP32[$84 >> 2] | 0;
    $113 = $112 | 1;
    HEAP32[$84 >> 2] = $113;
    label = 25;
    break;
   case 25:
    $115 = $nn_284 + 1 | 0;
    $116 = HEAP32[$69 >> 2] | 0;
    $117 = $115 >>> 0 < $116 >>> 0;
    if ($117) {
      $nn_284 = $115;
      label = 19;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    return;
  }
}
function _af_latin_metrics_init_blues($metrics, $face) {
  $metrics = $metrics | 0;
  $face = $face | 0;
  var $flats = 0, $rounds = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $bb_0153 = 0, $11 = 0, $12 = 0, $num_flats_0148 = 0, $num_rounds_0147 = 0, $p_0146 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $first_0136 = 0, $nn_0135 = 0, $best_y_0134 = 0, $best_last_0133 = 0, $best_first_0132 = 0, $best_point_0130 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $pp_0118 = 0, $best_y_1117 = 0, $best_point_1116 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $53 = 0, $best_point_2 = 0, $best_y_2 = 0, $55 = 0, $exitcond = 0, $pp_1125 = 0, $best_y_3124 = 0, $best_point_3123 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $best_point_4 = 0, $best_y_4 = 0, $66 = 0, $exitcond155 = 0, $best_point_5 = 0, $best_y_5 = 0, $67 = 0, $best_first_0_first_0 = 0, $best_last_0_ = 0, $best_point_6 = 0, $best_first_1 = 0, $best_last_1 = 0, $best_y_6 = 0, $69 = 0, $70 = 0, $71 = 0, $phitmp = 0, $73 = 0, $prev_0 = 0, $74 = 0, $75 = 0, $prev_1 = 0, $76 = 0, $77 = 0, $_off = 0, $78 = 0, $79 = 0, $or_cond = 0, $next_0 = 0, $80 = 0, $81 = 0, $next_1 = 0, $82 = 0, $83 = 0, $_off111 = 0, $84 = 0, $85 = 0, $or_cond112 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $best_y_0_lcssa159 = 0, $99 = 0, $100 = 0, $num_rounds_1 = 0, $num_flats_1 = 0, $102 = 0, $103 = 0, $num_flats_0_lcssa = 0, $num_rounds_0_lcssa = 0, $104 = 0, $105 = 0, $106 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $114 = 0, $115 = 0, $116 = 0, $118 = 0, $119 = 0, $120 = 0, $123 = 0, $124 = 0, $125 = 0, $127 = 0, $128 = 0, $129 = 0, $131 = 0, $133 = 0, $134 = 0, $136 = 0, $137 = 0, $storemerge = 0, $140 = 0, $141 = 0, $143 = 0, $exitcond158 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 96 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $flats = __stackBase__ | 0;
    $rounds = __stackBase__ + 48 | 0;
    $1 = $face + 84 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $rounds | 0;
    $4 = $flats | 0;
    $5 = $metrics + 652 | 0;
    $6 = $2 + 110 | 0;
    $7 = $2 + 112 | 0;
    $8 = $2 + 108 | 0;
    $9 = $2 + 116 | 0;
    $10 = $2 + 120 | 0;
    $bb_0153 = 0;
    label = 2;
    break;
   case 2:
    $11 = 5318656 + ($bb_0153 * 13 & -1) | 0;
    $12 = 5318644 + ($bb_0153 * 13 & -1) | 0;
    $p_0146 = $12;
    $num_rounds_0147 = 0;
    $num_flats_0148 = 0;
    label = 3;
    break;
   case 3:
    $14 = HEAP8[$p_0146] | 0;
    $15 = $14 << 24 >> 24 == 0;
    if ($15) {
      $num_rounds_0_lcssa = $num_rounds_0147;
      $num_flats_0_lcssa = $num_flats_0148;
      label = 33;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $17 = $14 << 24 >> 24;
    $18 = _FT_Get_Char_Index($face, $17) | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      $num_flats_1 = $num_flats_0148;
      $num_rounds_1 = $num_rounds_0147;
      label = 32;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $21 = _FT_Load_Glyph($face, $18, 1) | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 6;
      break;
    } else {
      $num_flats_1 = $num_flats_0148;
      $num_rounds_1 = $num_rounds_0147;
      label = 32;
      break;
    }
   case 6:
    $24 = HEAP16[$6 >> 1] | 0;
    $25 = $24 << 16 >> 16 < 1;
    if ($25) {
      $num_flats_1 = $num_flats_0148;
      $num_rounds_1 = $num_rounds_0147;
      label = 32;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $27 = HEAP32[$7 >> 2] | 0;
    $28 = HEAP16[$8 >> 1] | 0;
    $29 = $28 << 16 >> 16 > 0;
    if ($29) {
      label = 8;
      break;
    } else {
      $best_y_0_lcssa159 = 0;
      label = 31;
      break;
    }
   case 8:
    $30 = HEAP32[$10 >> 2] | 0;
    $31 = HEAP16[$8 >> 1] | 0;
    $32 = $31 << 16 >> 16;
    $best_point_0130 = -1;
    $best_first_0132 = 0;
    $best_last_0133 = 0;
    $best_y_0134 = 0;
    $nn_0135 = 0;
    $first_0136 = 0;
    label = 9;
    break;
   case 9:
    $34 = $30 + ($nn_0135 << 1) | 0;
    $35 = HEAP16[$34 >> 1] | 0;
    $36 = $35 << 16 >> 16;
    $37 = ($36 | 0) > ($first_0136 | 0);
    if ($37) {
      label = 10;
      break;
    } else {
      $best_y_6 = $best_y_0134;
      $best_last_1 = $best_last_0133;
      $best_first_1 = $best_first_0132;
      $best_point_6 = $best_point_0130;
      label = 24;
      break;
    }
   case 10:
    if (($bb_0153 | 0) == 3 | ($bb_0153 | 0) == 2 | ($bb_0153 | 0) == 0) {
      label = 13;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $39 = ($first_0136 | 0) > ($36 | 0);
    if ($39) {
      $best_y_5 = $best_y_0134;
      $best_point_5 = $best_point_0130;
      label = 23;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $40 = $35 << 16 >> 16;
    $41 = $40 + 1 | 0;
    $best_point_3123 = $best_point_0130;
    $best_y_3124 = $best_y_0134;
    $pp_1125 = $first_0136;
    label = 19;
    break;
   case 13:
    $42 = ($first_0136 | 0) > ($36 | 0);
    if ($42) {
      $best_y_5 = $best_y_0134;
      $best_point_5 = $best_point_0130;
      label = 23;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $43 = $35 << 16 >> 16;
    $44 = $43 + 1 | 0;
    $best_point_1116 = $best_point_0130;
    $best_y_1117 = $best_y_0134;
    $pp_0118 = $first_0136;
    label = 15;
    break;
   case 15:
    $46 = ($best_point_1116 | 0) < 0;
    if ($46) {
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $48 = $27 + ($pp_0118 << 3) + 4 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = ($49 | 0) > ($best_y_1117 | 0);
    if ($50) {
      label = 17;
      break;
    } else {
      $best_y_2 = $best_y_1117;
      $best_point_2 = $best_point_1116;
      label = 18;
      break;
    }
   case 17:
    $52 = $27 + ($pp_0118 << 3) + 4 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $best_y_2 = $53;
    $best_point_2 = $pp_0118;
    label = 18;
    break;
   case 18:
    $55 = $pp_0118 + 1 | 0;
    $exitcond = ($55 | 0) == ($44 | 0);
    if ($exitcond) {
      $best_y_5 = $best_y_2;
      $best_point_5 = $best_point_2;
      label = 23;
      break;
    } else {
      $best_point_1116 = $best_point_2;
      $best_y_1117 = $best_y_2;
      $pp_0118 = $55;
      label = 15;
      break;
    }
   case 19:
    $57 = ($best_point_3123 | 0) < 0;
    if ($57) {
      label = 21;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $59 = $27 + ($pp_1125 << 3) + 4 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = ($60 | 0) < ($best_y_3124 | 0);
    if ($61) {
      label = 21;
      break;
    } else {
      $best_y_4 = $best_y_3124;
      $best_point_4 = $best_point_3123;
      label = 22;
      break;
    }
   case 21:
    $63 = $27 + ($pp_1125 << 3) + 4 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $best_y_4 = $64;
    $best_point_4 = $pp_1125;
    label = 22;
    break;
   case 22:
    $66 = $pp_1125 + 1 | 0;
    $exitcond155 = ($66 | 0) == ($41 | 0);
    if ($exitcond155) {
      $best_y_5 = $best_y_4;
      $best_point_5 = $best_point_4;
      label = 23;
      break;
    } else {
      $best_point_3123 = $best_point_4;
      $best_y_3124 = $best_y_4;
      $pp_1125 = $66;
      label = 19;
      break;
    }
   case 23:
    $67 = ($best_point_5 | 0) == ($best_point_0130 | 0);
    $best_first_0_first_0 = $67 ? $best_first_0132 : $first_0136;
    $best_last_0_ = $67 ? $best_last_0133 : $36;
    $best_y_6 = $best_y_5;
    $best_last_1 = $best_last_0_;
    $best_first_1 = $best_first_0_first_0;
    $best_point_6 = $best_point_5;
    label = 24;
    break;
   case 24:
    $69 = $36 + 1 | 0;
    $70 = $nn_0135 + 1 | 0;
    $71 = ($70 | 0) < ($32 | 0);
    if ($71) {
      $best_point_0130 = $best_point_6;
      $best_first_0132 = $best_first_1;
      $best_last_0133 = $best_last_1;
      $best_y_0134 = $best_y_6;
      $nn_0135 = $70;
      $first_0136 = $69;
      label = 9;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $phitmp = 5 - $best_y_6 | 0;
    $73 = ($best_point_6 | 0) > -1;
    if ($73) {
      $prev_0 = $best_point_6;
      label = 26;
      break;
    } else {
      $best_y_0_lcssa159 = $best_y_6;
      label = 31;
      break;
    }
   case 26:
    $74 = ($prev_0 | 0) > ($best_first_1 | 0);
    $75 = $prev_0 - 1 | 0;
    $prev_1 = $74 ? $75 : $best_last_1;
    $76 = $27 + ($prev_1 << 3) + 4 | 0;
    $77 = HEAP32[$76 >> 2] | 0;
    $_off = $phitmp + $77 | 0;
    $78 = $_off >>> 0 > 10;
    $79 = ($prev_1 | 0) == ($best_point_6 | 0);
    $or_cond = $78 | $79;
    if ($or_cond) {
      $next_0 = $best_point_6;
      label = 27;
      break;
    } else {
      $prev_0 = $prev_1;
      label = 26;
      break;
    }
   case 27:
    $80 = ($next_0 | 0) < ($best_last_1 | 0);
    $81 = $next_0 + 1 | 0;
    $next_1 = $80 ? $81 : $best_first_1;
    $82 = $27 + ($next_1 << 3) + 4 | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $_off111 = $phitmp + $83 | 0;
    $84 = $_off111 >>> 0 > 10;
    $85 = ($next_1 | 0) == ($best_point_6 | 0);
    $or_cond112 = $84 | $85;
    if ($or_cond112) {
      label = 28;
      break;
    } else {
      $next_0 = $next_1;
      label = 27;
      break;
    }
   case 28:
    $87 = HEAP32[$9 >> 2] | 0;
    $88 = $87 + $prev_1 | 0;
    $89 = HEAP8[$88] | 0;
    $90 = $89 & 3;
    $91 = $90 << 24 >> 24 == 1;
    if ($91) {
      label = 29;
      break;
    } else {
      label = 30;
      break;
    }
   case 29:
    $93 = $87 + $next_1 | 0;
    $94 = HEAP8[$93] | 0;
    $95 = $94 & 3;
    $96 = $95 << 24 >> 24 == 1;
    if ($96) {
      $best_y_0_lcssa159 = $best_y_6;
      label = 31;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    $97 = $num_rounds_0147 + 1 | 0;
    $98 = $rounds + ($num_rounds_0147 << 2) | 0;
    HEAP32[$98 >> 2] = $best_y_6;
    $num_flats_1 = $num_flats_0148;
    $num_rounds_1 = $97;
    label = 32;
    break;
   case 31:
    $99 = $num_flats_0148 + 1 | 0;
    $100 = $flats + ($num_flats_0148 << 2) | 0;
    HEAP32[$100 >> 2] = $best_y_0_lcssa159;
    $num_flats_1 = $99;
    $num_rounds_1 = $num_rounds_0147;
    label = 32;
    break;
   case 32:
    $102 = $p_0146 + 1 | 0;
    $103 = $102 >>> 0 < $11 >>> 0;
    if ($103) {
      $p_0146 = $102;
      $num_rounds_0147 = $num_rounds_1;
      $num_flats_0148 = $num_flats_1;
      label = 3;
      break;
    } else {
      $num_rounds_0_lcssa = $num_rounds_1;
      $num_flats_0_lcssa = $num_flats_1;
      label = 33;
      break;
    }
   case 33:
    $104 = ($num_rounds_0_lcssa | 0) == 0;
    $105 = $num_flats_0_lcssa | $num_rounds_0_lcssa;
    $106 = ($105 | 0) == 0;
    if ($106) {
      label = 48;
      break;
    } else {
      label = 34;
      break;
    }
   case 34:
    $108 = ($num_flats_0_lcssa | 0) == 0;
    _af_sort_pos($num_rounds_0_lcssa, $3);
    _af_sort_pos($num_flats_0_lcssa, $4);
    $109 = HEAP32[$5 >> 2] | 0;
    $110 = $metrics + 656 + ($109 * 28 & -1) | 0;
    $111 = $metrics + 656 + ($109 * 28 & -1) + 12 | 0;
    $112 = $109 + 1 | 0;
    HEAP32[$5 >> 2] = $112;
    if ($108) {
      label = 35;
      break;
    } else {
      label = 36;
      break;
    }
   case 35:
    $114 = ($num_rounds_0_lcssa | 0) / 2 & -1;
    $115 = $rounds + ($114 << 2) | 0;
    $116 = HEAP32[$115 >> 2] | 0;
    HEAP32[$111 >> 2] = $116;
    HEAP32[$110 >> 2] = $116;
    label = 39;
    break;
   case 36:
    $118 = ($num_flats_0_lcssa | 0) / 2 & -1;
    $119 = $flats + ($118 << 2) | 0;
    $120 = HEAP32[$119 >> 2] | 0;
    if ($104) {
      label = 37;
      break;
    } else {
      label = 38;
      break;
    }
   case 37:
    HEAP32[$111 >> 2] = $120;
    HEAP32[$110 >> 2] = $120;
    label = 39;
    break;
   case 38:
    HEAP32[$110 >> 2] = $120;
    $123 = ($num_rounds_0_lcssa | 0) / 2 & -1;
    $124 = $rounds + ($123 << 2) | 0;
    $125 = HEAP32[$124 >> 2] | 0;
    HEAP32[$111 >> 2] = $125;
    label = 39;
    break;
   case 39:
    $127 = HEAP32[$111 >> 2] | 0;
    $128 = HEAP32[$110 >> 2] | 0;
    $129 = ($127 | 0) == ($128 | 0);
    if ($129) {
      label = 44;
      break;
    } else {
      label = 40;
      break;
    }
   case 40:
    $131 = ($127 | 0) > ($128 | 0);
    if (($bb_0153 | 0) == 2 | ($bb_0153 | 0) == 0 | ($bb_0153 | 0) == 3) {
      label = 41;
      break;
    } else {
      label = 42;
      break;
    }
   case 41:
    if ($131) {
      label = 44;
      break;
    } else {
      label = 43;
      break;
    }
   case 42:
    if ($131) {
      label = 43;
      break;
    } else {
      label = 44;
      break;
    }
   case 43:
    $133 = $128 + $127 | 0;
    $134 = ($133 | 0) / 2 & -1;
    HEAP32[$110 >> 2] = $134;
    HEAP32[$111 >> 2] = $134;
    label = 44;
    break;
   case 44:
    $136 = $metrics + 656 + ($109 * 28 & -1) + 24 | 0;
    $137 = ($bb_0153 | 0) == 3;
    if (($bb_0153 | 0) == 3 | ($bb_0153 | 0) == 2 | ($bb_0153 | 0) == 0) {
      label = 45;
      break;
    } else {
      $storemerge = 0;
      label = 46;
      break;
    }
   case 45:
    $storemerge = 2;
    label = 46;
    break;
   case 46:
    HEAP32[$136 >> 2] = $storemerge;
    if ($137) {
      label = 47;
      break;
    } else {
      label = 48;
      break;
    }
   case 47:
    $140 = $storemerge | 4;
    HEAP32[$136 >> 2] = $140;
    $141 = $bb_0153 + 1 | 0;
    $bb_0153 = $141;
    label = 2;
    break;
   case 48:
    $143 = $bb_0153 + 1 | 0;
    $exitcond158 = ($143 | 0) == 6;
    if ($exitcond158) {
      label = 49;
      break;
    } else {
      $bb_0153 = $143;
      label = 2;
      break;
    }
   case 49:
    STACKTOP = __stackBase__;
    return;
  }
}
function _bdf_cmap_done($bdfcmap) {
  $bdfcmap = $bdfcmap | 0;
  HEAP32[$bdfcmap + 20 >> 2] = 0;
  HEAP32[$bdfcmap + 16 >> 2] = 0;
  return;
}
function _bdf_cmap_char_index($bdfcmap, $charcode) {
  $bdfcmap = $bdfcmap | 0;
  $charcode = $charcode | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $min_011 = 0, $max_010 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $phitmp = 0, $19 = 0, $20 = 0, $_max_0 = 0, $min_0_ = 0, $21 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $bdfcmap + 20 | 0;
    $2 = $1;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $bdfcmap + 16 | 0;
    $5 = $4;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      $result_0 = 0;
      label = 5;
      break;
    } else {
      $max_010 = $6;
      $min_011 = 0;
      label = 2;
      break;
    }
   case 2:
    $8 = $min_011 + $max_010 | 0;
    $9 = $8 >>> 1;
    $10 = $3 + ($9 << 3) | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($11 | 0) == ($charcode | 0);
    if ($12) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $14 = $3 + ($9 << 3) + 4 | 0;
    $15 = HEAP16[$14 >> 1] | 0;
    $16 = $15 & 65535;
    $17 = $16 + 1 | 0;
    $phitmp = $17 & 65535;
    $result_0 = $phitmp;
    label = 5;
    break;
   case 4:
    $19 = $11 >>> 0 > $charcode >>> 0;
    $20 = $9 + 1 | 0;
    $_max_0 = $19 ? $9 : $max_010;
    $min_0_ = $19 ? $min_011 : $20;
    $21 = $min_0_ >>> 0 < $_max_0 >>> 0;
    if ($21) {
      $max_010 = $_max_0;
      $min_011 = $min_0_;
      label = 2;
      break;
    } else {
      $result_0 = 0;
      label = 5;
      break;
    }
   case 5:
    return $result_0 | 0;
  }
  return 0;
}
function _bdf_cmap_char_next($bdfcmap, $acharcode) {
  $bdfcmap = $bdfcmap | 0;
  $acharcode = $acharcode | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $min_022 = 0, $max_021 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $_max_0 = 0, $min_0_ = 0, $23 = 0, $min_0_lcssa = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $result_0 = 0, $charcode_0 = 0, $34 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $bdfcmap + 20 | 0;
    $2 = $1;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = HEAP32[$acharcode >> 2] | 0;
    $5 = $4 + 1 | 0;
    $6 = $bdfcmap + 16 | 0;
    $7 = $6;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      $min_0_lcssa = 0;
      label = 5;
      break;
    } else {
      $max_021 = $8;
      $min_022 = 0;
      label = 2;
      break;
    }
   case 2:
    $10 = $min_022 + $max_021 | 0;
    $11 = $10 >>> 1;
    $12 = $3 + ($11 << 3) | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = ($5 | 0) == ($13 | 0);
    if ($14) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $16 = $3 + ($11 << 3) + 4 | 0;
    $17 = HEAP16[$16 >> 1] | 0;
    $18 = $17 & 65535;
    $19 = $18 + 1 | 0;
    $charcode_0 = $5;
    $result_0 = $19;
    label = 7;
    break;
   case 4:
    $21 = $5 >>> 0 < $13 >>> 0;
    $22 = $11 + 1 | 0;
    $_max_0 = $21 ? $11 : $max_021;
    $min_0_ = $21 ? $min_022 : $22;
    $23 = $min_0_ >>> 0 < $_max_0 >>> 0;
    if ($23) {
      $max_021 = $_max_0;
      $min_022 = $min_0_;
      label = 2;
      break;
    } else {
      $min_0_lcssa = $min_0_;
      label = 5;
      break;
    }
   case 5:
    $24 = HEAP32[$7 >> 2] | 0;
    $25 = $min_0_lcssa >>> 0 < $24 >>> 0;
    if ($25) {
      label = 6;
      break;
    } else {
      $charcode_0 = 0;
      $result_0 = 0;
      label = 7;
      break;
    }
   case 6:
    $27 = $3 + ($min_0_lcssa << 3) | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $3 + ($min_0_lcssa << 3) + 4 | 0;
    $30 = HEAP16[$29 >> 1] | 0;
    $31 = $30 & 65535;
    $32 = $31 + 1 | 0;
    $charcode_0 = $28;
    $result_0 = $32;
    label = 7;
    break;
   case 7:
    HEAP32[$acharcode >> 2] = $charcode_0;
    $34 = $result_0 & 65535;
    return $34 | 0;
  }
  return 0;
}
function _bdf_driver_requester($module, $name) {
  $module = $module | 0;
  $name = $name | 0;
  return _ft_service_list_lookup(5317836, $name) | 0;
}
function _BDF_Face_Init($stream, $bdfface, $face_index, $num_params, $params) {
  $stream = $stream | 0;
  $bdfface = $bdfface | 0;
  $face_index = $face_index | 0;
  $num_params = $num_params | 0;
  $params = $params | 0;
  var $error = 0, $font = 0, $options = 0, $charmap = 0, $charmap1 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $_c = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $sext109 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $92 = 0, $93 = 0, $94 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $113 = 0, $114 = 0, $115 = 0, $117 = 0, $118 = 0, $119 = 0, $sext105 = 0, $120 = 0, $121 = 0, $122 = 0, $124 = 0, $125 = 0, $126 = 0, $128 = 0, $129 = 0, $130 = 0, $sext = 0, $phitmp = 0, $resolution_x_0 = 0, $132 = 0, $133 = 0, $134 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $resolution_y_0 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $151 = 0, $152 = 0, $153 = 0, $155 = 0, $156 = 0, $or_cond = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $_c102 = 0, $176 = 0, $177 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $n_0110 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $n_0_c = 0, $200 = 0, $201 = 0, $202 = 0, $_lcssa = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $or_cond107 = 0, $208 = 0, $209 = 0, $210 = 0, $212 = 0, $213 = 0, $214 = 0, $216 = 0, $217 = 0, $218 = 0, $220 = 0, $221 = 0, $222 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $_c103 = 0, $228 = 0, $229 = 0, $231 = 0, $232 = 0, $233 = 0, $_c104 = 0, $234 = 0, $235 = 0, $237 = 0, $239 = 0, $240 = 0, $242 = 0, $243 = 0, $245 = 0, $246 = 0, $247 = 0, $249 = 0, $250 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $$etemp$0$0 = 0, $$etemp$0$1 = 0, $st$1$0 = 0, $st$2$1 = 0, $259 = 0, $260 = 0, $261 = 0, $$etemp$3$0 = 0, $$etemp$3$1 = 0, $st$4$0 = 0, $st$5$1 = 0, $262 = 0, $263 = 0, $265 = 0, $267 = 0, $268 = 0, $269 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $281 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 48 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $font = __stackBase__ + 4 | 0;
    $options = __stackBase__ + 8 | 0;
    $charmap = __stackBase__ + 24 | 0;
    $charmap1 = __stackBase__ + 36 | 0;
    $1 = $bdfface;
    $2 = $bdfface + 100 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    HEAP32[$font >> 2] = 0;
    $4 = _FT_Stream_Seek($stream, 0) | 0;
    HEAP32[$error >> 2] = $4;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      label = 56;
      break;
    }
   case 2:
    $7 = $options | 0;
    HEAP32[$7 >> 2] = 1;
    $8 = $options + 4 | 0;
    HEAP32[$8 >> 2] = 1;
    $9 = $options + 8 | 0;
    HEAP32[$9 >> 2] = 0;
    $10 = $options + 12 | 0;
    HEAP32[$10 >> 2] = 8;
    $11 = _bdf_load_font($stream, $3, $options, $font) | 0;
    HEAP32[$error >> 2] = $11;
    if (($11 | 0) == 0) {
      label = 3;
      break;
    } else if (($11 | 0) == 176) {
      label = 57;
      break;
    } else {
      label = 56;
      break;
    }
   case 3:
    $13 = HEAP32[$font >> 2] | 0;
    $14 = $bdfface + 140 | 0;
    $_c = $13;
    HEAP32[$14 >> 2] = $_c;
    $15 = $bdfface | 0;
    HEAP32[$15 >> 2] = 1;
    $16 = $bdfface + 4 | 0;
    HEAP32[$16 >> 2] = 0;
    $17 = $bdfface + 8 | 0;
    HEAP32[$17 >> 2] = 146;
    $18 = HEAP32[$font >> 2] | 0;
    $19 = _bdf_get_font_property($18, 5324248) | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 8;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $22 = $19 + 4 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = ($23 | 0) == 1;
    if ($24) {
      label = 5;
      break;
    } else {
      label = 8;
      break;
    }
   case 5:
    $26 = $19 + 12 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = ($27 | 0) == 0;
    if ($28) {
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $30 = HEAP8[$27] | 0;
    if (($30 << 24 >> 24 | 0) == 77 | ($30 << 24 >> 24 | 0) == 109 | ($30 << 24 >> 24 | 0) == 67 | ($30 << 24 >> 24 | 0) == 99) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $32 = HEAP32[$17 >> 2] | 0;
    $33 = $32 | 4;
    HEAP32[$17 >> 2] = $33;
    label = 8;
    break;
   case 8:
    $35 = HEAP32[$font >> 2] | 0;
    $36 = _bdf_get_font_property($35, 5323268) | 0;
    $37 = ($36 | 0) == 0;
    if ($37) {
      label = 11;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $39 = $36 + 12 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = ($40 | 0) == 0;
    if ($41) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $43 = _ft_mem_strdup($3, $40, $error) | 0;
    $44 = $bdfface + 20 | 0;
    HEAP32[$44 >> 2] = $43;
    $45 = HEAP32[$error >> 2] | 0;
    $46 = ($45 | 0) == 0;
    if ($46) {
      label = 12;
      break;
    } else {
      label = 56;
      break;
    }
   case 11:
    $48 = $bdfface + 20 | 0;
    HEAP32[$48 >> 2] = 0;
    label = 12;
    break;
   case 12:
    $50 = _bdf_interpret_style($1) | 0;
    HEAP32[$error >> 2] = $50;
    $51 = ($50 | 0) == 0;
    if ($51) {
      label = 13;
      break;
    } else {
      label = 56;
      break;
    }
   case 13:
    $53 = HEAP32[$font >> 2] | 0;
    $54 = $53 + 48 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = $55 + 1 | 0;
    $57 = $bdfface + 16 | 0;
    HEAP32[$57 >> 2] = $56;
    $58 = $bdfface + 28 | 0;
    HEAP32[$58 >> 2] = 1;
    $59 = _ft_mem_realloc($3, 16, 0, 1, 0, $error) | 0;
    $60 = $59;
    $61 = $bdfface + 32 | 0;
    HEAP32[$61 >> 2] = $60;
    $62 = HEAP32[$error >> 2] | 0;
    $63 = ($62 | 0) == 0;
    if ($63) {
      label = 14;
      break;
    } else {
      label = 56;
      break;
    }
   case 14:
    _memset($59 | 0, 0, 16);
    $65 = HEAP32[$font >> 2] | 0;
    $66 = $65 + 40 | 0;
    $67 = HEAP32[$66 >> 2] | 0;
    $68 = $65 + 44 | 0;
    $69 = HEAP32[$68 >> 2] | 0;
    $70 = $69 + $67 | 0;
    $71 = $70 & 65535;
    $72 = $59;
    HEAP16[$72 >> 1] = $71;
    $73 = HEAP32[$font >> 2] | 0;
    $74 = _bdf_get_font_property($73, 5322436) | 0;
    $75 = ($74 | 0) == 0;
    if ($75) {
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $77 = $74 + 12 | 0;
    $78 = $77;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = $79 + 5 | 0;
    $81 = ($80 | 0) / 10 & -1;
    $82 = $81 & 65535;
    $83 = $59 + 2 | 0;
    $84 = $83;
    HEAP16[$84 >> 1] = $82;
    label = 17;
    break;
   case 16:
    $sext109 = $70 << 16;
    $86 = $sext109 >> 15;
    $87 = ($86 | 0) / 3 & -1;
    $88 = $87 & 65535;
    $89 = $59 + 2 | 0;
    $90 = $89;
    HEAP16[$90 >> 1] = $88;
    label = 17;
    break;
   case 17:
    $92 = HEAP32[$font >> 2] | 0;
    $93 = _bdf_get_font_property($92, 5321816) | 0;
    $94 = ($93 | 0) == 0;
    if ($94) {
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $96 = $93 + 12 | 0;
    $97 = $96;
    $98 = HEAP32[$97 >> 2] | 0;
    $99 = $98 * 460800 & -1;
    $100 = $99 + 36135 | 0;
    $101 = ($100 | 0) / 72270 & -1;
    $102 = $59 + 4 | 0;
    $103 = $102;
    HEAP32[$103 >> 2] = $101;
    label = 20;
    break;
   case 19:
    $105 = $59 + 2 | 0;
    $106 = $105;
    $107 = HEAP16[$106 >> 1] | 0;
    $108 = $107 << 16 >> 16;
    $109 = $108 << 6;
    $110 = $59 + 4 | 0;
    $111 = $110;
    HEAP32[$111 >> 2] = $109;
    label = 20;
    break;
   case 20:
    $113 = HEAP32[$font >> 2] | 0;
    $114 = _bdf_get_font_property($113, 5321148) | 0;
    $115 = ($114 | 0) == 0;
    if ($115) {
      label = 22;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $117 = $114 + 12 | 0;
    $118 = $117;
    $119 = HEAP32[$118 >> 2] | 0;
    $sext105 = $119 << 16;
    $120 = $sext105 >> 10;
    $121 = $59 + 12 | 0;
    $122 = $121;
    HEAP32[$122 >> 2] = $120;
    label = 22;
    break;
   case 22:
    $124 = HEAP32[$font >> 2] | 0;
    $125 = _bdf_get_font_property($124, 5320464) | 0;
    $126 = ($125 | 0) == 0;
    if ($126) {
      $resolution_x_0 = 0;
      label = 24;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $128 = $125 + 12 | 0;
    $129 = $128;
    $130 = HEAP32[$129 >> 2] | 0;
    $sext = $130 << 16;
    $phitmp = $sext >> 16;
    $resolution_x_0 = $phitmp;
    label = 24;
    break;
   case 24:
    $132 = HEAP32[$font >> 2] | 0;
    $133 = _bdf_get_font_property($132, 532e4) | 0;
    $134 = ($133 | 0) == 0;
    if ($134) {
      $resolution_y_0 = 0;
      label = 26;
      break;
    } else {
      label = 25;
      break;
    }
   case 25:
    $136 = $133 + 12 | 0;
    $137 = $136;
    $138 = HEAP32[$137 >> 2] | 0;
    $139 = $138 & 65535;
    $resolution_y_0 = $139;
    label = 26;
    break;
   case 26:
    $141 = $59 + 12 | 0;
    $142 = $141;
    $143 = HEAP32[$142 >> 2] | 0;
    $144 = ($143 | 0) == 0;
    if ($144) {
      label = 27;
      break;
    } else {
      label = 29;
      break;
    }
   case 27:
    $146 = $59 + 4 | 0;
    $147 = $146;
    $148 = HEAP32[$147 >> 2] | 0;
    HEAP32[$142 >> 2] = $148;
    $149 = $resolution_y_0 << 16 >> 16 == 0;
    if ($149) {
      label = 31;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $151 = $resolution_y_0 << 16 >> 16;
    $152 = Math_imul($148, $151);
    $153 = ($152 | 0) / 72 & -1;
    HEAP32[$142 >> 2] = $153;
    label = 29;
    break;
   case 29:
    $155 = ($resolution_x_0 | 0) == 0;
    $156 = $resolution_y_0 << 16 >> 16 == 0;
    $or_cond = $155 | $156;
    if ($or_cond) {
      label = 31;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    $158 = $resolution_y_0 << 16 >> 16;
    $159 = HEAP32[$142 >> 2] | 0;
    $160 = Math_imul($159, $resolution_x_0);
    $161 = ($160 | 0) / ($158 | 0) & -1;
    $162 = $59 + 8 | 0;
    $163 = $162;
    HEAP32[$163 >> 2] = $161;
    label = 32;
    break;
   case 31:
    $164 = HEAP32[$142 >> 2] | 0;
    $165 = $59 + 8 | 0;
    $166 = $165;
    HEAP32[$166 >> 2] = $164;
    label = 32;
    break;
   case 32:
    $168 = HEAP32[$font >> 2] | 0;
    $169 = $168 + 56 | 0;
    $170 = HEAP32[$169 >> 2] | 0;
    $171 = $168 + 48 | 0;
    $172 = HEAP32[$171 >> 2] | 0;
    $173 = _ft_mem_realloc($3, 8, 0, $172, 0, $error) | 0;
    $174 = $bdfface + 144 | 0;
    $175 = $174;
    $_c102 = $173;
    HEAP32[$174 >> 2] = $_c102;
    $176 = HEAP32[$error >> 2] | 0;
    $177 = ($176 | 0) == 0;
    if ($177) {
      label = 33;
      break;
    } else {
      label = 56;
      break;
    }
   case 33:
    $179 = $bdfface + 164 | 0;
    HEAP32[$179 >> 2] = 0;
    $180 = HEAP32[$font >> 2] | 0;
    $181 = $180 + 48 | 0;
    $182 = HEAP32[$181 >> 2] | 0;
    $183 = ($182 | 0) == 0;
    if ($183) {
      $_lcssa = $180;
      label = 38;
      break;
    } else {
      label = 34;
      break;
    }
   case 34:
    $184 = HEAP32[$font >> 2] | 0;
    $185 = $184 + 36 | 0;
    $186 = $184 + 48 | 0;
    $n_0110 = 0;
    label = 35;
    break;
   case 35:
    $188 = $170 + ($n_0110 * 36 & -1) + 4 | 0;
    $189 = HEAP32[$188 >> 2] | 0;
    $190 = HEAP32[$175 >> 2] | 0;
    $191 = $190 + ($n_0110 << 3) | 0;
    HEAP32[$191 >> 2] = $189;
    $192 = $n_0110 & 65535;
    $193 = HEAP32[$175 >> 2] | 0;
    $194 = $193 + ($n_0110 << 3) + 4 | 0;
    HEAP16[$194 >> 1] = $192;
    $195 = HEAP32[$188 >> 2] | 0;
    $196 = HEAP32[$185 >> 2] | 0;
    $197 = ($195 | 0) == ($196 | 0);
    if ($197) {
      label = 36;
      break;
    } else {
      label = 37;
      break;
    }
   case 36:
    $n_0_c = $n_0110;
    HEAP32[$179 >> 2] = $n_0_c;
    label = 37;
    break;
   case 37:
    $200 = $n_0110 + 1 | 0;
    $201 = HEAP32[$186 >> 2] | 0;
    $202 = $200 >>> 0 < $201 >>> 0;
    if ($202) {
      $n_0110 = $200;
      label = 35;
      break;
    } else {
      $_lcssa = $184;
      label = 38;
      break;
    }
   case 38:
    $203 = _bdf_get_font_property($_lcssa, 5319628) | 0;
    $204 = _bdf_get_font_property($_lcssa, 5319316) | 0;
    $205 = ($203 | 0) == 0;
    $206 = ($204 | 0) == 0;
    $or_cond107 = $205 | $206;
    if ($or_cond107) {
      label = 54;
      break;
    } else {
      label = 39;
      break;
    }
   case 39:
    $208 = $203 + 4 | 0;
    $209 = HEAP32[$208 >> 2] | 0;
    $210 = ($209 | 0) == 1;
    if ($210) {
      label = 40;
      break;
    } else {
      label = 54;
      break;
    }
   case 40:
    $212 = $204 + 4 | 0;
    $213 = HEAP32[$212 >> 2] | 0;
    $214 = ($213 | 0) == 1;
    if ($214) {
      label = 41;
      break;
    } else {
      label = 54;
      break;
    }
   case 41:
    $216 = $203 + 12 | 0;
    $217 = HEAP32[$216 >> 2] | 0;
    $218 = ($217 | 0) == 0;
    if ($218) {
      label = 54;
      break;
    } else {
      label = 42;
      break;
    }
   case 42:
    $220 = $204 + 12 | 0;
    $221 = HEAP32[$220 >> 2] | 0;
    $222 = ($221 | 0) == 0;
    if ($222) {
      label = 54;
      break;
    } else {
      label = 43;
      break;
    }
   case 43:
    $224 = _ft_mem_strdup($3, $221, $error) | 0;
    $225 = $bdfface + 132 | 0;
    $226 = $225;
    $227 = $225 | 0;
    $_c103 = $224;
    HEAP32[$227 >> 2] = $_c103;
    $228 = HEAP32[$error >> 2] | 0;
    $229 = ($228 | 0) == 0;
    if ($229) {
      label = 44;
      break;
    } else {
      label = 56;
      break;
    }
   case 44:
    $231 = HEAP32[$216 >> 2] | 0;
    $232 = _ft_mem_strdup($3, $231, $error) | 0;
    $233 = $bdfface + 136 | 0;
    $_c104 = $232;
    HEAP32[$233 >> 2] = $_c104;
    $234 = HEAP32[$error >> 2] | 0;
    $235 = ($234 | 0) == 0;
    if ($235) {
      label = 45;
      break;
    } else {
      label = 56;
      break;
    }
   case 45:
    $237 = HEAP8[$232] | 0;
    if (($237 << 24 >> 24 | 0) == 105 | ($237 << 24 >> 24 | 0) == 73) {
      label = 46;
      break;
    } else {
      label = 51;
      break;
    }
   case 46:
    $239 = $232 + 1 | 0;
    $240 = HEAP8[$239] | 0;
    if (($240 << 24 >> 24 | 0) == 115 | ($240 << 24 >> 24 | 0) == 83) {
      label = 47;
      break;
    } else {
      label = 51;
      break;
    }
   case 47:
    $242 = $232 + 2 | 0;
    $243 = HEAP8[$242] | 0;
    if (($243 << 24 >> 24 | 0) == 111 | ($243 << 24 >> 24 | 0) == 79) {
      label = 48;
      break;
    } else {
      label = 51;
      break;
    }
   case 48:
    $245 = $232 + 3 | 0;
    $246 = _strcmp($245 | 0, 5324748) | 0;
    $247 = ($246 | 0) == 0;
    if ($247) {
      label = 52;
      break;
    } else {
      label = 49;
      break;
    }
   case 49:
    $249 = _strcmp($245 | 0, 5324492) | 0;
    $250 = ($249 | 0) == 0;
    if ($250) {
      label = 50;
      break;
    } else {
      label = 51;
      break;
    }
   case 50:
    $252 = HEAP32[$226 >> 2] | 0;
    $253 = _strcmp($252 | 0, 5324368) | 0;
    $254 = ($253 | 0) == 0;
    if ($254) {
      label = 52;
      break;
    } else {
      label = 51;
      break;
    }
   case 51:
    $255 = $charmap | 0;
    HEAP32[$255 >> 2] = $bdfface;
    $256 = $charmap + 4 | 0;
    $257 = $256;
    $$etemp$0$0 = 0;
    $$etemp$0$1 = 0;
    $st$1$0 = $257 | 0;
    HEAP32[$st$1$0 >> 2] = $$etemp$0$0;
    $st$2$1 = $257 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $$etemp$0$1;
    label = 53;
    break;
   case 52:
    $259 = $charmap | 0;
    HEAP32[$259 >> 2] = $bdfface;
    $260 = $charmap + 4 | 0;
    $261 = $260;
    $$etemp$3$0 = 0;
    $$etemp$3$1 = 0;
    $st$4$0 = $261 | 0;
    HEAP32[$st$4$0 >> 2] = $$etemp$3$0;
    $st$5$1 = $261 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $$etemp$3$1;
    $262 = $charmap + 10 | 0;
    $263 = $charmap + 8 | 0;
    HEAP32[$260 >> 2] = 1970170211;
    HEAP16[$263 >> 1] = 3;
    HEAP16[$262 >> 1] = 1;
    label = 53;
    break;
   case 53:
    $265 = _FT_CMap_New(5317972, 0, $charmap, 0) | 0;
    HEAP32[$error >> 2] = $265;
    label = 56;
    break;
   case 54:
    $267 = $charmap1 | 0;
    HEAP32[$267 >> 2] = $bdfface;
    $268 = $charmap1 + 4 | 0;
    HEAP32[$268 >> 2] = 1094995778;
    $269 = $charmap1 + 8 | 0;
    HEAP16[$269 >> 1] = 7;
    $270 = $charmap1 + 10 | 0;
    HEAP16[$270 >> 1] = 0;
    $271 = _FT_CMap_New(5317972, 0, $charmap1, 0) | 0;
    HEAP32[$error >> 2] = $271;
    $272 = $bdfface + 36 | 0;
    $273 = HEAP32[$272 >> 2] | 0;
    $274 = ($273 | 0) == 0;
    if ($274) {
      label = 56;
      break;
    } else {
      label = 55;
      break;
    }
   case 55:
    $276 = $bdfface + 40 | 0;
    $277 = HEAP32[$276 >> 2] | 0;
    $278 = HEAP32[$277 >> 2] | 0;
    $279 = $bdfface + 92 | 0;
    HEAP32[$279 >> 2] = $278;
    label = 56;
    break;
   case 56:
    $281 = HEAP32[$error >> 2] | 0;
    $_0 = $281;
    label = 58;
    break;
   case 57:
    _BDF_Face_Done($bdfface);
    $_0 = 2;
    label = 58;
    break;
   case 58:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _BDF_Face_Done($bdfface) {
  $bdfface = $bdfface | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($bdfface | 0) == 0;
    if ($1) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $bdfface + 100 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $bdfface + 140 | 0;
    $6 = $5;
    $7 = HEAP32[$6 >> 2] | 0;
    _bdf_free_font($7);
    $8 = $bdfface + 144 | 0;
    $9 = $8;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10;
    _ft_mem_free($4, $11);
    HEAP32[$8 >> 2] = 0;
    $12 = $bdfface + 132 | 0;
    $13 = $12;
    $14 = HEAP32[$13 >> 2] | 0;
    _ft_mem_free($4, $14);
    $15 = $12 | 0;
    HEAP32[$15 >> 2] = 0;
    $16 = $bdfface + 136 | 0;
    $17 = $16;
    $18 = HEAP32[$17 >> 2] | 0;
    _ft_mem_free($4, $18);
    HEAP32[$16 >> 2] = 0;
    $19 = $bdfface + 20 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    _ft_mem_free($4, $20);
    HEAP32[$19 >> 2] = 0;
    $21 = $bdfface + 24 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    _ft_mem_free($4, $22);
    HEAP32[$21 >> 2] = 0;
    $23 = $bdfface + 32 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24;
    _ft_mem_free($4, $25);
    HEAP32[$23 >> 2] = 0;
    $26 = HEAP32[$6 >> 2] | 0;
    $27 = $26;
    _ft_mem_free($4, $27);
    HEAP32[$5 >> 2] = 0;
    label = 3;
    break;
   case 3:
    return;
  }
}
function _BDF_Glyph_Load($slot, $size, $glyph_index, $load_flags) {
  $slot = $slot | 0;
  $size = $size | 0;
  $glyph_index = $glyph_index | 0;
  $load_flags = $load_flags | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $_0 = 0, $23 = 0, $24 = 0, $25 = 0, $glyph_sroa_1_10__idx1 = 0, $glyph_sroa_1_10_copyload = 0, $glyph_sroa_2_12__idx2 = 0, $glyph_sroa_2_12_copyload = 0, $glyph_sroa_3_14__idx3 = 0, $glyph_sroa_3_14_copyload = 0, $glyph_sroa_4_16__idx4 = 0, $glyph_sroa_4_16_copyload = 0, $glyph_sroa_6_20__idx7 = 0, $glyph_sroa_6_20_copyload = 0, $glyph_sroa_8_24__idx10 = 0, $glyph_sroa_8_24_copyload = 0, $glyph_sroa_9_28__idx12 = 0, $glyph_sroa_9_28_copyload = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $34 = 0, $36 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 140 | 0;
    $4 = $3;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 + 16518 | 0;
    $7 = HEAP16[$6 >> 1] | 0;
    $8 = $7 & 65535;
    $9 = ($2 | 0) == 0;
    if ($9) {
      $error_0 = 6;
      label = 12;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $11 = $2 + 16 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 >>> 0 > $glyph_index >>> 0;
    if ($13) {
      label = 3;
      break;
    } else {
      $error_0 = 6;
      label = 12;
      break;
    }
   case 3:
    $15 = ($glyph_index | 0) == 0;
    if ($15) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $17 = $2 + 164 | 0;
    $18 = $17;
    $19 = HEAP32[$18 >> 2] | 0;
    $_0 = $19;
    label = 6;
    break;
   case 5:
    $21 = $glyph_index - 1 | 0;
    $_0 = $21;
    label = 6;
    break;
   case 6:
    $23 = HEAP32[$4 >> 2] | 0;
    $24 = $23 + 56 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $glyph_sroa_1_10__idx1 = $25 + ($_0 * 36 & -1) + 10 | 0;
    $glyph_sroa_1_10_copyload = HEAP16[$glyph_sroa_1_10__idx1 >> 1] | 0;
    $glyph_sroa_2_12__idx2 = $25 + ($_0 * 36 & -1) + 12 | 0;
    $glyph_sroa_2_12_copyload = HEAP16[$glyph_sroa_2_12__idx2 >> 1] | 0;
    $glyph_sroa_3_14__idx3 = $25 + ($_0 * 36 & -1) + 14 | 0;
    $glyph_sroa_3_14_copyload = HEAP16[$glyph_sroa_3_14__idx3 >> 1] | 0;
    $glyph_sroa_4_16__idx4 = $25 + ($_0 * 36 & -1) + 16 | 0;
    $glyph_sroa_4_16_copyload = HEAP16[$glyph_sroa_4_16__idx4 >> 1] | 0;
    $glyph_sroa_6_20__idx7 = $25 + ($_0 * 36 & -1) + 20 | 0;
    $glyph_sroa_6_20_copyload = HEAP16[$glyph_sroa_6_20__idx7 >> 1] | 0;
    $glyph_sroa_8_24__idx10 = $25 + ($_0 * 36 & -1) + 24 | 0;
    $glyph_sroa_8_24_copyload = HEAP32[$glyph_sroa_8_24__idx10 >> 2] | 0;
    $glyph_sroa_9_28__idx12 = $25 + ($_0 * 36 & -1) + 28 | 0;
    $glyph_sroa_9_28_copyload = HEAP32[$glyph_sroa_9_28__idx12 >> 2] | 0;
    $26 = $glyph_sroa_3_14_copyload & 65535;
    $27 = $slot + 76 | 0;
    HEAP32[$27 >> 2] = $26;
    $28 = $glyph_sroa_2_12_copyload & 65535;
    $29 = $slot + 80 | 0;
    HEAP32[$29 >> 2] = $28;
    $30 = $slot + 84 | 0;
    HEAP32[$30 >> 2] = $glyph_sroa_9_28_copyload;
    _ft_glyphslot_set_bitmap($slot, $glyph_sroa_8_24_copyload);
    if (($8 | 0) == 1) {
      label = 7;
      break;
    } else if (($8 | 0) == 2) {
      label = 8;
      break;
    } else if (($8 | 0) == 4) {
      label = 9;
      break;
    } else if (($8 | 0) == 8) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 7:
    $32 = $slot + 94 | 0;
    HEAP8[$32] = 1;
    label = 11;
    break;
   case 8:
    $34 = $slot + 94 | 0;
    HEAP8[$34] = 3;
    label = 11;
    break;
   case 9:
    $36 = $slot + 94 | 0;
    HEAP8[$36] = 4;
    label = 11;
    break;
   case 10:
    $38 = $slot + 94 | 0;
    HEAP8[$38] = 2;
    $39 = $slot + 92 | 0;
    HEAP16[$39 >> 1] = 256;
    label = 11;
    break;
   case 11:
    $41 = $slot + 72 | 0;
    HEAP32[$41 >> 2] = 1651078259;
    $42 = $glyph_sroa_4_16_copyload << 16 >> 16;
    $43 = $slot + 100 | 0;
    HEAP32[$43 >> 2] = $42;
    $44 = $glyph_sroa_6_20_copyload << 16 >> 16;
    $45 = $slot + 104 | 0;
    HEAP32[$45 >> 2] = $44;
    $46 = $glyph_sroa_1_10_copyload & 65535;
    $47 = $46 << 6;
    $48 = $slot + 24 | 0;
    $49 = $slot + 40 | 0;
    HEAP32[$49 >> 2] = $47;
    $50 = $42 << 6;
    $51 = $slot + 32 | 0;
    HEAP32[$51 >> 2] = $50;
    $52 = $44 << 6;
    $53 = $slot + 36 | 0;
    HEAP32[$53 >> 2] = $52;
    $54 = HEAP32[$29 >> 2] | 0;
    $55 = $54 << 6;
    $56 = $48 | 0;
    HEAP32[$56 >> 2] = $55;
    $57 = HEAP32[$27 >> 2] | 0;
    $58 = $57 << 6;
    $59 = $slot + 28 | 0;
    HEAP32[$59 >> 2] = $58;
    $60 = HEAP32[$4 >> 2] | 0;
    $61 = $60 + 6 | 0;
    $62 = HEAP16[$61 >> 1] | 0;
    $63 = $62 & 65535;
    $64 = $63 << 6;
    _ft_synthesize_vertical_metrics($48, $64);
    $error_0 = 0;
    label = 12;
    break;
   case 12:
    return $error_0 | 0;
  }
  return 0;
}
function _BDF_Size_Request($size, $req) {
  $size = $size | 0;
  $req = $req | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $_sink13 = 0, $35 = 0, $_ = 0, $37 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 32 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 + 140 | 0;
    $6 = $5;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $req + 16 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    $11 = $req + 8 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    if ($10) {
      $18 = $12;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $14 = Math_imul($12, $9);
    $15 = $14 + 36 | 0;
    $16 = ($15 | 0) / 72 & -1;
    $18 = $16;
    label = 3;
    break;
   case 3:
    $19 = $18 + 32 | 0;
    $20 = $19 >> 6;
    $21 = $req | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    if (($22 | 0) == 0) {
      label = 4;
      break;
    } else if (($22 | 0) == 1) {
      label = 5;
      break;
    } else {
      $_0 = 7;
      label = 8;
      break;
    }
   case 4:
    $24 = $4 + 12 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $25 + 32 | 0;
    $27 = $26 >> 6;
    $_sink13 = $27;
    label = 6;
    break;
   case 5:
    $29 = $7 + 40 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $7 + 44 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $32 + $30 | 0;
    $_sink13 = $33;
    label = 6;
    break;
   case 6:
    $35 = ($20 | 0) == ($_sink13 | 0);
    $_ = $35 ? 0 : 23;
    if ($35) {
      label = 7;
      break;
    } else {
      $_0 = $_;
      label = 8;
      break;
    }
   case 7:
    $37 = _BDF_Size_Select($size, 0) | 0;
    $_0 = 0;
    label = 8;
    break;
   case 8:
    return $_0 | 0;
  }
  return 0;
}
function _BDF_Size_Select($size, $strike_index) {
  $size = $size | 0;
  $strike_index = $strike_index | 0;
  var $2 = 0, $5 = 0;
  $2 = HEAP32[$size >> 2] | 0;
  $5 = HEAP32[$2 + 140 >> 2] | 0;
  _FT_Select_Metrics($2, $strike_index);
  HEAP32[$size + 24 >> 2] = HEAP32[$5 + 40 >> 2] << 6;
  HEAP32[$size + 28 >> 2] = -(HEAP32[$5 + 44 >> 2] | 0) << 6;
  HEAP32[$size + 36 >> 2] = (HEAPU16[$5 + 4 >> 1] | 0) << 6;
  return 0;
}
function _bdf_free_font($font) {
  $font = $font | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $i_097 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $_lcssa96 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $glyphs_092 = 0, $i_191 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $glyphs_187 = 0, $i_286 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $glyphs_282 = 0, $i_381 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $prop_080 = 0, $i_479 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $97 = 0, $98 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($font | 0) == 0;
    if ($1) {
      label = 23;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $font + 16520 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $font | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    _ft_mem_free($4, $6);
    HEAP32[$5 >> 2] = 0;
    $7 = $font + 128 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = $8;
    _hash_free($11, $4);
    $12 = HEAP32[$7 >> 2] | 0;
    _ft_mem_free($4, $12);
    HEAP32[$7 >> 2] = 0;
    label = 4;
    break;
   case 4:
    $14 = $font + 84 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    _ft_mem_free($4, $15);
    HEAP32[$14 >> 2] = 0;
    $16 = $font + 72 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($17 | 0) == 0;
    $19 = $font + 80 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    if ($18) {
      $_lcssa96 = $20;
      label = 8;
      break;
    } else {
      $i_097 = 0;
      $21 = $20;
      label = 5;
      break;
    }
   case 5:
    $22 = $21 + ($i_097 << 4) + 4 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = ($23 | 0) == 1;
    if ($24) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $26 = $21 + ($i_097 << 4) + 12 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    _ft_mem_free($4, $27);
    $28 = HEAP32[$19 >> 2] | 0;
    $29 = $28 + ($i_097 << 4) + 12 | 0;
    HEAP32[$29 >> 2] = 0;
    label = 7;
    break;
   case 7:
    $31 = $i_097 + 1 | 0;
    $32 = HEAP32[$16 >> 2] | 0;
    $33 = $31 >>> 0 < $32 >>> 0;
    $34 = HEAP32[$19 >> 2] | 0;
    if ($33) {
      $i_097 = $31;
      $21 = $34;
      label = 5;
      break;
    } else {
      $_lcssa96 = $34;
      label = 8;
      break;
    }
   case 8:
    $35 = $_lcssa96;
    _ft_mem_free($4, $35);
    HEAP32[$19 >> 2] = 0;
    $36 = $font + 56 | 0;
    $37 = $font + 52 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = ($38 | 0) == 0;
    if ($39) {
      label = 11;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $40 = HEAP32[$36 >> 2] | 0;
    $i_191 = 0;
    $glyphs_092 = $40;
    label = 10;
    break;
   case 10:
    $42 = $glyphs_092 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    _ft_mem_free($4, $43);
    HEAP32[$42 >> 2] = 0;
    $44 = $glyphs_092 + 24 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    _ft_mem_free($4, $45);
    HEAP32[$44 >> 2] = 0;
    $46 = $i_191 + 1 | 0;
    $47 = $glyphs_092 + 36 | 0;
    $48 = HEAP32[$37 >> 2] | 0;
    $49 = $46 >>> 0 < $48 >>> 0;
    if ($49) {
      $i_191 = $46;
      $glyphs_092 = $47;
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $50 = $font + 68 | 0;
    $51 = $font + 64 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = ($52 | 0) == 0;
    if ($53) {
      label = 14;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $54 = HEAP32[$50 >> 2] | 0;
    $i_286 = 0;
    $glyphs_187 = $54;
    label = 13;
    break;
   case 13:
    $56 = $glyphs_187 | 0;
    $57 = HEAP32[$56 >> 2] | 0;
    _ft_mem_free($4, $57);
    HEAP32[$56 >> 2] = 0;
    $58 = $glyphs_187 + 24 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    _ft_mem_free($4, $59);
    HEAP32[$58 >> 2] = 0;
    $60 = $i_286 + 1 | 0;
    $61 = $glyphs_187 + 36 | 0;
    $62 = HEAP32[$51 >> 2] | 0;
    $63 = $60 >>> 0 < $62 >>> 0;
    if ($63) {
      $i_286 = $60;
      $glyphs_187 = $61;
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $64 = HEAP32[$36 >> 2] | 0;
    $65 = $64;
    _ft_mem_free($4, $65);
    HEAP32[$36 >> 2] = 0;
    $66 = HEAP32[$50 >> 2] | 0;
    $67 = $66;
    _ft_mem_free($4, $67);
    HEAP32[$50 >> 2] = 0;
    $68 = $font + 104 | 0;
    $69 = $font + 112 | 0;
    $70 = HEAP32[$69 >> 2] | 0;
    $71 = ($70 | 0) == 0;
    if ($71) {
      label = 17;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $72 = HEAP32[$68 >> 2] | 0;
    $i_381 = 0;
    $glyphs_282 = $72;
    label = 16;
    break;
   case 16:
    $74 = $glyphs_282 | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    _ft_mem_free($4, $75);
    HEAP32[$74 >> 2] = 0;
    $76 = $glyphs_282 + 24 | 0;
    $77 = HEAP32[$76 >> 2] | 0;
    _ft_mem_free($4, $77);
    HEAP32[$76 >> 2] = 0;
    $78 = $i_381 + 1 | 0;
    $79 = $glyphs_282 + 36 | 0;
    $80 = HEAP32[$69 >> 2] | 0;
    $81 = $78 >>> 0 < $80 >>> 0;
    if ($81) {
      $i_381 = $78;
      $glyphs_282 = $79;
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $82 = HEAP32[$68 >> 2] | 0;
    $83 = $82;
    _ft_mem_free($4, $83);
    HEAP32[$68 >> 2] = 0;
    $84 = $font + 16532 | 0;
    _hash_free($84, $4);
    $85 = $font + 16524 | 0;
    $86 = $font + 16528 | 0;
    $87 = HEAP32[$86 >> 2] | 0;
    $88 = ($87 | 0) == 0;
    if ($88) {
      label = 22;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $89 = HEAP32[$85 >> 2] | 0;
    $i_479 = 0;
    $prop_080 = $89;
    label = 19;
    break;
   case 19:
    $91 = $prop_080 | 0;
    $92 = HEAP32[$91 >> 2] | 0;
    _ft_mem_free($4, $92);
    HEAP32[$91 >> 2] = 0;
    $93 = $prop_080 + 4 | 0;
    $94 = HEAP32[$93 >> 2] | 0;
    $95 = ($94 | 0) == 1;
    if ($95) {
      label = 20;
      break;
    } else {
      label = 21;
      break;
    }
   case 20:
    $97 = $prop_080 + 12 | 0;
    $98 = HEAP32[$97 >> 2] | 0;
    _ft_mem_free($4, $98);
    HEAP32[$97 >> 2] = 0;
    label = 21;
    break;
   case 21:
    $100 = $i_479 + 1 | 0;
    $101 = $prop_080 + 16 | 0;
    $102 = HEAP32[$86 >> 2] | 0;
    $103 = $100 >>> 0 < $102 >>> 0;
    if ($103) {
      $i_479 = $100;
      $prop_080 = $101;
      label = 19;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $104 = HEAP32[$85 >> 2] | 0;
    $105 = $104;
    _ft_mem_free($4, $105);
    HEAP32[$85 >> 2] = 0;
    label = 23;
    break;
   case 23:
    return;
  }
}
function _hash_free($ht, $memory) {
  $ht = $ht | 0;
  $memory = $memory | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $bp_010 = 0, $i_09 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $exitcond = 0, $13 = 0, $14 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($ht | 0) == 0;
    if ($1) {
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $ht + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $ht + 12 | 0;
    $6 = ($4 | 0) > 0;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $7 = HEAP32[$5 >> 2] | 0;
    $i_09 = 0;
    $bp_010 = $7;
    label = 4;
    break;
   case 4:
    $9 = HEAP32[$bp_010 >> 2] | 0;
    $10 = $9;
    _ft_mem_free($memory, $10);
    HEAP32[$bp_010 >> 2] = 0;
    $11 = $i_09 + 1 | 0;
    $12 = $bp_010 + 4 | 0;
    $exitcond = ($11 | 0) == ($4 | 0);
    if ($exitcond) {
      label = 5;
      break;
    } else {
      $i_09 = $11;
      $bp_010 = $12;
      label = 4;
      break;
    }
   case 5:
    $13 = HEAP32[$5 >> 2] | 0;
    $14 = $13;
    _ft_mem_free($memory, $14);
    HEAP32[$5 >> 2] = 0;
    label = 6;
    break;
   case 6:
    return;
  }
}
function _bdf_load_font($stream, $extmemory, $opts, $font) {
  $stream = $stream | 0;
  $extmemory = $extmemory | 0;
  $opts = $opts | 0;
  $font = $font | 0;
  var $lineno = 0, $error = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $71 = 0, $72 = 0, $73 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $81 = 0, $82 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $92 = 0, $93 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $121 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $128 = 0, $129 = 0, $133 = 0, $134 = 0, $136 = 0, $137 = 0, $138 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $158 = 0, $159 = 0, $161 = 0, $163 = 0, $165 = 0, $166 = 0, $168 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $lineno = __stackBase__ | 0;
    $error = __stackBase__ + 4 | 0;
    HEAP32[$lineno >> 2] = 0;
    HEAP32[$error >> 2] = 0;
    $1 = _ft_mem_alloc($extmemory, 8252, $error) | 0;
    $2 = HEAP32[$error >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 32;
      break;
    }
   case 2:
    $5 = ($opts | 0) != 0;
    $6 = $5 ? $opts : 5326756;
    $7 = $1 + 36 | 0;
    $8 = $7;
    HEAP32[$8 >> 2] = $6;
    $9 = $1 + 12 | 0;
    $10 = $9;
    HEAP16[$10 >> 1] = 32767;
    $11 = $1 + 8248 | 0;
    $12 = $11;
    HEAP32[$12 >> 2] = $extmemory;
    $13 = $1 + 8232 | 0;
    $14 = $13;
    __bdf_list_init($14, $extmemory);
    $15 = __bdf_readstream($stream, $1, $lineno) | 0;
    HEAP32[$error >> 2] = $15;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 3;
      break;
    } else {
      label = 35;
      break;
    }
   case 3:
    $18 = $1 + 32 | 0;
    $19 = $18;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 21;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $23 = $20 + 28 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = ($24 | 0) == 8;
    if ($25) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $27 = $20 + 4 | 0;
    $28 = HEAP16[$27 >> 1] | 0;
    $29 = $20 + 32 | 0;
    HEAP16[$29 >> 1] = $28;
    label = 6;
    break;
   case 6:
    $31 = $1 + 4 | 0;
    $32 = $31;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = HEAP32[$19 >> 2] | 0;
    $35 = $34 + 52 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $34 + 64 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $38 + $36 | 0;
    $40 = ($33 | 0) == ($39 | 0);
    if ($40) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $42 = $34 + 16516 | 0;
    HEAP16[$42 >> 1] = 1;
    label = 8;
    break;
   case 8:
    $44 = HEAP32[$8 >> 2] | 0;
    $45 = $44 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = ($46 | 0) == 0;
    if ($47) {
      label = 21;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $49 = HEAP32[$19 >> 2] | 0;
    $50 = $49 + 52 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = ($51 | 0) == 0;
    if ($52) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $54 = $49 + 64 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = ($55 | 0) == 0;
    if ($56) {
      label = 21;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $58 = $1 + 16 | 0;
    $59 = $58;
    $60 = HEAP16[$59 >> 1] | 0;
    $61 = $60 << 16 >> 16;
    $62 = HEAP16[$10 >> 1] | 0;
    $63 = $62 << 16 >> 16;
    $64 = $61 - $63 | 0;
    $65 = HEAP32[$19 >> 2] | 0;
    $66 = $65 + 4 | 0;
    $67 = HEAP16[$66 >> 1] | 0;
    $68 = $67 & 65535;
    $69 = ($64 | 0) == ($68 | 0);
    if ($69) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $71 = $64 & 65535;
    HEAP16[$66 >> 1] = $71;
    $72 = HEAP32[$19 >> 2] | 0;
    $73 = $72 + 16516 | 0;
    HEAP16[$73 >> 1] = 1;
    label = 13;
    break;
   case 13:
    $75 = HEAP32[$19 >> 2] | 0;
    $76 = $75 + 8 | 0;
    $77 = HEAP16[$76 >> 1] | 0;
    $78 = HEAP16[$10 >> 1] | 0;
    $79 = $77 << 16 >> 16 == $78 << 16 >> 16;
    if ($79) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    HEAP16[$76 >> 1] = $78;
    $81 = HEAP32[$19 >> 2] | 0;
    $82 = $81 + 16516 | 0;
    HEAP16[$82 >> 1] = 1;
    label = 15;
    break;
   case 15:
    $84 = HEAP32[$19 >> 2] | 0;
    $85 = $84 + 12 | 0;
    $86 = HEAP16[$85 >> 1] | 0;
    $87 = $1 + 18 | 0;
    $88 = $87;
    $89 = HEAP16[$88 >> 1] | 0;
    $90 = $86 << 16 >> 16 == $89 << 16 >> 16;
    if ($90) {
      label = 17;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    HEAP16[$85 >> 1] = $89;
    $92 = HEAP32[$19 >> 2] | 0;
    $93 = $92 + 16516 | 0;
    HEAP16[$93 >> 1] = 1;
    label = 17;
    break;
   case 17:
    $95 = HEAP32[$19 >> 2] | 0;
    $96 = $95 + 14 | 0;
    $97 = HEAP16[$96 >> 1] | 0;
    $98 = $1 + 20 | 0;
    $99 = $98;
    $100 = HEAP16[$99 >> 1] | 0;
    $101 = $97 << 16 >> 16 == $100 << 16 >> 16;
    if ($101) {
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    HEAP16[$96 >> 1] = $100;
    $103 = HEAP16[$99 >> 1] | 0;
    $104 = -$103 & 65535;
    $105 = HEAP32[$19 >> 2] | 0;
    $106 = $105 + 10 | 0;
    HEAP16[$106 >> 1] = $104;
    $107 = HEAP32[$19 >> 2] | 0;
    $108 = $107 + 16516 | 0;
    HEAP16[$108 >> 1] = 1;
    label = 19;
    break;
   case 19:
    $110 = HEAP16[$88 >> 1] | 0;
    $111 = $110 << 16 >> 16;
    $112 = HEAP16[$99 >> 1] | 0;
    $113 = $112 << 16 >> 16;
    $114 = $113 + $111 | 0;
    $115 = HEAP32[$19 >> 2] | 0;
    $116 = $115 + 6 | 0;
    $117 = HEAP16[$116 >> 1] | 0;
    $118 = $117 & 65535;
    $119 = ($114 | 0) == ($118 | 0);
    if ($119) {
      label = 21;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $121 = $114 & 65535;
    HEAP16[$116 >> 1] = $121;
    label = 21;
    break;
   case 21:
    $123 = $1;
    $124 = HEAP32[$123 >> 2] | 0;
    $125 = $124 & 1;
    $126 = ($125 | 0) == 0;
    if ($126) {
      label = 25;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $128 = $124 & 32;
    $129 = ($128 | 0) == 0;
    if ($129) {
      label = 23;
      break;
    } else {
      label = 24;
      break;
    }
   case 23:
    HEAP32[$error >> 2] = 185;
    label = 32;
    break;
   case 24:
    HEAP32[$error >> 2] = 186;
    label = 32;
    break;
   case 25:
    $133 = HEAP32[$19 >> 2] | 0;
    $134 = ($133 | 0) == 0;
    if ($134) {
      label = 29;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $136 = $133 + 88 | 0;
    $137 = HEAP32[$136 >> 2] | 0;
    $138 = ($137 | 0) == 0;
    if ($138) {
      label = 31;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $140 = $133 + 16520 | 0;
    $141 = HEAP32[$140 >> 2] | 0;
    $142 = $137 + 1 | 0;
    $143 = $133 + 84 | 0;
    $144 = HEAP32[$143 >> 2] | 0;
    $145 = _ft_mem_realloc($141, 1, $137, $142, $144, $error) | 0;
    $146 = HEAP32[$19 >> 2] | 0;
    $147 = $146 + 84 | 0;
    HEAP32[$147 >> 2] = $145;
    $148 = HEAP32[$error >> 2] | 0;
    $149 = ($148 | 0) == 0;
    if ($149) {
      label = 28;
      break;
    } else {
      label = 35;
      break;
    }
   case 28:
    $151 = HEAP32[$19 >> 2] | 0;
    $152 = $151 + 88 | 0;
    $153 = HEAP32[$152 >> 2] | 0;
    $154 = $151 + 84 | 0;
    $155 = HEAP32[$154 >> 2] | 0;
    $156 = $155 + $153 | 0;
    HEAP8[$156] = 0;
    label = 31;
    break;
   case 29:
    $158 = HEAP32[$error >> 2] | 0;
    $159 = ($158 | 0) == 0;
    if ($159) {
      label = 30;
      break;
    } else {
      label = 31;
      break;
    }
   case 30:
    HEAP32[$error >> 2] = 3;
    label = 31;
    break;
   case 31:
    $161 = HEAP32[$19 >> 2] | 0;
    HEAP32[$font >> 2] = $161;
    label = 33;
    break;
   case 32:
    $163 = ($1 | 0) == 0;
    if ($163) {
      label = 34;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    $165 = $1 + 8232 | 0;
    $166 = $165;
    __bdf_list_done($166);
    _ft_mem_free($extmemory, $1);
    label = 34;
    break;
   case 34:
    $168 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $168 | 0;
   case 35:
    $170 = $1 + 32 | 0;
    $171 = $170;
    $172 = HEAP32[$171 >> 2] | 0;
    _bdf_free_font($172);
    $173 = HEAP32[$171 >> 2] | 0;
    $174 = $173;
    _ft_mem_free($extmemory, $174);
    HEAP32[$171 >> 2] = 0;
    label = 32;
    break;
  }
  return 0;
}
function _bdf_get_font_property($font, $name) {
  $font = $font | 0;
  $name = $name | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $or_cond = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($font | 0) == 0;
    if ($1) {
      $_0 = 0;
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $font + 72 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    $6 = ($name | 0) == 0;
    $or_cond = $5 | $6;
    if ($or_cond) {
      $_0 = 0;
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $8 = HEAP8[$name] | 0;
    $9 = $8 << 24 >> 24 == 0;
    if ($9) {
      $_0 = 0;
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $11 = $font + 128 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12;
    $14 = _hash_lookup($name, $13) | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      $_0 = 0;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = $font + 80 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $14 + 4 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $18 + ($20 << 4) | 0;
    $_0 = $21;
    label = 6;
    break;
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _bdf_interpret_style($bdf) {
  $bdf = $bdf | 0;
  var $error = 0, $strings = 0, $lengths = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $phitmp = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $61 = 0, $63 = 0, $64 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $74 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $82 = 0, $83 = 0, $len_1 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $90 = 0, $91 = 0, $len_2 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $103 = 0, $104 = 0, $106 = 0, $s_1 = 0, $107 = 0, $mm_067 = 0, $108 = 0, $109 = 0, $110 = 0, $113 = 0, $exitcond = 0, $114 = 0, $s_2 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $_0 = 0, $123 = 0, $124 = 0, $126 = 0, $s_1_1 = 0, $128 = 0, $s_2_1 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $136 = 0, $137 = 0, $139 = 0, $s_1_2 = 0, $141 = 0, $s_2_2 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $149 = 0, $150 = 0, $152 = 0, $s_1_3 = 0, $153 = 0, $mm_067_3 = 0, $154 = 0, $155 = 0, $156 = 0, $159 = 0, $exitcond_3 = 0, $160 = 0, $s_2_3 = 0, $162 = 0, $164 = 0, $165 = 0, $166 = 0, $len_1_1 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $173 = 0, $174 = 0, $175 = 0, $len_1_2 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $182 = 0, $183 = 0, $184 = 0, $len_1_3 = 0, $186 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 36 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $strings = __stackBase__ + 4 | 0;
    $lengths = __stackBase__ + 20 | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $bdf + 100 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $bdf + 140 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $strings;
    _memset($5 | 0, 0, 16);
    $6 = $bdf + 12 | 0;
    HEAP32[$6 >> 2] = 0;
    $7 = _bdf_get_font_property($4, 5324256) | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 8;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = $7 + 4 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($11 | 0) == 1;
    if ($12) {
      label = 3;
      break;
    } else {
      label = 8;
      break;
    }
   case 3:
    $14 = $7 + 12 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 8;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $18 = HEAP8[$15] | 0;
    if (($18 << 24 >> 24 | 0) == 79 | ($18 << 24 >> 24 | 0) == 111 | ($18 << 24 >> 24 | 0) == 73 | ($18 << 24 >> 24 | 0) == 105) {
      label = 5;
      break;
    } else {
      label = 8;
      break;
    }
   case 5:
    $20 = HEAP32[$6 >> 2] | 0;
    $21 = $20 | 1;
    HEAP32[$6 >> 2] = $21;
    $22 = HEAP32[$14 >> 2] | 0;
    $23 = HEAP8[$22] | 0;
    $24 = $23 << 24 >> 24 == 79;
    if ($24) {
      $28 = 5324140;
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $26 = $23 << 24 >> 24 == 111;
    $phitmp = $26 ? 5324140 : 5324064;
    $28 = $phitmp;
    label = 7;
    break;
   case 7:
    $29 = $strings + 8 | 0;
    HEAP32[$29 >> 2] = $28;
    label = 8;
    break;
   case 8:
    $31 = _bdf_get_font_property($4, 5323964) | 0;
    $32 = ($31 | 0) == 0;
    if ($32) {
      label = 13;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $34 = $31 + 4 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = ($35 | 0) == 1;
    if ($36) {
      label = 10;
      break;
    } else {
      label = 13;
      break;
    }
   case 10:
    $38 = $31 + 12 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = ($39 | 0) == 0;
    if ($40) {
      label = 13;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $42 = HEAP8[$39] | 0;
    if (($42 << 24 >> 24 | 0) == 66 | ($42 << 24 >> 24 | 0) == 98) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    $44 = HEAP32[$6 >> 2] | 0;
    $45 = $44 | 2;
    HEAP32[$6 >> 2] = $45;
    $46 = $strings + 4 | 0;
    HEAP32[$46 >> 2] = 5323892;
    label = 13;
    break;
   case 13:
    $48 = _bdf_get_font_property($4, 5323808) | 0;
    $49 = ($48 | 0) == 0;
    if ($49) {
      label = 18;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $51 = $48 + 4 | 0;
    $52 = HEAP32[$51 >> 2] | 0;
    $53 = ($52 | 0) == 1;
    if ($53) {
      label = 15;
      break;
    } else {
      label = 18;
      break;
    }
   case 15:
    $55 = $48 + 12 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = ($56 | 0) == 0;
    if ($57) {
      label = 18;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $59 = HEAP8[$56] | 0;
    if (($59 << 24 >> 24 | 0) == 0 | ($59 << 24 >> 24 | 0) == 78 | ($59 << 24 >> 24 | 0) == 110) {
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $61 = $strings + 12 | 0;
    HEAP32[$61 >> 2] = $56;
    label = 18;
    break;
   case 18:
    $63 = _bdf_get_font_property($4, 5323712) | 0;
    $64 = ($63 | 0) == 0;
    if ($64) {
      label = 23;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $66 = $63 + 4 | 0;
    $67 = HEAP32[$66 >> 2] | 0;
    $68 = ($67 | 0) == 1;
    if ($68) {
      label = 20;
      break;
    } else {
      label = 23;
      break;
    }
   case 20:
    $70 = $63 + 12 | 0;
    $71 = HEAP32[$70 >> 2] | 0;
    $72 = ($71 | 0) == 0;
    if ($72) {
      label = 23;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $74 = HEAP8[$71] | 0;
    if (($74 << 24 >> 24 | 0) == 0 | ($74 << 24 >> 24 | 0) == 78 | ($74 << 24 >> 24 | 0) == 110) {
      label = 23;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $76 = $strings | 0;
    HEAP32[$76 >> 2] = $71;
    label = 23;
    break;
   case 23:
    $77 = $lengths | 0;
    HEAP32[$77 >> 2] = 0;
    $78 = $strings | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = ($79 | 0) == 0;
    if ($80) {
      $len_1 = 0;
      label = 25;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $82 = _strlen($79 | 0) | 0;
    HEAP32[$77 >> 2] = $82;
    $83 = $82 + 1 | 0;
    $len_1 = $83;
    label = 25;
    break;
   case 25:
    $85 = $lengths + 4 | 0;
    HEAP32[$85 >> 2] = 0;
    $86 = $strings + 4 | 0;
    $87 = HEAP32[$86 >> 2] | 0;
    $88 = ($87 | 0) == 0;
    if ($88) {
      $len_1_1 = $len_1;
      label = 55;
      break;
    } else {
      label = 54;
      break;
    }
   case 26:
    $90 = $strings | 0;
    HEAP32[$90 >> 2] = 5323612;
    $91 = $lengths | 0;
    HEAP32[$91 >> 2] = 7;
    $len_2 = 8;
    label = 27;
    break;
   case 27:
    $93 = _ft_mem_alloc($2, $len_2, $error) | 0;
    $94 = $bdf + 24 | 0;
    HEAP32[$94 >> 2] = $93;
    $95 = HEAP32[$error >> 2] | 0;
    $96 = ($95 | 0) == 0;
    if ($96) {
      label = 28;
      break;
    } else {
      $_0 = $95;
      label = 37;
      break;
    }
   case 28:
    $97 = $strings | 0;
    $98 = HEAP32[$97 >> 2] | 0;
    $99 = $lengths | 0;
    $100 = HEAP32[$99 >> 2] | 0;
    $101 = ($98 | 0) == 0;
    if ($101) {
      $s_2 = $93;
      label = 36;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    $103 = HEAP32[$94 >> 2] | 0;
    $104 = ($93 | 0) == ($103 | 0);
    if ($104) {
      $s_1 = $93;
      label = 31;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    $106 = $93 + 1 | 0;
    HEAP8[$93] = 32;
    $s_1 = $106;
    label = 31;
    break;
   case 31:
    _memcpy($s_1 | 0, $98 | 0, $100 | 0);
    $107 = ($100 | 0) == 0;
    if ($107) {
      label = 35;
      break;
    } else {
      $mm_067 = 0;
      label = 32;
      break;
    }
   case 32:
    $108 = $s_1 + $mm_067 | 0;
    $109 = HEAP8[$108] | 0;
    $110 = $109 << 24 >> 24 == 32;
    if ($110) {
      label = 33;
      break;
    } else {
      label = 34;
      break;
    }
   case 33:
    HEAP8[$108] = 45;
    label = 34;
    break;
   case 34:
    $113 = $mm_067 + 1 | 0;
    $exitcond = ($113 | 0) == ($100 | 0);
    if ($exitcond) {
      label = 35;
      break;
    } else {
      $mm_067 = $113;
      label = 32;
      break;
    }
   case 35:
    $114 = $s_1 + $100 | 0;
    $s_2 = $114;
    label = 36;
    break;
   case 36:
    $116 = $strings + 4 | 0;
    $117 = HEAP32[$116 >> 2] | 0;
    $118 = $lengths + 4 | 0;
    $119 = HEAP32[$118 >> 2] | 0;
    $120 = ($117 | 0) == 0;
    if ($120) {
      $s_2_1 = $s_2;
      label = 41;
      break;
    } else {
      label = 38;
      break;
    }
   case 37:
    STACKTOP = __stackBase__;
    return $_0 | 0;
   case 38:
    $123 = HEAP32[$94 >> 2] | 0;
    $124 = ($s_2 | 0) == ($123 | 0);
    if ($124) {
      $s_1_1 = $s_2;
      label = 40;
      break;
    } else {
      label = 39;
      break;
    }
   case 39:
    $126 = $s_2 + 1 | 0;
    HEAP8[$s_2] = 32;
    $s_1_1 = $126;
    label = 40;
    break;
   case 40:
    _memcpy($s_1_1 | 0, $117 | 0, $119 | 0);
    $128 = $s_1_1 + $119 | 0;
    $s_2_1 = $128;
    label = 41;
    break;
   case 41:
    $130 = $strings + 8 | 0;
    $131 = HEAP32[$130 >> 2] | 0;
    $132 = $lengths + 8 | 0;
    $133 = HEAP32[$132 >> 2] | 0;
    $134 = ($131 | 0) == 0;
    if ($134) {
      $s_2_2 = $s_2_1;
      label = 45;
      break;
    } else {
      label = 42;
      break;
    }
   case 42:
    $136 = HEAP32[$94 >> 2] | 0;
    $137 = ($s_2_1 | 0) == ($136 | 0);
    if ($137) {
      $s_1_2 = $s_2_1;
      label = 44;
      break;
    } else {
      label = 43;
      break;
    }
   case 43:
    $139 = $s_2_1 + 1 | 0;
    HEAP8[$s_2_1] = 32;
    $s_1_2 = $139;
    label = 44;
    break;
   case 44:
    _memcpy($s_1_2 | 0, $131 | 0, $133 | 0);
    $141 = $s_1_2 + $133 | 0;
    $s_2_2 = $141;
    label = 45;
    break;
   case 45:
    $143 = $strings + 12 | 0;
    $144 = HEAP32[$143 >> 2] | 0;
    $145 = $lengths + 12 | 0;
    $146 = HEAP32[$145 >> 2] | 0;
    $147 = ($144 | 0) == 0;
    if ($147) {
      $s_2_3 = $s_2_2;
      label = 53;
      break;
    } else {
      label = 46;
      break;
    }
   case 46:
    $149 = HEAP32[$94 >> 2] | 0;
    $150 = ($s_2_2 | 0) == ($149 | 0);
    if ($150) {
      $s_1_3 = $s_2_2;
      label = 48;
      break;
    } else {
      label = 47;
      break;
    }
   case 47:
    $152 = $s_2_2 + 1 | 0;
    HEAP8[$s_2_2] = 32;
    $s_1_3 = $152;
    label = 48;
    break;
   case 48:
    _memcpy($s_1_3 | 0, $144 | 0, $146 | 0);
    $153 = ($146 | 0) == 0;
    if ($153) {
      label = 52;
      break;
    } else {
      $mm_067_3 = 0;
      label = 49;
      break;
    }
   case 49:
    $154 = $s_1_3 + $mm_067_3 | 0;
    $155 = HEAP8[$154] | 0;
    $156 = $155 << 24 >> 24 == 32;
    if ($156) {
      label = 50;
      break;
    } else {
      label = 51;
      break;
    }
   case 50:
    HEAP8[$154] = 45;
    label = 51;
    break;
   case 51:
    $159 = $mm_067_3 + 1 | 0;
    $exitcond_3 = ($159 | 0) == ($146 | 0);
    if ($exitcond_3) {
      label = 52;
      break;
    } else {
      $mm_067_3 = $159;
      label = 49;
      break;
    }
   case 52:
    $160 = $s_1_3 + $146 | 0;
    $s_2_3 = $160;
    label = 53;
    break;
   case 53:
    HEAP8[$s_2_3] = 0;
    $162 = HEAP32[$error >> 2] | 0;
    $_0 = $162;
    label = 37;
    break;
   case 54:
    $164 = _strlen($87 | 0) | 0;
    HEAP32[$85 >> 2] = $164;
    $165 = $len_1 + 1 | 0;
    $166 = $165 + $164 | 0;
    $len_1_1 = $166;
    label = 55;
    break;
   case 55:
    $168 = $lengths + 8 | 0;
    HEAP32[$168 >> 2] = 0;
    $169 = $strings + 8 | 0;
    $170 = HEAP32[$169 >> 2] | 0;
    $171 = ($170 | 0) == 0;
    if ($171) {
      $len_1_2 = $len_1_1;
      label = 57;
      break;
    } else {
      label = 56;
      break;
    }
   case 56:
    $173 = _strlen($170 | 0) | 0;
    HEAP32[$168 >> 2] = $173;
    $174 = $len_1_1 + 1 | 0;
    $175 = $174 + $173 | 0;
    $len_1_2 = $175;
    label = 57;
    break;
   case 57:
    $177 = $lengths + 12 | 0;
    HEAP32[$177 >> 2] = 0;
    $178 = $strings + 12 | 0;
    $179 = HEAP32[$178 >> 2] | 0;
    $180 = ($179 | 0) == 0;
    if ($180) {
      $len_1_3 = $len_1_2;
      label = 59;
      break;
    } else {
      label = 58;
      break;
    }
   case 58:
    $182 = _strlen($179 | 0) | 0;
    HEAP32[$177 >> 2] = $182;
    $183 = $len_1_2 + 1 | 0;
    $184 = $183 + $182 | 0;
    $len_1_3 = $184;
    label = 59;
    break;
   case 59:
    $186 = ($len_1_3 | 0) == 0;
    if ($186) {
      label = 26;
      break;
    } else {
      $len_2 = $len_1_3;
      label = 27;
      break;
    }
  }
  return 0;
}
function _hash_lookup($key, $ht) {
  $key = $key | 0;
  $ht = $ht | 0;
  return HEAP32[_hash_bucket($key, $ht) >> 2] | 0;
}
function _hash_bucket($key, $ht) {
  $key = $key | 0;
  $ht = $ht | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $kp_020 = 0, $res_019 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $res_0_lcssa = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $ndp_017 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $ndp_0_be = 0, $35 = 0, $36 = 0, $ndp_0_lcssa = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $ht + 12 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = HEAP8[$key] | 0;
    $4 = $3 << 24 >> 24 == 0;
    if ($4) {
      $res_0_lcssa = 0;
      label = 3;
      break;
    } else {
      $res_019 = 0;
      $kp_020 = $key;
      $5 = $3;
      label = 2;
      break;
    }
   case 2:
    $6 = $res_019 * 31 & -1;
    $7 = $kp_020 + 1 | 0;
    $8 = $5 << 24 >> 24;
    $9 = $8 + $6 | 0;
    $10 = HEAP8[$7] | 0;
    $11 = $10 << 24 >> 24 == 0;
    if ($11) {
      $res_0_lcssa = $9;
      label = 3;
      break;
    } else {
      $res_019 = $9;
      $kp_020 = $7;
      $5 = $10;
      label = 2;
      break;
    }
   case 3:
    $12 = $ht + 4 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = ($res_0_lcssa >>> 0) % ($13 >>> 0);
    $15 = $2 + ($14 << 2) | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      $ndp_0_lcssa = $15;
      label = 10;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $18 = HEAP8[$key] | 0;
    $ndp_017 = $15;
    $20 = $16;
    label = 5;
    break;
   case 5:
    $21 = $20 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = HEAP8[$22] | 0;
    $24 = $23 << 24 >> 24 == $18 << 24 >> 24;
    if ($24) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $26 = _strcmp($22 | 0, $key | 0) | 0;
    $27 = ($26 | 0) == 0;
    if ($27) {
      $ndp_0_lcssa = $ndp_017;
      label = 10;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $29 = $ndp_017 - 4 | 0;
    $30 = $29 >>> 0 < $2 >>> 0;
    if ($30) {
      label = 8;
      break;
    } else {
      $ndp_0_be = $29;
      label = 9;
      break;
    }
   case 8:
    $32 = HEAP32[$12 >> 2] | 0;
    $33 = $32 - 1 | 0;
    $34 = $2 + ($33 << 2) | 0;
    $ndp_0_be = $34;
    label = 9;
    break;
   case 9:
    $35 = HEAP32[$ndp_0_be >> 2] | 0;
    $36 = ($35 | 0) == 0;
    if ($36) {
      $ndp_0_lcssa = $ndp_0_be;
      label = 10;
      break;
    } else {
      $ndp_017 = $ndp_0_be;
      $20 = $35;
      label = 5;
      break;
    }
   case 10:
    return $ndp_0_lcssa | 0;
  }
  return 0;
}
function __bdf_list_init($list, $memory) {
  $list = $list | 0;
  $memory = $memory | 0;
  _memset($list | 0, 0, 12);
  HEAP32[$list + 12 >> 2] = $memory;
  return;
}
function __bdf_readstream($stream, $client_data, $lno) {
  $stream = $stream | 0;
  $client_data = $client_data | 0;
  $lno = $lno | 0;
  var $cb = 0, $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $refill_0_ph_ph = 0, $to_skip_0_ph_ph = 0, $bytes_0_ph_ph = 0, $start_0_ph_ph = 0, $cursor_0_ph_ph = 0, $avail_0_ph_ph = 0, $buf_0_ph_ph = 0, $buf_size_0_ph_ph = 0, $lineno_0_ph_ph = 0, $refill_0_ph = 0, $to_skip_0_ph = 0, $bytes_0_ph = 0, $start_0_ph = 0, $cursor_0_ph = 0, $avail_0_ph = 0, $buf_0_ph = 0, $buf_size_0_ph = 0, $refill_0_ph6 = 0, $bytes_0_ph7 = 0, $start_0_ph8 = 0, $cursor_0_ph9 = 0, $avail_0_ph10 = 0, $buf_0_ph11 = 0, $buf_size_0_ph12 = 0, $8 = 0, $refill_0 = 0, $bytes_0 = 0, $cursor_0 = 0, $avail_0 = 0, $buf_0 = 0, $buf_size_0 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $bytes_1 = 0, $cursor_1 = 0, $avail_1 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $end_03 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $33 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $buf_2 = 0, $66 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $cb = __stackBase__ | 0;
    $error = __stackBase__ + 4 | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $3 = _ft_mem_realloc($2, 1, 0, 1024, 0, $error) | 0;
    $4 = HEAP32[$error >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $buf_2 = $3;
      label = 29;
      break;
    }
   case 2:
    HEAP32[$cb >> 2] = 402;
    HEAP8[$3] = 0;
    $7 = $cb;
    $lineno_0_ph_ph = 1;
    $buf_size_0_ph_ph = 1024;
    $buf_0_ph_ph = $3;
    $avail_0_ph_ph = 0;
    $cursor_0_ph_ph = 0;
    $start_0_ph_ph = 0;
    $bytes_0_ph_ph = 0;
    $to_skip_0_ph_ph = 256;
    $refill_0_ph_ph = 0;
    label = 3;
    break;
   case 3:
    $buf_size_0_ph = $buf_size_0_ph_ph;
    $buf_0_ph = $buf_0_ph_ph;
    $avail_0_ph = $avail_0_ph_ph;
    $cursor_0_ph = $cursor_0_ph_ph;
    $start_0_ph = $start_0_ph_ph;
    $bytes_0_ph = $bytes_0_ph_ph;
    $to_skip_0_ph = $to_skip_0_ph_ph;
    $refill_0_ph = $refill_0_ph_ph;
    label = 4;
    break;
   case 4:
    $buf_size_0_ph12 = $buf_size_0_ph;
    $buf_0_ph11 = $buf_0_ph;
    $avail_0_ph10 = $avail_0_ph;
    $cursor_0_ph9 = $cursor_0_ph;
    $start_0_ph8 = $start_0_ph;
    $bytes_0_ph7 = $bytes_0_ph;
    $refill_0_ph6 = $refill_0_ph;
    label = 5;
    break;
   case 5:
    $8 = ($start_0_ph8 | 0) == 0;
    $buf_size_0 = $buf_size_0_ph12;
    $buf_0 = $buf_0_ph11;
    $avail_0 = $avail_0_ph10;
    $cursor_0 = $cursor_0_ph9;
    $bytes_0 = $bytes_0_ph7;
    $refill_0 = $refill_0_ph6;
    label = 6;
    break;
   case 6:
    if ($refill_0) {
      $avail_1 = $avail_0;
      $cursor_1 = $cursor_0;
      $bytes_1 = $bytes_0;
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $11 = $buf_0 + $cursor_0 | 0;
    $12 = $buf_size_0 - $cursor_0 | 0;
    $13 = _FT_Stream_TryRead($stream, $11, $12) | 0;
    $14 = $13 + $cursor_0 | 0;
    $avail_1 = $14;
    $cursor_1 = 0;
    $bytes_1 = $13;
    label = 8;
    break;
   case 8:
    $16 = ($start_0_ph8 | 0) < ($avail_1 | 0);
    if ($16) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $17 = ($start_0_ph8 | 0) < ($avail_1 | 0);
    if ($17) {
      $end_03 = $start_0_ph8;
      label = 12;
      break;
    } else {
      label = 14;
      break;
    }
   case 10:
    $19 = $buf_0 + $start_0_ph8 | 0;
    $20 = HEAP8[$19] | 0;
    $21 = $20 << 24 >> 24;
    $22 = ($21 | 0) == ($to_skip_0_ph | 0);
    if ($22) {
      label = 11;
      break;
    } else {
      label = 9;
      break;
    }
   case 11:
    $24 = $start_0_ph8 + 1 | 0;
    $buf_size_0_ph = $buf_size_0;
    $buf_0_ph = $buf_0;
    $avail_0_ph = $avail_1;
    $cursor_0_ph = $cursor_1;
    $start_0_ph = $24;
    $bytes_0_ph = $bytes_1;
    $to_skip_0_ph = 256;
    $refill_0_ph = 1;
    label = 4;
    break;
   case 12:
    $25 = $buf_0 + $end_03 | 0;
    $26 = HEAP8[$25] | 0;
    if (($26 << 24 >> 24 | 0) == 13 | ($26 << 24 >> 24 | 0) == 10) {
      label = 20;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $28 = $end_03 + 1 | 0;
    $29 = ($28 | 0) < ($avail_1 | 0);
    if ($29) {
      $end_03 = $28;
      label = 12;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $30 = ($bytes_1 | 0) == 0;
    if ($30) {
      label = 28;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    if ($8) {
      label = 16;
      break;
    } else {
      label = 19;
      break;
    }
   case 16:
    $33 = $buf_size_0 >>> 0 > 65535;
    if ($33) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    HEAP32[$error >> 2] = 6;
    $buf_2 = $buf_0;
    label = 29;
    break;
   case 18:
    $36 = $buf_size_0 << 1;
    $37 = _ft_mem_realloc($2, 1, $buf_size_0, $36, $buf_0, $error) | 0;
    $38 = HEAP32[$error >> 2] | 0;
    $39 = ($38 | 0) == 0;
    if ($39) {
      $cursor_0 = $buf_size_0;
      $buf_size_0 = $36;
      $buf_0 = $37;
      $avail_0 = $avail_1;
      $bytes_0 = $bytes_1;
      $refill_0 = 0;
      label = 6;
      break;
    } else {
      $buf_2 = $37;
      label = 29;
      break;
    }
   case 19:
    $41 = $avail_1 - $start_0_ph8 | 0;
    $42 = $buf_0 + $start_0_ph8 | 0;
    _memcpy($buf_0 | 0, $42 | 0, $41 | 0);
    $buf_size_0_ph12 = $buf_size_0;
    $buf_0_ph11 = $buf_0;
    $avail_0_ph10 = $start_0_ph8;
    $cursor_0_ph9 = $41;
    $start_0_ph8 = 0;
    $bytes_0_ph7 = $41;
    $refill_0_ph6 = 0;
    label = 5;
    break;
   case 20:
    $44 = $buf_0 + $end_03 | 0;
    $45 = HEAP8[$44] | 0;
    HEAP8[$44] = 0;
    $46 = $buf_0 + $start_0_ph8 | 0;
    $47 = HEAP8[$46] | 0;
    if (($47 << 24 >> 24 | 0) == 35 | ($47 << 24 >> 24 | 0) == 26) {
      label = 25;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $49 = ($end_03 | 0) > ($start_0_ph8 | 0);
    if ($49) {
      label = 22;
      break;
    } else {
      label = 25;
      break;
    }
   case 22:
    $51 = HEAP32[$cb >> 2] | 0;
    $52 = $end_03 - $start_0_ph8 | 0;
    $53 = FUNCTION_TABLE_iiiiii[$51 & 1023]($46, $52, $lineno_0_ph_ph, $7, $client_data) | 0;
    HEAP32[$error >> 2] = $53;
    $54 = ($53 | 0) == -1;
    if ($54) {
      label = 23;
      break;
    } else {
      $59 = $53;
      label = 24;
      break;
    }
   case 23:
    $56 = HEAP32[$cb >> 2] | 0;
    $57 = FUNCTION_TABLE_iiiiii[$56 & 1023]($46, $52, $lineno_0_ph_ph, $7, $client_data) | 0;
    HEAP32[$error >> 2] = $57;
    $59 = $57;
    label = 24;
    break;
   case 24:
    $60 = ($59 | 0) == 0;
    if ($60) {
      label = 25;
      break;
    } else {
      label = 28;
      break;
    }
   case 25:
    $62 = $lineno_0_ph_ph + 1 | 0;
    HEAP8[$44] = $45;
    $63 = $end_03 + 1 | 0;
    if (($45 << 24 >> 24 | 0) == 10) {
      $lineno_0_ph_ph = $62;
      $buf_size_0_ph_ph = $buf_size_0;
      $buf_0_ph_ph = $buf_0;
      $avail_0_ph_ph = $avail_1;
      $cursor_0_ph_ph = $cursor_1;
      $start_0_ph_ph = $63;
      $bytes_0_ph_ph = $bytes_1;
      $to_skip_0_ph_ph = 13;
      $refill_0_ph_ph = 1;
      label = 3;
      break;
    } else if (($45 << 24 >> 24 | 0) == 13) {
      label = 26;
      break;
    } else {
      label = 27;
      break;
    }
   case 26:
    $lineno_0_ph_ph = $62;
    $buf_size_0_ph_ph = $buf_size_0;
    $buf_0_ph_ph = $buf_0;
    $avail_0_ph_ph = $avail_1;
    $cursor_0_ph_ph = $cursor_1;
    $start_0_ph_ph = $63;
    $bytes_0_ph_ph = $bytes_1;
    $to_skip_0_ph_ph = 10;
    $refill_0_ph_ph = 1;
    label = 3;
    break;
   case 27:
    $lineno_0_ph_ph = $62;
    $buf_size_0_ph_ph = $buf_size_0;
    $buf_0_ph_ph = $buf_0;
    $avail_0_ph_ph = $avail_1;
    $cursor_0_ph_ph = $cursor_1;
    $start_0_ph_ph = $63;
    $bytes_0_ph_ph = $bytes_1;
    $to_skip_0_ph_ph = 256;
    $refill_0_ph_ph = 1;
    label = 3;
    break;
   case 28:
    HEAP32[$lno >> 2] = $lineno_0_ph_ph;
    $buf_2 = $buf_0;
    label = 29;
    break;
   case 29:
    _ft_mem_free($2, $buf_2);
    $66 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $66 | 0;
  }
  return 0;
}
function __bdf_parse_start($line, $linelen, $lineno, $call_data, $client_data) {
  $line = $line | 0;
  $linelen = $linelen | 0;
  $lineno = $lineno | 0;
  $call_data = $call_data | 0;
  $client_data = $client_data | 0;
  var $slen = 0, $error = 0, $nbuf = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $memory_0 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $_0 = 0, $s_0 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $prop_0124 = 0, $i_0123 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $90 = 0, $91 = 0, $93 = 0, $94 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $118 = 0, $119 = 0, $121 = 0, $122 = 0, $124 = 0, $125 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $173 = 0, $174 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $181 = 0, $182 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $210 = 0, $211 = 0, $213 = 0, $214 = 0, $216 = 0, $217 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $249 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $shift_0127 = 0, $i1_0126 = 0, $bitcount_0125 = 0, $259 = 0, $260 = 0, $bitcount_0_i1_0 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $bitcount_0_lcssa128 = 0, $265 = 0, $266 = 0, $phitmp122 = 0, $268 = 0, $269 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $275 = 0, $276 = 0, $278 = 0, $279 = 0, $281 = 0, $282 = 0, $284 = 0, $285 = 0, $287 = 0, $288 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $320 = 0, $321 = 0, $323 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 136 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $slen = __stackBase__ | 0;
    $error = __stackBase__ + 4 | 0;
    $nbuf = __stackBase__ + 8 | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $call_data;
    $2 = $client_data + 32 | 0;
    $3 = $2;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $memory_0 = 0;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $4 + 16520 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $memory_0 = $8;
    label = 3;
    break;
   case 3:
    $10 = _memcmp($line | 0, 5323472, 7) | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 4;
      break;
    } else {
      label = 9;
      break;
    }
   case 4:
    $13 = $client_data + 36 | 0;
    $14 = $13;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15 + 8 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 57;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $20 = HEAP32[$3 >> 2] | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 57;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $23 = $linelen - 7 | 0;
    $24 = $line + 7 | 0;
    $25 = HEAP8[$24] | 0;
    $26 = $25 << 24 >> 24 == 0;
    if ($26) {
      $s_0 = $24;
      $_0 = $23;
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $28 = $line + 8 | 0;
    $29 = $linelen - 8 | 0;
    $s_0 = $28;
    $_0 = $29;
    label = 8;
    break;
   case 8:
    $31 = HEAP32[$3 >> 2] | 0;
    $32 = __bdf_add_comment($31, $s_0, $_0) | 0;
    HEAP32[$error >> 2] = $32;
    label = 57;
    break;
   case 9:
    $34 = $client_data;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $35 & 1;
    $37 = ($36 | 0) == 0;
    if ($37) {
      label = 10;
      break;
    } else {
      label = 19;
      break;
    }
   case 10:
    $39 = $client_data + 8248 | 0;
    $40 = $39;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = _memcmp($line | 0, 5323380, 9) | 0;
    $43 = ($42 | 0) == 0;
    if ($43) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    HEAP32[$error >> 2] = 176;
    label = 57;
    break;
   case 12:
    HEAP32[$34 >> 2] = 1;
    HEAP32[$3 >> 2] = 0;
    $46 = _ft_mem_alloc($41, 16548, $error) | 0;
    $47 = HEAP32[$error >> 2] | 0;
    $48 = ($47 | 0) == 0;
    if ($48) {
      label = 13;
      break;
    } else {
      label = 57;
      break;
    }
   case 13:
    $50 = $46;
    HEAP32[$3 >> 2] = $50;
    $51 = HEAP32[$40 >> 2] | 0;
    $52 = $46 + 16520 | 0;
    $53 = $52;
    HEAP32[$53 >> 2] = $51;
    HEAP32[$40 >> 2] = 0;
    $54 = $46 + 16532 | 0;
    $55 = $54;
    $56 = _hash_init($55, $41) | 0;
    HEAP32[$error >> 2] = $56;
    $57 = ($56 | 0) == 0;
    if ($57) {
      $i_0123 = 0;
      $prop_0124 = 5325428;
      label = 14;
      break;
    } else {
      label = 57;
      break;
    }
   case 14:
    $58 = $prop_0124 | 0;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = _hash_insert($59, $i_0123, $55, $41) | 0;
    HEAP32[$error >> 2] = $60;
    $61 = ($60 | 0) == 0;
    if ($61) {
      label = 15;
      break;
    } else {
      label = 57;
      break;
    }
   case 15:
    $63 = $i_0123 + 1 | 0;
    $64 = $prop_0124 + 16 | 0;
    $65 = $63 >>> 0 < 83;
    if ($65) {
      $i_0123 = $63;
      $prop_0124 = $64;
      label = 14;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $67 = _ft_mem_alloc($41, 16, $error) | 0;
    $68 = HEAP32[$3 >> 2] | 0;
    $69 = $68 + 128 | 0;
    HEAP32[$69 >> 2] = $67;
    $70 = HEAP32[$error >> 2] | 0;
    $71 = ($70 | 0) == 0;
    if ($71) {
      label = 17;
      break;
    } else {
      label = 57;
      break;
    }
   case 17:
    $73 = HEAP32[$3 >> 2] | 0;
    $74 = $73 + 128 | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    $76 = $75;
    $77 = _hash_init($76, $41) | 0;
    HEAP32[$error >> 2] = $77;
    $78 = ($77 | 0) == 0;
    if ($78) {
      label = 18;
      break;
    } else {
      label = 57;
      break;
    }
   case 18:
    $80 = $client_data + 36 | 0;
    $81 = $80;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = $82 + 12 | 0;
    $84 = HEAP32[$83 >> 2] | 0;
    $85 = HEAP32[$3 >> 2] | 0;
    $86 = $85 + 28 | 0;
    HEAP32[$86 >> 2] = $84;
    $87 = HEAP32[$3 >> 2] | 0;
    $88 = $87 + 36 | 0;
    HEAP32[$88 >> 2] = -1;
    label = 57;
    break;
   case 19:
    $90 = _memcmp($line | 0, 5323280, 15) | 0;
    $91 = ($90 | 0) == 0;
    if ($91) {
      label = 20;
      break;
    } else {
      label = 25;
      break;
    }
   case 20:
    $93 = $35 & 8;
    $94 = ($93 | 0) == 0;
    if ($94) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    HEAP32[$error >> 2] = 179;
    label = 57;
    break;
   case 22:
    $97 = $client_data + 8232 | 0;
    $98 = $97;
    $99 = __bdf_list_split($98, 5323180, $line, $linelen) | 0;
    HEAP32[$error >> 2] = $99;
    $100 = ($99 | 0) == 0;
    if ($100) {
      label = 23;
      break;
    } else {
      label = 57;
      break;
    }
   case 23:
    $102 = $97;
    $103 = HEAP32[$102 >> 2] | 0;
    $104 = $103 + 4 | 0;
    $105 = HEAP32[$104 >> 2] | 0;
    $106 = __bdf_atoul($105) | 0;
    $107 = HEAP32[$3 >> 2] | 0;
    $108 = $107 + 72 | 0;
    HEAP32[$108 >> 2] = $106;
    $109 = $client_data + 4 | 0;
    $110 = $109;
    HEAP32[$110 >> 2] = $106;
    $111 = _ft_mem_realloc($memory_0, 16, 0, $106, 0, $error) | 0;
    $112 = $111;
    $113 = HEAP32[$3 >> 2] | 0;
    $114 = $113 + 80 | 0;
    HEAP32[$114 >> 2] = $112;
    $115 = HEAP32[$error >> 2] | 0;
    $116 = ($115 | 0) == 0;
    if ($116) {
      label = 24;
      break;
    } else {
      label = 57;
      break;
    }
   case 24:
    $118 = HEAP32[$34 >> 2] | 0;
    $119 = $118 | 16;
    HEAP32[$34 >> 2] = $119;
    HEAP32[$1 >> 2] = 102;
    label = 57;
    break;
   case 25:
    $121 = _memcmp($line | 0, 5323108, 15) | 0;
    $122 = ($121 | 0) == 0;
    if ($122) {
      label = 26;
      break;
    } else {
      label = 30;
      break;
    }
   case 26:
    $124 = $35 & 4;
    $125 = ($124 | 0) == 0;
    if ($125) {
      label = 27;
      break;
    } else {
      label = 28;
      break;
    }
   case 27:
    HEAP32[$error >> 2] = 178;
    label = 57;
    break;
   case 28:
    $128 = $client_data + 8232 | 0;
    $129 = $128;
    $130 = __bdf_list_split($129, 5323180, $line, $linelen) | 0;
    HEAP32[$error >> 2] = $130;
    $131 = ($130 | 0) == 0;
    if ($131) {
      label = 29;
      break;
    } else {
      label = 57;
      break;
    }
   case 29:
    $133 = $128;
    $134 = HEAP32[$133 >> 2] | 0;
    $135 = $134 + 4 | 0;
    $136 = HEAP32[$135 >> 2] | 0;
    $137 = __bdf_atos($136) | 0;
    $138 = HEAP32[$3 >> 2] | 0;
    $139 = $138 + 4 | 0;
    HEAP16[$139 >> 1] = $137;
    $140 = HEAP32[$133 >> 2] | 0;
    $141 = $140 + 8 | 0;
    $142 = HEAP32[$141 >> 2] | 0;
    $143 = __bdf_atos($142) | 0;
    $144 = HEAP32[$3 >> 2] | 0;
    $145 = $144 + 6 | 0;
    HEAP16[$145 >> 1] = $143;
    $146 = HEAP32[$133 >> 2] | 0;
    $147 = $146 + 12 | 0;
    $148 = HEAP32[$147 >> 2] | 0;
    $149 = __bdf_atos($148) | 0;
    $150 = HEAP32[$3 >> 2] | 0;
    $151 = $150 + 8 | 0;
    HEAP16[$151 >> 1] = $149;
    $152 = HEAP32[$133 >> 2] | 0;
    $153 = $152 + 16 | 0;
    $154 = HEAP32[$153 >> 2] | 0;
    $155 = __bdf_atos($154) | 0;
    $156 = HEAP32[$3 >> 2] | 0;
    $157 = $156 + 10 | 0;
    HEAP16[$157 >> 1] = $155;
    $158 = HEAP32[$3 >> 2] | 0;
    $159 = $158 + 6 | 0;
    $160 = HEAP16[$159 >> 1] | 0;
    $161 = $158 + 10 | 0;
    $162 = HEAP16[$161 >> 1] | 0;
    $163 = $162 + $160 & 65535;
    $164 = $158 + 12 | 0;
    HEAP16[$164 >> 1] = $163;
    $165 = HEAP32[$3 >> 2] | 0;
    $166 = $165 + 10 | 0;
    $167 = HEAP16[$166 >> 1] | 0;
    $168 = -$167 & 65535;
    $169 = $165 + 14 | 0;
    HEAP16[$169 >> 1] = $168;
    $170 = HEAP32[$34 >> 2] | 0;
    $171 = $170 | 8;
    HEAP32[$34 >> 2] = $171;
    label = 57;
    break;
   case 30:
    $173 = _memcmp($line | 0, 5323024, 4) | 0;
    $174 = ($173 | 0) == 0;
    if ($174) {
      label = 31;
      break;
    } else {
      label = 37;
      break;
    }
   case 31:
    $176 = $client_data + 8232 | 0;
    $177 = $176;
    $178 = __bdf_list_split($177, 5323180, $line, $linelen) | 0;
    HEAP32[$error >> 2] = $178;
    $179 = ($178 | 0) == 0;
    if ($179) {
      label = 32;
      break;
    } else {
      label = 57;
      break;
    }
   case 32:
    __bdf_list_shift($177);
    $181 = __bdf_list_join($177, $slen) | 0;
    $182 = ($181 | 0) == 0;
    if ($182) {
      label = 33;
      break;
    } else {
      label = 34;
      break;
    }
   case 33:
    HEAP32[$error >> 2] = 3;
    label = 57;
    break;
   case 34:
    $185 = HEAP32[$3 >> 2] | 0;
    $186 = $185 | 0;
    $187 = HEAP32[$186 >> 2] | 0;
    _ft_mem_free($memory_0, $187);
    $188 = HEAP32[$3 >> 2] | 0;
    $189 = $188 | 0;
    HEAP32[$189 >> 2] = 0;
    $190 = HEAP32[$slen >> 2] | 0;
    $191 = $190 + 1 | 0;
    $192 = _ft_mem_realloc($memory_0, 1, 0, $191, 0, $error) | 0;
    $193 = HEAP32[$3 >> 2] | 0;
    $194 = $193 | 0;
    HEAP32[$194 >> 2] = $192;
    $195 = HEAP32[$error >> 2] | 0;
    $196 = ($195 | 0) == 0;
    if ($196) {
      label = 35;
      break;
    } else {
      label = 57;
      break;
    }
   case 35:
    $198 = HEAP32[$3 >> 2] | 0;
    $199 = $198 | 0;
    $200 = HEAP32[$199 >> 2] | 0;
    $201 = HEAP32[$slen >> 2] | 0;
    $202 = $201 + 1 | 0;
    _memcpy($200 | 0, $181 | 0, $202 | 0);
    $203 = HEAP32[$3 >> 2] | 0;
    $204 = $client_data + 36 | 0;
    $205 = $204;
    $206 = HEAP32[$205 >> 2] | 0;
    $207 = __bdf_set_default_spacing($203, $206) | 0;
    HEAP32[$error >> 2] = $207;
    $208 = ($207 | 0) == 0;
    if ($208) {
      label = 36;
      break;
    } else {
      label = 57;
      break;
    }
   case 36:
    $210 = HEAP32[$34 >> 2] | 0;
    $211 = $210 | 2;
    HEAP32[$34 >> 2] = $211;
    label = 57;
    break;
   case 37:
    $213 = _memcmp($line | 0, 5322956, 4) | 0;
    $214 = ($213 | 0) == 0;
    if ($214) {
      label = 38;
      break;
    } else {
      label = 50;
      break;
    }
   case 38:
    $216 = $35 & 2;
    $217 = ($216 | 0) == 0;
    if ($217) {
      label = 39;
      break;
    } else {
      label = 40;
      break;
    }
   case 39:
    HEAP32[$error >> 2] = 177;
    label = 57;
    break;
   case 40:
    $220 = $client_data + 8232 | 0;
    $221 = $220;
    $222 = __bdf_list_split($221, 5323180, $line, $linelen) | 0;
    HEAP32[$error >> 2] = $222;
    $223 = ($222 | 0) == 0;
    if ($223) {
      label = 41;
      break;
    } else {
      label = 57;
      break;
    }
   case 41:
    $225 = $220;
    $226 = HEAP32[$225 >> 2] | 0;
    $227 = $226 + 4 | 0;
    $228 = HEAP32[$227 >> 2] | 0;
    $229 = __bdf_atoul($228) | 0;
    $230 = HEAP32[$3 >> 2] | 0;
    $231 = $230 + 16 | 0;
    HEAP32[$231 >> 2] = $229;
    $232 = HEAP32[$225 >> 2] | 0;
    $233 = $232 + 8 | 0;
    $234 = HEAP32[$233 >> 2] | 0;
    $235 = __bdf_atoul($234) | 0;
    $236 = HEAP32[$3 >> 2] | 0;
    $237 = $236 + 20 | 0;
    HEAP32[$237 >> 2] = $235;
    $238 = HEAP32[$225 >> 2] | 0;
    $239 = $238 + 12 | 0;
    $240 = HEAP32[$239 >> 2] | 0;
    $241 = __bdf_atoul($240) | 0;
    $242 = HEAP32[$3 >> 2] | 0;
    $243 = $242 + 24 | 0;
    HEAP32[$243 >> 2] = $241;
    $244 = $client_data + 8240 | 0;
    $245 = $244;
    $246 = HEAP32[$245 >> 2] | 0;
    $247 = ($246 | 0) == 5;
    if ($247) {
      label = 42;
      break;
    } else {
      label = 48;
      break;
    }
   case 42:
    $249 = HEAP32[$225 >> 2] | 0;
    $250 = $249 + 16 | 0;
    $251 = HEAP32[$250 >> 2] | 0;
    $252 = __bdf_atos($251) | 0;
    $253 = HEAP32[$3 >> 2] | 0;
    $254 = $253 + 16518 | 0;
    HEAP16[$254 >> 1] = $252;
    $255 = HEAP32[$3 >> 2] | 0;
    $256 = $255 + 16518 | 0;
    $257 = HEAP16[$256 >> 1] | 0;
    $258 = $257 << 16 >> 16 == 0;
    if ($258) {
      $bitcount_0_lcssa128 = 0;
      label = 45;
      break;
    } else {
      $bitcount_0125 = 0;
      $i1_0126 = 0;
      $shift_0127 = $257;
      label = 43;
      break;
    }
   case 43:
    $259 = $shift_0127 & 1;
    $260 = $259 << 16 >> 16 == 0;
    $bitcount_0_i1_0 = $260 ? $bitcount_0125 : $i1_0126;
    $261 = ($shift_0127 & 65535) >>> 1;
    $262 = $i1_0126 + 1 & 65535;
    $263 = $261 << 16 >> 16 == 0;
    if ($263) {
      label = 44;
      break;
    } else {
      $bitcount_0125 = $bitcount_0_i1_0;
      $i1_0126 = $262;
      $shift_0127 = $261;
      label = 43;
      break;
    }
   case 44:
    $264 = ($bitcount_0_i1_0 & 65535) > 3;
    if ($264) {
      $268 = 8;
      label = 46;
      break;
    } else {
      $bitcount_0_lcssa128 = $bitcount_0_i1_0;
      label = 45;
      break;
    }
   case 45:
    $265 = $bitcount_0_lcssa128 & 65535;
    $266 = 1 << $265;
    $phitmp122 = $266 & 65535;
    $268 = $phitmp122;
    label = 46;
    break;
   case 46:
    $269 = HEAP32[$3 >> 2] | 0;
    $270 = $269 + 16518 | 0;
    $271 = HEAP16[$270 >> 1] | 0;
    $272 = $271 & 65535;
    $273 = ($272 | 0) == ($268 | 0);
    if ($273) {
      label = 49;
      break;
    } else {
      label = 47;
      break;
    }
   case 47:
    $275 = $268 << 1;
    $276 = $275 & 65535;
    HEAP16[$270 >> 1] = $276;
    label = 49;
    break;
   case 48:
    $278 = HEAP32[$3 >> 2] | 0;
    $279 = $278 + 16518 | 0;
    HEAP16[$279 >> 1] = 1;
    label = 49;
    break;
   case 49:
    $281 = HEAP32[$34 >> 2] | 0;
    $282 = $281 | 4;
    HEAP32[$34 >> 2] = $282;
    label = 57;
    break;
   case 50:
    $284 = _memcmp($line | 0, 5322884, 5) | 0;
    $285 = ($284 | 0) == 0;
    if ($285) {
      label = 51;
      break;
    } else {
      label = 56;
      break;
    }
   case 51:
    $287 = $35 & 8;
    $288 = ($287 | 0) == 0;
    if ($288) {
      label = 52;
      break;
    } else {
      label = 53;
      break;
    }
   case 52:
    HEAP32[$error >> 2] = 179;
    label = 57;
    break;
   case 53:
    $291 = HEAP32[$3 >> 2] | 0;
    $292 = $291 + 12 | 0;
    $293 = HEAP16[$292 >> 1] | 0;
    $294 = $293 << 16 >> 16;
    $295 = $291 + 40 | 0;
    HEAP32[$295 >> 2] = $294;
    $296 = $nbuf | 0;
    $297 = HEAP32[$3 >> 2] | 0;
    $298 = $297 + 12 | 0;
    $299 = HEAP16[$298 >> 1] | 0;
    $300 = $299 << 16 >> 16;
    $301 = _sprintf($296 | 0, 5322816, (tempInt = STACKTOP, STACKTOP = STACKTOP + 4 | 0, HEAP32[tempInt >> 2] = $300, tempInt) | 0) | 0;
    $302 = HEAP32[$3 >> 2] | 0;
    $303 = __bdf_add_property($302, 5322732, $296) | 0;
    HEAP32[$error >> 2] = $303;
    $304 = ($303 | 0) == 0;
    if ($304) {
      label = 54;
      break;
    } else {
      label = 57;
      break;
    }
   case 54:
    $306 = HEAP32[$3 >> 2] | 0;
    $307 = $306 + 14 | 0;
    $308 = HEAP16[$307 >> 1] | 0;
    $309 = $308 << 16 >> 16;
    $310 = $306 + 44 | 0;
    HEAP32[$310 >> 2] = $309;
    $311 = HEAP32[$3 >> 2] | 0;
    $312 = $311 + 14 | 0;
    $313 = HEAP16[$312 >> 1] | 0;
    $314 = $313 << 16 >> 16;
    $315 = _sprintf($296 | 0, 5322816, (tempInt = STACKTOP, STACKTOP = STACKTOP + 4 | 0, HEAP32[tempInt >> 2] = $314, tempInt) | 0) | 0;
    $316 = HEAP32[$3 >> 2] | 0;
    $317 = __bdf_add_property($316, 5322636, $296) | 0;
    HEAP32[$error >> 2] = $317;
    $318 = ($317 | 0) == 0;
    if ($318) {
      label = 55;
      break;
    } else {
      label = 57;
      break;
    }
   case 55:
    $320 = HEAP32[$3 >> 2] | 0;
    $321 = $320 + 16516 | 0;
    HEAP16[$321 >> 1] = 1;
    HEAP32[$1 >> 2] = 112;
    HEAP32[$error >> 2] = -1;
    label = 57;
    break;
   case 56:
    HEAP32[$error >> 2] = 3;
    label = 57;
    break;
   case 57:
    $323 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $323 | 0;
  }
  return 0;
}
function __bdf_list_done($list) {
  $list = $list | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $list + 12 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $list | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6;
    _ft_mem_free($2, $7);
    $8 = $list;
    _memset($8 | 0, 0, 16);
    label = 3;
    break;
   case 3:
    return;
  }
}
function __bdf_add_comment($font, $comment, $len) {
  $font = $font | 0;
  $comment = $comment | 0;
  $len = $len | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $_sum = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $font + 16520 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $3 = $font + 88 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $len + 1 | 0;
    $6 = $5 + $4 | 0;
    $7 = $font + 84 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = _ft_mem_realloc($2, 1, $4, $6, $8, $error) | 0;
    HEAP32[$7 >> 2] = $9;
    $10 = HEAP32[$error >> 2] | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $13 = HEAP32[$3 >> 2] | 0;
    $14 = $9 + $13 | 0;
    _memcpy($14 | 0, $comment | 0, $len | 0);
    $_sum = $13 + $len | 0;
    $15 = $9 + $_sum | 0;
    HEAP8[$15] = 10;
    $16 = $len + 1 | 0;
    $17 = HEAP32[$3 >> 2] | 0;
    $18 = $16 + $17 | 0;
    HEAP32[$3 >> 2] = $18;
    label = 3;
    break;
   case 3:
    $20 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $20 | 0;
  }
  return 0;
}
function _hash_init($ht, $memory) {
  $ht = $ht | 0;
  $memory = $memory | 0;
  var $error = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  $error = __stackBase__ | 0;
  HEAP32[$error >> 2] = 0;
  HEAP32[$ht + 4 >> 2] = 241;
  HEAP32[$ht >> 2] = 80;
  HEAP32[$ht + 8 >> 2] = 0;
  HEAP32[$ht + 12 >> 2] = _ft_mem_realloc($memory, 4, 0, 241, 0, $error) | 0;
  STACKTOP = __stackBase__;
  return HEAP32[$error >> 2] | 0;
}
function _hash_insert($key, $data, $ht, $memory) {
  $key = $key | 0;
  $data = $data | 0;
  $ht = $ht | 0;
  $memory = $memory | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = _hash_bucket($key, $ht) | 0;
    HEAP32[$error >> 2] = 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $5 = _ft_mem_alloc($memory, 8, $error) | 0;
    $6 = HEAP32[$error >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 3;
      break;
    } else {
      label = 7;
      break;
    }
   case 3:
    $9 = $5;
    HEAP32[$1 >> 2] = $9;
    $10 = $5;
    HEAP32[$10 >> 2] = $key;
    $11 = $5 + 4 | 0;
    $12 = $11;
    HEAP32[$12 >> 2] = $data;
    $13 = $ht + 8 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $ht | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($14 | 0) < ($16 | 0);
    if ($17) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $19 = _hash_rehash($ht, $memory) | 0;
    HEAP32[$error >> 2] = $19;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    $22 = HEAP32[$13 >> 2] | 0;
    $23 = $22 + 1 | 0;
    HEAP32[$13 >> 2] = $23;
    label = 7;
    break;
   case 6:
    $25 = $2 + 4 | 0;
    HEAP32[$25 >> 2] = $data;
    label = 7;
    break;
   case 7:
    $27 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $27 | 0;
  }
  return 0;
}
function __bdf_atoul($s) {
  $s = $s | 0;
  var $1 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0, $_018 = 0, $_1 = 0, $dmap_1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $v_02 = 0, $_1191 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $_017 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($s | 0) == 0;
    if ($1) {
      $_017 = 0;
      label = 7;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = HEAP8[$s] | 0;
    if (($3 << 24 >> 24 | 0) == 48) {
      label = 3;
      break;
    } else if (($3 << 24 >> 24 | 0) == 0) {
      $_017 = 0;
      label = 7;
      break;
    } else {
      $dmap_1 = 5312056;
      $_1 = 10;
      $_018 = $s;
      label = 5;
      break;
    }
   case 3:
    $5 = $s + 1 | 0;
    $6 = HEAP8[$5] | 0;
    if (($6 << 24 >> 24 | 0) == 120 | ($6 << 24 >> 24 | 0) == 88) {
      label = 4;
      break;
    } else {
      $dmap_1 = 5312056;
      $_1 = 10;
      $_018 = $s;
      label = 5;
      break;
    }
   case 4:
    $8 = $s + 2 | 0;
    $dmap_1 = 5251316;
    $_1 = 16;
    $_018 = $8;
    label = 5;
    break;
   case 5:
    $10 = HEAP8[$_018] | 0;
    $11 = $10 << 24 >> 24;
    $12 = $11 >> 3;
    $13 = $dmap_1 + $12 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 & 255;
    $16 = $11 & 7;
    $17 = 1 << $16;
    $18 = $17 & $15;
    $19 = ($18 | 0) == 0;
    if ($19) {
      $_017 = 0;
      label = 7;
      break;
    } else {
      $_1191 = $_018;
      $v_02 = 0;
      $20 = $11;
      label = 6;
      break;
    }
   case 6:
    $21 = Math_imul($v_02, $_1);
    $22 = $20 + 5319020 | 0;
    $23 = HEAP8[$22] | 0;
    $24 = $23 & 255;
    $25 = $24 + $21 | 0;
    $26 = $_1191 + 1 | 0;
    $27 = HEAP8[$26] | 0;
    $28 = $27 << 24 >> 24;
    $29 = $28 >> 3;
    $30 = $dmap_1 + $29 | 0;
    $31 = HEAP8[$30] | 0;
    $32 = $31 & 255;
    $33 = $28 & 7;
    $34 = 1 << $33;
    $35 = $34 & $32;
    $36 = ($35 | 0) == 0;
    if ($36) {
      $_017 = $25;
      label = 7;
      break;
    } else {
      $_1191 = $26;
      $v_02 = $25;
      $20 = $28;
      label = 6;
      break;
    }
   case 7:
    return $_017 | 0;
  }
  return 0;
}
function __bdf_atos($s) {
  $s = $s | 0;
  var $1 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $_s = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $14 = 0, $_121 = 0, $_1 = 0, $dmap_1 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $v_02 = 0, $_21 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $sext = 0, $phitmp = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $v_0_lcssa = 0, $43 = 0, $44 = 0, $45 = 0, $_019 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($s | 0) == 0;
    if ($1) {
      $_019 = 0;
      label = 9;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = HEAP8[$s] | 0;
    $4 = $3 << 24 >> 24 == 0;
    if ($4) {
      $_019 = 0;
      label = 9;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $6 = $3 << 24 >> 24 == 45;
    $7 = $s + 1 | 0;
    $_s = $6 ? $7 : $s;
    $8 = HEAP8[$_s] | 0;
    $9 = $8 << 24 >> 24 == 48;
    if ($9) {
      label = 4;
      break;
    } else {
      $dmap_1 = 5312056;
      $_1 = 10;
      $_121 = $_s;
      label = 6;
      break;
    }
   case 4:
    $11 = $_s + 1 | 0;
    $12 = HEAP8[$11] | 0;
    if (($12 << 24 >> 24 | 0) == 120 | ($12 << 24 >> 24 | 0) == 88) {
      label = 5;
      break;
    } else {
      $dmap_1 = 5312056;
      $_1 = 10;
      $_121 = $_s;
      label = 6;
      break;
    }
   case 5:
    $14 = $_s + 2 | 0;
    $dmap_1 = 5251316;
    $_1 = 16;
    $_121 = $14;
    label = 6;
    break;
   case 6:
    $16 = HEAP8[$_121] | 0;
    $17 = $16 << 24 >> 24;
    $18 = $17 >> 3;
    $19 = $dmap_1 + $18 | 0;
    $20 = HEAP8[$19] | 0;
    $21 = $20 & 255;
    $22 = $17 & 7;
    $23 = 1 << $22;
    $24 = $23 & $21;
    $25 = ($24 | 0) == 0;
    if ($25) {
      $v_0_lcssa = 0;
      label = 8;
      break;
    } else {
      $_21 = $_121;
      $v_02 = 0;
      $26 = $17;
      label = 7;
      break;
    }
   case 7:
    $27 = Math_imul($v_02, $_1);
    $28 = $26 + 5319020 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $29 & 255;
    $31 = $30 + $27 | 0;
    $32 = $_21 + 1 | 0;
    $sext = $31 << 16;
    $phitmp = $sext >> 16;
    $33 = HEAP8[$32] | 0;
    $34 = $33 << 24 >> 24;
    $35 = $34 >> 3;
    $36 = $dmap_1 + $35 | 0;
    $37 = HEAP8[$36] | 0;
    $38 = $37 & 255;
    $39 = $34 & 7;
    $40 = 1 << $39;
    $41 = $40 & $38;
    $42 = ($41 | 0) == 0;
    if ($42) {
      $v_0_lcssa = $phitmp;
      label = 8;
      break;
    } else {
      $_21 = $32;
      $v_02 = $phitmp;
      $26 = $34;
      label = 7;
      break;
    }
   case 8:
    $43 = -$v_0_lcssa | 0;
    $44 = $6 ? $43 : $v_0_lcssa;
    $45 = $44 & 65535;
    $_019 = $45;
    label = 9;
    break;
   case 9:
    return $_019 | 0;
  }
  return 0;
}
function __bdf_list_shift($list) {
  $list = $list | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $u_02 = 0, $i_01 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $_lcssa = 0, $21 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($list | 0) == 0;
    if ($1) {
      label = 9;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $list + 8 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 9;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $4 >>> 0 < 2;
    if ($7) {
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $8 = HEAP32[$3 >> 2] | 0;
    $9 = $8 >>> 0 > 1;
    if ($9) {
      label = 5;
      break;
    } else {
      $_lcssa = $8;
      label = 8;
      break;
    }
   case 5:
    $10 = $list | 0;
    $i_01 = 0;
    $u_02 = 1;
    label = 7;
    break;
   case 6:
    HEAP32[$3 >> 2] = 0;
    label = 9;
    break;
   case 7:
    $13 = HEAP32[$10 >> 2] | 0;
    $14 = $13 + ($u_02 << 2) | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $13 + ($i_01 << 2) | 0;
    HEAP32[$16 >> 2] = $15;
    $17 = $i_01 + 1 | 0;
    $18 = $u_02 + 1 | 0;
    $19 = HEAP32[$3 >> 2] | 0;
    $20 = $18 >>> 0 < $19 >>> 0;
    if ($20) {
      $i_01 = $17;
      $u_02 = $18;
      label = 7;
      break;
    } else {
      $_lcssa = $19;
      label = 8;
      break;
    }
   case 8:
    $21 = $_lcssa - 1 | 0;
    HEAP32[$3 >> 2] = $21;
    label = 9;
    break;
   case 9:
    return;
  }
}
function __bdf_list_join($list, $alen) {
  $list = $list | 0;
  $alen = $alen | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $j_04 = 0, $i_03 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $fp_02 = 0, $j_11 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $j_1_lcssa = 0, $23 = 0, $24 = 0, $25 = 0, $j_0_be = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $j_0_lcssa = 0, $31 = 0, $33 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    HEAP32[$alen >> 2] = 0;
    $1 = ($list | 0) == 0;
    if ($1) {
      $_0 = 0;
      label = 12;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $list + 8 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $_0 = 0;
      label = 12;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $list | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = HEAP32[$3 >> 2] | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      $j_0_lcssa = 0;
      label = 9;
      break;
    } else {
      $i_03 = 0;
      $j_04 = 0;
      label = 4;
      break;
    }
   case 4:
    $12 = HEAP32[$7 >> 2] | 0;
    $13 = $12 + ($i_03 << 2) | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = HEAP8[$14] | 0;
    $16 = $15 << 24 >> 24 == 0;
    if ($16) {
      $j_1_lcssa = $j_04;
      label = 6;
      break;
    } else {
      $j_11 = $j_04;
      $fp_02 = $14;
      $17 = $15;
      label = 5;
      break;
    }
   case 5:
    $18 = $fp_02 + 1 | 0;
    $19 = $j_11 + 1 | 0;
    $20 = $9 + $j_11 | 0;
    HEAP8[$20] = $17;
    $21 = HEAP8[$18] | 0;
    $22 = $21 << 24 >> 24 == 0;
    if ($22) {
      $j_1_lcssa = $19;
      label = 6;
      break;
    } else {
      $j_11 = $19;
      $fp_02 = $18;
      $17 = $21;
      label = 5;
      break;
    }
   case 6:
    $23 = $i_03 + 1 | 0;
    $24 = HEAP32[$3 >> 2] | 0;
    $25 = $23 >>> 0 < $24 >>> 0;
    if ($25) {
      label = 8;
      break;
    } else {
      $j_0_be = $j_1_lcssa;
      label = 7;
      break;
    }
   case 7:
    $26 = HEAP32[$3 >> 2] | 0;
    $27 = $23 >>> 0 < $26 >>> 0;
    if ($27) {
      $i_03 = $23;
      $j_04 = $j_0_be;
      label = 4;
      break;
    } else {
      $j_0_lcssa = $j_0_be;
      label = 9;
      break;
    }
   case 8:
    $29 = $j_1_lcssa + 1 | 0;
    $30 = $9 + $j_1_lcssa | 0;
    HEAP8[$30] = 32;
    $j_0_be = $29;
    label = 7;
    break;
   case 9:
    $31 = ($9 | 0) == 5312052;
    if ($31) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $33 = $9 + $j_0_lcssa | 0;
    HEAP8[$33] = 0;
    label = 11;
    break;
   case 11:
    HEAP32[$alen >> 2] = $j_0_lcssa;
    $_0 = $9;
    label = 12;
    break;
   case 12:
    return $_0 | 0;
  }
  return 0;
}
function __bdf_list_split($list, $separators, $line, $linelen) {
  $list = $list | 0;
  $separators = $separators | 0;
  $line = $line | 0;
  $linelen = $linelen | 0;
  var $seps = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $mult_068 = 0, $sp_066 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $mult_1 = 0, $30 = 0, $31 = 0, $mult_0_lcssa = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $sp_163 = 0, $final_empty_062 = 0, $38 = 0, $39 = 0, $ep_1 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $ep_260 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $82 = 0, $84 = 0, $ep_2_lcssa = 0, $85 = 0, $ep_356 = 0, $87 = 0, $88 = 0, $ep_357 = 0, $89 = 0, $90 = 0, $91 = 0, $final_empty_0_lcssa = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $98 = 0, $99 = 0, $100 = 0, $102 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $error_3 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 32 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $seps = __stackBase__ | 0;
    $1 = $list + 8 | 0;
    HEAP32[$1 >> 2] = 0;
    $2 = ($linelen | 0) == 0;
    if ($2) {
      $error_3 = 0;
      label = 31;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = HEAP8[$line] | 0;
    $5 = $4 << 24 >> 24 == 0;
    if ($5) {
      $error_3 = 0;
      label = 31;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = ($separators | 0) == 0;
    if ($7) {
      $error_3 = 6;
      label = 31;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $9 = HEAP8[$separators] | 0;
    $10 = $9 << 24 >> 24 == 0;
    if ($10) {
      $error_3 = 6;
      label = 31;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $11 = $seps | 0;
    _memset($11 | 0, 0, 32);
    $sp_066 = $separators;
    $mult_068 = 0;
    label = 6;
    break;
   case 6:
    $13 = HEAP8[$sp_066] | 0;
    if (($13 << 24 >> 24 | 0) == 43) {
      label = 7;
      break;
    } else if (($13 << 24 >> 24 | 0) == 0) {
      $mult_0_lcssa = $mult_068;
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $15 = $sp_066 + 1 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 << 24 >> 24 == 0;
    if ($17) {
      $mult_1 = 1;
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $19 = HEAP8[$sp_066] | 0;
    $20 = $19 & 255;
    $21 = $20 & 7;
    $22 = 1 << $21;
    $23 = $20 >>> 3;
    $24 = $seps + $23 | 0;
    $25 = HEAP8[$24] | 0;
    $26 = $25 & 255;
    $27 = $22 | $26;
    $28 = $27 & 255;
    HEAP8[$24] = $28;
    $mult_1 = $mult_068;
    label = 9;
    break;
   case 9:
    $30 = $sp_066 + 1 | 0;
    $31 = ($30 | 0) == 0;
    if ($31) {
      $mult_0_lcssa = $mult_1;
      label = 10;
      break;
    } else {
      $sp_066 = $30;
      $mult_068 = $mult_1;
      label = 6;
      break;
    }
   case 10:
    $32 = $line + $linelen | 0;
    $33 = ($linelen | 0) > 0;
    if ($33) {
      label = 11;
      break;
    } else {
      $final_empty_0_lcssa = 0;
      label = 26;
      break;
    }
   case 11:
    $34 = $list + 4 | 0;
    $35 = $list | 0;
    $36 = ($mult_0_lcssa | 0) == 0;
    $final_empty_062 = 0;
    $sp_163 = $line;
    label = 12;
    break;
   case 12:
    $38 = HEAP8[$sp_163] | 0;
    $39 = $38 << 24 >> 24 == 0;
    if ($39) {
      $final_empty_0_lcssa = $final_empty_062;
      label = 26;
      break;
    } else {
      $ep_1 = $sp_163;
      label = 13;
      break;
    }
   case 13:
    $40 = HEAP8[$ep_1] | 0;
    $41 = $40 << 24 >> 24 == 0;
    if ($41) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $43 = $40 & 255;
    $44 = $43 >>> 3;
    $45 = $seps + $44 | 0;
    $46 = HEAP8[$45] | 0;
    $47 = $46 << 24 >> 24;
    $48 = $43 & 7;
    $49 = 1 << $48;
    $50 = $47 & $49;
    $51 = ($50 | 0) == 0;
    $52 = $ep_1 + 1 | 0;
    if ($51) {
      $ep_1 = $52;
      label = 13;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $53 = HEAP32[$1 >> 2] | 0;
    $54 = HEAP32[$34 >> 2] | 0;
    $55 = ($53 | 0) == ($54 | 0);
    if ($55) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    $57 = $53 + 1 | 0;
    $58 = __bdf_list_ensure($list, $57) | 0;
    $59 = ($58 | 0) == 0;
    if ($59) {
      label = 17;
      break;
    } else {
      $error_3 = $58;
      label = 31;
      break;
    }
   case 17:
    $61 = $ep_1 >>> 0 > $sp_163 >>> 0;
    $62 = $61 ? $sp_163 : 5312052;
    $63 = HEAP32[$1 >> 2] | 0;
    $64 = $63 + 1 | 0;
    HEAP32[$1 >> 2] = $64;
    $65 = HEAP32[$35 >> 2] | 0;
    $66 = $65 + ($63 << 2) | 0;
    HEAP32[$66 >> 2] = $62;
    $67 = HEAP8[$ep_1] | 0;
    $68 = $67 << 24 >> 24 == 0;
    if ($36) {
      label = 21;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    if ($68) {
      $89 = 0;
      $ep_357 = $ep_1;
      label = 25;
      break;
    } else {
      $ep_260 = $ep_1;
      $69 = $67;
      label = 19;
      break;
    }
   case 19:
    $70 = $69 & 255;
    $71 = $70 >>> 3;
    $72 = $seps + $71 | 0;
    $73 = HEAP8[$72] | 0;
    $74 = $73 << 24 >> 24;
    $75 = $70 & 7;
    $76 = 1 << $75;
    $77 = $74 & $76;
    $78 = ($77 | 0) == 0;
    if ($78) {
      $ep_2_lcssa = $ep_260;
      label = 23;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    HEAP8[$ep_260] = 0;
    $80 = $ep_260 + 1 | 0;
    $81 = HEAP8[$80] | 0;
    $82 = $81 << 24 >> 24 == 0;
    if ($82) {
      $ep_2_lcssa = $80;
      label = 23;
      break;
    } else {
      $ep_260 = $80;
      $69 = $81;
      label = 19;
      break;
    }
   case 21:
    if ($68) {
      $89 = 0;
      $ep_357 = $ep_1;
      label = 25;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $84 = $ep_1 + 1 | 0;
    HEAP8[$ep_1] = 0;
    $ep_356 = $84;
    label = 24;
    break;
   case 23:
    $85 = $ep_2_lcssa >>> 0 > $ep_1 >>> 0;
    if ($85) {
      $ep_356 = $ep_2_lcssa;
      label = 24;
      break;
    } else {
      $89 = 0;
      $ep_357 = $ep_2_lcssa;
      label = 25;
      break;
    }
   case 24:
    $87 = HEAP8[$ep_356] | 0;
    $88 = $87 << 24 >> 24 == 0;
    $89 = $88;
    $ep_357 = $ep_356;
    label = 25;
    break;
   case 25:
    $90 = $89 & 1;
    $91 = $ep_357 >>> 0 < $32 >>> 0;
    if ($91) {
      $final_empty_062 = $90;
      $sp_163 = $ep_357;
      label = 12;
      break;
    } else {
      $final_empty_0_lcssa = $90;
      label = 26;
      break;
    }
   case 26:
    $92 = HEAP32[$1 >> 2] | 0;
    $93 = $92 + $final_empty_0_lcssa | 0;
    $94 = $list + 4 | 0;
    $95 = HEAP32[$94 >> 2] | 0;
    $96 = $93 >>> 0 < $95 >>> 0;
    if ($96) {
      label = 28;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $98 = $93 + 1 | 0;
    $99 = __bdf_list_ensure($list, $98) | 0;
    $100 = ($99 | 0) == 0;
    if ($100) {
      label = 28;
      break;
    } else {
      $error_3 = $99;
      label = 31;
      break;
    }
   case 28:
    $102 = ($final_empty_0_lcssa | 0) == 0;
    if ($102) {
      label = 30;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    $104 = HEAP32[$1 >> 2] | 0;
    $105 = $104 + 1 | 0;
    HEAP32[$1 >> 2] = $105;
    $106 = $list | 0;
    $107 = HEAP32[$106 >> 2] | 0;
    $108 = $107 + ($104 << 2) | 0;
    HEAP32[$108 >> 2] = 5312052;
    label = 30;
    break;
   case 30:
    $110 = HEAP32[$1 >> 2] | 0;
    $111 = $list | 0;
    $112 = HEAP32[$111 >> 2] | 0;
    $113 = $112 + ($110 << 2) | 0;
    HEAP32[$113 >> 2] = 0;
    $error_3 = 0;
    label = 31;
    break;
   case 31:
    STACKTOP = __stackBase__;
    return $error_3 | 0;
  }
  return 0;
}
function __bdf_parse_properties($line, $linelen, $lineno, $call_data, $client_data) {
  $line = $line | 0;
  $linelen = $linelen | 0;
  $lineno = $lineno | 0;
  $call_data = $call_data | 0;
  $client_data = $client_data | 0;
  var $vlen = 0, $name = 0, $value = 0, $nbuf = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $error_2 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 140 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $vlen = __stackBase__ | 0;
    $name = __stackBase__ + 4 | 0;
    $value = __stackBase__ + 8 | 0;
    $nbuf = __stackBase__ + 12 | 0;
    $1 = $call_data;
    $2 = _memcmp($line | 0, 5321912, 13) | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 9;
      break;
    }
   case 2:
    $5 = $client_data + 32 | 0;
    $6 = $5;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = _bdf_get_font_property($7, 5322732) | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $11 = $7 + 12 | 0;
    $12 = HEAP16[$11 >> 1] | 0;
    $13 = $12 << 16 >> 16;
    $14 = $7 + 40 | 0;
    HEAP32[$14 >> 2] = $13;
    $15 = $nbuf | 0;
    $16 = HEAP32[$6 >> 2] | 0;
    $17 = $16 + 12 | 0;
    $18 = HEAP16[$17 >> 1] | 0;
    $19 = $18 << 16 >> 16;
    $20 = _sprintf($15 | 0, 5322816, (tempInt = STACKTOP, STACKTOP = STACKTOP + 4 | 0, HEAP32[tempInt >> 2] = $19, tempInt) | 0) | 0;
    $21 = HEAP32[$6 >> 2] | 0;
    $22 = __bdf_add_property($21, 5322732, $15) | 0;
    $23 = ($22 | 0) == 0;
    if ($23) {
      label = 4;
      break;
    } else {
      $error_2 = $22;
      label = 18;
      break;
    }
   case 4:
    $25 = HEAP32[$6 >> 2] | 0;
    $26 = $25 + 16516 | 0;
    HEAP16[$26 >> 1] = 1;
    label = 5;
    break;
   case 5:
    $28 = HEAP32[$6 >> 2] | 0;
    $29 = _bdf_get_font_property($28, 5322636) | 0;
    $30 = ($29 | 0) == 0;
    if ($30) {
      label = 6;
      break;
    } else {
      label = 8;
      break;
    }
   case 6:
    $32 = $28 + 14 | 0;
    $33 = HEAP16[$32 >> 1] | 0;
    $34 = $33 << 16 >> 16;
    $35 = $28 + 44 | 0;
    HEAP32[$35 >> 2] = $34;
    $36 = $nbuf | 0;
    $37 = HEAP32[$6 >> 2] | 0;
    $38 = $37 + 14 | 0;
    $39 = HEAP16[$38 >> 1] | 0;
    $40 = $39 << 16 >> 16;
    $41 = _sprintf($36 | 0, 5322816, (tempInt = STACKTOP, STACKTOP = STACKTOP + 4 | 0, HEAP32[tempInt >> 2] = $40, tempInt) | 0) | 0;
    $42 = HEAP32[$6 >> 2] | 0;
    $43 = __bdf_add_property($42, 5322636, $36) | 0;
    $44 = ($43 | 0) == 0;
    if ($44) {
      label = 7;
      break;
    } else {
      $error_2 = $43;
      label = 18;
      break;
    }
   case 7:
    $46 = HEAP32[$6 >> 2] | 0;
    $47 = $46 + 16516 | 0;
    HEAP16[$47 >> 1] = 1;
    label = 8;
    break;
   case 8:
    $49 = $client_data;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $50 & -17;
    HEAP32[$49 >> 2] = $51;
    HEAP32[$1 >> 2] = 112;
    $error_2 = 0;
    label = 18;
    break;
   case 9:
    $53 = _memcmp($line | 0, 5321836, 21) | 0;
    $54 = ($53 | 0) == 0;
    if ($54) {
      $error_2 = 0;
      label = 18;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $56 = _memcmp($line | 0, 5323472, 7) | 0;
    $57 = ($56 | 0) == 0;
    if ($57) {
      label = 11;
      break;
    } else {
      label = 14;
      break;
    }
   case 11:
    HEAP32[$name >> 2] = $line;
    $59 = $line + 7 | 0;
    HEAP32[$value >> 2] = $59;
    $60 = HEAP8[$59] | 0;
    $61 = $60 << 24 >> 24 == 0;
    if ($61) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $63 = $line + 8 | 0;
    HEAP32[$value >> 2] = $63;
    HEAP8[$59] = 0;
    label = 13;
    break;
   case 13:
    $65 = $client_data + 32 | 0;
    $66 = $65;
    $67 = HEAP32[$66 >> 2] | 0;
    $68 = HEAP32[$name >> 2] | 0;
    $69 = HEAP32[$value >> 2] | 0;
    $70 = __bdf_add_property($67, $68, $69) | 0;
    $error_2 = $70;
    label = 18;
    break;
   case 14:
    $72 = $client_data + 32 | 0;
    $73 = $72;
    $74 = HEAP32[$73 >> 2] | 0;
    $75 = __bdf_is_atom($line, $linelen, $name, $value, $74) | 0;
    $76 = ($75 | 0) == 0;
    if ($76) {
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $78 = HEAP32[$73 >> 2] | 0;
    $79 = HEAP32[$name >> 2] | 0;
    $80 = HEAP32[$value >> 2] | 0;
    $81 = __bdf_add_property($78, $79, $80) | 0;
    $error_2 = $81;
    label = 18;
    break;
   case 16:
    $83 = $client_data + 8232 | 0;
    $84 = $83;
    $85 = __bdf_list_split($84, 5323180, $line, $linelen) | 0;
    $86 = ($85 | 0) == 0;
    if ($86) {
      label = 17;
      break;
    } else {
      $error_2 = $85;
      label = 18;
      break;
    }
   case 17:
    $88 = $83;
    $89 = HEAP32[$88 >> 2] | 0;
    $90 = HEAP32[$89 >> 2] | 0;
    HEAP32[$name >> 2] = $90;
    __bdf_list_shift($84);
    $91 = __bdf_list_join($84, $vlen) | 0;
    HEAP32[$value >> 2] = $91;
    $92 = HEAP32[$73 >> 2] | 0;
    $93 = HEAP32[$name >> 2] | 0;
    $94 = __bdf_add_property($92, $93, $91) | 0;
    $error_2 = $94;
    label = 18;
    break;
   case 18:
    STACKTOP = __stackBase__;
    return $error_2 | 0;
  }
  return 0;
}
function __bdf_set_default_spacing($font, $opts) {
  $font = $font | 0;
  $opts = $opts | 0;
  var $name = 0, $list = 0, $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 272 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $name = __stackBase__ | 0;
    $list = __stackBase__ + 256 | 0;
    $1 = ($font | 0) == 0;
    if ($1) {
      $error_0 = 6;
      label = 12;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $font | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $error_0 = 6;
      label = 12;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = HEAP8[$4] | 0;
    $8 = $7 << 24 >> 24 == 0;
    if ($8) {
      $error_0 = 6;
      label = 12;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $10 = $font + 16520 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    __bdf_list_init($list, $11);
    $12 = $opts + 12 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $font + 28 | 0;
    HEAP32[$14 >> 2] = $13;
    $15 = HEAP32[$3 >> 2] | 0;
    $16 = _strlen($15 | 0) | 0;
    $17 = $16 + 1 | 0;
    $18 = $17 >>> 0 > 255;
    if ($18) {
      $error_0 = 6;
      label = 12;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $20 = $name | 0;
    _memcpy($20 | 0, $15 | 0, $17 | 0);
    $21 = __bdf_list_split($list, 5321988, $20, $17) | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 6;
      break;
    } else {
      label = 11;
      break;
    }
   case 6:
    $24 = $list + 8 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = ($25 | 0) == 15;
    if ($26) {
      label = 7;
      break;
    } else {
      label = 11;
      break;
    }
   case 7:
    $28 = $list | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $29 + 44 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = HEAP8[$31] | 0;
    $33 = $32 << 24 >> 24;
    if (($33 | 0) == 67 | ($33 | 0) == 99) {
      label = 8;
      break;
    } else if (($33 | 0) == 77 | ($33 | 0) == 109) {
      label = 9;
      break;
    } else if (($33 | 0) == 80 | ($33 | 0) == 112) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 8:
    HEAP32[$14 >> 2] = 32;
    label = 11;
    break;
   case 9:
    HEAP32[$14 >> 2] = 16;
    label = 11;
    break;
   case 10:
    HEAP32[$14 >> 2] = 8;
    label = 11;
    break;
   case 11:
    __bdf_list_done($list);
    $error_0 = $21;
    label = 12;
    break;
   case 12:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function __bdf_add_property($font, $name, $value) {
  $font = $font | 0;
  $name = $name | 0;
  $value = $value | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0, $26 = 0, $_c85 = 0, $28 = 0, $29 = 0, $_c84 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $38 = 0, $hn_0 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $71 = 0, $72 = 0, $73 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $prop_0 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $96 = 0, $97 = 0, $99 = 0, $100 = 0, $102 = 0, $103 = 0, $104 = 0, $106 = 0, $107 = 0, $_c83 = 0, $109 = 0, $110 = 0, $_c = 0, $112 = 0, $113 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $132 = 0, $133 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $140 = 0, $141 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $148 = 0, $149 = 0, $151 = 0, $152 = 0, $153 = 0, $156 = 0, $158 = 0, $160 = 0, $162 = 0, $164 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $font + 16520 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $3 = $font + 128 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4;
    $6 = _hash_lookup($name, $5) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 8;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = $font + 80 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $6 + 4 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $10 + ($12 << 4) + 4 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    if (($14 | 0) == 1) {
      label = 3;
      break;
    } else if (($14 | 0) == 2) {
      label = 6;
      break;
    } else if (($14 | 0) == 3) {
      label = 7;
      break;
    } else {
      label = 40;
      break;
    }
   case 3:
    $16 = $10 + ($12 << 4) + 12 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    _ft_mem_free($2, $17);
    HEAP32[$16 >> 2] = 0;
    $18 = ($value | 0) == 0;
    if ($18) {
      label = 40;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $20 = HEAP8[$value] | 0;
    $21 = $20 << 24 >> 24 == 0;
    if ($21) {
      label = 40;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $23 = _ft_mem_strdup($2, $value, $error) | 0;
    HEAP32[$16 >> 2] = $23;
    label = 40;
    break;
   case 6:
    $25 = __bdf_atol($value) | 0;
    $26 = $10 + ($12 << 4) + 12 | 0;
    $_c85 = $25;
    HEAP32[$26 >> 2] = $_c85;
    label = 40;
    break;
   case 7:
    $28 = __bdf_atoul($value) | 0;
    $29 = $10 + ($12 << 4) + 12 | 0;
    $_c84 = $28;
    HEAP32[$29 >> 2] = $_c84;
    label = 40;
    break;
   case 8:
    $31 = $font + 16532 | 0;
    $32 = _hash_lookup($name, $31) | 0;
    $33 = ($32 | 0) == 0;
    if ($33) {
      label = 9;
      break;
    } else {
      $hn_0 = $32;
      label = 11;
      break;
    }
   case 9:
    $35 = _bdf_create_property($name, $font) | 0;
    HEAP32[$error >> 2] = $35;
    $36 = ($35 | 0) == 0;
    if ($36) {
      label = 10;
      break;
    } else {
      label = 40;
      break;
    }
   case 10:
    $38 = _hash_lookup($name, $31) | 0;
    $hn_0 = $38;
    label = 11;
    break;
   case 11:
    $40 = $font + 76 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = $font + 72 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = ($41 | 0) == ($43 | 0);
    if ($44) {
      label = 12;
      break;
    } else {
      label = 16;
      break;
    }
   case 12:
    $46 = ($43 | 0) == 0;
    if ($46) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    $48 = _ft_mem_realloc($2, 16, 0, 1, 0, $error) | 0;
    $49 = $48;
    $50 = $font + 80 | 0;
    HEAP32[$50 >> 2] = $49;
    $51 = HEAP32[$error >> 2] | 0;
    $52 = ($51 | 0) == 0;
    if ($52) {
      label = 15;
      break;
    } else {
      label = 40;
      break;
    }
   case 14:
    $54 = $43 + 1 | 0;
    $55 = $font + 80 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = $56;
    $58 = _ft_mem_realloc($2, 16, $43, $54, $57, $error) | 0;
    $59 = $58;
    HEAP32[$55 >> 2] = $59;
    $60 = HEAP32[$error >> 2] | 0;
    $61 = ($60 | 0) == 0;
    if ($61) {
      label = 15;
      break;
    } else {
      label = 40;
      break;
    }
   case 15:
    $63 = $font + 80 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = HEAP32[$42 >> 2] | 0;
    $66 = $64 + ($65 << 4) | 0;
    $67 = $66;
    _memset($67 | 0, 0, 16);
    $68 = HEAP32[$42 >> 2] | 0;
    $69 = $68 + 1 | 0;
    HEAP32[$42 >> 2] = $69;
    label = 16;
    break;
   case 16:
    $71 = $hn_0 + 4 | 0;
    $72 = HEAP32[$71 >> 2] | 0;
    $73 = $72 >>> 0 > 82;
    if ($73) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    $75 = $font + 16524 | 0;
    $76 = HEAP32[$75 >> 2] | 0;
    $77 = $72 - 83 | 0;
    $78 = $76 + ($77 << 4) | 0;
    $prop_0 = $78;
    label = 19;
    break;
   case 18:
    $80 = 5325428 + ($72 << 4) | 0;
    $prop_0 = $80;
    label = 19;
    break;
   case 19:
    $82 = $font + 80 | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = HEAP32[$40 >> 2] | 0;
    $85 = $prop_0 | 0;
    $86 = HEAP32[$85 >> 2] | 0;
    $87 = $83 + ($84 << 4) | 0;
    HEAP32[$87 >> 2] = $86;
    $88 = $prop_0 + 4 | 0;
    $89 = HEAP32[$88 >> 2] | 0;
    $90 = $83 + ($84 << 4) + 4 | 0;
    HEAP32[$90 >> 2] = $89;
    $91 = $prop_0 + 8 | 0;
    $92 = HEAP32[$91 >> 2] | 0;
    $93 = $83 + ($84 << 4) + 8 | 0;
    HEAP32[$93 >> 2] = $92;
    $94 = HEAP32[$88 >> 2] | 0;
    if (($94 | 0) == 1) {
      label = 20;
      break;
    } else if (($94 | 0) == 2) {
      label = 23;
      break;
    } else if (($94 | 0) == 3) {
      label = 24;
      break;
    } else {
      label = 25;
      break;
    }
   case 20:
    $96 = $83 + ($84 << 4) + 12 | 0;
    HEAP32[$96 >> 2] = 0;
    $97 = ($value | 0) == 0;
    if ($97) {
      label = 25;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $99 = HEAP8[$value] | 0;
    $100 = $99 << 24 >> 24 == 0;
    if ($100) {
      label = 25;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $102 = _ft_mem_strdup($2, $value, $error) | 0;
    HEAP32[$96 >> 2] = $102;
    $103 = HEAP32[$error >> 2] | 0;
    $104 = ($103 | 0) == 0;
    if ($104) {
      label = 25;
      break;
    } else {
      label = 40;
      break;
    }
   case 23:
    $106 = __bdf_atol($value) | 0;
    $107 = $83 + ($84 << 4) + 12 | 0;
    $_c83 = $106;
    HEAP32[$107 >> 2] = $_c83;
    label = 25;
    break;
   case 24:
    $109 = __bdf_atoul($value) | 0;
    $110 = $83 + ($84 << 4) + 12 | 0;
    $_c = $109;
    HEAP32[$110 >> 2] = $_c;
    label = 25;
    break;
   case 25:
    $112 = _memcmp($name | 0, 5323472, 7) | 0;
    $113 = ($112 | 0) == 0;
    if ($113) {
      label = 27;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $115 = HEAP32[$87 >> 2] | 0;
    $116 = HEAP32[$40 >> 2] | 0;
    $117 = HEAP32[$3 >> 2] | 0;
    $118 = $117;
    $119 = _hash_insert($115, $116, $118, $2) | 0;
    HEAP32[$error >> 2] = $119;
    $120 = ($119 | 0) == 0;
    if ($120) {
      label = 27;
      break;
    } else {
      label = 40;
      break;
    }
   case 27:
    $122 = HEAP32[$40 >> 2] | 0;
    $123 = $122 + 1 | 0;
    HEAP32[$40 >> 2] = $123;
    $124 = _memcmp($name | 0, 5322040, 12) | 0;
    $125 = ($124 | 0) == 0;
    if ($125) {
      label = 28;
      break;
    } else {
      label = 29;
      break;
    }
   case 28:
    $127 = $83 + ($84 << 4) + 12 | 0;
    $128 = $127;
    $129 = HEAP32[$128 >> 2] | 0;
    $130 = $font + 36 | 0;
    HEAP32[$130 >> 2] = $129;
    label = 40;
    break;
   case 29:
    $132 = _memcmp($name | 0, 5322732, 11) | 0;
    $133 = ($132 | 0) == 0;
    if ($133) {
      label = 30;
      break;
    } else {
      label = 31;
      break;
    }
   case 30:
    $135 = $83 + ($84 << 4) + 12 | 0;
    $136 = $135;
    $137 = HEAP32[$136 >> 2] | 0;
    $138 = $font + 40 | 0;
    HEAP32[$138 >> 2] = $137;
    label = 40;
    break;
   case 31:
    $140 = _memcmp($name | 0, 5322636, 12) | 0;
    $141 = ($140 | 0) == 0;
    if ($141) {
      label = 32;
      break;
    } else {
      label = 33;
      break;
    }
   case 32:
    $143 = $83 + ($84 << 4) + 12 | 0;
    $144 = $143;
    $145 = HEAP32[$144 >> 2] | 0;
    $146 = $font + 44 | 0;
    HEAP32[$146 >> 2] = $145;
    label = 40;
    break;
   case 33:
    $148 = _memcmp($name | 0, 5324248, 7) | 0;
    $149 = ($148 | 0) == 0;
    if ($149) {
      label = 34;
      break;
    } else {
      label = 40;
      break;
    }
   case 34:
    $151 = $83 + ($84 << 4) + 12 | 0;
    $152 = HEAP32[$151 >> 2] | 0;
    $153 = ($152 | 0) == 0;
    if ($153) {
      label = 35;
      break;
    } else {
      label = 36;
      break;
    }
   case 35:
    HEAP32[$error >> 2] = 3;
    label = 40;
    break;
   case 36:
    $156 = HEAP8[$152] | 0;
    if (($156 << 24 >> 24 | 0) == 112 | ($156 << 24 >> 24 | 0) == 80) {
      label = 37;
      break;
    } else if (($156 << 24 >> 24 | 0) == 109 | ($156 << 24 >> 24 | 0) == 77) {
      label = 38;
      break;
    } else if (($156 << 24 >> 24 | 0) == 99 | ($156 << 24 >> 24 | 0) == 67) {
      label = 39;
      break;
    } else {
      label = 40;
      break;
    }
   case 37:
    $158 = $font + 28 | 0;
    HEAP32[$158 >> 2] = 8;
    label = 40;
    break;
   case 38:
    $160 = $font + 28 | 0;
    HEAP32[$160 >> 2] = 16;
    label = 40;
    break;
   case 39:
    $162 = $font + 28 | 0;
    HEAP32[$162 >> 2] = 32;
    label = 40;
    break;
   case 40:
    $164 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $164 | 0;
  }
  return 0;
}
function _by_encoding($a, $b) {
  $a = $a | 0;
  $b = $b | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $_ = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $a + 4 | 0;
    $2 = $1;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $b + 4 | 0;
    $5 = $4;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($3 | 0) < ($6 | 0);
    if ($7) {
      $_0 = -1;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = ($3 | 0) > ($6 | 0);
    $_ = $9 & 1;
    $_0 = $_;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function __bdf_atol($s) {
  $s = $s | 0;
  var $1 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $_s = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $14 = 0, $_121 = 0, $_1 = 0, $dmap_1 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $v_02 = 0, $_21 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $v_0_lcssa = 0, $43 = 0, $44 = 0, $_019 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($s | 0) == 0;
    if ($1) {
      $_019 = 0;
      label = 9;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = HEAP8[$s] | 0;
    $4 = $3 << 24 >> 24 == 0;
    if ($4) {
      $_019 = 0;
      label = 9;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $6 = $3 << 24 >> 24 == 45;
    $7 = $s + 1 | 0;
    $_s = $6 ? $7 : $s;
    $8 = HEAP8[$_s] | 0;
    $9 = $8 << 24 >> 24 == 48;
    if ($9) {
      label = 4;
      break;
    } else {
      $dmap_1 = 5312056;
      $_1 = 10;
      $_121 = $_s;
      label = 6;
      break;
    }
   case 4:
    $11 = $_s + 1 | 0;
    $12 = HEAP8[$11] | 0;
    if (($12 << 24 >> 24 | 0) == 120 | ($12 << 24 >> 24 | 0) == 88) {
      label = 5;
      break;
    } else {
      $dmap_1 = 5312056;
      $_1 = 10;
      $_121 = $_s;
      label = 6;
      break;
    }
   case 5:
    $14 = $_s + 2 | 0;
    $dmap_1 = 5251316;
    $_1 = 16;
    $_121 = $14;
    label = 6;
    break;
   case 6:
    $16 = HEAP8[$_121] | 0;
    $17 = $16 << 24 >> 24;
    $18 = $17 >> 3;
    $19 = $dmap_1 + $18 | 0;
    $20 = HEAP8[$19] | 0;
    $21 = $20 & 255;
    $22 = $17 & 7;
    $23 = 1 << $22;
    $24 = $23 & $21;
    $25 = ($24 | 0) == 0;
    if ($25) {
      $v_0_lcssa = 0;
      label = 8;
      break;
    } else {
      $_21 = $_121;
      $v_02 = 0;
      $26 = $17;
      label = 7;
      break;
    }
   case 7:
    $27 = Math_imul($v_02, $_1);
    $28 = $26 + 5319020 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $29 & 255;
    $31 = $30 + $27 | 0;
    $32 = $_21 + 1 | 0;
    $33 = HEAP8[$32] | 0;
    $34 = $33 << 24 >> 24;
    $35 = $34 >> 3;
    $36 = $dmap_1 + $35 | 0;
    $37 = HEAP8[$36] | 0;
    $38 = $37 & 255;
    $39 = $34 & 7;
    $40 = 1 << $39;
    $41 = $40 & $38;
    $42 = ($41 | 0) == 0;
    if ($42) {
      $v_0_lcssa = $31;
      label = 8;
      break;
    } else {
      $_21 = $32;
      $v_02 = $31;
      $26 = $34;
      label = 7;
      break;
    }
   case 8:
    $43 = -$v_0_lcssa | 0;
    $44 = $6 ? $43 : $v_0_lcssa;
    $_019 = $44;
    label = 9;
    break;
   case 9:
    return $_019 | 0;
  }
  return 0;
}
function __bdf_parse_glyphs($line, $linelen, $lineno, $call_data, $client_data) {
  $line = $line | 0;
  $linelen = $linelen | 0;
  $lineno = $lineno | 0;
  $call_data = $call_data | 0;
  $client_data = $client_data | 0;
  var $slen = 0, $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $s_0 = 0, $_0 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $_pr = 0, $45 = 0, $46 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $93 = 0, $94 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $104 = 0, $105 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $119 = 0, $120 = 0, $122 = 0, $123 = 0, $124 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $152 = 0, $154 = 0, $156 = 0, $157 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $174 = 0, $175 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $210 = 0, $211 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $220 = 0, $221 = 0, $222 = 0, $224 = 0, $225 = 0, $226 = 0, $228 = 0, $229 = 0, $231 = 0, $232 = 0, $233 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $247 = 0, $248 = 0, $249 = 0, $250 = 0, $251 = 0, $252 = 0, $glyph_0 = 0, $254 = 0, $255 = 0, $256 = 0, $258 = 0, $259 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $266 = 0, $268 = 0, $269 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $i_0_ph = 0, $bp_0_ph = 0, $i_0 = 0, $279 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $290 = 0, $291 = 0, $292 = 0, $or_cond = 0, $294 = 0, $296 = 0, $297 = 0, $298 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $310 = 0, $312 = 0, $313 = 0, $314 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $321 = 0, $322 = 0, $323 = 0, $325 = 0, $326 = 0, $328 = 0, $329 = 0, $331 = 0, $332 = 0, $334 = 0, $335 = 0, $338 = 0, $339 = 0, $340 = 0, $341 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $350 = 0, $351 = 0, $353 = 0, $354 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $370 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $380 = 0, $382 = 0, $383 = 0, $385 = 0, $386 = 0, $388 = 0, $389 = 0, $390 = 0, $391 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $_ = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $_sink1 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $_240 = 0, $439 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $_sink3 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $_241 = 0, $449 = 0, $450 = 0, $451 = 0, $453 = 0, $454 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $460 = 0, $461 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $477 = 0, $478 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $499 = 0, $500 = 0, $501 = 0, $503 = 0, $504 = 0, $506 = 0, $507 = 0, $509 = 0, $510 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $539 = 0, $540 = 0, $541 = 0, $542 = 0, $_pr242 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $550 = 0, $552 = 0, $553 = 0, $554 = 0, $556 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $slen = __stackBase__ | 0;
    $error = __stackBase__ + 4 | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $client_data + 32 | 0;
    $2 = $1;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 + 16520 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = _memcmp($line | 0, 5323472, 7) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 2:
    $9 = $linelen - 7 | 0;
    $10 = $line + 7 | 0;
    $11 = HEAP8[$10] | 0;
    $12 = $11 << 24 >> 24 == 0;
    if ($12) {
      $_0 = $9;
      $s_0 = $10;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $14 = $line + 8 | 0;
    $15 = $linelen - 8 | 0;
    $_0 = $15;
    $s_0 = $14;
    label = 4;
    break;
   case 4:
    $17 = HEAP32[$2 >> 2] | 0;
    $18 = __bdf_add_comment($17, $s_0, $_0) | 0;
    HEAP32[$error >> 2] = $18;
    $545 = $18;
    label = 99;
    break;
   case 5:
    $20 = $client_data;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $21 & 32;
    $23 = ($22 | 0) == 0;
    if ($23) {
      label = 6;
      break;
    } else {
      label = 15;
      break;
    }
   case 6:
    $25 = _memcmp($line | 0, 5322884, 5) | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    HEAP32[$error >> 2] = 180;
    label = 100;
    break;
   case 8:
    $29 = $client_data + 8232 | 0;
    $30 = $29;
    $31 = __bdf_list_split($30, 5323180, $line, $linelen) | 0;
    HEAP32[$error >> 2] = $31;
    $32 = ($31 | 0) == 0;
    if ($32) {
      label = 9;
      break;
    } else {
      label = 100;
      break;
    }
   case 9:
    $34 = $29;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $35 + 4 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = __bdf_atoul($37) | 0;
    $39 = $3 + 48 | 0;
    HEAP32[$39 >> 2] = $38;
    $40 = $client_data + 4 | 0;
    $41 = $40;
    HEAP32[$41 >> 2] = $38;
    $42 = ($38 | 0) == 0;
    if ($42) {
      label = 10;
      break;
    } else {
      $45 = $38;
      label = 11;
      break;
    }
   case 10:
    HEAP32[$39 >> 2] = 64;
    $_pr = HEAP32[$41 >> 2] | 0;
    $45 = $_pr;
    label = 11;
    break;
   case 11:
    $46 = $45 >>> 0 > 1114111;
    if ($46) {
      label = 12;
      break;
    } else {
      label = 13;
      break;
    }
   case 12:
    HEAP32[$error >> 2] = 6;
    label = 100;
    break;
   case 13:
    $49 = HEAP32[$39 >> 2] | 0;
    $50 = _ft_mem_realloc($5, 36, 0, $49, 0, $error) | 0;
    $51 = $50;
    $52 = $3 + 56 | 0;
    HEAP32[$52 >> 2] = $51;
    $53 = HEAP32[$error >> 2] | 0;
    $54 = ($53 | 0) == 0;
    if ($54) {
      label = 14;
      break;
    } else {
      label = 100;
      break;
    }
   case 14:
    $56 = HEAP32[$20 >> 2] | 0;
    $57 = $56 | 32;
    HEAP32[$20 >> 2] = $57;
    label = 98;
    break;
   case 15:
    $59 = _memcmp($line | 0, 5322540, 7) | 0;
    $60 = ($59 | 0) == 0;
    if ($60) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    $62 = $3 + 56 | 0;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = $63;
    $65 = $3 + 52 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    _qsort($64 | 0, $66 | 0, 36, 848);
    $67 = HEAP32[$20 >> 2] | 0;
    $68 = $67 & -2;
    HEAP32[$20 >> 2] = $68;
    label = 98;
    break;
   case 17:
    $70 = _memcmp($line | 0, 5322452, 7) | 0;
    $71 = ($70 | 0) == 0;
    if ($71) {
      label = 18;
      break;
    } else {
      label = 19;
      break;
    }
   case 18:
    $73 = $client_data + 28 | 0;
    $74 = $73;
    HEAP32[$74 >> 2] = 0;
    $75 = HEAP32[$20 >> 2] | 0;
    $76 = $75 & -4033;
    HEAP32[$20 >> 2] = $76;
    label = 98;
    break;
   case 19:
    $78 = $21 & 64;
    $79 = ($78 | 0) == 0;
    if ($79) {
      label = 22;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $81 = $client_data + 28 | 0;
    $82 = $81;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = ($83 | 0) == -1;
    if ($84) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    $86 = $client_data + 36 | 0;
    $87 = $86;
    $88 = HEAP32[$87 >> 2] | 0;
    $89 = $88 + 4 | 0;
    $90 = HEAP32[$89 >> 2] | 0;
    $91 = ($90 | 0) == 0;
    if ($91) {
      label = 98;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $93 = _memcmp($line | 0, 5322340, 9) | 0;
    $94 = ($93 | 0) == 0;
    if ($94) {
      label = 23;
      break;
    } else {
      label = 28;
      break;
    }
   case 23:
    $96 = $client_data + 24 | 0;
    $97 = $96;
    $98 = HEAP32[$97 >> 2] | 0;
    _ft_mem_free($5, $98);
    HEAP32[$97 >> 2] = 0;
    $99 = $client_data + 8232 | 0;
    $100 = $99;
    $101 = __bdf_list_split($100, 5323180, $line, $linelen) | 0;
    HEAP32[$error >> 2] = $101;
    $102 = ($101 | 0) == 0;
    if ($102) {
      label = 24;
      break;
    } else {
      label = 100;
      break;
    }
   case 24:
    __bdf_list_shift($100);
    $104 = __bdf_list_join($100, $slen) | 0;
    $105 = ($104 | 0) == 0;
    if ($105) {
      label = 25;
      break;
    } else {
      label = 26;
      break;
    }
   case 25:
    HEAP32[$error >> 2] = 3;
    label = 100;
    break;
   case 26:
    $108 = HEAP32[$slen >> 2] | 0;
    $109 = $108 + 1 | 0;
    $110 = _ft_mem_realloc($5, 1, 0, $109, 0, $error) | 0;
    HEAP32[$97 >> 2] = $110;
    $111 = HEAP32[$error >> 2] | 0;
    $112 = ($111 | 0) == 0;
    if ($112) {
      label = 27;
      break;
    } else {
      label = 100;
      break;
    }
   case 27:
    $114 = HEAP32[$slen >> 2] | 0;
    $115 = $114 + 1 | 0;
    _memcpy($110 | 0, $104 | 0, $115 | 0);
    $116 = HEAP32[$20 >> 2] | 0;
    $117 = $116 | 64;
    HEAP32[$20 >> 2] = $117;
    label = 98;
    break;
   case 28:
    $119 = _memcmp($line | 0, 5322280, 8) | 0;
    $120 = ($119 | 0) == 0;
    if ($120) {
      label = 29;
      break;
    } else {
      label = 50;
      break;
    }
   case 29:
    $122 = HEAP32[$20 >> 2] | 0;
    $123 = $122 & 64;
    $124 = ($123 | 0) == 0;
    if ($124) {
      label = 30;
      break;
    } else {
      label = 31;
      break;
    }
   case 30:
    HEAP32[$error >> 2] = 181;
    label = 100;
    break;
   case 31:
    $127 = $client_data + 8232 | 0;
    $128 = $127;
    $129 = __bdf_list_split($128, 5323180, $line, $linelen) | 0;
    HEAP32[$error >> 2] = $129;
    $130 = ($129 | 0) == 0;
    if ($130) {
      label = 32;
      break;
    } else {
      label = 100;
      break;
    }
   case 32:
    $132 = $127;
    $133 = HEAP32[$132 >> 2] | 0;
    $134 = $133 + 4 | 0;
    $135 = HEAP32[$134 >> 2] | 0;
    $136 = __bdf_atol($135) | 0;
    $137 = $client_data + 28 | 0;
    $138 = $137;
    HEAP32[$138 >> 2] = $136;
    $139 = $136 >>> 0 > 65535;
    if ($139) {
      label = 33;
      break;
    } else {
      label = 34;
      break;
    }
   case 33:
    HEAP32[$error >> 2] = 3;
    label = 100;
    break;
   case 34:
    $142 = $136 >> 5;
    $143 = $client_data + 40 | 0;
    $144 = $143;
    $145 = $144 + ($142 << 2) | 0;
    $146 = HEAP32[$145 >> 2] | 0;
    $147 = $136 & 31;
    $148 = 1 << $147;
    $149 = $146 & $148;
    $150 = ($149 | 0) == 0;
    if ($150) {
      label = 36;
      break;
    } else {
      label = 35;
      break;
    }
   case 35:
    HEAP32[$138 >> 2] = -1;
    $152 = $3 + 16516 | 0;
    HEAP16[$152 >> 1] = 1;
    label = 37;
    break;
   case 36:
    $154 = $146 | $148;
    HEAP32[$145 >> 2] = $154;
    label = 37;
    break;
   case 37:
    $156 = HEAP32[$138 >> 2] | 0;
    $157 = ($156 | 0) > -1;
    if ($157) {
      label = 38;
      break;
    } else {
      label = 42;
      break;
    }
   case 38:
    $159 = $3 + 52 | 0;
    $160 = HEAP32[$159 >> 2] | 0;
    $161 = $3 + 48 | 0;
    $162 = HEAP32[$161 >> 2] | 0;
    $163 = ($160 | 0) == ($162 | 0);
    if ($163) {
      label = 39;
      break;
    } else {
      label = 41;
      break;
    }
   case 39:
    $165 = $162 + 64 | 0;
    $166 = $3 + 56 | 0;
    $167 = HEAP32[$166 >> 2] | 0;
    $168 = $167;
    $169 = _ft_mem_realloc($5, 36, $162, $165, $168, $error) | 0;
    $170 = $169;
    HEAP32[$166 >> 2] = $170;
    $171 = HEAP32[$error >> 2] | 0;
    $172 = ($171 | 0) == 0;
    if ($172) {
      label = 40;
      break;
    } else {
      label = 100;
      break;
    }
   case 40:
    $174 = HEAP32[$161 >> 2] | 0;
    $175 = $174 + 64 | 0;
    HEAP32[$161 >> 2] = $175;
    label = 41;
    break;
   case 41:
    $177 = $3 + 56 | 0;
    $178 = HEAP32[$177 >> 2] | 0;
    $179 = HEAP32[$159 >> 2] | 0;
    $180 = $179 + 1 | 0;
    HEAP32[$159 >> 2] = $180;
    $181 = $client_data + 24 | 0;
    $182 = $181;
    $183 = HEAP32[$182 >> 2] | 0;
    $184 = $178 + ($179 * 36 & -1) | 0;
    HEAP32[$184 >> 2] = $183;
    $185 = HEAP32[$138 >> 2] | 0;
    $186 = $178 + ($179 * 36 & -1) + 4 | 0;
    HEAP32[$186 >> 2] = $185;
    HEAP32[$182 >> 2] = 0;
    label = 49;
    break;
   case 42:
    $188 = $client_data + 36 | 0;
    $189 = $188;
    $190 = HEAP32[$189 >> 2] | 0;
    $191 = $190 + 4 | 0;
    $192 = HEAP32[$191 >> 2] | 0;
    $193 = ($192 | 0) == 0;
    if ($193) {
      label = 47;
      break;
    } else {
      label = 43;
      break;
    }
   case 43:
    $195 = $3 + 64 | 0;
    $196 = HEAP32[$195 >> 2] | 0;
    $197 = $3 + 60 | 0;
    $198 = HEAP32[$197 >> 2] | 0;
    $199 = ($196 | 0) == ($198 | 0);
    if ($199) {
      label = 44;
      break;
    } else {
      label = 46;
      break;
    }
   case 44:
    $201 = $198 + 4 | 0;
    $202 = $3 + 68 | 0;
    $203 = HEAP32[$202 >> 2] | 0;
    $204 = $203;
    $205 = _ft_mem_realloc($5, 36, $198, $201, $204, $error) | 0;
    $206 = $205;
    HEAP32[$202 >> 2] = $206;
    $207 = HEAP32[$error >> 2] | 0;
    $208 = ($207 | 0) == 0;
    if ($208) {
      label = 45;
      break;
    } else {
      label = 100;
      break;
    }
   case 45:
    $210 = HEAP32[$197 >> 2] | 0;
    $211 = $210 + 4 | 0;
    HEAP32[$197 >> 2] = $211;
    label = 46;
    break;
   case 46:
    $213 = $3 + 68 | 0;
    $214 = HEAP32[$213 >> 2] | 0;
    $215 = HEAP32[$195 >> 2] | 0;
    $216 = $client_data + 24 | 0;
    $217 = $216;
    $218 = HEAP32[$217 >> 2] | 0;
    $219 = $214 + ($215 * 36 & -1) | 0;
    HEAP32[$219 >> 2] = $218;
    $220 = HEAP32[$195 >> 2] | 0;
    $221 = $220 + 1 | 0;
    HEAP32[$195 >> 2] = $221;
    $222 = $214 + ($215 * 36 & -1) + 4 | 0;
    HEAP32[$222 >> 2] = $220;
    label = 48;
    break;
   case 47:
    $224 = $client_data + 24 | 0;
    $225 = $224;
    $226 = HEAP32[$225 >> 2] | 0;
    _ft_mem_free($5, $226);
    HEAP32[$225 >> 2] = 0;
    label = 48;
    break;
   case 48:
    $228 = $client_data + 24 | 0;
    $229 = $228;
    HEAP32[$229 >> 2] = 0;
    label = 49;
    break;
   case 49:
    $231 = HEAP32[$20 >> 2] | 0;
    $232 = $231 & 1073741695;
    $233 = $232 | 128;
    HEAP32[$20 >> 2] = $233;
    label = 98;
    break;
   case 50:
    $235 = $client_data + 28 | 0;
    $236 = $235;
    $237 = HEAP32[$236 >> 2] | 0;
    $238 = ($237 | 0) == -1;
    if ($238) {
      label = 51;
      break;
    } else {
      label = 52;
      break;
    }
   case 51:
    $240 = $3 + 68 | 0;
    $241 = HEAP32[$240 >> 2] | 0;
    $242 = $3 + 64 | 0;
    $243 = HEAP32[$242 >> 2] | 0;
    $244 = $243 - 1 | 0;
    $245 = $241 + ($244 * 36 & -1) | 0;
    $glyph_0 = $245;
    label = 53;
    break;
   case 52:
    $247 = $3 + 56 | 0;
    $248 = HEAP32[$247 >> 2] | 0;
    $249 = $3 + 52 | 0;
    $250 = HEAP32[$249 >> 2] | 0;
    $251 = $250 - 1 | 0;
    $252 = $248 + ($251 * 36 & -1) | 0;
    $glyph_0 = $252;
    label = 53;
    break;
   case 53:
    $254 = HEAP32[$20 >> 2] | 0;
    $255 = $254 & 2048;
    $256 = ($255 | 0) == 0;
    if ($256) {
      label = 69;
      break;
    } else {
      label = 54;
      break;
    }
   case 54:
    $258 = $client_data + 8 | 0;
    $259 = $258;
    $260 = HEAP32[$259 >> 2] | 0;
    $261 = $glyph_0 + 14 | 0;
    $262 = HEAP16[$261 >> 1] | 0;
    $263 = $262 & 65535;
    $264 = $260 >>> 0 < $263 >>> 0;
    if ($264) {
      label = 57;
      break;
    } else {
      label = 55;
      break;
    }
   case 55:
    $266 = ($254 | 0) < 0;
    if ($266) {
      label = 98;
      break;
    } else {
      label = 56;
      break;
    }
   case 56:
    $268 = $254 | -2147483648;
    HEAP32[$20 >> 2] = $268;
    $269 = $3 + 16516 | 0;
    HEAP16[$269 >> 1] = 1;
    label = 98;
    break;
   case 57:
    $271 = $glyph_0 + 28 | 0;
    $272 = HEAP32[$271 >> 2] | 0;
    $273 = $272 << 1;
    $274 = $glyph_0 + 24 | 0;
    $275 = HEAP32[$274 >> 2] | 0;
    $276 = Math_imul($272, $260);
    $277 = $275 + $276 | 0;
    $bp_0_ph = $277;
    $i_0_ph = 0;
    label = 58;
    break;
   case 58:
    $i_0 = $i_0_ph;
    label = 59;
    break;
   case 59:
    $279 = $i_0 >>> 0 < $273 >>> 0;
    if ($279) {
      label = 60;
      break;
    } else {
      label = 62;
      break;
    }
   case 60:
    $281 = $line + $i_0 | 0;
    $282 = HEAP8[$281] | 0;
    $283 = $282 << 24 >> 24;
    $284 = HEAP8[$bp_0_ph] | 0;
    $285 = $284 << 4;
    $286 = $283 + 5319020 | 0;
    $287 = HEAP8[$286] | 0;
    $288 = $285 + $287 & 255;
    HEAP8[$bp_0_ph] = $288;
    $289 = $i_0 + 1 | 0;
    $290 = $289 >>> 0 >= $273 >>> 0;
    $291 = $i_0 & 1;
    $292 = ($291 | 0) == 0;
    $or_cond = $290 | $292;
    if ($or_cond) {
      $i_0 = $289;
      label = 59;
      break;
    } else {
      label = 61;
      break;
    }
   case 61:
    $294 = $bp_0_ph + 1 | 0;
    HEAP8[$294] = 0;
    $bp_0_ph = $294;
    $i_0_ph = $289;
    label = 58;
    break;
   case 62:
    $296 = $glyph_0 + 12 | 0;
    $297 = HEAP16[$296 >> 1] | 0;
    $298 = $297 << 16 >> 16 == 0;
    if ($298) {
      label = 64;
      break;
    } else {
      label = 63;
      break;
    }
   case 63:
    $300 = HEAP32[$2 >> 2] | 0;
    $301 = $300 + 16518 | 0;
    $302 = HEAP16[$301 >> 1] | 0;
    $303 = $302 & 65535;
    $304 = $297 & 65535;
    $305 = Math_imul($303, $304);
    $306 = $305 & 7;
    $307 = $306 + 5251280 | 0;
    $308 = HEAP8[$307] | 0;
    $309 = HEAP8[$bp_0_ph] | 0;
    $310 = $309 & $308;
    HEAP8[$bp_0_ph] = $310;
    label = 64;
    break;
   case 64:
    $312 = $line + $273 | 0;
    $313 = HEAP8[$312] | 0;
    $314 = $313 << 24 >> 24 == 48;
    if ($314) {
      label = 66;
      break;
    } else {
      label = 65;
      break;
    }
   case 65:
    $316 = $313 << 24 >> 24;
    $317 = $316 + 5319020 | 0;
    $318 = HEAP8[$317] | 0;
    $319 = $318 << 24 >> 24 == 0;
    if ($319) {
      label = 68;
      break;
    } else {
      label = 66;
      break;
    }
   case 66:
    $321 = HEAP32[$20 >> 2] | 0;
    $322 = $321 & 1073741824;
    $323 = ($322 | 0) == 0;
    if ($323) {
      label = 67;
      break;
    } else {
      label = 68;
      break;
    }
   case 67:
    $325 = $321 | 1073741824;
    HEAP32[$20 >> 2] = $325;
    $326 = $3 + 16516 | 0;
    HEAP16[$326 >> 1] = 1;
    label = 68;
    break;
   case 68:
    $328 = HEAP32[$259 >> 2] | 0;
    $329 = $328 + 1 | 0;
    HEAP32[$259 >> 2] = $329;
    label = 98;
    break;
   case 69:
    $331 = _memcmp($line | 0, 5322232, 6) | 0;
    $332 = ($331 | 0) == 0;
    if ($332) {
      label = 70;
      break;
    } else {
      label = 74;
      break;
    }
   case 70:
    $334 = $254 & 128;
    $335 = ($334 | 0) == 0;
    if ($335) {
      label = 71;
      break;
    } else {
      label = 72;
      break;
    }
   case 71:
    HEAP32[$error >> 2] = 182;
    label = 100;
    break;
   case 72:
    $338 = $client_data + 8232 | 0;
    $339 = $338;
    $340 = __bdf_list_split($339, 5323180, $line, $linelen) | 0;
    HEAP32[$error >> 2] = $340;
    $341 = ($340 | 0) == 0;
    if ($341) {
      label = 73;
      break;
    } else {
      label = 100;
      break;
    }
   case 73:
    $343 = $338;
    $344 = HEAP32[$343 >> 2] | 0;
    $345 = $344 + 4 | 0;
    $346 = HEAP32[$345 >> 2] | 0;
    $347 = __bdf_atoul($346) | 0;
    $348 = $347 & 65535;
    $349 = $glyph_0 + 8 | 0;
    HEAP16[$349 >> 1] = $348;
    $350 = HEAP32[$20 >> 2] | 0;
    $351 = $350 | 256;
    HEAP32[$20 >> 2] = $351;
    label = 98;
    break;
   case 74:
    $353 = _memcmp($line | 0, 5322188, 6) | 0;
    $354 = ($353 | 0) == 0;
    if ($354) {
      label = 75;
      break;
    } else {
      label = 79;
      break;
    }
   case 75:
    $356 = $client_data + 8232 | 0;
    $357 = $356;
    $358 = __bdf_list_split($357, 5323180, $line, $linelen) | 0;
    HEAP32[$error >> 2] = $358;
    $359 = ($358 | 0) == 0;
    if ($359) {
      label = 76;
      break;
    } else {
      label = 100;
      break;
    }
   case 76:
    $361 = $356;
    $362 = HEAP32[$361 >> 2] | 0;
    $363 = $362 + 4 | 0;
    $364 = HEAP32[$363 >> 2] | 0;
    $365 = __bdf_atoul($364) | 0;
    $366 = $365 & 65535;
    $367 = $glyph_0 + 10 | 0;
    HEAP16[$367 >> 1] = $366;
    $368 = HEAP32[$20 >> 2] | 0;
    $369 = $368 & 256;
    $370 = ($369 | 0) == 0;
    if ($370) {
      label = 77;
      break;
    } else {
      label = 78;
      break;
    }
   case 77:
    $372 = $365 & 65535;
    $373 = $3 + 16 | 0;
    $374 = HEAP32[$373 >> 2] | 0;
    $375 = $3 + 20 | 0;
    $376 = HEAP32[$375 >> 2] | 0;
    $377 = Math_imul($376, $374);
    $378 = _FT_MulDiv($372, 72e3, $377) | 0;
    $379 = $378 & 65535;
    $380 = $glyph_0 + 8 | 0;
    HEAP16[$380 >> 1] = $379;
    label = 78;
    break;
   case 78:
    $382 = HEAP32[$20 >> 2] | 0;
    $383 = $382 | 512;
    HEAP32[$20 >> 2] = $383;
    label = 98;
    break;
   case 79:
    $385 = _memcmp($line | 0, 5322152, 3) | 0;
    $386 = ($385 | 0) == 0;
    if ($386) {
      label = 80;
      break;
    } else {
      label = 90;
      break;
    }
   case 80:
    $388 = $client_data + 8232 | 0;
    $389 = $388;
    $390 = __bdf_list_split($389, 5323180, $line, $linelen) | 0;
    HEAP32[$error >> 2] = $390;
    $391 = ($390 | 0) == 0;
    if ($391) {
      label = 81;
      break;
    } else {
      label = 100;
      break;
    }
   case 81:
    $393 = $388;
    $394 = HEAP32[$393 >> 2] | 0;
    $395 = $394 + 4 | 0;
    $396 = HEAP32[$395 >> 2] | 0;
    $397 = __bdf_atos($396) | 0;
    $398 = $glyph_0 + 12 | 0;
    HEAP16[$398 >> 1] = $397;
    $399 = HEAP32[$393 >> 2] | 0;
    $400 = $399 + 8 | 0;
    $401 = HEAP32[$400 >> 2] | 0;
    $402 = __bdf_atos($401) | 0;
    $403 = $glyph_0 + 14 | 0;
    HEAP16[$403 >> 1] = $402;
    $404 = HEAP32[$393 >> 2] | 0;
    $405 = $404 + 12 | 0;
    $406 = HEAP32[$405 >> 2] | 0;
    $407 = __bdf_atos($406) | 0;
    $408 = $glyph_0 + 16 | 0;
    HEAP16[$408 >> 1] = $407;
    $409 = HEAP32[$393 >> 2] | 0;
    $410 = $409 + 16 | 0;
    $411 = HEAP32[$410 >> 2] | 0;
    $412 = __bdf_atos($411) | 0;
    $413 = $glyph_0 + 18 | 0;
    HEAP16[$413 >> 1] = $412;
    $414 = HEAP16[$403 >> 1] | 0;
    $415 = $414 + $412 & 65535;
    $416 = $glyph_0 + 20 | 0;
    HEAP16[$416 >> 1] = $415;
    $417 = HEAP16[$413 >> 1] | 0;
    $418 = -$417 & 65535;
    $419 = $glyph_0 + 22 | 0;
    HEAP16[$419 >> 1] = $418;
    $420 = HEAP16[$416 >> 1] | 0;
    $421 = $client_data + 18 | 0;
    $422 = $421;
    $423 = HEAP16[$422 >> 1] | 0;
    $424 = $420 << 16 >> 16 > $423 << 16 >> 16;
    $_ = $424 ? $420 : $423;
    HEAP16[$422 >> 1] = $_;
    $425 = HEAP16[$419 >> 1] | 0;
    $426 = $client_data + 20 | 0;
    $427 = $426;
    $428 = HEAP16[$427 >> 1] | 0;
    $429 = $425 << 16 >> 16 > $428 << 16 >> 16;
    $_sink1 = $429 ? $425 : $428;
    HEAP16[$427 >> 1] = $_sink1;
    $430 = HEAP16[$398 >> 1] | 0;
    $431 = HEAP16[$408 >> 1] | 0;
    $432 = $431 + $430 & 65535;
    $433 = $client_data + 22 | 0;
    $434 = $433;
    HEAP16[$434 >> 1] = $432;
    $435 = $client_data + 16 | 0;
    $436 = $435;
    $437 = HEAP16[$436 >> 1] | 0;
    $438 = $432 << 16 >> 16 > $437 << 16 >> 16;
    $_240 = $438 ? $432 : $437;
    HEAP16[$436 >> 1] = $_240;
    $439 = HEAP16[$408 >> 1] | 0;
    $440 = $client_data + 12 | 0;
    $441 = $440;
    $442 = HEAP16[$441 >> 1] | 0;
    $443 = $439 << 16 >> 16 < $442 << 16 >> 16;
    $_sink3 = $443 ? $439 : $442;
    HEAP16[$441 >> 1] = $_sink3;
    $444 = HEAP16[$408 >> 1] | 0;
    $445 = $client_data + 14 | 0;
    $446 = $445;
    $447 = HEAP16[$446 >> 1] | 0;
    $448 = $444 << 16 >> 16 > $447 << 16 >> 16;
    $_241 = $448 ? $444 : $447;
    HEAP16[$446 >> 1] = $_241;
    $449 = HEAP32[$20 >> 2] | 0;
    $450 = $449 & 512;
    $451 = ($450 | 0) == 0;
    if ($451) {
      label = 82;
      break;
    } else {
      label = 83;
      break;
    }
   case 82:
    $453 = HEAP16[$398 >> 1] | 0;
    $454 = $glyph_0 + 10 | 0;
    HEAP16[$454 >> 1] = $453;
    label = 83;
    break;
   case 83:
    $456 = $client_data + 36 | 0;
    $457 = $456;
    $458 = HEAP32[$457 >> 2] | 0;
    $459 = $458 | 0;
    $460 = HEAP32[$459 >> 2] | 0;
    $461 = ($460 | 0) == 0;
    if ($461) {
      label = 89;
      break;
    } else {
      label = 84;
      break;
    }
   case 84:
    $463 = $glyph_0 + 10 | 0;
    $464 = HEAP16[$463 >> 1] | 0;
    $465 = $464 & 65535;
    $466 = $3 + 16 | 0;
    $467 = HEAP32[$466 >> 2] | 0;
    $468 = $3 + 20 | 0;
    $469 = HEAP32[$468 >> 2] | 0;
    $470 = Math_imul($469, $467);
    $471 = _FT_MulDiv($465, 72e3, $470) | 0;
    $472 = $glyph_0 + 8 | 0;
    $473 = HEAP16[$472 >> 1] | 0;
    $474 = $471 & 65535;
    $475 = $473 << 16 >> 16 == $474 << 16 >> 16;
    if ($475) {
      label = 89;
      break;
    } else {
      label = 85;
      break;
    }
   case 85:
    HEAP16[$472 >> 1] = $474;
    $477 = HEAP32[$236 >> 2] | 0;
    $478 = ($477 | 0) == -1;
    if ($478) {
      label = 86;
      break;
    } else {
      label = 87;
      break;
    }
   case 86:
    $480 = $3 + 64 | 0;
    $481 = HEAP32[$480 >> 2] | 0;
    $482 = $481 - 1 | 0;
    $483 = $482 & 31;
    $484 = 1 << $483;
    $485 = $482 >>> 5;
    $486 = $3 + 8324 + ($485 << 2) | 0;
    $487 = HEAP32[$486 >> 2] | 0;
    $488 = $484 | $487;
    HEAP32[$486 >> 2] = $488;
    label = 88;
    break;
   case 87:
    $490 = $glyph_0 + 4 | 0;
    $491 = HEAP32[$490 >> 2] | 0;
    $492 = $491 & 31;
    $493 = 1 << $492;
    $494 = $491 >> 5;
    $495 = $3 + 132 + ($494 << 2) | 0;
    $496 = HEAP32[$495 >> 2] | 0;
    $497 = $493 | $496;
    HEAP32[$495 >> 2] = $497;
    label = 88;
    break;
   case 88:
    $499 = HEAP32[$20 >> 2] | 0;
    $500 = $499 | 4096;
    HEAP32[$20 >> 2] = $500;
    $501 = $3 + 16516 | 0;
    HEAP16[$501 >> 1] = 1;
    label = 89;
    break;
   case 89:
    $503 = HEAP32[$20 >> 2] | 0;
    $504 = $503 | 1024;
    HEAP32[$20 >> 2] = $504;
    label = 98;
    break;
   case 90:
    $506 = _memcmp($line | 0, 5322112, 6) | 0;
    $507 = ($506 | 0) == 0;
    if ($507) {
      label = 91;
      break;
    } else {
      label = 97;
      break;
    }
   case 91:
    $509 = $254 & 1024;
    $510 = ($509 | 0) == 0;
    if ($510) {
      label = 92;
      break;
    } else {
      label = 93;
      break;
    }
   case 92:
    HEAP32[$error >> 2] = 183;
    label = 100;
    break;
   case 93:
    $513 = $glyph_0 + 12 | 0;
    $514 = HEAP16[$513 >> 1] | 0;
    $515 = $514 & 65535;
    $516 = HEAP32[$2 >> 2] | 0;
    $517 = $516 + 16518 | 0;
    $518 = HEAP16[$517 >> 1] | 0;
    $519 = $518 & 65535;
    $520 = Math_imul($519, $515);
    $521 = $520 + 7 | 0;
    $522 = $521 >>> 3;
    $523 = $glyph_0 + 28 | 0;
    HEAP32[$523 >> 2] = $522;
    $524 = $glyph_0 + 14 | 0;
    $525 = HEAP16[$524 >> 1] | 0;
    $526 = $525 & 65535;
    $527 = Math_imul($522, $526);
    $528 = $527 >>> 0 > 65535;
    if ($528) {
      label = 94;
      break;
    } else {
      label = 95;
      break;
    }
   case 94:
    HEAP32[$error >> 2] = 184;
    label = 100;
    break;
   case 95:
    $531 = $527 & 65535;
    $532 = $glyph_0 + 32 | 0;
    HEAP16[$532 >> 1] = $531;
    $533 = $527 & 65535;
    $534 = _ft_mem_realloc($5, 1, 0, $533, 0, $error) | 0;
    $535 = $glyph_0 + 24 | 0;
    HEAP32[$535 >> 2] = $534;
    $536 = HEAP32[$error >> 2] | 0;
    $537 = ($536 | 0) == 0;
    if ($537) {
      label = 96;
      break;
    } else {
      label = 100;
      break;
    }
   case 96:
    $539 = $client_data + 8 | 0;
    $540 = $539;
    HEAP32[$540 >> 2] = 0;
    $541 = HEAP32[$20 >> 2] | 0;
    $542 = $541 | 2048;
    HEAP32[$20 >> 2] = $542;
    label = 98;
    break;
   case 97:
    HEAP32[$error >> 2] = 3;
    label = 100;
    break;
   case 98:
    $_pr242 = HEAP32[$error >> 2] | 0;
    $545 = $_pr242;
    label = 99;
    break;
   case 99:
    $546 = ($545 | 0) == 0;
    if ($546) {
      label = 102;
      break;
    } else {
      label = 100;
      break;
    }
   case 100:
    $547 = $client_data;
    $548 = HEAP32[$547 >> 2] | 0;
    $549 = $548 & 64;
    $550 = ($549 | 0) == 0;
    if ($550) {
      label = 102;
      break;
    } else {
      label = 101;
      break;
    }
   case 101:
    $552 = $client_data + 24 | 0;
    $553 = $552;
    $554 = HEAP32[$553 >> 2] | 0;
    _ft_mem_free($5, $554);
    HEAP32[$553 >> 2] = 0;
    label = 102;
    break;
   case 102:
    $556 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $556 | 0;
  }
  return 0;
}
function _cff_driver_init($module) {
  $module = $module | 0;
  return 0;
}
function _cff_driver_done($module) {
  $module = $module | 0;
  return;
}
function _bdf_get_charset_id($face, $acharset_encoding, $acharset_registry) {
  $face = $face | 0;
  $acharset_encoding = $acharset_encoding | 0;
  $acharset_registry = $acharset_registry | 0;
  HEAP32[$acharset_encoding >> 2] = HEAP32[$face + 132 >> 2] | 0;
  HEAP32[$acharset_registry >> 2] = HEAP32[$face + 136 >> 2] | 0;
  return 0;
}
function _bdf_create_property($name, $font) {
  $name = $name | 0;
  $font = $font | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $39 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $font + 16520 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $3 = $font + 16532 | 0;
    $4 = _hash_lookup($name, $3) | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $7 = $font + 16528 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 + 1 | 0;
    $10 = $font + 16524 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11;
    $13 = _ft_mem_realloc($2, 16, $8, $9, $12, $error) | 0;
    $14 = $13;
    HEAP32[$10 >> 2] = $14;
    $15 = HEAP32[$error >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 3:
    $18 = HEAP32[$7 >> 2] | 0;
    $19 = $14 + ($18 << 4) | 0;
    $20 = $19;
    _memset($20 | 0, 0, 16);
    $21 = _strlen($name | 0) | 0;
    $22 = $21 + 1 | 0;
    $23 = _ft_mem_realloc($2, 1, 0, $22, 0, $error) | 0;
    $24 = $19 | 0;
    HEAP32[$24 >> 2] = $23;
    $25 = HEAP32[$error >> 2] | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 4;
      break;
    } else {
      label = 6;
      break;
    }
   case 4:
    _memcpy($23 | 0, $name | 0, $22 | 0);
    $28 = $14 + ($18 << 4) + 4 | 0;
    HEAP32[$28 >> 2] = 1;
    $29 = $14 + ($18 << 4) + 8 | 0;
    HEAP32[$29 >> 2] = 0;
    $30 = HEAP32[$7 >> 2] | 0;
    $31 = $30 + 83 | 0;
    $32 = HEAP32[$24 >> 2] | 0;
    $33 = _hash_insert($32, $31, $3, $2) | 0;
    HEAP32[$error >> 2] = $33;
    $34 = ($33 | 0) == 0;
    if ($34) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $36 = HEAP32[$7 >> 2] | 0;
    $37 = $36 + 1 | 0;
    HEAP32[$7 >> 2] = $37;
    label = 6;
    break;
   case 6:
    $39 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $39 | 0;
  }
  return 0;
}
function __bdf_is_atom($line, $linelen, $name, $value, $font) {
  $line = $line | 0;
  $linelen = $linelen | 0;
  $name = $name | 0;
  $value = $value | 0;
  $font = $font | 0;
  var $ep_0 = 0, $2 = 0, $4 = 0, $5 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $ep_0_pn = 0, $sp_0 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $_sp_0 = 0, $21 = 0, $ep_137 = 0, $22 = 0, $23 = 0, $25 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    HEAP32[$name >> 2] = $line;
    $ep_0 = $line;
    label = 2;
    break;
   case 2:
    $2 = HEAP8[$ep_0] | 0;
    if (($2 << 24 >> 24 | 0) == 0) {
      label = 4;
      break;
    } else if (($2 << 24 >> 24 | 0) == 9 | ($2 << 24 >> 24 | 0) == 32) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $4 = $ep_0 + 1 | 0;
    $ep_0 = $4;
    label = 2;
    break;
   case 4:
    $5 = _bdf_get_property($line, $font) | 0;
    $9 = $5;
    label = 6;
    break;
   case 5:
    HEAP8[$ep_0] = 0;
    $7 = _bdf_get_property($line, $font) | 0;
    HEAP8[$ep_0] = $2;
    $9 = $7;
    label = 6;
    break;
   case 6:
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $12 = $9 + 4 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = ($13 | 0) == 1;
    if ($14) {
      label = 8;
      break;
    } else {
      $_0 = 0;
      label = 14;
      break;
    }
   case 8:
    HEAP8[$ep_0] = 0;
    $ep_0_pn = $ep_0;
    label = 9;
    break;
   case 9:
    $sp_0 = $ep_0_pn + 1 | 0;
    $16 = HEAP8[$sp_0] | 0;
    if (($16 << 24 >> 24 | 0) == 9 | ($16 << 24 >> 24 | 0) == 32) {
      $ep_0_pn = $sp_0;
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $17 = $line + $linelen | 0;
    $18 = HEAP8[$sp_0] | 0;
    $19 = $18 << 24 >> 24 == 34;
    $20 = $ep_0_pn + 2 | 0;
    $_sp_0 = $19 ? $20 : $sp_0;
    HEAP32[$value >> 2] = $_sp_0;
    $21 = $17 >>> 0 > $_sp_0 >>> 0;
    if ($21) {
      $ep_137 = $17;
      label = 11;
      break;
    } else {
      $_0 = 1;
      label = 14;
      break;
    }
   case 11:
    $22 = $ep_137 - 1 | 0;
    $23 = HEAP8[$22] | 0;
    if (($23 << 24 >> 24 | 0) == 32 | ($23 << 24 >> 24 | 0) == 9) {
      label = 12;
      break;
    } else if (($23 << 24 >> 24 | 0) == 34) {
      label = 13;
      break;
    } else {
      $_0 = 1;
      label = 14;
      break;
    }
   case 12:
    HEAP8[$22] = 0;
    $25 = $22 >>> 0 > $_sp_0 >>> 0;
    if ($25) {
      $ep_137 = $22;
      label = 11;
      break;
    } else {
      $_0 = 1;
      label = 14;
      break;
    }
   case 13:
    HEAP8[$22] = 0;
    $_0 = 1;
    label = 14;
    break;
   case 14:
    return $_0 | 0;
  }
  return 0;
}
function _bdf_get_property($name, $font) {
  $name = $name | 0;
  $font = $font | 0;
  var $1 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($name | 0) == 0;
    if ($1) {
      $_0 = 0;
      label = 7;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = HEAP8[$name] | 0;
    $4 = $3 << 24 >> 24 == 0;
    if ($4) {
      $_0 = 0;
      label = 7;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $6 = $font + 16532 | 0;
    $7 = _hash_lookup($name, $6) | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      $_0 = 0;
      label = 7;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $10 = $7 + 4 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 >>> 0 > 82;
    if ($12) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $14 = $font + 16524 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $11 - 83 | 0;
    $17 = $15 + ($16 << 4) | 0;
    $_0 = $17;
    label = 7;
    break;
   case 6:
    $19 = 5325428 + ($11 << 4) | 0;
    $_0 = $19;
    label = 7;
    break;
   case 7:
    return $_0 | 0;
  }
  return 0;
}
function __bdf_list_ensure($list, $num_items) {
  $list = $list | 0;
  $num_items = $num_items | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $or_cond = 0, $newsize_0 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $24 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $list + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 >>> 0 < $num_items >>> 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $5 = $2 >>> 1;
    $6 = $2 + 4 | 0;
    $7 = $6 + $5 | 0;
    $8 = ($2 | 0) == 536870911;
    if ($8) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    HEAP32[$error >> 2] = 64;
    label = 6;
    break;
   case 4:
    $11 = $list + 12 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $7 >>> 0 < $2 >>> 0;
    $14 = $7 >>> 0 > 536870911;
    $or_cond = $13 | $14;
    $newsize_0 = $or_cond ? 536870911 : $7;
    $15 = $list | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $16;
    $18 = _ft_mem_realloc($12, 4, $2, $newsize_0, $17, $error) | 0;
    $19 = $18;
    HEAP32[$15 >> 2] = $19;
    $20 = HEAP32[$error >> 2] | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    HEAP32[$1 >> 2] = $newsize_0;
    label = 6;
    break;
   case 6:
    $24 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $24 | 0;
  }
  return 0;
}
function _hash_rehash($ht, $memory) {
  $ht = $ht | 0;
  $memory = $memory | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $i_016 = 0, $bp_015 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $exitcond = 0, $24 = 0, $26 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $ht + 12 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $ht + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $5 = HEAP32[$3 >> 2] | 0;
    $6 = $5 << 1;
    HEAP32[$3 >> 2] = $6;
    $7 = ($6 | 0) / 3 & -1;
    $8 = $ht | 0;
    HEAP32[$8 >> 2] = $7;
    $9 = HEAP32[$3 >> 2] | 0;
    $10 = _ft_mem_realloc($memory, 4, 0, $9, 0, $error) | 0;
    $11 = $10;
    HEAP32[$1 >> 2] = $11;
    $12 = HEAP32[$error >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 2;
      break;
    } else {
      label = 7;
      break;
    }
   case 2:
    $14 = ($4 | 0) > 0;
    if ($14) {
      $bp_015 = $2;
      $i_016 = 0;
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 3:
    $15 = HEAP32[$bp_015 >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $18 = $15 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = _hash_bucket($19, $ht) | 0;
    HEAP32[$20 >> 2] = $15;
    label = 5;
    break;
   case 5:
    $22 = $i_016 + 1 | 0;
    $23 = $bp_015 + 4 | 0;
    $exitcond = ($22 | 0) == ($4 | 0);
    if ($exitcond) {
      label = 6;
      break;
    } else {
      $bp_015 = $23;
      $i_016 = $22;
      label = 3;
      break;
    }
   case 6:
    $24 = $2;
    _ft_mem_free($memory, $24);
    label = 7;
    break;
   case 7:
    $26 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $26 | 0;
  }
  return 0;
}
function _bdf_get_bdf_property($face, $prop_name, $aproperty) {
  $face = $face | 0;
  $prop_name = $prop_name | 0;
  $aproperty = $aproperty | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $_c15 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $_c = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 140 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _bdf_get_font_property($2, $prop_name) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      $_0 = 6;
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $3 + 4 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    if (($7 | 0) == 1) {
      label = 3;
      break;
    } else if (($7 | 0) == 2) {
      label = 4;
      break;
    } else if (($7 | 0) == 3) {
      label = 5;
      break;
    } else {
      $_0 = 6;
      label = 6;
      break;
    }
   case 3:
    $9 = $aproperty | 0;
    HEAP32[$9 >> 2] = 1;
    $10 = $3 + 12 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $aproperty + 4 | 0;
    HEAP32[$12 >> 2] = $11;
    $_0 = 0;
    label = 6;
    break;
   case 4:
    $14 = $3 + 12 | 0;
    $15 = $14;
    $16 = $aproperty | 0;
    HEAP32[$16 >> 2] = 2;
    $17 = HEAP32[$15 >> 2] | 0;
    $18 = $aproperty + 4 | 0;
    $_c15 = $17;
    HEAP32[$18 >> 2] = $_c15;
    $_0 = 0;
    label = 6;
    break;
   case 5:
    $20 = $3 + 12 | 0;
    $21 = $20;
    $22 = $aproperty | 0;
    HEAP32[$22 >> 2] = 3;
    $23 = HEAP32[$21 >> 2] | 0;
    $24 = $aproperty + 4 | 0;
    $_c = $23;
    HEAP32[$24 >> 2] = $_c;
    $_0 = 0;
    label = 6;
    break;
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _cff_get_interface($driver, $module_interface) {
  $driver = $driver | 0;
  $module_interface = $module_interface | 0;
  var $1 = 0, $2 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _ft_service_list_lookup(5314532, $module_interface) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $_0 = $1;
      label = 5;
      break;
    }
   case 2:
    $4 = ($driver | 0) == 0;
    if ($4) {
      $_0 = 0;
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $6 = $driver + 4 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $7;
    $9 = _FT_Get_Module($8, 5324184) | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      $_0 = 0;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $12 = $9;
    $13 = $9;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 + 32 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = FUNCTION_TABLE_iii[$16 & 1023]($12, $module_interface) | 0;
    $_0 = $17;
    label = 5;
    break;
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function _cff_slot_done($slot) {
  $slot = $slot | 0;
  HEAP32[(HEAP32[$slot + 156 >> 2] | 0) + 36 >> 2] = 0;
  return;
}
function _cff_face_init($stream, $cffface, $face_index, $num_params, $params) {
  $stream = $stream | 0;
  $cffface = $cffface | 0;
  $face_index = $face_index | 0;
  $num_params = $num_params | 0;
  $params = $params | 0;
  var $error = 0, $cmaprec = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $30 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $pure_cff_0 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $56 = 0, $57 = 0, $sfnt_format_0 = 0, $pure_cff_1 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $_c = 0, $68 = 0, $69 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $or_cond240 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $91 = 0, $93 = 0, $94 = 0, $95 = 0, $97 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $i_0258 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $155 = 0, $156 = 0, $157 = 0, $or_cond241 = 0, $159 = 0, $_ = 0, $scaling_0 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $ld$0$0 = 0, $171$0 = 0, $ld$1$1 = 0, $171$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $172 = 0, $storemerge238 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $182 = 0, $183 = 0, $185 = 0, $186 = 0, $storemerge239 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $220 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $227 = 0, $228 = 0, $229 = 0, $storemerge = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $sext = 0, $268 = 0, $269 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $276 = 0, $278 = 0, $279 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $290 = 0, $291 = 0, $292 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $300 = 0, $301 = 0, $302 = 0, $304 = 0, $305 = 0, $_242 = 0, $family_0 = 0, $307 = 0, $308 = 0, $or_cond243 = 0, $309 = 0, $310 = 0, $311 = 0, $family_1_ph264 = 0, $fullp_0_ph263 = 0, $313 = 0, $family_1257 = 0, $314 = 0, $315 = 0, $317 = 0, $family_1_ph_be = 0, $fullp_0_ph_be = 0, $318 = 0, $319 = 0, $323 = 0, $324 = 0, $325 = 0, $327 = 0, $328 = 0, $329 = 0, $330 = 0, $331 = 0, $333 = 0, $335 = 0, $336 = 0, $338 = 0, $339 = 0, $340 = 0, $342 = 0, $_244 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $flags_1 = 0, $347 = 0, $348 = 0, $349 = 0, $350 = 0, $not_ = 0, $_245 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $357 = 0, $358 = 0, $360 = 0, $361 = 0, $363 = 0, $flags_3 = 0, $365 = 0, $366 = 0, $368 = 0, $369 = 0, $370 = 0, $372 = 0, $373 = 0, $375 = 0, $376 = 0, $378 = 0, $flags_4 = 0, $380 = 0, $382 = 0, $383 = 0, $385 = 0, $386 = 0, $387 = 0, $389 = 0, $390 = 0, $or_cond246 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $nn_0 = 0, $399 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $408 = 0, $409 = 0, $410 = 0, $_pr = 0, $412 = 0, $413 = 0, $414 = 0, $417 = 0, $418 = 0, $420 = 0, $421 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $431 = 0, $432 = 0, $433 = 0, $435 = 0, $436 = 0, $438 = 0, $439 = 0, $440 = 0, $441 = 0, $nn_1 = 0, $442 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $449 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $456 = 0, $457 = 0, $459 = 0, $460 = 0, $462 = 0, $464 = 0, $466 = 0, $467 = 0, $469 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 16 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $cmaprec = __stackBase__ + 4 | 0;
    $1 = $cffface;
    $2 = $cffface + 96 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5;
    $7 = _FT_Get_Module_Interface($6, 5324184) | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 94;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = $3;
    $11 = _ft_module_get_service($10, 5323212) | 0;
    $12 = $11;
    $13 = _FT_Get_Module_Interface($6, 5322380) | 0;
    $14 = $13;
    $15 = _FT_Stream_Seek($stream, 0) | 0;
    HEAP32[$error >> 2] = $15;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 3;
      break;
    } else {
      label = 93;
      break;
    }
   case 3:
    $18 = $7 + 4 | 0;
    $19 = $18;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = FUNCTION_TABLE_iiiiii[$20 & 1023]($stream, $1, $face_index, $num_params, $params) | 0;
    HEAP32[$error >> 2] = $21;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 4;
      break;
    } else {
      label = 12;
      break;
    }
   case 4:
    $24 = $cffface + 148 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = ($25 | 0) == 1330926671;
    if ($26) {
      label = 5;
      break;
    } else {
      label = 94;
      break;
    }
   case 5:
    $28 = ($face_index | 0) < 0;
    if ($28) {
      $_0 = 0;
      label = 95;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $30 = ($face_index | 0) > 0;
    if ($30) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    HEAP32[$error >> 2] = 6;
    label = 93;
    break;
   case 8:
    $33 = $cffface + 508 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $34;
    $36 = FUNCTION_TABLE_iiiii[$35 & 1023]($1, 1751474532, $stream, 0) | 0;
    HEAP32[$error >> 2] = $36;
    $37 = ($36 | 0) == 0;
    if ($37) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $39 = $7 + 8 | 0;
    $40 = $39;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = FUNCTION_TABLE_iiiiii[$41 & 1023]($stream, $1, 0, $num_params, $params) | 0;
    HEAP32[$error >> 2] = $42;
    $43 = ($42 | 0) == 0;
    if ($43) {
      $pure_cff_0 = 0;
      label = 11;
      break;
    } else {
      label = 93;
      break;
    }
   case 10:
    $45 = $7 + 40 | 0;
    $46 = $45;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = FUNCTION_TABLE_iii[$47 & 1023]($1, $stream) | 0;
    HEAP32[$error >> 2] = $48;
    $49 = ($48 | 0) == 0;
    if ($49) {
      $pure_cff_0 = 1;
      label = 11;
      break;
    } else {
      label = 93;
      break;
    }
   case 11:
    $51 = HEAP32[$33 >> 2] | 0;
    $52 = $51;
    $53 = FUNCTION_TABLE_iiiii[$52 & 1023]($1, 1128678944, $stream, 0) | 0;
    HEAP32[$error >> 2] = $53;
    $54 = ($53 | 0) == 0;
    if ($54) {
      $pure_cff_1 = $pure_cff_0;
      $sfnt_format_0 = 1;
      label = 14;
      break;
    } else {
      label = 93;
      break;
    }
   case 12:
    $56 = _FT_Stream_Seek($stream, 0) | 0;
    HEAP32[$error >> 2] = $56;
    $57 = ($56 | 0) == 0;
    if ($57) {
      label = 13;
      break;
    } else {
      label = 93;
      break;
    }
   case 13:
    HEAP32[$error >> 2] = 0;
    $pure_cff_1 = 1;
    $sfnt_format_0 = 0;
    label = 14;
    break;
   case 14:
    $60 = $cffface + 100 | 0;
    $61 = HEAP32[$60 >> 2] | 0;
    $62 = _ft_mem_alloc($61, 2072, $error) | 0;
    $63 = $62;
    $64 = HEAP32[$error >> 2] | 0;
    $65 = ($64 | 0) == 0;
    if ($65) {
      label = 15;
      break;
    } else {
      label = 93;
      break;
    }
   case 15:
    $67 = $cffface + 692 | 0;
    $_c = $62;
    HEAP32[$67 >> 2] = $_c;
    $68 = _cff_font_load($5, $stream, $face_index, $63, $pure_cff_1) | 0;
    HEAP32[$error >> 2] = $68;
    $69 = ($68 | 0) == 0;
    if ($69) {
      label = 16;
      break;
    } else {
      label = 93;
      break;
    }
   case 16:
    $71 = $62 + 2052 | 0;
    $72 = $71;
    HEAP32[$72 >> 2] = $14;
    $73 = $62 + 2056 | 0;
    $74 = $73;
    HEAP32[$74 >> 2] = $12;
    $75 = $cffface + 4 | 0;
    HEAP32[$75 >> 2] = $face_index;
    $76 = $62 + 12 | 0;
    $77 = $76;
    $78 = HEAP32[$77 >> 2] | 0;
    $79 = $cffface + 16 | 0;
    HEAP32[$79 >> 2] = $78;
    $80 = $62 + 1452 | 0;
    $81 = $80;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = ($82 | 0) == 65535;
    $84 = ($11 | 0) == 0;
    $or_cond240 = $83 & $84;
    if ($or_cond240) {
      label = 94;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $86 = $62 + 1388 | 0;
    $87 = $86;
    $88 = HEAP32[$87 >> 2] | 0;
    $89 = ($88 | 0) == 0;
    if ($89) {
      label = 18;
      break;
    } else {
      label = 21;
      break;
    }
   case 18:
    $91 = $pure_cff_1 << 24 >> 24 == 0;
    if ($91) {
      label = 19;
      break;
    } else {
      $97 = 1e3;
      label = 20;
      break;
    }
   case 19:
    $93 = $cffface + 68 | 0;
    $94 = HEAP16[$93 >> 1] | 0;
    $95 = $94 & 65535;
    $97 = $95;
    label = 20;
    break;
   case 20:
    HEAP32[$87 >> 2] = $97;
    label = 21;
    break;
   case 21:
    $99 = $62 + 1372 | 0;
    $100 = $99;
    $101 = $62 + 1392 | 0;
    $102 = $62 + 1384 | 0;
    $103 = $102;
    $104 = HEAP32[$103 >> 2] | 0;
    $105 = ($104 | 0) < 0;
    $106 = -$104 | 0;
    $107 = $105 ? $106 : $104;
    $108 = ($107 | 0) == 65536;
    if ($108) {
      label = 23;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $110 = HEAP32[$87 >> 2] | 0;
    $111 = _FT_DivFix($110, $107) | 0;
    HEAP32[$87 >> 2] = $111;
    $112 = $99;
    $113 = HEAP32[$112 >> 2] | 0;
    $114 = _FT_DivFix($113, $107) | 0;
    HEAP32[$112 >> 2] = $114;
    $115 = $62 + 1380 | 0;
    $116 = $115;
    $117 = HEAP32[$116 >> 2] | 0;
    $118 = _FT_DivFix($117, $107) | 0;
    HEAP32[$116 >> 2] = $118;
    $119 = $62 + 1376 | 0;
    $120 = $119;
    $121 = HEAP32[$120 >> 2] | 0;
    $122 = _FT_DivFix($121, $107) | 0;
    HEAP32[$120 >> 2] = $122;
    $123 = HEAP32[$103 >> 2] | 0;
    $124 = _FT_DivFix($123, $107) | 0;
    HEAP32[$103 >> 2] = $124;
    $125 = $101;
    $126 = HEAP32[$125 >> 2] | 0;
    $127 = _FT_DivFix($126, $107) | 0;
    HEAP32[$125 >> 2] = $127;
    $128 = $62 + 1396 | 0;
    $129 = $128;
    $130 = HEAP32[$129 >> 2] | 0;
    $131 = _FT_DivFix($130, $107) | 0;
    HEAP32[$129 >> 2] = $131;
    label = 23;
    break;
   case 23:
    $133 = $101;
    $134 = HEAP32[$133 >> 2] | 0;
    $135 = $134 >> 16;
    HEAP32[$133 >> 2] = $135;
    $136 = $62 + 1396 | 0;
    $137 = $136;
    $138 = HEAP32[$137 >> 2] | 0;
    $139 = $138 >> 16;
    HEAP32[$137 >> 2] = $139;
    $140 = $62 + 1892 | 0;
    $141 = $140;
    $142 = HEAP32[$141 >> 2] | 0;
    $143 = ($142 | 0) == 0;
    if ($143) {
      label = 35;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $144 = $62 + 1896 | 0;
    $145 = $144;
    $146 = $101;
    $i_0258 = $142;
    label = 25;
    break;
   case 25:
    $148 = $i_0258 - 1 | 0;
    $149 = $145 + ($148 << 2) | 0;
    $150 = HEAP32[$149 >> 2] | 0;
    $151 = $150 + 64 | 0;
    $152 = HEAP32[$151 >> 2] | 0;
    $153 = ($152 | 0) == 0;
    if ($153) {
      label = 29;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $155 = HEAP32[$87 >> 2] | 0;
    $156 = $155 >>> 0 > 1;
    $157 = $152 >>> 0 > 1;
    $or_cond241 = $156 & $157;
    if ($or_cond241) {
      label = 27;
      break;
    } else {
      $scaling_0 = 1;
      label = 28;
      break;
    }
   case 27:
    $159 = $155 >>> 0 < $152 >>> 0;
    $_ = $159 ? $155 : $152;
    $scaling_0 = $_;
    label = 28;
    break;
   case 28:
    $161 = $150 + 48 | 0;
    _FT_Matrix_Multiply_Scaled($100, $161, $scaling_0);
    $162 = $150 + 68 | 0;
    _FT_Vector_Transform_Scaled($162, $100, $scaling_0);
    $163 = HEAP32[$151 >> 2] | 0;
    $164 = HEAP32[$87 >> 2] | 0;
    $165 = _FT_MulDiv($163, $164, $scaling_0) | 0;
    $storemerge238 = $165;
    label = 30;
    break;
   case 29:
    $167 = $150 + 48 | 0;
    $168 = $167;
    _memcpy($168 | 0, $99 | 0, 16);
    $169 = $150 + 68 | 0;
    $170 = $169;
    $ld$0$0 = $146 | 0;
    $171$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $146 + 4 | 0;
    $171$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $st$2$0 = $170 | 0;
    HEAP32[$st$2$0 >> 2] = $171$0;
    $st$3$1 = $170 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $171$1;
    $172 = HEAP32[$87 >> 2] | 0;
    $storemerge238 = $172;
    label = 30;
    break;
   case 30:
    HEAP32[$151 >> 2] = $storemerge238;
    $174 = $150 + 68 | 0;
    $175 = $150 + 60 | 0;
    $176 = HEAP32[$175 >> 2] | 0;
    $177 = ($176 | 0) < 0;
    $178 = -$176 | 0;
    $179 = $177 ? $178 : $176;
    $180 = ($179 | 0) == 65536;
    if ($180) {
      label = 34;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    $182 = _FT_DivFix($storemerge238, $179) | 0;
    $183 = $182 >>> 0 > 1e5;
    if ($183) {
      label = 32;
      break;
    } else {
      $storemerge239 = $182;
      label = 33;
      break;
    }
   case 32:
    $185 = $182 + 500 | 0;
    $186 = ($185 >>> 0) / 1e3 >>> 0;
    $storemerge239 = $186;
    label = 33;
    break;
   case 33:
    HEAP32[$151 >> 2] = $storemerge239;
    $188 = $150 + 48 | 0;
    $189 = HEAP32[$188 >> 2] | 0;
    $190 = _FT_DivFix($189, $179) | 0;
    HEAP32[$188 >> 2] = $190;
    $191 = $150 + 56 | 0;
    $192 = HEAP32[$191 >> 2] | 0;
    $193 = _FT_DivFix($192, $179) | 0;
    HEAP32[$191 >> 2] = $193;
    $194 = $150 + 52 | 0;
    $195 = HEAP32[$194 >> 2] | 0;
    $196 = _FT_DivFix($195, $179) | 0;
    HEAP32[$194 >> 2] = $196;
    $197 = HEAP32[$175 >> 2] | 0;
    $198 = _FT_DivFix($197, $179) | 0;
    HEAP32[$175 >> 2] = $198;
    $199 = $174 | 0;
    $200 = HEAP32[$199 >> 2] | 0;
    $201 = _FT_DivFix($200, $179) | 0;
    HEAP32[$199 >> 2] = $201;
    $202 = $150 + 72 | 0;
    $203 = HEAP32[$202 >> 2] | 0;
    $204 = _FT_DivFix($203, $179) | 0;
    HEAP32[$202 >> 2] = $204;
    label = 34;
    break;
   case 34:
    $206 = $174 | 0;
    $207 = HEAP32[$206 >> 2] | 0;
    $208 = $207 >> 16;
    HEAP32[$206 >> 2] = $208;
    $209 = $150 + 72 | 0;
    $210 = HEAP32[$209 >> 2] | 0;
    $211 = $210 >> 16;
    HEAP32[$209 >> 2] = $211;
    $212 = ($148 | 0) == 0;
    if ($212) {
      label = 35;
      break;
    } else {
      $i_0258 = $148;
      label = 25;
      break;
    }
   case 35:
    $213 = $pure_cff_1 << 24 >> 24 == 0;
    if ($213) {
      label = 68;
      break;
    } else {
      label = 36;
      break;
    }
   case 36:
    $215 = $62 + 8 | 0;
    $216 = $215;
    $217 = HEAP32[$216 >> 2] | 0;
    $218 = $cffface | 0;
    HEAP32[$218 >> 2] = $217;
    $219 = HEAP32[$81 >> 2] | 0;
    $220 = ($219 | 0) == 65535;
    if ($220) {
      label = 38;
      break;
    } else {
      label = 37;
      break;
    }
   case 37:
    $222 = $62 + 1168 | 0;
    $223 = $222;
    $224 = HEAP32[$223 >> 2] | 0;
    $225 = $224 + 1 | 0;
    $storemerge = $225;
    label = 39;
    break;
   case 38:
    $227 = $62 + 1184 | 0;
    $228 = $227;
    $229 = HEAP32[$228 >> 2] | 0;
    $storemerge = $229;
    label = 39;
    break;
   case 39:
    HEAP32[$79 >> 2] = $storemerge;
    $231 = $62 + 1404 | 0;
    $232 = $231;
    $233 = HEAP32[$232 >> 2] | 0;
    $234 = $233 >> 16;
    $235 = $cffface + 52 | 0;
    HEAP32[$235 >> 2] = $234;
    $236 = $62 + 1408 | 0;
    $237 = $236;
    $238 = HEAP32[$237 >> 2] | 0;
    $239 = $238 >> 16;
    $240 = $cffface + 56 | 0;
    HEAP32[$240 >> 2] = $239;
    $241 = $62 + 1412 | 0;
    $242 = $241;
    $243 = HEAP32[$242 >> 2] | 0;
    $244 = $243 + 65535 | 0;
    $245 = $244 >> 16;
    $246 = $cffface + 60 | 0;
    HEAP32[$246 >> 2] = $245;
    $247 = $62 + 1416 | 0;
    $248 = $247;
    $249 = HEAP32[$248 >> 2] | 0;
    $250 = $249 + 65535 | 0;
    $251 = $250 >> 16;
    $252 = $cffface + 64 | 0;
    HEAP32[$252 >> 2] = $251;
    $253 = HEAP32[$87 >> 2] | 0;
    $254 = $253 & 65535;
    $255 = $cffface + 68 | 0;
    HEAP16[$255 >> 1] = $254;
    $256 = HEAP32[$252 >> 2] | 0;
    $257 = $256 & 65535;
    $258 = $cffface + 70 | 0;
    HEAP16[$258 >> 1] = $257;
    $259 = HEAP32[$240 >> 2] | 0;
    $260 = $259 & 65535;
    $261 = $cffface + 72 | 0;
    HEAP16[$261 >> 1] = $260;
    $262 = HEAP16[$255 >> 1] | 0;
    $263 = $262 & 65535;
    $264 = $263 * 12 & -1;
    $265 = ($264 >>> 0) / 10 >>> 0;
    $266 = $265 & 65535;
    $267 = $cffface + 74 | 0;
    HEAP16[$267 >> 1] = $266;
    $sext = $265 << 16;
    $268 = $sext >> 16;
    $269 = HEAP16[$258 >> 1] | 0;
    $270 = $269 << 16 >> 16;
    $271 = HEAP16[$261 >> 1] | 0;
    $272 = $271 << 16 >> 16;
    $273 = $270 - $272 | 0;
    $274 = ($268 | 0) < ($273 | 0);
    if ($274) {
      label = 40;
      break;
    } else {
      label = 41;
      break;
    }
   case 40:
    $276 = $273 & 65535;
    HEAP16[$267 >> 1] = $276;
    label = 41;
    break;
   case 41:
    $278 = $62 + 1356 | 0;
    $279 = $278;
    $280 = HEAP32[$279 >> 2] | 0;
    $281 = $280 >>> 16;
    $282 = $281 & 65535;
    $283 = $cffface + 80 | 0;
    HEAP16[$283 >> 1] = $282;
    $284 = $62 + 1360 | 0;
    $285 = $284;
    $286 = HEAP32[$285 >> 2] | 0;
    $287 = $286 >>> 16;
    $288 = $287 & 65535;
    $289 = $cffface + 82 | 0;
    HEAP16[$289 >> 1] = $288;
    $290 = _cff_index_get_name($63, $face_index) | 0;
    $291 = $cffface + 20 | 0;
    HEAP32[$291 >> 2] = $290;
    $292 = ($290 | 0) == 0;
    if ($292) {
      label = 53;
      break;
    } else {
      label = 42;
      break;
    }
   case 42:
    $294 = $62 + 1336 | 0;
    $295 = $294;
    $296 = HEAP32[$295 >> 2] | 0;
    $297 = _cff_index_get_sid_string($63, $296) | 0;
    $298 = HEAP32[$291 >> 2] | 0;
    _remove_subset_prefix($298);
    $299 = $62 + 1340 | 0;
    $300 = $299;
    $301 = HEAP32[$300 >> 2] | 0;
    $302 = ($301 | 0) == 0;
    if ($302) {
      $family_0 = $298;
      label = 44;
      break;
    } else {
      label = 43;
      break;
    }
   case 43:
    $304 = _cff_index_get_sid_string($63, $301) | 0;
    $305 = ($304 | 0) == 0;
    $_242 = $305 ? $298 : $304;
    $family_0 = $_242;
    label = 44;
    break;
   case 44:
    $307 = ($297 | 0) == 0;
    $308 = ($family_0 | 0) == 0;
    $or_cond243 = $307 | $308;
    if ($or_cond243) {
      label = 57;
      break;
    } else {
      label = 45;
      break;
    }
   case 45:
    $309 = HEAP8[$297] | 0;
    $310 = $309 << 24 >> 24 == 0;
    if ($310) {
      label = 57;
      break;
    } else {
      $fullp_0_ph263 = $297;
      $family_1_ph264 = $family_0;
      $311 = $309;
      label = 46;
      break;
    }
   case 46:
    $family_1257 = $family_1_ph264;
    $313 = $311;
    label = 47;
    break;
   case 47:
    $314 = HEAP8[$family_1257] | 0;
    $315 = $313 << 24 >> 24 == $314 << 24 >> 24;
    if ($315) {
      label = 48;
      break;
    } else {
      label = 50;
      break;
    }
   case 48:
    $317 = $family_1257 + 1 | 0;
    $family_1_ph_be = $317;
    label = 49;
    break;
   case 49:
    $fullp_0_ph_be = $fullp_0_ph263 + 1 | 0;
    $318 = HEAP8[$fullp_0_ph_be] | 0;
    $319 = $318 << 24 >> 24 == 0;
    if ($319) {
      label = 57;
      break;
    } else {
      $fullp_0_ph263 = $fullp_0_ph_be;
      $family_1_ph264 = $family_1_ph_be;
      $311 = $318;
      label = 46;
      break;
    }
   case 50:
    if (($313 << 24 >> 24 | 0) == 32 | ($313 << 24 >> 24 | 0) == 45) {
      $family_1_ph_be = $family_1257;
      label = 49;
      break;
    } else {
      label = 51;
      break;
    }
   case 51:
    if (($314 << 24 >> 24 | 0) == 32 | ($314 << 24 >> 24 | 0) == 45) {
      label = 52;
      break;
    } else if (($314 << 24 >> 24 | 0) == 0) {
      label = 55;
      break;
    } else {
      label = 57;
      break;
    }
   case 52:
    $323 = $family_1257 + 1 | 0;
    $324 = HEAP8[$fullp_0_ph263] | 0;
    $325 = $324 << 24 >> 24 == 0;
    if ($325) {
      label = 57;
      break;
    } else {
      $family_1257 = $323;
      $313 = $324;
      label = 47;
      break;
    }
   case 53:
    $327 = $62 + 1492 | 0;
    $328 = $327;
    $329 = HEAP32[$328 >> 2] | 0;
    $330 = _cff_index_get_sid_string($63, $329) | 0;
    $331 = ($330 | 0) == 0;
    if ($331) {
      label = 57;
      break;
    } else {
      label = 54;
      break;
    }
   case 54:
    $333 = _cff_strcpy($61, $330) | 0;
    HEAP32[$291 >> 2] = $333;
    label = 57;
    break;
   case 55:
    $335 = _cff_strcpy($61, $fullp_0_ph263) | 0;
    $336 = ($335 | 0) == 0;
    if ($336) {
      label = 57;
      break;
    } else {
      label = 56;
      break;
    }
   case 56:
    $338 = $cffface + 24 | 0;
    HEAP32[$338 >> 2] = $335;
    label = 58;
    break;
   case 57:
    $339 = _cff_strcpy($61, 5321780) | 0;
    $340 = $cffface + 24 | 0;
    HEAP32[$340 >> 2] = $339;
    label = 58;
    break;
   case 58:
    $342 = $sfnt_format_0 << 24 >> 24 == 0;
    $_244 = $342 ? 2065 : 2073;
    $343 = $62 + 1348 | 0;
    $344 = HEAP8[$343] | 0;
    $345 = $344 << 24 >> 24 == 0;
    $346 = $_244 | 4;
    $flags_1 = $345 ? $_244 : $346;
    $347 = $cffface + 8 | 0;
    HEAP32[$347 >> 2] = $flags_1;
    $348 = $62 + 1352 | 0;
    $349 = $348;
    $350 = HEAP32[$349 >> 2] | 0;
    $not_ = ($350 | 0) != 0;
    $_245 = $not_ & 1;
    $351 = $62 + 1344 | 0;
    $352 = $351;
    $353 = HEAP32[$352 >> 2] | 0;
    $354 = _cff_index_get_sid_string($63, $353) | 0;
    $355 = ($354 | 0) == 0;
    if ($355) {
      $flags_3 = $_245;
      label = 62;
      break;
    } else {
      label = 59;
      break;
    }
   case 59:
    $357 = _strcmp($354 | 0, 5321104) | 0;
    $358 = ($357 | 0) == 0;
    if ($358) {
      label = 61;
      break;
    } else {
      label = 60;
      break;
    }
   case 60:
    $360 = _strcmp($354 | 0, 5320416) | 0;
    $361 = ($360 | 0) == 0;
    if ($361) {
      label = 61;
      break;
    } else {
      $flags_3 = $_245;
      label = 62;
      break;
    }
   case 61:
    $363 = $_245 | 2;
    $flags_3 = $363;
    label = 62;
    break;
   case 62:
    $365 = $flags_3 & 2;
    $366 = ($365 | 0) == 0;
    if ($366) {
      label = 63;
      break;
    } else {
      $flags_4 = $flags_3;
      label = 67;
      break;
    }
   case 63:
    $368 = $cffface + 24 | 0;
    $369 = HEAP32[$368 >> 2] | 0;
    $370 = ($369 | 0) == 0;
    if ($370) {
      $flags_4 = $flags_3;
      label = 67;
      break;
    } else {
      label = 64;
      break;
    }
   case 64:
    $372 = _strncmp($369 | 0, 5321104, 4) | 0;
    $373 = ($372 | 0) == 0;
    if ($373) {
      label = 66;
      break;
    } else {
      label = 65;
      break;
    }
   case 65:
    $375 = _strncmp($369 | 0, 5320416, 5) | 0;
    $376 = ($375 | 0) == 0;
    if ($376) {
      label = 66;
      break;
    } else {
      $flags_4 = $flags_3;
      label = 67;
      break;
    }
   case 66:
    $378 = $flags_3 | 2;
    $flags_4 = $378;
    label = 67;
    break;
   case 67:
    $380 = $cffface + 12 | 0;
    HEAP32[$380 >> 2] = $flags_4;
    label = 68;
    break;
   case 68:
    $382 = HEAP32[$81 >> 2] | 0;
    $383 = ($382 | 0) == 65535;
    if ($383) {
      label = 69;
      break;
    } else {
      label = 70;
      break;
    }
   case 69:
    $385 = $cffface + 8 | 0;
    $386 = HEAP32[$385 >> 2] | 0;
    $387 = $386 | 512;
    HEAP32[$385 >> 2] = $387;
    label = 70;
    break;
   case 70:
    $389 = HEAP32[$81 >> 2] | 0;
    $390 = ($389 | 0) == 65535;
    $or_cond246 = $390 | $213;
    if ($or_cond246) {
      label = 72;
      break;
    } else {
      label = 71;
      break;
    }
   case 71:
    $392 = $cffface + 8 | 0;
    $393 = HEAP32[$392 >> 2] | 0;
    $394 = $393 | 4096;
    HEAP32[$392 >> 2] = $394;
    label = 72;
    break;
   case 72:
    $395 = $cffface + 36 | 0;
    $396 = HEAP32[$395 >> 2] | 0;
    $397 = $cffface + 40 | 0;
    $nn_0 = 0;
    label = 73;
    break;
   case 73:
    $399 = $nn_0 >>> 0 < $396 >>> 0;
    if ($399) {
      label = 74;
      break;
    } else {
      label = 78;
      break;
    }
   case 74:
    $401 = HEAP32[$397 >> 2] | 0;
    $402 = $401 + ($nn_0 << 2) | 0;
    $403 = HEAP32[$402 >> 2] | 0;
    $404 = $403 + 8 | 0;
    $405 = HEAP16[$404 >> 1] | 0;
    $406 = $405 << 16 >> 16 == 3;
    if ($406) {
      label = 75;
      break;
    } else {
      $412 = $405;
      label = 77;
      break;
    }
   case 75:
    $408 = $403 + 10 | 0;
    $409 = HEAP16[$408 >> 1] | 0;
    $410 = $409 << 16 >> 16 == 1;
    if ($410) {
      $nn_1 = $nn_0;
      label = 85;
      break;
    } else {
      label = 76;
      break;
    }
   case 76:
    $_pr = HEAP16[$404 >> 1] | 0;
    $412 = $_pr;
    label = 77;
    break;
   case 77:
    $413 = $412 << 16 >> 16 == 0;
    $414 = $nn_0 + 1 | 0;
    if ($413) {
      $nn_1 = $nn_0;
      label = 85;
      break;
    } else {
      $nn_0 = $414;
      label = 73;
      break;
    }
   case 78:
    if ($213) {
      label = 80;
      break;
    } else {
      label = 79;
      break;
    }
   case 79:
    $417 = HEAP32[$81 >> 2] | 0;
    $418 = ($417 | 0) == 65535;
    if ($418) {
      label = 80;
      break;
    } else {
      label = 93;
      break;
    }
   case 80:
    $420 = $nn_0 + 1 | 0;
    $421 = $420 >>> 0 > 15;
    if ($421) {
      label = 93;
      break;
    } else {
      label = 81;
      break;
    }
   case 81:
    $423 = $cmaprec | 0;
    HEAP32[$423 >> 2] = $cffface;
    $424 = $cmaprec + 8 | 0;
    HEAP16[$424 >> 1] = 3;
    $425 = $cmaprec + 10 | 0;
    HEAP16[$425 >> 1] = 1;
    $426 = $cmaprec + 4 | 0;
    HEAP32[$426 >> 2] = 1970170211;
    $427 = HEAP32[$395 >> 2] | 0;
    $428 = $cmaprec;
    $429 = _FT_CMap_New(5317696, 0, $428, 0) | 0;
    HEAP32[$error >> 2] = $429;
    if (($429 | 0) == 163 | ($429 | 0) == 0) {
      label = 82;
      break;
    } else {
      label = 93;
      break;
    }
   case 82:
    HEAP32[$error >> 2] = 0;
    $431 = $cffface + 92 | 0;
    $432 = HEAP32[$431 >> 2] | 0;
    $433 = ($432 | 0) == 0;
    if ($433) {
      label = 83;
      break;
    } else {
      $nn_1 = $427;
      label = 85;
      break;
    }
   case 83:
    $435 = HEAP32[$395 >> 2] | 0;
    $436 = ($427 | 0) == ($435 | 0);
    if ($436) {
      $nn_1 = $427;
      label = 85;
      break;
    } else {
      label = 84;
      break;
    }
   case 84:
    $438 = $cffface + 40 | 0;
    $439 = HEAP32[$438 >> 2] | 0;
    $440 = $439 + ($427 << 2) | 0;
    $441 = HEAP32[$440 >> 2] | 0;
    HEAP32[$431 >> 2] = $441;
    $nn_1 = $427;
    label = 85;
    break;
   case 85:
    $442 = $nn_1 >>> 0 > 15;
    if ($442) {
      label = 93;
      break;
    } else {
      label = 86;
      break;
    }
   case 86:
    $444 = $62 + 124 | 0;
    $445 = $444;
    $446 = HEAP32[$445 >> 2] | 0;
    $447 = ($446 | 0) == 0;
    if ($447) {
      label = 93;
      break;
    } else {
      label = 87;
      break;
    }
   case 87:
    $449 = $cmaprec | 0;
    HEAP32[$449 >> 2] = $cffface;
    $450 = $cmaprec + 8 | 0;
    HEAP16[$450 >> 1] = 7;
    $451 = $62 + 120 | 0;
    $452 = $451;
    $453 = HEAP32[$452 >> 2] | 0;
    $454 = ($453 | 0) == 0;
    if ($454) {
      label = 88;
      break;
    } else {
      label = 89;
      break;
    }
   case 88:
    $456 = $cmaprec + 10 | 0;
    HEAP16[$456 >> 1] = 0;
    $457 = $cmaprec + 4 | 0;
    HEAP32[$457 >> 2] = 1094995778;
    label = 92;
    break;
   case 89:
    $459 = ($453 | 0) == 1;
    $460 = $cmaprec + 10 | 0;
    if ($459) {
      label = 90;
      break;
    } else {
      label = 91;
      break;
    }
   case 90:
    HEAP16[$460 >> 1] = 1;
    $462 = $cmaprec + 4 | 0;
    HEAP32[$462 >> 2] = 1094992453;
    label = 92;
    break;
   case 91:
    HEAP16[$460 >> 1] = 2;
    $464 = $cmaprec + 4 | 0;
    HEAP32[$464 >> 2] = 1094992451;
    label = 92;
    break;
   case 92:
    $466 = $cmaprec;
    $467 = _FT_CMap_New(5317736, 0, $466, 0) | 0;
    HEAP32[$error >> 2] = $467;
    label = 93;
    break;
   case 93:
    $469 = HEAP32[$error >> 2] | 0;
    $_0 = $469;
    label = 95;
    break;
   case 94:
    HEAP32[$error >> 2] = 2;
    label = 93;
    break;
   case 95:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _cff_face_done($cffface) {
  $cffface = $cffface | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cffface;
    $2 = ($cffface | 0) == 0;
    if ($2) {
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $cffface + 100 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $cffface + 532 | 0;
    $7 = $6;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = $8 + 12 | 0;
    $12 = $11;
    $13 = HEAP32[$12 >> 2] | 0;
    FUNCTION_TABLE_vi[$13 & 1023]($1);
    label = 4;
    break;
   case 4:
    $15 = $cffface + 692 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $19 = $16;
    _cff_font_done($19);
    $20 = HEAP32[$15 >> 2] | 0;
    $21 = $20;
    _ft_mem_free($5, $21);
    HEAP32[$15 >> 2] = 0;
    label = 6;
    break;
   case 6:
    return;
  }
}
function _cff_size_init($cffsize) {
  $cffsize = $cffsize | 0;
  var $error = 0, $priv = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $i_0 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 200 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $priv = __stackBase__ + 4 | 0;
    $1 = $cffsize;
    HEAP32[$error >> 2] = 0;
    $2 = _cff_size_get_globals_funcs($1) | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 8;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $cffsize | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + 692 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $6 + 100 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = _ft_mem_alloc($10, 132, $error) | 0;
    $12 = HEAP32[$error >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 3;
      break;
    } else {
      label = 9;
      break;
    }
   case 3:
    $15 = $8 + 1324 | 0;
    $16 = $15;
    _cff_make_private_dict($16, $priv);
    $17 = $2 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = HEAP32[$5 >> 2] | 0;
    $20 = $19 + 100 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $11;
    $23 = FUNCTION_TABLE_iiii[$18 & 1023]($21, $priv, $22) | 0;
    HEAP32[$error >> 2] = $23;
    $24 = ($23 | 0) == 0;
    if ($24) {
      label = 4;
      break;
    } else {
      label = 9;
      break;
    }
   case 4:
    $26 = $8 + 1892 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $8 + 1896 | 0;
    $29 = $28;
    $30 = $11 + 4 | 0;
    $31 = $30;
    $i_0 = $27;
    label = 5;
    break;
   case 5:
    $33 = ($i_0 | 0) == 0;
    if ($33) {
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $35 = $i_0 - 1 | 0;
    $36 = $29 + ($35 << 2) | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    _cff_make_private_dict($37, $priv);
    $38 = HEAP32[$17 >> 2] | 0;
    $39 = HEAP32[$5 >> 2] | 0;
    $40 = $39 + 100 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = $31 + ($35 << 2) | 0;
    $43 = FUNCTION_TABLE_iiii[$38 & 1023]($41, $priv, $42) | 0;
    HEAP32[$error >> 2] = $43;
    $44 = ($43 | 0) == 0;
    if ($44) {
      $i_0 = $35;
      label = 5;
      break;
    } else {
      label = 9;
      break;
    }
   case 7:
    $46 = $11;
    $47 = $cffsize + 40 | 0;
    HEAP32[$47 >> 2] = $46;
    label = 8;
    break;
   case 8:
    $49 = $cffsize + 44 | 0;
    HEAP32[$49 >> 2] = -1;
    label = 9;
    break;
   case 9:
    $50 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $50 | 0;
  }
  return 0;
}
function _cff_size_done($cffsize) {
  $cffsize = $cffsize | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $i_09 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cffsize | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 692 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $cffsize + 40 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6;
    $8 = ($6 | 0) == 0;
    if ($8) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = $cffsize;
    $11 = _cff_size_get_globals_funcs($10) | 0;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $14 = $11 + 8 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $6;
    $17 = HEAP32[$16 >> 2] | 0;
    FUNCTION_TABLE_vi[$15 & 1023]($17);
    $18 = $4 + 1892 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 5;
      break;
    } else {
      $i_09 = $19;
      label = 4;
      break;
    }
   case 4:
    $21 = HEAP32[$14 >> 2] | 0;
    $22 = $i_09 - 1 | 0;
    $23 = $7 + 4 + ($22 << 2) | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    FUNCTION_TABLE_vi[$21 & 1023]($24);
    $25 = ($22 | 0) == 0;
    if ($25) {
      label = 5;
      break;
    } else {
      $i_09 = $22;
      label = 4;
      break;
    }
   case 5:
    return;
  }
}
function _cff_slot_init($slot) {
  $slot = $slot | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $slot + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 692 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 2052 | 0;
    $6 = $5;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = $2 + 96 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 + 4 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13;
    $15 = _FT_Get_Module($14, 5322380) | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $18 = $15;
    $19 = $7 + 8 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = FUNCTION_TABLE_ii[$20 & 1023]($18) | 0;
    $22 = $21;
    $23 = $slot + 156 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24 + 36 | 0;
    HEAP32[$25 >> 2] = $22;
    label = 4;
    break;
   case 4:
    return 0;
  }
  return 0;
}
function _cff_cmap_encoding_init($cmap) {
  $cmap = $cmap | 0;
  HEAP32[$cmap + 16 >> 2] = ((HEAP32[(HEAP32[$cmap >> 2] | 0) + 692 >> 2] | 0) + 116 | 0) + 524 | 0;
  return 0;
}
function _cff_cmap_encoding_done($cmap) {
  $cmap = $cmap | 0;
  HEAP32[$cmap + 16 >> 2] = 0;
  return;
}
function _cff_cmap_encoding_char_index($cmap, $char_code) {
  $cmap = $cmap | 0;
  $char_code = $char_code | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $char_code >>> 0 < 256;
    if ($1) {
      label = 2;
      break;
    } else {
      $result_0 = 0;
      label = 3;
      break;
    }
   case 2:
    $3 = $cmap + 16 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + ($char_code << 1) | 0;
    $6 = HEAP16[$5 >> 1] | 0;
    $7 = $6 & 65535;
    $result_0 = $7;
    label = 3;
    break;
   case 3:
    return $result_0 | 0;
  }
  return 0;
}
function _cff_cmap_encoding_char_next($cmap, $pchar_code) {
  $cmap = $cmap | 0;
  $pchar_code = $pchar_code | 0;
  var $1 = 0, $2 = 0, $3 = 0, $result_0 = 0, $code_0_in = 0, $code_0 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $result_1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$pchar_code >> 2] | 0;
    HEAP32[$pchar_code >> 2] = 0;
    $2 = $1 >>> 0 < 255;
    if ($2) {
      label = 2;
      break;
    } else {
      $result_1 = 0;
      label = 6;
      break;
    }
   case 2:
    $3 = $cmap + 16 | 0;
    $code_0_in = $1;
    $result_0 = 0;
    label = 3;
    break;
   case 3:
    $code_0 = $code_0_in + 1 | 0;
    $5 = $code_0 >>> 0 > 255;
    if ($5) {
      $result_1 = $result_0;
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $7 = HEAP32[$3 >> 2] | 0;
    $8 = $7 + ($code_0 << 1) | 0;
    $9 = HEAP16[$8 >> 1] | 0;
    $10 = $9 & 65535;
    $11 = $9 << 16 >> 16 == 0;
    if ($11) {
      $code_0_in = $code_0;
      $result_0 = $10;
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    HEAP32[$pchar_code >> 2] = $code_0;
    $result_1 = $10;
    label = 6;
    break;
   case 6:
    return $result_1 | 0;
  }
  return 0;
}
function _cff_index_get_string($font, $element) {
  $font = $font | 0;
  $element = $element | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $font + 1312 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 >>> 0 > $element >>> 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $10 = 0;
      label = 3;
      break;
    }
   case 2:
    $5 = $font + 1316 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + ($element << 2) | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $10 = $8;
    label = 3;
    break;
   case 3:
    return $10 | 0;
  }
  return 0;
}
function _cff_encoding_done($encoding) {
  $encoding = $encoding | 0;
  HEAP32[$encoding >> 2] = 0;
  HEAP32[$encoding + 4 >> 2] = 0;
  HEAP32[$encoding + 8 >> 2] = 0;
  return;
}
function _Load_Glyph433($cffslot, $cffsize, $glyph_index, $load_flags) {
  $cffslot = $cffslot | 0;
  $cffsize = $cffsize | 0;
  $glyph_index = $glyph_index | 0;
  $load_flags = $load_flags | 0;
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $_load_flags = 0, $7 = 0, $8 = 0, $size_0 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cffslot;
    $2 = ($cffslot | 0) == 0;
    if ($2) {
      $_0 = 37;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $4 = $cffsize;
    $5 = ($cffsize | 0) == 0;
    $6 = $load_flags | 3;
    $_load_flags = $5 ? $6 : $load_flags;
    $7 = $_load_flags & 1;
    $8 = ($7 | 0) == 0;
    $size_0 = $8 ? $4 : 0;
    $9 = ($size_0 | 0) == 0;
    if ($9) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = $cffsize | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $cffslot + 4 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($12 | 0) == ($14 | 0);
    if ($15) {
      label = 4;
      break;
    } else {
      $_0 = 35;
      label = 5;
      break;
    }
   case 4:
    $17 = _cff_slot_load($1, $size_0, $glyph_index, $_load_flags) | 0;
    $_0 = $17;
    label = 5;
    break;
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function _cff_get_kerning($ttface, $left_glyph, $right_glyph, $kerning) {
  $ttface = $ttface | 0;
  $left_glyph = $left_glyph | 0;
  $right_glyph = $right_glyph | 0;
  $kerning = $kerning | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $ttface + 532 | 0;
    $2 = $1;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $kerning | 0;
    HEAP32[$4 >> 2] = 0;
    $5 = $kerning + 4 | 0;
    HEAP32[$5 >> 2] = 0;
    $6 = ($3 | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $ttface;
    $9 = $3 + 128 | 0;
    $10 = $9;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = FUNCTION_TABLE_iiii[$11 & 1023]($8, $left_glyph, $right_glyph) | 0;
    HEAP32[$4 >> 2] = $12;
    label = 3;
    break;
   case 3:
    return 0;
  }
  return 0;
}
function _cff_get_advances($face, $start, $count, $flags, $advances) {
  $face = $face | 0;
  $start = $start | 0;
  $count = $count | 0;
  $flags = $flags | 0;
  $advances = $advances | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_in = 0, $nn_013 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $error_1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 84 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $flags | 256;
    $4 = $face + 88 | 0;
    $5 = ($count | 0) == 0;
    if ($5) {
      $error_1 = 0;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $flags & 16;
    $7 = ($6 | 0) == 0;
    $8 = $2 + 60 | 0;
    $9 = $2 + 56 | 0;
    $_in = $7 ? $9 : $8;
    $nn_013 = 0;
    label = 3;
    break;
   case 3:
    $11 = HEAP32[$4 >> 2] | 0;
    $12 = $nn_013 + $start | 0;
    $13 = _Load_Glyph433($2, $11, $12, $3) | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 4;
      break;
    } else {
      $error_1 = $13;
      label = 5;
      break;
    }
   case 4:
    $16 = HEAP32[$_in >> 2] | 0;
    $17 = $advances + ($nn_013 << 2) | 0;
    HEAP32[$17 >> 2] = $16;
    $18 = $nn_013 + 1 | 0;
    $19 = $18 >>> 0 < $count >>> 0;
    if ($19) {
      $nn_013 = $18;
      label = 3;
      break;
    } else {
      $error_1 = 0;
      label = 5;
      break;
    }
   case 5:
    return $error_1 | 0;
  }
  return 0;
}
function _cff_size_request($size, $req) {
  $size = $size | 0;
  $req = $req | 0;
  var $strike_index = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $i_029 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $x_scale_0 = 0, $y_scale_0 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $strike_index = __stackBase__ | 0;
    $1 = $size;
    $2 = $size | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 + 8 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 & 2;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = $3;
    $10 = $3 + 532 | 0;
    $11 = $10;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + 148 | 0;
    $14 = $13;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = FUNCTION_TABLE_iiii[$15 & 1023]($9, $req, $strike_index) | 0;
    $17 = ($16 | 0) == 0;
    if ($17) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $19 = $size + 44 | 0;
    HEAP32[$19 >> 2] = -1;
    label = 5;
    break;
   case 4:
    $21 = HEAP32[$strike_index >> 2] | 0;
    $22 = _cff_size_select($size, $21) | 0;
    label = 12;
    break;
   case 5:
    $24 = HEAP32[$2 >> 2] | 0;
    $25 = $24;
    _FT_Request_Metrics($25, $req);
    $26 = _cff_size_get_globals_funcs($1) | 0;
    $27 = ($26 | 0) == 0;
    if ($27) {
      label = 12;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $29 = HEAP32[$2 >> 2] | 0;
    $30 = $29 + 692 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $size + 40 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $33;
    $35 = $31 + 1324 | 0;
    $36 = $35 + 64 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $26 + 4 | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = $33;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = $size + 16 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $size + 20 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = FUNCTION_TABLE_iiiiii[$39 & 1023]($41, $43, $45, 0, 0) | 0;
    $47 = $31 + 1892 | 0;
    $48 = HEAP32[$47 >> 2] | 0;
    $49 = ($48 | 0) == 0;
    if ($49) {
      label = 12;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $50 = $31 + 1896 | 0;
    $51 = $50;
    $i_029 = $48;
    label = 8;
    break;
   case 8:
    $53 = $i_029 - 1 | 0;
    $54 = $51 + ($53 << 2) | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = $55 + 64 | 0;
    $57 = HEAP32[$56 >> 2] | 0;
    $58 = ($37 | 0) == ($57 | 0);
    $59 = HEAP32[$42 >> 2] | 0;
    if ($58) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $61 = _FT_MulDiv($59, $37, $57) | 0;
    $62 = HEAP32[$44 >> 2] | 0;
    $63 = _FT_MulDiv($62, $37, $57) | 0;
    $y_scale_0 = $63;
    $x_scale_0 = $61;
    label = 11;
    break;
   case 10:
    $65 = HEAP32[$44 >> 2] | 0;
    $y_scale_0 = $65;
    $x_scale_0 = $59;
    label = 11;
    break;
   case 11:
    $67 = HEAP32[$38 >> 2] | 0;
    $68 = $34 + 4 + ($53 << 2) | 0;
    $69 = HEAP32[$68 >> 2] | 0;
    $70 = FUNCTION_TABLE_iiiiii[$67 & 1023]($69, $x_scale_0, $y_scale_0, 0, 0) | 0;
    $71 = ($53 | 0) == 0;
    if ($71) {
      label = 12;
      break;
    } else {
      $i_029 = $53;
      label = 8;
      break;
    }
   case 12:
    STACKTOP = __stackBase__;
    return 0;
  }
  return 0;
}
function _cff_size_select($size, $strike_index) {
  $size = $size | 0;
  $strike_index = $strike_index | 0;
  var $1 = 0, $2 = 0, $strike_index_c = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $i_024 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $x_scale_0 = 0, $y_scale_0 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size;
    $2 = $size + 44 | 0;
    $strike_index_c = $strike_index;
    HEAP32[$2 >> 2] = $strike_index_c;
    $3 = $size | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4;
    _FT_Select_Metrics($5, $strike_index);
    $6 = _cff_size_get_globals_funcs($1) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 8;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = HEAP32[$3 >> 2] | 0;
    $10 = $9 + 692 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $size + 40 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13;
    $15 = $11 + 1324 | 0;
    $16 = $15 + 64 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = $6 + 4 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $13;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $size + 16 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $size + 20 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = FUNCTION_TABLE_iiiiii[$19 & 1023]($21, $23, $25, 0, 0) | 0;
    $27 = $11 + 1892 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 8;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $30 = $11 + 1896 | 0;
    $31 = $30;
    $i_024 = $28;
    label = 4;
    break;
   case 4:
    $33 = $i_024 - 1 | 0;
    $34 = $31 + ($33 << 2) | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $35 + 64 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = ($17 | 0) == ($37 | 0);
    $39 = HEAP32[$22 >> 2] | 0;
    if ($38) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $41 = _FT_MulDiv($39, $17, $37) | 0;
    $42 = HEAP32[$24 >> 2] | 0;
    $43 = _FT_MulDiv($42, $17, $37) | 0;
    $y_scale_0 = $43;
    $x_scale_0 = $41;
    label = 7;
    break;
   case 6:
    $45 = HEAP32[$24 >> 2] | 0;
    $y_scale_0 = $45;
    $x_scale_0 = $39;
    label = 7;
    break;
   case 7:
    $47 = HEAP32[$18 >> 2] | 0;
    $48 = $14 + 4 + ($33 << 2) | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = FUNCTION_TABLE_iiiiii[$47 & 1023]($49, $x_scale_0, $y_scale_0, 0, 0) | 0;
    $51 = ($33 | 0) == 0;
    if ($51) {
      label = 8;
      break;
    } else {
      $i_024 = $33;
      label = 4;
      break;
    }
   case 8:
    return 0;
  }
  return 0;
}
function _cff_cmap_unicode_init($unicodes) {
  $unicodes = $unicodes | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $unicodes | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 692 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 1160 | 0;
    $6 = $5;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      $_0 = 163;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = $4 + 2056 | 0;
    $11 = $10;
    $12 = $2 + 100 | 0;
    $13 = HEAP32[$11 >> 2] | 0;
    $14 = HEAP32[$12 >> 2] | 0;
    $15 = $13 + 4 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $4 + 12 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $2;
    $20 = FUNCTION_TABLE_iiiiiii[$16 & 1023]($14, $unicodes, $18, 770, 0, $19) | 0;
    $_0 = $20;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _cff_cmap_unicode_done($unicodes) {
  $unicodes = $unicodes | 0;
  var $5 = 0;
  $5 = $unicodes + 20 | 0;
  _ft_mem_free(HEAP32[(HEAP32[$unicodes >> 2] | 0) + 100 >> 2] | 0, HEAP32[$5 >> 2] | 0);
  HEAP32[$5 >> 2] = 0;
  HEAP32[$unicodes + 16 >> 2] = 0;
  return;
}
function _cff_cmap_unicode_char_index($unicodes, $char_code) {
  $unicodes = $unicodes | 0;
  $char_code = $char_code | 0;
  return FUNCTION_TABLE_iii[HEAP32[(HEAP32[(HEAP32[(HEAP32[$unicodes >> 2] | 0) + 692 >> 2] | 0) + 2056 >> 2] | 0) + 8 >> 2] & 1023]($unicodes, $char_code) | 0;
}
function _cff_cmap_unicode_char_next($unicodes, $pchar_code) {
  $unicodes = $unicodes | 0;
  $pchar_code = $pchar_code | 0;
  return FUNCTION_TABLE_iii[HEAP32[(HEAP32[(HEAP32[(HEAP32[$unicodes >> 2] | 0) + 692 >> 2] | 0) + 2056 >> 2] | 0) + 12 >> 2] & 1023]($unicodes, $pchar_code) | 0;
}
function _cff_sid_to_glyph_name($face, $idx) {
  $face = $face | 0;
  $idx = $idx | 0;
  var $2 = 0;
  $2 = HEAP32[$face + 692 >> 2] | 0;
  return _cff_index_get_sid_string($2, HEAPU16[(HEAP32[$2 + 1160 >> 2] | 0) + ($idx << 1) >> 1] | 0) | 0;
}
function _cff_index_get_sid_string($font, $sid) {
  $font = $font | 0;
  $sid = $sid | 0;
  var $1 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($sid | 0) == 65535;
    if ($1) {
      $_0 = 0;
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $sid >>> 0 > 390;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $5 = $sid - 391 | 0;
    $6 = _cff_index_get_string($font, $5) | 0;
    $_0 = $6;
    label = 6;
    break;
   case 4:
    $8 = $font + 2056 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      $_0 = 0;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $12 = $9 + 20 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = FUNCTION_TABLE_ii[$13 & 1023]($sid) | 0;
    $_0 = $14;
    label = 6;
    break;
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _cff_font_done($font) {
  $font = $font | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $idx_034 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $font + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $font + 84 | 0;
    _cff_index_done($3);
    $4 = $font + 1208 | 0;
    _cff_index_done($4);
    $5 = $font + 20 | 0;
    _cff_index_done($5);
    $6 = $font + 1176 | 0;
    _cff_index_done($6);
    $7 = $font + 1892 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = HEAP32[$7 >> 2] | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 4;
      break;
    } else {
      $idx_034 = 0;
      label = 3;
      break;
    }
   case 3:
    $12 = $font + 1896 + ($idx_034 << 2) | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    _cff_subfont_done($2, $13);
    $14 = $idx_034 + 1 | 0;
    $15 = HEAP32[$7 >> 2] | 0;
    $16 = $14 >>> 0 < $15 >>> 0;
    if ($16) {
      $idx_034 = $14;
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $17 = $font + 1896 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $18;
    _ft_mem_free($2, $19);
    HEAP32[$17 >> 2] = 0;
    label = 5;
    break;
   case 5:
    $21 = $font + 116 | 0;
    _cff_encoding_done($21);
    $22 = $font + 1152 | 0;
    $23 = $font | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    _cff_charset_done($22, $24);
    $25 = $font + 1324 | 0;
    _cff_subfont_done($2, $25);
    $26 = $font + 2024 | 0;
    $27 = HEAP32[$23 >> 2] | 0;
    _CFF_Done_FD_Select($26, $27);
    $28 = $font + 2060 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $29;
    _ft_mem_free($2, $30);
    HEAP32[$28 >> 2] = 0;
    $31 = $font + 1304 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    _ft_mem_free($2, $32);
    HEAP32[$31 >> 2] = 0;
    $33 = $font + 1308 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $34;
    _ft_mem_free($2, $35);
    HEAP32[$33 >> 2] = 0;
    $36 = $font + 1316 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $37;
    _ft_mem_free($2, $38);
    HEAP32[$36 >> 2] = 0;
    $39 = $font + 1320 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    _ft_mem_free($2, $40);
    HEAP32[$39 >> 2] = 0;
    return;
  }
}
function _cff_index_done($idx) {
  $idx = $idx | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $idx | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 + 28 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $idx + 28 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    _FT_Stream_ReleaseFrame($2, $7);
    label = 4;
    break;
   case 4:
    $12 = $idx + 24 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13;
    _ft_mem_free($6, $14);
    $15 = $idx;
    _memset($15 | 0, 0, 32);
    label = 5;
    break;
   case 5:
    return;
  }
}
function _cff_subfont_done($memory, $subfont) {
  $memory = $memory | 0;
  $subfont = $subfont | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($subfont | 0) == 0;
    if ($1) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $subfont + 532 | 0;
    _cff_index_done($3);
    $4 = $subfont + 564 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5;
    _ft_mem_free($memory, $6);
    HEAP32[$4 >> 2] = 0;
    label = 3;
    break;
   case 3:
    return;
  }
}
function _cff_charset_done($charset, $stream) {
  $charset = $charset | 0;
  $stream = $stream | 0;
  var $2 = 0, $3 = 0;
  $2 = HEAP32[$stream + 28 >> 2] | 0;
  _cff_charset_free_cids($charset, $2);
  $3 = $charset + 8 | 0;
  _ft_mem_free($2, HEAP32[$3 >> 2] | 0);
  HEAP32[$3 >> 2] = 0;
  HEAP32[$charset >> 2] = 0;
  HEAP32[$charset + 4 >> 2] = 0;
  return;
}
function _CFF_Done_FD_Select($fdselect, $stream) {
  $fdselect = $fdselect | 0;
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $fdselect + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    _FT_Stream_ReleaseFrame($stream, $1);
    label = 3;
    break;
   case 3:
    $6 = $fdselect + 12 | 0;
    HEAP32[$6 >> 2] = 0;
    $7 = $fdselect | 0;
    HEAP8[$7] = 0;
    $8 = $fdselect + 4 | 0;
    HEAP32[$8 >> 2] = 0;
    return;
  }
}
function _cff_charset_free_cids($charset, $memory) {
  $charset = $charset | 0;
  $memory = $memory | 0;
  var $1 = 0;
  $1 = $charset + 12 | 0;
  _ft_mem_free($memory, HEAP32[$1 >> 2] | 0);
  HEAP32[$1 >> 2] = 0;
  HEAP32[$charset + 16 >> 2] = 0;
  return;
}
function _cff_font_load($library, $stream, $face_index, $font, $pure_cff) {
  $library = $library | 0;
  $stream = $stream | 0;
  $face_index = $face_index | 0;
  $font = $font | 0;
  $pure_cff = $pure_cff | 0;
  var $error = 0, $string_index = 0, $fd_index = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $59 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $74 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $84 = 0, $85 = 0, $87 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $idx_088 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $idx_1 = 0, $105 = 0, $106 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $124 = 0, $126 = 0, $127 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $137 = 0, $138 = 0, $140 = 0, $141 = 0, $not_ = 0, $_ = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $149 = 0, $150 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $159 = 0, $160 = 0, $162 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 68 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $string_index = __stackBase__ + 4 | 0;
    $fd_index = __stackBase__ + 36 | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $font;
    _memset($3 | 0, 0, 2072);
    $4 = $string_index;
    _memset($4 | 0, 0, 32);
    $5 = $font | 0;
    HEAP32[$5 >> 2] = $stream;
    $6 = $font + 4 | 0;
    HEAP32[$6 >> 2] = $2;
    $7 = $font + 1324 | 0;
    $8 = _FT_Stream_Pos($stream) | 0;
    $9 = _FT_Stream_ReadFields($stream, 5315092, $3) | 0;
    HEAP32[$error >> 2] = $9;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 2;
      break;
    } else {
      label = 39;
      break;
    }
   case 2:
    $12 = $font + 16 | 0;
    $13 = HEAP8[$12] | 0;
    $14 = $13 << 24 >> 24 == 1;
    if ($14) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $16 = $font + 18 | 0;
    $17 = HEAP8[$16] | 0;
    $18 = $17 & 255;
    $19 = ($17 & 255) < 4;
    if ($19) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $21 = $font + 19 | 0;
    $22 = HEAP8[$21] | 0;
    $23 = ($22 & 255) > 4;
    if ($23) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    HEAP32[$error >> 2] = 2;
    label = 39;
    break;
   case 6:
    $26 = $18 - 4 | 0;
    $27 = _FT_Stream_Skip($stream, $26) | 0;
    HEAP32[$error >> 2] = $27;
    $28 = ($27 | 0) == 0;
    if ($28) {
      label = 7;
      break;
    } else {
      label = 39;
      break;
    }
   case 7:
    $30 = $font + 20 | 0;
    $31 = _cff_index_init($30, $stream, 0) | 0;
    HEAP32[$error >> 2] = $31;
    $32 = ($31 | 0) == 0;
    if ($32) {
      label = 8;
      break;
    } else {
      label = 39;
      break;
    }
   case 8:
    $34 = $font + 1208 | 0;
    $35 = _cff_index_init($34, $stream, 0) | 0;
    HEAP32[$error >> 2] = $35;
    $36 = ($35 | 0) == 0;
    if ($36) {
      label = 9;
      break;
    } else {
      label = 39;
      break;
    }
   case 9:
    $38 = _cff_index_init($string_index, $stream, 1) | 0;
    HEAP32[$error >> 2] = $38;
    $39 = ($38 | 0) == 0;
    if ($39) {
      label = 10;
      break;
    } else {
      label = 39;
      break;
    }
   case 10:
    $41 = $font + 84 | 0;
    $42 = _cff_index_init($41, $stream, 1) | 0;
    HEAP32[$error >> 2] = $42;
    $43 = ($42 | 0) == 0;
    if ($43) {
      label = 11;
      break;
    } else {
      label = 39;
      break;
    }
   case 11:
    $45 = $font + 1316 | 0;
    $46 = $font + 1320 | 0;
    $47 = _cff_index_get_pointers($string_index, $45, $46) | 0;
    HEAP32[$error >> 2] = $47;
    $48 = ($47 | 0) == 0;
    if ($48) {
      label = 12;
      break;
    } else {
      label = 39;
      break;
    }
   case 12:
    $50 = $string_index + 8 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = $font + 1312 | 0;
    HEAP32[$52 >> 2] = $51;
    $53 = $font + 28 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = $font + 8 | 0;
    HEAP32[$55 >> 2] = $54;
    $56 = ($54 | 0) > ($face_index | 0);
    if ($56) {
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    HEAP32[$error >> 2] = 6;
    label = 14;
    break;
   case 14:
    $59 = ($face_index | 0) < 0;
    if ($59) {
      label = 39;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $61 = _cff_subfont_load($7, $34, $face_index, $stream, $8, $library) | 0;
    HEAP32[$error >> 2] = $61;
    $62 = ($61 | 0) == 0;
    if ($62) {
      label = 16;
      break;
    } else {
      label = 39;
      break;
    }
   case 16:
    $64 = $font + 1432 | 0;
    $65 = HEAP32[$64 >> 2] | 0;
    $66 = $65 + $8 | 0;
    $67 = _FT_Stream_Seek($stream, $66) | 0;
    HEAP32[$error >> 2] = $67;
    $68 = ($67 | 0) == 0;
    if ($68) {
      label = 17;
      break;
    } else {
      label = 39;
      break;
    }
   case 17:
    $70 = $font + 1176 | 0;
    $71 = _cff_index_init($70, $stream, 0) | 0;
    HEAP32[$error >> 2] = $71;
    $72 = ($71 | 0) == 0;
    if ($72) {
      label = 18;
      break;
    } else {
      label = 39;
      break;
    }
   case 18:
    $74 = $font + 1452 | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    $76 = ($75 | 0) == 65535;
    if ($76) {
      label = 30;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $78 = $font + 1484 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = $79 + $8 | 0;
    $81 = _FT_Stream_Seek($stream, $80) | 0;
    HEAP32[$error >> 2] = $81;
    $82 = ($81 | 0) == 0;
    if ($82) {
      label = 20;
      break;
    } else {
      label = 39;
      break;
    }
   case 20:
    $84 = _cff_index_init($fd_index, $stream, 0) | 0;
    HEAP32[$error >> 2] = $84;
    $85 = ($84 | 0) == 0;
    if ($85) {
      label = 21;
      break;
    } else {
      label = 39;
      break;
    }
   case 21:
    $87 = $fd_index + 8 | 0;
    $88 = HEAP32[$87 >> 2] | 0;
    $89 = $88 >>> 0 > 32;
    if ($89) {
      label = 29;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $91 = $font + 1892 | 0;
    HEAP32[$91 >> 2] = $88;
    $92 = HEAP32[$87 >> 2] | 0;
    $93 = _ft_mem_realloc($2, 568, 0, $92, 0, $error) | 0;
    $94 = $93;
    $95 = HEAP32[$error >> 2] | 0;
    $96 = ($95 | 0) == 0;
    if ($96) {
      label = 23;
      break;
    } else {
      label = 29;
      break;
    }
   case 23:
    $97 = HEAP32[$87 >> 2] | 0;
    $98 = ($97 | 0) == 0;
    if ($98) {
      $idx_1 = 0;
      label = 26;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $99 = HEAP32[$87 >> 2] | 0;
    $idx_088 = 0;
    label = 25;
    break;
   case 25:
    $101 = $94 + ($idx_088 * 568 & -1) | 0;
    $102 = $font + 1896 + ($idx_088 << 2) | 0;
    HEAP32[$102 >> 2] = $101;
    $103 = $idx_088 + 1 | 0;
    $104 = $103 >>> 0 < $99 >>> 0;
    if ($104) {
      $idx_088 = $103;
      label = 25;
      break;
    } else {
      $idx_1 = 0;
      label = 26;
      break;
    }
   case 26:
    $105 = HEAP32[$87 >> 2] | 0;
    $106 = $idx_1 >>> 0 < $105 >>> 0;
    if ($106) {
      label = 27;
      break;
    } else {
      label = 28;
      break;
    }
   case 27:
    $108 = $font + 1896 + ($idx_1 << 2) | 0;
    $109 = HEAP32[$108 >> 2] | 0;
    $110 = _cff_subfont_load($109, $fd_index, $idx_1, $stream, $8, $library) | 0;
    HEAP32[$error >> 2] = $110;
    $111 = ($110 | 0) == 0;
    $112 = $idx_1 + 1 | 0;
    if ($111) {
      $idx_1 = $112;
      label = 26;
      break;
    } else {
      label = 29;
      break;
    }
   case 28:
    $114 = $font + 2024 | 0;
    $115 = $font + 1184 | 0;
    $116 = HEAP32[$115 >> 2] | 0;
    $117 = $font + 1488 | 0;
    $118 = HEAP32[$117 >> 2] | 0;
    $119 = $118 + $8 | 0;
    $120 = _CFF_Load_FD_Select($114, $116, $stream, $119) | 0;
    HEAP32[$error >> 2] = $120;
    label = 29;
    break;
   case 29:
    _cff_index_done($fd_index);
    $121 = HEAP32[$error >> 2] | 0;
    $122 = ($121 | 0) == 0;
    if ($122) {
      label = 31;
      break;
    } else {
      label = 39;
      break;
    }
   case 30:
    $124 = $font + 1892 | 0;
    HEAP32[$124 >> 2] = 0;
    label = 31;
    break;
   case 31:
    $126 = HEAP32[$64 >> 2] | 0;
    $127 = ($126 | 0) == 0;
    if ($127) {
      label = 32;
      break;
    } else {
      label = 33;
      break;
    }
   case 32:
    HEAP32[$error >> 2] = 2;
    label = 39;
    break;
   case 33:
    $130 = $font + 1184 | 0;
    $131 = HEAP32[$130 >> 2] | 0;
    $132 = $font + 12 | 0;
    HEAP32[$132 >> 2] = $131;
    $133 = $font + 1308 | 0;
    $134 = _cff_index_get_pointers($41, $133, 0) | 0;
    HEAP32[$error >> 2] = $134;
    $135 = ($134 | 0) == 0;
    if ($135) {
      label = 34;
      break;
    } else {
      label = 39;
      break;
    }
   case 34:
    $137 = HEAP32[$132 >> 2] | 0;
    $138 = ($137 | 0) == 0;
    if ($138) {
      label = 38;
      break;
    } else {
      label = 35;
      break;
    }
   case 35:
    $140 = HEAP32[$74 >> 2] | 0;
    $141 = $pure_cff << 24 >> 24 != 0;
    $not_ = ($140 | 0) != 65535;
    $_ = $141 & $not_;
    $142 = $_ & 1;
    $143 = $font + 1152 | 0;
    $144 = $font + 1424 | 0;
    $145 = HEAP32[$144 >> 2] | 0;
    $146 = _cff_charset_load($143, $137, $stream, $8, $145, $142) | 0;
    HEAP32[$error >> 2] = $146;
    $147 = ($146 | 0) == 0;
    if ($147) {
      label = 36;
      break;
    } else {
      label = 39;
      break;
    }
   case 36:
    $149 = HEAP32[$74 >> 2] | 0;
    $150 = ($149 | 0) == 65535;
    if ($150) {
      label = 37;
      break;
    } else {
      label = 38;
      break;
    }
   case 37:
    $152 = $font + 116 | 0;
    $153 = HEAP32[$132 >> 2] | 0;
    $154 = $font + 1428 | 0;
    $155 = HEAP32[$154 >> 2] | 0;
    $156 = _cff_encoding_load($152, $143, $153, $stream, $8, $155) | 0;
    HEAP32[$error >> 2] = $156;
    $157 = ($156 | 0) == 0;
    if ($157) {
      label = 38;
      break;
    } else {
      label = 39;
      break;
    }
   case 38:
    $159 = _cff_index_get_name($font, $face_index) | 0;
    $160 = $font + 1304 | 0;
    HEAP32[$160 >> 2] = $159;
    label = 39;
    break;
   case 39:
    _cff_index_done($string_index);
    $162 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $162 | 0;
  }
  return 0;
}
function _cff_index_get_name($font, $element) {
  $font = $font | 0;
  $element = $element | 0;
  var $bytes = 0, $byte_len = 0, $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $name_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $bytes = __stackBase__ | 0;
    $byte_len = __stackBase__ + 4 | 0;
    $error = __stackBase__ + 8 | 0;
    $1 = $font + 20 | 0;
    $2 = $1 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 + 28 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = _cff_index_access_element($1, $element, $bytes, $byte_len) | 0;
    HEAP32[$error >> 2] = $6;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 2;
      break;
    } else {
      $name_0 = 0;
      label = 5;
      break;
    }
   case 2:
    $9 = HEAP32[$byte_len >> 2] | 0;
    $10 = $9 + 1 | 0;
    $11 = _ft_mem_alloc($5, $10, $error) | 0;
    $12 = HEAP32[$error >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $15 = HEAP32[$bytes >> 2] | 0;
    $16 = HEAP32[$byte_len >> 2] | 0;
    _memcpy($11 | 0, $15 | 0, $16 | 0);
    $17 = HEAP32[$byte_len >> 2] | 0;
    $18 = $11 + $17 | 0;
    HEAP8[$18] = 0;
    label = 4;
    break;
   case 4:
    _cff_index_forget_element($1, $bytes);
    $name_0 = $11;
    label = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return $name_0 | 0;
  }
  return 0;
}
function _remove_subset_prefix($name) {
  $name = $name | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $continue_search_019 = 0, $7 = 0, $8 = 0, $9 = 0, $_off = 0, $10 = 0, $continue_search_2 = 0, $11 = 0, $12 = 0, $_off_1 = 0, $13 = 0, $continue_search_2_1 = 0, $14 = 0, $15 = 0, $_off_2 = 0, $16 = 0, $continue_search_2_2 = 0, $17 = 0, $18 = 0, $_off_3 = 0, $19 = 0, $continue_search_2_3 = 0, $20 = 0, $21 = 0, $_off_4 = 0, $22 = 0, $continue_search_2_4 = 0, $23 = 0, $24 = 0, $_off_5 = 0, $25 = 0, $continue_search_2_5 = 0, $26 = 0, $27 = 0, $idx_118 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $exitcond = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _strlen($name | 0) | 0;
    $2 = $1 + 1 | 0;
    $3 = ($2 | 0) > 6;
    $4 = $name + 6 | 0;
    $5 = ($2 | 0) > 7;
    $continue_search_019 = 1;
    label = 2;
    break;
   case 2:
    if ($3) {
      label = 3;
      break;
    } else {
      label = 8;
      break;
    }
   case 3:
    $7 = HEAP8[$4] | 0;
    $8 = $7 << 24 >> 24 == 43;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 8;
      break;
    }
   case 4:
    $9 = HEAP8[$name] | 0;
    $_off = $9 - 65 & 255;
    $10 = ($_off & 255) < 26;
    $continue_search_2 = $10 ? $continue_search_019 : 0;
    $11 = $name + 1 | 0;
    $12 = HEAP8[$11] | 0;
    $_off_1 = $12 - 65 & 255;
    $13 = ($_off_1 & 255) < 26;
    $continue_search_2_1 = $13 ? $continue_search_2 : 0;
    $14 = $name + 2 | 0;
    $15 = HEAP8[$14] | 0;
    $_off_2 = $15 - 65 & 255;
    $16 = ($_off_2 & 255) < 26;
    $continue_search_2_2 = $16 ? $continue_search_2_1 : 0;
    $17 = $name + 3 | 0;
    $18 = HEAP8[$17] | 0;
    $_off_3 = $18 - 65 & 255;
    $19 = ($_off_3 & 255) < 26;
    $continue_search_2_3 = $19 ? $continue_search_2_2 : 0;
    $20 = $name + 4 | 0;
    $21 = HEAP8[$20] | 0;
    $_off_4 = $21 - 65 & 255;
    $22 = ($_off_4 & 255) < 26;
    $continue_search_2_4 = $22 ? $continue_search_2_3 : 0;
    $23 = $name + 5 | 0;
    $24 = HEAP8[$23] | 0;
    $_off_5 = $24 - 65 & 255;
    $25 = ($_off_5 & 255) < 26;
    $continue_search_2_5 = $25 ? $continue_search_2_4 : 0;
    $26 = $continue_search_2_5 << 24 >> 24 == 0;
    if ($26) {
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $27 = $continue_search_2_5 << 24 >> 24 == 0;
    if ($27) {
      label = 8;
      break;
    } else {
      $continue_search_019 = $continue_search_2_5;
      label = 2;
      break;
    }
   case 6:
    if ($5) {
      $idx_118 = 7;
      label = 7;
      break;
    } else {
      $continue_search_019 = $continue_search_2_5;
      label = 2;
      break;
    }
   case 7:
    $28 = $name + $idx_118 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $idx_118 - 7 | 0;
    $31 = $name + $30 | 0;
    HEAP8[$31] = $29;
    $32 = $idx_118 + 1 | 0;
    $exitcond = ($32 | 0) == ($2 | 0);
    if ($exitcond) {
      label = 5;
      break;
    } else {
      $idx_118 = $32;
      label = 7;
      break;
    }
   case 8:
    return;
  }
}
function _cff_strcpy($memory, $source) {
  $memory = $memory | 0;
  $source = $source | 0;
  var $1 = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  $1 = _ft_mem_strdup($memory, $source, __stackBase__ | 0) | 0;
  STACKTOP = __stackBase__;
  return $1 | 0;
}
function _cff_index_access_element($idx, $element, $pbytes, $pbyte_len) {
  $idx = $idx | 0;
  $element = $element | 0;
  $pbytes = $pbytes | 0;
  $pbyte_len = $pbyte_len | 0;
  var $error = 0, $1 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $_0 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $_1 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $off1_0_ph = 0, $50 = 0, $51 = 0, $off1_0 = 0, $off2_0 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $off2_050 = 0, $off1_049 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $off1_048 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $off1_047 = 0, $off2_1 = 0, $72 = 0, $73 = 0, $or_cond = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $_sum = 0, $80 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $89 = 0, $93 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = ($idx | 0) == 0;
    if ($1) {
      label = 24;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $idx + 8 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 >>> 0 > $element >>> 0;
    if ($5) {
      label = 3;
      break;
    } else {
      label = 24;
      break;
    }
   case 3:
    $7 = $idx | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $idx + 24 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 4;
      break;
    } else {
      label = 9;
      break;
    }
   case 4:
    $13 = $idx + 12 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $14 & 255;
    $16 = Math_imul($15, $element);
    $17 = $idx + 4 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    $19 = $18 + 3 | 0;
    $20 = $19 + $16 | 0;
    $21 = _FT_Stream_Seek($8, $20) | 0;
    HEAP32[$error >> 2] = $21;
    $22 = ($21 | 0) == 0;
    if ($22) {
      label = 5;
      break;
    } else {
      label = 25;
      break;
    }
   case 5:
    $24 = _cff_index_read_offset($idx, $error) | 0;
    $25 = HEAP32[$error >> 2] | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 6;
      break;
    } else {
      label = 25;
      break;
    }
   case 6:
    $28 = ($24 | 0) == 0;
    if ($28) {
      label = 13;
      break;
    } else {
      $_0 = $element;
      label = 7;
      break;
    }
   case 7:
    $29 = $_0 + 1 | 0;
    $30 = _cff_index_read_offset($idx, $error) | 0;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 8;
      break;
    } else {
      $off2_0 = $30;
      $off1_0 = $24;
      label = 15;
      break;
    }
   case 8:
    $33 = HEAP32[$3 >> 2] | 0;
    $34 = $29 >>> 0 < $33 >>> 0;
    if ($34) {
      $_0 = $29;
      label = 7;
      break;
    } else {
      $off1_0_ph = $24;
      label = 14;
      break;
    }
   case 9:
    $36 = $10 + ($element << 2) | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = ($37 | 0) == 0;
    if ($38) {
      label = 13;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $39 = HEAP32[$9 >> 2] | 0;
    $_1 = $element;
    label = 11;
    break;
   case 11:
    $41 = $_1 + 1 | 0;
    $42 = $39 + ($41 << 2) | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = ($43 | 0) == 0;
    if ($44) {
      label = 12;
      break;
    } else {
      $off2_0 = $43;
      $off1_0 = $37;
      label = 15;
      break;
    }
   case 12:
    $46 = HEAP32[$3 >> 2] | 0;
    $47 = $41 >>> 0 < $46 >>> 0;
    if ($47) {
      $_1 = $41;
      label = 11;
      break;
    } else {
      $off1_0_ph = $37;
      label = 14;
      break;
    }
   case 13:
    $48 = $8 + 4 | 0;
    $49 = HEAP32[$48 >> 2] | 0;
    $off1_049 = 0;
    $off2_050 = 0;
    $58 = $48;
    $57 = $49;
    label = 16;
    break;
   case 14:
    $50 = $8 + 4 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $off1_049 = $off1_0_ph;
    $off2_050 = 0;
    $58 = $50;
    $57 = $51;
    label = 16;
    break;
   case 15:
    $52 = $8 + 4 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $53 + 1 | 0;
    $55 = $off2_0 >>> 0 > $54 >>> 0;
    if ($55) {
      $off1_048 = $off1_0;
      $65 = $52;
      label = 17;
      break;
    } else {
      $off1_049 = $off1_0;
      $off2_050 = $off2_0;
      $58 = $52;
      $57 = $53;
      label = 16;
      break;
    }
   case 16:
    $59 = $idx + 16 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = $57 + 1 | 0;
    $62 = $61 - $off2_050 | 0;
    $63 = $60 >>> 0 > $62 >>> 0;
    if ($63) {
      $off1_048 = $off1_049;
      $65 = $58;
      label = 17;
      break;
    } else {
      $off2_1 = $off2_050;
      $off1_047 = $off1_049;
      label = 18;
      break;
    }
   case 17:
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = $idx + 16 | 0;
    $68 = HEAP32[$67 >> 2] | 0;
    $69 = $66 + 1 | 0;
    $70 = $69 - $68 | 0;
    $off2_1 = $70;
    $off1_047 = $off1_048;
    label = 18;
    break;
   case 18:
    $72 = ($off1_047 | 0) != 0;
    $73 = $off2_1 >>> 0 > $off1_047 >>> 0;
    $or_cond = $72 & $73;
    if ($or_cond) {
      label = 19;
      break;
    } else {
      label = 23;
      break;
    }
   case 19:
    $75 = $off2_1 - $off1_047 | 0;
    HEAP32[$pbyte_len >> 2] = $75;
    $76 = $idx + 28 | 0;
    $77 = HEAP32[$76 >> 2] | 0;
    $78 = ($77 | 0) == 0;
    if ($78) {
      label = 21;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $_sum = $off1_047 - 1 | 0;
    $80 = $77 + $_sum | 0;
    HEAP32[$pbytes >> 2] = $80;
    label = 25;
    break;
   case 21:
    $82 = $idx + 16 | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = $off1_047 - 1 | 0;
    $85 = $84 + $83 | 0;
    $86 = _FT_Stream_Seek($8, $85) | 0;
    HEAP32[$error >> 2] = $86;
    $87 = ($86 | 0) == 0;
    if ($87) {
      label = 22;
      break;
    } else {
      label = 25;
      break;
    }
   case 22:
    $89 = _FT_Stream_ExtractFrame($8, $75, $pbytes) | 0;
    HEAP32[$error >> 2] = $89;
    label = 25;
    break;
   case 23:
    HEAP32[$pbytes >> 2] = 0;
    HEAP32[$pbyte_len >> 2] = 0;
    label = 25;
    break;
   case 24:
    HEAP32[$error >> 2] = 6;
    label = 25;
    break;
   case 25:
    $93 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $93 | 0;
  }
  return 0;
}
function _cff_index_forget_element($idx, $pbytes) {
  $idx = $idx | 0;
  $pbytes = $pbytes | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $idx + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $5 = $idx | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    _FT_Stream_ReleaseFrame($6, $pbytes);
    label = 3;
    break;
   case 3:
    return;
  }
}
function _cff_index_read_offset($idx, $errorp) {
  $idx = $idx | 0;
  $errorp = $errorp | 0;
  var $tmp = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $nn_08 = 0, $result_07 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $result_1 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $tmp = __stackBase__ | 0;
    $1 = $idx | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $tmp | 0;
    $4 = $idx + 12 | 0;
    $5 = HEAP8[$4] | 0;
    $6 = $5 & 255;
    $7 = _FT_Stream_Read($2, $3, $6) | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 2;
      break;
    } else {
      $result_1 = 0;
      label = 5;
      break;
    }
   case 2:
    $9 = HEAP8[$4] | 0;
    $10 = $9 << 24 >> 24 == 0;
    if ($10) {
      $result_1 = 0;
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = HEAP8[$4] | 0;
    $12 = $11 & 255;
    $result_07 = 0;
    $nn_08 = 0;
    label = 4;
    break;
   case 4:
    $14 = $result_07 << 8;
    $15 = $tmp + $nn_08 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 & 255;
    $18 = $17 | $14;
    $19 = $nn_08 + 1 | 0;
    $20 = ($19 | 0) < ($12 | 0);
    if ($20) {
      $result_07 = $18;
      $nn_08 = $19;
      label = 4;
      break;
    } else {
      $result_1 = $18;
      label = 5;
      break;
    }
   case 5:
    HEAP32[$errorp >> 2] = $7;
    STACKTOP = __stackBase__;
    return $result_1 | 0;
  }
  return 0;
}
function _cff_index_init($idx, $stream, $load) {
  $idx = $idx | 0;
  $stream = $stream | 0;
  $load = $load | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $or_cond = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $49 = 0, $_pr = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $idx;
    _memset($3 | 0, 0, 32);
    $4 = $idx | 0;
    HEAP32[$4 >> 2] = $stream;
    $5 = _FT_Stream_Pos($stream) | 0;
    $6 = $idx + 4 | 0;
    HEAP32[$6 >> 2] = $5;
    $7 = _FT_Stream_ReadShort($stream, $error) | 0;
    $8 = HEAP32[$error >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 2;
      break;
    } else {
      label = 15;
      break;
    }
   case 2:
    $11 = $7 & 65535;
    $12 = $7 << 16 >> 16 == 0;
    if ($12) {
      label = 13;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $14 = _FT_Stream_ReadChar($stream, $error) | 0;
    $15 = HEAP32[$error >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 4;
      break;
    } else {
      label = 15;
      break;
    }
   case 4:
    $18 = $14 & 255;
    $19 = $14 << 24 >> 24 == 0;
    $20 = ($14 & 255) > 4;
    $or_cond = $19 | $20;
    if ($or_cond) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    HEAP32[$error >> 2] = 8;
    label = 15;
    break;
   case 6:
    $23 = $idx + 8 | 0;
    HEAP32[$23 >> 2] = $11;
    $24 = $idx + 12 | 0;
    HEAP8[$24] = $14;
    $25 = $11 + 1 | 0;
    $26 = Math_imul($18, $25);
    $27 = HEAP32[$6 >> 2] | 0;
    $28 = $26 + 3 | 0;
    $29 = $28 + $27 | 0;
    $30 = $idx + 16 | 0;
    HEAP32[$30 >> 2] = $29;
    $31 = $26 - $18 | 0;
    $32 = _FT_Stream_Skip($stream, $31) | 0;
    HEAP32[$error >> 2] = $32;
    $33 = ($32 | 0) == 0;
    if ($33) {
      label = 7;
      break;
    } else {
      label = 15;
      break;
    }
   case 7:
    $35 = _cff_index_read_offset($idx, $error) | 0;
    $36 = HEAP32[$error >> 2] | 0;
    $37 = ($36 | 0) == 0;
    if ($37) {
      label = 8;
      break;
    } else {
      label = 15;
      break;
    }
   case 8:
    $39 = ($35 | 0) == 0;
    if ($39) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    HEAP32[$error >> 2] = 8;
    label = 15;
    break;
   case 10:
    $42 = $35 - 1 | 0;
    $43 = $idx + 20 | 0;
    HEAP32[$43 >> 2] = $42;
    $44 = $load << 24 >> 24 == 0;
    if ($44) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $46 = $idx + 28 | 0;
    $47 = _FT_Stream_ExtractFrame($stream, $42, $46) | 0;
    HEAP32[$error >> 2] = $47;
    $51 = $47;
    label = 14;
    break;
   case 12:
    $49 = _FT_Stream_Skip($stream, $42) | 0;
    HEAP32[$error >> 2] = $49;
    $51 = $49;
    label = 14;
    break;
   case 13:
    $_pr = HEAP32[$error >> 2] | 0;
    $51 = $_pr;
    label = 14;
    break;
   case 14:
    $52 = ($51 | 0) == 0;
    if ($52) {
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $53 = $idx + 24 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = $54;
    _ft_mem_free($2, $55);
    HEAP32[$53 >> 2] = 0;
    label = 16;
    break;
   case 16:
    $57 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $57 | 0;
  }
  return 0;
}
function _cff_index_get_pointers($idx, $table, $pool) {
  $idx = $idx | 0;
  $table = $table | 0;
  $pool = $pool | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $new_bytes_0 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $_ = 0, $_pn = 0, $storemerge = 0, $40 = 0, $41 = 0, $42 = 0, $extra_061 = 0, $cur_offset_160 = 0, $n_059 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $or_cond = 0, $50 = 0, $51 = 0, $52 = 0, $or_cond58 = 0, $next_offset_0 = 0, $56 = 0, $57 = 0, $_sum = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $extra_1 = 0, $75 = 0, $76 = 0, $77 = 0, $80 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $idx | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 28 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    HEAP32[$table >> 2] = 0;
    $5 = $idx + 24 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $9 = _cff_index_load_offsets($idx) | 0;
    HEAP32[$error >> 2] = $9;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 3;
      break;
    } else {
      label = 18;
      break;
    }
   case 3:
    $12 = $idx + 8 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 18;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $16 = $13 + 1 | 0;
    $17 = _ft_mem_realloc($4, 4, 0, $16, 0, $error) | 0;
    $18 = $17;
    $19 = HEAP32[$error >> 2] | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 5;
      break;
    } else {
      label = 18;
      break;
    }
   case 5:
    $22 = ($pool | 0) != 0;
    if ($22) {
      label = 6;
      break;
    } else {
      $new_bytes_0 = 0;
      label = 7;
      break;
    }
   case 6:
    $24 = $idx + 20 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = HEAP32[$12 >> 2] | 0;
    $27 = $26 + $25 | 0;
    $28 = _ft_mem_alloc($4, $27, $error) | 0;
    $29 = HEAP32[$error >> 2] | 0;
    $30 = ($29 | 0) == 0;
    if ($30) {
      $new_bytes_0 = $28;
      label = 7;
      break;
    } else {
      label = 18;
      break;
    }
   case 7:
    $32 = $idx + 28 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = HEAP32[$5 >> 2] | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = $35 - 1 | 0;
    $37 = $idx + 20 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = $36 >>> 0 < $38 >>> 0;
    $_ = $39 ? $36 : 0;
    $_pn = $22 ? $new_bytes_0 : $33;
    $storemerge = $_pn + $_ | 0;
    HEAP32[$18 >> 2] = $storemerge;
    $40 = HEAP32[$12 >> 2] | 0;
    $41 = ($40 | 0) == 0;
    if ($41) {
      label = 16;
      break;
    } else {
      $n_059 = 1;
      $cur_offset_160 = $_;
      $extra_061 = 0;
      $42 = $40;
      label = 8;
      break;
    }
   case 8:
    $43 = HEAP32[$5 >> 2] | 0;
    $44 = $43 + ($n_059 << 2) | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = $45 - 1 | 0;
    $47 = ($46 | 0) == 0;
    $48 = $46 >>> 0 < $cur_offset_160 >>> 0;
    $or_cond = $47 | $48;
    if ($or_cond) {
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $50 = HEAP32[$37 >> 2] | 0;
    $51 = $46 >>> 0 >= $50 >>> 0;
    $52 = $n_059 >>> 0 < $42 >>> 0;
    $or_cond58 = $51 & $52;
    if ($or_cond58) {
      label = 10;
      break;
    } else {
      $next_offset_0 = $46;
      label = 11;
      break;
    }
   case 10:
    $next_offset_0 = $cur_offset_160;
    label = 11;
    break;
   case 11:
    if ($22) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $56 = $33 + $next_offset_0 | 0;
    $57 = $18 + ($n_059 << 2) | 0;
    HEAP32[$57 >> 2] = $56;
    $extra_1 = $extra_061;
    label = 15;
    break;
   case 13:
    $_sum = $next_offset_0 + $extra_061 | 0;
    $59 = $new_bytes_0 + $_sum | 0;
    $60 = $18 + ($n_059 << 2) | 0;
    HEAP32[$60 >> 2] = $59;
    $61 = ($next_offset_0 | 0) == ($cur_offset_160 | 0);
    if ($61) {
      $extra_1 = $extra_061;
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $63 = $n_059 - 1 | 0;
    $64 = $18 + ($63 << 2) | 0;
    $65 = HEAP32[$64 >> 2] | 0;
    $66 = $33 + $cur_offset_160 | 0;
    $67 = $59;
    $68 = $65;
    $69 = $67 - $68 | 0;
    _memcpy($65 | 0, $66 | 0, $69 | 0);
    $70 = HEAP32[$60 >> 2] | 0;
    HEAP8[$70] = 0;
    $71 = HEAP32[$60 >> 2] | 0;
    $72 = $71 + 1 | 0;
    HEAP32[$60 >> 2] = $72;
    $73 = $extra_061 + 1 | 0;
    $extra_1 = $73;
    label = 15;
    break;
   case 15:
    $75 = $n_059 + 1 | 0;
    $76 = HEAP32[$12 >> 2] | 0;
    $77 = $75 >>> 0 > $76 >>> 0;
    if ($77) {
      label = 16;
      break;
    } else {
      $n_059 = $75;
      $cur_offset_160 = $next_offset_0;
      $extra_061 = $extra_1;
      $42 = $76;
      label = 8;
      break;
    }
   case 16:
    HEAP32[$table >> 2] = $18;
    if ($22) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    HEAP32[$pool >> 2] = $new_bytes_0;
    label = 18;
    break;
   case 18:
    $80 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $80 | 0;
  }
  return 0;
}
function _cff_subfont_load($font, $idx, $font_index, $stream, $base_offset, $library) {
  $font = $font | 0;
  $idx = $idx | 0;
  $font_index = $font_index | 0;
  $stream = $stream | 0;
  $base_offset = $base_offset | 0;
  $library = $library | 0;
  var $parser = 0, $dict = 0, $dict_len = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $60 = 0, $61 = 0, $error_1 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $73 = 0, $74 = 0, $75 = 0, $77 = 0, $78 = 0, $error_2 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 424 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $parser = __stackBase__ | 0;
    $dict = __stackBase__ + 416 | 0;
    $dict_len = __stackBase__ + 420 | 0;
    HEAP32[$dict >> 2] = 0;
    $1 = $font;
    _cff_parser_init($parser, 4096, $1, $library);
    _memset($1 | 0, 0, 168);
    $2 = $font + 32 | 0;
    HEAP32[$2 >> 2] = -6553600;
    $3 = $font + 36 | 0;
    HEAP32[$3 >> 2] = 3276800;
    $4 = $font + 44 | 0;
    HEAP32[$4 >> 2] = 2;
    $5 = $font + 48 | 0;
    HEAP32[$5 >> 2] = 65536;
    $6 = $font + 60 | 0;
    HEAP32[$6 >> 2] = 65536;
    $7 = $font + 152 | 0;
    HEAP32[$7 >> 2] = 8720;
    $8 = $font | 0;
    HEAP32[$8 >> 2] = 65535;
    $9 = $font + 4 | 0;
    HEAP32[$9 >> 2] = 65535;
    $10 = $font + 8 | 0;
    HEAP32[$10 >> 2] = 65535;
    $11 = $font + 12 | 0;
    HEAP32[$11 >> 2] = 65535;
    $12 = $font + 16 | 0;
    HEAP32[$12 >> 2] = 65535;
    $13 = $font + 20 | 0;
    HEAP32[$13 >> 2] = 65535;
    $14 = $font + 124 | 0;
    HEAP32[$14 >> 2] = 65535;
    $15 = $font + 128 | 0;
    HEAP32[$15 >> 2] = 65535;
    $16 = $font + 132 | 0;
    HEAP32[$16 >> 2] = 65535;
    $17 = $font + 168 | 0;
    HEAP32[$17 >> 2] = 65535;
    $18 = _cff_index_access_element($idx, $font_index, $dict, $dict_len) | 0;
    $19 = ($18 | 0) == 0;
    if ($19) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    _cff_index_forget_element($idx, $dict);
    $error_2 = $18;
    label = 15;
    break;
   case 3:
    $21 = HEAP32[$dict >> 2] | 0;
    $22 = HEAP32[$dict_len >> 2] | 0;
    $23 = $21 + $22 | 0;
    $24 = _cff_parser_run($parser, $21, $23) | 0;
    _cff_index_forget_element($idx, $dict);
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 4;
      break;
    } else {
      $error_2 = $24;
      label = 15;
      break;
    }
   case 4:
    $27 = HEAP32[$15 >> 2] | 0;
    $28 = ($27 | 0) == 65535;
    if ($28) {
      label = 5;
      break;
    } else {
      $error_2 = 0;
      label = 15;
      break;
    }
   case 5:
    $30 = $font + 112 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = ($31 | 0) == 0;
    if ($32) {
      $error_1 = $24;
      label = 11;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $34 = $font + 116 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    $36 = ($35 | 0) == 0;
    if ($36) {
      $error_1 = $24;
      label = 11;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $38 = $font + 172 | 0;
    _memset($38 | 0, 0, 360);
    $39 = $font + 372 | 0;
    HEAP32[$39 >> 2] = 7;
    $40 = $font + 376 | 0;
    HEAP32[$40 >> 2] = 1;
    $41 = $font + 504 | 0;
    HEAP32[$41 >> 2] = -1;
    $42 = $font + 512 | 0;
    HEAP32[$42 >> 2] = 3932;
    $43 = $font + 368 | 0;
    HEAP32[$43 >> 2] = 2596864;
    _cff_parser_init($parser, 8192, $38, $library);
    $44 = HEAP32[$30 >> 2] | 0;
    $45 = $44 + $base_offset | 0;
    $46 = _FT_Stream_Seek($stream, $45) | 0;
    $47 = ($46 | 0) == 0;
    if ($47) {
      label = 8;
      break;
    } else {
      $error_2 = $46;
      label = 15;
      break;
    }
   case 8:
    $49 = HEAP32[$34 >> 2] | 0;
    $50 = _FT_Stream_EnterFrame($stream, $49) | 0;
    $51 = ($50 | 0) == 0;
    if ($51) {
      label = 9;
      break;
    } else {
      $error_2 = $50;
      label = 15;
      break;
    }
   case 9:
    $53 = $stream + 32 | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = $stream + 36 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = _cff_parser_run($parser, $54, $56) | 0;
    _FT_Stream_ExitFrame($stream);
    $58 = ($57 | 0) == 0;
    if ($58) {
      label = 10;
      break;
    } else {
      $error_2 = $57;
      label = 15;
      break;
    }
   case 10:
    $60 = HEAP8[$38] | 0;
    $61 = $60 & -2;
    HEAP8[$38] = $61;
    $error_1 = 0;
    label = 11;
    break;
   case 11:
    $63 = $font + 520 | 0;
    $64 = HEAP32[$63 >> 2] | 0;
    $65 = ($64 | 0) == 0;
    if ($65) {
      $error_2 = $error_1;
      label = 15;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $67 = HEAP32[$30 >> 2] | 0;
    $68 = $64 + $base_offset | 0;
    $69 = $68 + $67 | 0;
    $70 = _FT_Stream_Seek($stream, $69) | 0;
    $71 = ($70 | 0) == 0;
    if ($71) {
      label = 13;
      break;
    } else {
      $error_2 = $70;
      label = 15;
      break;
    }
   case 13:
    $73 = $font + 532 | 0;
    $74 = _cff_index_init($73, $stream, 1) | 0;
    $75 = ($74 | 0) == 0;
    if ($75) {
      label = 14;
      break;
    } else {
      $error_2 = $74;
      label = 15;
      break;
    }
   case 14:
    $77 = $font + 564 | 0;
    $78 = _cff_index_get_pointers($73, $77, 0) | 0;
    $error_2 = $78;
    label = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return $error_2 | 0;
  }
  return 0;
}
function _CFF_Load_FD_Select($fdselect, $num_glyphs, $stream, $offset) {
  $fdselect = $fdselect | 0;
  $num_glyphs = $num_glyphs | 0;
  $stream = $stream | 0;
  $offset = $offset | 0;
  var $error = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $29 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = _FT_Stream_Seek($stream, $offset) | 0;
    HEAP32[$error >> 2] = $1;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      label = 9;
      break;
    }
   case 2:
    $4 = _FT_Stream_ReadChar($stream, $error) | 0;
    $5 = HEAP32[$error >> 2] | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 9;
      break;
    }
   case 3:
    $8 = $fdselect | 0;
    HEAP8[$8] = $4;
    $9 = $fdselect + 20 | 0;
    HEAP32[$9 >> 2] = 0;
    $10 = $4 & 255;
    if (($10 | 0) == 0) {
      label = 4;
      break;
    } else if (($10 | 0) == 3) {
      label = 5;
      break;
    } else {
      label = 8;
      break;
    }
   case 4:
    $12 = $fdselect + 12 | 0;
    HEAP32[$12 >> 2] = $num_glyphs;
    label = 7;
    break;
   case 5:
    $14 = _FT_Stream_ReadShort($stream, $error) | 0;
    $15 = HEAP32[$error >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 6;
      break;
    } else {
      label = 9;
      break;
    }
   case 6:
    $18 = $14 & 65535;
    $19 = $18 * 3 & -1;
    $20 = $19 + 2 | 0;
    $21 = $fdselect + 12 | 0;
    HEAP32[$21 >> 2] = $20;
    label = 7;
    break;
   case 7:
    $23 = $fdselect + 12 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $fdselect + 8 | 0;
    $26 = _FT_Stream_ExtractFrame($stream, $24, $25) | 0;
    HEAP32[$error >> 2] = $26;
    label = 9;
    break;
   case 8:
    HEAP32[$error >> 2] = 3;
    label = 9;
    break;
   case 9:
    $29 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $29 | 0;
  }
  return 0;
}
function _cff_charset_cid_to_gindex($charset, $cid) {
  $charset = $charset | 0;
  $cid = $cid | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $charset + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 >>> 0 < $cid >>> 0;
    if ($3) {
      $result_0 = 0;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $charset + 12 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + ($cid << 1) | 0;
    $8 = HEAP16[$7 >> 1] | 0;
    $9 = $8 & 65535;
    $result_0 = $9;
    label = 3;
    break;
   case 3:
    return $result_0 | 0;
  }
  return 0;
}
function _cff_charset_load($charset, $num_glyphs, $stream, $base_offset, $offset, $invert) {
  $charset = $charset | 0;
  $num_glyphs = $num_glyphs | 0;
  $stream = $stream | 0;
  $base_offset = $base_offset | 0;
  $offset = $offset | 0;
  $invert = $invert | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $j_070 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $exitcond = 0, $36 = 0, $j_2_lcssa = 0, $37 = 0, $j_177 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $nleft_0 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $_nleft_0 = 0, $60 = 0, $61 = 0, $62 = 0, $umax = 0, $63 = 0, $i_074 = 0, $j_273 = 0, $glyph_sid_072 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $exitcond79 = 0, $72 = 0, $74 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $83 = 0, $85 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $94 = 0, $96 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $105 = 0, $107 = 0, $109 = 0, $_pr = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $121 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $stream + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP32[$error >> 2] = 0;
    $3 = $offset >>> 0 > 2;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 22;
      break;
    }
   case 2:
    $5 = $offset + $base_offset | 0;
    $6 = $charset + 4 | 0;
    HEAP32[$6 >> 2] = $5;
    $7 = _FT_Stream_Seek($stream, $5) | 0;
    HEAP32[$error >> 2] = $7;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 3;
      break;
    } else {
      label = 40;
      break;
    }
   case 3:
    $10 = _FT_Stream_ReadChar($stream, $error) | 0;
    $11 = $10 & 255;
    $12 = $charset | 0;
    HEAP32[$12 >> 2] = $11;
    $13 = HEAP32[$error >> 2] | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 4;
      break;
    } else {
      label = 40;
      break;
    }
   case 4:
    $16 = _ft_mem_realloc($2, 2, 0, $num_glyphs, 0, $error) | 0;
    $17 = $16;
    $18 = $charset + 8 | 0;
    HEAP32[$18 >> 2] = $17;
    $19 = HEAP32[$error >> 2] | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 5;
      break;
    } else {
      label = 40;
      break;
    }
   case 5:
    HEAP16[$17 >> 1] = 0;
    $22 = HEAP32[$12 >> 2] | 0;
    if (($22 | 0) == 1 | ($22 | 0) == 2) {
      label = 6;
      break;
    } else if (($22 | 0) == 0) {
      label = 7;
      break;
    } else {
      label = 21;
      break;
    }
   case 6:
    $23 = $num_glyphs >>> 0 > 1;
    if ($23) {
      $j_177 = 1;
      label = 14;
      break;
    } else {
      label = 36;
      break;
    }
   case 7:
    $25 = ($num_glyphs | 0) == 0;
    if ($25) {
      label = 36;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $27 = $num_glyphs << 1;
    $28 = $27 - 2 | 0;
    $29 = _FT_Stream_EnterFrame($stream, $28) | 0;
    HEAP32[$error >> 2] = $29;
    $30 = ($29 | 0) == 0;
    if ($30) {
      label = 9;
      break;
    } else {
      label = 40;
      break;
    }
   case 9:
    $31 = $num_glyphs >>> 0 > 1;
    if ($31) {
      $j_070 = 1;
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $32 = _FT_Stream_GetShort($stream) | 0;
    $33 = HEAP32[$18 >> 2] | 0;
    $34 = $33 + ($j_070 << 1) | 0;
    HEAP16[$34 >> 1] = $32;
    $35 = $j_070 + 1 | 0;
    $exitcond = ($35 | 0) == ($num_glyphs | 0);
    if ($exitcond) {
      label = 11;
      break;
    } else {
      $j_070 = $35;
      label = 10;
      break;
    }
   case 11:
    _FT_Stream_ExitFrame($stream);
    label = 36;
    break;
   case 12:
    $36 = $j_177 - $umax | 0;
    $j_2_lcssa = $36;
    label = 13;
    break;
   case 13:
    $37 = $j_2_lcssa >>> 0 < $num_glyphs >>> 0;
    if ($37) {
      $j_177 = $j_2_lcssa;
      label = 14;
      break;
    } else {
      label = 36;
      break;
    }
   case 14:
    $38 = _FT_Stream_ReadShort($stream, $error) | 0;
    $39 = HEAP32[$error >> 2] | 0;
    $40 = ($39 | 0) == 0;
    if ($40) {
      label = 15;
      break;
    } else {
      label = 40;
      break;
    }
   case 15:
    $42 = HEAP32[$12 >> 2] | 0;
    $43 = ($42 | 0) == 2;
    if ($43) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    $45 = _FT_Stream_ReadShort($stream, $error) | 0;
    $46 = $45 & 65535;
    $47 = HEAP32[$error >> 2] | 0;
    $48 = ($47 | 0) == 0;
    if ($48) {
      $nleft_0 = $46;
      label = 18;
      break;
    } else {
      label = 40;
      break;
    }
   case 17:
    $50 = _FT_Stream_ReadChar($stream, $error) | 0;
    $51 = $50 & 255;
    $52 = HEAP32[$error >> 2] | 0;
    $53 = ($52 | 0) == 0;
    if ($53) {
      $nleft_0 = $51;
      label = 18;
      break;
    } else {
      label = 40;
      break;
    }
   case 18:
    $55 = $38 & 65535;
    $56 = $j_177 >>> 0 < $num_glyphs >>> 0;
    if ($56) {
      label = 19;
      break;
    } else {
      $j_2_lcssa = $j_177;
      label = 13;
      break;
    }
   case 19:
    $57 = $nleft_0 ^ 65535;
    $58 = $55 ^ 65535;
    $59 = $55 >>> 0 > $57 >>> 0;
    $_nleft_0 = $59 ? $58 : $nleft_0;
    $60 = $j_177 - $num_glyphs | 0;
    $61 = $_nleft_0 ^ -1;
    $62 = $60 >>> 0 > $61 >>> 0;
    $umax = $62 ? $60 : $61;
    $63 = -$umax | 0;
    $glyph_sid_072 = $38;
    $j_273 = $j_177;
    $i_074 = 0;
    label = 20;
    break;
   case 20:
    $65 = HEAP32[$18 >> 2] | 0;
    $66 = $65 + ($j_273 << 1) | 0;
    HEAP16[$66 >> 1] = $glyph_sid_072;
    $67 = $i_074 + 1 | 0;
    $68 = $j_273 + 1 | 0;
    $69 = $glyph_sid_072 + 1 & 65535;
    $exitcond79 = ($67 | 0) == ($63 | 0);
    if ($exitcond79) {
      label = 12;
      break;
    } else {
      $glyph_sid_072 = $69;
      $j_273 = $68;
      $i_074 = $67;
      label = 20;
      break;
    }
   case 21:
    HEAP32[$error >> 2] = 3;
    label = 40;
    break;
   case 22:
    $72 = $charset + 4 | 0;
    HEAP32[$72 >> 2] = $offset;
    if (($offset | 0) == 0) {
      label = 23;
      break;
    } else if (($offset | 0) == 1) {
      label = 27;
      break;
    } else if (($offset | 0) == 2) {
      label = 31;
      break;
    } else {
      label = 35;
      break;
    }
   case 23:
    $74 = $num_glyphs >>> 0 > 229;
    if ($74) {
      label = 24;
      break;
    } else {
      label = 25;
      break;
    }
   case 24:
    HEAP32[$error >> 2] = 3;
    label = 40;
    break;
   case 25:
    $77 = _ft_mem_realloc($2, 2, 0, $num_glyphs, 0, $error) | 0;
    $78 = $77;
    $79 = $charset + 8 | 0;
    HEAP32[$79 >> 2] = $78;
    $80 = HEAP32[$error >> 2] | 0;
    $81 = ($80 | 0) == 0;
    if ($81) {
      label = 26;
      break;
    } else {
      label = 40;
      break;
    }
   case 26:
    $83 = $num_glyphs << 1;
    _memcpy($77 | 0, 5314632, $83 | 0);
    label = 36;
    break;
   case 27:
    $85 = $num_glyphs >>> 0 > 166;
    if ($85) {
      label = 28;
      break;
    } else {
      label = 29;
      break;
    }
   case 28:
    HEAP32[$error >> 2] = 3;
    label = 40;
    break;
   case 29:
    $88 = _ft_mem_realloc($2, 2, 0, $num_glyphs, 0, $error) | 0;
    $89 = $88;
    $90 = $charset + 8 | 0;
    HEAP32[$90 >> 2] = $89;
    $91 = HEAP32[$error >> 2] | 0;
    $92 = ($91 | 0) == 0;
    if ($92) {
      label = 30;
      break;
    } else {
      label = 40;
      break;
    }
   case 30:
    $94 = $num_glyphs << 1;
    _memcpy($88 | 0, 5317260, $94 | 0);
    label = 36;
    break;
   case 31:
    $96 = $num_glyphs >>> 0 > 87;
    if ($96) {
      label = 32;
      break;
    } else {
      label = 33;
      break;
    }
   case 32:
    HEAP32[$error >> 2] = 3;
    label = 40;
    break;
   case 33:
    $99 = _ft_mem_realloc($2, 2, 0, $num_glyphs, 0, $error) | 0;
    $100 = $99;
    $101 = $charset + 8 | 0;
    HEAP32[$101 >> 2] = $100;
    $102 = HEAP32[$error >> 2] | 0;
    $103 = ($102 | 0) == 0;
    if ($103) {
      label = 34;
      break;
    } else {
      label = 40;
      break;
    }
   case 34:
    $105 = $num_glyphs << 1;
    _memcpy($99 | 0, 5316572, $105 | 0);
    label = 36;
    break;
   case 35:
    HEAP32[$error >> 2] = 3;
    label = 40;
    break;
   case 36:
    $107 = $invert << 24 >> 24 == 0;
    if ($107) {
      label = 38;
      break;
    } else {
      label = 37;
      break;
    }
   case 37:
    $109 = _cff_charset_compute_cids($charset, $num_glyphs, $2) | 0;
    HEAP32[$error >> 2] = $109;
    $111 = $109;
    label = 39;
    break;
   case 38:
    $_pr = HEAP32[$error >> 2] | 0;
    $111 = $_pr;
    label = 39;
    break;
   case 39:
    $112 = ($111 | 0) == 0;
    if ($112) {
      label = 41;
      break;
    } else {
      label = 40;
      break;
    }
   case 40:
    $113 = $charset + 8 | 0;
    $114 = HEAP32[$113 >> 2] | 0;
    $115 = $114;
    _ft_mem_free($2, $115);
    HEAP32[$113 >> 2] = 0;
    $116 = $charset + 12 | 0;
    $117 = HEAP32[$116 >> 2] | 0;
    $118 = $117;
    _ft_mem_free($2, $118);
    $119 = $charset;
    _memset($119 | 0, 0, 16);
    label = 41;
    break;
   case 41:
    $121 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $121 | 0;
  }
  return 0;
}
function _cff_encoding_load($encoding, $charset, $num_glyphs, $stream, $base_offset, $offset) {
  $encoding = $encoding | 0;
  $charset = $charset | 0;
  $num_glyphs = $num_glyphs | 0;
  $stream = $stream | 0;
  $base_offset = $base_offset | 0;
  $offset = $offset | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $j_0120 = 0, $5 = 0, $6 = 0, $7 = 0, $exitcond123 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $p_0102 = 0, $j_1101 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $i_0111 = 0, $j_2110 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $k_0106 = 0, $glyph_code_0105 = 0, $76 = 0, $77 = 0, $or_cond = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $86 = 0, $87 = 0, $exitcond = 0, $88 = 0, $89 = 0, $_pr = 0, $90 = 0, $93 = 0, $94 = 0, $95 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $or_cond126 = 0, $j_3100 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $107 = 0, $108 = 0, $109 = 0, $111 = 0, $gindex_0 = 0, $113 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $127 = 0, $128 = 0, $130 = 0, $131 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $j_4117 = 0, $138 = 0, $139 = 0, $140 = 0, $142 = 0, $143 = 0, $144 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $151 = 0, $exitcond122 = 0, $153 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $charset + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $j_0120 = 0;
      label = 3;
      break;
    }
   case 2:
    HEAP32[$error >> 2] = 3;
    label = 49;
    break;
   case 3:
    $5 = $encoding + 12 + ($j_0120 << 1) | 0;
    HEAP16[$5 >> 1] = 0;
    $6 = $encoding + 524 + ($j_0120 << 1) | 0;
    HEAP16[$6 >> 1] = 0;
    $7 = $j_0120 + 1 | 0;
    $exitcond123 = ($7 | 0) == 256;
    if ($exitcond123) {
      label = 4;
      break;
    } else {
      $j_0120 = $7;
      label = 3;
      break;
    }
   case 4:
    $9 = $offset >>> 0 > 1;
    if ($9) {
      label = 5;
      break;
    } else {
      label = 39;
      break;
    }
   case 5:
    $11 = $offset + $base_offset | 0;
    $12 = $encoding + 4 | 0;
    HEAP32[$12 >> 2] = $11;
    $13 = _FT_Stream_Seek($stream, $11) | 0;
    HEAP32[$error >> 2] = $13;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 6;
      break;
    } else {
      label = 49;
      break;
    }
   case 6:
    $16 = _FT_Stream_ReadChar($stream, $error) | 0;
    $17 = $16 & 255;
    $18 = $encoding | 0;
    HEAP32[$18 >> 2] = $17;
    $19 = HEAP32[$error >> 2] | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      label = 7;
      break;
    } else {
      label = 49;
      break;
    }
   case 7:
    $22 = _FT_Stream_ReadChar($stream, $error) | 0;
    $23 = $22 & 255;
    $24 = HEAP32[$error >> 2] | 0;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 8;
      break;
    } else {
      label = 49;
      break;
    }
   case 8:
    $27 = HEAP32[$18 >> 2] | 0;
    $28 = $27 & 127;
    if (($28 | 0) == 0) {
      label = 9;
      break;
    } else if (($28 | 0) == 1) {
      label = 16;
      break;
    } else {
      label = 29;
      break;
    }
   case 9:
    $30 = $23 + 1 | 0;
    $31 = $encoding + 8 | 0;
    HEAP32[$31 >> 2] = $30;
    $32 = _FT_Stream_EnterFrame($stream, $23) | 0;
    HEAP32[$error >> 2] = $32;
    $33 = ($32 | 0) == 0;
    if ($33) {
      label = 10;
      break;
    } else {
      label = 49;
      break;
    }
   case 10:
    $35 = $22 << 24 >> 24 == 0;
    if ($35) {
      label = 15;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $36 = $stream + 32 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $j_1101 = 1;
    $p_0102 = $37;
    label = 12;
    break;
   case 12:
    $39 = $p_0102 + 1 | 0;
    $40 = HEAP8[$p_0102] | 0;
    $41 = $40 & 255;
    $42 = $j_1101 >>> 0 < $num_glyphs >>> 0;
    if ($42) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    $44 = $j_1101 & 65535;
    $45 = $encoding + 524 + ($41 << 1) | 0;
    HEAP16[$45 >> 1] = $44;
    $46 = HEAP32[$1 >> 2] | 0;
    $47 = $46 + ($j_1101 << 1) | 0;
    $48 = HEAP16[$47 >> 1] | 0;
    $49 = $encoding + 12 + ($41 << 1) | 0;
    HEAP16[$49 >> 1] = $48;
    label = 14;
    break;
   case 14:
    $51 = $j_1101 + 1 | 0;
    $52 = $51 >>> 0 > $23 >>> 0;
    if ($52) {
      label = 15;
      break;
    } else {
      $j_1101 = $51;
      $p_0102 = $39;
      label = 12;
      break;
    }
   case 15:
    _FT_Stream_ExitFrame($stream);
    label = 30;
    break;
   case 16:
    $54 = $encoding + 8 | 0;
    HEAP32[$54 >> 2] = 0;
    $55 = $22 << 24 >> 24 == 0;
    if ($55) {
      label = 30;
      break;
    } else {
      $j_2110 = 0;
      $i_0111 = 1;
      label = 17;
      break;
    }
   case 17:
    $56 = _FT_Stream_ReadChar($stream, $error) | 0;
    $57 = $56 & 255;
    $58 = HEAP32[$error >> 2] | 0;
    $59 = ($58 | 0) == 0;
    if ($59) {
      label = 18;
      break;
    } else {
      label = 49;
      break;
    }
   case 18:
    $61 = _FT_Stream_ReadChar($stream, $error) | 0;
    $62 = HEAP32[$error >> 2] | 0;
    $63 = ($62 | 0) == 0;
    if ($63) {
      label = 19;
      break;
    } else {
      label = 49;
      break;
    }
   case 19:
    $65 = $61 & 255;
    $66 = $65 + 1 | 0;
    $67 = HEAP32[$54 >> 2] | 0;
    $68 = $66 >>> 0 > $67 >>> 0;
    if ($68) {
      label = 20;
      break;
    } else {
      label = 21;
      break;
    }
   case 20:
    HEAP32[$54 >> 2] = $66;
    label = 21;
    break;
   case 21:
    $70 = $66 + $i_0111 | 0;
    $71 = $i_0111 >>> 0 < $70 >>> 0;
    if ($71) {
      label = 22;
      break;
    } else {
      label = 26;
      break;
    }
   case 22:
    $72 = $i_0111 + 1 | 0;
    $73 = $61 & 255;
    $74 = $72 + $73 | 0;
    $glyph_code_0105 = $57;
    $k_0106 = $i_0111;
    label = 23;
    break;
   case 23:
    $76 = $k_0106 >>> 0 < $num_glyphs >>> 0;
    $77 = $glyph_code_0105 >>> 0 < 256;
    $or_cond = $76 & $77;
    if ($or_cond) {
      label = 24;
      break;
    } else {
      label = 25;
      break;
    }
   case 24:
    $79 = $k_0106 & 65535;
    $80 = $encoding + 524 + ($glyph_code_0105 << 1) | 0;
    HEAP16[$80 >> 1] = $79;
    $81 = HEAP32[$1 >> 2] | 0;
    $82 = $81 + ($k_0106 << 1) | 0;
    $83 = HEAP16[$82 >> 1] | 0;
    $84 = $encoding + 12 + ($glyph_code_0105 << 1) | 0;
    HEAP16[$84 >> 1] = $83;
    label = 25;
    break;
   case 25:
    $86 = $k_0106 + 1 | 0;
    $87 = $glyph_code_0105 + 1 | 0;
    $exitcond = ($86 | 0) == ($74 | 0);
    if ($exitcond) {
      label = 26;
      break;
    } else {
      $glyph_code_0105 = $87;
      $k_0106 = $86;
      label = 23;
      break;
    }
   case 26:
    $88 = $j_2110 + 1 | 0;
    $89 = $88 >>> 0 < $23 >>> 0;
    if ($89) {
      $j_2110 = $88;
      $i_0111 = $70;
      label = 17;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $_pr = HEAP32[$54 >> 2] | 0;
    $90 = $_pr >>> 0 > 256;
    if ($90) {
      label = 28;
      break;
    } else {
      label = 30;
      break;
    }
   case 28:
    HEAP32[$54 >> 2] = 256;
    label = 30;
    break;
   case 29:
    HEAP32[$error >> 2] = 3;
    label = 49;
    break;
   case 30:
    $93 = HEAP32[$18 >> 2] | 0;
    $94 = $93 & 128;
    $95 = ($94 | 0) == 0;
    if ($95) {
      label = 49;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    $97 = _FT_Stream_ReadChar($stream, $error) | 0;
    $98 = $97 & 255;
    $99 = HEAP32[$error >> 2] | 0;
    $100 = ($99 | 0) != 0;
    $101 = $97 << 24 >> 24 == 0;
    $or_cond126 = $100 | $101;
    if ($or_cond126) {
      label = 49;
      break;
    } else {
      $j_3100 = 0;
      label = 32;
      break;
    }
   case 32:
    $102 = _FT_Stream_ReadChar($stream, $error) | 0;
    $103 = $102 & 255;
    $104 = HEAP32[$error >> 2] | 0;
    $105 = ($104 | 0) == 0;
    if ($105) {
      label = 33;
      break;
    } else {
      label = 49;
      break;
    }
   case 33:
    $107 = _FT_Stream_ReadShort($stream, $error) | 0;
    $108 = HEAP32[$error >> 2] | 0;
    $109 = ($108 | 0) == 0;
    if ($109) {
      label = 34;
      break;
    } else {
      label = 49;
      break;
    }
   case 34:
    $111 = $encoding + 12 + ($103 << 1) | 0;
    HEAP16[$111 >> 1] = $107;
    $gindex_0 = 0;
    label = 35;
    break;
   case 35:
    $113 = $gindex_0 >>> 0 < $num_glyphs >>> 0;
    if ($113) {
      label = 36;
      break;
    } else {
      label = 38;
      break;
    }
   case 36:
    $115 = HEAP32[$1 >> 2] | 0;
    $116 = $115 + ($gindex_0 << 1) | 0;
    $117 = HEAP16[$116 >> 1] | 0;
    $118 = $117 << 16 >> 16 == $107 << 16 >> 16;
    $119 = $gindex_0 + 1 | 0;
    if ($118) {
      label = 37;
      break;
    } else {
      $gindex_0 = $119;
      label = 35;
      break;
    }
   case 37:
    $121 = $gindex_0 & 65535;
    $122 = $encoding + 524 + ($103 << 1) | 0;
    HEAP16[$122 >> 1] = $121;
    label = 38;
    break;
   case 38:
    $123 = $j_3100 + 1 | 0;
    $124 = $123 >>> 0 < $98 >>> 0;
    if ($124) {
      $j_3100 = $123;
      label = 32;
      break;
    } else {
      label = 49;
      break;
    }
   case 39:
    if (($offset | 0) == 0) {
      label = 40;
      break;
    } else if (($offset | 0) == 1) {
      label = 41;
      break;
    } else {
      label = 48;
      break;
    }
   case 40:
    $127 = $encoding + 12 | 0;
    $128 = $127;
    _memcpy($128 | 0, 5314020, 512);
    label = 42;
    break;
   case 41:
    $130 = $encoding + 12 | 0;
    $131 = $130;
    _memcpy($131 | 0, 5316748, 512);
    label = 42;
    break;
   case 42:
    $133 = $encoding + 8 | 0;
    HEAP32[$133 >> 2] = 0;
    $134 = $stream + 28 | 0;
    $135 = HEAP32[$134 >> 2] | 0;
    $136 = _cff_charset_compute_cids($charset, $num_glyphs, $135) | 0;
    HEAP32[$error >> 2] = $136;
    $137 = ($136 | 0) == 0;
    if ($137) {
      $j_4117 = 0;
      label = 43;
      break;
    } else {
      label = 49;
      break;
    }
   case 43:
    $138 = $encoding + 12 + ($j_4117 << 1) | 0;
    $139 = HEAP16[$138 >> 1] | 0;
    $140 = $139 << 16 >> 16 == 0;
    if ($140) {
      label = 46;
      break;
    } else {
      label = 44;
      break;
    }
   case 44:
    $142 = $139 & 65535;
    $143 = _cff_charset_cid_to_gindex($charset, $142) | 0;
    $144 = ($143 | 0) == 0;
    if ($144) {
      label = 46;
      break;
    } else {
      label = 45;
      break;
    }
   case 45:
    $146 = $143 & 65535;
    $147 = $encoding + 524 + ($j_4117 << 1) | 0;
    HEAP16[$147 >> 1] = $146;
    $148 = $j_4117 + 1 | 0;
    HEAP32[$133 >> 2] = $148;
    label = 47;
    break;
   case 46:
    $149 = $encoding + 524 + ($j_4117 << 1) | 0;
    HEAP16[$149 >> 1] = 0;
    HEAP16[$138 >> 1] = 0;
    label = 47;
    break;
   case 47:
    $151 = $j_4117 + 1 | 0;
    $exitcond122 = ($151 | 0) == 256;
    if ($exitcond122) {
      label = 49;
      break;
    } else {
      $j_4117 = $151;
      label = 43;
      break;
    }
   case 48:
    HEAP32[$error >> 2] = 3;
    label = 49;
    break;
   case 49:
    $153 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $153 | 0;
  }
  return 0;
}
function _cff_charset_compute_cids($charset, $num_glyphs, $memory) {
  $charset = $charset | 0;
  $num_glyphs = $num_glyphs | 0;
  $memory = $memory | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $max_cid_024 = 0, $i_023 = 0, $8 = 0, $9 = 0, $10 = 0, $_max_cid_0 = 0, $11 = 0, $exitcond = 0, $phitmp = 0, $max_cid_0_lcssa = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $j_020 = 0, $19 = 0, $20 = 0, $j_021 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $j_0 = 0, $29 = 0, $30 = 0, $32 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $charset + 16 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 11;
      break;
    }
   case 2:
    $4 = ($num_glyphs | 0) == 0;
    if ($4) {
      $max_cid_0_lcssa = 0;
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $5 = $charset + 8 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $i_023 = 0;
    $max_cid_024 = 0;
    label = 4;
    break;
   case 4:
    $8 = $6 + ($i_023 << 1) | 0;
    $9 = HEAP16[$8 >> 1] | 0;
    $10 = ($9 & 65535) > ($max_cid_024 & 65535);
    $_max_cid_0 = $10 ? $9 : $max_cid_024;
    $11 = $i_023 + 1 | 0;
    $exitcond = ($11 | 0) == ($num_glyphs | 0);
    if ($exitcond) {
      label = 5;
      break;
    } else {
      $i_023 = $11;
      $max_cid_024 = $_max_cid_0;
      label = 4;
      break;
    }
   case 5:
    $phitmp = $_max_cid_0 & 65535;
    $max_cid_0_lcssa = $phitmp;
    label = 6;
    break;
   case 6:
    $13 = $max_cid_0_lcssa + 1 | 0;
    $14 = _ft_mem_realloc($memory, 2, 0, $13, 0, $error) | 0;
    $15 = $14;
    $16 = $charset + 12 | 0;
    HEAP32[$16 >> 2] = $15;
    $17 = HEAP32[$error >> 2] | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 7;
      break;
    } else {
      label = 11;
      break;
    }
   case 7:
    $j_020 = $num_glyphs - 1 | 0;
    $19 = ($j_020 | 0) > -1;
    if ($19) {
      label = 8;
      break;
    } else {
      label = 10;
      break;
    }
   case 8:
    $20 = $charset + 8 | 0;
    $j_021 = $j_020;
    label = 9;
    break;
   case 9:
    $22 = $j_021 & 65535;
    $23 = HEAP32[$20 >> 2] | 0;
    $24 = $23 + ($j_021 << 1) | 0;
    $25 = HEAP16[$24 >> 1] | 0;
    $26 = $25 & 65535;
    $27 = HEAP32[$16 >> 2] | 0;
    $28 = $27 + ($26 << 1) | 0;
    HEAP16[$28 >> 1] = $22;
    $j_0 = $j_021 - 1 | 0;
    $29 = ($j_0 | 0) > -1;
    if ($29) {
      $j_021 = $j_0;
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    HEAP32[$1 >> 2] = $max_cid_0_lcssa;
    $30 = $charset + 20 | 0;
    HEAP32[$30 >> 2] = $num_glyphs;
    label = 11;
    break;
   case 11:
    $32 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $32 | 0;
  }
  return 0;
}
function _cff_parser_init($parser, $code, $object, $library) {
  $parser = $parser | 0;
  $code = $code | 0;
  $object = $object | 0;
  $library = $library | 0;
  _memset($parser | 0, 0, 412);
  HEAP32[$parser + 404 >> 2] = $parser + 16 | 0;
  HEAP32[$parser + 408 >> 2] = $code;
  HEAP32[$parser + 412 >> 2] = $object;
  HEAP32[$parser >> 2] = $library;
  return;
}
function _cff_parser_run($parser, $start, $limit) {
  $parser = $parser | 0;
  $start = $start | 0;
  $limit = $limit | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p_0100 = 0, $11 = 0, $12 = 0, $13 = 0, $or_cond = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $21 = 0, $p_0_pn = 0, $p_1 = 0, $22 = 0, $24 = 0, $25 = 0, $_mask = 0, $26 = 0, $27 = 0, $28 = 0, $or_cond87 = 0, $30 = 0, $32 = 0, $34 = 0, $35 = 0, $_p_0 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $code_0 = 0, $p_2 = 0, $47 = 0, $48 = 0, $field_0 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $or_cond88 = 0, $67 = 0, $69 = 0, $71 = 0, $val_0 = 0, $73 = 0, $74 = 0, $75 = 0, $77 = 0, $79 = 0, $80 = 0, $82 = 0, $84 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $_ = 0, $92 = 0, $93 = 0, $94 = 0, $data_095 = 0, $q_094 = 0, $val_193 = 0, $num_args_192 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $102 = 0, $104 = 0, $105 = 0, $107 = 0, $109 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $p_3 = 0, $121 = 0, $122 = 0, $error_3 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $parser + 16 | 0;
    $2 = $parser + 404 | 0;
    HEAP32[$2 >> 2] = $1;
    $3 = $parser + 4 | 0;
    HEAP32[$3 >> 2] = $start;
    $4 = $parser + 8 | 0;
    HEAP32[$4 >> 2] = $limit;
    $5 = $parser + 12 | 0;
    HEAP32[$5 >> 2] = $start;
    $6 = $start >>> 0 < $limit >>> 0;
    if ($6) {
      label = 2;
      break;
    } else {
      $error_3 = 0;
      label = 38;
      break;
    }
   case 2:
    $7 = $1;
    $8 = $parser + 408 | 0;
    $9 = $parser + 412 | 0;
    $p_0100 = $start;
    label = 3;
    break;
   case 3:
    $11 = HEAP8[$p_0100] | 0;
    $12 = ($11 & 255) > 26;
    $13 = $11 << 24 >> 24 != 31;
    $or_cond = $12 & $13;
    $14 = HEAP32[$2 >> 2] | 0;
    $15 = $14;
    $16 = $15 - $7 | 0;
    $17 = $16 >> 2;
    if ($or_cond) {
      label = 4;
      break;
    } else {
      label = 11;
      break;
    }
   case 4:
    $19 = ($16 | 0) > 380;
    if ($19) {
      $error_3 = 6;
      label = 38;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $21 = $14 + 4 | 0;
    HEAP32[$2 >> 2] = $21;
    HEAP32[$14 >> 2] = $p_0100;
    if (($11 << 24 >> 24 | 0) == 30) {
      $p_0_pn = $p_0100;
      label = 6;
      break;
    } else if (($11 << 24 >> 24 | 0) == 28) {
      label = 8;
      break;
    } else if (($11 << 24 >> 24 | 0) == 29) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 6:
    $p_1 = $p_0_pn + 1 | 0;
    $22 = $p_1 >>> 0 < $limit >>> 0;
    if ($22) {
      label = 7;
      break;
    } else {
      $error_3 = 0;
      label = 38;
      break;
    }
   case 7:
    $24 = HEAP8[$p_1] | 0;
    $25 = $24 & 255;
    $_mask = $25 & 240;
    $26 = ($_mask | 0) == 240;
    $27 = $25 & 15;
    $28 = ($27 | 0) == 15;
    $or_cond87 = $26 | $28;
    if ($or_cond87) {
      $p_3 = $p_1;
      label = 37;
      break;
    } else {
      $p_0_pn = $p_1;
      label = 6;
      break;
    }
   case 8:
    $30 = $p_0100 + 2 | 0;
    $p_3 = $30;
    label = 37;
    break;
   case 9:
    $32 = $p_0100 + 4 | 0;
    $p_3 = $32;
    label = 37;
    break;
   case 10:
    $34 = ($11 & 255) > 246;
    $35 = $p_0100 + 1 | 0;
    $_p_0 = $34 ? $35 : $p_0100;
    $p_3 = $_p_0;
    label = 37;
    break;
   case 11:
    $37 = $11 & 255;
    HEAP32[$14 >> 2] = $p_0100;
    $38 = $11 << 24 >> 24 == 12;
    if ($38) {
      label = 12;
      break;
    } else {
      $p_2 = $p_0100;
      $code_0 = $37;
      label = 14;
      break;
    }
   case 12:
    $40 = $p_0100 + 1 | 0;
    $41 = $40 >>> 0 < $limit >>> 0;
    if ($41) {
      label = 13;
      break;
    } else {
      $error_3 = 6;
      label = 38;
      break;
    }
   case 13:
    $43 = HEAP8[$40] | 0;
    $44 = $43 & 255;
    $45 = $44 | 256;
    $p_2 = $40;
    $code_0 = $45;
    label = 14;
    break;
   case 14:
    $47 = HEAP32[$8 >> 2] | 0;
    $48 = $47 | $code_0;
    $field_0 = 5315116;
    label = 15;
    break;
   case 15:
    $50 = $field_0 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = ($51 | 0) == 0;
    if ($52) {
      label = 36;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $54 = $field_0 + 4 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = ($55 | 0) == ($48 | 0);
    $57 = $field_0 + 28 | 0;
    if ($56) {
      label = 17;
      break;
    } else {
      $field_0 = $57;
      label = 15;
      break;
    }
   case 17:
    $59 = HEAP32[$9 >> 2] | 0;
    $60 = $field_0 + 8 | 0;
    $61 = HEAP32[$60 >> 2] | 0;
    $62 = $59 + $61 | 0;
    $63 = ($51 | 0) != 6;
    $64 = ($17 | 0) == 0;
    $or_cond88 = $63 & $64;
    if ($or_cond88) {
      $error_3 = 6;
      label = 38;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    if (($51 | 0) == 5 | ($51 | 0) == 4 | ($51 | 0) == 1) {
      label = 19;
      break;
    } else if (($51 | 0) == 2) {
      label = 20;
      break;
    } else if (($51 | 0) == 3) {
      label = 21;
      break;
    } else if (($51 | 0) == 6) {
      label = 27;
      break;
    } else {
      label = 35;
      break;
    }
   case 19:
    $67 = _cff_parse_num($1) | 0;
    $val_0 = $67;
    label = 22;
    break;
   case 20:
    $69 = _cff_parse_fixed($1) | 0;
    $val_0 = $69;
    label = 22;
    break;
   case 21:
    $71 = _cff_parse_fixed_scaled($1, 3) | 0;
    $val_0 = $71;
    label = 22;
    break;
   case 22:
    $73 = $field_0 + 12 | 0;
    $74 = HEAP8[$73] | 0;
    $75 = $74 & 255;
    if (($75 | 0) == 1) {
      label = 23;
      break;
    } else if (($75 | 0) == 2) {
      label = 24;
      break;
    } else if (($75 | 0) == 4) {
      label = 25;
      break;
    } else {
      label = 26;
      break;
    }
   case 23:
    $77 = $val_0 & 255;
    HEAP8[$62] = $77;
    label = 36;
    break;
   case 24:
    $79 = $val_0 & 65535;
    $80 = $62;
    HEAP16[$80 >> 1] = $79;
    label = 36;
    break;
   case 25:
    $82 = $62;
    HEAP32[$82 >> 2] = $val_0;
    label = 36;
    break;
   case 26:
    $84 = $62;
    HEAP32[$84 >> 2] = $val_0;
    label = 36;
    break;
   case 27:
    $86 = $field_0 + 24 | 0;
    $87 = HEAP32[$86 >> 2] | 0;
    $88 = $59 + $87 | 0;
    $89 = $field_0 + 20 | 0;
    $90 = HEAP32[$89 >> 2] | 0;
    $91 = $17 >>> 0 > $90 >>> 0;
    $_ = $91 ? $90 : $17;
    $92 = $_ & 255;
    HEAP8[$88] = $92;
    $93 = ($_ | 0) == 0;
    if ($93) {
      label = 36;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $94 = $field_0 + 12 | 0;
    $num_args_192 = $_;
    $val_193 = 0;
    $q_094 = $62;
    $data_095 = $1;
    label = 29;
    break;
   case 29:
    $96 = $data_095 + 4 | 0;
    $97 = _cff_parse_num($data_095) | 0;
    $98 = $97 + $val_193 | 0;
    $99 = HEAP8[$94] | 0;
    $100 = $99 & 255;
    if (($100 | 0) == 1) {
      label = 30;
      break;
    } else if (($100 | 0) == 2) {
      label = 31;
      break;
    } else if (($100 | 0) == 4) {
      label = 32;
      break;
    } else {
      label = 33;
      break;
    }
   case 30:
    $102 = $98 & 255;
    HEAP8[$q_094] = $102;
    label = 34;
    break;
   case 31:
    $104 = $98 & 65535;
    $105 = $q_094;
    HEAP16[$105 >> 1] = $104;
    label = 34;
    break;
   case 32:
    $107 = $q_094;
    HEAP32[$107 >> 2] = $98;
    label = 34;
    break;
   case 33:
    $109 = $q_094;
    HEAP32[$109 >> 2] = $98;
    label = 34;
    break;
   case 34:
    $111 = HEAP8[$94] | 0;
    $112 = $111 & 255;
    $113 = $q_094 + $112 | 0;
    $114 = $num_args_192 - 1 | 0;
    $115 = ($114 | 0) == 0;
    if ($115) {
      label = 36;
      break;
    } else {
      $num_args_192 = $114;
      $val_193 = $98;
      $q_094 = $113;
      $data_095 = $96;
      label = 29;
      break;
    }
   case 35:
    $117 = $field_0 + 16 | 0;
    $118 = HEAP32[$117 >> 2] | 0;
    $119 = FUNCTION_TABLE_ii[$118 & 1023]($parser) | 0;
    $120 = ($119 | 0) == 0;
    if ($120) {
      label = 36;
      break;
    } else {
      $error_3 = $119;
      label = 38;
      break;
    }
   case 36:
    HEAP32[$2 >> 2] = $1;
    $p_3 = $p_2;
    label = 37;
    break;
   case 37:
    $121 = $p_3 + 1 | 0;
    $122 = $121 >>> 0 < $limit >>> 0;
    if ($122) {
      $p_0100 = $121;
      label = 3;
      break;
    } else {
      $error_3 = 0;
      label = 38;
      break;
    }
   case 38:
    return $error_3 | 0;
  }
  return 0;
}
function _cff_parse_num($d) {
  $d = $d | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $12 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$d >> 2] | 0;
    $2 = HEAP8[$1] | 0;
    $3 = $2 << 24 >> 24 == 30;
    $4 = $d + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $7 = _cff_parse_real($1, $5, 0, 0) | 0;
    $8 = $7 >> 16;
    $12 = $8;
    label = 4;
    break;
   case 3:
    $10 = _cff_parse_integer($1, $5) | 0;
    $12 = $10;
    label = 4;
    break;
   case 4:
    return $12 | 0;
  }
  return 0;
}
function _cff_parse_fixed($d) {
  $d = $d | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$d >> 2] | 0;
    $2 = HEAP8[$1] | 0;
    $3 = $2 << 24 >> 24 == 30;
    $4 = $d + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $7 = _cff_parse_real($1, $5, 0, 0) | 0;
    $12 = $7;
    label = 4;
    break;
   case 3:
    $9 = _cff_parse_integer($1, $5) | 0;
    $10 = $9 << 16;
    $12 = $10;
    label = 4;
    break;
   case 4:
    return $12 | 0;
  }
  return 0;
}
function _cff_parse_integer($start, $limit) {
  $start = $start | 0;
  $limit = $limit | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $val_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $start + 1 | 0;
    $2 = HEAP8[$start] | 0;
    $3 = $2 & 255;
    if (($2 << 24 >> 24 | 0) == 28) {
      label = 2;
      break;
    } else if (($2 << 24 >> 24 | 0) == 29) {
      label = 4;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $5 = $start + 3 | 0;
    $6 = $5 >>> 0 > $limit >>> 0;
    if ($6) {
      $val_0 = 0;
      label = 13;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $8 = HEAP8[$1] | 0;
    $9 = $8 & 255;
    $10 = $9 << 8;
    $11 = $start + 2 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $12 & 255;
    $14 = $10 | $13;
    $15 = $14 << 16 >> 16;
    $val_0 = $15;
    label = 13;
    break;
   case 4:
    $17 = $start + 5 | 0;
    $18 = $17 >>> 0 > $limit >>> 0;
    if ($18) {
      $val_0 = 0;
      label = 13;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $20 = HEAP8[$1] | 0;
    $21 = $20 & 255;
    $22 = $21 << 24;
    $23 = $start + 2 | 0;
    $24 = HEAP8[$23] | 0;
    $25 = $24 & 255;
    $26 = $25 << 16;
    $27 = $26 | $22;
    $28 = $start + 3 | 0;
    $29 = HEAP8[$28] | 0;
    $30 = $29 & 255;
    $31 = $30 << 8;
    $32 = $27 | $31;
    $33 = $start + 4 | 0;
    $34 = HEAP8[$33] | 0;
    $35 = $34 & 255;
    $36 = $32 | $35;
    $val_0 = $36;
    label = 13;
    break;
   case 6:
    $38 = ($2 & 255) < 247;
    if ($38) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $40 = $3 - 139 | 0;
    $val_0 = $40;
    label = 13;
    break;
   case 8:
    $42 = ($2 & 255) < 251;
    $43 = $start + 2 | 0;
    $44 = $43 >>> 0 > $limit >>> 0;
    if ($42) {
      label = 9;
      break;
    } else {
      label = 11;
      break;
    }
   case 9:
    if ($44) {
      $val_0 = 0;
      label = 13;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $47 = $3 << 8;
    $48 = $47 - 63232 | 0;
    $49 = HEAP8[$1] | 0;
    $50 = $49 & 255;
    $51 = $50 | $48;
    $52 = $51 + 108 | 0;
    $val_0 = $52;
    label = 13;
    break;
   case 11:
    if ($44) {
      $val_0 = 0;
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $55 = 251 - $3 | 0;
    $56 = $55 << 8;
    $57 = HEAP8[$1] | 0;
    $58 = $57 & 255;
    $59 = $56 - 108 | 0;
    $60 = $59 - $58 | 0;
    $val_0 = $60;
    label = 13;
    break;
   case 13:
    return $val_0 | 0;
  }
  return 0;
}
function _cff_parse_fixed_scaled($d, $scaling) {
  $d = $d | 0;
  $scaling = $scaling | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$d >> 2] | 0;
    $2 = HEAP8[$1] | 0;
    $3 = $2 << 24 >> 24 == 30;
    $4 = $d + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $7 = _cff_parse_real($1, $5, $scaling, 0) | 0;
    $15 = $7;
    label = 4;
    break;
   case 3:
    $9 = _cff_parse_integer($1, $5) | 0;
    $10 = 5250188 + ($scaling << 2) | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $9 << 16;
    $13 = Math_imul($12, $11);
    $15 = $13;
    label = 4;
    break;
   case 4:
    return $15 | 0;
  }
  return 0;
}
function _cff_parse_real($start, $limit, $power_ten, $scaling) {
  $start = $start | 0;
  $limit = $limit | 0;
  $power_ten = $power_ten | 0;
  $scaling = $scaling | 0;
  var $1 = 0, $phase_0_ph = 0, $number_0_ph = 0, $sign_0_ph = 0, $exponent_add_0_ph = 0, $integer_length_0_ph = 0, $p_0_ph = 0, $3 = 0, $phase_0_ph124 = 0, $sign_0_ph125 = 0, $exponent_add_0_ph126 = 0, $p_0_ph128 = 0, $phase_0_ph130 = 0, $exponent_add_0_ph131 = 0, $p_0_ph133 = 0, $phase_0 = 0, $p_0 = 0, $5 = 0, $7 = 0, $8 = 0, $p_1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $20 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $phase_1_ph = 0, $number_1_ph = 0, $exponent_add_1_ph = 0, $fraction_length_0_ph = 0, $p_2_ph = 0, $30 = 0, $31 = 0, $or_cond103 = 0, $phase_1_ph109 = 0, $exponent_add_1_ph110 = 0, $p_2_ph112 = 0, $phase_1 = 0, $p_2 = 0, $33 = 0, $35 = 0, $36 = 0, $p_3 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $48 = 0, $51 = 0, $52 = 0, $53 = 0, $phase_2 = 0, $number_2 = 0, $exponent_add_2 = 0, $fraction_length_1 = 0, $nib_0 = 0, $p_4 = 0, $54 = 0, $nib_0_off = 0, $55 = 0, $phase_3 = 0, $exponent_0 = 0, $p_5 = 0, $56 = 0, $58 = 0, $59 = 0, $p_6 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $72 = 0, $exponent_0_ = 0, $exponent_1 = 0, $74 = 0, $75 = 0, $77 = 0, $78 = 0, $79 = 0, $81 = 0, $83 = 0, $84 = 0, $85 = 0, $87 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $98 = 0, $99 = 0, $101 = 0, $number_3 = 0, $exponent_2 = 0, $103 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $117 = 0, $118 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $126 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $number_4 = 0, $fraction_length_2 = 0, $133 = 0, $135 = 0, $136 = 0, $number_5 = 0, $fraction_length_3 = 0, $138 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $145 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $153 = 0, $result_0 = 0, $155 = 0, $157 = 0, $result_1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($scaling | 0) != 0;
    if ($1) {
      label = 2;
      break;
    } else {
      $p_0_ph = $start;
      $integer_length_0_ph = 0;
      $exponent_add_0_ph = 0;
      $sign_0_ph = 0;
      $number_0_ph = 0;
      $phase_0_ph = 4;
      label = 3;
      break;
    }
   case 2:
    HEAP32[$scaling >> 2] = 0;
    $p_0_ph = $start;
    $integer_length_0_ph = 0;
    $exponent_add_0_ph = 0;
    $sign_0_ph = 0;
    $number_0_ph = 0;
    $phase_0_ph = 4;
    label = 3;
    break;
   case 3:
    $3 = ($number_0_ph | 0) > 214748363;
    $p_0_ph128 = $p_0_ph;
    $exponent_add_0_ph126 = $exponent_add_0_ph;
    $sign_0_ph125 = $sign_0_ph;
    $phase_0_ph124 = $phase_0_ph;
    label = 4;
    break;
   case 4:
    $p_0_ph133 = $p_0_ph128;
    $exponent_add_0_ph131 = $exponent_add_0_ph126;
    $phase_0_ph130 = $phase_0_ph124;
    label = 5;
    break;
   case 5:
    $p_0 = $p_0_ph133;
    $phase_0 = $phase_0_ph130;
    label = 6;
    break;
   case 6:
    $5 = ($phase_0 | 0) == 0;
    if ($5) {
      $p_1 = $p_0;
      label = 8;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $7 = $p_0 + 1 | 0;
    $8 = $7 >>> 0 < $limit >>> 0;
    if ($8) {
      $p_1 = $7;
      label = 8;
      break;
    } else {
      $result_1 = 0;
      label = 54;
      break;
    }
   case 8:
    $10 = HEAP8[$p_1] | 0;
    $11 = $10 & 255;
    $12 = $11 >>> ($phase_0 >>> 0);
    $13 = $12 & 15;
    $14 = 4 - $phase_0 | 0;
    $15 = ($13 | 0) == 14;
    if ($15) {
      $p_0_ph128 = $p_1;
      $exponent_add_0_ph126 = $exponent_add_0_ph131;
      $sign_0_ph125 = 1;
      $phase_0_ph124 = $14;
      label = 4;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $17 = $13 >>> 0 > 9;
    if ($17) {
      label = 14;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    if ($3) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $20 = $exponent_add_0_ph131 + 1 | 0;
    $p_0_ph133 = $p_1;
    $exponent_add_0_ph131 = $20;
    $phase_0_ph130 = $14;
    label = 5;
    break;
   case 12:
    $22 = $13 | $number_0_ph;
    $23 = ($22 | 0) == 0;
    if ($23) {
      $p_0 = $p_1;
      $phase_0 = $14;
      label = 6;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $25 = $integer_length_0_ph + 1 | 0;
    $26 = $number_0_ph * 10 & -1;
    $27 = $13 + $26 | 0;
    $p_0_ph = $p_1;
    $integer_length_0_ph = $25;
    $exponent_add_0_ph = $exponent_add_0_ph131;
    $sign_0_ph = $sign_0_ph125;
    $number_0_ph = $27;
    $phase_0_ph = $14;
    label = 3;
    break;
   case 14:
    $29 = ($13 | 0) == 10;
    if ($29) {
      $p_2_ph = $p_1;
      $fraction_length_0_ph = 0;
      $exponent_add_1_ph = $exponent_add_0_ph131;
      $number_1_ph = $number_0_ph;
      $phase_1_ph = $14;
      label = 15;
      break;
    } else {
      $p_4 = $p_1;
      $nib_0 = $13;
      $fraction_length_1 = 0;
      $exponent_add_2 = $exponent_add_0_ph131;
      $number_2 = $number_0_ph;
      $phase_2 = $14;
      label = 24;
      break;
    }
   case 15:
    $30 = ($number_1_ph | 0) < 214748364;
    $31 = ($fraction_length_0_ph | 0) < 9;
    $or_cond103 = $30 & $31;
    $p_2_ph112 = $p_2_ph;
    $exponent_add_1_ph110 = $exponent_add_1_ph;
    $phase_1_ph109 = $phase_1_ph;
    label = 16;
    break;
   case 16:
    $p_2 = $p_2_ph112;
    $phase_1 = $phase_1_ph109;
    label = 17;
    break;
   case 17:
    $33 = ($phase_1 | 0) == 0;
    if ($33) {
      $p_3 = $p_2;
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $35 = $p_2 + 1 | 0;
    $36 = $35 >>> 0 < $limit >>> 0;
    if ($36) {
      $p_3 = $35;
      label = 19;
      break;
    } else {
      $result_1 = 0;
      label = 54;
      break;
    }
   case 19:
    $38 = HEAP8[$p_3] | 0;
    $39 = $38 & 255;
    $40 = $39 >>> ($phase_1 >>> 0);
    $41 = $40 & 15;
    $42 = 4 - $phase_1 | 0;
    $43 = $41 >>> 0 > 9;
    if ($43) {
      $p_4 = $p_3;
      $nib_0 = $41;
      $fraction_length_1 = $fraction_length_0_ph;
      $exponent_add_2 = $exponent_add_1_ph110;
      $number_2 = $number_1_ph;
      $phase_2 = $42;
      label = 24;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $45 = $41 | $number_1_ph;
    $46 = ($45 | 0) == 0;
    if ($46) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    $48 = $exponent_add_1_ph110 - 1 | 0;
    $p_2_ph112 = $p_3;
    $exponent_add_1_ph110 = $48;
    $phase_1_ph109 = $42;
    label = 16;
    break;
   case 22:
    if ($or_cond103) {
      label = 23;
      break;
    } else {
      $p_2 = $p_3;
      $phase_1 = $42;
      label = 17;
      break;
    }
   case 23:
    $51 = $fraction_length_0_ph + 1 | 0;
    $52 = $number_1_ph * 10 & -1;
    $53 = $41 + $52 | 0;
    $p_2_ph = $p_3;
    $fraction_length_0_ph = $51;
    $exponent_add_1_ph = $exponent_add_1_ph110;
    $number_1_ph = $53;
    $phase_1_ph = $42;
    label = 15;
    break;
   case 24:
    $54 = ($nib_0 | 0) == 12;
    $nib_0_off = $nib_0 - 11 | 0;
    $55 = $nib_0_off >>> 0 < 2;
    if ($55) {
      $p_5 = $p_4;
      $exponent_0 = 0;
      $phase_3 = $phase_2;
      label = 25;
      break;
    } else {
      $exponent_1 = 0;
      label = 30;
      break;
    }
   case 25:
    $56 = ($phase_3 | 0) == 0;
    if ($56) {
      $p_6 = $p_5;
      label = 27;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $58 = $p_5 + 1 | 0;
    $59 = $58 >>> 0 < $limit >>> 0;
    if ($59) {
      $p_6 = $58;
      label = 27;
      break;
    } else {
      $result_1 = 0;
      label = 54;
      break;
    }
   case 27:
    $61 = HEAP8[$p_6] | 0;
    $62 = $61 & 255;
    $63 = $62 >>> ($phase_3 >>> 0);
    $64 = $63 & 15;
    $65 = $64 >>> 0 > 9;
    if ($65) {
      label = 29;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $67 = 4 - $phase_3 | 0;
    $68 = $exponent_0 * 10 & -1;
    $69 = $64 + $68 | 0;
    $70 = ($69 | 0) > 1e3;
    if ($70) {
      $result_1 = 0;
      label = 54;
      break;
    } else {
      $p_5 = $p_6;
      $exponent_0 = $69;
      $phase_3 = $67;
      label = 25;
      break;
    }
   case 29:
    $72 = -$exponent_0 | 0;
    $exponent_0_ = $54 ? $72 : $exponent_0;
    $exponent_1 = $exponent_0_;
    label = 30;
    break;
   case 30:
    $74 = $exponent_add_2 + $power_ten | 0;
    $75 = $74 + $exponent_1 | 0;
    if ($1) {
      label = 31;
      break;
    } else {
      label = 42;
      break;
    }
   case 31:
    $77 = $fraction_length_1 + $integer_length_0_ph | 0;
    $78 = $75 + $integer_length_0_ph | 0;
    $79 = ($77 | 0) < 6;
    if ($79) {
      label = 32;
      break;
    } else {
      label = 39;
      break;
    }
   case 32:
    $81 = ($number_2 | 0) > 32767;
    if ($81) {
      label = 33;
      break;
    } else {
      label = 34;
      break;
    }
   case 33:
    $83 = _FT_DivFix($number_2, 10) | 0;
    $84 = 1 - $77 | 0;
    $85 = $84 + $78 | 0;
    HEAP32[$scaling >> 2] = $85;
    $result_0 = $83;
    label = 52;
    break;
   case 34:
    $87 = ($78 | 0) > 0;
    if ($87) {
      label = 35;
      break;
    } else {
      label = 37;
      break;
    }
   case 35:
    $89 = ($78 | 0) < 5;
    $90 = $89 ? $78 : 5;
    $91 = $78 - $90 | 0;
    $92 = $90 - $77 | 0;
    $93 = 5250188 + ($92 << 2) | 0;
    $94 = HEAP32[$93 >> 2] | 0;
    $95 = Math_imul($94, $number_2);
    $96 = ($95 | 0) > 32767;
    if ($96) {
      label = 36;
      break;
    } else {
      $exponent_2 = $91;
      $number_3 = $95;
      label = 38;
      break;
    }
   case 36:
    $98 = ($95 | 0) / 10 & -1;
    $99 = $91 + 1 | 0;
    $exponent_2 = $99;
    $number_3 = $98;
    label = 38;
    break;
   case 37:
    $101 = $78 - $77 | 0;
    $exponent_2 = $101;
    $number_3 = $number_2;
    label = 38;
    break;
   case 38:
    $103 = $number_3 << 16;
    HEAP32[$scaling >> 2] = $exponent_2;
    $result_0 = $103;
    label = 52;
    break;
   case 39:
    $105 = $77 - 5 | 0;
    $106 = 5250188 + ($105 << 2) | 0;
    $107 = HEAP32[$106 >> 2] | 0;
    $108 = ($number_2 | 0) / ($107 | 0) & -1;
    $109 = ($108 | 0) > 32767;
    if ($109) {
      label = 40;
      break;
    } else {
      label = 41;
      break;
    }
   case 40:
    $111 = $77 - 4 | 0;
    $112 = 5250188 + ($111 << 2) | 0;
    $113 = HEAP32[$112 >> 2] | 0;
    $114 = _FT_DivFix($number_2, $113) | 0;
    $115 = $78 - 4 | 0;
    HEAP32[$scaling >> 2] = $115;
    $result_0 = $114;
    label = 52;
    break;
   case 41:
    $117 = _FT_DivFix($number_2, $107) | 0;
    $118 = $78 - 5 | 0;
    HEAP32[$scaling >> 2] = $118;
    $result_0 = $117;
    label = 52;
    break;
   case 42:
    $120 = $75 + $integer_length_0_ph | 0;
    $121 = ($120 | 0) < 0;
    $122 = -$120 | 0;
    $123 = $121 ? $122 : $120;
    $124 = ($123 | 0) > 5;
    if ($124) {
      $result_1 = 0;
      label = 54;
      break;
    } else {
      label = 43;
      break;
    }
   case 43:
    $126 = $fraction_length_1 - $75 | 0;
    if ($121) {
      label = 44;
      break;
    } else {
      $fraction_length_2 = $126;
      $number_4 = $number_2;
      label = 45;
      break;
    }
   case 44:
    $128 = 5250188 + ($122 << 2) | 0;
    $129 = HEAP32[$128 >> 2] | 0;
    $130 = ($number_2 | 0) / ($129 | 0) & -1;
    $131 = $fraction_length_1 + $integer_length_0_ph | 0;
    $fraction_length_2 = $131;
    $number_4 = $130;
    label = 45;
    break;
   case 45:
    $133 = ($fraction_length_2 | 0) == 10;
    if ($133) {
      label = 46;
      break;
    } else {
      $fraction_length_3 = $fraction_length_2;
      $number_5 = $number_4;
      label = 47;
      break;
    }
   case 46:
    $135 = ($number_4 | 0) / 10 & -1;
    $136 = $fraction_length_2 - 1 | 0;
    $fraction_length_3 = $136;
    $number_5 = $135;
    label = 47;
    break;
   case 47:
    $138 = ($fraction_length_3 | 0) > 0;
    if ($138) {
      label = 48;
      break;
    } else {
      label = 50;
      break;
    }
   case 48:
    $140 = 5250188 + ($fraction_length_3 << 2) | 0;
    $141 = HEAP32[$140 >> 2] | 0;
    $142 = ($number_5 | 0) / ($141 | 0) & -1;
    $143 = ($142 | 0) > 32767;
    if ($143) {
      $result_1 = 0;
      label = 54;
      break;
    } else {
      label = 49;
      break;
    }
   case 49:
    $145 = _FT_DivFix($number_5, $141) | 0;
    $result_0 = $145;
    label = 52;
    break;
   case 50:
    $147 = -$fraction_length_3 | 0;
    $148 = 5250188 + ($147 << 2) | 0;
    $149 = HEAP32[$148 >> 2] | 0;
    $150 = Math_imul($149, $number_5);
    $151 = ($150 | 0) > 32767;
    if ($151) {
      $result_1 = 0;
      label = 54;
      break;
    } else {
      label = 51;
      break;
    }
   case 51:
    $153 = $150 << 16;
    $result_0 = $153;
    label = 52;
    break;
   case 52:
    $155 = ($sign_0_ph125 | 0) == 0;
    if ($155) {
      $result_1 = $result_0;
      label = 54;
      break;
    } else {
      label = 53;
      break;
    }
   case 53:
    $157 = -$result_0 | 0;
    $result_1 = $157;
    label = 54;
    break;
   case 54:
    return $result_1 | 0;
  }
  return 0;
}
function _cff_parse_font_matrix($parser) {
  $parser = $parser | 0;
  var $scaling = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $or_cond = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $scaling = __stackBase__ | 0;
    $1 = $parser + 412 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 68 | 0;
    $4 = $2 + 64 | 0;
    $5 = $4;
    $6 = $parser + 404 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $parser + 40 | 0;
    $9 = $7 >>> 0 < $8 >>> 0;
    if ($9) {
      $error_0 = 161;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $11 = $2 + 48 | 0;
    $12 = $parser + 16 | 0;
    $13 = _cff_parse_fixed_dynamic($12, $scaling) | 0;
    $14 = $11;
    HEAP32[$14 >> 2] = $13;
    $15 = HEAP32[$scaling >> 2] | 0;
    $16 = -$15 | 0;
    HEAP32[$scaling >> 2] = $16;
    $17 = ($15 | 0) > 0;
    $18 = ($16 | 0) > 9;
    $or_cond = $17 | $18;
    if ($or_cond) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    HEAP32[$14 >> 2] = 65536;
    $20 = $2 + 56 | 0;
    $21 = $20;
    HEAP32[$21 >> 2] = 0;
    $22 = $2 + 60 | 0;
    $23 = $22;
    HEAP32[$23 >> 2] = 65536;
    $24 = $3;
    HEAP32[$24 >> 2] = 0;
    $25 = $2 + 72 | 0;
    $26 = $25;
    HEAP32[$26 >> 2] = 0;
    HEAP32[$5 >> 2] = 1;
    $error_0 = 0;
    label = 5;
    break;
   case 4:
    $28 = $parser + 20 | 0;
    $29 = $parser + 24 | 0;
    $30 = _cff_parse_fixed_scaled($28, $16) | 0;
    $31 = $2 + 56 | 0;
    $32 = $31;
    HEAP32[$32 >> 2] = $30;
    $33 = $parser + 28 | 0;
    $34 = HEAP32[$scaling >> 2] | 0;
    $35 = _cff_parse_fixed_scaled($29, $34) | 0;
    $36 = $2 + 52 | 0;
    $37 = $36;
    HEAP32[$37 >> 2] = $35;
    $38 = $parser + 32 | 0;
    $39 = HEAP32[$scaling >> 2] | 0;
    $40 = _cff_parse_fixed_scaled($33, $39) | 0;
    $41 = $2 + 60 | 0;
    $42 = $41;
    HEAP32[$42 >> 2] = $40;
    $43 = $parser + 36 | 0;
    $44 = HEAP32[$scaling >> 2] | 0;
    $45 = _cff_parse_fixed_scaled($38, $44) | 0;
    $46 = $3;
    HEAP32[$46 >> 2] = $45;
    $47 = HEAP32[$scaling >> 2] | 0;
    $48 = _cff_parse_fixed_scaled($43, $47) | 0;
    $49 = $2 + 72 | 0;
    $50 = $49;
    HEAP32[$50 >> 2] = $48;
    $51 = HEAP32[$scaling >> 2] | 0;
    $52 = 5250188 + ($51 << 2) | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    HEAP32[$5 >> 2] = $53;
    $error_0 = 0;
    label = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _cff_parse_font_bbox($parser) {
  $parser = $parser | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $parser + 412 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $parser + 404 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $parser + 32 | 0;
    $6 = $4 >>> 0 < $5 >>> 0;
    if ($6) {
      $error_0 = 161;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $2 + 80 | 0;
    $9 = $parser + 16 | 0;
    $10 = $parser + 20 | 0;
    $11 = _cff_parse_fixed($9) | 0;
    $12 = _FT_RoundFix($11) | 0;
    $13 = $8;
    HEAP32[$13 >> 2] = $12;
    $14 = $parser + 24 | 0;
    $15 = _cff_parse_fixed($10) | 0;
    $16 = _FT_RoundFix($15) | 0;
    $17 = $2 + 84 | 0;
    $18 = $17;
    HEAP32[$18 >> 2] = $16;
    $19 = $parser + 28 | 0;
    $20 = _cff_parse_fixed($14) | 0;
    $21 = _FT_RoundFix($20) | 0;
    $22 = $2 + 88 | 0;
    $23 = $22;
    HEAP32[$23 >> 2] = $21;
    $24 = _cff_parse_fixed($19) | 0;
    $25 = _FT_RoundFix($24) | 0;
    $26 = $2 + 92 | 0;
    $27 = $26;
    HEAP32[$27 >> 2] = $25;
    $error_0 = 0;
    label = 3;
    break;
   case 3:
    return $error_0 | 0;
  }
  return 0;
}
function _cff_parse_private_dict($parser) {
  $parser = $parser | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $parser + 412 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $parser + 404 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $parser + 24 | 0;
    $6 = $4 >>> 0 < $5 >>> 0;
    if ($6) {
      $error_0 = 161;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $parser + 16 | 0;
    $9 = $parser + 20 | 0;
    $10 = _cff_parse_num($8) | 0;
    $11 = $2 + 116 | 0;
    $12 = $11;
    HEAP32[$12 >> 2] = $10;
    $13 = _cff_parse_num($9) | 0;
    $14 = $2 + 112 | 0;
    $15 = $14;
    HEAP32[$15 >> 2] = $13;
    $error_0 = 0;
    label = 3;
    break;
   case 3:
    return $error_0 | 0;
  }
  return 0;
}
function _cff_parse_cid_ros($parser) {
  $parser = $parser | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $parser + 412 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $parser + 404 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $parser + 28 | 0;
    $6 = $4 >>> 0 < $5 >>> 0;
    if ($6) {
      $error_0 = 161;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $parser + 16 | 0;
    $9 = $parser + 20 | 0;
    $10 = _cff_parse_num($8) | 0;
    $11 = $2 + 128 | 0;
    $12 = $11;
    HEAP32[$12 >> 2] = $10;
    $13 = $parser + 24 | 0;
    $14 = _cff_parse_num($9) | 0;
    $15 = $2 + 132 | 0;
    $16 = $15;
    HEAP32[$16 >> 2] = $14;
    $17 = _cff_parse_num($13) | 0;
    $18 = $2 + 136 | 0;
    $19 = $18;
    HEAP32[$19 >> 2] = $17;
    $error_0 = 0;
    label = 3;
    break;
   case 3:
    return $error_0 | 0;
  }
  return 0;
}
function _cff_parse_fixed_dynamic($d, $scaling) {
  $d = $d | 0;
  $scaling = $scaling | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $9 = 0, $10 = 0, $integer_length_0 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $32 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[$d >> 2] | 0;
    $2 = HEAP8[$1] | 0;
    $3 = $2 << 24 >> 24 == 30;
    $4 = $d + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $7 = _cff_parse_real($1, $5, 0, $scaling) | 0;
    $_0 = $7;
    label = 10;
    break;
   case 3:
    $9 = _cff_parse_integer($1, $5) | 0;
    $10 = ($9 | 0) > 32767;
    if ($10) {
      $integer_length_0 = 5;
      label = 4;
      break;
    } else {
      label = 9;
      break;
    }
   case 4:
    $11 = ($integer_length_0 | 0) < 10;
    if ($11) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $13 = 5250188 + ($integer_length_0 << 2) | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = ($9 | 0) < ($14 | 0);
    $16 = $integer_length_0 + 1 | 0;
    if ($15) {
      label = 6;
      break;
    } else {
      $integer_length_0 = $16;
      label = 4;
      break;
    }
   case 6:
    $18 = $integer_length_0 - 5 | 0;
    $19 = 5250188 + ($18 << 2) | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = ($9 | 0) / ($20 | 0) & -1;
    $22 = ($21 | 0) > 32767;
    if ($22) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $24 = $integer_length_0 - 4 | 0;
    HEAP32[$scaling >> 2] = $24;
    $25 = 5250188 + ($24 << 2) | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = _FT_DivFix($9, $26) | 0;
    $_0 = $27;
    label = 10;
    break;
   case 8:
    HEAP32[$scaling >> 2] = $18;
    $29 = HEAP32[$19 >> 2] | 0;
    $30 = _FT_DivFix($9, $29) | 0;
    $_0 = $30;
    label = 10;
    break;
   case 9:
    HEAP32[$scaling >> 2] = 0;
    $32 = $9 << 16;
    $_0 = $32;
    label = 10;
    break;
   case 10:
    return $_0 | 0;
  }
  return 0;
}
function _cff_index_load_offsets($idx) {
  $idx = $idx | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $poff_051 = 0, $p_050 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $poff_156 = 0, $p_155 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $poff_261 = 0, $p_260 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $poff_347 = 0, $p_346 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $_pr = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $96 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    HEAP32[$error >> 2] = 0;
    $1 = $idx | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 28 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $idx + 8 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 16;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = $idx + 24 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 3;
      break;
    } else {
      label = 16;
      break;
    }
   case 3:
    $13 = $idx + 12 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $6 + 1 | 0;
    $16 = $14 & 255;
    $17 = Math_imul($16, $15);
    $18 = _ft_mem_realloc($4, 4, 0, $15, 0, $error) | 0;
    $19 = $18;
    HEAP32[$9 >> 2] = $19;
    $20 = HEAP32[$error >> 2] | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 4;
      break;
    } else {
      label = 17;
      break;
    }
   case 4:
    $23 = $idx + 4 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24 + 3 | 0;
    $26 = _FT_Stream_Seek($2, $25) | 0;
    HEAP32[$error >> 2] = $26;
    $27 = ($26 | 0) == 0;
    if ($27) {
      label = 5;
      break;
    } else {
      label = 17;
      break;
    }
   case 5:
    $29 = _FT_Stream_EnterFrame($2, $17) | 0;
    HEAP32[$error >> 2] = $29;
    $30 = ($29 | 0) == 0;
    if ($30) {
      label = 6;
      break;
    } else {
      label = 17;
      break;
    }
   case 6:
    $32 = HEAP32[$9 >> 2] | 0;
    $33 = $2 + 32 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $34 + $17 | 0;
    if (($16 | 0) == 3) {
      label = 7;
      break;
    } else if (($16 | 0) == 2) {
      label = 8;
      break;
    } else if (($16 | 0) == 1) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 7:
    $36 = ($17 | 0) > 0;
    if ($36) {
      $p_260 = $34;
      $poff_261 = $32;
      label = 13;
      break;
    } else {
      label = 15;
      break;
    }
   case 8:
    $37 = ($17 | 0) > 0;
    if ($37) {
      $p_155 = $34;
      $poff_156 = $32;
      label = 12;
      break;
    } else {
      label = 15;
      break;
    }
   case 9:
    $38 = ($17 | 0) > 0;
    if ($38) {
      $p_050 = $34;
      $poff_051 = $32;
      label = 11;
      break;
    } else {
      label = 15;
      break;
    }
   case 10:
    $39 = ($17 | 0) > 0;
    if ($39) {
      $p_346 = $34;
      $poff_347 = $32;
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 11:
    $40 = HEAP8[$p_050] | 0;
    $41 = $40 & 255;
    HEAP32[$poff_051 >> 2] = $41;
    $42 = $p_050 + 1 | 0;
    $43 = $poff_051 + 4 | 0;
    $44 = $42 >>> 0 < $35 >>> 0;
    if ($44) {
      $p_050 = $42;
      $poff_051 = $43;
      label = 11;
      break;
    } else {
      label = 15;
      break;
    }
   case 12:
    $45 = HEAP8[$p_155] | 0;
    $46 = $45 & 255;
    $47 = $46 << 8;
    $48 = $p_155 + 1 | 0;
    $49 = HEAP8[$48] | 0;
    $50 = $49 & 255;
    $51 = $47 | $50;
    HEAP32[$poff_156 >> 2] = $51;
    $52 = $p_155 + 2 | 0;
    $53 = $poff_156 + 4 | 0;
    $54 = $52 >>> 0 < $35 >>> 0;
    if ($54) {
      $p_155 = $52;
      $poff_156 = $53;
      label = 12;
      break;
    } else {
      label = 15;
      break;
    }
   case 13:
    $55 = HEAP8[$p_260] | 0;
    $56 = $55 << 24 >> 24;
    $57 = $56 << 16;
    $58 = $p_260 + 1 | 0;
    $59 = HEAP8[$58] | 0;
    $60 = $59 & 255;
    $61 = $60 << 8;
    $62 = $61 | $57;
    $63 = $p_260 + 2 | 0;
    $64 = HEAP8[$63] | 0;
    $65 = $64 & 255;
    $66 = $62 | $65;
    HEAP32[$poff_261 >> 2] = $66;
    $67 = $p_260 + 3 | 0;
    $68 = $poff_261 + 4 | 0;
    $69 = $67 >>> 0 < $35 >>> 0;
    if ($69) {
      $p_260 = $67;
      $poff_261 = $68;
      label = 13;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $70 = HEAP8[$p_346] | 0;
    $71 = $70 & 255;
    $72 = $71 << 24;
    $73 = $p_346 + 1 | 0;
    $74 = HEAP8[$73] | 0;
    $75 = $74 & 255;
    $76 = $75 << 16;
    $77 = $76 | $72;
    $78 = $p_346 + 2 | 0;
    $79 = HEAP8[$78] | 0;
    $80 = $79 & 255;
    $81 = $80 << 8;
    $82 = $77 | $81;
    $83 = $p_346 + 3 | 0;
    $84 = HEAP8[$83] | 0;
    $85 = $84 & 255;
    $86 = $82 | $85;
    HEAP32[$poff_347 >> 2] = $86;
    $87 = $p_346 + 4 | 0;
    $88 = $poff_347 + 4 | 0;
    $89 = $87 >>> 0 < $35 >>> 0;
    if ($89) {
      $p_346 = $87;
      $poff_347 = $88;
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    _FT_Stream_ExitFrame($2);
    label = 16;
    break;
   case 16:
    $_pr = HEAP32[$error >> 2] | 0;
    $91 = ($_pr | 0) == 0;
    if ($91) {
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $92 = $idx + 24 | 0;
    $93 = HEAP32[$92 >> 2] | 0;
    $94 = $93;
    _ft_mem_free($4, $94);
    HEAP32[$92 >> 2] = 0;
    label = 18;
    break;
   case 18:
    $96 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $96 | 0;
  }
  return 0;
}
function _cff_size_get_globals_funcs($size) {
  $size = $size | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $or_cond = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $24 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $size | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 692 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 2052 | 0;
    $6 = $5;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $2 + 96 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 + 4 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11;
    $13 = _FT_Get_Module($12, 5322380) | 0;
    $14 = $13;
    $15 = ($13 | 0) == 0;
    $16 = ($7 | 0) == 0;
    $or_cond = $15 | $16;
    if ($or_cond) {
      $24 = 0;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $18 = $7 | 0;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = ($19 | 0) == 0;
    if ($20) {
      $24 = 0;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $22 = FUNCTION_TABLE_ii[$19 & 1023]($14) | 0;
    $24 = $22;
    label = 4;
    break;
   case 4:
    return $24 | 0;
  }
  return 0;
}
function _cff_fd_select_get($fdselect, $glyph_index) {
  $fdselect = $fdselect | 0;
  $glyph_index = $glyph_index | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $p_0 = 0, $first_0 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $51 = 0, $fd_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $fdselect | 0;
    $2 = HEAP8[$1] | 0;
    $3 = $2 & 255;
    if (($3 | 0) == 0) {
      label = 2;
      break;
    } else if (($3 | 0) == 3) {
      label = 3;
      break;
    } else {
      $fd_0 = 0;
      label = 10;
      break;
    }
   case 2:
    $5 = $fdselect + 8 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $6 + $glyph_index | 0;
    $8 = HEAP8[$7] | 0;
    $fd_0 = $8;
    label = 10;
    break;
   case 3:
    $10 = $fdselect + 16 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $glyph_index - $11 | 0;
    $13 = $fdselect + 20 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $12 >>> 0 < $14 >>> 0;
    if ($15) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $17 = $fdselect + 24 | 0;
    $18 = HEAP8[$17] | 0;
    $fd_0 = $18;
    label = 10;
    break;
   case 5:
    $20 = $fdselect + 8 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $fdselect + 12 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $21 + $23 | 0;
    $25 = $21 + 2 | 0;
    $26 = HEAP8[$21] | 0;
    $27 = $26 & 255;
    $28 = $27 << 8;
    $29 = $21 + 1 | 0;
    $30 = HEAP8[$29] | 0;
    $31 = $30 & 255;
    $32 = $28 | $31;
    $first_0 = $32;
    $p_0 = $25;
    label = 6;
    break;
   case 6:
    $34 = $first_0 >>> 0 > $glyph_index >>> 0;
    if ($34) {
      $fd_0 = 0;
      label = 10;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $36 = HEAP8[$p_0] | 0;
    $37 = $p_0 + 3 | 0;
    $38 = $p_0 + 1 | 0;
    $39 = HEAP8[$38] | 0;
    $40 = $39 & 255;
    $41 = $40 << 8;
    $42 = $p_0 + 2 | 0;
    $43 = HEAP8[$42] | 0;
    $44 = $43 & 255;
    $45 = $41 | $44;
    $46 = $45 >>> 0 > $glyph_index >>> 0;
    if ($46) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    HEAP32[$10 >> 2] = $first_0;
    $48 = $45 - $first_0 | 0;
    HEAP32[$13 >> 2] = $48;
    $49 = $fdselect + 24 | 0;
    HEAP8[$49] = $36;
    $fd_0 = $36;
    label = 10;
    break;
   case 9:
    $51 = $37 >>> 0 < $24 >>> 0;
    if ($51) {
      $first_0 = $45;
      $p_0 = $37;
      label = 6;
      break;
    } else {
      $fd_0 = 0;
      label = 10;
      break;
    }
   case 10:
    return $fd_0 | 0;
  }
  return 0;
}
function _cff_make_private_dict($subfont, $priv) {
  $subfont = $subfont | 0;
  $priv = $priv | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $n_086 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $exitcond94 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $n_182 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $exitcond93 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $n_278 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $exitcond92 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $n_374 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $exitcond91 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $n_470 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $exitcond90 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $n_569 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $exitcond = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $priv;
    _memset($1 | 0, 0, 196);
    $2 = $subfont + 172 | 0;
    $3 = HEAP8[$2] | 0;
    $4 = $priv + 8 | 0;
    HEAP8[$4] = $3;
    $5 = $3 << 24 >> 24 == 0;
    if ($5) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $3 & 255;
    $n_086 = 0;
    label = 3;
    break;
   case 3:
    $8 = $subfont + 176 + ($n_086 << 2) | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 & 65535;
    $11 = $priv + 12 + ($n_086 << 1) | 0;
    HEAP16[$11 >> 1] = $10;
    $12 = $n_086 + 1 | 0;
    $exitcond94 = ($12 | 0) == ($6 | 0);
    if ($exitcond94) {
      label = 4;
      break;
    } else {
      $n_086 = $12;
      label = 3;
      break;
    }
   case 4:
    $13 = $subfont + 173 | 0;
    $14 = HEAP8[$13] | 0;
    $15 = $priv + 9 | 0;
    HEAP8[$15] = $14;
    $16 = $14 << 24 >> 24 == 0;
    if ($16) {
      label = 7;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = $14 & 255;
    $n_182 = 0;
    label = 6;
    break;
   case 6:
    $19 = $subfont + 232 + ($n_182 << 2) | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $20 & 65535;
    $22 = $priv + 40 + ($n_182 << 1) | 0;
    HEAP16[$22 >> 1] = $21;
    $23 = $n_182 + 1 | 0;
    $exitcond93 = ($23 | 0) == ($17 | 0);
    if ($exitcond93) {
      label = 7;
      break;
    } else {
      $n_182 = $23;
      label = 6;
      break;
    }
   case 7:
    $24 = $subfont + 174 | 0;
    $25 = HEAP8[$24] | 0;
    $26 = $priv + 10 | 0;
    HEAP8[$26] = $25;
    $27 = $25 << 24 >> 24 == 0;
    if ($27) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $28 = $25 & 255;
    $n_278 = 0;
    label = 9;
    break;
   case 9:
    $30 = $subfont + 272 + ($n_278 << 2) | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $31 & 65535;
    $33 = $priv + 60 + ($n_278 << 1) | 0;
    HEAP16[$33 >> 1] = $32;
    $34 = $n_278 + 1 | 0;
    $exitcond92 = ($34 | 0) == ($28 | 0);
    if ($exitcond92) {
      label = 10;
      break;
    } else {
      $n_278 = $34;
      label = 9;
      break;
    }
   case 10:
    $35 = $subfont + 175 | 0;
    $36 = HEAP8[$35] | 0;
    $37 = $priv + 11 | 0;
    HEAP8[$37] = $36;
    $38 = $36 << 24 >> 24 == 0;
    if ($38) {
      label = 13;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $39 = $36 & 255;
    $n_374 = 0;
    label = 12;
    break;
   case 12:
    $41 = $subfont + 328 + ($n_374 << 2) | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = $42 & 65535;
    $44 = $priv + 88 + ($n_374 << 1) | 0;
    HEAP16[$44 >> 1] = $43;
    $45 = $n_374 + 1 | 0;
    $exitcond91 = ($45 | 0) == ($39 | 0);
    if ($exitcond91) {
      label = 13;
      break;
    } else {
      $n_374 = $45;
      label = 12;
      break;
    }
   case 13:
    $46 = $subfont + 368 | 0;
    $47 = HEAP32[$46 >> 2] | 0;
    $48 = $priv + 108 | 0;
    HEAP32[$48 >> 2] = $47;
    $49 = $subfont + 372 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $priv + 112 | 0;
    HEAP32[$51 >> 2] = $50;
    $52 = $subfont + 376 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $priv + 116 | 0;
    HEAP32[$54 >> 2] = $53;
    $55 = $subfont + 380 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = $56 & 65535;
    $58 = $priv + 120 | 0;
    HEAP16[$58 >> 1] = $57;
    $59 = $subfont + 384 | 0;
    $60 = HEAP32[$59 >> 2] | 0;
    $61 = $60 & 65535;
    $62 = $priv + 122 | 0;
    HEAP16[$62 >> 1] = $61;
    $63 = $subfont + 388 | 0;
    $64 = HEAP8[$63] | 0;
    $65 = $priv + 124 | 0;
    HEAP8[$65] = $64;
    $66 = $64 << 24 >> 24 == 0;
    if ($66) {
      label = 16;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $67 = $64 & 255;
    $n_470 = 0;
    label = 15;
    break;
   case 15:
    $69 = $subfont + 392 + ($n_470 << 2) | 0;
    $70 = HEAP32[$69 >> 2] | 0;
    $71 = $70 & 65535;
    $72 = $priv + 128 + ($n_470 << 1) | 0;
    HEAP16[$72 >> 1] = $71;
    $73 = $n_470 + 1 | 0;
    $exitcond90 = ($73 | 0) == ($67 | 0);
    if ($exitcond90) {
      label = 16;
      break;
    } else {
      $n_470 = $73;
      label = 15;
      break;
    }
   case 16:
    $74 = $subfont + 389 | 0;
    $75 = HEAP8[$74] | 0;
    $76 = $priv + 125 | 0;
    HEAP8[$76] = $75;
    $77 = $75 << 24 >> 24 == 0;
    if ($77) {
      label = 19;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $78 = $75 & 255;
    $n_569 = 0;
    label = 18;
    break;
   case 18:
    $80 = $subfont + 444 + ($n_569 << 2) | 0;
    $81 = HEAP32[$80 >> 2] | 0;
    $82 = $81 & 65535;
    $83 = $priv + 154 + ($n_569 << 1) | 0;
    HEAP16[$83 >> 1] = $82;
    $84 = $n_569 + 1 | 0;
    $exitcond = ($84 | 0) == ($78 | 0);
    if ($exitcond) {
      label = 19;
      break;
    } else {
      $n_569 = $84;
      label = 18;
      break;
    }
   case 19:
    $85 = $subfont + 496 | 0;
    $86 = HEAP8[$85] | 0;
    $87 = $priv + 126 | 0;
    HEAP8[$87] = $86;
    $88 = $subfont + 508 | 0;
    $89 = HEAP32[$88 >> 2] | 0;
    $90 = $priv + 184 | 0;
    HEAP32[$90 >> 2] = $89;
    $91 = $subfont + 504 | 0;
    $92 = HEAP32[$91 >> 2] | 0;
    $93 = $priv + 4 | 0;
    HEAP32[$93 >> 2] = $92;
    return;
  }
}
function _cff_slot_load($glyph, $size, $glyph_index, $load_flags) {
  $glyph = $glyph | 0;
  $size = $size | 0;
  $glyph_index = $glyph_index | 0;
  $load_flags = $load_flags | 0;
  var $decoder = 0, $font_matrix = 0, $metrics = 0, $charstring = 0, $charstring_len = 0, $metrics1 = 0, $cbox = 0, $advance = 0, $vertBearingY = 0, $vertAdvance = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $_0183 = 0, $27 = 0, $28 = 0, $29 = 0, $load_flags_ = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $126 = 0, $127 = 0, $128 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $137 = 0, $138 = 0, $fd_index_0 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $font_offset_sroa_0_0__idx49 = 0, $font_offset_sroa_0_0_copyload50 = 0, $font_offset_sroa_1_4__idx56 = 0, $font_offset_sroa_1_4_copyload57 = 0, $153 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $160 = 0, $161 = 0, $162 = 0, $font_offset_sroa_0_0__idx47 = 0, $163 = 0, $font_offset_sroa_0_0_copyload48 = 0, $164 = 0, $font_offset_sroa_1_4_copyload55 = 0, $font_offset_sroa_0_0 = 0, $font_offset_sroa_1_0 = 0, $force_scaling_0 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $172 = 0, $173 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $183 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $191 = 0, $192 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $206 = 0, $207 = 0, $209 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $_sum = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $230 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $260 = 0, $261 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $font_offset_sroa_0_0__idx = 0, $font_offset_sroa_1_4__idx53 = 0, $274 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $319 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $340 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $348 = 0, $349 = 0, $350 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $359 = 0, $360 = 0, $361 = 0, $363 = 0, $364 = 0, $365 = 0, $367 = 0, $368 = 0, $369 = 0, $372 = 0, $373 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $_not = 0, $384 = 0, $or_cond186 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $391 = 0, $392 = 0, $393 = 0, $395 = 0, $396 = 0, $397 = 0, $vec_0193 = 0, $n_0192 = 0, $399 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $410 = 0, $411 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $436 = 0, $437 = 0, $439 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 1008 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $decoder = __stackBase__ | 0;
    $font_matrix = __stackBase__ + 928 | 0;
    $metrics = __stackBase__ + 944 | 0;
    $charstring = __stackBase__ + 952 | 0;
    $charstring_len = __stackBase__ + 956 | 0;
    $metrics1 = __stackBase__ + 960 | 0;
    $cbox = __stackBase__ + 976 | 0;
    $advance = __stackBase__ + 992 | 0;
    $vertBearingY = __stackBase__ + 1e3 | 0;
    $vertAdvance = __stackBase__ + 1004 | 0;
    $1 = $glyph + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    $4 = $2 + 692 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 + 1324 | 0;
    $7 = $6 + 128 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 65535;
    if ($9) {
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $11 = $5 + 1152 | 0;
    $12 = $11;
    $13 = $5 + 1164 | 0;
    $14 = $13;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $18 = ($glyph_index | 0) == 0;
    if ($18) {
      $_0183 = 0;
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $20 = _cff_charset_cid_to_gindex($12, $glyph_index) | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      $_0 = 6;
      label = 66;
      break;
    } else {
      $_0183 = $20;
      label = 6;
      break;
    }
   case 5:
    $23 = $5 + 12 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24 >>> 0 > $glyph_index >>> 0;
    if ($25) {
      $_0183 = $glyph_index;
      label = 6;
      break;
    } else {
      $_0 = 6;
      label = 66;
      break;
    }
   case 6:
    $27 = $load_flags & 1024;
    $28 = ($27 | 0) == 0;
    $29 = $load_flags | 3;
    $load_flags_ = $28 ? $load_flags : $29;
    $30 = $glyph + 164 | 0;
    HEAP32[$30 >> 2] = 65536;
    $31 = $glyph + 168 | 0;
    HEAP32[$31 >> 2] = 65536;
    $32 = ($size | 0) != 0;
    if ($32) {
      label = 7;
      break;
    } else {
      label = 14;
      break;
    }
   case 7:
    $34 = $size + 16 | 0;
    $35 = HEAP32[$34 >> 2] | 0;
    HEAP32[$30 >> 2] = $35;
    $36 = $size + 20 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    HEAP32[$31 >> 2] = $37;
    $38 = $size | 0;
    $39 = HEAP32[$38 >> 2] | 0;
    $40 = $39 + 532 | 0;
    $41 = $40;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = $39 + 104 | 0;
    $44 = HEAP32[$43 >> 2] | 0;
    $45 = $size + 44 | 0;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = ($46 | 0) == -1;
    if ($47) {
      label = 14;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $49 = $42 + 140 | 0;
    $50 = $49;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = ($51 | 0) == 0;
    if ($52) {
      label = 14;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $54 = $load_flags_ & 8;
    $55 = ($54 | 0) == 0;
    if ($55) {
      label = 10;
      break;
    } else {
      label = 14;
      break;
    }
   case 10:
    $57 = $42 + 104 | 0;
    $58 = $57;
    $59 = HEAP32[$58 >> 2] | 0;
    $60 = $glyph + 76 | 0;
    $61 = FUNCTION_TABLE_iiiiiiii[$59 & 1023]($3, $46, $_0183, $load_flags_, $44, $60, $metrics) | 0;
    $62 = ($61 | 0) == 0;
    if ($62) {
      label = 11;
      break;
    } else {
      label = 14;
      break;
    }
   case 11:
    $64 = $glyph + 110 | 0;
    HEAP16[$64 >> 1] = 0;
    $65 = $glyph + 108 | 0;
    HEAP16[$65 >> 1] = 0;
    $66 = $metrics + 1 | 0;
    $67 = HEAP8[$66] | 0;
    $68 = $67 & 255;
    $69 = $68 << 6;
    $70 = $glyph + 24 | 0;
    HEAP32[$70 >> 2] = $69;
    $71 = $metrics | 0;
    $72 = HEAP8[$71] | 0;
    $73 = $72 & 255;
    $74 = $73 << 6;
    $75 = $glyph + 28 | 0;
    HEAP32[$75 >> 2] = $74;
    $76 = $metrics + 2 | 0;
    $77 = HEAP8[$76] | 0;
    $78 = $77 << 24 >> 24;
    $79 = $78 << 6;
    $80 = $glyph + 32 | 0;
    HEAP32[$80 >> 2] = $79;
    $81 = $metrics + 3 | 0;
    $82 = HEAP8[$81] | 0;
    $83 = $82 << 24 >> 24;
    $84 = $83 << 6;
    $85 = $glyph + 36 | 0;
    HEAP32[$85 >> 2] = $84;
    $86 = $metrics + 4 | 0;
    $87 = HEAP8[$86] | 0;
    $88 = $87 & 255;
    $89 = $88 << 6;
    $90 = $glyph + 40 | 0;
    HEAP32[$90 >> 2] = $89;
    $91 = $metrics + 5 | 0;
    $92 = HEAP8[$91] | 0;
    $93 = $92 << 24 >> 24;
    $94 = $93 << 6;
    $95 = $glyph + 44 | 0;
    HEAP32[$95 >> 2] = $94;
    $96 = $metrics + 6 | 0;
    $97 = HEAP8[$96] | 0;
    $98 = $97 << 24 >> 24;
    $99 = $98 << 6;
    $100 = $glyph + 48 | 0;
    HEAP32[$100 >> 2] = $99;
    $101 = $metrics + 7 | 0;
    $102 = HEAP8[$101] | 0;
    $103 = $102 & 255;
    $104 = $103 << 6;
    $105 = $glyph + 52 | 0;
    HEAP32[$105 >> 2] = $104;
    $106 = $glyph + 72 | 0;
    HEAP32[$106 >> 2] = 1651078259;
    $107 = $load_flags_ & 16;
    $108 = ($107 | 0) == 0;
    if ($108) {
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $110 = HEAP8[$91] | 0;
    $111 = $110 << 24 >> 24;
    $112 = $glyph + 100 | 0;
    HEAP32[$112 >> 2] = $111;
    $113 = HEAP8[$96] | 0;
    $114 = $113 << 24 >> 24;
    $115 = $glyph + 104 | 0;
    HEAP32[$115 >> 2] = $114;
    $_0 = 0;
    label = 66;
    break;
   case 13:
    $117 = HEAP8[$76] | 0;
    $118 = $117 << 24 >> 24;
    $119 = $glyph + 100 | 0;
    HEAP32[$119 >> 2] = $118;
    $120 = HEAP8[$81] | 0;
    $121 = $120 << 24 >> 24;
    $122 = $glyph + 104 | 0;
    HEAP32[$122 >> 2] = $121;
    $_0 = $61;
    label = 66;
    break;
   case 14:
    $123 = $load_flags_ & 16384;
    $124 = ($123 | 0) == 0;
    if ($124) {
      label = 15;
      break;
    } else {
      $_0 = 6;
      label = 66;
      break;
    }
   case 15:
    $126 = $5 + 1892 | 0;
    $127 = HEAP32[$126 >> 2] | 0;
    $128 = ($127 | 0) == 0;
    if ($128) {
      label = 20;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $130 = $5 + 2024 | 0;
    $131 = $130;
    $132 = _cff_fd_select_get($131, $_0183) | 0;
    $133 = $132 & 255;
    $134 = HEAP32[$126 >> 2] | 0;
    $135 = $133 >>> 0 < $134 >>> 0;
    if ($135) {
      $fd_index_0 = $132;
      label = 18;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $137 = $134 + 255 | 0;
    $138 = $137 & 255;
    $fd_index_0 = $138;
    label = 18;
    break;
   case 18:
    $140 = $6 + 64 | 0;
    $141 = HEAP32[$140 >> 2] | 0;
    $142 = $fd_index_0 & 255;
    $143 = $5 + 1896 | 0;
    $144 = $143;
    $145 = $144 + ($142 << 2) | 0;
    $146 = HEAP32[$145 >> 2] | 0;
    $147 = $146 + 64 | 0;
    $148 = HEAP32[$147 >> 2] | 0;
    $149 = $146 + 48 | 0;
    $150 = $font_matrix;
    $151 = $149;
    _memcpy($150 | 0, $151 | 0, 16);
    $152 = HEAP32[$145 >> 2] | 0;
    $font_offset_sroa_0_0__idx49 = $152 + 68 | 0;
    $font_offset_sroa_0_0_copyload50 = HEAP32[$font_offset_sroa_0_0__idx49 >> 2] | 0;
    $font_offset_sroa_1_4__idx56 = $152 + 72 | 0;
    $font_offset_sroa_1_4_copyload57 = HEAP32[$font_offset_sroa_1_4__idx56 >> 2] | 0;
    $153 = ($141 | 0) == ($148 | 0);
    if ($153) {
      $force_scaling_0 = 0;
      $font_offset_sroa_1_0 = $font_offset_sroa_1_4_copyload57;
      $font_offset_sroa_0_0 = $font_offset_sroa_0_0_copyload50;
      label = 21;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $155 = HEAP32[$30 >> 2] | 0;
    $156 = _FT_MulDiv($155, $141, $148) | 0;
    HEAP32[$30 >> 2] = $156;
    $157 = HEAP32[$31 >> 2] | 0;
    $158 = _FT_MulDiv($157, $141, $148) | 0;
    HEAP32[$31 >> 2] = $158;
    $force_scaling_0 = 1;
    $font_offset_sroa_1_0 = $font_offset_sroa_1_4_copyload57;
    $font_offset_sroa_0_0 = $font_offset_sroa_0_0_copyload50;
    label = 21;
    break;
   case 20:
    $160 = $6 + 48 | 0;
    $161 = $font_matrix;
    $162 = $160;
    _memcpy($161 | 0, $162 | 0, 16);
    $font_offset_sroa_0_0__idx47 = $5 + 1392 | 0;
    $163 = $font_offset_sroa_0_0__idx47;
    $font_offset_sroa_0_0_copyload48 = HEAP32[$163 >> 2] | 0;
    $164 = $5 + 1396 | 0;
    $font_offset_sroa_1_4_copyload55 = HEAP32[$164 >> 2] | 0;
    $force_scaling_0 = 0;
    $font_offset_sroa_1_0 = $font_offset_sroa_1_4_copyload55;
    $font_offset_sroa_0_0 = $font_offset_sroa_0_0_copyload48;
    label = 21;
    break;
   case 21:
    $166 = $glyph + 108 | 0;
    $167 = $glyph + 110 | 0;
    HEAP16[$167 >> 1] = 0;
    $168 = $166 | 0;
    HEAP16[$168 >> 1] = 0;
    $169 = $load_flags_ & 1;
    $170 = ($169 | 0) == 0;
    if ($170) {
      label = 22;
      break;
    } else {
      $175 = 0;
      label = 23;
      break;
    }
   case 22:
    $172 = $load_flags_ & 2;
    $173 = ($172 | 0) == 0;
    $175 = $173;
    label = 23;
    break;
   case 23:
    $176 = $175 & 1;
    $177 = $glyph + 72 | 0;
    HEAP32[$177 >> 2] = 1869968492;
    $178 = $load_flags_ >>> 16;
    $179 = $178 & 15;
    _cff_decoder_init($decoder, $3, $size, $glyph, $176, $179);
    $180 = $load_flags_ & 256;
    $181 = ($180 | 0) == 0;
    if ($181) {
      label = 25;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $183 = $decoder + 753 | 0;
    HEAP8[$183] = 1;
    label = 25;
    break;
   case 25:
    $185 = $load_flags_ & 1024;
    $186 = $decoder | 0;
    $187 = $decoder + 66 | 0;
    HEAP8[$187] = 0;
    $188 = _cff_get_glyph_data($3, $_0183, $charstring, $charstring_len) | 0;
    $189 = ($188 | 0) == 0;
    if ($189) {
      label = 26;
      break;
    } else {
      $_0 = $188;
      label = 66;
      break;
    }
   case 26:
    $191 = _cff_decoder_prepare($decoder, $size, $_0183) | 0;
    $192 = ($191 | 0) == 0;
    if ($192) {
      label = 27;
      break;
    } else {
      $_0 = $191;
      label = 66;
      break;
    }
   case 27:
    $194 = HEAP32[$charstring >> 2] | 0;
    $195 = HEAP32[$charstring_len >> 2] | 0;
    $196 = _cff_decoder_parse_charstrings($decoder, $194, $195) | 0;
    $197 = HEAP32[$charstring_len >> 2] | 0;
    _cff_free_glyph_data($3, $charstring, $197);
    $198 = ($196 | 0) == 0;
    if ($198) {
      label = 28;
      break;
    } else {
      $_0 = $196;
      label = 66;
      break;
    }
   case 28:
    $200 = $2 + 128 | 0;
    $201 = HEAP32[$200 >> 2] | 0;
    $202 = $201 + 52 | 0;
    $203 = HEAP32[$202 >> 2] | 0;
    $204 = ($203 | 0) == 0;
    if ($204) {
      label = 30;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    $206 = $glyph + 136 | 0;
    HEAP32[$206 >> 2] = 0;
    $207 = $glyph + 140 | 0;
    HEAP32[$207 >> 2] = 0;
    label = 32;
    break;
   case 30:
    $209 = $5 + 1176 | 0;
    $210 = $209 + 24 | 0;
    $211 = $210;
    $212 = HEAP32[$211 >> 2] | 0;
    $213 = ($212 | 0) == 0;
    if ($213) {
      label = 33;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    $215 = $209 + 28 | 0;
    $216 = $215;
    $217 = HEAP32[$216 >> 2] | 0;
    $218 = $212 + ($_0183 << 2) | 0;
    $219 = HEAP32[$218 >> 2] | 0;
    $_sum = $219 - 1 | 0;
    $220 = $217 + $_sum | 0;
    $221 = $glyph + 136 | 0;
    HEAP32[$221 >> 2] = $220;
    $222 = HEAP32[$charstring_len >> 2] | 0;
    $223 = $glyph + 140 | 0;
    HEAP32[$223 >> 2] = $222;
    label = 32;
    break;
   case 32:
    $225 = ($196 | 0) == 0;
    if ($225) {
      label = 33;
      break;
    } else {
      $_0 = $196;
      label = 66;
      break;
    }
   case 33:
    _cff_builder_done($186);
    $226 = $2 + 128 | 0;
    $227 = HEAP32[$226 >> 2] | 0;
    $228 = $227 + 52 | 0;
    $229 = HEAP32[$228 >> 2] | 0;
    $230 = ($229 | 0) == 0;
    if ($230) {
      label = 36;
      break;
    } else {
      label = 34;
      break;
    }
   case 34:
    $232 = $229 | 0;
    $233 = HEAP32[$232 >> 2] | 0;
    $234 = $233 + 8 | 0;
    $235 = HEAP32[$234 >> 2] | 0;
    $236 = ($235 | 0) == 0;
    if ($236) {
      label = 36;
      break;
    } else {
      label = 35;
      break;
    }
   case 35:
    $237 = $decoder + 32 | 0;
    $238 = HEAP32[$237 >> 2] | 0;
    $239 = $metrics1 | 0;
    HEAP32[$239 >> 2] = $238;
    $240 = $metrics1 + 4 | 0;
    HEAP32[$240 >> 2] = 0;
    $241 = $decoder + 40 | 0;
    $242 = HEAP32[$241 >> 2] | 0;
    $243 = $metrics1 + 8 | 0;
    HEAP32[$243 >> 2] = $242;
    $244 = $decoder + 44 | 0;
    $245 = HEAP32[$244 >> 2] | 0;
    $246 = $metrics1 + 12 | 0;
    HEAP32[$246 >> 2] = $245;
    $247 = HEAP32[$226 >> 2] | 0;
    $248 = $247 + 52 | 0;
    $249 = HEAP32[$248 >> 2] | 0;
    $250 = $249 | 0;
    $251 = HEAP32[$250 >> 2] | 0;
    $252 = $251 + 8 | 0;
    $253 = HEAP32[$252 >> 2] | 0;
    $254 = $249 + 4 | 0;
    $255 = HEAP32[$254 >> 2] | 0;
    $256 = FUNCTION_TABLE_iiiii[$253 & 1023]($255, $_0183, 0, $metrics1) | 0;
    $257 = HEAP32[$239 >> 2] | 0;
    HEAP32[$237 >> 2] = $257;
    $258 = HEAP32[$243 >> 2] | 0;
    HEAP32[$241 >> 2] = $258;
    $259 = HEAP32[$246 >> 2] | 0;
    HEAP32[$244 >> 2] = $259;
    $260 = ($256 | 0) == 0;
    if ($260) {
      label = 36;
      break;
    } else {
      $_0 = $256;
      label = 66;
      break;
    }
   case 36:
    $261 = ($185 | 0) == 0;
    if ($261) {
      label = 38;
      break;
    } else {
      label = 37;
      break;
    }
   case 37:
    $263 = $glyph + 156 | 0;
    $264 = HEAP32[$263 >> 2] | 0;
    $265 = $decoder + 32 | 0;
    $266 = HEAP32[$265 >> 2] | 0;
    $267 = $glyph + 32 | 0;
    HEAP32[$267 >> 2] = $266;
    $268 = $decoder + 744 | 0;
    $269 = HEAP32[$268 >> 2] | 0;
    $270 = $glyph + 40 | 0;
    HEAP32[$270 >> 2] = $269;
    $271 = $264 + 12 | 0;
    $272 = $271;
    $273 = $font_matrix;
    _memcpy($272 | 0, $273 | 0, 16);
    $font_offset_sroa_0_0__idx = $264 + 28 | 0;
    HEAP32[$font_offset_sroa_0_0__idx >> 2] = $font_offset_sroa_0_0;
    $font_offset_sroa_1_4__idx53 = $264 + 32 | 0;
    HEAP32[$font_offset_sroa_1_4__idx53 >> 2] = $font_offset_sroa_1_0;
    $274 = $264 + 8 | 0;
    HEAP8[$274] = 1;
    $_0 = 0;
    label = 66;
    break;
   case 38:
    $276 = $glyph + 24 | 0;
    $277 = $decoder + 744 | 0;
    $278 = HEAP32[$277 >> 2] | 0;
    $279 = $glyph + 40 | 0;
    HEAP32[$279 >> 2] = $278;
    $280 = HEAP32[$277 >> 2] | 0;
    $281 = $glyph + 56 | 0;
    HEAP32[$281 >> 2] = $280;
    $282 = $glyph + 156 | 0;
    $283 = HEAP32[$282 >> 2] | 0;
    $284 = $283 + 8 | 0;
    HEAP8[$284] = 0;
    $285 = $2 + 296 | 0;
    $286 = $285;
    $287 = HEAP8[$286] | 0;
    $288 = $287 << 24 >> 24 == 0;
    if ($288) {
      label = 42;
      break;
    } else {
      label = 39;
      break;
    }
   case 39:
    $290 = $2 + 300 | 0;
    $291 = $290;
    $292 = $291 + 34 | 0;
    $293 = HEAP16[$292 >> 1] | 0;
    $294 = $293 << 16 >> 16 == 0;
    if ($294) {
      label = 42;
      break;
    } else {
      label = 40;
      break;
    }
   case 40:
    $296 = $290 + 36 | 0;
    $297 = $296;
    $298 = HEAP32[$297 >> 2] | 0;
    $299 = ($298 | 0) == 0;
    if ($299) {
      label = 42;
      break;
    } else {
      label = 41;
      break;
    }
   case 41:
    HEAP16[$vertBearingY >> 1] = 0;
    HEAP16[$vertAdvance >> 1] = 0;
    $301 = $2 + 532 | 0;
    $302 = $301;
    $303 = HEAP32[$302 >> 2] | 0;
    $304 = $303 + 156 | 0;
    $305 = $304;
    $306 = HEAP32[$305 >> 2] | 0;
    $307 = FUNCTION_TABLE_iiiiii[$306 & 1023]($3, 1, $_0183, $vertBearingY, $vertAdvance) | 0;
    $308 = HEAP16[$vertBearingY >> 1] | 0;
    $309 = $308 << 16 >> 16;
    $310 = $glyph + 48 | 0;
    HEAP32[$310 >> 2] = $309;
    $311 = HEAP16[$vertAdvance >> 1] | 0;
    $312 = $311 & 65535;
    $313 = $glyph + 52 | 0;
    HEAP32[$313 >> 2] = $312;
    $342 = 1;
    label = 45;
    break;
   case 42:
    $314 = $2 + 368 | 0;
    $315 = $314;
    $316 = HEAP16[$315 >> 1] | 0;
    $317 = $316 << 16 >> 16 == -1;
    if ($317) {
      label = 44;
      break;
    } else {
      label = 43;
      break;
    }
   case 43:
    $319 = $314;
    $320 = $319 + 70 | 0;
    $321 = HEAP16[$320 >> 1] | 0;
    $322 = $321 << 16 >> 16;
    $323 = $314 + 72 | 0;
    $324 = $323;
    $325 = HEAP16[$324 >> 1] | 0;
    $326 = $325 << 16 >> 16;
    $327 = $322 - $326 | 0;
    $328 = $glyph + 52 | 0;
    HEAP32[$328 >> 2] = $327;
    $342 = 0;
    label = 45;
    break;
   case 44:
    $330 = $2 + 216 | 0;
    $331 = $330;
    $332 = $330 + 4 | 0;
    $333 = $332;
    $334 = HEAP16[$333 >> 1] | 0;
    $335 = $334 << 16 >> 16;
    $336 = $331 + 6 | 0;
    $337 = HEAP16[$336 >> 1] | 0;
    $338 = $337 << 16 >> 16;
    $339 = $335 - $338 | 0;
    $340 = $glyph + 52 | 0;
    HEAP32[$340 >> 2] = $339;
    $342 = 0;
    label = 45;
    break;
   case 45:
    $343 = $glyph + 52 | 0;
    $344 = HEAP32[$343 >> 2] | 0;
    $345 = $glyph + 60 | 0;
    HEAP32[$345 >> 2] = $344;
    HEAP32[$177 >> 2] = 1869968492;
    $346 = $glyph + 124 | 0;
    HEAP32[$346 >> 2] = 0;
    if ($32) {
      label = 46;
      break;
    } else {
      label = 48;
      break;
    }
   case 46:
    $348 = $size + 14 | 0;
    $349 = HEAP16[$348 >> 1] | 0;
    $350 = ($349 & 65535) < 24;
    if ($350) {
      label = 47;
      break;
    } else {
      label = 48;
      break;
    }
   case 47:
    HEAP32[$346 >> 2] = 256;
    label = 48;
    break;
   case 48:
    $353 = HEAP32[$346 >> 2] | 0;
    $354 = $353 | 4;
    HEAP32[$346 >> 2] = $354;
    $355 = $font_matrix | 0;
    $356 = HEAP32[$355 >> 2] | 0;
    $357 = ($356 | 0) == 65536;
    if ($357) {
      label = 49;
      break;
    } else {
      label = 52;
      break;
    }
   case 49:
    $359 = $font_matrix + 12 | 0;
    $360 = HEAP32[$359 >> 2] | 0;
    $361 = ($360 | 0) == 65536;
    if ($361) {
      label = 50;
      break;
    } else {
      label = 52;
      break;
    }
   case 50:
    $363 = $font_matrix + 4 | 0;
    $364 = HEAP32[$363 >> 2] | 0;
    $365 = ($364 | 0) == 0;
    if ($365) {
      label = 51;
      break;
    } else {
      label = 52;
      break;
    }
   case 51:
    $367 = $font_matrix + 8 | 0;
    $368 = HEAP32[$367 >> 2] | 0;
    $369 = ($368 | 0) == 0;
    if ($369) {
      label = 53;
      break;
    } else {
      label = 52;
      break;
    }
   case 52:
    _FT_Outline_Transform($166, $font_matrix);
    label = 53;
    break;
   case 53:
    $372 = $font_offset_sroa_1_0 | $font_offset_sroa_0_0;
    $373 = ($372 | 0) == 0;
    if ($373) {
      label = 55;
      break;
    } else {
      label = 54;
      break;
    }
   case 54:
    _FT_Outline_Translate($166, $font_offset_sroa_0_0, $font_offset_sroa_1_0);
    label = 55;
    break;
   case 55:
    $376 = HEAP32[$279 >> 2] | 0;
    $377 = $advance | 0;
    HEAP32[$377 >> 2] = $376;
    $378 = $advance + 4 | 0;
    HEAP32[$378 >> 2] = 0;
    _FT_Vector_Transform($advance, $font_matrix);
    $379 = HEAP32[$377 >> 2] | 0;
    $380 = $379 + $font_offset_sroa_0_0 | 0;
    HEAP32[$279 >> 2] = $380;
    HEAP32[$377 >> 2] = 0;
    $381 = HEAP32[$343 >> 2] | 0;
    HEAP32[$378 >> 2] = $381;
    _FT_Vector_Transform($advance, $font_matrix);
    $382 = HEAP32[$378 >> 2] | 0;
    $383 = $382 + $font_offset_sroa_1_0 | 0;
    HEAP32[$343 >> 2] = $383;
    $_not = $170 ^ 1;
    $384 = ($force_scaling_0 | 0) == 0;
    $or_cond186 = $384 & $_not;
    if ($or_cond186) {
      label = 62;
      break;
    } else {
      label = 56;
      break;
    }
   case 56:
    $386 = $glyph + 112 | 0;
    $387 = HEAP32[$386 >> 2] | 0;
    $388 = HEAP32[$30 >> 2] | 0;
    $389 = HEAP32[$31 >> 2] | 0;
    if ($175) {
      label = 57;
      break;
    } else {
      label = 58;
      break;
    }
   case 57:
    $391 = $decoder + 68 | 0;
    $392 = HEAP32[$391 >> 2] | 0;
    $393 = ($392 | 0) == 0;
    if ($393) {
      label = 58;
      break;
    } else {
      label = 61;
      break;
    }
   case 58:
    $395 = HEAP16[$167 >> 1] | 0;
    $396 = $395 << 16 >> 16 > 0;
    if ($396) {
      label = 59;
      break;
    } else {
      label = 61;
      break;
    }
   case 59:
    $397 = $395 << 16 >> 16;
    $n_0192 = $397;
    $vec_0193 = $387;
    label = 60;
    break;
   case 60:
    $399 = $vec_0193 | 0;
    $400 = HEAP32[$399 >> 2] | 0;
    $401 = _FT_MulFix($400, $388) | 0;
    HEAP32[$399 >> 2] = $401;
    $402 = $vec_0193 + 4 | 0;
    $403 = HEAP32[$402 >> 2] | 0;
    $404 = _FT_MulFix($403, $389) | 0;
    HEAP32[$402 >> 2] = $404;
    $405 = $n_0192 - 1 | 0;
    $406 = $vec_0193 + 8 | 0;
    $407 = ($405 | 0) > 0;
    if ($407) {
      $n_0192 = $405;
      $vec_0193 = $406;
      label = 60;
      break;
    } else {
      label = 61;
      break;
    }
   case 61:
    $408 = HEAP32[$279 >> 2] | 0;
    $409 = _FT_MulFix($408, $388) | 0;
    HEAP32[$279 >> 2] = $409;
    $410 = HEAP32[$343 >> 2] | 0;
    $411 = _FT_MulFix($410, $389) | 0;
    HEAP32[$343 >> 2] = $411;
    label = 62;
    break;
   case 62:
    _FT_Outline_Get_CBox($166, $cbox);
    $413 = $cbox + 8 | 0;
    $414 = HEAP32[$413 >> 2] | 0;
    $415 = $cbox | 0;
    $416 = HEAP32[$415 >> 2] | 0;
    $417 = $414 - $416 | 0;
    $418 = $276 | 0;
    HEAP32[$418 >> 2] = $417;
    $419 = $cbox + 12 | 0;
    $420 = HEAP32[$419 >> 2] | 0;
    $421 = $cbox + 4 | 0;
    $422 = HEAP32[$421 >> 2] | 0;
    $423 = $420 - $422 | 0;
    $424 = $glyph + 28 | 0;
    HEAP32[$424 >> 2] = $423;
    $425 = HEAP32[$415 >> 2] | 0;
    $426 = $glyph + 32 | 0;
    HEAP32[$426 >> 2] = $425;
    $427 = HEAP32[$419 >> 2] | 0;
    $428 = $glyph + 36 | 0;
    HEAP32[$428 >> 2] = $427;
    if ($342) {
      label = 63;
      break;
    } else {
      label = 64;
      break;
    }
   case 63:
    $430 = HEAP32[$426 >> 2] | 0;
    $431 = HEAP32[$279 >> 2] | 0;
    $432 = ($431 | 0) / 2 & -1;
    $433 = $430 - $432 | 0;
    $434 = $glyph + 44 | 0;
    HEAP32[$434 >> 2] = $433;
    $_0 = 0;
    label = 66;
    break;
   case 64:
    $436 = $load_flags_ & 16;
    $437 = ($436 | 0) == 0;
    if ($437) {
      $_0 = 0;
      label = 66;
      break;
    } else {
      label = 65;
      break;
    }
   case 65:
    $439 = HEAP32[$343 >> 2] | 0;
    _ft_synthesize_vertical_metrics($276, $439);
    $_0 = 0;
    label = 66;
    break;
   case 66:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _cff_decoder_init($decoder, $face, $size, $slot, $hinting, $hint_mode) {
  $decoder = $decoder | 0;
  $face = $face | 0;
  $size = $size | 0;
  $slot = $slot | 0;
  $hinting = $hinting | 0;
  $hint_mode = $hint_mode | 0;
  var $2 = 0, $10 = 0;
  $2 = HEAP32[$face + 692 >> 2] | 0;
  _memset($decoder | 0, 0, 928);
  _cff_builder_init($decoder | 0, $face, $size, $slot, $hinting);
  HEAP32[$decoder + 76 >> 2] = $2;
  $10 = $decoder + 892 | 0;
  HEAP32[$10 >> 2] = HEAP32[$2 + 92 >> 2] | 0;
  HEAP32[$decoder + 908 >> 2] = HEAP32[$2 + 1308 >> 2] | 0;
  HEAP32[$decoder + 900 >> 2] = _cff_compute_bias(HEAP32[$2 + 1368 >> 2] | 0, HEAP32[$10 >> 2] | 0) | 0;
  HEAP32[$decoder + 920 >> 2] = $hint_mode;
  return;
}
function _cff_get_glyph_data($face, $glyph_index, $pointer, $length) {
  $face = $face | 0;
  $glyph_index = $glyph_index | 0;
  $pointer = $pointer | 0;
  $length = $length | 0;
  var $data = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $data = __stackBase__ | 0;
    $1 = $face + 128 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 52 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $8 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $4 + 4 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = FUNCTION_TABLE_iiii[$10 & 1023]($12, $glyph_index, $data) | 0;
    $14 = $data | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    HEAP32[$pointer >> 2] = $15;
    $16 = $data + 4 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    HEAP32[$length >> 2] = $17;
    $_0 = $13;
    label = 4;
    break;
   case 3:
    $19 = $face + 692 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $20 + 1176 | 0;
    $22 = $21;
    $23 = _cff_index_access_element($22, $glyph_index, $pointer, $length) | 0;
    $_0 = $23;
    label = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _cff_decoder_prepare($decoder, $size, $glyph_index) {
  $decoder = $decoder | 0;
  $size = $size | 0;
  $glyph_index = $glyph_index | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $or_cond = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $sub_0 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $decoder + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 692 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 1324 | 0;
    $6 = $5;
    $7 = $4 + 1892 | 0;
    $8 = $7;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      $sub_0 = $6;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $12 = $4 + 2024 | 0;
    $13 = $12;
    $14 = _cff_fd_select_get($13, $glyph_index) | 0;
    $15 = $14 & 255;
    $16 = HEAP32[$8 >> 2] | 0;
    $17 = $15 >>> 0 < $16 >>> 0;
    if ($17) {
      label = 3;
      break;
    } else {
      $error_0 = 3;
      label = 6;
      break;
    }
   case 3:
    $19 = $4 + 1896 | 0;
    $20 = $19;
    $21 = $20 + ($15 << 2) | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $decoder + 68 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = ($24 | 0) == 0;
    $26 = ($size | 0) == 0;
    $or_cond = $25 | $26;
    if ($or_cond) {
      $sub_0 = $22;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $28 = $size + 40 | 0;
    $29 = HEAP32[$28 >> 2] | 0;
    $30 = $29;
    $31 = $30 + 4 + ($15 << 2) | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $32;
    $34 = $decoder + 72 | 0;
    HEAP32[$34 >> 2] = $33;
    $sub_0 = $22;
    label = 5;
    break;
   case 5:
    $36 = $sub_0 + 540 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $decoder + 888 | 0;
    HEAP32[$38 >> 2] = $37;
    $39 = $sub_0 + 564 | 0;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $decoder + 904 | 0;
    HEAP32[$41 >> 2] = $40;
    $42 = $decoder + 76 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $43 + 1368 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = HEAP32[$38 >> 2] | 0;
    $47 = _cff_compute_bias($45, $46) | 0;
    $48 = $decoder + 896 | 0;
    HEAP32[$48 >> 2] = $47;
    $49 = $sub_0 + 524 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $decoder + 744 | 0;
    HEAP32[$51 >> 2] = $50;
    $52 = $sub_0 + 528 | 0;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $decoder + 748 | 0;
    HEAP32[$54 >> 2] = $53;
    $error_0 = 0;
    label = 6;
    break;
   case 6:
    return $error_0 | 0;
  }
  return 0;
}
function _cff_decoder_parse_charstrings($decoder, $charstring_base, $charstring_len) {
  $decoder = $decoder | 0;
  $charstring_base = $charstring_base | 0;
  $charstring_len = $charstring_len | 0;
  var $1 = 0, $2 = 0, $seed = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $_ = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $_784 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $y_0_ph = 0, $x_0_ph = 0, $limit_0_ph = 0, $ip_0_ph = 0, $zone_0_ph = 0, $69 = 0, $ip_0905 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $or_cond = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $89 = 0, $91 = 0, $93 = 0, $95 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $105 = 0, $107 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $117 = 0, $118 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $val_0 = 0, $shift_0 = 0, $ip_1 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $145 = 0, $146 = 0, $147 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $167 = 0, $169 = 0, $170 = 0, $171 = 0, $op_0_ph = 0, $ip_2_ph = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $228 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $236 = 0, $238 = 0, $240 = 0, $241 = 0, $_785 = 0, $242 = 0, $set_width_ok_0 = 0, $244 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $258 = 0, $num_args_0 = 0, $259 = 0, $260 = 0, $req_args_0 = 0, $num_args_1 = 0, $262 = 0, $263 = 0, $265 = 0, $266 = 0, $267 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $_786 = 0, $274 = 0, $275 = 0, $276 = 0, $sum782 = 0, $_sum781 = 0, $277 = 0, $279 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $285 = 0, $288 = 0, $289 = 0, $290 = 0, $291 = 0, $sum780 = 0, $_sum779 = 0, $292 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $309 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $318 = 0, $319 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $_sum776 = 0, $328 = 0, $329 = 0, $330 = 0, $req_args_0_not778 = 0, $_sum777 = 0, $331 = 0, $332 = 0, $333 = 0, $req_args_0_not775 = 0, $_sum774 = 0, $335 = 0, $336 = 0, $337 = 0, $req_args_0_not773 = 0, $_sum772 = 0, $339 = 0, $340 = 0, $341 = 0, $343 = 0, $344 = 0, $346 = 0, $347 = 0, $348 = 0, $350 = 0, $352 = 0, $sum771 = 0, $_sum770 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $x_1895 = 0, $y_1894 = 0, $args_0893 = 0, $358 = 0, $359 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $369 = 0, $370 = 0, $371 = 0, $373 = 0, $374 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $380 = 0, $381 = 0, $x_2888 = 0, $y_2887 = 0, $args_1886 = 0, $phase_0885 = 0, $382 = 0, $383 = 0, $384 = 0, $y_3 = 0, $385 = 0, $x_3 = 0, $386 = 0, $387 = 0, $389 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $396 = 0, $398 = 0, $399 = 0, $400 = 0, $401 = 0, $403 = 0, $404 = 0, $405 = 0, $sum769 = 0, $_sum768 = 0, $407 = 0, $408 = 0, $409 = 0, $410 = 0, $411 = 0, $x_4876 = 0, $y_4875 = 0, $args_2874 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $435 = 0, $437 = 0, $438 = 0, $439 = 0, $440 = 0, $nargs1_0 = 0, $441 = 0, $442 = 0, $sum766 = 0, $_sum765 = 0, $444 = 0, $445 = 0, $446 = 0, $448 = 0, $449 = 0, $_sum767 = 0, $450 = 0, $451 = 0, $nargs1_1 = 0, $args_3 = 0, $x_5 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $460 = 0, $x_6869 = 0, $y_5868 = 0, $args_4867 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $478 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $nargs2_0 = 0, $484 = 0, $485 = 0, $sum763 = 0, $_sum762 = 0, $487 = 0, $488 = 0, $489 = 0, $491 = 0, $492 = 0, $_sum764 = 0, $493 = 0, $494 = 0, $nargs2_1 = 0, $args_5 = 0, $y_6 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $x_7861 = 0, $y_7860 = 0, $args_6859 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $521 = 0, $522 = 0, $524 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $nargs4_0 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $535 = 0, $sum761 = 0, $536 = 0, $_sum760 = 0, $537 = 0, $538 = 0, $x_8852 = 0, $y_8851 = 0, $args_7850 = 0, $phase3_0849 = 0, $nargs4_1848 = 0, $540 = 0, $541 = 0, $542 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $556 = 0, $557 = 0, $558 = 0, $x_9 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $570 = 0, $571 = 0, $573 = 0, $574 = 0, $575 = 0, $y_9 = 0, $y_10 = 0, $x_10 = 0, $578 = 0, $579 = 0, $580 = 0, $582 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $590 = 0, $591 = 0, $592 = 0, $sum759 = 0, $_sum758 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $_sum926 = 0, $598 = 0, $599 = 0, $600 = 0, $601 = 0, $602 = 0, $smax = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $609 = 0, $610 = 0, $args_8840 = 0, $num_lines_0839 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $scevgep_sum = 0, $scevgep948 = 0, $_lcssa838 = 0, $_lcssa837 = 0, $args_8_lcssa = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $630 = 0, $631 = 0, $633 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $_neg796 = 0, $646 = 0, $647 = 0, $_sum757 = 0, $648 = 0, $649 = 0, $650 = 0, $651 = 0, $_sum925 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $args_9831 = 0, $num_curves_0830 = 0, $657 = 0, $658 = 0, $659 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $_lcssa829 = 0, $_lcssa828 = 0, $678 = 0, $679 = 0, $681 = 0, $682 = 0, $684 = 0, $685 = 0, $_sum749 = 0, $686 = 0, $687 = 0, $688 = 0, $_sum750 = 0, $689 = 0, $690 = 0, $691 = 0, $_sum751 = 0, $692 = 0, $693 = 0, $694 = 0, $_sum752 = 0, $695 = 0, $696 = 0, $697 = 0, $_sum753 = 0, $698 = 0, $699 = 0, $700 = 0, $_sum754 = 0, $701 = 0, $702 = 0, $703 = 0, $_sum755 = 0, $704 = 0, $705 = 0, $706 = 0, $_sum756 = 0, $707 = 0, $708 = 0, $709 = 0, $711 = 0, $712 = 0, $714 = 0, $715 = 0, $717 = 0, $718 = 0, $_sum743 = 0, $719 = 0, $720 = 0, $721 = 0, $_sum744 = 0, $722 = 0, $723 = 0, $724 = 0, $_sum745 = 0, $725 = 0, $726 = 0, $727 = 0, $_sum746 = 0, $728 = 0, $729 = 0, $730 = 0, $_sum747 = 0, $731 = 0, $732 = 0, $733 = 0, $_sum748 = 0, $734 = 0, $735 = 0, $736 = 0, $738 = 0, $739 = 0, $741 = 0, $742 = 0, $744 = 0, $_sum985 = 0, $745 = 0, $746 = 0, $_sum986 = 0, $747 = 0, $748 = 0, $749 = 0, $_sum987 = 0, $750 = 0, $751 = 0, $752 = 0, $_sum988 = 0, $753 = 0, $754 = 0, $755 = 0, $_sum989 = 0, $756 = 0, $757 = 0, $758 = 0, $_sum990 = 0, $759 = 0, $760 = 0, $761 = 0, $_sum991 = 0, $762 = 0, $763 = 0, $764 = 0, $_sum992 = 0, $765 = 0, $766 = 0, $767 = 0, $_sum993 = 0, $768 = 0, $769 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $dy_1 = 0, $775 = 0, $_sum994 = 0, $776 = 0, $777 = 0, $778 = 0, $_sum995 = 0, $779 = 0, $780 = 0, $781 = 0, $_sum996 = 0, $782 = 0, $783 = 0, $784 = 0, $_sum997 = 0, $785 = 0, $786 = 0, $787 = 0, $_sum998 = 0, $788 = 0, $789 = 0, $790 = 0, $_sum999 = 0, $791 = 0, $792 = 0, $793 = 0, $_sum1000 = 0, $794 = 0, $795 = 0, $796 = 0, $_sum1001 = 0, $797 = 0, $798 = 0, $799 = 0, $_sum1002 = 0, $800 = 0, $801 = 0, $802 = 0, $_sum1003 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $_dx_0 = 0, $807 = 0, $808 = 0, $y_14 = 0, $x_14 = 0, $810 = 0, $811 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $_sum974 = 0, $817 = 0, $818 = 0, $819 = 0, $_sum975 = 0, $820 = 0, $821 = 0, $822 = 0, $_sum976 = 0, $823 = 0, $824 = 0, $825 = 0, $_sum977 = 0, $826 = 0, $827 = 0, $828 = 0, $_sum978 = 0, $829 = 0, $830 = 0, $831 = 0, $_sum979 = 0, $832 = 0, $833 = 0, $834 = 0, $_sum980 = 0, $835 = 0, $836 = 0, $837 = 0, $_sum981 = 0, $838 = 0, $839 = 0, $840 = 0, $_sum982 = 0, $841 = 0, $842 = 0, $843 = 0, $_sum983 = 0, $844 = 0, $845 = 0, $846 = 0, $_sum984 = 0, $847 = 0, $848 = 0, $849 = 0, $851 = 0, $852 = 0, $_sum739 = 0, $853 = 0, $854 = 0, $_sum740 = 0, $855 = 0, $856 = 0, $_sum741 = 0, $857 = 0, $858 = 0, $859 = 0, $_sum742 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $867 = 0, $869 = 0, $870 = 0, $871 = 0, $_sum735 = 0, $872 = 0, $873 = 0, $_sum736 = 0, $874 = 0, $875 = 0, $_sum737 = 0, $876 = 0, $877 = 0, $878 = 0, $req_args_0_not = 0, $_sum738 = 0, $879 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $887 = 0, $888 = 0, $889 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $910 = 0, $911 = 0, $913 = 0, $914 = 0, $916 = 0, $917 = 0, $919 = 0, $_sum734 = 0, $921 = 0, $_sum733 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $_sum732 = 0, $928 = 0, $929 = 0, $930 = 0, $931 = 0, $933 = 0, $_sum731 = 0, $934 = 0, $935 = 0, $936 = 0, $938 = 0, $939 = 0, $_sum730 = 0, $940 = 0, $942 = 0, $943 = 0, $944 = 0, $_788 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $storemerge729 = 0, $_sum728 = 0, $950 = 0, $952 = 0, $_sum727 = 0, $953 = 0, $954 = 0, $955 = 0, $957 = 0, $958 = 0, $root_0 = 0, $959 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $storemerge = 0, $_sum726 = 0, $965 = 0, $967 = 0, $_sum724 = 0, $968 = 0, $969 = 0, $_sum725 = 0, $970 = 0, $972 = 0, $973 = 0, $974 = 0, $976 = 0, $977 = 0, $_789 = 0, $phitmp795 = 0, $idx_0 = 0, $_sum722 = 0, $979 = 0, $980 = 0, $_sum723 = 0, $981 = 0, $983 = 0, $984 = 0, $_sum713 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $_790 = 0, $sum = 0, $_sum714 = 0, $989 = 0, $990 = 0, $992 = 0, $993 = 0, $994 = 0, $_sum719 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $1000 = 0, $idx12_0807 = 0, $1002 = 0, $i_0801 = 0, $_sum720 = 0, $1003 = 0, $1004 = 0, $_sum721 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $idx12_1799 = 0, $1011 = 0, $i15_0798 = 0, $1012 = 0, $_sum717 = 0, $1013 = 0, $1014 = 0, $_sum718 = 0, $1015 = 0, $1016 = 0, $_sum716 = 0, $1017 = 0, $1018 = 0, $exitcond = 0, $1020 = 0, $_sum711 = 0, $1021 = 0, $_sum712 = 0, $1022 = 0, $_sum710 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1029 = 0, $1030 = 0, $1031 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $val19_0 = 0, $_sum709 = 0, $1041 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $_sum708 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $_sum706 = 0, $1068 = 0, $1069 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $_sum707 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $_sum705 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $_sum703 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $_sum704 = 0, $1105 = 0, $1106 = 0, $_sum702 = 0, $1108 = 0, $1110 = 0, $1111 = 0, $_sum701 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $phitmp699 = 0, $1117 = 0, $_sum700 = 0, $1118 = 0, $1120 = 0, $1121 = 0, $_sum697 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $phitmp = 0, $1127 = 0, $_sum698 = 0, $1128 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $_sum696 = 0, $1133 = 0, $_sum = 0, $1135 = 0, $1136 = 0, $_sum693 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $_sum694 = 0, $1141 = 0, $1142 = 0, $_sum695 = 0, $1144 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $1160 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $1180 = 0, $1182 = 0, $1183 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1226 = 0, $1227 = 0, $1229 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $args_12 = 0, $y_16 = 0, $x_16 = 0, $limit_1 = 0, $ip_3 = 0, $zone_1 = 0, $1248 = 0, $1249 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 12 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = __stackBase__ | 0;
    $2 = __stackBase__ + 4 | 0;
    $seed = __stackBase__ + 8 | 0;
    HEAP32[$1 >> 2] = $decoder;
    HEAP32[$2 >> 2] = $charstring_base;
    $3 = $decoder | 0;
    $4 = $decoder + 76 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 + 1368 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $decoder + 756 | 0;
    HEAP32[$8 >> 2] = 0;
    $9 = HEAP32[$1 >> 2] | 0;
    $10 = $9 + 752 | 0;
    HEAP8[$10] = 1;
    $11 = $seed;
    $12 = $1;
    $13 = $2;
    $14 = $13 ^ $12;
    $15 = $14 ^ $11;
    $16 = $15 >>> 10;
    $17 = $16 ^ $15;
    $18 = $15 >> 20;
    $19 = $17 ^ $18;
    $20 = $19 & 65535;
    $21 = ($20 | 0) == 0;
    $_ = $21 ? 29572 : $20;
    HEAP32[$seed >> 2] = $_;
    $22 = HEAP32[$1 >> 2] | 0;
    $23 = $22 + 80 | 0;
    $24 = $22 + 276 | 0;
    HEAP32[$24 >> 2] = $23;
    $25 = HEAP32[$1 >> 2] | 0;
    $26 = $25 + 280 | 0;
    $27 = $25 + 676 | 0;
    HEAP32[$27 >> 2] = $26;
    $28 = HEAP32[$1 >> 2] | 0;
    $29 = $28 + 280 | 0;
    $30 = $28 + 276 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = $decoder + 68 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = $decoder + 64 | 0;
    HEAP8[$34] = 0;
    $35 = HEAP32[$2 >> 2] | 0;
    $36 = $29 | 0;
    HEAP32[$36 >> 2] = $35;
    $37 = HEAP32[$2 >> 2] | 0;
    $38 = $37 + $charstring_len | 0;
    $39 = $28 + 284 | 0;
    HEAP32[$39 >> 2] = $38;
    $40 = HEAP32[$36 >> 2] | 0;
    $41 = $28 + 288 | 0;
    HEAP32[$41 >> 2] = $40;
    $42 = $decoder + 24 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $decoder + 28 | 0;
    $45 = HEAP32[$44 >> 2] | 0;
    $46 = ($33 | 0) != 0;
    if ($46) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $48 = $33 + 4 | 0;
    $49 = $48;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $33;
    $52 = HEAP32[$51 >> 2] | 0;
    FUNCTION_TABLE_vi[$50 & 1023]($52);
    label = 3;
    break;
   case 3:
    $53 = $31;
    $54 = ($7 | 0) == 2;
    $_784 = $54 ? 0 : 16;
    $55 = $33 + 12 | 0;
    $56 = $55;
    $57 = $33;
    $58 = $31;
    $59 = $33 + 12 | 0;
    $60 = $59;
    $61 = $33;
    $62 = $33 + 16 | 0;
    $63 = $62;
    $64 = $33;
    $65 = $decoder + 20 | 0;
    $66 = $33 + 20 | 0;
    $67 = $66;
    $68 = $33;
    $zone_0_ph = $29;
    $ip_0_ph = $40;
    $limit_0_ph = $38;
    $x_0_ph = $43;
    $y_0_ph = $45;
    label = 4;
    break;
   case 4:
    $69 = $ip_0_ph >>> 0 < $limit_0_ph >>> 0;
    if ($69) {
      $ip_0905 = $ip_0_ph;
      label = 5;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 5:
    $70 = $ip_0905 + 1 | 0;
    $71 = HEAP8[$ip_0905] | 0;
    $72 = $71 & 255;
    $73 = ($71 & 255) > 31;
    $74 = $71 << 24 >> 24 == 28;
    $or_cond = $73 | $74;
    if ($or_cond) {
      label = 6;
      break;
    } else {
      label = 21;
      break;
    }
   case 6:
    if ($74) {
      label = 7;
      break;
    } else {
      label = 9;
      break;
    }
   case 7:
    $77 = $ip_0905 + 2 | 0;
    $78 = $77 >>> 0 < $limit_0_ph >>> 0;
    if ($78) {
      label = 8;
      break;
    } else {
      $_0 = 3;
      label = 249;
      break;
    }
   case 8:
    $80 = HEAP8[$70] | 0;
    $81 = $80 & 255;
    $82 = $81 << 8;
    $83 = HEAP8[$77] | 0;
    $84 = $83 & 255;
    $85 = $82 | $84;
    $86 = $85 << 16 >> 16;
    $87 = $ip_0905 + 3 | 0;
    $ip_1 = $87;
    $shift_0 = 16;
    $val_0 = $86;
    label = 19;
    break;
   case 9:
    $89 = ($71 & 255) < 247;
    if ($89) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $91 = $72 - 139 | 0;
    $ip_1 = $70;
    $shift_0 = 16;
    $val_0 = $91;
    label = 19;
    break;
   case 11:
    $93 = ($71 & 255) < 251;
    if ($93) {
      label = 12;
      break;
    } else {
      label = 14;
      break;
    }
   case 12:
    $95 = $70 >>> 0 < $limit_0_ph >>> 0;
    if ($95) {
      label = 13;
      break;
    } else {
      $_0 = 3;
      label = 249;
      break;
    }
   case 13:
    $97 = $72 << 8;
    $98 = $97 - 63232 | 0;
    $99 = $ip_0905 + 2 | 0;
    $100 = HEAP8[$70] | 0;
    $101 = $100 & 255;
    $102 = $101 | $98;
    $103 = $102 + 108 | 0;
    $ip_1 = $99;
    $shift_0 = 16;
    $val_0 = $103;
    label = 19;
    break;
   case 14:
    $105 = $71 << 24 >> 24 == -1;
    if ($105) {
      label = 17;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $107 = $70 >>> 0 < $limit_0_ph >>> 0;
    if ($107) {
      label = 16;
      break;
    } else {
      $_0 = 3;
      label = 249;
      break;
    }
   case 16:
    $109 = 251 - $72 | 0;
    $110 = $109 << 8;
    $111 = $ip_0905 + 2 | 0;
    $112 = HEAP8[$70] | 0;
    $113 = $112 & 255;
    $114 = $110 - 108 | 0;
    $115 = $114 - $113 | 0;
    $ip_1 = $111;
    $shift_0 = 16;
    $val_0 = $115;
    label = 19;
    break;
   case 17:
    $117 = $ip_0905 + 4 | 0;
    $118 = $117 >>> 0 < $limit_0_ph >>> 0;
    if ($118) {
      label = 18;
      break;
    } else {
      $_0 = 3;
      label = 249;
      break;
    }
   case 18:
    $120 = HEAP8[$70] | 0;
    $121 = $120 & 255;
    $122 = $121 << 24;
    $123 = $ip_0905 + 2 | 0;
    $124 = HEAP8[$123] | 0;
    $125 = $124 & 255;
    $126 = $125 << 16;
    $127 = $126 | $122;
    $128 = $ip_0905 + 3 | 0;
    $129 = HEAP8[$128] | 0;
    $130 = $129 & 255;
    $131 = $130 << 8;
    $132 = $127 | $131;
    $133 = HEAP8[$117] | 0;
    $134 = $133 & 255;
    $135 = $132 | $134;
    $136 = $ip_0905 + 5 | 0;
    $ip_1 = $136;
    $shift_0 = $_784;
    $val_0 = $135;
    label = 19;
    break;
   case 19:
    $138 = HEAP32[$1 >> 2] | 0;
    $139 = $138 + 276 | 0;
    $140 = HEAP32[$139 >> 2] | 0;
    $141 = $140;
    $142 = $141 - $53 | 0;
    $143 = ($142 | 0) > 188;
    if ($143) {
      $_0 = 130;
      label = 249;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $145 = $val_0 << $shift_0;
    $146 = $140 + 4 | 0;
    HEAP32[$139 >> 2] = $146;
    HEAP32[$140 >> 2] = $145;
    $147 = $ip_1 >>> 0 < $limit_0_ph >>> 0;
    if ($147) {
      $ip_0905 = $ip_1;
      label = 5;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 21:
    $149 = HEAP32[$1 >> 2] | 0;
    $150 = $149 + 276 | 0;
    $151 = HEAP32[$150 >> 2] | 0;
    $152 = $149 + 80 | 0;
    $153 = $151;
    $154 = $152;
    $155 = $153 - $154 | 0;
    $156 = $155 >> 2;
    if (($72 | 0) == 3) {
      label = 22;
      break;
    } else if (($72 | 0) == 4) {
      label = 23;
      break;
    } else if (($72 | 0) == 5) {
      label = 24;
      break;
    } else if (($72 | 0) == 6) {
      label = 25;
      break;
    } else if (($72 | 0) == 7) {
      label = 26;
      break;
    } else if (($72 | 0) == 8) {
      label = 27;
      break;
    } else if (($72 | 0) == 9) {
      label = 28;
      break;
    } else if (($72 | 0) == 10) {
      label = 29;
      break;
    } else if (($72 | 0) == 11) {
      label = 30;
      break;
    } else if (($72 | 0) == 12) {
      label = 31;
      break;
    } else if (($72 | 0) == 13) {
      label = 66;
      break;
    } else if (($72 | 0) == 14) {
      label = 67;
      break;
    } else if (($72 | 0) == 16) {
      label = 68;
      break;
    } else if (($72 | 0) == 18) {
      label = 69;
      break;
    } else if (($72 | 0) == 19) {
      label = 70;
      break;
    } else if (($72 | 0) == 20) {
      label = 71;
      break;
    } else if (($72 | 0) == 21) {
      label = 72;
      break;
    } else if (($72 | 0) == 22) {
      label = 73;
      break;
    } else if (($72 | 0) == 23) {
      label = 74;
      break;
    } else if (($72 | 0) == 24) {
      label = 75;
      break;
    } else if (($72 | 0) == 25) {
      label = 76;
      break;
    } else if (($72 | 0) == 26) {
      label = 77;
      break;
    } else if (($72 | 0) == 27) {
      label = 78;
      break;
    } else if (($72 | 0) == 29) {
      label = 79;
      break;
    } else if (($72 | 0) == 30) {
      label = 80;
      break;
    } else if (($72 | 0) == 31) {
      label = 81;
      break;
    } else if (($72 | 0) == 1) {
      $ip_2_ph = $70;
      $op_0_ph = 19;
      label = 82;
      break;
    } else {
      $_0 = 3;
      label = 249;
      break;
    }
   case 22:
    $ip_2_ph = $70;
    $op_0_ph = 20;
    label = 82;
    break;
   case 23:
    $ip_2_ph = $70;
    $op_0_ph = 3;
    label = 82;
    break;
   case 24:
    $ip_2_ph = $70;
    $op_0_ph = 4;
    label = 82;
    break;
   case 25:
    $ip_2_ph = $70;
    $op_0_ph = 5;
    label = 82;
    break;
   case 26:
    $ip_2_ph = $70;
    $op_0_ph = 6;
    label = 82;
    break;
   case 27:
    $ip_2_ph = $70;
    $op_0_ph = 7;
    label = 82;
    break;
   case 28:
    $ip_2_ph = $70;
    $op_0_ph = 53;
    label = 82;
    break;
   case 29:
    $ip_2_ph = $70;
    $op_0_ph = 49;
    label = 82;
    break;
   case 30:
    $ip_2_ph = $70;
    $op_0_ph = 51;
    label = 82;
    break;
   case 31:
    $167 = $70 >>> 0 < $limit_0_ph >>> 0;
    if ($167) {
      label = 32;
      break;
    } else {
      $_0 = 3;
      label = 249;
      break;
    }
   case 32:
    $169 = $ip_0905 + 2 | 0;
    $170 = HEAP8[$70] | 0;
    $171 = $170 & 255;
    if (($171 | 0) == 1) {
      label = 33;
      break;
    } else if (($171 | 0) == 2) {
      label = 34;
      break;
    } else if (($171 | 0) == 3) {
      label = 35;
      break;
    } else if (($171 | 0) == 4) {
      label = 36;
      break;
    } else if (($171 | 0) == 5) {
      label = 37;
      break;
    } else if (($171 | 0) == 6) {
      label = 38;
      break;
    } else if (($171 | 0) == 7) {
      label = 39;
      break;
    } else if (($171 | 0) == 8) {
      label = 40;
      break;
    } else if (($171 | 0) == 9) {
      label = 41;
      break;
    } else if (($171 | 0) == 10) {
      label = 42;
      break;
    } else if (($171 | 0) == 11) {
      label = 43;
      break;
    } else if (($171 | 0) == 12) {
      label = 44;
      break;
    } else if (($171 | 0) == 13) {
      label = 45;
      break;
    } else if (($171 | 0) == 14) {
      label = 46;
      break;
    } else if (($171 | 0) == 15) {
      label = 47;
      break;
    } else if (($171 | 0) == 16) {
      label = 48;
      break;
    } else if (($171 | 0) == 17) {
      label = 49;
      break;
    } else if (($171 | 0) == 18) {
      label = 50;
      break;
    } else if (($171 | 0) == 20) {
      label = 51;
      break;
    } else if (($171 | 0) == 21) {
      label = 52;
      break;
    } else if (($171 | 0) == 22) {
      label = 53;
      break;
    } else if (($171 | 0) == 23) {
      label = 54;
      break;
    } else if (($171 | 0) == 24) {
      label = 55;
      break;
    } else if (($171 | 0) == 26) {
      label = 56;
      break;
    } else if (($171 | 0) == 27) {
      label = 57;
      break;
    } else if (($171 | 0) == 28) {
      label = 58;
      break;
    } else if (($171 | 0) == 29) {
      label = 59;
      break;
    } else if (($171 | 0) == 30) {
      label = 60;
      break;
    } else if (($171 | 0) == 33) {
      label = 61;
      break;
    } else if (($171 | 0) == 34) {
      label = 62;
      break;
    } else if (($171 | 0) == 35) {
      label = 63;
      break;
    } else if (($171 | 0) == 36) {
      label = 64;
      break;
    } else if (($171 | 0) == 37) {
      label = 65;
      break;
    } else if (($171 | 0) == 0) {
      $ip_2_ph = $169;
      $op_0_ph = 25;
      label = 82;
      break;
    } else {
      $_0 = 3;
      label = 249;
      break;
    }
   case 33:
    $ip_2_ph = $169;
    $op_0_ph = 20;
    label = 82;
    break;
   case 34:
    $ip_2_ph = $169;
    $op_0_ph = 19;
    label = 82;
    break;
   case 35:
    $ip_2_ph = $169;
    $op_0_ph = 44;
    label = 82;
    break;
   case 36:
    $ip_2_ph = $169;
    $op_0_ph = 45;
    label = 82;
    break;
   case 37:
    $ip_2_ph = $169;
    $op_0_ph = 46;
    label = 82;
    break;
   case 38:
    $ip_2_ph = $169;
    $op_0_ph = 56;
    label = 82;
    break;
   case 39:
    $ip_2_ph = $169;
    $op_0_ph = 57;
    label = 82;
    break;
   case 40:
    $ip_2_ph = $169;
    $op_0_ph = 42;
    label = 82;
    break;
   case 41:
    $ip_2_ph = $169;
    $op_0_ph = 26;
    label = 82;
    break;
   case 42:
    $ip_2_ph = $169;
    $op_0_ph = 27;
    label = 82;
    break;
   case 43:
    $ip_2_ph = $169;
    $op_0_ph = 28;
    label = 82;
    break;
   case 44:
    $ip_2_ph = $169;
    $op_0_ph = 29;
    label = 82;
    break;
   case 45:
    $ip_2_ph = $169;
    $op_0_ph = 43;
    label = 82;
    break;
   case 46:
    $ip_2_ph = $169;
    $op_0_ph = 30;
    label = 82;
    break;
   case 47:
    $ip_2_ph = $169;
    $op_0_ph = 47;
    label = 82;
    break;
   case 48:
    $ip_2_ph = $169;
    $op_0_ph = 54;
    label = 82;
    break;
   case 49:
    $ip_2_ph = $169;
    $op_0_ph = 55;
    label = 82;
    break;
   case 50:
    $ip_2_ph = $169;
    $op_0_ph = 35;
    label = 82;
    break;
   case 51:
    $ip_2_ph = $169;
    $op_0_ph = 40;
    label = 82;
    break;
   case 52:
    $ip_2_ph = $169;
    $op_0_ph = 41;
    label = 82;
    break;
   case 53:
    $ip_2_ph = $169;
    $op_0_ph = 48;
    label = 82;
    break;
   case 54:
    $ip_2_ph = $169;
    $op_0_ph = 31;
    label = 82;
    break;
   case 55:
    $ip_2_ph = $169;
    $op_0_ph = 32;
    label = 82;
    break;
   case 56:
    $ip_2_ph = $169;
    $op_0_ph = 33;
    label = 82;
    break;
   case 57:
    $ip_2_ph = $169;
    $op_0_ph = 39;
    label = 82;
    break;
   case 58:
    $ip_2_ph = $169;
    $op_0_ph = 36;
    label = 82;
    break;
   case 59:
    $ip_2_ph = $169;
    $op_0_ph = 37;
    label = 82;
    break;
   case 60:
    $ip_2_ph = $169;
    $op_0_ph = 38;
    label = 82;
    break;
   case 61:
    $ip_2_ph = $169;
    $op_0_ph = 58;
    label = 82;
    break;
   case 62:
    $ip_2_ph = $169;
    $op_0_ph = 15;
    label = 82;
    break;
   case 63:
    $ip_2_ph = $169;
    $op_0_ph = 14;
    label = 82;
    break;
   case 64:
    $ip_2_ph = $169;
    $op_0_ph = 16;
    label = 82;
    break;
   case 65:
    $ip_2_ph = $169;
    $op_0_ph = 17;
    label = 82;
    break;
   case 66:
    $ip_2_ph = $70;
    $op_0_ph = 52;
    label = 82;
    break;
   case 67:
    $ip_2_ph = $70;
    $op_0_ph = 18;
    label = 82;
    break;
   case 68:
    $ip_2_ph = $70;
    $op_0_ph = 34;
    label = 82;
    break;
   case 69:
    $ip_2_ph = $70;
    $op_0_ph = 21;
    label = 82;
    break;
   case 70:
    $ip_2_ph = $70;
    $op_0_ph = 23;
    label = 82;
    break;
   case 71:
    $ip_2_ph = $70;
    $op_0_ph = 24;
    label = 82;
    break;
   case 72:
    $ip_2_ph = $70;
    $op_0_ph = 1;
    label = 82;
    break;
   case 73:
    $ip_2_ph = $70;
    $op_0_ph = 2;
    label = 82;
    break;
   case 74:
    $ip_2_ph = $70;
    $op_0_ph = 22;
    label = 82;
    break;
   case 75:
    $ip_2_ph = $70;
    $op_0_ph = 10;
    label = 82;
    break;
   case 76:
    $ip_2_ph = $70;
    $op_0_ph = 11;
    label = 82;
    break;
   case 77:
    $ip_2_ph = $70;
    $op_0_ph = 13;
    label = 82;
    break;
   case 78:
    $ip_2_ph = $70;
    $op_0_ph = 8;
    label = 82;
    break;
   case 79:
    $ip_2_ph = $70;
    $op_0_ph = 50;
    label = 82;
    break;
   case 80:
    $ip_2_ph = $70;
    $op_0_ph = 12;
    label = 82;
    break;
   case 81:
    $ip_2_ph = $70;
    $op_0_ph = 9;
    label = 82;
    break;
   case 82:
    $222 = $op_0_ph + 5317776 | 0;
    $223 = HEAP8[$222] | 0;
    $224 = $223 & 255;
    $225 = $224 & 128;
    $226 = ($225 | 0) == 0;
    if ($226) {
      $num_args_1 = $156;
      $req_args_0 = $224;
      label = 93;
      break;
    } else {
      label = 83;
      break;
    }
   case 83:
    $228 = ($155 | 0) > 0;
    if ($228) {
      label = 84;
      break;
    } else {
      $num_args_0 = $156;
      label = 92;
      break;
    }
   case 84:
    $230 = HEAP32[$1 >> 2] | 0;
    $231 = $230 + 752 | 0;
    $232 = HEAP8[$231] | 0;
    $233 = $232 << 24 >> 24 == 0;
    if ($233) {
      $num_args_0 = $156;
      label = 92;
      break;
    } else {
      label = 85;
      break;
    }
   case 85:
    if (($op_0_ph | 0) == 2 | ($op_0_ph | 0) == 3) {
      label = 86;
      break;
    } else if (($op_0_ph | 0) == 19 | ($op_0_ph | 0) == 20 | ($op_0_ph | 0) == 21 | ($op_0_ph | 0) == 22 | ($op_0_ph | 0) == 1 | ($op_0_ph | 0) == 23 | ($op_0_ph | 0) == 24) {
      label = 87;
      break;
    } else if (($op_0_ph | 0) == 18) {
      label = 88;
      break;
    } else {
      $num_args_0 = $156;
      label = 92;
      break;
    }
   case 86:
    $236 = $156 & 2;
    $set_width_ok_0 = $236;
    label = 89;
    break;
   case 87:
    $238 = $156 & 1;
    $set_width_ok_0 = $238;
    label = 89;
    break;
   case 88:
    $240 = ($156 | 0) == 5;
    $241 = ($156 | 0) == 1;
    $_785 = $240 | $241;
    $242 = $_785 & 1;
    $set_width_ok_0 = $242;
    label = 89;
    break;
   case 89:
    $244 = ($set_width_ok_0 | 0) == 0;
    if ($244) {
      $num_args_0 = $156;
      label = 92;
      break;
    } else {
      label = 90;
      break;
    }
   case 90:
    $246 = HEAP32[$1 >> 2] | 0;
    $247 = $246 + 748 | 0;
    $248 = HEAP32[$247 >> 2] | 0;
    $249 = HEAP32[$31 >> 2] | 0;
    $250 = $249 >> 16;
    $251 = $250 + $248 | 0;
    $252 = $246 + 744 | 0;
    HEAP32[$252 >> 2] = $251;
    $253 = HEAP32[$1 >> 2] | 0;
    $254 = $253 + 753 | 0;
    $255 = HEAP8[$254] | 0;
    $256 = $255 << 24 >> 24 == 0;
    if ($256) {
      label = 91;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 91:
    $258 = $156 - 1 | 0;
    $num_args_0 = $258;
    label = 92;
    break;
   case 92:
    $259 = HEAP32[$1 >> 2] | 0;
    $260 = $259 + 752 | 0;
    HEAP8[$260] = 0;
    $num_args_1 = $num_args_0;
    $req_args_0 = 0;
    label = 93;
    break;
   case 93:
    $262 = $req_args_0 & 15;
    $263 = ($num_args_1 | 0) < ($262 | 0);
    if ($263) {
      $_0 = 129;
      label = 249;
      break;
    } else {
      label = 94;
      break;
    }
   case 94:
    $265 = -$262 | 0;
    $266 = $151 + ($265 << 2) | 0;
    $267 = $num_args_1 - $262 | 0;
    if (($op_0_ph | 0) == 19 | ($op_0_ph | 0) == 20 | ($op_0_ph | 0) == 21 | ($op_0_ph | 0) == 22) {
      label = 95;
      break;
    } else if (($op_0_ph | 0) == 23 | ($op_0_ph | 0) == 24) {
      label = 98;
      break;
    } else if (($op_0_ph | 0) == 1) {
      label = 108;
      break;
    } else if (($op_0_ph | 0) == 3) {
      label = 109;
      break;
    } else if (($op_0_ph | 0) == 2) {
      label = 110;
      break;
    } else if (($op_0_ph | 0) == 4) {
      label = 111;
      break;
    } else if (($op_0_ph | 0) == 5 | ($op_0_ph | 0) == 6) {
      label = 116;
      break;
    } else if (($op_0_ph | 0) == 7) {
      label = 122;
      break;
    } else if (($op_0_ph | 0) == 13) {
      label = 127;
      break;
    } else if (($op_0_ph | 0) == 8) {
      label = 134;
      break;
    } else if (($op_0_ph | 0) == 12 | ($op_0_ph | 0) == 9) {
      label = 141;
      break;
    } else if (($op_0_ph | 0) == 11) {
      label = 154;
      break;
    } else if (($op_0_ph | 0) == 10) {
      label = 162;
      break;
    } else if (($op_0_ph | 0) == 16) {
      label = 168;
      break;
    } else if (($op_0_ph | 0) == 15) {
      label = 171;
      break;
    } else if (($op_0_ph | 0) == 17) {
      label = 174;
      break;
    } else if (($op_0_ph | 0) == 14) {
      label = 177;
      break;
    } else if (($op_0_ph | 0) == 56) {
      label = 180;
      break;
    } else if (($op_0_ph | 0) == 18) {
      label = 181;
      break;
    } else if (($op_0_ph | 0) == 26) {
      label = 187;
      break;
    } else if (($op_0_ph | 0) == 27) {
      label = 190;
      break;
    } else if (($op_0_ph | 0) == 28) {
      label = 191;
      break;
    } else if (($op_0_ph | 0) == 29) {
      label = 192;
      break;
    } else if (($op_0_ph | 0) == 30) {
      label = 193;
      break;
    } else if (($op_0_ph | 0) == 31) {
      label = 194;
      break;
    } else if (($op_0_ph | 0) == 32) {
      label = 195;
      break;
    } else if (($op_0_ph | 0) == 33) {
      label = 196;
      break;
    } else if (($op_0_ph | 0) == 36) {
      label = 199;
      break;
    } else if (($op_0_ph | 0) == 37) {
      label = 200;
      break;
    } else if (($op_0_ph | 0) == 38) {
      label = 203;
      break;
    } else if (($op_0_ph | 0) == 39) {
      label = 214;
      break;
    } else if (($op_0_ph | 0) == 40) {
      label = 215;
      break;
    } else if (($op_0_ph | 0) == 41) {
      label = 217;
      break;
    } else if (($op_0_ph | 0) == 53) {
      label = 220;
      break;
    } else if (($op_0_ph | 0) == 52) {
      label = 221;
      break;
    } else if (($op_0_ph | 0) == 57) {
      label = 222;
      break;
    } else if (($op_0_ph | 0) == 58) {
      label = 223;
      break;
    } else if (($op_0_ph | 0) == 54) {
      label = 224;
      break;
    } else if (($op_0_ph | 0) == 55) {
      label = 225;
      break;
    } else if (($op_0_ph | 0) == 44) {
      label = 226;
      break;
    } else if (($op_0_ph | 0) == 45) {
      label = 229;
      break;
    } else if (($op_0_ph | 0) == 47) {
      label = 232;
      break;
    } else if (($op_0_ph | 0) == 48) {
      label = 233;
      break;
    } else if (($op_0_ph | 0) == 49) {
      label = 236;
      break;
    } else if (($op_0_ph | 0) == 50) {
      label = 241;
      break;
    } else if (($op_0_ph | 0) == 51) {
      label = 246;
      break;
    } else if (($op_0_ph | 0) == 35 | ($op_0_ph | 0) == 25) {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $x_0_ph;
      $y_16 = $y_0_ph;
      $args_12 = $266;
      label = 248;
      break;
    } else {
      $_0 = 7;
      label = 249;
      break;
    }
   case 95:
    if ($46) {
      label = 96;
      break;
    } else {
      label = 97;
      break;
    }
   case 96:
    $270 = HEAP32[$56 >> 2] | 0;
    $271 = HEAP32[$57 >> 2] | 0;
    $272 = ($op_0_ph | 0) == 19;
    $273 = ($op_0_ph | 0) == 21;
    $_786 = $272 | $273;
    $274 = $_786 & 1;
    $275 = ($267 | 0) / 2 & -1;
    $276 = $267 & -2;
    $sum782 = $262 + $276 | 0;
    $_sum781 = -$sum782 | 0;
    $277 = $151 + ($_sum781 << 2) | 0;
    FUNCTION_TABLE_viiii[$270 & 1023]($271, $274, $275, $277);
    label = 97;
    break;
   case 97:
    $279 = ($267 | 0) / 2 & -1;
    $280 = HEAP32[$1 >> 2] | 0;
    $281 = $280 + 756 | 0;
    $282 = HEAP32[$281 >> 2] | 0;
    $283 = $282 + $279 | 0;
    HEAP32[$281 >> 2] = $283;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $31;
    label = 248;
    break;
   case 98:
    $285 = ($267 | 0) > 0;
    if ($285) {
      label = 99;
      break;
    } else {
      label = 102;
      break;
    }
   case 99:
    if ($46) {
      label = 100;
      break;
    } else {
      label = 101;
      break;
    }
   case 100:
    $288 = HEAP32[$60 >> 2] | 0;
    $289 = HEAP32[$61 >> 2] | 0;
    $290 = ($267 | 0) / 2 & -1;
    $291 = $267 & -2;
    $sum780 = $262 + $291 | 0;
    $_sum779 = -$sum780 | 0;
    $292 = $151 + ($_sum779 << 2) | 0;
    FUNCTION_TABLE_viiii[$288 & 1023]($289, 0, $290, $292);
    label = 101;
    break;
   case 101:
    $294 = ($267 | 0) / 2 & -1;
    $295 = HEAP32[$1 >> 2] | 0;
    $296 = $295 + 756 | 0;
    $297 = HEAP32[$296 >> 2] | 0;
    $298 = $297 + $294 | 0;
    HEAP32[$296 >> 2] = $298;
    label = 102;
    break;
   case 102:
    $300 = HEAP32[$1 >> 2] | 0;
    $301 = $300 + 756 | 0;
    $302 = HEAP32[$301 >> 2] | 0;
    $303 = $302 + 7 | 0;
    $304 = $303 >> 3;
    $305 = $ip_2_ph + $304 | 0;
    $306 = $305 >>> 0 < $limit_0_ph >>> 0;
    if ($306) {
      label = 103;
      break;
    } else {
      $_0 = 3;
      label = 249;
      break;
    }
   case 103:
    if ($46) {
      label = 104;
      break;
    } else {
      label = 107;
      break;
    }
   case 104:
    $309 = ($op_0_ph | 0) == 23;
    if ($309) {
      label = 105;
      break;
    } else {
      label = 106;
      break;
    }
   case 105:
    $311 = HEAP32[$63 >> 2] | 0;
    $312 = HEAP32[$64 >> 2] | 0;
    $313 = HEAP32[$65 >> 2] | 0;
    $314 = $313 + 2 | 0;
    $315 = HEAP16[$314 >> 1] | 0;
    $316 = $315 << 16 >> 16;
    FUNCTION_TABLE_viiii[$311 & 1023]($312, $316, $302, $ip_2_ph);
    label = 107;
    break;
   case 106:
    $318 = HEAP32[$67 >> 2] | 0;
    $319 = HEAP32[$68 >> 2] | 0;
    FUNCTION_TABLE_viii[$318 & 1023]($319, $302, $ip_2_ph);
    label = 107;
    break;
   case 107:
    $321 = HEAP32[$1 >> 2] | 0;
    $322 = $321 + 756 | 0;
    $323 = HEAP32[$322 >> 2] | 0;
    $324 = $323 + 7 | 0;
    $325 = $324 >> 3;
    $326 = $ip_2_ph + $325 | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $326;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $31;
    label = 248;
    break;
   case 108:
    _cff_builder_close_contour($3);
    HEAP8[$34] = 0;
    $_sum776 = -2 - $262 | 0;
    $328 = $151 + ($_sum776 << 2) | 0;
    $329 = HEAP32[$328 >> 2] | 0;
    $330 = $329 + $x_0_ph | 0;
    $req_args_0_not778 = $req_args_0 | -16;
    $_sum777 = $req_args_0_not778 ^ 15;
    $331 = $151 + ($_sum777 << 2) | 0;
    $332 = HEAP32[$331 >> 2] | 0;
    $333 = $332 + $y_0_ph | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $330;
    $y_16 = $333;
    $args_12 = $31;
    label = 248;
    break;
   case 109:
    _cff_builder_close_contour($3);
    HEAP8[$34] = 0;
    $req_args_0_not775 = $req_args_0 | -16;
    $_sum774 = $req_args_0_not775 ^ 15;
    $335 = $151 + ($_sum774 << 2) | 0;
    $336 = HEAP32[$335 >> 2] | 0;
    $337 = $336 + $y_0_ph | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $337;
    $args_12 = $31;
    label = 248;
    break;
   case 110:
    _cff_builder_close_contour($3);
    HEAP8[$34] = 0;
    $req_args_0_not773 = $req_args_0 | -16;
    $_sum772 = $req_args_0_not773 ^ 15;
    $339 = $151 + ($_sum772 << 2) | 0;
    $340 = HEAP32[$339 >> 2] | 0;
    $341 = $340 + $x_0_ph | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $341;
    $y_16 = $y_0_ph;
    $args_12 = $31;
    label = 248;
    break;
   case 111:
    $343 = _cff_builder_start_point($3, $x_0_ph, $y_0_ph) | 0;
    $344 = ($343 | 0) == 0;
    if ($344) {
      label = 112;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 112:
    $346 = ($267 | 0) / 2 & -1;
    $347 = _check_points($3, $346) | 0;
    $348 = ($347 | 0) == 0;
    if ($348) {
      label = 113;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 113:
    $350 = ($267 | 0) < 2;
    if ($350) {
      $_0 = 129;
      label = 249;
      break;
    } else {
      label = 114;
      break;
    }
   case 114:
    $352 = $267 & -2;
    $sum771 = $262 + $352 | 0;
    $_sum770 = -$sum771 | 0;
    $353 = $151 + ($_sum770 << 2) | 0;
    $354 = HEAP32[$1 >> 2] | 0;
    $355 = $354 + 276 | 0;
    $356 = HEAP32[$355 >> 2] | 0;
    $357 = $353 >>> 0 < $356 >>> 0;
    if ($357) {
      $args_0893 = $353;
      $y_1894 = $y_0_ph;
      $x_1895 = $x_0_ph;
      label = 115;
      break;
    } else {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $x_0_ph;
      $y_16 = $y_0_ph;
      $args_12 = $31;
      label = 248;
      break;
    }
   case 115:
    $358 = HEAP32[$args_0893 >> 2] | 0;
    $359 = $358 + $x_1895 | 0;
    $360 = $args_0893 + 4 | 0;
    $361 = HEAP32[$360 >> 2] | 0;
    $362 = $361 + $y_1894 | 0;
    _cff_builder_add_point($3, $359, $362, 1);
    $363 = $args_0893 + 8 | 0;
    $364 = HEAP32[$1 >> 2] | 0;
    $365 = $364 + 276 | 0;
    $366 = HEAP32[$365 >> 2] | 0;
    $367 = $363 >>> 0 < $366 >>> 0;
    if ($367) {
      $args_0893 = $363;
      $y_1894 = $362;
      $x_1895 = $359;
      label = 115;
      break;
    } else {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $359;
      $y_16 = $362;
      $args_12 = $31;
      label = 248;
      break;
    }
   case 116:
    $369 = ($op_0_ph | 0) == 5;
    $370 = $369 & 1;
    $371 = ($267 | 0) < 1;
    if ($371) {
      $_0 = 129;
      label = 249;
      break;
    } else {
      label = 117;
      break;
    }
   case 117:
    $373 = _cff_builder_start_point($3, $x_0_ph, $y_0_ph) | 0;
    $374 = ($373 | 0) == 0;
    if ($374) {
      label = 118;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 118:
    $376 = _check_points($3, $267) | 0;
    $377 = ($376 | 0) == 0;
    if ($377) {
      label = 119;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 119:
    $378 = HEAP32[$1 >> 2] | 0;
    $379 = $378 + 276 | 0;
    $380 = HEAP32[$379 >> 2] | 0;
    $381 = $31 >>> 0 < $380 >>> 0;
    if ($381) {
      $phase_0885 = $370;
      $args_1886 = $31;
      $y_2887 = $y_0_ph;
      $x_2888 = $x_0_ph;
      label = 120;
      break;
    } else {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $x_0_ph;
      $y_16 = $y_0_ph;
      $args_12 = $31;
      label = 248;
      break;
    }
   case 120:
    $382 = ($phase_0885 | 0) == 0;
    $383 = HEAP32[$args_1886 >> 2] | 0;
    $384 = $382 ? $383 : 0;
    $y_3 = $384 + $y_2887 | 0;
    $385 = $382 ? 0 : $383;
    $x_3 = $385 + $x_2888 | 0;
    $386 = _cff_builder_add_point1($3, $x_3, $y_3) | 0;
    $387 = ($386 | 0) == 0;
    if ($387) {
      label = 121;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 121:
    $389 = $args_1886 + 4 | 0;
    $390 = $phase_0885 ^ 1;
    $391 = HEAP32[$1 >> 2] | 0;
    $392 = $391 + 276 | 0;
    $393 = HEAP32[$392 >> 2] | 0;
    $394 = $389 >>> 0 < $393 >>> 0;
    if ($394) {
      $phase_0885 = $390;
      $args_1886 = $389;
      $y_2887 = $y_3;
      $x_2888 = $x_3;
      label = 120;
      break;
    } else {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $x_3;
      $y_16 = $y_3;
      $args_12 = $31;
      label = 248;
      break;
    }
   case 122:
    $396 = ($267 | 0) < 6;
    if ($396) {
      $_0 = 129;
      label = 249;
      break;
    } else {
      label = 123;
      break;
    }
   case 123:
    $398 = ($267 | 0) % 6;
    $399 = $267 - $398 | 0;
    $400 = _cff_builder_start_point($3, $x_0_ph, $y_0_ph) | 0;
    $401 = ($400 | 0) == 0;
    if ($401) {
      label = 124;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 124:
    $403 = ($399 | 0) / 2 & -1;
    $404 = _check_points($3, $403) | 0;
    $405 = ($404 | 0) == 0;
    if ($405) {
      label = 125;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 125:
    $sum769 = $262 + $399 | 0;
    $_sum768 = -$sum769 | 0;
    $407 = $151 + ($_sum768 << 2) | 0;
    $408 = HEAP32[$1 >> 2] | 0;
    $409 = $408 + 276 | 0;
    $410 = HEAP32[$409 >> 2] | 0;
    $411 = $407 >>> 0 < $410 >>> 0;
    if ($411) {
      $args_2874 = $407;
      $y_4875 = $y_0_ph;
      $x_4876 = $x_0_ph;
      label = 126;
      break;
    } else {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $x_0_ph;
      $y_16 = $y_0_ph;
      $args_12 = $31;
      label = 248;
      break;
    }
   case 126:
    $412 = HEAP32[$args_2874 >> 2] | 0;
    $413 = $412 + $x_4876 | 0;
    $414 = $args_2874 + 4 | 0;
    $415 = HEAP32[$414 >> 2] | 0;
    $416 = $415 + $y_4875 | 0;
    _cff_builder_add_point($3, $413, $416, 0);
    $417 = $args_2874 + 8 | 0;
    $418 = HEAP32[$417 >> 2] | 0;
    $419 = $418 + $413 | 0;
    $420 = $args_2874 + 12 | 0;
    $421 = HEAP32[$420 >> 2] | 0;
    $422 = $421 + $416 | 0;
    _cff_builder_add_point($3, $419, $422, 0);
    $423 = $args_2874 + 16 | 0;
    $424 = HEAP32[$423 >> 2] | 0;
    $425 = $424 + $419 | 0;
    $426 = $args_2874 + 20 | 0;
    $427 = HEAP32[$426 >> 2] | 0;
    $428 = $427 + $422 | 0;
    _cff_builder_add_point($3, $425, $428, 1);
    $429 = $args_2874 + 24 | 0;
    $430 = HEAP32[$1 >> 2] | 0;
    $431 = $430 + 276 | 0;
    $432 = HEAP32[$431 >> 2] | 0;
    $433 = $429 >>> 0 < $432 >>> 0;
    if ($433) {
      $args_2874 = $429;
      $y_4875 = $428;
      $x_4876 = $425;
      label = 126;
      break;
    } else {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $425;
      $y_16 = $428;
      $args_12 = $31;
      label = 248;
      break;
    }
   case 127:
    $435 = ($267 | 0) < 4;
    if ($435) {
      $_0 = 129;
      label = 249;
      break;
    } else {
      label = 128;
      break;
    }
   case 128:
    $437 = ($267 | 0) % 4;
    $438 = $267 - $437 | 0;
    $439 = ($437 | 0) > 0;
    $440 = $439 & 1;
    $nargs1_0 = $440 + $438 | 0;
    $441 = _cff_builder_start_point($3, $x_0_ph, $y_0_ph) | 0;
    $442 = ($441 | 0) == 0;
    if ($442) {
      label = 129;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 129:
    $sum766 = $nargs1_0 + $262 | 0;
    $_sum765 = -$sum766 | 0;
    $444 = $151 + ($_sum765 << 2) | 0;
    $445 = $nargs1_0 & 1;
    $446 = ($445 | 0) == 0;
    if ($446) {
      $x_5 = $x_0_ph;
      $args_3 = $444;
      $nargs1_1 = $nargs1_0;
      label = 131;
      break;
    } else {
      label = 130;
      break;
    }
   case 130:
    $448 = HEAP32[$444 >> 2] | 0;
    $449 = $448 + $x_0_ph | 0;
    $_sum767 = 1 - $sum766 | 0;
    $450 = $151 + ($_sum767 << 2) | 0;
    $451 = $nargs1_0 - 1 | 0;
    $x_5 = $449;
    $args_3 = $450;
    $nargs1_1 = $451;
    label = 131;
    break;
   case 131:
    $453 = ($nargs1_1 | 0) / 4 & -1;
    $454 = $453 * 3 & -1;
    $455 = _check_points($3, $454) | 0;
    $456 = ($455 | 0) == 0;
    if ($456) {
      label = 132;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 132:
    $457 = HEAP32[$1 >> 2] | 0;
    $458 = $457 + 276 | 0;
    $459 = HEAP32[$458 >> 2] | 0;
    $460 = $args_3 >>> 0 < $459 >>> 0;
    if ($460) {
      $args_4867 = $args_3;
      $y_5868 = $y_0_ph;
      $x_6869 = $x_5;
      label = 133;
      break;
    } else {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $x_5;
      $y_16 = $y_0_ph;
      $args_12 = $31;
      label = 248;
      break;
    }
   case 133:
    $461 = HEAP32[$args_4867 >> 2] | 0;
    $462 = $461 + $y_5868 | 0;
    _cff_builder_add_point($3, $x_6869, $462, 0);
    $463 = $args_4867 + 4 | 0;
    $464 = HEAP32[$463 >> 2] | 0;
    $465 = $464 + $x_6869 | 0;
    $466 = $args_4867 + 8 | 0;
    $467 = HEAP32[$466 >> 2] | 0;
    $468 = $467 + $462 | 0;
    _cff_builder_add_point($3, $465, $468, 0);
    $469 = $args_4867 + 12 | 0;
    $470 = HEAP32[$469 >> 2] | 0;
    $471 = $470 + $468 | 0;
    _cff_builder_add_point($3, $465, $471, 1);
    $472 = $args_4867 + 16 | 0;
    $473 = HEAP32[$1 >> 2] | 0;
    $474 = $473 + 276 | 0;
    $475 = HEAP32[$474 >> 2] | 0;
    $476 = $472 >>> 0 < $475 >>> 0;
    if ($476) {
      $args_4867 = $472;
      $y_5868 = $471;
      $x_6869 = $465;
      label = 133;
      break;
    } else {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $465;
      $y_16 = $471;
      $args_12 = $31;
      label = 248;
      break;
    }
   case 134:
    $478 = ($267 | 0) < 4;
    if ($478) {
      $_0 = 129;
      label = 249;
      break;
    } else {
      label = 135;
      break;
    }
   case 135:
    $480 = ($267 | 0) % 4;
    $481 = $267 - $480 | 0;
    $482 = ($480 | 0) > 0;
    $483 = $482 & 1;
    $nargs2_0 = $483 + $481 | 0;
    $484 = _cff_builder_start_point($3, $x_0_ph, $y_0_ph) | 0;
    $485 = ($484 | 0) == 0;
    if ($485) {
      label = 136;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 136:
    $sum763 = $nargs2_0 + $262 | 0;
    $_sum762 = -$sum763 | 0;
    $487 = $151 + ($_sum762 << 2) | 0;
    $488 = $nargs2_0 & 1;
    $489 = ($488 | 0) == 0;
    if ($489) {
      $y_6 = $y_0_ph;
      $args_5 = $487;
      $nargs2_1 = $nargs2_0;
      label = 138;
      break;
    } else {
      label = 137;
      break;
    }
   case 137:
    $491 = HEAP32[$487 >> 2] | 0;
    $492 = $491 + $y_0_ph | 0;
    $_sum764 = 1 - $sum763 | 0;
    $493 = $151 + ($_sum764 << 2) | 0;
    $494 = $nargs2_0 - 1 | 0;
    $y_6 = $492;
    $args_5 = $493;
    $nargs2_1 = $494;
    label = 138;
    break;
   case 138:
    $496 = ($nargs2_1 | 0) / 4 & -1;
    $497 = $496 * 3 & -1;
    $498 = _check_points($3, $497) | 0;
    $499 = ($498 | 0) == 0;
    if ($499) {
      label = 139;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 139:
    $500 = HEAP32[$1 >> 2] | 0;
    $501 = $500 + 276 | 0;
    $502 = HEAP32[$501 >> 2] | 0;
    $503 = $args_5 >>> 0 < $502 >>> 0;
    if ($503) {
      $args_6859 = $args_5;
      $y_7860 = $y_6;
      $x_7861 = $x_0_ph;
      label = 140;
      break;
    } else {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $x_0_ph;
      $y_16 = $y_6;
      $args_12 = $31;
      label = 248;
      break;
    }
   case 140:
    $504 = HEAP32[$args_6859 >> 2] | 0;
    $505 = $504 + $x_7861 | 0;
    _cff_builder_add_point($3, $505, $y_7860, 0);
    $506 = $args_6859 + 4 | 0;
    $507 = HEAP32[$506 >> 2] | 0;
    $508 = $507 + $505 | 0;
    $509 = $args_6859 + 8 | 0;
    $510 = HEAP32[$509 >> 2] | 0;
    $511 = $510 + $y_7860 | 0;
    _cff_builder_add_point($3, $508, $511, 0);
    $512 = $args_6859 + 12 | 0;
    $513 = HEAP32[$512 >> 2] | 0;
    $514 = $513 + $508 | 0;
    _cff_builder_add_point($3, $514, $511, 1);
    $515 = $args_6859 + 16 | 0;
    $516 = HEAP32[$1 >> 2] | 0;
    $517 = $516 + 276 | 0;
    $518 = HEAP32[$517 >> 2] | 0;
    $519 = $515 >>> 0 < $518 >>> 0;
    if ($519) {
      $args_6859 = $515;
      $y_7860 = $511;
      $x_7861 = $514;
      label = 140;
      break;
    } else {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $514;
      $y_16 = $511;
      $args_12 = $31;
      label = 248;
      break;
    }
   case 141:
    $521 = _cff_builder_start_point($3, $x_0_ph, $y_0_ph) | 0;
    $522 = ($521 | 0) == 0;
    if ($522) {
      label = 142;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 142:
    $524 = ($267 | 0) < 4;
    if ($524) {
      $_0 = 129;
      label = 249;
      break;
    } else {
      label = 143;
      break;
    }
   case 143:
    $526 = ($267 | 0) % 4;
    $527 = $267 - $526 | 0;
    $528 = ($526 | 0) > 0;
    $529 = $528 & 1;
    $nargs4_0 = $529 + $527 | 0;
    $530 = ($nargs4_0 | 0) / 4 & -1;
    $531 = $530 * 3 & -1;
    $532 = _check_points($3, $531) | 0;
    $533 = ($532 | 0) == 0;
    if ($533) {
      label = 144;
      break;
    } else {
      $_0 = 129;
      label = 249;
      break;
    }
   case 144:
    $535 = ($nargs4_0 | 0) > 3;
    if ($535) {
      label = 145;
      break;
    } else {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $x_0_ph;
      $y_16 = $y_0_ph;
      $args_12 = $31;
      label = 248;
      break;
    }
   case 145:
    $sum761 = $262 + $nargs4_0 | 0;
    $536 = ($op_0_ph | 0) == 9;
    $_sum760 = -$sum761 | 0;
    $537 = $536 & 1;
    $538 = $151 + ($_sum760 << 2) | 0;
    $nargs4_1848 = $nargs4_0;
    $phase3_0849 = $537;
    $args_7850 = $538;
    $y_8851 = $y_0_ph;
    $x_8852 = $x_0_ph;
    label = 146;
    break;
   case 146:
    $540 = $nargs4_1848 - 4 | 0;
    $541 = ($phase3_0849 | 0) == 0;
    $542 = HEAP32[$args_7850 >> 2] | 0;
    if ($541) {
      label = 150;
      break;
    } else {
      label = 147;
      break;
    }
   case 147:
    $544 = $542 + $x_8852 | 0;
    _cff_builder_add_point($3, $544, $y_8851, 0);
    $545 = $args_7850 + 4 | 0;
    $546 = HEAP32[$545 >> 2] | 0;
    $547 = $546 + $544 | 0;
    $548 = $args_7850 + 8 | 0;
    $549 = HEAP32[$548 >> 2] | 0;
    $550 = $549 + $y_8851 | 0;
    _cff_builder_add_point($3, $547, $550, 0);
    $551 = $args_7850 + 12 | 0;
    $552 = HEAP32[$551 >> 2] | 0;
    $553 = $552 + $550 | 0;
    $554 = ($540 | 0) == 1;
    if ($554) {
      label = 148;
      break;
    } else {
      $x_9 = $547;
      label = 149;
      break;
    }
   case 148:
    $556 = $args_7850 + 16 | 0;
    $557 = HEAP32[$556 >> 2] | 0;
    $558 = $557 + $547 | 0;
    $x_9 = $558;
    label = 149;
    break;
   case 149:
    _cff_builder_add_point($3, $x_9, $553, 1);
    $x_10 = $x_9;
    $y_10 = $553;
    label = 153;
    break;
   case 150:
    $561 = $542 + $y_8851 | 0;
    _cff_builder_add_point($3, $x_8852, $561, 0);
    $562 = $args_7850 + 4 | 0;
    $563 = HEAP32[$562 >> 2] | 0;
    $564 = $563 + $x_8852 | 0;
    $565 = $args_7850 + 8 | 0;
    $566 = HEAP32[$565 >> 2] | 0;
    $567 = $566 + $561 | 0;
    _cff_builder_add_point($3, $564, $567, 0);
    $568 = $args_7850 + 12 | 0;
    $569 = HEAP32[$568 >> 2] | 0;
    $570 = $569 + $564 | 0;
    $571 = ($540 | 0) == 1;
    if ($571) {
      label = 151;
      break;
    } else {
      $y_9 = $567;
      label = 152;
      break;
    }
   case 151:
    $573 = $args_7850 + 16 | 0;
    $574 = HEAP32[$573 >> 2] | 0;
    $575 = $574 + $567 | 0;
    $y_9 = $575;
    label = 152;
    break;
   case 152:
    _cff_builder_add_point($3, $570, $y_9, 1);
    $x_10 = $570;
    $y_10 = $y_9;
    label = 153;
    break;
   case 153:
    $578 = $args_7850 + 16 | 0;
    $579 = $phase3_0849 ^ 1;
    $580 = ($540 | 0) > 3;
    if ($580) {
      $nargs4_1848 = $540;
      $phase3_0849 = $579;
      $args_7850 = $578;
      $y_8851 = $y_10;
      $x_8852 = $x_10;
      label = 146;
      break;
    } else {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $x_10;
      $y_16 = $y_10;
      $args_12 = $31;
      label = 248;
      break;
    }
   case 154:
    $582 = ($267 | 0) < 8;
    if ($582) {
      $_0 = 129;
      label = 249;
      break;
    } else {
      label = 155;
      break;
    }
   case 155:
    $584 = $267 & -2;
    $585 = $584 - 6 | 0;
    $586 = ($585 | 0) / 2 & -1;
    $587 = _cff_builder_start_point($3, $x_0_ph, $y_0_ph) | 0;
    $588 = ($587 | 0) == 0;
    if ($588) {
      label = 156;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 156:
    $590 = $586 + 3 | 0;
    $591 = _check_points($3, $590) | 0;
    $592 = ($591 | 0) == 0;
    if ($592) {
      label = 157;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 157:
    $sum759 = $262 + $584 | 0;
    $_sum758 = -$sum759 | 0;
    $594 = $151 + ($_sum758 << 2) | 0;
    $595 = ($585 | 0) > 1;
    $596 = HEAP32[$594 >> 2] | 0;
    $597 = $596 + $x_0_ph | 0;
    $_sum926 = 1 - $sum759 | 0;
    $598 = $151 + ($_sum926 << 2) | 0;
    $599 = HEAP32[$598 >> 2] | 0;
    $600 = $599 + $y_0_ph | 0;
    if ($595) {
      label = 158;
      break;
    } else {
      $args_8_lcssa = $594;
      $_lcssa837 = $597;
      $_lcssa838 = $600;
      label = 161;
      break;
    }
   case 158:
    $601 = -$586 | 0;
    $602 = ($601 | 0) > -1;
    $smax = $602 ? $601 : 2147483647;
    $603 = $586 + $smax | 0;
    $604 = $603 << 1;
    $605 = $req_args_0 & 15;
    $606 = $584 + $605 | 0;
    $607 = $604 - $606 | 0;
    $num_lines_0839 = $586;
    $args_8840 = $594;
    $610 = $597;
    $609 = $600;
    label = 159;
    break;
   case 159:
    _cff_builder_add_point($3, $610, $609, 1);
    $611 = $args_8840 + 8 | 0;
    $612 = $num_lines_0839 - 1 | 0;
    $613 = ($612 | 0) > 0;
    $614 = HEAP32[$611 >> 2] | 0;
    $615 = $614 + $610 | 0;
    $616 = $args_8840 + 12 | 0;
    $617 = HEAP32[$616 >> 2] | 0;
    $618 = $617 + $609 | 0;
    if ($613) {
      $num_lines_0839 = $612;
      $args_8840 = $611;
      $610 = $615;
      $609 = $618;
      label = 159;
      break;
    } else {
      label = 160;
      break;
    }
   case 160:
    $scevgep_sum = $607 + 2 | 0;
    $scevgep948 = $151 + ($scevgep_sum << 2) | 0;
    $args_8_lcssa = $scevgep948;
    $_lcssa837 = $615;
    $_lcssa838 = $618;
    label = 161;
    break;
   case 161:
    _cff_builder_add_point($3, $_lcssa837, $_lcssa838, 0);
    $620 = $args_8_lcssa + 8 | 0;
    $621 = HEAP32[$620 >> 2] | 0;
    $622 = $621 + $_lcssa837 | 0;
    $623 = $args_8_lcssa + 12 | 0;
    $624 = HEAP32[$623 >> 2] | 0;
    $625 = $624 + $_lcssa838 | 0;
    _cff_builder_add_point($3, $622, $625, 0);
    $626 = $args_8_lcssa + 16 | 0;
    $627 = HEAP32[$626 >> 2] | 0;
    $628 = $627 + $622 | 0;
    $629 = $args_8_lcssa + 20 | 0;
    $630 = HEAP32[$629 >> 2] | 0;
    $631 = $630 + $625 | 0;
    _cff_builder_add_point($3, $628, $631, 1);
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $628;
    $y_16 = $631;
    $args_12 = $31;
    label = 248;
    break;
   case 162:
    $633 = ($267 | 0) < 8;
    if ($633) {
      $_0 = 129;
      label = 249;
      break;
    } else {
      label = 163;
      break;
    }
   case 163:
    $635 = $267 - 2 | 0;
    $636 = ($635 | 0) % 6;
    $637 = ($635 | 0) / 6 & -1;
    $638 = _cff_builder_start_point($3, $x_0_ph, $y_0_ph) | 0;
    $639 = ($638 | 0) == 0;
    if ($639) {
      label = 164;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 164:
    $641 = $637 * 3 & -1;
    $642 = $641 + 2 | 0;
    $643 = _check_points($3, $642) | 0;
    $644 = ($643 | 0) == 0;
    if ($644) {
      label = 165;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 165:
    $_neg796 = 2 - $267 | 0;
    $646 = -2 - $262 | 0;
    $647 = $646 + $_neg796 | 0;
    $_sum757 = $647 + $636 | 0;
    $648 = $151 + ($_sum757 << 2) | 0;
    $649 = ($635 | 0) > 5;
    $650 = HEAP32[$648 >> 2] | 0;
    $651 = $650 + $x_0_ph | 0;
    $_sum925 = $_sum757 + 1 | 0;
    $652 = $151 + ($_sum925 << 2) | 0;
    $653 = HEAP32[$652 >> 2] | 0;
    $654 = $653 + $y_0_ph | 0;
    if ($649) {
      $num_curves_0830 = $637;
      $args_9831 = $648;
      $656 = $651;
      $655 = $654;
      label = 166;
      break;
    } else {
      $_lcssa828 = $651;
      $_lcssa829 = $654;
      label = 167;
      break;
    }
   case 166:
    _cff_builder_add_point($3, $656, $655, 0);
    $657 = $args_9831 + 8 | 0;
    $658 = HEAP32[$657 >> 2] | 0;
    $659 = $658 + $656 | 0;
    $660 = $args_9831 + 12 | 0;
    $661 = HEAP32[$660 >> 2] | 0;
    $662 = $661 + $655 | 0;
    _cff_builder_add_point($3, $659, $662, 0);
    $663 = $args_9831 + 16 | 0;
    $664 = HEAP32[$663 >> 2] | 0;
    $665 = $664 + $659 | 0;
    $666 = $args_9831 + 20 | 0;
    $667 = HEAP32[$666 >> 2] | 0;
    $668 = $667 + $662 | 0;
    _cff_builder_add_point($3, $665, $668, 1);
    $669 = $args_9831 + 24 | 0;
    $670 = $num_curves_0830 - 1 | 0;
    $671 = ($670 | 0) > 0;
    $672 = HEAP32[$669 >> 2] | 0;
    $673 = $672 + $665 | 0;
    $674 = $args_9831 + 28 | 0;
    $675 = HEAP32[$674 >> 2] | 0;
    $676 = $675 + $668 | 0;
    if ($671) {
      $num_curves_0830 = $670;
      $args_9831 = $669;
      $656 = $673;
      $655 = $676;
      label = 166;
      break;
    } else {
      $_lcssa828 = $673;
      $_lcssa829 = $676;
      label = 167;
      break;
    }
   case 167:
    _cff_builder_add_point($3, $_lcssa828, $_lcssa829, 1);
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $_lcssa828;
    $y_16 = $_lcssa829;
    $args_12 = $31;
    label = 248;
    break;
   case 168:
    $678 = _cff_builder_start_point($3, $x_0_ph, $y_0_ph) | 0;
    $679 = ($678 | 0) == 0;
    if ($679) {
      label = 169;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 169:
    $681 = _check_points($3, 6) | 0;
    $682 = ($681 | 0) == 0;
    if ($682) {
      label = 170;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 170:
    $684 = HEAP32[$266 >> 2] | 0;
    $685 = $684 + $x_0_ph | 0;
    $_sum749 = 1 - $262 | 0;
    $686 = $151 + ($_sum749 << 2) | 0;
    $687 = HEAP32[$686 >> 2] | 0;
    $688 = $687 + $y_0_ph | 0;
    _cff_builder_add_point($3, $685, $688, 0);
    $_sum750 = 2 - $262 | 0;
    $689 = $151 + ($_sum750 << 2) | 0;
    $690 = HEAP32[$689 >> 2] | 0;
    $691 = $690 + $685 | 0;
    $_sum751 = 3 - $262 | 0;
    $692 = $151 + ($_sum751 << 2) | 0;
    $693 = HEAP32[$692 >> 2] | 0;
    $694 = $693 + $688 | 0;
    _cff_builder_add_point($3, $691, $694, 0);
    $_sum752 = 4 - $262 | 0;
    $695 = $151 + ($_sum752 << 2) | 0;
    $696 = HEAP32[$695 >> 2] | 0;
    $697 = $696 + $691 | 0;
    _cff_builder_add_point($3, $697, $694, 1);
    $_sum753 = 5 - $262 | 0;
    $698 = $151 + ($_sum753 << 2) | 0;
    $699 = HEAP32[$698 >> 2] | 0;
    $700 = $699 + $697 | 0;
    _cff_builder_add_point($3, $700, $694, 0);
    $_sum754 = 6 - $262 | 0;
    $701 = $151 + ($_sum754 << 2) | 0;
    $702 = HEAP32[$701 >> 2] | 0;
    $703 = $702 + $700 | 0;
    $_sum755 = 7 - $262 | 0;
    $704 = $151 + ($_sum755 << 2) | 0;
    $705 = HEAP32[$704 >> 2] | 0;
    $706 = $705 + $694 | 0;
    _cff_builder_add_point($3, $703, $706, 0);
    $_sum756 = 8 - $262 | 0;
    $707 = $151 + ($_sum756 << 2) | 0;
    $708 = HEAP32[$707 >> 2] | 0;
    $709 = $708 + $703 | 0;
    _cff_builder_add_point($3, $709, $y_0_ph, 1);
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $709;
    $y_16 = $y_0_ph;
    $args_12 = $31;
    label = 248;
    break;
   case 171:
    $711 = _cff_builder_start_point($3, $x_0_ph, $y_0_ph) | 0;
    $712 = ($711 | 0) == 0;
    if ($712) {
      label = 172;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 172:
    $714 = _check_points($3, 6) | 0;
    $715 = ($714 | 0) == 0;
    if ($715) {
      label = 173;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 173:
    $717 = HEAP32[$266 >> 2] | 0;
    $718 = $717 + $x_0_ph | 0;
    _cff_builder_add_point($3, $718, $y_0_ph, 0);
    $_sum743 = 1 - $262 | 0;
    $719 = $151 + ($_sum743 << 2) | 0;
    $720 = HEAP32[$719 >> 2] | 0;
    $721 = $720 + $718 | 0;
    $_sum744 = 2 - $262 | 0;
    $722 = $151 + ($_sum744 << 2) | 0;
    $723 = HEAP32[$722 >> 2] | 0;
    $724 = $723 + $y_0_ph | 0;
    _cff_builder_add_point($3, $721, $724, 0);
    $_sum745 = 3 - $262 | 0;
    $725 = $151 + ($_sum745 << 2) | 0;
    $726 = HEAP32[$725 >> 2] | 0;
    $727 = $726 + $721 | 0;
    _cff_builder_add_point($3, $727, $724, 1);
    $_sum746 = 4 - $262 | 0;
    $728 = $151 + ($_sum746 << 2) | 0;
    $729 = HEAP32[$728 >> 2] | 0;
    $730 = $729 + $727 | 0;
    _cff_builder_add_point($3, $730, $724, 0);
    $_sum747 = 5 - $262 | 0;
    $731 = $151 + ($_sum747 << 2) | 0;
    $732 = HEAP32[$731 >> 2] | 0;
    $733 = $732 + $730 | 0;
    _cff_builder_add_point($3, $733, $y_0_ph, 0);
    $_sum748 = 6 - $262 | 0;
    $734 = $151 + ($_sum748 << 2) | 0;
    $735 = HEAP32[$734 >> 2] | 0;
    $736 = $735 + $733 | 0;
    _cff_builder_add_point($3, $736, $y_0_ph, 1);
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $736;
    $y_16 = $y_0_ph;
    $args_12 = $31;
    label = 248;
    break;
   case 174:
    $738 = _cff_builder_start_point($3, $x_0_ph, $y_0_ph) | 0;
    $739 = ($738 | 0) == 0;
    if ($739) {
      label = 175;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 175:
    $741 = _check_points($3, 6) | 0;
    $742 = ($741 | 0) == 0;
    if ($742) {
      label = 176;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 176:
    $744 = HEAP32[$266 >> 2] | 0;
    $_sum985 = 1 - $262 | 0;
    $745 = $151 + ($_sum985 << 2) | 0;
    $746 = HEAP32[$745 >> 2] | 0;
    $_sum986 = 2 - $262 | 0;
    $747 = $151 + ($_sum986 << 2) | 0;
    $748 = HEAP32[$747 >> 2] | 0;
    $749 = $748 + $744 | 0;
    $_sum987 = $_sum986 + 1 | 0;
    $750 = $151 + ($_sum987 << 2) | 0;
    $751 = HEAP32[$750 >> 2] | 0;
    $752 = $751 + $746 | 0;
    $_sum988 = $_sum986 + 2 | 0;
    $753 = $151 + ($_sum988 << 2) | 0;
    $754 = HEAP32[$753 >> 2] | 0;
    $755 = $754 + $749 | 0;
    $_sum989 = $_sum986 + 3 | 0;
    $756 = $151 + ($_sum989 << 2) | 0;
    $757 = HEAP32[$756 >> 2] | 0;
    $758 = $757 + $752 | 0;
    $_sum990 = $_sum986 + 4 | 0;
    $759 = $151 + ($_sum990 << 2) | 0;
    $760 = HEAP32[$759 >> 2] | 0;
    $761 = $760 + $755 | 0;
    $_sum991 = $_sum986 + 5 | 0;
    $762 = $151 + ($_sum991 << 2) | 0;
    $763 = HEAP32[$762 >> 2] | 0;
    $764 = $763 + $758 | 0;
    $_sum992 = $_sum986 + 6 | 0;
    $765 = $151 + ($_sum992 << 2) | 0;
    $766 = HEAP32[$765 >> 2] | 0;
    $767 = $766 + $761 | 0;
    $_sum993 = $_sum986 + 7 | 0;
    $768 = $151 + ($_sum993 << 2) | 0;
    $769 = HEAP32[$768 >> 2] | 0;
    $770 = $769 + $764 | 0;
    $771 = HEAP32[$266 >> 2] | 0;
    $772 = $771 + $x_0_ph | 0;
    $773 = -$770 | 0;
    $774 = ($770 | 0) < 0;
    $dy_1 = $774 ? $773 : $770;
    $775 = -$767 | 0;
    $_sum994 = 1 - $262 | 0;
    $776 = $151 + ($_sum994 << 2) | 0;
    $777 = HEAP32[$776 >> 2] | 0;
    $778 = $777 + $y_0_ph | 0;
    _cff_builder_add_point($3, $772, $778, 0);
    $_sum995 = 2 - $262 | 0;
    $779 = $151 + ($_sum995 << 2) | 0;
    $780 = HEAP32[$779 >> 2] | 0;
    $781 = $780 + $772 | 0;
    $_sum996 = $_sum995 + 1 | 0;
    $782 = $151 + ($_sum996 << 2) | 0;
    $783 = HEAP32[$782 >> 2] | 0;
    $784 = $783 + $778 | 0;
    _cff_builder_add_point($3, $781, $784, 0);
    $_sum997 = $_sum995 + 2 | 0;
    $785 = $151 + ($_sum997 << 2) | 0;
    $786 = HEAP32[$785 >> 2] | 0;
    $787 = $786 + $781 | 0;
    $_sum998 = $_sum995 + 3 | 0;
    $788 = $151 + ($_sum998 << 2) | 0;
    $789 = HEAP32[$788 >> 2] | 0;
    $790 = $789 + $784 | 0;
    _cff_builder_add_point($3, $787, $790, 1);
    $_sum999 = $_sum995 + 4 | 0;
    $791 = $151 + ($_sum999 << 2) | 0;
    $792 = HEAP32[$791 >> 2] | 0;
    $793 = $792 + $787 | 0;
    $_sum1000 = $_sum995 + 5 | 0;
    $794 = $151 + ($_sum1000 << 2) | 0;
    $795 = HEAP32[$794 >> 2] | 0;
    $796 = $795 + $790 | 0;
    _cff_builder_add_point($3, $793, $796, 0);
    $_sum1001 = $_sum995 + 6 | 0;
    $797 = $151 + ($_sum1001 << 2) | 0;
    $798 = HEAP32[$797 >> 2] | 0;
    $799 = $798 + $793 | 0;
    $_sum1002 = $_sum995 + 7 | 0;
    $800 = $151 + ($_sum1002 << 2) | 0;
    $801 = HEAP32[$800 >> 2] | 0;
    $802 = $801 + $796 | 0;
    _cff_builder_add_point($3, $799, $802, 0);
    $_sum1003 = $_sum995 + 8 | 0;
    $803 = $151 + ($_sum1003 << 2) | 0;
    $804 = HEAP32[$803 >> 2] | 0;
    $805 = $804 + $799 | 0;
    $806 = ($767 | 0) < 0;
    $_dx_0 = $806 ? $775 : $767;
    $807 = ($_dx_0 | 0) > ($dy_1 | 0);
    $808 = $804 + $802 | 0;
    $y_14 = $807 ? $y_0_ph : $808;
    $x_14 = $807 ? $805 : $x_0_ph;
    _cff_builder_add_point($3, $x_14, $y_14, 1);
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_14;
    $y_16 = $y_14;
    $args_12 = $31;
    label = 248;
    break;
   case 177:
    $810 = _cff_builder_start_point($3, $x_0_ph, $y_0_ph) | 0;
    $811 = ($810 | 0) == 0;
    if ($811) {
      label = 178;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 178:
    $813 = _check_points($3, 6) | 0;
    $814 = ($813 | 0) == 0;
    if ($814) {
      label = 179;
      break;
    } else {
      $_0 = 0;
      label = 249;
      break;
    }
   case 179:
    $815 = HEAP32[$266 >> 2] | 0;
    $816 = $815 + $x_0_ph | 0;
    $_sum974 = 1 - $262 | 0;
    $817 = $151 + ($_sum974 << 2) | 0;
    $818 = HEAP32[$817 >> 2] | 0;
    $819 = $818 + $y_0_ph | 0;
    _cff_builder_add_point($3, $816, $819, 0);
    $_sum975 = 2 - $262 | 0;
    $820 = $151 + ($_sum975 << 2) | 0;
    $821 = HEAP32[$820 >> 2] | 0;
    $822 = $821 + $816 | 0;
    $_sum976 = $_sum975 + 1 | 0;
    $823 = $151 + ($_sum976 << 2) | 0;
    $824 = HEAP32[$823 >> 2] | 0;
    $825 = $824 + $819 | 0;
    _cff_builder_add_point($3, $822, $825, 0);
    $_sum977 = $_sum975 + 2 | 0;
    $826 = $151 + ($_sum977 << 2) | 0;
    $827 = HEAP32[$826 >> 2] | 0;
    $828 = $827 + $822 | 0;
    $_sum978 = $_sum975 + 3 | 0;
    $829 = $151 + ($_sum978 << 2) | 0;
    $830 = HEAP32[$829 >> 2] | 0;
    $831 = $830 + $825 | 0;
    _cff_builder_add_point($3, $828, $831, 1);
    $_sum979 = $_sum975 + 4 | 0;
    $832 = $151 + ($_sum979 << 2) | 0;
    $833 = HEAP32[$832 >> 2] | 0;
    $834 = $833 + $828 | 0;
    $_sum980 = $_sum975 + 5 | 0;
    $835 = $151 + ($_sum980 << 2) | 0;
    $836 = HEAP32[$835 >> 2] | 0;
    $837 = $836 + $831 | 0;
    _cff_builder_add_point($3, $834, $837, 0);
    $_sum981 = $_sum975 + 6 | 0;
    $838 = $151 + ($_sum981 << 2) | 0;
    $839 = HEAP32[$838 >> 2] | 0;
    $840 = $839 + $834 | 0;
    $_sum982 = $_sum975 + 7 | 0;
    $841 = $151 + ($_sum982 << 2) | 0;
    $842 = HEAP32[$841 >> 2] | 0;
    $843 = $842 + $837 | 0;
    _cff_builder_add_point($3, $840, $843, 0);
    $_sum983 = $_sum975 + 8 | 0;
    $844 = $151 + ($_sum983 << 2) | 0;
    $845 = HEAP32[$844 >> 2] | 0;
    $846 = $845 + $840 | 0;
    $_sum984 = $_sum975 + 9 | 0;
    $847 = $151 + ($_sum984 << 2) | 0;
    $848 = HEAP32[$847 >> 2] | 0;
    $849 = $848 + $843 | 0;
    _cff_builder_add_point($3, $846, $849, 1);
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $846;
    $y_16 = $849;
    $args_12 = $31;
    label = 248;
    break;
   case 180:
    $851 = HEAP32[$1 >> 2] | 0;
    $852 = HEAP32[$266 >> 2] | 0;
    $_sum739 = 1 - $262 | 0;
    $853 = $151 + ($_sum739 << 2) | 0;
    $854 = HEAP32[$853 >> 2] | 0;
    $_sum740 = 2 - $262 | 0;
    $855 = $151 + ($_sum740 << 2) | 0;
    $856 = HEAP32[$855 >> 2] | 0;
    $_sum741 = 3 - $262 | 0;
    $857 = $151 + ($_sum741 << 2) | 0;
    $858 = HEAP32[$857 >> 2] | 0;
    $859 = $858 >> 16;
    $_sum742 = 4 - $262 | 0;
    $860 = $151 + ($_sum742 << 2) | 0;
    $861 = HEAP32[$860 >> 2] | 0;
    $862 = $861 >> 16;
    $863 = _cff_operator_seac($851, $852, $854, $856, $859, $862) | 0;
    $864 = $decoder + 12 | 0;
    $865 = HEAP32[$864 >> 2] | 0;
    _FT_GlyphLoader_Add($865);
    $_0 = $863;
    label = 249;
    break;
   case 181:
    $867 = ($267 | 0) > 3;
    if ($867) {
      label = 182;
      break;
    } else {
      label = 183;
      break;
    }
   case 182:
    $869 = HEAP32[$1 >> 2] | 0;
    $870 = $869 + 744 | 0;
    $871 = HEAP32[$870 >> 2] | 0;
    $_sum735 = -4 - $262 | 0;
    $872 = $151 + ($_sum735 << 2) | 0;
    $873 = HEAP32[$872 >> 2] | 0;
    $_sum736 = -3 - $262 | 0;
    $874 = $151 + ($_sum736 << 2) | 0;
    $875 = HEAP32[$874 >> 2] | 0;
    $_sum737 = -2 - $262 | 0;
    $876 = $151 + ($_sum737 << 2) | 0;
    $877 = HEAP32[$876 >> 2] | 0;
    $878 = $877 >> 16;
    $req_args_0_not = $req_args_0 | -16;
    $_sum738 = $req_args_0_not ^ 15;
    $879 = $151 + ($_sum738 << 2) | 0;
    $880 = HEAP32[$879 >> 2] | 0;
    $881 = $880 >> 16;
    $882 = _cff_operator_seac($869, 0, $873, $875, $878, $881) | 0;
    $883 = HEAP32[$1 >> 2] | 0;
    $884 = $883 + 744 | 0;
    HEAP32[$884 >> 2] = $871;
    $_0 = $882;
    label = 249;
    break;
   case 183:
    _cff_builder_close_contour($3);
    if ($46) {
      label = 184;
      break;
    } else {
      label = 186;
      break;
    }
   case 184:
    $887 = $33 + 8 | 0;
    $888 = $887;
    $889 = HEAP32[$888 >> 2] | 0;
    $890 = $33;
    $891 = HEAP32[$890 >> 2] | 0;
    $892 = $decoder + 20 | 0;
    $893 = HEAP32[$892 >> 2] | 0;
    $894 = $893 + 2 | 0;
    $895 = HEAP16[$894 >> 1] | 0;
    $896 = $895 << 16 >> 16;
    $897 = FUNCTION_TABLE_iii[$889 & 1023]($891, $896) | 0;
    $898 = ($897 | 0) == 0;
    if ($898) {
      label = 185;
      break;
    } else {
      $_0 = 3;
      label = 249;
      break;
    }
   case 185:
    $900 = $33 + 24 | 0;
    $901 = $900;
    $902 = HEAP32[$901 >> 2] | 0;
    $903 = HEAP32[$890 >> 2] | 0;
    $904 = HEAP32[$892 >> 2] | 0;
    $905 = $decoder + 72 | 0;
    $906 = HEAP32[$905 >> 2] | 0;
    $907 = $906;
    $908 = HEAP32[$1 >> 2] | 0;
    $909 = $908 + 920 | 0;
    $910 = HEAP32[$909 >> 2] | 0;
    $911 = FUNCTION_TABLE_iiiii[$902 & 1023]($903, $904, $907, $910) | 0;
    label = 186;
    break;
   case 186:
    $913 = $decoder + 12 | 0;
    $914 = HEAP32[$913 >> 2] | 0;
    _FT_GlyphLoader_Add($914);
    $_0 = 0;
    label = 249;
    break;
   case 187:
    $916 = HEAP32[$266 >> 2] | 0;
    $917 = ($916 | 0) < 0;
    if ($917) {
      label = 188;
      break;
    } else {
      label = 189;
      break;
    }
   case 188:
    $919 = -$916 | 0;
    HEAP32[$266 >> 2] = $919;
    label = 189;
    break;
   case 189:
    $_sum734 = 1 - $262 | 0;
    $921 = $151 + ($_sum734 << 2) | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $921;
    label = 248;
    break;
   case 190:
    $_sum733 = 1 - $262 | 0;
    $923 = $151 + ($_sum733 << 2) | 0;
    $924 = HEAP32[$923 >> 2] | 0;
    $925 = HEAP32[$266 >> 2] | 0;
    $926 = $925 + $924 | 0;
    HEAP32[$266 >> 2] = $926;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $923;
    label = 248;
    break;
   case 191:
    $_sum732 = 1 - $262 | 0;
    $928 = $151 + ($_sum732 << 2) | 0;
    $929 = HEAP32[$928 >> 2] | 0;
    $930 = HEAP32[$266 >> 2] | 0;
    $931 = $930 - $929 | 0;
    HEAP32[$266 >> 2] = $931;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $928;
    label = 248;
    break;
   case 192:
    $933 = HEAP32[$266 >> 2] | 0;
    $_sum731 = 1 - $262 | 0;
    $934 = $151 + ($_sum731 << 2) | 0;
    $935 = HEAP32[$934 >> 2] | 0;
    $936 = _FT_DivFix($933, $935) | 0;
    HEAP32[$266 >> 2] = $936;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $934;
    label = 248;
    break;
   case 193:
    $938 = HEAP32[$266 >> 2] | 0;
    $939 = -$938 | 0;
    HEAP32[$266 >> 2] = $939;
    $_sum730 = 1 - $262 | 0;
    $940 = $151 + ($_sum730 << 2) | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $940;
    label = 248;
    break;
   case 194:
    $942 = HEAP32[$seed >> 2] | 0;
    $943 = ($942 | 0) > 32767;
    $944 = $943 & 1;
    $_788 = $944 + $942 | 0;
    HEAP32[$266 >> 2] = $_788;
    $945 = HEAP32[$seed >> 2] | 0;
    $946 = 65536 - $945 | 0;
    $947 = _FT_MulFix($945, $946) | 0;
    $948 = ($947 | 0) == 0;
    $949 = $947 + 10355 | 0;
    $storemerge729 = $948 ? $949 : $947;
    HEAP32[$seed >> 2] = $storemerge729;
    $_sum728 = 1 - $262 | 0;
    $950 = $151 + ($_sum728 << 2) | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $950;
    label = 248;
    break;
   case 195:
    $952 = HEAP32[$266 >> 2] | 0;
    $_sum727 = 1 - $262 | 0;
    $953 = $151 + ($_sum727 << 2) | 0;
    $954 = HEAP32[$953 >> 2] | 0;
    $955 = _FT_MulFix($952, $954) | 0;
    HEAP32[$266 >> 2] = $955;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $953;
    label = 248;
    break;
   case 196:
    $957 = HEAP32[$266 >> 2] | 0;
    $958 = ($957 | 0) > 0;
    if ($958) {
      $root_0 = $957;
      label = 197;
      break;
    } else {
      $storemerge = 0;
      label = 198;
      break;
    }
   case 197:
    $959 = HEAP32[$266 >> 2] | 0;
    $960 = _FT_DivFix($959, $root_0) | 0;
    $961 = $root_0 + 1 | 0;
    $962 = $961 + $960 | 0;
    $963 = $962 >> 1;
    $964 = ($963 | 0) == ($root_0 | 0);
    if ($964) {
      $storemerge = $963;
      label = 198;
      break;
    } else {
      $root_0 = $963;
      label = 197;
      break;
    }
   case 198:
    HEAP32[$266 >> 2] = $storemerge;
    $_sum726 = 1 - $262 | 0;
    $965 = $151 + ($_sum726 << 2) | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $965;
    label = 248;
    break;
   case 199:
    $967 = HEAP32[$266 >> 2] | 0;
    $_sum724 = 1 - $262 | 0;
    $968 = $151 + ($_sum724 << 2) | 0;
    $969 = HEAP32[$968 >> 2] | 0;
    HEAP32[$266 >> 2] = $969;
    HEAP32[$968 >> 2] = $967;
    $_sum725 = 2 - $262 | 0;
    $970 = $151 + ($_sum725 << 2) | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $970;
    label = 248;
    break;
   case 200:
    $972 = HEAP32[$266 >> 2] | 0;
    $973 = $972 >> 16;
    $974 = ($973 | 0) < 0;
    if ($974) {
      $idx_0 = -1;
      label = 202;
      break;
    } else {
      label = 201;
      break;
    }
   case 201:
    $976 = $267 - 2 | 0;
    $977 = ($973 | 0) > ($976 | 0);
    $_789 = $977 ? $976 : $973;
    $phitmp795 = $_789 ^ -1;
    $idx_0 = $phitmp795;
    label = 202;
    break;
   case 202:
    $_sum722 = $idx_0 - $262 | 0;
    $979 = $151 + ($_sum722 << 2) | 0;
    $980 = HEAP32[$979 >> 2] | 0;
    HEAP32[$266 >> 2] = $980;
    $_sum723 = 1 - $262 | 0;
    $981 = $151 + ($_sum723 << 2) | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $981;
    label = 248;
    break;
   case 203:
    $983 = HEAP32[$266 >> 2] | 0;
    $984 = $983 >> 16;
    $_sum713 = 1 - $262 | 0;
    $985 = $151 + ($_sum713 << 2) | 0;
    $986 = HEAP32[$985 >> 2] | 0;
    $987 = $986 >> 16;
    $988 = ($984 | 0) < 1;
    $_790 = $988 ? 1 : $984;
    $sum = $_790 + $262 | 0;
    $_sum714 = -$sum | 0;
    $989 = $151 + ($_sum714 << 2) | 0;
    $990 = $989 >>> 0 < $31 >>> 0;
    if ($990) {
      $_0 = 129;
      label = 249;
      break;
    } else {
      label = 204;
      break;
    }
   case 204:
    $992 = ($987 | 0) > -1;
    if ($992) {
      label = 205;
      break;
    } else {
      label = 207;
      break;
    }
   case 205:
    $993 = ($987 | 0) > 0;
    if ($993) {
      label = 206;
      break;
    } else {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $x_0_ph;
      $y_16 = $y_0_ph;
      $args_12 = $266;
      label = 248;
      break;
    }
   case 206:
    $994 = $_790 - 1 | 0;
    $_sum719 = $994 - $sum | 0;
    $995 = $151 + ($_sum719 << 2) | 0;
    $996 = $_790 - 2 | 0;
    $997 = ($996 | 0) > -1;
    $998 = 1 - $sum | 0;
    $idx12_0807 = $987;
    label = 208;
    break;
   case 207:
    $999 = $_790 - 1 | 0;
    $1000 = ($999 | 0) > 0;
    $idx12_1799 = $987;
    label = 211;
    break;
   case 208:
    $1002 = HEAP32[$995 >> 2] | 0;
    if ($997) {
      $i_0801 = $996;
      label = 209;
      break;
    } else {
      label = 210;
      break;
    }
   case 209:
    $_sum720 = $i_0801 - $sum | 0;
    $1003 = $151 + ($_sum720 << 2) | 0;
    $1004 = HEAP32[$1003 >> 2] | 0;
    $_sum721 = $998 + $i_0801 | 0;
    $1005 = $151 + ($_sum721 << 2) | 0;
    HEAP32[$1005 >> 2] = $1004;
    $1006 = $i_0801 - 1 | 0;
    $1007 = ($i_0801 | 0) > 0;
    if ($1007) {
      $i_0801 = $1006;
      label = 209;
      break;
    } else {
      label = 210;
      break;
    }
   case 210:
    HEAP32[$989 >> 2] = $1002;
    $1008 = $idx12_0807 - 1 | 0;
    $1009 = ($1008 | 0) > 0;
    if ($1009) {
      $idx12_0807 = $1008;
      label = 208;
      break;
    } else {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $x_0_ph;
      $y_16 = $y_0_ph;
      $args_12 = $266;
      label = 248;
      break;
    }
   case 211:
    $1011 = HEAP32[$989 >> 2] | 0;
    if ($1000) {
      $i15_0798 = 0;
      label = 212;
      break;
    } else {
      label = 213;
      break;
    }
   case 212:
    $1012 = $i15_0798 + 1 | 0;
    $_sum717 = $1012 - $sum | 0;
    $1013 = $151 + ($_sum717 << 2) | 0;
    $1014 = HEAP32[$1013 >> 2] | 0;
    $_sum718 = $i15_0798 - $sum | 0;
    $1015 = $151 + ($_sum718 << 2) | 0;
    HEAP32[$1015 >> 2] = $1014;
    $1016 = ($1012 | 0) < ($999 | 0);
    if ($1016) {
      $i15_0798 = $1012;
      label = 212;
      break;
    } else {
      label = 213;
      break;
    }
   case 213:
    $_sum716 = $999 - $sum | 0;
    $1017 = $151 + ($_sum716 << 2) | 0;
    HEAP32[$1017 >> 2] = $1011;
    $1018 = $idx12_1799 + 1 | 0;
    $exitcond = ($1018 | 0) == 0;
    if ($exitcond) {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $x_0_ph;
      $y_16 = $y_0_ph;
      $args_12 = $266;
      label = 248;
      break;
    } else {
      $idx12_1799 = $1018;
      label = 211;
      break;
    }
   case 214:
    $1020 = HEAP32[$266 >> 2] | 0;
    $_sum711 = 1 - $262 | 0;
    $1021 = $151 + ($_sum711 << 2) | 0;
    HEAP32[$1021 >> 2] = $1020;
    $_sum712 = 2 - $262 | 0;
    $1022 = $151 + ($_sum712 << 2) | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $1022;
    label = 248;
    break;
   case 215:
    $_sum710 = 1 - $262 | 0;
    $1024 = $151 + ($_sum710 << 2) | 0;
    $1025 = HEAP32[$1024 >> 2] | 0;
    $1026 = $1025 >> 16;
    $1027 = $1026 >>> 0 < 32;
    if ($1027) {
      label = 216;
      break;
    } else {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $x_0_ph;
      $y_16 = $y_0_ph;
      $args_12 = $266;
      label = 248;
      break;
    }
   case 216:
    $1029 = HEAP32[$266 >> 2] | 0;
    $1030 = HEAP32[$1 >> 2] | 0;
    $1031 = $1030 + 760 + ($1026 << 2) | 0;
    HEAP32[$1031 >> 2] = $1029;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $266;
    label = 248;
    break;
   case 217:
    $1033 = HEAP32[$266 >> 2] | 0;
    $1034 = $1033 >> 16;
    $1035 = $1034 >>> 0 < 32;
    if ($1035) {
      label = 218;
      break;
    } else {
      $val19_0 = 0;
      label = 219;
      break;
    }
   case 218:
    $1037 = HEAP32[$1 >> 2] | 0;
    $1038 = $1037 + 760 + ($1034 << 2) | 0;
    $1039 = HEAP32[$1038 >> 2] | 0;
    $val19_0 = $1039;
    label = 219;
    break;
   case 219:
    HEAP32[$266 >> 2] = $val19_0;
    $_sum709 = 1 - $262 | 0;
    $1041 = $151 + ($_sum709 << 2) | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $1041;
    label = 248;
    break;
   case 220:
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $31;
    label = 248;
    break;
   case 221:
    $1044 = HEAP32[$1 >> 2] | 0;
    $1045 = $1044 + 748 | 0;
    $1046 = HEAP32[$1045 >> 2] | 0;
    $_sum708 = 1 - $262 | 0;
    $1047 = $151 + ($_sum708 << 2) | 0;
    $1048 = HEAP32[$1047 >> 2] | 0;
    $1049 = $1048 >> 16;
    $1050 = $1049 + $1046 | 0;
    $1051 = $1044 + 744 | 0;
    HEAP32[$1051 >> 2] = $1050;
    $1052 = HEAP32[$266 >> 2] | 0;
    $1053 = HEAP32[$1 >> 2] | 0;
    $1054 = $1053 + 32 | 0;
    HEAP32[$1054 >> 2] = $1052;
    $1055 = HEAP32[$1 >> 2] | 0;
    $1056 = $1055 + 36 | 0;
    HEAP32[$1056 >> 2] = 0;
    $1057 = HEAP32[$1 >> 2] | 0;
    $1058 = $1057 + 24 | 0;
    $1059 = HEAP32[$1058 >> 2] | 0;
    $1060 = HEAP32[$266 >> 2] | 0;
    $1061 = $1060 + $1059 | 0;
    $1062 = $1057 + 28 | 0;
    $1063 = HEAP32[$1062 >> 2] | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $1061;
    $y_16 = $1063;
    $args_12 = $31;
    label = 248;
    break;
   case 222:
    $1065 = HEAP32[$1 >> 2] | 0;
    $1066 = $1065 + 748 | 0;
    $1067 = HEAP32[$1066 >> 2] | 0;
    $_sum706 = 2 - $262 | 0;
    $1068 = $151 + ($_sum706 << 2) | 0;
    $1069 = HEAP32[$1068 >> 2] | 0;
    $1070 = $1069 >> 16;
    $1071 = $1070 + $1067 | 0;
    $1072 = $1065 + 744 | 0;
    HEAP32[$1072 >> 2] = $1071;
    $1073 = HEAP32[$266 >> 2] | 0;
    $1074 = HEAP32[$1 >> 2] | 0;
    $1075 = $1074 + 32 | 0;
    HEAP32[$1075 >> 2] = $1073;
    $_sum707 = 1 - $262 | 0;
    $1076 = $151 + ($_sum707 << 2) | 0;
    $1077 = HEAP32[$1076 >> 2] | 0;
    $1078 = HEAP32[$1 >> 2] | 0;
    $1079 = $1078 + 36 | 0;
    HEAP32[$1079 >> 2] = $1077;
    $1080 = HEAP32[$1 >> 2] | 0;
    $1081 = $1080 + 24 | 0;
    $1082 = HEAP32[$1081 >> 2] | 0;
    $1083 = HEAP32[$266 >> 2] | 0;
    $1084 = $1083 + $1082 | 0;
    $1085 = $1080 + 28 | 0;
    $1086 = HEAP32[$1085 >> 2] | 0;
    $1087 = HEAP32[$1076 >> 2] | 0;
    $1088 = $1087 + $1086 | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $1084;
    $y_16 = $1088;
    $args_12 = $31;
    label = 248;
    break;
   case 223:
    $1090 = HEAP32[$1 >> 2] | 0;
    $1091 = $1090 + 24 | 0;
    $1092 = HEAP32[$1091 >> 2] | 0;
    $1093 = HEAP32[$266 >> 2] | 0;
    $1094 = $1093 + $1092 | 0;
    $1095 = $1090 + 28 | 0;
    $1096 = HEAP32[$1095 >> 2] | 0;
    $_sum705 = 1 - $262 | 0;
    $1097 = $151 + ($_sum705 << 2) | 0;
    $1098 = HEAP32[$1097 >> 2] | 0;
    $1099 = $1098 + $1096 | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $1094;
    $y_16 = $1099;
    $args_12 = $31;
    label = 248;
    break;
   case 224:
    $_sum703 = -2 - $262 | 0;
    $1101 = $151 + ($_sum703 << 2) | 0;
    $1102 = HEAP32[$1101 >> 2] | 0;
    $1103 = $1102 >> 16;
    $1104 = -2 - $262 | 0;
    $_sum704 = $1104 - $1103 | 0;
    $1105 = $151 + ($_sum704 << 2) | 0;
    $1106 = $1105 >>> 0 < $31 >>> 0;
    if ($1106) {
      $_0 = 129;
      label = 249;
      break;
    } else {
      $zone_1 = $zone_0_ph;
      $ip_3 = $ip_2_ph;
      $limit_1 = $limit_0_ph;
      $x_16 = $x_0_ph;
      $y_16 = $y_0_ph;
      $args_12 = $1105;
      label = 248;
      break;
    }
   case 225:
    $_sum702 = 1 - $262 | 0;
    $1108 = $151 + ($_sum702 << 2) | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $1108;
    label = 248;
    break;
   case 226:
    $1110 = HEAP32[$266 >> 2] | 0;
    $1111 = ($1110 | 0) == 0;
    if ($1111) {
      $1117 = 0;
      label = 228;
      break;
    } else {
      label = 227;
      break;
    }
   case 227:
    $_sum701 = 1 - $262 | 0;
    $1113 = $151 + ($_sum701 << 2) | 0;
    $1114 = HEAP32[$1113 >> 2] | 0;
    $1115 = ($1114 | 0) != 0;
    $phitmp699 = $1115 ? 65536 : 0;
    $1117 = $phitmp699;
    label = 228;
    break;
   case 228:
    HEAP32[$266 >> 2] = $1117;
    $_sum700 = 1 - $262 | 0;
    $1118 = $151 + ($_sum700 << 2) | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $1118;
    label = 248;
    break;
   case 229:
    $1120 = HEAP32[$266 >> 2] | 0;
    $1121 = ($1120 | 0) == 0;
    if ($1121) {
      label = 230;
      break;
    } else {
      $1127 = 65536;
      label = 231;
      break;
    }
   case 230:
    $_sum697 = 1 - $262 | 0;
    $1123 = $151 + ($_sum697 << 2) | 0;
    $1124 = HEAP32[$1123 >> 2] | 0;
    $1125 = ($1124 | 0) != 0;
    $phitmp = $1125 ? 65536 : 0;
    $1127 = $phitmp;
    label = 231;
    break;
   case 231:
    HEAP32[$266 >> 2] = $1127;
    $_sum698 = 1 - $262 | 0;
    $1128 = $151 + ($_sum698 << 2) | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $1128;
    label = 248;
    break;
   case 232:
    $1130 = HEAP32[$266 >> 2] | 0;
    $1131 = ($1130 | 0) == 0;
    $1132 = $1131 ? 65536 : 0;
    HEAP32[$266 >> 2] = $1132;
    $_sum696 = 1 - $262 | 0;
    $1133 = $151 + ($_sum696 << 2) | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $1133;
    label = 248;
    break;
   case 233:
    $_sum = 2 - $262 | 0;
    $1135 = $151 + ($_sum << 2) | 0;
    $1136 = HEAP32[$1135 >> 2] | 0;
    $_sum693 = 3 - $262 | 0;
    $1137 = $151 + ($_sum693 << 2) | 0;
    $1138 = HEAP32[$1137 >> 2] | 0;
    $1139 = ($1136 | 0) > ($1138 | 0);
    if ($1139) {
      label = 234;
      break;
    } else {
      label = 235;
      break;
    }
   case 234:
    $_sum694 = 1 - $262 | 0;
    $1141 = $151 + ($_sum694 << 2) | 0;
    $1142 = HEAP32[$1141 >> 2] | 0;
    HEAP32[$266 >> 2] = $1142;
    label = 235;
    break;
   case 235:
    $_sum695 = 1 - $262 | 0;
    $1144 = $151 + ($_sum695 << 2) | 0;
    $zone_1 = $zone_0_ph;
    $ip_3 = $ip_2_ph;
    $limit_1 = $limit_0_ph;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $1144;
    label = 248;
    break;
   case 236:
    $1146 = HEAP32[$266 >> 2] | 0;
    $1147 = $1146 >> 16;
    $1148 = HEAP32[$1 >> 2] | 0;
    $1149 = $1148 + 896 | 0;
    $1150 = HEAP32[$1149 >> 2] | 0;
    $1151 = $1150 + $1147 | 0;
    $1152 = $1148 + 888 | 0;
    $1153 = HEAP32[$1152 >> 2] | 0;
    $1154 = $1151 >>> 0 < $1153 >>> 0;
    if ($1154) {
      label = 237;
      break;
    } else {
      $_0 = 3;
      label = 249;
      break;
    }
   case 237:
    $1156 = $1148 + 280 | 0;
    $1157 = $zone_0_ph;
    $1158 = $1156;
    $1159 = $1157 - $1158 | 0;
    $1160 = ($1159 | 0) > 372;
    if ($1160) {
      $_0 = 3;
      label = 249;
      break;
    } else {
      label = 238;
      break;
    }
   case 238:
    $1162 = $zone_0_ph + 8 | 0;
    HEAP32[$1162 >> 2] = $ip_2_ph;
    $1163 = $zone_0_ph + 12 | 0;
    $1164 = HEAP32[$1 >> 2] | 0;
    $1165 = $1164 + 904 | 0;
    $1166 = HEAP32[$1165 >> 2] | 0;
    $1167 = $1166 + ($1151 << 2) | 0;
    $1168 = HEAP32[$1167 >> 2] | 0;
    $1169 = $1163 | 0;
    HEAP32[$1169 >> 2] = $1168;
    $1170 = $1151 + 1 | 0;
    $1171 = HEAP32[$1 >> 2] | 0;
    $1172 = $1171 + 904 | 0;
    $1173 = HEAP32[$1172 >> 2] | 0;
    $1174 = $1173 + ($1170 << 2) | 0;
    $1175 = HEAP32[$1174 >> 2] | 0;
    $1176 = $zone_0_ph + 16 | 0;
    HEAP32[$1176 >> 2] = $1175;
    $1177 = HEAP32[$1169 >> 2] | 0;
    $1178 = $zone_0_ph + 20 | 0;
    HEAP32[$1178 >> 2] = $1177;
    $1179 = HEAP32[$1169 >> 2] | 0;
    $1180 = ($1179 | 0) == 0;
    if ($1180) {
      $_0 = 3;
      label = 249;
      break;
    } else {
      label = 239;
      break;
    }
   case 239:
    $1182 = HEAP32[$1176 >> 2] | 0;
    $1183 = ($1182 | 0) == ($1179 | 0);
    if ($1183) {
      $_0 = 3;
      label = 249;
      break;
    } else {
      label = 240;
      break;
    }
   case 240:
    $1185 = HEAP32[$1 >> 2] | 0;
    $1186 = $1185 + 676 | 0;
    HEAP32[$1186 >> 2] = $1163;
    $1187 = HEAP32[$1169 >> 2] | 0;
    $1188 = HEAP32[$1176 >> 2] | 0;
    $zone_1 = $1163;
    $ip_3 = $1187;
    $limit_1 = $1188;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $266;
    label = 248;
    break;
   case 241:
    $1190 = HEAP32[$266 >> 2] | 0;
    $1191 = $1190 >> 16;
    $1192 = HEAP32[$1 >> 2] | 0;
    $1193 = $1192 + 900 | 0;
    $1194 = HEAP32[$1193 >> 2] | 0;
    $1195 = $1194 + $1191 | 0;
    $1196 = $1192 + 892 | 0;
    $1197 = HEAP32[$1196 >> 2] | 0;
    $1198 = $1195 >>> 0 < $1197 >>> 0;
    if ($1198) {
      label = 242;
      break;
    } else {
      $_0 = 3;
      label = 249;
      break;
    }
   case 242:
    $1200 = $1192 + 280 | 0;
    $1201 = $zone_0_ph;
    $1202 = $1200;
    $1203 = $1201 - $1202 | 0;
    $1204 = ($1203 | 0) > 372;
    if ($1204) {
      $_0 = 3;
      label = 249;
      break;
    } else {
      label = 243;
      break;
    }
   case 243:
    $1206 = $zone_0_ph + 8 | 0;
    HEAP32[$1206 >> 2] = $ip_2_ph;
    $1207 = $zone_0_ph + 12 | 0;
    $1208 = HEAP32[$1 >> 2] | 0;
    $1209 = $1208 + 908 | 0;
    $1210 = HEAP32[$1209 >> 2] | 0;
    $1211 = $1210 + ($1195 << 2) | 0;
    $1212 = HEAP32[$1211 >> 2] | 0;
    $1213 = $1207 | 0;
    HEAP32[$1213 >> 2] = $1212;
    $1214 = $1195 + 1 | 0;
    $1215 = HEAP32[$1 >> 2] | 0;
    $1216 = $1215 + 908 | 0;
    $1217 = HEAP32[$1216 >> 2] | 0;
    $1218 = $1217 + ($1214 << 2) | 0;
    $1219 = HEAP32[$1218 >> 2] | 0;
    $1220 = $zone_0_ph + 16 | 0;
    HEAP32[$1220 >> 2] = $1219;
    $1221 = HEAP32[$1213 >> 2] | 0;
    $1222 = $zone_0_ph + 20 | 0;
    HEAP32[$1222 >> 2] = $1221;
    $1223 = HEAP32[$1213 >> 2] | 0;
    $1224 = ($1223 | 0) == 0;
    if ($1224) {
      $_0 = 3;
      label = 249;
      break;
    } else {
      label = 244;
      break;
    }
   case 244:
    $1226 = HEAP32[$1220 >> 2] | 0;
    $1227 = ($1226 | 0) == ($1223 | 0);
    if ($1227) {
      $_0 = 3;
      label = 249;
      break;
    } else {
      label = 245;
      break;
    }
   case 245:
    $1229 = HEAP32[$1 >> 2] | 0;
    $1230 = $1229 + 676 | 0;
    HEAP32[$1230 >> 2] = $1207;
    $1231 = HEAP32[$1213 >> 2] | 0;
    $1232 = HEAP32[$1220 >> 2] | 0;
    $zone_1 = $1207;
    $ip_3 = $1231;
    $limit_1 = $1232;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $266;
    label = 248;
    break;
   case 246:
    $1234 = HEAP32[$1 >> 2] | 0;
    $1235 = $1234 + 676 | 0;
    $1236 = HEAP32[$1235 >> 2] | 0;
    $1237 = $1234 + 280 | 0;
    $1238 = $1236 >>> 0 > $1237 >>> 0;
    if ($1238) {
      label = 247;
      break;
    } else {
      $_0 = 3;
      label = 249;
      break;
    }
   case 247:
    $1240 = $1236 - 12 | 0;
    HEAP32[$1235 >> 2] = $1240;
    $1241 = HEAP32[$1 >> 2] | 0;
    $1242 = $1241 + 676 | 0;
    $1243 = HEAP32[$1242 >> 2] | 0;
    $1244 = $1243 + 8 | 0;
    $1245 = HEAP32[$1244 >> 2] | 0;
    $1246 = $1243 + 4 | 0;
    $1247 = HEAP32[$1246 >> 2] | 0;
    $zone_1 = $1243;
    $ip_3 = $1245;
    $limit_1 = $1247;
    $x_16 = $x_0_ph;
    $y_16 = $y_0_ph;
    $args_12 = $266;
    label = 248;
    break;
   case 248:
    $1248 = HEAP32[$1 >> 2] | 0;
    $1249 = $1248 + 276 | 0;
    HEAP32[$1249 >> 2] = $args_12;
    $1250 = HEAP32[$1 >> 2] | 0;
    $1251 = $1250 + 276 | 0;
    $1252 = HEAP32[$1251 >> 2] | 0;
    $1253 = $1252;
    $1254 = $1253 - $58 | 0;
    $1255 = ($1254 | 0) > 188;
    if ($1255) {
      $_0 = 130;
      label = 249;
      break;
    } else {
      $zone_0_ph = $zone_1;
      $ip_0_ph = $ip_3;
      $limit_0_ph = $limit_1;
      $x_0_ph = $x_16;
      $y_0_ph = $y_16;
      label = 4;
      break;
    }
   case 249:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _cff_compute_bias($in_charstring_type, $num_subrs) {
  $in_charstring_type = $in_charstring_type | 0;
  $num_subrs = $num_subrs | 0;
  var $1 = 0, $3 = 0, $5 = 0, $_ = 0, $result_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($in_charstring_type | 0) == 1;
    if ($1) {
      $result_0 = 0;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $num_subrs >>> 0 < 1240;
    if ($3) {
      $result_0 = 107;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $5 = $num_subrs >>> 0 < 33900;
    $_ = $5 ? 1131 : 32768;
    $result_0 = $_;
    label = 4;
    break;
   case 4:
    return $result_0 | 0;
  }
  return 0;
}
function _cff_builder_close_contour($builder) {
  $builder = $builder | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $_sum = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $builder + 20 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 13;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 | 0;
    $6 = HEAP16[$5 >> 1] | 0;
    $7 = $6 << 16 >> 16 < 2;
    if ($7) {
      $18 = 0;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = $6 << 16 >> 16;
    $10 = $9 - 2 | 0;
    $11 = $2 + 12 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + ($10 << 1) | 0;
    $14 = HEAP16[$13 >> 1] | 0;
    $15 = $14 << 16 >> 16;
    $16 = $15 + 1 | 0;
    $18 = $16;
    label = 4;
    break;
   case 4:
    $19 = $2 + 2 | 0;
    $20 = HEAP16[$19 >> 1] | 0;
    $21 = $20 << 16 >> 16 > 1;
    if ($21) {
      label = 5;
      break;
    } else {
      label = 9;
      break;
    }
   case 5:
    $23 = $20 << 16 >> 16;
    $24 = $2 + 4 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $_sum = $23 - 1 | 0;
    $26 = $2 + 8 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $27 + $_sum | 0;
    $29 = $25 + ($18 << 3) | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $25 + ($_sum << 3) | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = ($30 | 0) == ($32 | 0);
    if ($33) {
      label = 6;
      break;
    } else {
      label = 9;
      break;
    }
   case 6:
    $35 = $25 + ($18 << 3) + 4 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $25 + ($_sum << 3) + 4 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = ($36 | 0) == ($38 | 0);
    if ($39) {
      label = 7;
      break;
    } else {
      label = 9;
      break;
    }
   case 7:
    $41 = HEAP8[$28] | 0;
    $42 = $41 << 24 >> 24 == 1;
    if ($42) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $44 = $20 - 1 & 65535;
    HEAP16[$19 >> 1] = $44;
    label = 9;
    break;
   case 9:
    $46 = HEAP16[$5 >> 1] | 0;
    $47 = $46 << 16 >> 16;
    $48 = $46 << 16 >> 16 > 0;
    if ($48) {
      label = 10;
      break;
    } else {
      label = 13;
      break;
    }
   case 10:
    $50 = HEAP16[$19 >> 1] | 0;
    $51 = $50 << 16 >> 16;
    $52 = $51 - 1 | 0;
    $53 = ($18 | 0) == ($52 | 0);
    if ($53) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    $55 = $46 - 1 & 65535;
    HEAP16[$5 >> 1] = $55;
    $56 = HEAP16[$19 >> 1] | 0;
    $57 = $56 - 1 & 65535;
    HEAP16[$19 >> 1] = $57;
    label = 13;
    break;
   case 12:
    $59 = $52 & 65535;
    $60 = $47 - 1 | 0;
    $61 = $2 + 12 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    $63 = $62 + ($60 << 1) | 0;
    HEAP16[$63 >> 1] = $59;
    label = 13;
    break;
   case 13:
    return;
  }
}
function _cff_builder_add_point($builder, $x, $y, $flag) {
  $builder = $builder | 0;
  $x = $x | 0;
  $y = $y | 0;
  $flag = $flag | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $builder + 20 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $builder + 65 | 0;
    $4 = HEAP8[$3] | 0;
    $5 = $4 << 24 >> 24 == 0;
    if ($5) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $2 + 4 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $2 + 2 | 0;
    $10 = HEAP16[$9 >> 1] | 0;
    $11 = $10 << 16 >> 16;
    $12 = $2 + 8 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 + $11 | 0;
    $15 = $x >> 16;
    $16 = $8 + ($11 << 3) | 0;
    HEAP32[$16 >> 2] = $15;
    $17 = $y >> 16;
    $18 = $8 + ($11 << 3) + 4 | 0;
    HEAP32[$18 >> 2] = $17;
    $19 = $flag << 24 >> 24 != 0;
    $20 = $19 ? 1 : 2;
    HEAP8[$14] = $20;
    label = 3;
    break;
   case 3:
    $22 = $2 + 2 | 0;
    $23 = HEAP16[$22 >> 1] | 0;
    $24 = $23 + 1 & 65535;
    HEAP16[$22 >> 1] = $24;
    return;
  }
}
function _cff_get_standard_encoding($charcode) {
  $charcode = $charcode | 0;
  var $1 = 0, $3 = 0, $4 = 0, $6 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $charcode >>> 0 < 256;
    if ($1) {
      label = 2;
      break;
    } else {
      $6 = 0;
      label = 3;
      break;
    }
   case 2:
    $3 = 5314020 + ($charcode << 1) | 0;
    $4 = HEAP16[$3 >> 1] | 0;
    $6 = $4;
    label = 3;
    break;
   case 3:
    return $6 | 0;
  }
  return 0;
}
function _cff_get_is_cid($face, $is_cid) {
  $face = $face | 0;
  $is_cid = $is_cid | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 692 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    HEAP8[$is_cid] = 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 + 1452 | 0;
    $6 = $5;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = ($7 | 0) == 65535;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    HEAP8[$is_cid] = 1;
    label = 4;
    break;
   case 4:
    return 0;
  }
  return 0;
}
function _cff_get_cid_from_glyph_index($face, $glyph_index, $cid) {
  $face = $face | 0;
  $glyph_index = $glyph_index | 0;
  $cid = $cid | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 692 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      $error_0 = 0;
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 + 1452 | 0;
    $6 = $5;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = ($7 | 0) == 65535;
    if ($8) {
      $error_0 = 6;
      label = 6;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $10 = $2 + 12 | 0;
    $11 = $10;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 >>> 0 < $glyph_index >>> 0;
    if ($13) {
      $error_0 = 6;
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $15 = ($cid | 0) == 0;
    if ($15) {
      $error_0 = 0;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $17 = $2 + 1160 | 0;
    $18 = $17;
    $19 = HEAP32[$18 >> 2] | 0;
    $20 = $19 + ($glyph_index << 1) | 0;
    $21 = HEAP16[$20 >> 1] | 0;
    $22 = $21 & 65535;
    HEAP32[$cid >> 2] = $22;
    $error_0 = 0;
    label = 6;
    break;
   case 6:
    return $error_0 | 0;
  }
  return 0;
}
function _cff_get_ps_name($face) {
  $face = $face | 0;
  return HEAP32[(HEAP32[$face + 692 >> 2] | 0) + 1304 >> 2] | 0;
}
function _cff_ps_has_glyph_names($face) {
  $face = $face | 0;
  return (HEAP32[$face + 8 >> 2] | 0) >>> 9 & 1 | 0;
}
function _cff_free_glyph_data($face, $pointer, $length) {
  $face = $face | 0;
  $pointer = $pointer | 0;
  $length = $length | 0;
  var $data = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $data = __stackBase__ | 0;
    $1 = $face + 128 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 52 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = HEAP32[$pointer >> 2] | 0;
    $8 = $data | 0;
    HEAP32[$8 >> 2] = $7;
    $9 = $data + 4 | 0;
    HEAP32[$9 >> 2] = $length;
    $10 = HEAP32[$1 >> 2] | 0;
    $11 = $10 + 52 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $14 + 4 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $12 + 4 | 0;
    $18 = HEAP32[$17 >> 2] | 0;
    FUNCTION_TABLE_vii[$16 & 1023]($18, $data);
    label = 4;
    break;
   case 3:
    $20 = $face + 692 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $21 + 1176 | 0;
    $23 = $22;
    _cff_index_forget_element($23, $pointer);
    label = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
  }
}
function _cff_builder_done($builder) {
  $builder = $builder | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $builder + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $2 + 108 | 0;
    $6 = $builder + 16 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $5;
    $9 = $7;
    _memcpy($8 | 0, $9 | 0, 20);
    label = 3;
    break;
   case 3:
    return;
  }
}
function _cff_builder_start_point($builder, $x, $y) {
  $builder = $builder | 0;
  $x = $x | 0;
  $y = $y | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $builder + 64 | 0;
    $2 = HEAP8[$1] | 0;
    $3 = $2 << 24 >> 24 == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $error_0 = 0;
      label = 4;
      break;
    }
   case 2:
    HEAP8[$1] = 1;
    $5 = _cff_builder_add_contour($builder) | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      $error_0 = $5;
      label = 4;
      break;
    }
   case 3:
    $8 = _cff_builder_add_point1($builder, $x, $y) | 0;
    $error_0 = $8;
    label = 4;
    break;
   case 4:
    return $error_0 | 0;
  }
  return 0;
}
function _check_points($builder, $count) {
  $builder = $builder | 0;
  $count = $count | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($count | 0) == 0;
    if ($1) {
      $19 = 0;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $builder + 12 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 22 | 0;
    $6 = HEAP16[$5 >> 1] | 0;
    $7 = $6 << 16 >> 16;
    $8 = $4 + 58 | 0;
    $9 = HEAP16[$8 >> 1] | 0;
    $10 = $9 << 16 >> 16;
    $11 = $7 + $count | 0;
    $12 = $11 + $10 | 0;
    $13 = $4 + 4 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $12 >>> 0 > $14 >>> 0;
    if ($15) {
      label = 3;
      break;
    } else {
      $19 = 0;
      label = 4;
      break;
    }
   case 3:
    $17 = _FT_GlyphLoader_CheckPoints($4, $count, 0) | 0;
    $19 = $17;
    label = 4;
    break;
   case 4:
    return $19 | 0;
  }
  return 0;
}
function _cff_builder_add_point1($builder, $x, $y) {
  $builder = $builder | 0;
  $x = $x | 0;
  $y = $y | 0;
  var $1 = 0, $2 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = _check_points($builder, 1) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    _cff_builder_add_point($builder, $x, $y, 1);
    label = 3;
    break;
   case 3:
    return $1 | 0;
  }
  return 0;
}
function _cff_operator_seac($decoder, $asb, $adx, $ady, $bchar, $achar) {
  $decoder = $decoder | 0;
  $asb = $asb | 0;
  $adx = $adx | 0;
  $ady = $ady | 0;
  $bchar = $bchar | 0;
  $achar = $achar | 0;
  var $charstring = 0, $charstring_len = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $achar_index_0 = 0, $bchar_index_0 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $72 = 0, $ld$0$0 = 0, $73$0 = 0, $ld$1$1 = 0, $73$1 = 0, $74 = 0, $75 = 0, $ld$2$0 = 0, $76$0 = 0, $ld$3$1 = 0, $76$1 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $error_0 = 0, $st$4$0 = 0, $st$5$1 = 0, $st$6$0 = 0, $st$7$1 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $charstring = __stackBase__ | 0;
    $charstring_len = __stackBase__ + 4 | 0;
    $1 = $decoder + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $decoder + 924 | 0;
    $4 = HEAP8[$3] | 0;
    $5 = $4 << 24 >> 24 == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      $_0 = 160;
      label = 13;
      break;
    }
   case 2:
    $7 = $decoder + 32 | 0;
    $8 = $7 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = $9 + $adx | 0;
    $11 = $decoder + 36 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + $ady | 0;
    $14 = $2 + 128 | 0;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = $15 + 52 | 0;
    $17 = HEAP32[$16 >> 2] | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 3;
      break;
    } else {
      $bchar_index_0 = $bchar;
      $achar_index_0 = $achar;
      label = 4;
      break;
    }
   case 3:
    $20 = $2 + 692 | 0;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = $21;
    $23 = _cff_lookup_glyph_by_stdcharcode($22, $bchar) | 0;
    $24 = _cff_lookup_glyph_by_stdcharcode($22, $achar) | 0;
    $bchar_index_0 = $23;
    $achar_index_0 = $24;
    label = 4;
    break;
   case 4:
    $26 = $bchar_index_0 | $achar_index_0;
    $27 = ($26 | 0) < 0;
    if ($27) {
      $_0 = 160;
      label = 13;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $29 = $decoder + 66 | 0;
    $30 = HEAP8[$29] | 0;
    $31 = $30 << 24 >> 24 == 0;
    if ($31) {
      label = 8;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $33 = $decoder + 8 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $34 + 156 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = $36 | 0;
    $38 = HEAP32[$37 >> 2] | 0;
    $39 = _FT_GlyphLoader_CheckSubGlyphs($38, 2) | 0;
    $40 = ($39 | 0) == 0;
    if ($40) {
      label = 7;
      break;
    } else {
      $_0 = $39;
      label = 13;
      break;
    }
   case 7:
    $42 = $38 + 88 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $43 | 0;
    HEAP32[$44 >> 2] = $bchar_index_0;
    $45 = $43 + 4 | 0;
    HEAP16[$45 >> 1] = 514;
    $46 = $43 + 8 | 0;
    HEAP32[$46 >> 2] = 0;
    $47 = $43 + 12 | 0;
    HEAP32[$47 >> 2] = 0;
    $48 = $43 + 32 | 0;
    HEAP32[$48 >> 2] = $achar_index_0;
    $49 = $43 + 36 | 0;
    HEAP16[$49 >> 1] = 2;
    $50 = $10 >> 16;
    $51 = $43 + 40 | 0;
    HEAP32[$51 >> 2] = $50;
    $52 = $13 >> 16;
    $53 = $43 + 44 | 0;
    HEAP32[$53 >> 2] = $52;
    $54 = $34 + 128 | 0;
    HEAP32[$54 >> 2] = 2;
    $55 = $38 + 52 | 0;
    $56 = HEAP32[$55 >> 2] | 0;
    $57 = $34 + 132 | 0;
    HEAP32[$57 >> 2] = $56;
    $58 = $34 + 72 | 0;
    HEAP32[$58 >> 2] = 1668246896;
    $59 = $38 + 84 | 0;
    HEAP32[$59 >> 2] = 2;
    label = 8;
    break;
   case 8:
    $61 = $decoder + 12 | 0;
    $62 = HEAP32[$61 >> 2] | 0;
    _FT_GlyphLoader_Prepare($62);
    $63 = _cff_get_glyph_data($2, $bchar_index_0, $charstring, $charstring_len) | 0;
    $64 = ($63 | 0) == 0;
    if ($64) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    HEAP8[$3] = 1;
    $66 = HEAP32[$charstring >> 2] | 0;
    $67 = HEAP32[$charstring_len >> 2] | 0;
    $68 = _cff_decoder_parse_charstrings($decoder, $66, $67) | 0;
    HEAP8[$3] = 0;
    $69 = HEAP32[$charstring_len >> 2] | 0;
    _cff_free_glyph_data($2, $charstring, $69);
    $70 = ($68 | 0) == 0;
    if ($70) {
      label = 10;
      break;
    } else {
      $_0 = $68;
      label = 13;
      break;
    }
   case 10:
    $72 = $7;
    $ld$0$0 = $72 | 0;
    $73$0 = HEAP32[$ld$0$0 >> 2] | 0;
    $ld$1$1 = $72 + 4 | 0;
    $73$1 = HEAP32[$ld$1$1 >> 2] | 0;
    $74 = $decoder + 40 | 0;
    $75 = $74;
    $ld$2$0 = $75 | 0;
    $76$0 = HEAP32[$ld$2$0 >> 2] | 0;
    $ld$3$1 = $75 + 4 | 0;
    $76$1 = HEAP32[$ld$3$1 >> 2] | 0;
    $77 = $decoder + 744 | 0;
    $78 = HEAP32[$77 >> 2] | 0;
    HEAP32[$8 >> 2] = 0;
    HEAP32[$11 >> 2] = 0;
    $79 = $10 - $asb | 0;
    $80 = $decoder + 24 | 0;
    HEAP32[$80 >> 2] = $79;
    $81 = $decoder + 28 | 0;
    HEAP32[$81 >> 2] = $13;
    $82 = _cff_get_glyph_data($2, $achar_index_0, $charstring, $charstring_len) | 0;
    $83 = ($82 | 0) == 0;
    if ($83) {
      label = 11;
      break;
    } else {
      $error_0 = $82;
      label = 12;
      break;
    }
   case 11:
    HEAP8[$3] = 1;
    $85 = HEAP32[$charstring >> 2] | 0;
    $86 = HEAP32[$charstring_len >> 2] | 0;
    $87 = _cff_decoder_parse_charstrings($decoder, $85, $86) | 0;
    HEAP8[$3] = 0;
    $88 = HEAP32[$charstring_len >> 2] | 0;
    _cff_free_glyph_data($2, $charstring, $88);
    $89 = ($87 | 0) == 0;
    if ($89) {
      $error_0 = 0;
      label = 12;
      break;
    } else {
      $_0 = $87;
      label = 13;
      break;
    }
   case 12:
    $st$4$0 = $72 | 0;
    HEAP32[$st$4$0 >> 2] = $73$0;
    $st$5$1 = $72 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $73$1;
    $st$6$0 = $75 | 0;
    HEAP32[$st$6$0 >> 2] = $76$0;
    $st$7$1 = $75 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $76$1;
    HEAP32[$77 >> 2] = $78;
    HEAP32[$80 >> 2] = 0;
    HEAP32[$81 >> 2] = 0;
    $_0 = $error_0;
    label = 13;
    break;
   case 13:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _cff_lookup_glyph_by_stdcharcode($cff, $charcode) {
  $cff = $cff | 0;
  $charcode = $charcode | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $or_cond = 0, $6 = 0, $7 = 0, $8 = 0, $n_0 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $cff + 1160 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    $4 = $charcode >>> 0 > 255;
    $or_cond = $3 | $4;
    if ($or_cond) {
      $_0 = -1;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = _cff_get_standard_encoding($charcode) | 0;
    $7 = $cff + 12 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $n_0 = 0;
    label = 3;
    break;
   case 3:
    $10 = $n_0 >>> 0 < $8 >>> 0;
    if ($10) {
      label = 4;
      break;
    } else {
      $_0 = -1;
      label = 5;
      break;
    }
   case 4:
    $12 = HEAP32[$1 >> 2] | 0;
    $13 = $12 + ($n_0 << 1) | 0;
    $14 = HEAP16[$13 >> 1] | 0;
    $15 = $14 << 16 >> 16 == $6 << 16 >> 16;
    $16 = $n_0 + 1 | 0;
    if ($15) {
      $_0 = $n_0;
      label = 5;
      break;
    } else {
      $n_0 = $16;
      label = 3;
      break;
    }
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function _cff_builder_add_contour($builder) {
  $builder = $builder | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $builder + 20 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $builder + 65 | 0;
    $4 = HEAP8[$3] | 0;
    $5 = $4 << 24 >> 24 == 0;
    if ($5) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $7 = $2 | 0;
    $8 = HEAP16[$7 >> 1] | 0;
    $9 = $8 + 1 & 65535;
    HEAP16[$7 >> 1] = $9;
    $_0 = 0;
    label = 8;
    break;
   case 3:
    $11 = $builder + 12 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = $12 + 20 | 0;
    $14 = HEAP16[$13 >> 1] | 0;
    $15 = $14 << 16 >> 16;
    $16 = $12 + 56 | 0;
    $17 = HEAP16[$16 >> 1] | 0;
    $18 = $17 << 16 >> 16;
    $19 = $15 + 1 | 0;
    $20 = $19 + $18 | 0;
    $21 = $12 + 8 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $20 >>> 0 > $22 >>> 0;
    if ($23) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $25 = _FT_GlyphLoader_CheckPoints($12, 0, 1) | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 5;
      break;
    } else {
      $_0 = $25;
      label = 8;
      break;
    }
   case 5:
    $27 = $2 | 0;
    $28 = HEAP16[$27 >> 1] | 0;
    $29 = $28 << 16 >> 16 > 0;
    if ($29) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $31 = $28 << 16 >> 16;
    $32 = $2 + 2 | 0;
    $33 = HEAP16[$32 >> 1] | 0;
    $34 = $33 - 1 & 65535;
    $35 = $31 - 1 | 0;
    $36 = $2 + 12 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = $37 + ($35 << 1) | 0;
    HEAP16[$38 >> 1] = $34;
    label = 7;
    break;
   case 7:
    $40 = HEAP16[$27 >> 1] | 0;
    $41 = $40 + 1 & 65535;
    HEAP16[$27 >> 1] = $41;
    $_0 = 0;
    label = 8;
    break;
   case 8:
    return $_0 | 0;
  }
  return 0;
}
function _cff_builder_init($builder, $face, $size, $glyph, $hinting) {
  $builder = $builder | 0;
  $face = $face | 0;
  $size = $size | 0;
  $glyph = $glyph | 0;
  $hinting = $hinting | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $or_cond = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $builder + 64 | 0;
    HEAP8[$1] = 0;
    $2 = $builder + 65 | 0;
    HEAP8[$2] = 1;
    $3 = $builder + 4 | 0;
    HEAP32[$3 >> 2] = $face;
    $4 = $builder + 8 | 0;
    HEAP32[$4 >> 2] = $glyph;
    $5 = $face + 100 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $builder | 0;
    HEAP32[$7 >> 2] = $6;
    $8 = ($glyph | 0) == 0;
    if ($8) {
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = $glyph + 156 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $builder + 12 | 0;
    HEAP32[$14 >> 2] = $13;
    $15 = $13 + 20 | 0;
    $16 = $builder + 16 | 0;
    HEAP32[$16 >> 2] = $15;
    $17 = $13 + 56 | 0;
    $18 = $builder + 20 | 0;
    HEAP32[$18 >> 2] = $17;
    _FT_GlyphLoader_Rewind($13);
    $19 = $builder + 72 | 0;
    HEAP32[$19 >> 2] = 0;
    $20 = $builder + 68 | 0;
    HEAP32[$20 >> 2] = 0;
    $21 = $hinting << 24 >> 24 == 0;
    $22 = ($size | 0) == 0;
    $or_cond = $21 | $22;
    if ($or_cond) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $24 = $size + 40 | 0;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = $25;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $27;
    HEAP32[$19 >> 2] = $28;
    $29 = HEAP32[$10 >> 2] | 0;
    $30 = $29 + 36 | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    HEAP32[$20 >> 2] = $31;
    label = 4;
    break;
   case 4:
    $33 = $builder + 24 | 0;
    $34 = $33;
    _memset($34 | 0, 0, 24);
    return;
  }
}
function _cff_get_ros($face, $registry, $ordering, $supplement) {
  $face = $face | 0;
  $registry = $registry | 0;
  $ordering = $ordering | 0;
  $supplement = $supplement | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $20 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $36 = 0, $38 = 0, $39 = 0, $40 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 692 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    $4 = ($2 | 0) == 0;
    if ($4) {
      $error_0 = 0;
      label = 13;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $2 + 1452 | 0;
    $7 = $6;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 65535;
    if ($9) {
      $error_0 = 6;
      label = 13;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $11 = ($registry | 0) == 0;
    if ($11) {
      label = 7;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $13 = $2 + 2064 | 0;
    $14 = $13;
    $15 = HEAP32[$14 >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $18 = _cff_index_get_sid_string($3, $8) | 0;
    HEAP32[$14 >> 2] = $18;
    label = 6;
    break;
   case 6:
    $20 = HEAP32[$14 >> 2] | 0;
    HEAP32[$registry >> 2] = $20;
    label = 7;
    break;
   case 7:
    $22 = ($ordering | 0) == 0;
    if ($22) {
      label = 11;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $24 = $2 + 2068 | 0;
    $25 = $24;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = ($26 | 0) == 0;
    if ($27) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    $29 = $2 + 1456 | 0;
    $30 = $29;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = _cff_index_get_sid_string($3, $31) | 0;
    HEAP32[$25 >> 2] = $32;
    label = 10;
    break;
   case 10:
    $34 = HEAP32[$25 >> 2] | 0;
    HEAP32[$ordering >> 2] = $34;
    label = 11;
    break;
   case 11:
    $36 = ($supplement | 0) == 0;
    if ($36) {
      $error_0 = 0;
      label = 13;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $38 = $2 + 1460 | 0;
    $39 = $38;
    $40 = HEAP32[$39 >> 2] | 0;
    HEAP32[$supplement >> 2] = $40;
    $error_0 = 0;
    label = 13;
    break;
   case 13:
    return $error_0 | 0;
  }
  return 0;
}
function _cff_get_cmap_info($charmap, $cmap_info) {
  $charmap = $charmap | 0;
  $cmap_info = $cmap_info | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $or_cond = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $charmap | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 96 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 + 4 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $cmap_info | 0;
    HEAP32[$7 >> 2] = 0;
    $8 = $cmap_info + 4 | 0;
    HEAP32[$8 >> 2] = 0;
    $9 = $charmap + 12 | 0;
    $10 = $9;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($11 | 0) == 5317736;
    $13 = ($11 | 0) == 5317696;
    $or_cond = $12 | $13;
    if ($or_cond) {
      $error_0 = 0;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $15 = $6;
    $16 = _FT_Get_Module($15, 5324184) | 0;
    $17 = _ft_module_get_service($16, 5324356) | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      $error_0 = 0;
      label = 5;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $20 = $17;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = ($21 | 0) == 0;
    if ($22) {
      $error_0 = 0;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $24 = FUNCTION_TABLE_iii[$21 & 1023]($charmap, $cmap_info) | 0;
    $error_0 = $24;
    label = 5;
    break;
   case 5:
    return $error_0 | 0;
  }
  return 0;
}
function _cff_get_glyph_name($face, $glyph_index, $buffer, $buffer_max) {
  $face = $face | 0;
  $glyph_index = $glyph_index | 0;
  $buffer = $buffer | 0;
  $buffer_max = $buffer_max | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 692 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 2056 | 0;
    $4 = $3;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      $error_0 = 2;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $8 = $2;
    $9 = $2 + 1160 | 0;
    $10 = $9;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11 + ($glyph_index << 1) | 0;
    $13 = HEAP16[$12 >> 1] | 0;
    $14 = $13 & 65535;
    $15 = _cff_index_get_sid_string($8, $14) | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      $error_0 = 0;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $18 = _ft_mem_strcpyn($buffer, $15, $buffer_max) | 0;
    $error_0 = 0;
    label = 4;
    break;
   case 4:
    return $error_0 | 0;
  }
  return 0;
}
function _cff_get_name_index($face, $glyph_name) {
  $face = $face | 0;
  $glyph_name = $glyph_name | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $i_013 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $name_0 = 0, $30 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $face + 692 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    $4 = $face + 96 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5;
    $7 = _ft_module_get_service($6, 5323212) | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      $_0 = 0;
      label = 10;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = $2 + 12 | 0;
    $10 = $9;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = ($11 | 0) == 0;
    if ($12) {
      $_0 = 0;
      label = 10;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $13 = $2 + 1160 | 0;
    $14 = $13;
    $15 = $7 + 20 | 0;
    $16 = $15;
    $i_013 = 0;
    label = 4;
    break;
   case 4:
    $18 = HEAP32[$14 >> 2] | 0;
    $19 = $18 + ($i_013 << 1) | 0;
    $20 = HEAP16[$19 >> 1] | 0;
    $21 = $20 & 65535;
    $22 = ($20 & 65535) > 390;
    if ($22) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $24 = $21 - 391 | 0;
    $25 = _cff_index_get_string($3, $24) | 0;
    $name_0 = $25;
    label = 7;
    break;
   case 6:
    $27 = HEAP32[$16 >> 2] | 0;
    $28 = FUNCTION_TABLE_ii[$27 & 1023]($21) | 0;
    $name_0 = $28;
    label = 7;
    break;
   case 7:
    $30 = ($name_0 | 0) == 0;
    if ($30) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $32 = _strcmp($glyph_name | 0, $name_0 | 0) | 0;
    $33 = ($32 | 0) == 0;
    if ($33) {
      $_0 = $i_013;
      label = 10;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $35 = $i_013 + 1 | 0;
    $36 = HEAP32[$10 >> 2] | 0;
    $37 = $35 >>> 0 < $36 >>> 0;
    if ($37) {
      $i_013 = $35;
      label = 4;
      break;
    } else {
      $_0 = 0;
      label = 10;
      break;
    }
   case 10:
    return $_0 | 0;
  }
  return 0;
}
function _cff_ps_get_font_info($face, $afont_info) {
  $face = $face | 0;
  $afont_info = $afont_info | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $face + 692 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2;
    HEAP32[$error >> 2] = 0;
    $4 = ($2 | 0) != 0;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 6;
      break;
    }
   case 2:
    $6 = $2 + 2060 | 0;
    $7 = $6;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = ($8 | 0) == 0;
    if ($9) {
      label = 3;
      break;
    } else {
      label = 5;
      break;
    }
   case 3:
    $11 = $face + 100 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = _ft_mem_alloc($12, 32, $error) | 0;
    $14 = HEAP32[$error >> 2] | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 4;
      break;
    } else {
      label = 6;
      break;
    }
   case 4:
    $17 = $2 + 1324 | 0;
    $18 = $13;
    $19 = $17;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = _cff_index_get_sid_string($3, $20) | 0;
    $22 = $13;
    HEAP32[$22 >> 2] = $21;
    $23 = $2 + 1328 | 0;
    $24 = $23;
    $25 = HEAP32[$24 >> 2] | 0;
    $26 = _cff_index_get_sid_string($3, $25) | 0;
    $27 = $13 + 4 | 0;
    $28 = $27;
    HEAP32[$28 >> 2] = $26;
    $29 = $2 + 1336 | 0;
    $30 = $29;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = _cff_index_get_sid_string($3, $31) | 0;
    $33 = $13 + 8 | 0;
    $34 = $33;
    HEAP32[$34 >> 2] = $32;
    $35 = $2 + 1340 | 0;
    $36 = $35;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = _cff_index_get_sid_string($3, $37) | 0;
    $39 = $13 + 12 | 0;
    $40 = $39;
    HEAP32[$40 >> 2] = $38;
    $41 = $2 + 1344 | 0;
    $42 = $41;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = _cff_index_get_sid_string($3, $43) | 0;
    $45 = $13 + 16 | 0;
    $46 = $45;
    HEAP32[$46 >> 2] = $44;
    $47 = $2 + 1352 | 0;
    $48 = $47;
    $49 = HEAP32[$48 >> 2] | 0;
    $50 = $13 + 20 | 0;
    $51 = $50;
    HEAP32[$51 >> 2] = $49;
    $52 = $2 + 1348 | 0;
    $53 = HEAP8[$52] | 0;
    $54 = $13 + 24 | 0;
    HEAP8[$54] = $53;
    $55 = $2 + 1356 | 0;
    $56 = $55;
    $57 = HEAP32[$56 >> 2] | 0;
    $58 = $57 & 65535;
    $59 = $13 + 26 | 0;
    $60 = $59;
    HEAP16[$60 >> 1] = $58;
    $61 = $2 + 1360 | 0;
    $62 = $61;
    $63 = HEAP32[$62 >> 2] | 0;
    $64 = $63 & 65535;
    $65 = $13 + 28 | 0;
    $66 = $65;
    HEAP16[$66 >> 1] = $64;
    HEAP32[$7 >> 2] = $18;
    if ($4) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $67 = HEAP32[$7 >> 2] | 0;
    $68 = $afont_info;
    $69 = $67;
    _memcpy($68 | 0, $69 | 0, 32);
    label = 6;
    break;
   case 6:
    $70 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $70 | 0;
  }
  return 0;
}
function _ft_lzwstate_reset($state) {
  $state = $state | 0;
  HEAP32[$state + 4 >> 2] = 0;
  HEAP32[$state + 24 >> 2] = 0;
  HEAP32[$state + 28 >> 2] = 0;
  HEAP8[$state + 32 | 0] = 0;
  HEAP32[$state + 36 >> 2] = 0;
  HEAP32[$state + 92 >> 2] = 0;
  HEAP32[$state + 52 >> 2] = 9;
  HEAP32[$state >> 2] = 0;
  return;
}
function _FT_Stream_OpenGzip($stream, $source) {
  $stream = $stream | 0;
  $source = $source | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $17 = 0, $_c = 0, $19 = 0, $20 = 0, $21 = 0, $or_cond = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $source + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _ft_gzip_check_header($source) | 0;
    HEAP32[$error >> 2] = $3;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 13;
      break;
    }
   case 2:
    $6 = $stream;
    _memset($6 | 0, 0, 40);
    $7 = $stream + 28 | 0;
    HEAP32[$7 >> 2] = $2;
    $8 = _ft_mem_qalloc($2, 8276, $error) | 0;
    $9 = $8;
    $10 = HEAP32[$error >> 2] | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 3:
    $13 = _ft_gzip_file_init($9, $stream, $source) | 0;
    HEAP32[$error >> 2] = $13;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    _ft_mem_free($2, $8);
    label = 13;
    break;
   case 5:
    $17 = $stream + 12 | 0;
    $_c = $8;
    HEAP32[$17 >> 2] = $_c;
    label = 6;
    break;
   case 6:
    $19 = _ft_gzip_get_uncompressed_size($source) | 0;
    $20 = ($19 | 0) != 0;
    $21 = $19 >>> 0 < 40960;
    $or_cond = $20 & $21;
    if ($or_cond) {
      label = 7;
      break;
    } else {
      label = 12;
      break;
    }
   case 7:
    $23 = _ft_mem_alloc($2, $19, $error) | 0;
    $24 = HEAP32[$error >> 2] | 0;
    $25 = ($24 | 0) == 0;
    if ($25) {
      label = 8;
      break;
    } else {
      label = 11;
      break;
    }
   case 8:
    $27 = _ft_gzip_file_io($9, 0, $23, $19) | 0;
    $28 = ($27 | 0) == ($19 | 0);
    if ($28) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    _ft_gzip_file_done($9);
    _ft_mem_free($2, $8);
    $30 = $stream + 12 | 0;
    HEAP32[$30 >> 2] = 0;
    $31 = $stream + 4 | 0;
    HEAP32[$31 >> 2] = $19;
    $32 = $stream + 8 | 0;
    HEAP32[$32 >> 2] = 0;
    $33 = $stream | 0;
    HEAP32[$33 >> 2] = $23;
    $34 = $stream + 20 | 0;
    HEAP32[$34 >> 2] = 0;
    $35 = $stream + 24 | 0;
    HEAP32[$35 >> 2] = 488;
    label = 13;
    break;
   case 10:
    $37 = _ft_gzip_file_io($9, 0, 0, 0) | 0;
    _ft_mem_free($2, $23);
    label = 11;
    break;
   case 11:
    HEAP32[$error >> 2] = 0;
    label = 12;
    break;
   case 12:
    $40 = $stream + 4 | 0;
    HEAP32[$40 >> 2] = 2147483647;
    $41 = $stream + 8 | 0;
    HEAP32[$41 >> 2] = 0;
    $42 = $stream | 0;
    HEAP32[$42 >> 2] = 0;
    $43 = $stream + 20 | 0;
    HEAP32[$43 >> 2] = 582;
    $44 = $stream + 24 | 0;
    HEAP32[$44 >> 2] = 488;
    label = 13;
    break;
   case 13:
    $46 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $46 | 0;
  }
  return 0;
}
function _ft_gzip_check_header($stream) {
  $stream = $stream | 0;
  var $error = 0, $head = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $head = __stackBase__ + 4 | 0;
    $1 = _FT_Stream_Seek($stream, 0) | 0;
    HEAP32[$error >> 2] = $1;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      label = 19;
      break;
    }
   case 2:
    $4 = $head | 0;
    $5 = _FT_Stream_Read($stream, $4, 4) | 0;
    HEAP32[$error >> 2] = $5;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      label = 19;
      break;
    }
   case 3:
    $8 = HEAP8[$4] | 0;
    $9 = $8 << 24 >> 24 == 31;
    if ($9) {
      label = 4;
      break;
    } else {
      label = 7;
      break;
    }
   case 4:
    $11 = $head + 1 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $12 << 24 >> 24 == -117;
    if ($13) {
      label = 5;
      break;
    } else {
      label = 7;
      break;
    }
   case 5:
    $15 = $head + 2 | 0;
    $16 = HEAP8[$15] | 0;
    $17 = $16 << 24 >> 24 == 8;
    if ($17) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $19 = $head + 3 | 0;
    $20 = HEAP8[$19] | 0;
    $21 = ($20 & 255) > 31;
    if ($21) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    HEAP32[$error >> 2] = 3;
    label = 19;
    break;
   case 8:
    $24 = _FT_Stream_Skip($stream, 6) | 0;
    HEAP32[$error >> 2] = $24;
    $25 = HEAP8[$19] | 0;
    $26 = $25 & 4;
    $27 = $26 << 24 >> 24 == 0;
    if ($27) {
      label = 11;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $29 = _FT_Stream_ReadShortLE($stream, $error) | 0;
    $30 = HEAP32[$error >> 2] | 0;
    $31 = ($30 | 0) == 0;
    if ($31) {
      label = 10;
      break;
    } else {
      label = 19;
      break;
    }
   case 10:
    $33 = $29 & 65535;
    $34 = _FT_Stream_Skip($stream, $33) | 0;
    HEAP32[$error >> 2] = $34;
    $35 = ($34 | 0) == 0;
    if ($35) {
      label = 11;
      break;
    } else {
      label = 19;
      break;
    }
   case 11:
    $37 = HEAP8[$19] | 0;
    $38 = $37 & 8;
    $39 = $38 << 24 >> 24 == 0;
    if ($39) {
      label = 14;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $40 = _FT_Stream_ReadChar($stream, $error) | 0;
    $41 = HEAP32[$error >> 2] | 0;
    $42 = ($41 | 0) == 0;
    if ($42) {
      label = 13;
      break;
    } else {
      label = 19;
      break;
    }
   case 13:
    $44 = $40 << 24 >> 24 == 0;
    if ($44) {
      label = 14;
      break;
    } else {
      label = 12;
      break;
    }
   case 14:
    $45 = HEAP8[$19] | 0;
    $46 = $45 & 16;
    $47 = $46 << 24 >> 24 == 0;
    if ($47) {
      label = 17;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $48 = _FT_Stream_ReadChar($stream, $error) | 0;
    $49 = HEAP32[$error >> 2] | 0;
    $50 = ($49 | 0) == 0;
    if ($50) {
      label = 16;
      break;
    } else {
      label = 19;
      break;
    }
   case 16:
    $52 = $48 << 24 >> 24 == 0;
    if ($52) {
      label = 17;
      break;
    } else {
      label = 15;
      break;
    }
   case 17:
    $53 = HEAP8[$19] | 0;
    $54 = $53 & 2;
    $55 = $54 << 24 >> 24 == 0;
    if ($55) {
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $57 = _FT_Stream_Skip($stream, 2) | 0;
    HEAP32[$error >> 2] = $57;
    label = 19;
    break;
   case 19:
    $58 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $58 | 0;
  }
  return 0;
}
function _ft_gzip_file_init($zip, $stream, $source) {
  $zip = $zip | 0;
  $stream = $stream | 0;
  $source = $source | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $zip + 12 | 0;
    $2 = $zip + 4 | 0;
    HEAP32[$2 >> 2] = $stream;
    $3 = $zip | 0;
    HEAP32[$3 >> 2] = $source;
    $4 = $stream + 28 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $zip + 8 | 0;
    HEAP32[$6 >> 2] = $5;
    $7 = $zip + 8264 | 0;
    $8 = $zip + 8272 | 0;
    HEAP32[$8 >> 2] = $7;
    $9 = $zip + 8268 | 0;
    HEAP32[$9 >> 2] = $7;
    $10 = $zip + 8264 | 0;
    HEAP32[$10 >> 2] = 0;
    $11 = _ft_gzip_check_header($source) | 0;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 2;
      break;
    } else {
      $error_0 = $11;
      label = 5;
      break;
    }
   case 2:
    $14 = $zip + 4168 | 0;
    $15 = _FT_Stream_Pos($source) | 0;
    $16 = $zip + 68 | 0;
    HEAP32[$16 >> 2] = $15;
    $17 = $zip + 44 | 0;
    HEAP32[$17 >> 2] = 462;
    $18 = $zip + 48 | 0;
    HEAP32[$18 >> 2] = 566;
    $19 = $source + 28 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $20;
    $22 = $zip + 52 | 0;
    HEAP32[$22 >> 2] = $21;
    $23 = $zip + 16 | 0;
    HEAP32[$23 >> 2] = 0;
    $24 = $1 | 0;
    HEAP32[$24 >> 2] = $14;
    $25 = abort(3) | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $28 = HEAP32[$24 >> 2] | 0;
    $29 = ($28 | 0) == 0;
    if ($29) {
      label = 4;
      break;
    } else {
      $error_0 = $11;
      label = 5;
      break;
    }
   case 4:
    $error_0 = 3;
    label = 5;
    break;
   case 5:
    return $error_0 | 0;
  }
  return 0;
}
function _ft_gzip_get_uncompressed_size($stream) {
  $stream = $stream | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $_ = 0, $12 = 0, $result_1 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $stream + 8 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $stream + 4 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $4 - 4 | 0;
    $6 = _FT_Stream_Seek($stream, $5) | 0;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 2;
      break;
    } else {
      $result_1 = 0;
      label = 3;
      break;
    }
   case 2:
    $9 = _FT_Stream_ReadLong($stream, $error) | 0;
    $10 = HEAP32[$error >> 2] | 0;
    $11 = ($10 | 0) == 0;
    $_ = $11 ? $9 : 0;
    $12 = _FT_Stream_Seek($stream, $2) | 0;
    $result_1 = $_;
    label = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return $result_1 | 0;
  }
  return 0;
}
function _ft_gzip_file_io($zip, $pos, $buffer, $count) {
  $zip = $zip | 0;
  $pos = $pos | 0;
  $buffer = $buffer | 0;
  $count = $count | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $or_cond = 0, $_old = 0, $16 = 0, $17 = 0, $_030 = 0, $_0 = 0, $result_0 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $__0 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $result_1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $zip + 8264 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 >>> 0 > $pos >>> 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $5 = _ft_gzip_file_reset($zip) | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      $result_1 = 0;
      label = 9;
      break;
    }
   case 3:
    $8 = HEAP32[$1 >> 2] | 0;
    $9 = $8 >>> 0 < $pos >>> 0;
    if ($9) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $11 = $pos - $8 | 0;
    $12 = _ft_gzip_file_skip_output($zip, $11) | 0;
    $13 = ($12 | 0) != 0;
    $14 = ($count | 0) == 0;
    $or_cond = $13 | $14;
    if ($or_cond) {
      $result_1 = 0;
      label = 9;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $_old = ($count | 0) == 0;
    if ($_old) {
      $result_1 = 0;
      label = 9;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $16 = $zip + 8272 | 0;
    $17 = $zip + 8268 | 0;
    $result_0 = 0;
    $_0 = $count;
    $_030 = $buffer;
    label = 7;
    break;
   case 7:
    $19 = HEAP32[$16 >> 2] | 0;
    $20 = HEAP32[$17 >> 2] | 0;
    $21 = $19;
    $22 = $20;
    $23 = $21 - $22 | 0;
    $24 = $23 >>> 0 < $_0 >>> 0;
    $__0 = $24 ? $23 : $_0;
    _memcpy($_030 | 0, $20 | 0, $__0 | 0);
    $25 = $__0 + $result_0 | 0;
    $26 = HEAP32[$17 >> 2] | 0;
    $27 = $26 + $__0 | 0;
    HEAP32[$17 >> 2] = $27;
    $28 = HEAP32[$1 >> 2] | 0;
    $29 = $__0 + $28 | 0;
    HEAP32[$1 >> 2] = $29;
    $30 = ($_0 | 0) == ($__0 | 0);
    if ($30) {
      $result_1 = $25;
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $32 = $_0 - $__0 | 0;
    $33 = $_030 + $__0 | 0;
    $34 = _ft_gzip_file_fill_output($zip) | 0;
    $35 = ($34 | 0) == 0;
    if ($35) {
      $result_0 = $25;
      $_0 = $32;
      $_030 = $33;
      label = 7;
      break;
    } else {
      $result_1 = $25;
      label = 9;
      break;
    }
   case 9:
    return $result_1 | 0;
  }
  return 0;
}
function _ft_gzip_file_done($zip) {
  $zip = $zip | 0;
  abort(0);
  HEAP32[$zip + 44 >> 2] = 0;
  HEAP32[$zip + 48 >> 2] = 0;
  HEAP32[$zip + 52 >> 2] = 0;
  HEAP32[$zip + 24 >> 2] = 0;
  HEAP32[$zip + 28 >> 2] = 0;
  _memset($zip | 0, 0, 20);
  return;
}
function _ft_gzip_stream_close($stream) {
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $stream + 12 | 0;
    $2 = $1;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $stream + 28 | 0;
    $7 = $3;
    $8 = HEAP32[$6 >> 2] | 0;
    _ft_gzip_file_done($7);
    _ft_mem_free($8, $3);
    $9 = $1 | 0;
    HEAP32[$9 >> 2] = 0;
    label = 3;
    break;
   case 3:
    return;
  }
}
function _ft_gzip_stream_io($stream, $pos, $buffer, $count) {
  $stream = $stream | 0;
  $pos = $pos | 0;
  $buffer = $buffer | 0;
  $count = $count | 0;
  return _ft_gzip_file_io(HEAP32[$stream + 12 >> 2] | 0, $pos, $buffer, $count) | 0;
}
function _ft_gzip_file_reset($zip) {
  $zip = $zip | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $zip | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $zip + 68 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = _FT_Stream_Seek($2, $4) | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $8 = $zip + 12 | 0;
    $9 = abort(2) | 0;
    $10 = $zip + 16 | 0;
    HEAP32[$10 >> 2] = 0;
    $11 = $zip + 72 | 0;
    $12 = $8 | 0;
    HEAP32[$12 >> 2] = $11;
    $13 = $zip + 28 | 0;
    HEAP32[$13 >> 2] = 0;
    $14 = $zip + 4168 | 0;
    $15 = $zip + 24 | 0;
    HEAP32[$15 >> 2] = $14;
    $16 = $zip + 8264 | 0;
    $17 = $zip + 8272 | 0;
    HEAP32[$17 >> 2] = $16;
    $18 = $zip + 8268 | 0;
    HEAP32[$18 >> 2] = $16;
    $19 = $zip + 8264 | 0;
    HEAP32[$19 >> 2] = 0;
    label = 3;
    break;
   case 3:
    return $5 | 0;
  }
  return 0;
}
function _ft_gzip_file_skip_output($zip, $count) {
  $zip = $zip | 0;
  $count = $count | 0;
  var $1 = 0, $2 = 0, $3 = 0, $_0 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $__0 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $error_1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $zip + 8272 | 0;
    $2 = $zip + 8268 | 0;
    $3 = $zip + 8264 | 0;
    $_0 = $count;
    label = 2;
    break;
   case 2:
    $5 = HEAP32[$1 >> 2] | 0;
    $6 = HEAP32[$2 >> 2] | 0;
    $7 = $5;
    $8 = $6;
    $9 = $7 - $8 | 0;
    $10 = $9 >>> 0 < $_0 >>> 0;
    $__0 = $10 ? $9 : $_0;
    $11 = $6 + $__0 | 0;
    HEAP32[$2 >> 2] = $11;
    $12 = HEAP32[$3 >> 2] | 0;
    $13 = $__0 + $12 | 0;
    HEAP32[$3 >> 2] = $13;
    $14 = ($_0 | 0) == ($__0 | 0);
    if ($14) {
      $error_1 = 0;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $16 = $_0 - $__0 | 0;
    $17 = _ft_gzip_file_fill_output($zip) | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      $_0 = $16;
      label = 2;
      break;
    } else {
      $error_1 = $17;
      label = 4;
      break;
    }
   case 4:
    return $error_1 | 0;
  }
  return 0;
}
function _ft_gzip_file_fill_output($zip) {
  $zip = $zip | 0;
  var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_pr = 0, $phitmp = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $_error_1 = 0, $error_2 = 0, label = 0;
  label = 2;
  while (1) switch (label | 0) {
   case 2:
    $0 = $zip + 12 | 0;
    $1 = $zip + 4168 | 0;
    $2 = $zip + 8268 | 0;
    HEAP32[$2 >> 2] = $1;
    $3 = $zip + 24 | 0;
    HEAP32[$3 >> 2] = $1;
    $4 = $zip + 28 | 0;
    HEAP32[$4 >> 2] = 4096;
    $5 = $zip + 16 | 0;
    label = 4;
    break;
   case 3:
    $_pr = HEAP32[$4 >> 2] | 0;
    $phitmp = ($_pr | 0) == 0;
    if ($phitmp) {
      $error_2 = 0;
      label = 8;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $7 = HEAP32[$5 >> 2] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $10 = _ft_gzip_file_fill_input($zip) | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 6;
      break;
    } else {
      $error_2 = $10;
      label = 8;
      break;
    }
   case 6:
    $13 = abort(1) | 0;
    if (($13 | 0) == 0) {
      label = 3;
      break;
    } else if (($13 | 0) == 1) {
      label = 7;
      break;
    } else {
      $error_2 = 85;
      label = 8;
      break;
    }
   case 7:
    $15 = HEAP32[$3 >> 2] | 0;
    $16 = $zip + 8272 | 0;
    HEAP32[$16 >> 2] = $15;
    $17 = HEAP32[$2 >> 2] | 0;
    $18 = ($15 | 0) == ($17 | 0);
    $_error_1 = $18 ? 85 : 0;
    return $_error_1 | 0;
   case 8:
    return $error_2 | 0;
  }
  return 0;
}
function _ft_gzip_file_fill_input($zip) {
  $zip = $zip | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $_ = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $size_1 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $zip | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 + 20 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($4 | 0) == 0;
    if ($5) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $2 + 8 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $zip + 72 | 0;
    $10 = FUNCTION_TABLE_iiiii[$4 & 1023]($2, $8, $9, 4096) | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      $_0 = 85;
      label = 6;
      break;
    } else {
      $size_1 = $10;
      label = 5;
      break;
    }
   case 3:
    $13 = $2 + 4 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $2 + 8 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $14 - $16 | 0;
    $18 = $17 >>> 0 > 4096;
    $_ = $18 ? 4096 : $17;
    $19 = ($_ | 0) == 0;
    if ($19) {
      $_0 = 85;
      label = 6;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $21 = $zip + 72 | 0;
    $22 = $2 | 0;
    $23 = HEAP32[$22 >> 2] | 0;
    $24 = $23 + $16 | 0;
    _memcpy($21 | 0, $24 | 0, $_ | 0);
    $size_1 = $_;
    label = 5;
    break;
   case 5:
    $26 = $2 + 8 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $27 + $size_1 | 0;
    HEAP32[$26 >> 2] = $28;
    $29 = $zip + 72 | 0;
    $30 = $zip + 12 | 0;
    HEAP32[$30 >> 2] = $29;
    $31 = $zip + 16 | 0;
    HEAP32[$31 >> 2] = $size_1;
    $_0 = 0;
    label = 6;
    break;
   case 6:
    return $_0 | 0;
  }
  return 0;
}
function _ft_gzip_alloc($memory, $items, $size) {
  $memory = $memory | 0;
  $items = $items | 0;
  $size = $size | 0;
  var $2 = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  $2 = _ft_mem_alloc($memory, Math_imul($size, $items), __stackBase__ | 0) | 0;
  STACKTOP = __stackBase__;
  return $2 | 0;
}
function _ft_gzip_free($memory, $address) {
  $memory = $memory | 0;
  $address = $address | 0;
  _ft_mem_free($memory, $address);
  return;
}
function _FT_Stream_OpenLZW($stream, $source) {
  $stream = $stream | 0;
  $source = $source | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $17 = 0, $_c = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $source + 28 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _ft_lzw_check_header($source) | 0;
    HEAP32[$error >> 2] = $3;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 7;
      break;
    }
   case 2:
    $6 = $stream;
    _memset($6 | 0, 0, 40);
    $7 = $stream + 28 | 0;
    HEAP32[$7 >> 2] = $2;
    $8 = _ft_mem_alloc($2, 4292, $error) | 0;
    $9 = HEAP32[$error >> 2] | 0;
    $10 = ($9 | 0) == 0;
    if ($10) {
      label = 3;
      break;
    } else {
      label = 6;
      break;
    }
   case 3:
    $12 = $8;
    $13 = _ft_lzw_file_init($12, $stream, $source) | 0;
    HEAP32[$error >> 2] = $13;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    _ft_mem_free($2, $8);
    label = 7;
    break;
   case 5:
    $17 = $stream + 12 | 0;
    $_c = $8;
    HEAP32[$17 >> 2] = $_c;
    label = 6;
    break;
   case 6:
    $19 = $stream + 4 | 0;
    HEAP32[$19 >> 2] = 2147483647;
    $20 = $stream + 8 | 0;
    HEAP32[$20 >> 2] = 0;
    $21 = $stream | 0;
    HEAP32[$21 >> 2] = 0;
    $22 = $stream + 20 | 0;
    HEAP32[$22 >> 2] = 784;
    $23 = $stream + 24 | 0;
    HEAP32[$23 >> 2] = 846;
    label = 7;
    break;
   case 7:
    $25 = HEAP32[$error >> 2] | 0;
    STACKTOP = __stackBase__;
    return $25 | 0;
  }
  return 0;
}
function _ft_lzw_check_header($stream) {
  $stream = $stream | 0;
  var $head = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $error_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $head = __stackBase__ | 0;
    $1 = _FT_Stream_Seek($stream, 0) | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      $error_0 = $1;
      label = 6;
      break;
    }
   case 2:
    $4 = $head | 0;
    $5 = _FT_Stream_Read($stream, $4, 2) | 0;
    $6 = ($5 | 0) == 0;
    if ($6) {
      label = 3;
      break;
    } else {
      $error_0 = $5;
      label = 6;
      break;
    }
   case 3:
    $8 = HEAP8[$4] | 0;
    $9 = $8 << 24 >> 24 == 31;
    if ($9) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $11 = $head + 1 | 0;
    $12 = HEAP8[$11] | 0;
    $13 = $12 << 24 >> 24 == -99;
    if ($13) {
      $error_0 = $5;
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $error_0 = 3;
    label = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return $error_0 | 0;
  }
  return 0;
}
function _ft_lzw_file_init($zip, $stream, $source) {
  $zip = $zip | 0;
  $stream = $stream | 0;
  $source = $source | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $zip + 4 | 0;
    HEAP32[$1 >> 2] = $stream;
    $2 = $zip | 0;
    HEAP32[$2 >> 2] = $source;
    $3 = $stream + 28 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $zip + 8 | 0;
    HEAP32[$5 >> 2] = $4;
    $6 = $zip + 4280 | 0;
    $7 = $zip + 4288 | 0;
    HEAP32[$7 >> 2] = $6;
    $8 = $zip + 4284 | 0;
    HEAP32[$8 >> 2] = $6;
    $9 = $zip + 4280 | 0;
    HEAP32[$9 >> 2] = 0;
    $10 = _ft_lzw_check_header($source) | 0;
    $11 = ($10 | 0) == 0;
    if ($11) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $13 = $zip + 12 | 0;
    _ft_lzwstate_init($13, $source);
    label = 3;
    break;
   case 3:
    return $10 | 0;
  }
  return 0;
}
function _ft_lzw_stream_io($stream, $pos, $buffer, $count) {
  $stream = $stream | 0;
  $pos = $pos | 0;
  $buffer = $buffer | 0;
  $count = $count | 0;
  return _ft_lzw_file_io(HEAP32[$stream + 12 >> 2] | 0, $pos, $buffer, $count) | 0;
}
function _ft_lzw_stream_close($stream) {
  $stream = $stream | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $stream + 12 | 0;
    $2 = $1;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $stream + 28 | 0;
    $7 = $3;
    $8 = HEAP32[$6 >> 2] | 0;
    _ft_lzw_file_done($7);
    _ft_mem_free($8, $3);
    $9 = $1 | 0;
    HEAP32[$9 >> 2] = 0;
    label = 3;
    break;
   case 3:
    return;
  }
}
function _ft_lzwstate_init($state, $source) {
  $state = $state | 0;
  $source = $source | 0;
  _memset($state | 0, 0, 172);
  HEAP32[$state + 164 >> 2] = $source;
  HEAP32[$state + 168 >> 2] = HEAP32[$source + 28 >> 2] | 0;
  HEAP32[$state + 76 >> 2] = 0;
  HEAP32[$state + 80 >> 2] = 0;
  HEAP32[$state + 84 >> 2] = 0;
  HEAP32[$state + 88 >> 2] = $state + 100 | 0;
  HEAP32[$state + 96 >> 2] = 64;
  _ft_lzwstate_reset($state);
  return;
}
function _ft_lzwstate_done($state) {
  $state = $state | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $state + 168 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    _ft_lzwstate_reset($state);
    $3 = $state + 88 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $state + 100 | 0;
    $6 = ($4 | 0) == ($5 | 0);
    if ($6) {
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    _ft_mem_free($2, $4);
    HEAP32[$3 >> 2] = 0;
    label = 3;
    break;
   case 3:
    $9 = $state + 76 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10;
    _ft_mem_free($2, $11);
    $12 = $state;
    _memset($12 | 0, 0, 172);
    return;
  }
}
function _ft_lzwstate_io($state, $buffer, $out_size) {
  $state = $state | 0;
  $buffer = $buffer | 0;
  $out_size = $out_size | 0;
  var $max_bits = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $56 = 0, $58 = 0, $60 = 0, $old_char_0 = 0, $old_code_0 = 0, $in_code_0 = 0, $result_0 = 0, $63 = 0, $64 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $code_0 = 0, $77 = 0, $code_092 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $89 = 0, $90 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $code_1_ph = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $_pr = 0, $105 = 0, $code_199 = 0, $106 = 0, $108 = 0, $109 = 0, $110 = 0, $112 = 0, $113 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $code_093 = 0, $code_2 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $134 = 0, $135 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $old_char_1_ph = 0, $old_code_1_ph = 0, $in_code_1_ph = 0, $result_1_ph = 0, $143 = 0, $144 = 0, $145 = 0, $result_1 = 0, $147 = 0, $148 = 0, $150 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $157 = 0, $158 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $166 = 0, $167 = 0, $168 = 0, $170 = 0, $171 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $old_char_2 = 0, $old_code_2 = 0, $in_code_2 = 0, $result_2 = 0, $old_char_3 = 0, $old_code_3 = 0, $in_code_3 = 0, $result_3 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $max_bits = __stackBase__ | 0;
    $1 = $state + 68 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $state + 64 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $state + 72 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = ($out_size | 0) == 0;
    if ($7) {
      $result_2 = 0;
      $in_code_2 = $6;
      $old_code_2 = $4;
      $old_char_2 = $2;
      label = 42;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $9 = $state | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    if (($10 | 0) == 0) {
      label = 3;
      break;
    } else if (($10 | 0) == 1) {
      $result_0 = 0;
      $in_code_0 = $6;
      $old_code_0 = $4;
      $old_char_0 = $2;
      label = 14;
      break;
    } else if (($10 | 0) == 2) {
      $result_1_ph = 0;
      $in_code_1_ph = $6;
      $old_code_1_ph = $4;
      $old_char_1_ph = $2;
      label = 32;
      break;
    } else {
      $result_2 = 0;
      $in_code_2 = $6;
      $old_code_2 = $4;
      $old_char_2 = $2;
      label = 42;
      break;
    }
   case 3:
    $12 = $state + 164 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = _FT_Stream_Seek($13, 2) | 0;
    $15 = ($14 | 0) == 0;
    if ($15) {
      label = 4;
      break;
    } else {
      $result_3 = 0;
      $in_code_3 = $6;
      $old_code_3 = $4;
      $old_char_3 = $2;
      label = 43;
      break;
    }
   case 4:
    $17 = HEAP32[$12 >> 2] | 0;
    $18 = _FT_Stream_TryRead($17, $max_bits, 1) | 0;
    $19 = ($18 | 0) == 1;
    if ($19) {
      label = 5;
      break;
    } else {
      $result_3 = 0;
      $in_code_3 = $6;
      $old_code_3 = $4;
      $old_char_3 = $2;
      label = 43;
      break;
    }
   case 5:
    $21 = HEAP8[$max_bits] | 0;
    $22 = $21 & 255;
    $23 = $22 & 31;
    $24 = $state + 40 | 0;
    HEAP32[$24 >> 2] = $23;
    $25 = HEAP8[$max_bits] | 0;
    $26 = $25 & 255;
    $27 = $26 & 128;
    $28 = $state + 44 | 0;
    HEAP32[$28 >> 2] = $27;
    $29 = HEAP32[$24 >> 2] | 0;
    $30 = 1 << $29;
    $31 = $30 - 256 | 0;
    $32 = $state + 48 | 0;
    HEAP32[$32 >> 2] = $31;
    $33 = HEAP32[$24 >> 2] | 0;
    $34 = $33 >>> 0 > 16;
    if ($34) {
      $result_3 = 0;
      $in_code_3 = $6;
      $old_code_3 = $4;
      $old_char_3 = $2;
      label = 43;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $36 = $state + 52 | 0;
    HEAP32[$36 >> 2] = 9;
    $37 = HEAP32[$28 >> 2] | 0;
    $38 = ($37 | 0) != 0;
    $39 = $38 & 1;
    $40 = $state + 56 | 0;
    HEAP32[$40 >> 2] = $39;
    $41 = HEAP32[$36 >> 2] | 0;
    $42 = HEAP32[$24 >> 2] | 0;
    $43 = $41 >>> 0 < $42 >>> 0;
    if ($43) {
      label = 7;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $45 = 1 << $41;
    $46 = $45 - 256 | 0;
    $51 = $46;
    label = 9;
    break;
   case 8:
    $48 = HEAP32[$32 >> 2] | 0;
    $49 = $48 + 1 | 0;
    $51 = $49;
    label = 9;
    break;
   case 9:
    $52 = $state + 60 | 0;
    HEAP32[$52 >> 2] = $51;
    $53 = _ft_lzwstate_get_code($state) | 0;
    $54 = ($53 | 0) < 0;
    if ($54) {
      $result_3 = 0;
      $in_code_3 = 0;
      $old_code_3 = $4;
      $old_char_3 = $2;
      label = 43;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $56 = ($buffer | 0) == 0;
    if ($56) {
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $58 = $53 & 255;
    HEAP8[$buffer] = $58;
    label = 12;
    break;
   case 12:
    $60 = $out_size >>> 0 < 2;
    if ($60) {
      $result_2 = 1;
      $in_code_2 = 0;
      $old_code_2 = $53;
      $old_char_2 = $53;
      label = 42;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    HEAP32[$9 >> 2] = 1;
    $result_0 = 1;
    $in_code_0 = 0;
    $old_code_0 = $53;
    $old_char_0 = $53;
    label = 14;
    break;
   case 14:
    $63 = _ft_lzwstate_get_code($state) | 0;
    $64 = ($63 | 0) < 0;
    if ($64) {
      $result_3 = $result_0;
      $in_code_3 = $in_code_0;
      $old_code_3 = $old_code_0;
      $old_char_3 = $old_char_0;
      label = 43;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $66 = ($63 | 0) == 256;
    if ($66) {
      label = 16;
      break;
    } else {
      $code_0 = $63;
      label = 18;
      break;
    }
   case 16:
    $68 = $state + 44 | 0;
    $69 = HEAP32[$68 >> 2] | 0;
    $70 = ($69 | 0) == 0;
    if ($70) {
      $code_092 = 256;
      label = 19;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $72 = $state + 56 | 0;
    HEAP32[$72 >> 2] = 0;
    $73 = $state + 32 | 0;
    HEAP8[$73] = 1;
    $74 = _ft_lzwstate_get_code($state) | 0;
    $75 = ($74 | 0) < 0;
    if ($75) {
      $result_3 = $result_0;
      $in_code_3 = $in_code_0;
      $old_code_3 = $old_code_0;
      $old_char_3 = $old_char_0;
      label = 43;
      break;
    } else {
      $code_0 = $74;
      label = 18;
      break;
    }
   case 18:
    $77 = $code_0 >>> 0 > 255;
    if ($77) {
      $code_092 = $code_0;
      label = 19;
      break;
    } else {
      $code_2 = $code_0;
      $code_093 = $code_0;
      label = 29;
      break;
    }
   case 19:
    $78 = $code_092 - 256 | 0;
    $79 = $state + 56 | 0;
    $80 = HEAP32[$79 >> 2] | 0;
    $81 = $78 >>> 0 < $80 >>> 0;
    if ($81) {
      $code_1_ph = $code_092;
      label = 23;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $83 = $state + 92 | 0;
    $84 = HEAP32[$83 >> 2] | 0;
    $85 = $state + 96 | 0;
    $86 = HEAP32[$85 >> 2] | 0;
    $87 = $84 >>> 0 < $86 >>> 0;
    if ($87) {
      label = 22;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $89 = _ft_lzwstate_stack_grow($state) | 0;
    $90 = ($89 | 0) < 0;
    if ($90) {
      $result_3 = $result_0;
      $in_code_3 = $code_092;
      $old_code_3 = $old_code_0;
      $old_char_3 = $old_char_0;
      label = 43;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $92 = $old_char_0 & 255;
    $93 = HEAP32[$83 >> 2] | 0;
    $94 = $93 + 1 | 0;
    HEAP32[$83 >> 2] = $94;
    $95 = $state + 88 | 0;
    $96 = HEAP32[$95 >> 2] | 0;
    $97 = $96 + $93 | 0;
    HEAP8[$97] = $92;
    $code_1_ph = $old_code_0;
    label = 23;
    break;
   case 23:
    $98 = $code_1_ph >>> 0 > 255;
    if ($98) {
      label = 24;
      break;
    } else {
      $code_2 = $code_1_ph;
      $code_093 = $code_092;
      label = 29;
      break;
    }
   case 24:
    $99 = $state + 76 | 0;
    $100 = $state + 92 | 0;
    $101 = $state + 96 | 0;
    $102 = $state + 80 | 0;
    $103 = $state + 88 | 0;
    $_pr = HEAP32[$99 >> 2] | 0;
    $code_199 = $code_1_ph;
    $105 = $_pr;
    label = 25;
    break;
   case 25:
    $106 = ($105 | 0) == 0;
    if ($106) {
      $result_3 = $result_0;
      $in_code_3 = $code_092;
      $old_code_3 = $old_code_0;
      $old_char_3 = $old_char_0;
      label = 43;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $108 = HEAP32[$100 >> 2] | 0;
    $109 = HEAP32[$101 >> 2] | 0;
    $110 = $108 >>> 0 < $109 >>> 0;
    if ($110) {
      label = 28;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $112 = _ft_lzwstate_stack_grow($state) | 0;
    $113 = ($112 | 0) < 0;
    if ($113) {
      $result_3 = $result_0;
      $in_code_3 = $code_092;
      $old_code_3 = $old_code_0;
      $old_char_3 = $old_char_0;
      label = 43;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $115 = $code_199 - 256 | 0;
    $116 = HEAP32[$102 >> 2] | 0;
    $117 = $116 + $115 | 0;
    $118 = HEAP8[$117] | 0;
    $119 = HEAP32[$100 >> 2] | 0;
    $120 = $119 + 1 | 0;
    HEAP32[$100 >> 2] = $120;
    $121 = HEAP32[$103 >> 2] | 0;
    $122 = $121 + $119 | 0;
    HEAP8[$122] = $118;
    $123 = HEAP32[$99 >> 2] | 0;
    $124 = $123 + ($115 << 1) | 0;
    $125 = HEAP16[$124 >> 1] | 0;
    $126 = $125 & 65535;
    $127 = ($125 & 65535) > 255;
    if ($127) {
      $code_199 = $126;
      $105 = $123;
      label = 25;
      break;
    } else {
      $code_2 = $126;
      $code_093 = $code_092;
      label = 29;
      break;
    }
   case 29:
    $128 = $state + 92 | 0;
    $129 = HEAP32[$128 >> 2] | 0;
    $130 = $state + 96 | 0;
    $131 = HEAP32[$130 >> 2] | 0;
    $132 = $129 >>> 0 < $131 >>> 0;
    if ($132) {
      label = 31;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    $134 = _ft_lzwstate_stack_grow($state) | 0;
    $135 = ($134 | 0) < 0;
    if ($135) {
      $result_3 = $result_0;
      $in_code_3 = $code_093;
      $old_code_3 = $old_code_0;
      $old_char_3 = $code_2;
      label = 43;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    $137 = $code_2 & 255;
    $138 = HEAP32[$128 >> 2] | 0;
    $139 = $138 + 1 | 0;
    HEAP32[$128 >> 2] = $139;
    $140 = $state + 88 | 0;
    $141 = HEAP32[$140 >> 2] | 0;
    $142 = $141 + $138 | 0;
    HEAP8[$142] = $137;
    HEAP32[$9 >> 2] = 2;
    $result_1_ph = $result_0;
    $in_code_1_ph = $code_093;
    $old_code_1_ph = $old_code_0;
    $old_char_1_ph = $code_2;
    label = 32;
    break;
   case 32:
    $143 = $state + 92 | 0;
    $144 = ($buffer | 0) == 0;
    $145 = $state + 88 | 0;
    $result_1 = $result_1_ph;
    label = 33;
    break;
   case 33:
    $147 = HEAP32[$143 >> 2] | 0;
    $148 = ($147 | 0) == 0;
    if ($148) {
      label = 37;
      break;
    } else {
      label = 34;
      break;
    }
   case 34:
    $150 = $147 - 1 | 0;
    HEAP32[$143 >> 2] = $150;
    if ($144) {
      label = 36;
      break;
    } else {
      label = 35;
      break;
    }
   case 35:
    $152 = HEAP32[$145 >> 2] | 0;
    $153 = $152 + $150 | 0;
    $154 = HEAP8[$153] | 0;
    $155 = $buffer + $result_1 | 0;
    HEAP8[$155] = $154;
    label = 36;
    break;
   case 36:
    $157 = $result_1 + 1 | 0;
    $158 = ($157 | 0) == ($out_size | 0);
    if ($158) {
      $result_2 = $157;
      $in_code_2 = $in_code_1_ph;
      $old_code_2 = $old_code_1_ph;
      $old_char_2 = $old_char_1_ph;
      label = 42;
      break;
    } else {
      $result_1 = $157;
      label = 33;
      break;
    }
   case 37:
    $160 = $state + 56 | 0;
    $161 = HEAP32[$160 >> 2] | 0;
    $162 = $state + 48 | 0;
    $163 = HEAP32[$162 >> 2] | 0;
    $164 = $161 >>> 0 < $163 >>> 0;
    if ($164) {
      label = 38;
      break;
    } else {
      label = 41;
      break;
    }
   case 38:
    $166 = $state + 84 | 0;
    $167 = HEAP32[$166 >> 2] | 0;
    $168 = $161 >>> 0 < $167 >>> 0;
    if ($168) {
      label = 40;
      break;
    } else {
      label = 39;
      break;
    }
   case 39:
    $170 = _ft_lzwstate_prefix_grow($state) | 0;
    $171 = ($170 | 0) < 0;
    if ($171) {
      $result_3 = $result_1;
      $in_code_3 = $in_code_1_ph;
      $old_code_3 = $old_code_1_ph;
      $old_char_3 = $old_char_1_ph;
      label = 43;
      break;
    } else {
      label = 40;
      break;
    }
   case 40:
    $173 = $old_code_1_ph & 65535;
    $174 = HEAP32[$160 >> 2] | 0;
    $175 = $state + 76 | 0;
    $176 = HEAP32[$175 >> 2] | 0;
    $177 = $176 + ($174 << 1) | 0;
    HEAP16[$177 >> 1] = $173;
    $178 = $old_char_1_ph & 255;
    $179 = HEAP32[$160 >> 2] | 0;
    $180 = $state + 80 | 0;
    $181 = HEAP32[$180 >> 2] | 0;
    $182 = $181 + $179 | 0;
    HEAP8[$182] = $178;
    $183 = HEAP32[$160 >> 2] | 0;
    $184 = $183 + 1 | 0;
    HEAP32[$160 >> 2] = $184;
    label = 41;
    break;
   case 41:
    HEAP32[$9 >> 2] = 1;
    $result_0 = $result_1;
    $in_code_0 = $in_code_1_ph;
    $old_code_0 = $in_code_1_ph;
    $old_char_0 = $old_char_1_ph;
    label = 14;
    break;
   case 42:
    HEAP32[$3 >> 2] = $old_code_2;
    HEAP32[$1 >> 2] = $old_char_2;
    HEAP32[$5 >> 2] = $in_code_2;
    STACKTOP = __stackBase__;
    return $result_2 | 0;
   case 43:
    HEAP32[$9 >> 2] = 3;
    $result_2 = $result_3;
    $in_code_2 = $in_code_3;
    $old_code_2 = $old_code_3;
    $old_char_2 = $old_char_3;
    label = 42;
    break;
  }
  return 0;
}
function _ft_lzwstate_get_code($state) {
  $state = $state | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $30 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $num_bits_0 = 0, $39 = 0, $40 = 0, $num_bits_1 = 0, $43 = 0, $44 = 0, $num_bits_2 = 0, $offset_0 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $_sum = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $_sum42 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $num_bits_3 = 0, $offset_1 = 0, $p_0 = 0, $result_0 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $state + 52 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $state + 24 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $state + 32 | 0;
    $6 = HEAP8[$5] | 0;
    $7 = $6 << 24 >> 24 == 0;
    if ($7) {
      label = 2;
      break;
    } else {
      label = 4;
      break;
    }
   case 2:
    $9 = $state + 28 | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = ($4 | 0) < ($10 | 0);
    if ($11) {
      label = 3;
      break;
    } else {
      label = 4;
      break;
    }
   case 3:
    $13 = $state + 56 | 0;
    $14 = HEAP32[$13 >> 2] | 0;
    $15 = $state + 60 | 0;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $14 >>> 0 < $16 >>> 0;
    if ($17) {
      $offset_0 = $4;
      $num_bits_2 = $2;
      label = 12;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $19 = $state + 56 | 0;
    $20 = HEAP32[$19 >> 2] | 0;
    $21 = $state + 60 | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $20 >>> 0 < $22 >>> 0;
    if ($23) {
      $num_bits_0 = $2;
      label = 9;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $25 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $25;
    $26 = $state + 40 | 0;
    $27 = HEAP32[$26 >> 2] | 0;
    $28 = $25 >>> 0 < $27 >>> 0;
    if ($28) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $30 = 1 << $25;
    $31 = $30 - 256 | 0;
    $37 = $31;
    label = 8;
    break;
   case 7:
    $33 = $state + 48 | 0;
    $34 = HEAP32[$33 >> 2] | 0;
    $35 = $34 + 1 | 0;
    $37 = $35;
    label = 8;
    break;
   case 8:
    HEAP32[$21 >> 2] = $37;
    $num_bits_0 = $25;
    label = 9;
    break;
   case 9:
    $39 = HEAP8[$5] | 0;
    $40 = $39 << 24 >> 24 == 0;
    if ($40) {
      $num_bits_1 = $num_bits_0;
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    HEAP32[$1 >> 2] = 9;
    HEAP32[$21 >> 2] = 256;
    HEAP8[$5] = 0;
    $num_bits_1 = 9;
    label = 11;
    break;
   case 11:
    $43 = _ft_lzwstate_refill($state) | 0;
    $44 = ($43 | 0) < 0;
    if ($44) {
      $_0 = -1;
      label = 16;
      break;
    } else {
      $offset_0 = 0;
      $num_bits_2 = $num_bits_1;
      label = 12;
      break;
    }
   case 12:
    $46 = $offset_0 + $num_bits_2 | 0;
    HEAP32[$3 >> 2] = $46;
    $47 = $offset_0 >> 3;
    $48 = $47 + ($state + 8) | 0;
    $49 = $offset_0 & 7;
    $_sum = $47 + 1 | 0;
    $50 = $_sum + ($state + 8) | 0;
    $51 = HEAP8[$48] | 0;
    $52 = $51 & 255;
    $53 = $52 >>> ($49 >>> 0);
    $54 = 8 - $49 | 0;
    $55 = $num_bits_2 - $54 | 0;
    $56 = $55 >>> 0 > 7;
    if ($56) {
      label = 13;
      break;
    } else {
      $result_0 = $53;
      $p_0 = $50;
      $offset_1 = $54;
      $num_bits_3 = $55;
      label = 14;
      break;
    }
   case 13:
    $_sum42 = $47 + 2 | 0;
    $58 = $_sum42 + ($state + 8) | 0;
    $59 = HEAP8[$50] | 0;
    $60 = $59 & 255;
    $61 = $60 << $54;
    $62 = $61 | $53;
    $63 = $54 + 8 | 0;
    $64 = $55 - 8 | 0;
    $result_0 = $62;
    $p_0 = $58;
    $offset_1 = $63;
    $num_bits_3 = $64;
    label = 14;
    break;
   case 14:
    $66 = ($num_bits_3 | 0) == 0;
    if ($66) {
      $_0 = $result_0;
      label = 16;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $68 = HEAP8[$p_0] | 0;
    $69 = $68 & 255;
    $70 = 1 << $num_bits_3;
    $71 = $70 - 1 | 0;
    $72 = $69 & $71;
    $73 = $72 << $offset_1;
    $74 = $73 | $result_0;
    $_0 = $74;
    label = 16;
    break;
   case 16:
    return $_0 | 0;
  }
  return 0;
}
function _ft_lzwstate_stack_grow($state) {
  $state = $state | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $old_size_0 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $state + 92 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $state + 96 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2 >>> 0 < $4 >>> 0;
    if ($5) {
      $_0 = 0;
      label = 6;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $state + 168 | 0;
    $8 = HEAP32[$7 >> 2] | 0;
    $9 = $4 >>> 1;
    $10 = $4 + 4 | 0;
    $11 = $10 + $9 | 0;
    $12 = $state + 88 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $state + 100 | 0;
    $15 = ($13 | 0) == ($14 | 0);
    if ($15) {
      label = 3;
      break;
    } else {
      $old_size_0 = $4;
      label = 4;
      break;
    }
   case 3:
    HEAP32[$12 >> 2] = 0;
    $old_size_0 = 0;
    label = 4;
    break;
   case 4:
    $18 = HEAP32[$12 >> 2] | 0;
    $19 = _ft_mem_realloc($8, 1, $old_size_0, $11, $18, $error) | 0;
    HEAP32[$12 >> 2] = $19;
    $20 = HEAP32[$error >> 2] | 0;
    $21 = ($20 | 0) == 0;
    if ($21) {
      label = 5;
      break;
    } else {
      $_0 = -1;
      label = 6;
      break;
    }
   case 5:
    HEAP32[$3 >> 2] = $11;
    $_0 = 0;
    label = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _ft_lzwstate_prefix_grow($state) {
  $state = $state | 0;
  var $error = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $new_size_0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $_0 = 0, label = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 4 | 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $error = __stackBase__ | 0;
    $1 = $state + 84 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $state + 168 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = ($2 | 0) == 0;
    if ($5) {
      $new_size_0 = 512;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = $2 >>> 2;
    $8 = $7 + $2 | 0;
    $new_size_0 = $8;
    label = 3;
    break;
   case 3:
    $10 = $state + 76 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $11;
    $13 = _ft_mem_realloc($4, 3, $2, $new_size_0, $12, $error) | 0;
    $14 = $13;
    HEAP32[$10 >> 2] = $14;
    $15 = HEAP32[$error >> 2] | 0;
    $16 = ($15 | 0) == 0;
    if ($16) {
      label = 4;
      break;
    } else {
      $_0 = -1;
      label = 5;
      break;
    }
   case 4:
    $18 = $14 + ($new_size_0 << 1) | 0;
    $19 = $18;
    $20 = $state + 80 | 0;
    HEAP32[$20 >> 2] = $19;
    $21 = HEAP32[$10 >> 2] | 0;
    $22 = $21 + ($2 << 1) | 0;
    $23 = $22;
    _memmove($19 | 0, $23 | 0, $2 | 0);
    HEAP32[$1 >> 2] = $new_size_0;
    $_0 = 0;
    label = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return $_0 | 0;
  }
  return 0;
}
function _ft_lzwstate_refill($state) {
  $state = $state | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $_neg16 = 0, $22 = 0, $23 = 0, $_ = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $state + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = ($2 | 0) == 0;
    if ($3) {
      label = 2;
      break;
    } else {
      $_0 = -1;
      label = 3;
      break;
    }
   case 2:
    $5 = $state + 164 | 0;
    $6 = HEAP32[$5 >> 2] | 0;
    $7 = $state + 8 | 0;
    $8 = $state + 52 | 0;
    $9 = HEAP32[$8 >> 2] | 0;
    $10 = _FT_Stream_TryRead($6, $7, $9) | 0;
    $11 = $state + 28 | 0;
    HEAP32[$11 >> 2] = $10;
    $12 = $state + 36 | 0;
    $13 = HEAP32[$12 >> 2] | 0;
    $14 = $13 + $10 | 0;
    HEAP32[$12 >> 2] = $14;
    $15 = HEAP32[$8 >> 2] | 0;
    $16 = $10 >>> 0 < $15 >>> 0;
    $17 = $16 & 1;
    HEAP32[$1 >> 2] = $17;
    $18 = $state + 24 | 0;
    HEAP32[$18 >> 2] = 0;
    $19 = HEAP32[$11 >> 2] | 0;
    $20 = $19 << 3;
    $21 = HEAP32[$8 >> 2] | 0;
    $_neg16 = 1 - $21 | 0;
    $22 = $_neg16 + $20 | 0;
    HEAP32[$11 >> 2] = $22;
    $23 = ($10 | 0) == 0;
    $_ = $23 << 31 >> 31;
    $_0 = $_;
    label = 3;
    break;
   case 3:
    return $_0 | 0;
  }
  return 0;
}
function _ft_lzw_file_done($zip) {
  $zip = $zip | 0;
  _ft_lzwstate_done($zip + 12 | 0);
  HEAP32[$zip + 8 >> 2] = 0;
  HEAP32[$zip >> 2] = 0;
  HEAP32[$zip + 4 >> 2] = 0;
  return;
}
function _ft_lzw_file_io($zip, $pos, $buffer, $count) {
  $zip = $zip | 0;
  $pos = $pos | 0;
  $buffer = $buffer | 0;
  $count = $count | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $or_cond = 0, $_old = 0, $28 = 0, $29 = 0, $_0 = 0, $result_0 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $__0 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $result_1 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $zip + 4280 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 >>> 0 > $pos >>> 0;
    if ($3) {
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 2:
    $5 = $2 - $pos | 0;
    $6 = $zip + 4284 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $zip + 184 | 0;
    $9 = $7;
    $10 = $8;
    $11 = $9 - $10 | 0;
    $12 = $5 >>> 0 > $11 >>> 0;
    if ($12) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $14 = -$5 | 0;
    $15 = $7 + $14 | 0;
    HEAP32[$6 >> 2] = $15;
    HEAP32[$1 >> 2] = $pos;
    label = 5;
    break;
   case 4:
    $17 = _ft_lzw_file_reset($zip) | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 5;
      break;
    } else {
      $result_1 = 0;
      label = 11;
      break;
    }
   case 5:
    $20 = HEAP32[$1 >> 2] | 0;
    $21 = $20 >>> 0 < $pos >>> 0;
    if ($21) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $23 = $pos - $20 | 0;
    $24 = _ft_lzw_file_skip_output($zip, $23) | 0;
    $25 = ($24 | 0) != 0;
    $26 = ($count | 0) == 0;
    $or_cond = $25 | $26;
    if ($or_cond) {
      $result_1 = 0;
      label = 11;
      break;
    } else {
      label = 8;
      break;
    }
   case 7:
    $_old = ($count | 0) == 0;
    if ($_old) {
      $result_1 = 0;
      label = 11;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $28 = $zip + 4288 | 0;
    $29 = $zip + 4284 | 0;
    $result_0 = 0;
    $_0 = $count;
    label = 9;
    break;
   case 9:
    $31 = HEAP32[$28 >> 2] | 0;
    $32 = HEAP32[$29 >> 2] | 0;
    $33 = $31;
    $34 = $32;
    $35 = $33 - $34 | 0;
    $36 = $35 >>> 0 < $_0 >>> 0;
    $__0 = $36 ? $35 : $_0;
    $37 = $buffer + $result_0 | 0;
    _memcpy($37 | 0, $32 | 0, $__0 | 0);
    $38 = $__0 + $result_0 | 0;
    $39 = HEAP32[$29 >> 2] | 0;
    $40 = $39 + $__0 | 0;
    HEAP32[$29 >> 2] = $40;
    $41 = HEAP32[$1 >> 2] | 0;
    $42 = $__0 + $41 | 0;
    HEAP32[$1 >> 2] = $42;
    $43 = ($_0 | 0) == ($__0 | 0);
    if ($43) {
      $result_1 = $38;
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $45 = $_0 - $__0 | 0;
    $46 = _ft_lzw_file_fill_output($zip) | 0;
    $47 = ($46 | 0) == 0;
    if ($47) {
      $result_0 = $38;
      $_0 = $45;
      label = 9;
      break;
    } else {
      $result_1 = $38;
      label = 11;
      break;
    }
   case 11:
    return $result_1 | 0;
  }
  return 0;
}
function _ft_lzw_file_reset($zip) {
  $zip = $zip | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $zip | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = _FT_Stream_Seek($2, 0) | 0;
    $4 = ($3 | 0) == 0;
    if ($4) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $6 = $zip + 12 | 0;
    _ft_lzwstate_reset($6);
    $7 = $zip + 4280 | 0;
    $8 = $zip + 4288 | 0;
    HEAP32[$8 >> 2] = $7;
    $9 = $zip + 4284 | 0;
    HEAP32[$9 >> 2] = $7;
    $10 = $zip + 4280 | 0;
    HEAP32[$10 >> 2] = 0;
    label = 3;
    break;
   case 3:
    return $3 | 0;
  }
  return 0;
}
function _ft_lzw_file_skip_output($zip, $count) {
  $zip = $zip | 0;
  $count = $count | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_count = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $_020 = 0, $17 = 0, $_0_ = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $error_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $zip + 4288 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $zip + 4284 | 0;
    $4 = HEAP32[$3 >> 2] | 0;
    $5 = $2;
    $6 = $4;
    $7 = $5 - $6 | 0;
    $8 = $7 >>> 0 < $count >>> 0;
    $_count = $8 ? $7 : $count;
    $9 = $4 + $_count | 0;
    HEAP32[$3 >> 2] = $9;
    $10 = $zip + 4280 | 0;
    $11 = HEAP32[$10 >> 2] | 0;
    $12 = $_count + $11 | 0;
    HEAP32[$10 >> 2] = $12;
    $13 = ($_count | 0) == ($count | 0);
    if ($13) {
      $error_0 = 0;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $14 = $count - $_count | 0;
    $15 = $zip + 12 | 0;
    $_020 = $14;
    label = 3;
    break;
   case 3:
    $17 = $_020 >>> 0 < 4096;
    $_0_ = $17 ? $_020 : 4096;
    $18 = _ft_lzwstate_io($15, 0, $_0_) | 0;
    $19 = $18 >>> 0 < $_0_ >>> 0;
    if ($19) {
      $error_0 = 85;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $21 = HEAP32[$10 >> 2] | 0;
    $22 = $21 + $_0_ | 0;
    HEAP32[$10 >> 2] = $22;
    $23 = $_020 - $_0_ | 0;
    $24 = ($_020 | 0) == ($_0_ | 0);
    if ($24) {
      $error_0 = 0;
      label = 5;
      break;
    } else {
      $_020 = $23;
      label = 3;
      break;
    }
   case 5:
    return $error_0 | 0;
  }
  return 0;
}
function _ft_lzw_file_fill_output($zip) {
  $zip = $zip | 0;
  var $2 = 0, $3 = 0, $4 = 0;
  $2 = $zip + 184 | 0;
  $3 = $zip + 4284 | 0;
  HEAP32[$3 >> 2] = $2;
  $4 = _ft_lzwstate_io($zip + 12 | 0, $2, 4096) | 0;
  HEAP32[$zip + 4288 >> 2] = (HEAP32[$3 >> 2] | 0) + $4 | 0;
  return (($4 | 0) == 0 ? 85 : 0) | 0;
}
function _malloc($bytes) {
  $bytes = $bytes | 0;
  var $1 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $_sum110 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $_sum111112 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $_sum104 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $92 = 0, $93 = 0, $94 = 0, $96 = 0, $97 = 0, $98 = 0, $100 = 0, $101 = 0, $102 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $_sum105106 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $130 = 0, $_sum109 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $F4_0 = 0, $_sum108 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $144 = 0, $146 = 0, $147 = 0, $149 = 0, $150 = 0, $152 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $159 = 0, $160 = 0, $nb_0 = 0, $162 = 0, $163 = 0, $165 = 0, $166 = 0, $167 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $_sum102 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $180 = 0, $181 = 0, $182 = 0, $_sum101 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $188 = 0, $189 = 0, $191 = 0, $192 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $_sum = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $207 = 0, $mem_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $bytes >>> 0 < 245;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 29;
      break;
    }
   case 2:
    $3 = $bytes >>> 0 < 11;
    if ($3) {
      $8 = 16;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $5 = $bytes + 11 | 0;
    $6 = $5 & -8;
    $8 = $6;
    label = 4;
    break;
   case 4:
    $9 = $8 >>> 3;
    $10 = HEAP32[1331239] | 0;
    $11 = $10 >>> ($9 >>> 0);
    $12 = $11 & 3;
    $13 = ($12 | 0) == 0;
    if ($13) {
      label = 12;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $15 = $11 & 1;
    $16 = $15 ^ 1;
    $17 = $16 + $9 | 0;
    $18 = $17 << 1;
    $19 = 5324996 + ($18 << 2) | 0;
    $20 = $19;
    $_sum110 = $18 + 2 | 0;
    $21 = 5324996 + ($_sum110 << 2) | 0;
    $22 = HEAP32[$21 >> 2] | 0;
    $23 = $22 + 8 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = ($20 | 0) == ($24 | 0);
    if ($25) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $27 = 1 << $17;
    $28 = $27 ^ -1;
    $29 = $10 & $28;
    HEAP32[1331239] = $29;
    label = 11;
    break;
   case 7:
    $31 = $24;
    $32 = HEAP32[1331243] | 0;
    $33 = $31 >>> 0 < $32 >>> 0;
    if ($33) {
      label = 10;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $35 = $24 + 12 | 0;
    $36 = HEAP32[$35 >> 2] | 0;
    $37 = ($36 | 0) == ($22 | 0);
    if ($37) {
      label = 9;
      break;
    } else {
      label = 10;
      break;
    }
   case 9:
    HEAP32[$35 >> 2] = $20;
    HEAP32[$21 >> 2] = $24;
    label = 11;
    break;
   case 10:
    _abort();
    return 0;
    return 0;
   case 11:
    $40 = $17 << 3;
    $41 = $40 | 3;
    $42 = $22 + 4 | 0;
    HEAP32[$42 >> 2] = $41;
    $43 = $22;
    $_sum111112 = $40 | 4;
    $44 = $43 + $_sum111112 | 0;
    $45 = $44;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $46 | 1;
    HEAP32[$45 >> 2] = $47;
    $48 = $23;
    $mem_0 = $48;
    label = 40;
    break;
   case 12:
    $50 = HEAP32[1331241] | 0;
    $51 = $8 >>> 0 > $50 >>> 0;
    if ($51) {
      label = 13;
      break;
    } else {
      $nb_0 = $8;
      label = 32;
      break;
    }
   case 13:
    $53 = ($11 | 0) == 0;
    if ($53) {
      label = 27;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $55 = $11 << $9;
    $56 = 2 << $9;
    $57 = -$56 | 0;
    $58 = $56 | $57;
    $59 = $55 & $58;
    $60 = -$59 | 0;
    $61 = $59 & $60;
    $62 = $61 - 1 | 0;
    $63 = $62 >>> 12;
    $64 = $63 & 16;
    $65 = $62 >>> ($64 >>> 0);
    $66 = $65 >>> 5;
    $67 = $66 & 8;
    $68 = $67 | $64;
    $69 = $65 >>> ($67 >>> 0);
    $70 = $69 >>> 2;
    $71 = $70 & 4;
    $72 = $68 | $71;
    $73 = $69 >>> ($71 >>> 0);
    $74 = $73 >>> 1;
    $75 = $74 & 2;
    $76 = $72 | $75;
    $77 = $73 >>> ($75 >>> 0);
    $78 = $77 >>> 1;
    $79 = $78 & 1;
    $80 = $76 | $79;
    $81 = $77 >>> ($79 >>> 0);
    $82 = $80 + $81 | 0;
    $83 = $82 << 1;
    $84 = 5324996 + ($83 << 2) | 0;
    $85 = $84;
    $_sum104 = $83 + 2 | 0;
    $86 = 5324996 + ($_sum104 << 2) | 0;
    $87 = HEAP32[$86 >> 2] | 0;
    $88 = $87 + 8 | 0;
    $89 = HEAP32[$88 >> 2] | 0;
    $90 = ($85 | 0) == ($89 | 0);
    if ($90) {
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 15:
    $92 = 1 << $82;
    $93 = $92 ^ -1;
    $94 = $10 & $93;
    HEAP32[1331239] = $94;
    label = 20;
    break;
   case 16:
    $96 = $89;
    $97 = HEAP32[1331243] | 0;
    $98 = $96 >>> 0 < $97 >>> 0;
    if ($98) {
      label = 19;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $100 = $89 + 12 | 0;
    $101 = HEAP32[$100 >> 2] | 0;
    $102 = ($101 | 0) == ($87 | 0);
    if ($102) {
      label = 18;
      break;
    } else {
      label = 19;
      break;
    }
   case 18:
    HEAP32[$100 >> 2] = $85;
    HEAP32[$86 >> 2] = $89;
    label = 20;
    break;
   case 19:
    _abort();
    return 0;
    return 0;
   case 20:
    $105 = $82 << 3;
    $106 = $105 - $8 | 0;
    $107 = $8 | 3;
    $108 = $87 + 4 | 0;
    HEAP32[$108 >> 2] = $107;
    $109 = $87;
    $110 = $109 + $8 | 0;
    $111 = $110;
    $112 = $106 | 1;
    $_sum105106 = $8 | 4;
    $113 = $109 + $_sum105106 | 0;
    $114 = $113;
    HEAP32[$114 >> 2] = $112;
    $115 = $109 + $105 | 0;
    $116 = $115;
    HEAP32[$116 >> 2] = $106;
    $117 = HEAP32[1331241] | 0;
    $118 = ($117 | 0) == 0;
    if ($118) {
      label = 26;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $120 = HEAP32[1331244] | 0;
    $121 = $117 >>> 3;
    $122 = $121 << 1;
    $123 = 5324996 + ($122 << 2) | 0;
    $124 = $123;
    $125 = HEAP32[1331239] | 0;
    $126 = 1 << $121;
    $127 = $125 & $126;
    $128 = ($127 | 0) == 0;
    if ($128) {
      label = 22;
      break;
    } else {
      label = 23;
      break;
    }
   case 22:
    $130 = $125 | $126;
    HEAP32[1331239] = $130;
    $F4_0 = $124;
    label = 25;
    break;
   case 23:
    $_sum109 = $122 + 2 | 0;
    $132 = 5324996 + ($_sum109 << 2) | 0;
    $133 = HEAP32[$132 >> 2] | 0;
    $134 = $133;
    $135 = HEAP32[1331243] | 0;
    $136 = $134 >>> 0 < $135 >>> 0;
    if ($136) {
      label = 24;
      break;
    } else {
      $F4_0 = $133;
      label = 25;
      break;
    }
   case 24:
    _abort();
    return 0;
    return 0;
   case 25:
    $_sum108 = $122 + 2 | 0;
    $139 = 5324996 + ($_sum108 << 2) | 0;
    HEAP32[$139 >> 2] = $120;
    $140 = $F4_0 + 12 | 0;
    HEAP32[$140 >> 2] = $120;
    $141 = $120 + 8 | 0;
    HEAP32[$141 >> 2] = $F4_0;
    $142 = $120 + 12 | 0;
    HEAP32[$142 >> 2] = $124;
    label = 26;
    break;
   case 26:
    HEAP32[1331241] = $106;
    HEAP32[1331244] = $111;
    $144 = $88;
    $mem_0 = $144;
    label = 40;
    break;
   case 27:
    $146 = HEAP32[1331240] | 0;
    $147 = ($146 | 0) == 0;
    if ($147) {
      $nb_0 = $8;
      label = 32;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $149 = _tmalloc_small($8) | 0;
    $150 = ($149 | 0) == 0;
    if ($150) {
      $nb_0 = $8;
      label = 32;
      break;
    } else {
      $mem_0 = $149;
      label = 40;
      break;
    }
   case 29:
    $152 = $bytes >>> 0 > 4294967231;
    if ($152) {
      $nb_0 = -1;
      label = 32;
      break;
    } else {
      label = 30;
      break;
    }
   case 30:
    $154 = $bytes + 11 | 0;
    $155 = $154 & -8;
    $156 = HEAP32[1331240] | 0;
    $157 = ($156 | 0) == 0;
    if ($157) {
      $nb_0 = $155;
      label = 32;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    $159 = _tmalloc_large($155) | 0;
    $160 = ($159 | 0) == 0;
    if ($160) {
      $nb_0 = $155;
      label = 32;
      break;
    } else {
      $mem_0 = $159;
      label = 40;
      break;
    }
   case 32:
    $162 = HEAP32[1331241] | 0;
    $163 = $nb_0 >>> 0 > $162 >>> 0;
    if ($163) {
      label = 37;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    $165 = $162 - $nb_0 | 0;
    $166 = HEAP32[1331244] | 0;
    $167 = $165 >>> 0 > 15;
    if ($167) {
      label = 34;
      break;
    } else {
      label = 35;
      break;
    }
   case 34:
    $169 = $166;
    $170 = $169 + $nb_0 | 0;
    $171 = $170;
    HEAP32[1331244] = $171;
    HEAP32[1331241] = $165;
    $172 = $165 | 1;
    $_sum102 = $nb_0 + 4 | 0;
    $173 = $169 + $_sum102 | 0;
    $174 = $173;
    HEAP32[$174 >> 2] = $172;
    $175 = $169 + $162 | 0;
    $176 = $175;
    HEAP32[$176 >> 2] = $165;
    $177 = $nb_0 | 3;
    $178 = $166 + 4 | 0;
    HEAP32[$178 >> 2] = $177;
    label = 36;
    break;
   case 35:
    HEAP32[1331241] = 0;
    HEAP32[1331244] = 0;
    $180 = $162 | 3;
    $181 = $166 + 4 | 0;
    HEAP32[$181 >> 2] = $180;
    $182 = $166;
    $_sum101 = $162 + 4 | 0;
    $183 = $182 + $_sum101 | 0;
    $184 = $183;
    $185 = HEAP32[$184 >> 2] | 0;
    $186 = $185 | 1;
    HEAP32[$184 >> 2] = $186;
    label = 36;
    break;
   case 36:
    $188 = $166 + 8 | 0;
    $189 = $188;
    $mem_0 = $189;
    label = 40;
    break;
   case 37:
    $191 = HEAP32[1331242] | 0;
    $192 = $nb_0 >>> 0 < $191 >>> 0;
    if ($192) {
      label = 38;
      break;
    } else {
      label = 39;
      break;
    }
   case 38:
    $194 = $191 - $nb_0 | 0;
    HEAP32[1331242] = $194;
    $195 = HEAP32[1331245] | 0;
    $196 = $195;
    $197 = $196 + $nb_0 | 0;
    $198 = $197;
    HEAP32[1331245] = $198;
    $199 = $194 | 1;
    $_sum = $nb_0 + 4 | 0;
    $200 = $196 + $_sum | 0;
    $201 = $200;
    HEAP32[$201 >> 2] = $199;
    $202 = $nb_0 | 3;
    $203 = $195 + 4 | 0;
    HEAP32[$203 >> 2] = $202;
    $204 = $195 + 8 | 0;
    $205 = $204;
    $mem_0 = $205;
    label = 40;
    break;
   case 39:
    $207 = _sys_alloc($nb_0) | 0;
    $mem_0 = $207;
    label = 40;
    break;
   case 40:
    return $mem_0 | 0;
  }
  return 0;
}
function _tmalloc_small($nb) {
  $nb = $nb | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $rsize_0 = 0, $v_0 = 0, $t_0 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $_rsize_0 = 0, $_v_0 = 0, $46 = 0, $47 = 0, $48 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $71 = 0, $74 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $80 = 0, $RP_0 = 0, $R_0 = 0, $81 = 0, $82 = 0, $83 = 0, $85 = 0, $86 = 0, $87 = 0, $CP_0 = 0, $88 = 0, $90 = 0, $91 = 0, $92 = 0, $R_1 = 0, $96 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $cond = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $110 = 0, $111 = 0, $112 = 0, $114 = 0, $115 = 0, $116 = 0, $119 = 0, $122 = 0, $124 = 0, $125 = 0, $126 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $133 = 0, $134 = 0, $135 = 0, $137 = 0, $138 = 0, $141 = 0, $142 = 0, $143 = 0, $145 = 0, $146 = 0, $147 = 0, $149 = 0, $150 = 0, $154 = 0, $156 = 0, $157 = 0, $158 = 0, $_sum4 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0, $164 = 0, $165 = 0, $166 = 0, $_sum = 0, $167 = 0, $168 = 0, $_sum1 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $180 = 0, $181 = 0, $182 = 0, $184 = 0, $_sum3 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $F1_0 = 0, $_sum2 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $199 = 0, $200 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[1331240] | 0;
    $2 = -$1 | 0;
    $3 = $1 & $2;
    $4 = $3 - 1 | 0;
    $5 = $4 >>> 12;
    $6 = $5 & 16;
    $7 = $4 >>> ($6 >>> 0);
    $8 = $7 >>> 5;
    $9 = $8 & 8;
    $10 = $9 | $6;
    $11 = $7 >>> ($9 >>> 0);
    $12 = $11 >>> 2;
    $13 = $12 & 4;
    $14 = $10 | $13;
    $15 = $11 >>> ($13 >>> 0);
    $16 = $15 >>> 1;
    $17 = $16 & 2;
    $18 = $14 | $17;
    $19 = $15 >>> ($17 >>> 0);
    $20 = $19 >>> 1;
    $21 = $20 & 1;
    $22 = $18 | $21;
    $23 = $19 >>> ($21 >>> 0);
    $24 = $22 + $23 | 0;
    $25 = 5325260 + ($24 << 2) | 0;
    $26 = HEAP32[$25 >> 2] | 0;
    $27 = $26 + 4 | 0;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $28 & -8;
    $30 = $29 - $nb | 0;
    $t_0 = $26;
    $v_0 = $26;
    $rsize_0 = $30;
    label = 2;
    break;
   case 2:
    $32 = $t_0 + 16 | 0;
    $33 = HEAP32[$32 >> 2] | 0;
    $34 = ($33 | 0) == 0;
    if ($34) {
      label = 3;
      break;
    } else {
      $39 = $33;
      label = 4;
      break;
    }
   case 3:
    $36 = $t_0 + 20 | 0;
    $37 = HEAP32[$36 >> 2] | 0;
    $38 = ($37 | 0) == 0;
    if ($38) {
      label = 5;
      break;
    } else {
      $39 = $37;
      label = 4;
      break;
    }
   case 4:
    $40 = $39 + 4 | 0;
    $41 = HEAP32[$40 >> 2] | 0;
    $42 = $41 & -8;
    $43 = $42 - $nb | 0;
    $44 = $43 >>> 0 < $rsize_0 >>> 0;
    $_rsize_0 = $44 ? $43 : $rsize_0;
    $_v_0 = $44 ? $39 : $v_0;
    $t_0 = $39;
    $v_0 = $_v_0;
    $rsize_0 = $_rsize_0;
    label = 2;
    break;
   case 5:
    $46 = $v_0;
    $47 = HEAP32[1331243] | 0;
    $48 = $46 >>> 0 < $47 >>> 0;
    if ($48) {
      label = 51;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $50 = $46 + $nb | 0;
    $51 = $50;
    $52 = $46 >>> 0 < $50 >>> 0;
    if ($52) {
      label = 7;
      break;
    } else {
      label = 51;
      break;
    }
   case 7:
    $54 = $v_0 + 24 | 0;
    $55 = HEAP32[$54 >> 2] | 0;
    $56 = $v_0 + 12 | 0;
    $57 = HEAP32[$56 >> 2] | 0;
    $58 = ($57 | 0) == ($v_0 | 0);
    if ($58) {
      label = 13;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $60 = $v_0 + 8 | 0;
    $61 = HEAP32[$60 >> 2] | 0;
    $62 = $61;
    $63 = $62 >>> 0 < $47 >>> 0;
    if ($63) {
      label = 12;
      break;
    } else {
      label = 9;
      break;
    }
   case 9:
    $65 = $61 + 12 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = ($66 | 0) == ($v_0 | 0);
    if ($67) {
      label = 10;
      break;
    } else {
      label = 12;
      break;
    }
   case 10:
    $69 = $57 + 8 | 0;
    $70 = HEAP32[$69 >> 2] | 0;
    $71 = ($70 | 0) == ($v_0 | 0);
    if ($71) {
      label = 11;
      break;
    } else {
      label = 12;
      break;
    }
   case 11:
    HEAP32[$65 >> 2] = $57;
    HEAP32[$69 >> 2] = $61;
    $R_1 = $57;
    label = 21;
    break;
   case 12:
    _abort();
    return 0;
    return 0;
   case 13:
    $74 = $v_0 + 20 | 0;
    $75 = HEAP32[$74 >> 2] | 0;
    $76 = ($75 | 0) == 0;
    if ($76) {
      label = 14;
      break;
    } else {
      $R_0 = $75;
      $RP_0 = $74;
      label = 15;
      break;
    }
   case 14:
    $78 = $v_0 + 16 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = ($79 | 0) == 0;
    if ($80) {
      $R_1 = 0;
      label = 21;
      break;
    } else {
      $R_0 = $79;
      $RP_0 = $78;
      label = 15;
      break;
    }
   case 15:
    $81 = $R_0 + 20 | 0;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = ($82 | 0) == 0;
    if ($83) {
      label = 16;
      break;
    } else {
      $CP_0 = $81;
      label = 17;
      break;
    }
   case 16:
    $85 = $R_0 + 16 | 0;
    $86 = HEAP32[$85 >> 2] | 0;
    $87 = ($86 | 0) == 0;
    if ($87) {
      label = 18;
      break;
    } else {
      $CP_0 = $85;
      label = 17;
      break;
    }
   case 17:
    $88 = HEAP32[$CP_0 >> 2] | 0;
    $R_0 = $88;
    $RP_0 = $CP_0;
    label = 15;
    break;
   case 18:
    $90 = $RP_0;
    $91 = HEAP32[1331243] | 0;
    $92 = $90 >>> 0 < $91 >>> 0;
    if ($92) {
      label = 20;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    HEAP32[$RP_0 >> 2] = 0;
    $R_1 = $R_0;
    label = 21;
    break;
   case 20:
    _abort();
    return 0;
    return 0;
   case 21:
    $96 = ($55 | 0) == 0;
    if ($96) {
      label = 41;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $98 = $v_0 + 28 | 0;
    $99 = HEAP32[$98 >> 2] | 0;
    $100 = 5325260 + ($99 << 2) | 0;
    $101 = HEAP32[$100 >> 2] | 0;
    $102 = ($v_0 | 0) == ($101 | 0);
    if ($102) {
      label = 23;
      break;
    } else {
      label = 25;
      break;
    }
   case 23:
    HEAP32[$100 >> 2] = $R_1;
    $cond = ($R_1 | 0) == 0;
    if ($cond) {
      label = 24;
      break;
    } else {
      label = 31;
      break;
    }
   case 24:
    $104 = HEAP32[$98 >> 2] | 0;
    $105 = 1 << $104;
    $106 = $105 ^ -1;
    $107 = HEAP32[1331240] | 0;
    $108 = $107 & $106;
    HEAP32[1331240] = $108;
    label = 41;
    break;
   case 25:
    $110 = $55;
    $111 = HEAP32[1331243] | 0;
    $112 = $110 >>> 0 < $111 >>> 0;
    if ($112) {
      label = 29;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $114 = $55 + 16 | 0;
    $115 = HEAP32[$114 >> 2] | 0;
    $116 = ($115 | 0) == ($v_0 | 0);
    if ($116) {
      label = 27;
      break;
    } else {
      label = 28;
      break;
    }
   case 27:
    HEAP32[$114 >> 2] = $R_1;
    label = 30;
    break;
   case 28:
    $119 = $55 + 20 | 0;
    HEAP32[$119 >> 2] = $R_1;
    label = 30;
    break;
   case 29:
    _abort();
    return 0;
    return 0;
   case 30:
    $122 = ($R_1 | 0) == 0;
    if ($122) {
      label = 41;
      break;
    } else {
      label = 31;
      break;
    }
   case 31:
    $124 = $R_1;
    $125 = HEAP32[1331243] | 0;
    $126 = $124 >>> 0 < $125 >>> 0;
    if ($126) {
      label = 40;
      break;
    } else {
      label = 32;
      break;
    }
   case 32:
    $128 = $R_1 + 24 | 0;
    HEAP32[$128 >> 2] = $55;
    $129 = $v_0 + 16 | 0;
    $130 = HEAP32[$129 >> 2] | 0;
    $131 = ($130 | 0) == 0;
    if ($131) {
      label = 36;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    $133 = $130;
    $134 = HEAP32[1331243] | 0;
    $135 = $133 >>> 0 < $134 >>> 0;
    if ($135) {
      label = 35;
      break;
    } else {
      label = 34;
      break;
    }
   case 34:
    $137 = $R_1 + 16 | 0;
    HEAP32[$137 >> 2] = $130;
    $138 = $130 + 24 | 0;
    HEAP32[$138 >> 2] = $R_1;
    label = 36;
    break;
   case 35:
    _abort();
    return 0;
    return 0;
   case 36:
    $141 = $v_0 + 20 | 0;
    $142 = HEAP32[$141 >> 2] | 0;
    $143 = ($142 | 0) == 0;
    if ($143) {
      label = 41;
      break;
    } else {
      label = 37;
      break;
    }
   case 37:
    $145 = $142;
    $146 = HEAP32[1331243] | 0;
    $147 = $145 >>> 0 < $146 >>> 0;
    if ($147) {
      label = 39;
      break;
    } else {
      label = 38;
      break;
    }
   case 38:
    $149 = $R_1 + 20 | 0;
    HEAP32[$149 >> 2] = $142;
    $150 = $142 + 24 | 0;
    HEAP32[$150 >> 2] = $R_1;
    label = 41;
    break;
   case 39:
    _abort();
    return 0;
    return 0;
   case 40:
    _abort();
    return 0;
    return 0;
   case 41:
    $154 = $rsize_0 >>> 0 < 16;
    if ($154) {
      label = 42;
      break;
    } else {
      label = 43;
      break;
    }
   case 42:
    $156 = $rsize_0 + $nb | 0;
    $157 = $156 | 3;
    $158 = $v_0 + 4 | 0;
    HEAP32[$158 >> 2] = $157;
    $_sum4 = $156 + 4 | 0;
    $159 = $46 + $_sum4 | 0;
    $160 = $159;
    $161 = HEAP32[$160 >> 2] | 0;
    $162 = $161 | 1;
    HEAP32[$160 >> 2] = $162;
    label = 50;
    break;
   case 43:
    $164 = $nb | 3;
    $165 = $v_0 + 4 | 0;
    HEAP32[$165 >> 2] = $164;
    $166 = $rsize_0 | 1;
    $_sum = $nb + 4 | 0;
    $167 = $46 + $_sum | 0;
    $168 = $167;
    HEAP32[$168 >> 2] = $166;
    $_sum1 = $rsize_0 + $nb | 0;
    $169 = $46 + $_sum1 | 0;
    $170 = $169;
    HEAP32[$170 >> 2] = $rsize_0;
    $171 = HEAP32[1331241] | 0;
    $172 = ($171 | 0) == 0;
    if ($172) {
      label = 49;
      break;
    } else {
      label = 44;
      break;
    }
   case 44:
    $174 = HEAP32[1331244] | 0;
    $175 = $171 >>> 3;
    $176 = $175 << 1;
    $177 = 5324996 + ($176 << 2) | 0;
    $178 = $177;
    $179 = HEAP32[1331239] | 0;
    $180 = 1 << $175;
    $181 = $179 & $180;
    $182 = ($181 | 0) == 0;
    if ($182) {
      label = 45;
      break;
    } else {
      label = 46;
      break;
    }
   case 45:
    $184 = $179 | $180;
    HEAP32[1331239] = $184;
    $F1_0 = $178;
    label = 48;
    break;
   case 46:
    $_sum3 = $176 + 2 | 0;
    $186 = 5324996 + ($_sum3 << 2) | 0;
    $187 = HEAP32[$186 >> 2] | 0;
    $188 = $187;
    $189 = HEAP32[1331243] | 0;
    $190 = $188 >>> 0 < $189 >>> 0;
    if ($190) {
      label = 47;
      break;
    } else {
      $F1_0 = $187;
      label = 48;
      break;
    }
   case 47:
    _abort();
    return 0;
    return 0;
   case 48:
    $_sum2 = $176 + 2 | 0;
    $193 = 5324996 + ($_sum2 << 2) | 0;
    HEAP32[$193 >> 2] = $174;
    $194 = $F1_0 + 12 | 0;
    HEAP32[$194 >> 2] = $174;
    $195 = $174 + 8 | 0;
    HEAP32[$195 >> 2] = $F1_0;
    $196 = $174 + 12 | 0;
    HEAP32[$196 >> 2] = $178;
    label = 49;
    break;
   case 49:
    HEAP32[1331241] = $rsize_0;
    HEAP32[1331244] = $51;
    label = 50;
    break;
   case 50:
    $199 = $v_0 + 8 | 0;
    $200 = $199;
    return $200 | 0;
   case 51:
    _abort();
    return 0;
    return 0;
  }
  return 0;
}
function _tmalloc_large($nb) {
  $nb = $nb | 0;
  var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $idx_0 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $rst_0 = 0, $sizebits_0 = 0, $t_0 = 0, $rsize_0 = 0, $v_0 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $48 = 0, $rsize_1 = 0, $v_1 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $or_cond = 0, $rst_1 = 0, $57 = 0, $58 = 0, $t_1 = 0, $rsize_2 = 0, $v_2 = 0, $59 = 0, $60 = 0, $or_cond19 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $t_2_ph = 0, $94 = 0, $v_328 = 0, $rsize_327 = 0, $t_226 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_rsize_3 = 0, $t_2_v_3 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $v_3_lcssa = 0, $rsize_3_lcssa = 0, $106 = 0, $108 = 0, $109 = 0, $110 = 0, $112 = 0, $113 = 0, $114 = 0, $116 = 0, $117 = 0, $118 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $131 = 0, $132 = 0, $133 = 0, $135 = 0, $136 = 0, $137 = 0, $140 = 0, $141 = 0, $142 = 0, $144 = 0, $145 = 0, $146 = 0, $RP_0 = 0, $R_0 = 0, $147 = 0, $148 = 0, $149 = 0, $151 = 0, $152 = 0, $153 = 0, $CP_0 = 0, $154 = 0, $156 = 0, $157 = 0, $158 = 0, $R_1 = 0, $162 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $cond = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $176 = 0, $177 = 0, $178 = 0, $180 = 0, $181 = 0, $182 = 0, $185 = 0, $188 = 0, $190 = 0, $191 = 0, $192 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $199 = 0, $200 = 0, $201 = 0, $203 = 0, $204 = 0, $207 = 0, $208 = 0, $209 = 0, $211 = 0, $212 = 0, $213 = 0, $215 = 0, $216 = 0, $220 = 0, $222 = 0, $223 = 0, $224 = 0, $_sum18 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $230 = 0, $231 = 0, $232 = 0, $_sum = 0, $233 = 0, $234 = 0, $_sum1 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $248 = 0, $_sum17 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $F5_0 = 0, $_sum14 = 0, $257 = 0, $258 = 0, $_sum15 = 0, $259 = 0, $260 = 0, $_sum16 = 0, $261 = 0, $262 = 0, $264 = 0, $265 = 0, $266 = 0, $268 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $290 = 0, $291 = 0, $I7_0 = 0, $293 = 0, $_sum2 = 0, $294 = 0, $295 = 0, $_sum3 = 0, $296 = 0, $_sum4 = 0, $297 = 0, $298 = 0, $299 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $305 = 0, $306 = 0, $_sum5 = 0, $307 = 0, $308 = 0, $_sum6 = 0, $309 = 0, $310 = 0, $_sum7 = 0, $311 = 0, $312 = 0, $314 = 0, $315 = 0, $317 = 0, $318 = 0, $320 = 0, $321 = 0, $T_0 = 0, $K12_0 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $328 = 0, $329 = 0, $330 = 0, $331 = 0, $332 = 0, $334 = 0, $335 = 0, $336 = 0, $_sum11 = 0, $338 = 0, $339 = 0, $_sum12 = 0, $340 = 0, $341 = 0, $_sum13 = 0, $342 = 0, $343 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $350 = 0, $352 = 0, $353 = 0, $355 = 0, $_sum8 = 0, $356 = 0, $357 = 0, $_sum9 = 0, $358 = 0, $359 = 0, $_sum10 = 0, $360 = 0, $361 = 0, $363 = 0, $364 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = -$nb | 0;
    $2 = $nb >>> 8;
    $3 = ($2 | 0) == 0;
    if ($3) {
      $idx_0 = 0;
      label = 4;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $5 = $nb >>> 0 > 16777215;
    if ($5) {
      $idx_0 = 31;
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $7 = $2 + 1048320 | 0;
    $8 = $7 >>> 16;
    $9 = $8 & 8;
    $10 = $2 << $9;
    $11 = $10 + 520192 | 0;
    $12 = $11 >>> 16;
    $13 = $12 & 4;
    $14 = $13 | $9;
    $15 = $10 << $13;
    $16 = $15 + 245760 | 0;
    $17 = $16 >>> 16;
    $18 = $17 & 2;
    $19 = $14 | $18;
    $20 = 14 - $19 | 0;
    $21 = $15 << $18;
    $22 = $21 >>> 15;
    $23 = $20 + $22 | 0;
    $24 = $23 << 1;
    $25 = $23 + 7 | 0;
    $26 = $nb >>> ($25 >>> 0);
    $27 = $26 & 1;
    $28 = $27 | $24;
    $idx_0 = $28;
    label = 4;
    break;
   case 4:
    $30 = 5325260 + ($idx_0 << 2) | 0;
    $31 = HEAP32[$30 >> 2] | 0;
    $32 = ($31 | 0) == 0;
    if ($32) {
      $v_2 = 0;
      $rsize_2 = $1;
      $t_1 = 0;
      label = 11;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $34 = ($idx_0 | 0) == 31;
    if ($34) {
      $39 = 0;
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $36 = $idx_0 >>> 1;
    $37 = 25 - $36 | 0;
    $39 = $37;
    label = 7;
    break;
   case 7:
    $40 = $nb << $39;
    $v_0 = 0;
    $rsize_0 = $1;
    $t_0 = $31;
    $sizebits_0 = $40;
    $rst_0 = 0;
    label = 8;
    break;
   case 8:
    $42 = $t_0 + 4 | 0;
    $43 = HEAP32[$42 >> 2] | 0;
    $44 = $43 & -8;
    $45 = $44 - $nb | 0;
    $46 = $45 >>> 0 < $rsize_0 >>> 0;
    if ($46) {
      label = 9;
      break;
    } else {
      $v_1 = $v_0;
      $rsize_1 = $rsize_0;
      label = 10;
      break;
    }
   case 9:
    $48 = ($44 | 0) == ($nb | 0);
    if ($48) {
      $v_2 = $t_0;
      $rsize_2 = $45;
      $t_1 = $t_0;
      label = 11;
      break;
    } else {
      $v_1 = $t_0;
      $rsize_1 = $45;
      label = 10;
      break;
    }
   case 10:
    $50 = $t_0 + 20 | 0;
    $51 = HEAP32[$50 >> 2] | 0;
    $52 = $sizebits_0 >>> 31;
    $53 = $t_0 + 16 + ($52 << 2) | 0;
    $54 = HEAP32[$53 >> 2] | 0;
    $55 = ($51 | 0) == 0;
    $56 = ($51 | 0) == ($54 | 0);
    $or_cond = $55 | $56;
    $rst_1 = $or_cond ? $rst_0 : $51;
    $57 = ($54 | 0) == 0;
    $58 = $sizebits_0 << 1;
    if ($57) {
      $v_2 = $v_1;
      $rsize_2 = $rsize_1;
      $t_1 = $rst_1;
      label = 11;
      break;
    } else {
      $v_0 = $v_1;
      $rsize_0 = $rsize_1;
      $t_0 = $54;
      $sizebits_0 = $58;
      $rst_0 = $rst_1;
      label = 8;
      break;
    }
   case 11:
    $59 = ($t_1 | 0) == 0;
    $60 = ($v_2 | 0) == 0;
    $or_cond19 = $59 & $60;
    if ($or_cond19) {
      label = 12;
      break;
    } else {
      $t_2_ph = $t_1;
      label = 14;
      break;
    }
   case 12:
    $62 = 2 << $idx_0;
    $63 = -$62 | 0;
    $64 = $62 | $63;
    $65 = HEAP32[1331240] | 0;
    $66 = $65 & $64;
    $67 = ($66 | 0) == 0;
    if ($67) {
      $t_2_ph = $t_1;
      label = 14;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $69 = -$66 | 0;
    $70 = $66 & $69;
    $71 = $70 - 1 | 0;
    $72 = $71 >>> 12;
    $73 = $72 & 16;
    $74 = $71 >>> ($73 >>> 0);
    $75 = $74 >>> 5;
    $76 = $75 & 8;
    $77 = $76 | $73;
    $78 = $74 >>> ($76 >>> 0);
    $79 = $78 >>> 2;
    $80 = $79 & 4;
    $81 = $77 | $80;
    $82 = $78 >>> ($80 >>> 0);
    $83 = $82 >>> 1;
    $84 = $83 & 2;
    $85 = $81 | $84;
    $86 = $82 >>> ($84 >>> 0);
    $87 = $86 >>> 1;
    $88 = $87 & 1;
    $89 = $85 | $88;
    $90 = $86 >>> ($88 >>> 0);
    $91 = $89 + $90 | 0;
    $92 = 5325260 + ($91 << 2) | 0;
    $93 = HEAP32[$92 >> 2] | 0;
    $t_2_ph = $93;
    label = 14;
    break;
   case 14:
    $94 = ($t_2_ph | 0) == 0;
    if ($94) {
      $rsize_3_lcssa = $rsize_2;
      $v_3_lcssa = $v_2;
      label = 17;
      break;
    } else {
      $t_226 = $t_2_ph;
      $rsize_327 = $rsize_2;
      $v_328 = $v_2;
      label = 15;
      break;
    }
   case 15:
    $95 = $t_226 + 4 | 0;
    $96 = HEAP32[$95 >> 2] | 0;
    $97 = $96 & -8;
    $98 = $97 - $nb | 0;
    $99 = $98 >>> 0 < $rsize_327 >>> 0;
    $_rsize_3 = $99 ? $98 : $rsize_327;
    $t_2_v_3 = $99 ? $t_226 : $v_328;
    $100 = $t_226 + 16 | 0;
    $101 = HEAP32[$100 >> 2] | 0;
    $102 = ($101 | 0) == 0;
    if ($102) {
      label = 16;
      break;
    } else {
      $t_226 = $101;
      $rsize_327 = $_rsize_3;
      $v_328 = $t_2_v_3;
      label = 15;
      break;
    }
   case 16:
    $103 = $t_226 + 20 | 0;
    $104 = HEAP32[$103 >> 2] | 0;
    $105 = ($104 | 0) == 0;
    if ($105) {
      $rsize_3_lcssa = $_rsize_3;
      $v_3_lcssa = $t_2_v_3;
      label = 17;
      break;
    } else {
      $t_226 = $104;
      $rsize_327 = $_rsize_3;
      $v_328 = $t_2_v_3;
      label = 15;
      break;
    }
   case 17:
    $106 = ($v_3_lcssa | 0) == 0;
    if ($106) {
      $_0 = 0;
      label = 82;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $108 = HEAP32[1331241] | 0;
    $109 = $108 - $nb | 0;
    $110 = $rsize_3_lcssa >>> 0 < $109 >>> 0;
    if ($110) {
      label = 19;
      break;
    } else {
      $_0 = 0;
      label = 82;
      break;
    }
   case 19:
    $112 = $v_3_lcssa;
    $113 = HEAP32[1331243] | 0;
    $114 = $112 >>> 0 < $113 >>> 0;
    if ($114) {
      label = 81;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $116 = $112 + $nb | 0;
    $117 = $116;
    $118 = $112 >>> 0 < $116 >>> 0;
    if ($118) {
      label = 21;
      break;
    } else {
      label = 81;
      break;
    }
   case 21:
    $120 = $v_3_lcssa + 24 | 0;
    $121 = HEAP32[$120 >> 2] | 0;
    $122 = $v_3_lcssa + 12 | 0;
    $123 = HEAP32[$122 >> 2] | 0;
    $124 = ($123 | 0) == ($v_3_lcssa | 0);
    if ($124) {
      label = 27;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $126 = $v_3_lcssa + 8 | 0;
    $127 = HEAP32[$126 >> 2] | 0;
    $128 = $127;
    $129 = $128 >>> 0 < $113 >>> 0;
    if ($129) {
      label = 26;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $131 = $127 + 12 | 0;
    $132 = HEAP32[$131 >> 2] | 0;
    $133 = ($132 | 0) == ($v_3_lcssa | 0);
    if ($133) {
      label = 24;
      break;
    } else {
      label = 26;
      break;
    }
   case 24:
    $135 = $123 + 8 | 0;
    $136 = HEAP32[$135 >> 2] | 0;
    $137 = ($136 | 0) == ($v_3_lcssa | 0);
    if ($137) {
      label = 25;
      break;
    } else {
      label = 26;
      break;
    }
   case 25:
    HEAP32[$131 >> 2] = $123;
    HEAP32[$135 >> 2] = $127;
    $R_1 = $123;
    label = 35;
    break;
   case 26:
    _abort();
    return 0;
    return 0;
   case 27:
    $140 = $v_3_lcssa + 20 | 0;
    $141 = HEAP32[$140 >> 2] | 0;
    $142 = ($141 | 0) == 0;
    if ($142) {
      label = 28;
      break;
    } else {
      $R_0 = $141;
      $RP_0 = $140;
      label = 29;
      break;
    }
   case 28:
    $144 = $v_3_lcssa + 16 | 0;
    $145 = HEAP32[$144 >> 2] | 0;
    $146 = ($145 | 0) == 0;
    if ($146) {
      $R_1 = 0;
      label = 35;
      break;
    } else {
      $R_0 = $145;
      $RP_0 = $144;
      label = 29;
      break;
    }
   case 29:
    $147 = $R_0 + 20 | 0;
    $148 = HEAP32[$147 >> 2] | 0;
    $149 = ($148 | 0) == 0;
    if ($149) {
      label = 30;
      break;
    } else {
      $CP_0 = $147;
      label = 31;
      break;
    }
   case 30:
    $151 = $R_0 + 16 | 0;
    $152 = HEAP32[$151 >> 2] | 0;
    $153 = ($152 | 0) == 0;
    if ($153) {
      label = 32;
      break;
    } else {
      $CP_0 = $151;
      label = 31;
      break;
    }
   case 31:
    $154 = HEAP32[$CP_0 >> 2] | 0;
    $R_0 = $154;
    $RP_0 = $CP_0;
    label = 29;
    break;
   case 32:
    $156 = $RP_0;
    $157 = HEAP32[1331243] | 0;
    $158 = $156 >>> 0 < $157 >>> 0;
    if ($158) {
      label = 34;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    HEAP32[$RP_0 >> 2] = 0;
    $R_1 = $R_0;
    label = 35;
    break;
   case 34:
    _abort();
    return 0;
    return 0;
   case 35:
    $162 = ($121 | 0) == 0;
    if ($162) {
      label = 55;
      break;
    } else {
      label = 36;
      break;
    }
   case 36:
    $164 = $v_3_lcssa + 28 | 0;
    $165 = HEAP32[$164 >> 2] | 0;
    $166 = 5325260 + ($165 << 2) | 0;
    $167 = HEAP32[$166 >> 2] | 0;
    $168 = ($v_3_lcssa | 0) == ($167 | 0);
    if ($168) {
      label = 37;
      break;
    } else {
      label = 39;
      break;
    }
   case 37:
    HEAP32[$166 >> 2] = $R_1;
    $cond = ($R_1 | 0) == 0;
    if ($cond) {
      label = 38;
      break;
    } else {
      label = 45;
      break;
    }
   case 38:
    $170 = HEAP32[$164 >> 2] | 0;
    $171 = 1 << $170;
    $172 = $171 ^ -1;
    $173 = HEAP32[1331240] | 0;
    $174 = $173 & $172;
    HEAP32[1331240] = $174;
    label = 55;
    break;
   case 39:
    $176 = $121;
    $177 = HEAP32[1331243] | 0;
    $178 = $176 >>> 0 < $177 >>> 0;
    if ($178) {
      label = 43;
      break;
    } else {
      label = 40;
      break;
    }
   case 40:
    $180 = $121 + 16 | 0;
    $181 = HEAP32[$180 >> 2] | 0;
    $182 = ($181 | 0) == ($v_3_lcssa | 0);
    if ($182) {
      label = 41;
      break;
    } else {
      label = 42;
      break;
    }
   case 41:
    HEAP32[$180 >> 2] = $R_1;
    label = 44;
    break;
   case 42:
    $185 = $121 + 20 | 0;
    HEAP32[$185 >> 2] = $R_1;
    label = 44;
    break;
   case 43:
    _abort();
    return 0;
    return 0;
   case 44:
    $188 = ($R_1 | 0) == 0;
    if ($188) {
      label = 55;
      break;
    } else {
      label = 45;
      break;
    }
   case 45:
    $190 = $R_1;
    $191 = HEAP32[1331243] | 0;
    $192 = $190 >>> 0 < $191 >>> 0;
    if ($192) {
      label = 54;
      break;
    } else {
      label = 46;
      break;
    }
   case 46:
    $194 = $R_1 + 24 | 0;
    HEAP32[$194 >> 2] = $121;
    $195 = $v_3_lcssa + 16 | 0;
    $196 = HEAP32[$195 >> 2] | 0;
    $197 = ($196 | 0) == 0;
    if ($197) {
      label = 50;
      break;
    } else {
      label = 47;
      break;
    }
   case 47:
    $199 = $196;
    $200 = HEAP32[1331243] | 0;
    $201 = $199 >>> 0 < $200 >>> 0;
    if ($201) {
      label = 49;
      break;
    } else {
      label = 48;
      break;
    }
   case 48:
    $203 = $R_1 + 16 | 0;
    HEAP32[$203 >> 2] = $196;
    $204 = $196 + 24 | 0;
    HEAP32[$204 >> 2] = $R_1;
    label = 50;
    break;
   case 49:
    _abort();
    return 0;
    return 0;
   case 50:
    $207 = $v_3_lcssa + 20 | 0;
    $208 = HEAP32[$207 >> 2] | 0;
    $209 = ($208 | 0) == 0;
    if ($209) {
      label = 55;
      break;
    } else {
      label = 51;
      break;
    }
   case 51:
    $211 = $208;
    $212 = HEAP32[1331243] | 0;
    $213 = $211 >>> 0 < $212 >>> 0;
    if ($213) {
      label = 53;
      break;
    } else {
      label = 52;
      break;
    }
   case 52:
    $215 = $R_1 + 20 | 0;
    HEAP32[$215 >> 2] = $208;
    $216 = $208 + 24 | 0;
    HEAP32[$216 >> 2] = $R_1;
    label = 55;
    break;
   case 53:
    _abort();
    return 0;
    return 0;
   case 54:
    _abort();
    return 0;
    return 0;
   case 55:
    $220 = $rsize_3_lcssa >>> 0 < 16;
    if ($220) {
      label = 56;
      break;
    } else {
      label = 57;
      break;
    }
   case 56:
    $222 = $rsize_3_lcssa + $nb | 0;
    $223 = $222 | 3;
    $224 = $v_3_lcssa + 4 | 0;
    HEAP32[$224 >> 2] = $223;
    $_sum18 = $222 + 4 | 0;
    $225 = $112 + $_sum18 | 0;
    $226 = $225;
    $227 = HEAP32[$226 >> 2] | 0;
    $228 = $227 | 1;
    HEAP32[$226 >> 2] = $228;
    label = 80;
    break;
   case 57:
    $230 = $nb | 3;
    $231 = $v_3_lcssa + 4 | 0;
    HEAP32[$231 >> 2] = $230;
    $232 = $rsize_3_lcssa | 1;
    $_sum = $nb + 4 | 0;
    $233 = $112 + $_sum | 0;
    $234 = $233;
    HEAP32[$234 >> 2] = $232;
    $_sum1 = $rsize_3_lcssa + $nb | 0;
    $235 = $112 + $_sum1 | 0;
    $236 = $235;
    HEAP32[$236 >> 2] = $rsize_3_lcssa;
    $237 = $rsize_3_lcssa >>> 3;
    $238 = $rsize_3_lcssa >>> 0 < 256;
    if ($238) {
      label = 58;
      break;
    } else {
      label = 63;
      break;
    }
   case 58:
    $240 = $237 << 1;
    $241 = 5324996 + ($240 << 2) | 0;
    $242 = $241;
    $243 = HEAP32[1331239] | 0;
    $244 = 1 << $237;
    $245 = $243 & $244;
    $246 = ($245 | 0) == 0;
    if ($246) {
      label = 59;
      break;
    } else {
      label = 60;
      break;
    }
   case 59:
    $248 = $243 | $244;
    HEAP32[1331239] = $248;
    $F5_0 = $242;
    label = 62;
    break;
   case 60:
    $_sum17 = $240 + 2 | 0;
    $250 = 5324996 + ($_sum17 << 2) | 0;
    $251 = HEAP32[$250 >> 2] | 0;
    $252 = $251;
    $253 = HEAP32[1331243] | 0;
    $254 = $252 >>> 0 < $253 >>> 0;
    if ($254) {
      label = 61;
      break;
    } else {
      $F5_0 = $251;
      label = 62;
      break;
    }
   case 61:
    _abort();
    return 0;
    return 0;
   case 62:
    $_sum14 = $240 + 2 | 0;
    $257 = 5324996 + ($_sum14 << 2) | 0;
    HEAP32[$257 >> 2] = $117;
    $258 = $F5_0 + 12 | 0;
    HEAP32[$258 >> 2] = $117;
    $_sum15 = $nb + 8 | 0;
    $259 = $112 + $_sum15 | 0;
    $260 = $259;
    HEAP32[$260 >> 2] = $F5_0;
    $_sum16 = $nb + 12 | 0;
    $261 = $112 + $_sum16 | 0;
    $262 = $261;
    HEAP32[$262 >> 2] = $242;
    label = 80;
    break;
   case 63:
    $264 = $116;
    $265 = $rsize_3_lcssa >>> 8;
    $266 = ($265 | 0) == 0;
    if ($266) {
      $I7_0 = 0;
      label = 66;
      break;
    } else {
      label = 64;
      break;
    }
   case 64:
    $268 = $rsize_3_lcssa >>> 0 > 16777215;
    if ($268) {
      $I7_0 = 31;
      label = 66;
      break;
    } else {
      label = 65;
      break;
    }
   case 65:
    $270 = $265 + 1048320 | 0;
    $271 = $270 >>> 16;
    $272 = $271 & 8;
    $273 = $265 << $272;
    $274 = $273 + 520192 | 0;
    $275 = $274 >>> 16;
    $276 = $275 & 4;
    $277 = $276 | $272;
    $278 = $273 << $276;
    $279 = $278 + 245760 | 0;
    $280 = $279 >>> 16;
    $281 = $280 & 2;
    $282 = $277 | $281;
    $283 = 14 - $282 | 0;
    $284 = $278 << $281;
    $285 = $284 >>> 15;
    $286 = $283 + $285 | 0;
    $287 = $286 << 1;
    $288 = $286 + 7 | 0;
    $289 = $rsize_3_lcssa >>> ($288 >>> 0);
    $290 = $289 & 1;
    $291 = $290 | $287;
    $I7_0 = $291;
    label = 66;
    break;
   case 66:
    $293 = 5325260 + ($I7_0 << 2) | 0;
    $_sum2 = $nb + 28 | 0;
    $294 = $112 + $_sum2 | 0;
    $295 = $294;
    HEAP32[$295 >> 2] = $I7_0;
    $_sum3 = $nb + 16 | 0;
    $296 = $112 + $_sum3 | 0;
    $_sum4 = $nb + 20 | 0;
    $297 = $112 + $_sum4 | 0;
    $298 = $297;
    HEAP32[$298 >> 2] = 0;
    $299 = $296;
    HEAP32[$299 >> 2] = 0;
    $300 = HEAP32[1331240] | 0;
    $301 = 1 << $I7_0;
    $302 = $300 & $301;
    $303 = ($302 | 0) == 0;
    if ($303) {
      label = 67;
      break;
    } else {
      label = 68;
      break;
    }
   case 67:
    $305 = $300 | $301;
    HEAP32[1331240] = $305;
    HEAP32[$293 >> 2] = $264;
    $306 = $293;
    $_sum5 = $nb + 24 | 0;
    $307 = $112 + $_sum5 | 0;
    $308 = $307;
    HEAP32[$308 >> 2] = $306;
    $_sum6 = $nb + 12 | 0;
    $309 = $112 + $_sum6 | 0;
    $310 = $309;
    HEAP32[$310 >> 2] = $264;
    $_sum7 = $nb + 8 | 0;
    $311 = $112 + $_sum7 | 0;
    $312 = $311;
    HEAP32[$312 >> 2] = $264;
    label = 80;
    break;
   case 68:
    $314 = HEAP32[$293 >> 2] | 0;
    $315 = ($I7_0 | 0) == 31;
    if ($315) {
      $320 = 0;
      label = 70;
      break;
    } else {
      label = 69;
      break;
    }
   case 69:
    $317 = $I7_0 >>> 1;
    $318 = 25 - $317 | 0;
    $320 = $318;
    label = 70;
    break;
   case 70:
    $321 = $rsize_3_lcssa << $320;
    $K12_0 = $321;
    $T_0 = $314;
    label = 71;
    break;
   case 71:
    $323 = $T_0 + 4 | 0;
    $324 = HEAP32[$323 >> 2] | 0;
    $325 = $324 & -8;
    $326 = ($325 | 0) == ($rsize_3_lcssa | 0);
    if ($326) {
      label = 76;
      break;
    } else {
      label = 72;
      break;
    }
   case 72:
    $328 = $K12_0 >>> 31;
    $329 = $T_0 + 16 + ($328 << 2) | 0;
    $330 = HEAP32[$329 >> 2] | 0;
    $331 = ($330 | 0) == 0;
    $332 = $K12_0 << 1;
    if ($331) {
      label = 73;
      break;
    } else {
      $K12_0 = $332;
      $T_0 = $330;
      label = 71;
      break;
    }
   case 73:
    $334 = $329;
    $335 = HEAP32[1331243] | 0;
    $336 = $334 >>> 0 < $335 >>> 0;
    if ($336) {
      label = 75;
      break;
    } else {
      label = 74;
      break;
    }
   case 74:
    HEAP32[$329 >> 2] = $264;
    $_sum11 = $nb + 24 | 0;
    $338 = $112 + $_sum11 | 0;
    $339 = $338;
    HEAP32[$339 >> 2] = $T_0;
    $_sum12 = $nb + 12 | 0;
    $340 = $112 + $_sum12 | 0;
    $341 = $340;
    HEAP32[$341 >> 2] = $264;
    $_sum13 = $nb + 8 | 0;
    $342 = $112 + $_sum13 | 0;
    $343 = $342;
    HEAP32[$343 >> 2] = $264;
    label = 80;
    break;
   case 75:
    _abort();
    return 0;
    return 0;
   case 76:
    $346 = $T_0 + 8 | 0;
    $347 = HEAP32[$346 >> 2] | 0;
    $348 = $T_0;
    $349 = HEAP32[1331243] | 0;
    $350 = $348 >>> 0 < $349 >>> 0;
    if ($350) {
      label = 79;
      break;
    } else {
      label = 77;
      break;
    }
   case 77:
    $352 = $347;
    $353 = $352 >>> 0 < $349 >>> 0;
    if ($353) {
      label = 79;
      break;
    } else {
      label = 78;
      break;
    }
   case 78:
    $355 = $347 + 12 | 0;
    HEAP32[$355 >> 2] = $264;
    HEAP32[$346 >> 2] = $264;
    $_sum8 = $nb + 8 | 0;
    $356 = $112 + $_sum8 | 0;
    $357 = $356;
    HEAP32[$357 >> 2] = $347;
    $_sum9 = $nb + 12 | 0;
    $358 = $112 + $_sum9 | 0;
    $359 = $358;
    HEAP32[$359 >> 2] = $T_0;
    $_sum10 = $nb + 24 | 0;
    $360 = $112 + $_sum10 | 0;
    $361 = $360;
    HEAP32[$361 >> 2] = 0;
    label = 80;
    break;
   case 79:
    _abort();
    return 0;
    return 0;
   case 80:
    $363 = $v_3_lcssa + 8 | 0;
    $364 = $363;
    $_0 = $364;
    label = 82;
    break;
   case 81:
    _abort();
    return 0;
    return 0;
   case 82:
    return $_0 | 0;
  }
  return 0;
}
function _sys_alloc($nb) {
  $nb = $nb | 0;
  var $1 = 0, $2 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $or_cond1 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $ssize_0 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $or_cond = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $or_cond2 = 0, $57 = 0, $58 = 0, $ssize_0_ = 0, $_ = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $_3 = 0, $_4 = 0, $ssize_1 = 0, $br_0 = 0, $tsize_0 = 0, $tbase_0 = 0, $77 = 0, $78 = 0, $80 = 0, $81 = 0, $or_cond5 = 0, $82 = 0, $or_cond6 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $92 = 0, $93 = 0, $95 = 0, $97 = 0, $ssize_2 = 0, $99 = 0, $tsize_0172326 = 0, $100 = 0, $101 = 0, $tsize_1 = 0, $103 = 0, $105 = 0, $106 = 0, $notlhs = 0, $notrhs = 0, $or_cond8_not = 0, $107 = 0, $or_cond9 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $_tsize_1 = 0, $_tbase_1 = 0, $113 = 0, $tbase_232 = 0, $tsize_231 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $120 = 0, $121 = 0, $123 = 0, $124 = 0, $125 = 0, $or_cond10 = 0, $128 = 0, $129 = 0, $130 = 0, $sp_044 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $or_cond33 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $158 = 0, $sp_137 = 0, $160 = 0, $161 = 0, $162 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $177 = 0, $178 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $_sum = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $192 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[1312822] | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    _init_mparams();
    label = 3;
    break;
   case 3:
    $5 = $nb + 48 | 0;
    $6 = HEAP32[1312824] | 0;
    $7 = $nb + 47 | 0;
    $8 = $7 + $6 | 0;
    $9 = -$6 | 0;
    $10 = $8 & $9;
    $11 = $10 >>> 0 > $nb >>> 0;
    if ($11) {
      label = 4;
      break;
    } else {
      $_0 = 0;
      label = 51;
      break;
    }
   case 4:
    $13 = HEAP32[1331349] | 0;
    $14 = ($13 | 0) == 0;
    if ($14) {
      label = 6;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $16 = HEAP32[1331347] | 0;
    $17 = $16 + $10 | 0;
    $18 = $17 >>> 0 <= $16 >>> 0;
    $19 = $17 >>> 0 > $13 >>> 0;
    $or_cond1 = $18 | $19;
    if ($or_cond1) {
      $_0 = 0;
      label = 51;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $21 = HEAP32[1331350] | 0;
    $22 = $21 & 4;
    $23 = ($22 | 0) == 0;
    if ($23) {
      label = 7;
      break;
    } else {
      $tsize_1 = 0;
      label = 26;
      break;
    }
   case 7:
    $25 = HEAP32[1331245] | 0;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $28 = $25;
    $29 = _segment_holding($28) | 0;
    $30 = ($29 | 0) == 0;
    if ($30) {
      label = 9;
      break;
    } else {
      label = 16;
      break;
    }
   case 9:
    $31 = _sbrk(0) | 0;
    $32 = ($31 | 0) == -1;
    if ($32) {
      $tsize_0172326 = 0;
      label = 25;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $34 = $31;
    $35 = HEAP32[1312823] | 0;
    $36 = $35 - 1 | 0;
    $37 = $36 & $34;
    $38 = ($37 | 0) == 0;
    if ($38) {
      $ssize_0 = $10;
      label = 12;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $40 = $36 + $34 | 0;
    $41 = -$35 | 0;
    $42 = $40 & $41;
    $43 = $10 - $34 | 0;
    $44 = $43 + $42 | 0;
    $ssize_0 = $44;
    label = 12;
    break;
   case 12:
    $46 = HEAP32[1331347] | 0;
    $47 = $46 + $ssize_0 | 0;
    $48 = $ssize_0 >>> 0 > $nb >>> 0;
    $49 = $ssize_0 >>> 0 < 2147483647;
    $or_cond = $48 & $49;
    if ($or_cond) {
      label = 13;
      break;
    } else {
      $tsize_0172326 = 0;
      label = 25;
      break;
    }
   case 13:
    $51 = HEAP32[1331349] | 0;
    $52 = ($51 | 0) == 0;
    if ($52) {
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $54 = $47 >>> 0 <= $46 >>> 0;
    $55 = $47 >>> 0 > $51 >>> 0;
    $or_cond2 = $54 | $55;
    if ($or_cond2) {
      $tsize_0172326 = 0;
      label = 25;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $57 = _sbrk($ssize_0 | 0) | 0;
    $58 = ($57 | 0) == ($31 | 0);
    $ssize_0_ = $58 ? $ssize_0 : 0;
    $_ = $58 ? $31 : -1;
    $tbase_0 = $_;
    $tsize_0 = $ssize_0_;
    $br_0 = $57;
    $ssize_1 = $ssize_0;
    label = 18;
    break;
   case 16:
    $60 = HEAP32[1331242] | 0;
    $61 = HEAP32[1312824] | 0;
    $62 = $nb + 47 | 0;
    $63 = $62 - $60 | 0;
    $64 = $63 + $61 | 0;
    $65 = -$61 | 0;
    $66 = $64 & $65;
    $67 = $66 >>> 0 < 2147483647;
    if ($67) {
      label = 17;
      break;
    } else {
      $tsize_0172326 = 0;
      label = 25;
      break;
    }
   case 17:
    $69 = _sbrk($66 | 0) | 0;
    $70 = $29 | 0;
    $71 = HEAP32[$70 >> 2] | 0;
    $72 = $29 + 4 | 0;
    $73 = HEAP32[$72 >> 2] | 0;
    $74 = $71 + $73 | 0;
    $75 = ($69 | 0) == ($74 | 0);
    $_3 = $75 ? $66 : 0;
    $_4 = $75 ? $69 : -1;
    $tbase_0 = $_4;
    $tsize_0 = $_3;
    $br_0 = $69;
    $ssize_1 = $66;
    label = 18;
    break;
   case 18:
    $77 = -$ssize_1 | 0;
    $78 = ($tbase_0 | 0) == -1;
    if ($78) {
      label = 19;
      break;
    } else {
      $tsize_231 = $tsize_0;
      $tbase_232 = $tbase_0;
      label = 29;
      break;
    }
   case 19:
    $80 = ($br_0 | 0) != -1;
    $81 = $ssize_1 >>> 0 < 2147483647;
    $or_cond5 = $80 & $81;
    $82 = $ssize_1 >>> 0 < $5 >>> 0;
    $or_cond6 = $or_cond5 & $82;
    if ($or_cond6) {
      label = 20;
      break;
    } else {
      $ssize_2 = $ssize_1;
      label = 24;
      break;
    }
   case 20:
    $84 = HEAP32[1312824] | 0;
    $85 = $nb + 47 | 0;
    $86 = $85 - $ssize_1 | 0;
    $87 = $86 + $84 | 0;
    $88 = -$84 | 0;
    $89 = $87 & $88;
    $90 = $89 >>> 0 < 2147483647;
    if ($90) {
      label = 21;
      break;
    } else {
      $ssize_2 = $ssize_1;
      label = 24;
      break;
    }
   case 21:
    $92 = _sbrk($89 | 0) | 0;
    $93 = ($92 | 0) == -1;
    if ($93) {
      label = 23;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $95 = $89 + $ssize_1 | 0;
    $ssize_2 = $95;
    label = 24;
    break;
   case 23:
    $97 = _sbrk($77 | 0) | 0;
    $tsize_0172326 = $tsize_0;
    label = 25;
    break;
   case 24:
    $99 = ($br_0 | 0) == -1;
    if ($99) {
      $tsize_0172326 = $tsize_0;
      label = 25;
      break;
    } else {
      $tsize_231 = $ssize_2;
      $tbase_232 = $br_0;
      label = 29;
      break;
    }
   case 25:
    $100 = HEAP32[1331350] | 0;
    $101 = $100 | 4;
    HEAP32[1331350] = $101;
    $tsize_1 = $tsize_0172326;
    label = 26;
    break;
   case 26:
    $103 = $10 >>> 0 < 2147483647;
    if ($103) {
      label = 27;
      break;
    } else {
      label = 50;
      break;
    }
   case 27:
    $105 = _sbrk($10 | 0) | 0;
    $106 = _sbrk(0) | 0;
    $notlhs = ($105 | 0) != -1;
    $notrhs = ($106 | 0) != -1;
    $or_cond8_not = $notrhs & $notlhs;
    $107 = $105 >>> 0 < $106 >>> 0;
    $or_cond9 = $or_cond8_not & $107;
    if ($or_cond9) {
      label = 28;
      break;
    } else {
      label = 50;
      break;
    }
   case 28:
    $108 = $106;
    $109 = $105;
    $110 = $108 - $109 | 0;
    $111 = $nb + 40 | 0;
    $112 = $110 >>> 0 > $111 >>> 0;
    $_tsize_1 = $112 ? $110 : $tsize_1;
    $_tbase_1 = $112 ? $105 : -1;
    $113 = ($_tbase_1 | 0) == -1;
    if ($113) {
      label = 50;
      break;
    } else {
      $tsize_231 = $_tsize_1;
      $tbase_232 = $_tbase_1;
      label = 29;
      break;
    }
   case 29:
    $114 = HEAP32[1331347] | 0;
    $115 = $114 + $tsize_231 | 0;
    HEAP32[1331347] = $115;
    $116 = HEAP32[1331348] | 0;
    $117 = $115 >>> 0 > $116 >>> 0;
    if ($117) {
      label = 30;
      break;
    } else {
      label = 31;
      break;
    }
   case 30:
    HEAP32[1331348] = $115;
    label = 31;
    break;
   case 31:
    $120 = HEAP32[1331245] | 0;
    $121 = ($120 | 0) == 0;
    if ($121) {
      label = 32;
      break;
    } else {
      $sp_044 = 5325404;
      label = 35;
      break;
    }
   case 32:
    $123 = HEAP32[1331243] | 0;
    $124 = ($123 | 0) == 0;
    $125 = $tbase_232 >>> 0 < $123 >>> 0;
    $or_cond10 = $124 | $125;
    if ($or_cond10) {
      label = 33;
      break;
    } else {
      label = 34;
      break;
    }
   case 33:
    HEAP32[1331243] = $tbase_232;
    label = 34;
    break;
   case 34:
    HEAP32[1331351] = $tbase_232;
    HEAP32[1331352] = $tsize_231;
    HEAP32[1331354] = 0;
    $128 = HEAP32[1312822] | 0;
    HEAP32[1331248] = $128;
    HEAP32[1331247] = -1;
    _init_bins();
    $129 = $tbase_232;
    $130 = $tsize_231 - 40 | 0;
    _init_top($129, $130);
    label = 48;
    break;
   case 35:
    $131 = $sp_044 | 0;
    $132 = HEAP32[$131 >> 2] | 0;
    $133 = $sp_044 + 4 | 0;
    $134 = HEAP32[$133 >> 2] | 0;
    $135 = $132 + $134 | 0;
    $136 = ($tbase_232 | 0) == ($135 | 0);
    if ($136) {
      label = 37;
      break;
    } else {
      label = 36;
      break;
    }
   case 36:
    $138 = $sp_044 + 8 | 0;
    $139 = HEAP32[$138 >> 2] | 0;
    $140 = ($139 | 0) == 0;
    if ($140) {
      label = 40;
      break;
    } else {
      $sp_044 = $139;
      label = 35;
      break;
    }
   case 37:
    $141 = $sp_044 + 12 | 0;
    $142 = HEAP32[$141 >> 2] | 0;
    $143 = $142 & 8;
    $144 = ($143 | 0) == 0;
    if ($144) {
      label = 38;
      break;
    } else {
      label = 40;
      break;
    }
   case 38:
    $146 = HEAP32[1331245] | 0;
    $147 = $146;
    $148 = $147 >>> 0 >= $132 >>> 0;
    $149 = $147 >>> 0 < $135 >>> 0;
    $or_cond33 = $148 & $149;
    if ($or_cond33) {
      label = 39;
      break;
    } else {
      label = 40;
      break;
    }
   case 39:
    $151 = $134 + $tsize_231 | 0;
    HEAP32[$133 >> 2] = $151;
    $152 = HEAP32[1331245] | 0;
    $153 = HEAP32[1331242] | 0;
    $154 = $153 + $tsize_231 | 0;
    _init_top($152, $154);
    label = 48;
    break;
   case 40:
    $155 = HEAP32[1331243] | 0;
    $156 = $tbase_232 >>> 0 < $155 >>> 0;
    if ($156) {
      label = 41;
      break;
    } else {
      label = 42;
      break;
    }
   case 41:
    HEAP32[1331243] = $tbase_232;
    label = 42;
    break;
   case 42:
    $158 = $tbase_232 + $tsize_231 | 0;
    $sp_137 = 5325404;
    label = 43;
    break;
   case 43:
    $160 = $sp_137 | 0;
    $161 = HEAP32[$160 >> 2] | 0;
    $162 = ($161 | 0) == ($158 | 0);
    if ($162) {
      label = 45;
      break;
    } else {
      label = 44;
      break;
    }
   case 44:
    $164 = $sp_137 + 8 | 0;
    $165 = HEAP32[$164 >> 2] | 0;
    $166 = ($165 | 0) == 0;
    if ($166) {
      label = 47;
      break;
    } else {
      $sp_137 = $165;
      label = 43;
      break;
    }
   case 45:
    $167 = $sp_137 + 12 | 0;
    $168 = HEAP32[$167 >> 2] | 0;
    $169 = $168 & 8;
    $170 = ($169 | 0) == 0;
    if ($170) {
      label = 46;
      break;
    } else {
      label = 47;
      break;
    }
   case 46:
    HEAP32[$160 >> 2] = $tbase_232;
    $172 = $sp_137 + 4 | 0;
    $173 = HEAP32[$172 >> 2] | 0;
    $174 = $173 + $tsize_231 | 0;
    HEAP32[$172 >> 2] = $174;
    $175 = _prepend_alloc($tbase_232, $161, $nb) | 0;
    $_0 = $175;
    label = 51;
    break;
   case 47:
    _add_segment($tbase_232, $tsize_231);
    label = 48;
    break;
   case 48:
    $177 = HEAP32[1331242] | 0;
    $178 = $177 >>> 0 > $nb >>> 0;
    if ($178) {
      label = 49;
      break;
    } else {
      label = 50;
      break;
    }
   case 49:
    $180 = $177 - $nb | 0;
    HEAP32[1331242] = $180;
    $181 = HEAP32[1331245] | 0;
    $182 = $181;
    $183 = $182 + $nb | 0;
    $184 = $183;
    HEAP32[1331245] = $184;
    $185 = $180 | 1;
    $_sum = $nb + 4 | 0;
    $186 = $182 + $_sum | 0;
    $187 = $186;
    HEAP32[$187 >> 2] = $185;
    $188 = $nb | 3;
    $189 = $181 + 4 | 0;
    HEAP32[$189 >> 2] = $188;
    $190 = $181 + 8 | 0;
    $191 = $190;
    $_0 = $191;
    label = 51;
    break;
   case 50:
    $192 = ___errno_location() | 0;
    HEAP32[$192 >> 2] = 12;
    $_0 = 0;
    label = 51;
    break;
   case 51:
    return $_0 | 0;
  }
  return 0;
}
function _free($mem) {
  $mem = $mem | 0;
  var $1 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $_sum = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $_sum232 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $_sum266 = 0, $35 = 0, $36 = 0, $37 = 0, $_sum267 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $71 = 0, $_sum258 = 0, $72 = 0, $73 = 0, $74 = 0, $_sum259 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $_sum265 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $86 = 0, $87 = 0, $88 = 0, $90 = 0, $91 = 0, $92 = 0, $_sum261 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $_sum260 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $RP_0 = 0, $R_0 = 0, $104 = 0, $105 = 0, $106 = 0, $108 = 0, $109 = 0, $110 = 0, $CP_0 = 0, $111 = 0, $113 = 0, $114 = 0, $115 = 0, $R_1 = 0, $119 = 0, $_sum262 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $cond = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $134 = 0, $135 = 0, $136 = 0, $138 = 0, $139 = 0, $140 = 0, $143 = 0, $146 = 0, $148 = 0, $149 = 0, $150 = 0, $152 = 0, $_sum263 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $158 = 0, $159 = 0, $160 = 0, $162 = 0, $163 = 0, $_sum264 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $171 = 0, $172 = 0, $173 = 0, $175 = 0, $176 = 0, $_sum233 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $186 = 0, $187 = 0, $188 = 0, $_sum256 = 0, $189 = 0, $190 = 0, $191 = 0, $psize_0 = 0, $p_0 = 0, $193 = 0, $194 = 0, $_sum255 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $200 = 0, $202 = 0, $203 = 0, $205 = 0, $206 = 0, $208 = 0, $209 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $216 = 0, $217 = 0, $219 = 0, $221 = 0, $222 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $236 = 0, $237 = 0, $238 = 0, $_sum253254 = 0, $239 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $247 = 0, $248 = 0, $249 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $261 = 0, $263 = 0, $264 = 0, $265 = 0, $267 = 0, $268 = 0, $269 = 0, $270 = 0, $271 = 0, $273 = 0, $_sum235 = 0, $274 = 0, $275 = 0, $276 = 0, $_sum236237 = 0, $277 = 0, $278 = 0, $279 = 0, $280 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $289 = 0, $290 = 0, $291 = 0, $293 = 0, $294 = 0, $295 = 0, $_sum239 = 0, $298 = 0, $299 = 0, $300 = 0, $301 = 0, $_sum238 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $RP9_0 = 0, $R7_0 = 0, $307 = 0, $308 = 0, $309 = 0, $311 = 0, $312 = 0, $313 = 0, $CP10_0 = 0, $314 = 0, $316 = 0, $317 = 0, $318 = 0, $R7_1 = 0, $322 = 0, $_sum248 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $cond284 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $337 = 0, $338 = 0, $339 = 0, $341 = 0, $342 = 0, $343 = 0, $346 = 0, $349 = 0, $351 = 0, $352 = 0, $353 = 0, $355 = 0, $_sum249 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $361 = 0, $362 = 0, $363 = 0, $365 = 0, $366 = 0, $_sum250 = 0, $369 = 0, $370 = 0, $371 = 0, $372 = 0, $374 = 0, $375 = 0, $376 = 0, $378 = 0, $379 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $psize_1 = 0, $397 = 0, $398 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $408 = 0, $_sum247 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $F16_0 = 0, $_sum246 = 0, $417 = 0, $418 = 0, $419 = 0, $420 = 0, $422 = 0, $423 = 0, $424 = 0, $426 = 0, $428 = 0, $429 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $I18_0 = 0, $451 = 0, $452 = 0, $I18_0_c = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $460 = 0, $461 = 0, $_c = 0, $462 = 0, $463 = 0, $465 = 0, $466 = 0, $468 = 0, $469 = 0, $471 = 0, $472 = 0, $T_0 = 0, $K19_0 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $479 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $485 = 0, $486 = 0, $487 = 0, $489 = 0, $T_0_c243 = 0, $490 = 0, $491 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $500 = 0, $501 = 0, $503 = 0, $504 = 0, $_c242 = 0, $505 = 0, $T_0_c = 0, $506 = 0, $508 = 0, $509 = 0, $510 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($mem | 0) == 0;
    if ($1) {
      label = 141;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $3 = $mem - 8 | 0;
    $4 = $3;
    $5 = HEAP32[1331243] | 0;
    $6 = $3 >>> 0 < $5 >>> 0;
    if ($6) {
      label = 140;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $8 = $mem - 4 | 0;
    $9 = $8;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $10 & 3;
    $12 = ($11 | 0) == 1;
    if ($12) {
      label = 140;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $14 = $10 & -8;
    $_sum = $14 - 8 | 0;
    $15 = $mem + $_sum | 0;
    $16 = $15;
    $17 = $10 & 1;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 5;
      break;
    } else {
      $p_0 = $4;
      $psize_0 = $14;
      label = 56;
      break;
    }
   case 5:
    $20 = $3;
    $21 = HEAP32[$20 >> 2] | 0;
    $22 = ($11 | 0) == 0;
    if ($22) {
      label = 141;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $_sum232 = -8 - $21 | 0;
    $24 = $mem + $_sum232 | 0;
    $25 = $24;
    $26 = $21 + $14 | 0;
    $27 = $24 >>> 0 < $5 >>> 0;
    if ($27) {
      label = 140;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $29 = HEAP32[1331244] | 0;
    $30 = ($25 | 0) == ($29 | 0);
    if ($30) {
      label = 54;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $32 = $21 >>> 3;
    $33 = $21 >>> 0 < 256;
    if ($33) {
      label = 9;
      break;
    } else {
      label = 20;
      break;
    }
   case 9:
    $_sum266 = $_sum232 + 8 | 0;
    $35 = $mem + $_sum266 | 0;
    $36 = $35;
    $37 = HEAP32[$36 >> 2] | 0;
    $_sum267 = $_sum232 + 12 | 0;
    $38 = $mem + $_sum267 | 0;
    $39 = $38;
    $40 = HEAP32[$39 >> 2] | 0;
    $41 = $32 << 1;
    $42 = 5324996 + ($41 << 2) | 0;
    $43 = $42;
    $44 = ($37 | 0) == ($43 | 0);
    if ($44) {
      label = 12;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $46 = $37;
    $47 = $46 >>> 0 < $5 >>> 0;
    if ($47) {
      label = 19;
      break;
    } else {
      label = 11;
      break;
    }
   case 11:
    $49 = $37 + 12 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = ($50 | 0) == ($25 | 0);
    if ($51) {
      label = 12;
      break;
    } else {
      label = 19;
      break;
    }
   case 12:
    $52 = ($40 | 0) == ($37 | 0);
    if ($52) {
      label = 13;
      break;
    } else {
      label = 14;
      break;
    }
   case 13:
    $54 = 1 << $32;
    $55 = $54 ^ -1;
    $56 = HEAP32[1331239] | 0;
    $57 = $56 & $55;
    HEAP32[1331239] = $57;
    $p_0 = $25;
    $psize_0 = $26;
    label = 56;
    break;
   case 14:
    $59 = ($40 | 0) == ($43 | 0);
    if ($59) {
      label = 17;
      break;
    } else {
      label = 15;
      break;
    }
   case 15:
    $61 = $40;
    $62 = HEAP32[1331243] | 0;
    $63 = $61 >>> 0 < $62 >>> 0;
    if ($63) {
      label = 18;
      break;
    } else {
      label = 16;
      break;
    }
   case 16:
    $65 = $40 + 8 | 0;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = ($66 | 0) == ($25 | 0);
    if ($67) {
      label = 17;
      break;
    } else {
      label = 18;
      break;
    }
   case 17:
    $68 = $37 + 12 | 0;
    HEAP32[$68 >> 2] = $40;
    $69 = $40 + 8 | 0;
    HEAP32[$69 >> 2] = $37;
    $p_0 = $25;
    $psize_0 = $26;
    label = 56;
    break;
   case 18:
    _abort();
   case 19:
    _abort();
   case 20:
    $71 = $24;
    $_sum258 = $_sum232 + 24 | 0;
    $72 = $mem + $_sum258 | 0;
    $73 = $72;
    $74 = HEAP32[$73 >> 2] | 0;
    $_sum259 = $_sum232 + 12 | 0;
    $75 = $mem + $_sum259 | 0;
    $76 = $75;
    $77 = HEAP32[$76 >> 2] | 0;
    $78 = ($77 | 0) == ($71 | 0);
    if ($78) {
      label = 26;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $_sum265 = $_sum232 + 8 | 0;
    $80 = $mem + $_sum265 | 0;
    $81 = $80;
    $82 = HEAP32[$81 >> 2] | 0;
    $83 = $82;
    $84 = $83 >>> 0 < $5 >>> 0;
    if ($84) {
      label = 25;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $86 = $82 + 12 | 0;
    $87 = HEAP32[$86 >> 2] | 0;
    $88 = ($87 | 0) == ($71 | 0);
    if ($88) {
      label = 23;
      break;
    } else {
      label = 25;
      break;
    }
   case 23:
    $90 = $77 + 8 | 0;
    $91 = HEAP32[$90 >> 2] | 0;
    $92 = ($91 | 0) == ($71 | 0);
    if ($92) {
      label = 24;
      break;
    } else {
      label = 25;
      break;
    }
   case 24:
    HEAP32[$86 >> 2] = $77;
    HEAP32[$90 >> 2] = $82;
    $R_1 = $77;
    label = 34;
    break;
   case 25:
    _abort();
   case 26:
    $_sum261 = $_sum232 + 20 | 0;
    $95 = $mem + $_sum261 | 0;
    $96 = $95;
    $97 = HEAP32[$96 >> 2] | 0;
    $98 = ($97 | 0) == 0;
    if ($98) {
      label = 27;
      break;
    } else {
      $R_0 = $97;
      $RP_0 = $96;
      label = 28;
      break;
    }
   case 27:
    $_sum260 = $_sum232 + 16 | 0;
    $100 = $mem + $_sum260 | 0;
    $101 = $100;
    $102 = HEAP32[$101 >> 2] | 0;
    $103 = ($102 | 0) == 0;
    if ($103) {
      $R_1 = 0;
      label = 34;
      break;
    } else {
      $R_0 = $102;
      $RP_0 = $101;
      label = 28;
      break;
    }
   case 28:
    $104 = $R_0 + 20 | 0;
    $105 = HEAP32[$104 >> 2] | 0;
    $106 = ($105 | 0) == 0;
    if ($106) {
      label = 29;
      break;
    } else {
      $CP_0 = $104;
      label = 30;
      break;
    }
   case 29:
    $108 = $R_0 + 16 | 0;
    $109 = HEAP32[$108 >> 2] | 0;
    $110 = ($109 | 0) == 0;
    if ($110) {
      label = 31;
      break;
    } else {
      $CP_0 = $108;
      label = 30;
      break;
    }
   case 30:
    $111 = HEAP32[$CP_0 >> 2] | 0;
    $R_0 = $111;
    $RP_0 = $CP_0;
    label = 28;
    break;
   case 31:
    $113 = $RP_0;
    $114 = HEAP32[1331243] | 0;
    $115 = $113 >>> 0 < $114 >>> 0;
    if ($115) {
      label = 33;
      break;
    } else {
      label = 32;
      break;
    }
   case 32:
    HEAP32[$RP_0 >> 2] = 0;
    $R_1 = $R_0;
    label = 34;
    break;
   case 33:
    _abort();
   case 34:
    $119 = ($74 | 0) == 0;
    if ($119) {
      $p_0 = $25;
      $psize_0 = $26;
      label = 56;
      break;
    } else {
      label = 35;
      break;
    }
   case 35:
    $_sum262 = $_sum232 + 28 | 0;
    $121 = $mem + $_sum262 | 0;
    $122 = $121;
    $123 = HEAP32[$122 >> 2] | 0;
    $124 = 5325260 + ($123 << 2) | 0;
    $125 = HEAP32[$124 >> 2] | 0;
    $126 = ($71 | 0) == ($125 | 0);
    if ($126) {
      label = 36;
      break;
    } else {
      label = 38;
      break;
    }
   case 36:
    HEAP32[$124 >> 2] = $R_1;
    $cond = ($R_1 | 0) == 0;
    if ($cond) {
      label = 37;
      break;
    } else {
      label = 44;
      break;
    }
   case 37:
    $128 = HEAP32[$122 >> 2] | 0;
    $129 = 1 << $128;
    $130 = $129 ^ -1;
    $131 = HEAP32[1331240] | 0;
    $132 = $131 & $130;
    HEAP32[1331240] = $132;
    $p_0 = $25;
    $psize_0 = $26;
    label = 56;
    break;
   case 38:
    $134 = $74;
    $135 = HEAP32[1331243] | 0;
    $136 = $134 >>> 0 < $135 >>> 0;
    if ($136) {
      label = 42;
      break;
    } else {
      label = 39;
      break;
    }
   case 39:
    $138 = $74 + 16 | 0;
    $139 = HEAP32[$138 >> 2] | 0;
    $140 = ($139 | 0) == ($71 | 0);
    if ($140) {
      label = 40;
      break;
    } else {
      label = 41;
      break;
    }
   case 40:
    HEAP32[$138 >> 2] = $R_1;
    label = 43;
    break;
   case 41:
    $143 = $74 + 20 | 0;
    HEAP32[$143 >> 2] = $R_1;
    label = 43;
    break;
   case 42:
    _abort();
   case 43:
    $146 = ($R_1 | 0) == 0;
    if ($146) {
      $p_0 = $25;
      $psize_0 = $26;
      label = 56;
      break;
    } else {
      label = 44;
      break;
    }
   case 44:
    $148 = $R_1;
    $149 = HEAP32[1331243] | 0;
    $150 = $148 >>> 0 < $149 >>> 0;
    if ($150) {
      label = 53;
      break;
    } else {
      label = 45;
      break;
    }
   case 45:
    $152 = $R_1 + 24 | 0;
    HEAP32[$152 >> 2] = $74;
    $_sum263 = $_sum232 + 16 | 0;
    $153 = $mem + $_sum263 | 0;
    $154 = $153;
    $155 = HEAP32[$154 >> 2] | 0;
    $156 = ($155 | 0) == 0;
    if ($156) {
      label = 49;
      break;
    } else {
      label = 46;
      break;
    }
   case 46:
    $158 = $155;
    $159 = HEAP32[1331243] | 0;
    $160 = $158 >>> 0 < $159 >>> 0;
    if ($160) {
      label = 48;
      break;
    } else {
      label = 47;
      break;
    }
   case 47:
    $162 = $R_1 + 16 | 0;
    HEAP32[$162 >> 2] = $155;
    $163 = $155 + 24 | 0;
    HEAP32[$163 >> 2] = $R_1;
    label = 49;
    break;
   case 48:
    _abort();
   case 49:
    $_sum264 = $_sum232 + 20 | 0;
    $166 = $mem + $_sum264 | 0;
    $167 = $166;
    $168 = HEAP32[$167 >> 2] | 0;
    $169 = ($168 | 0) == 0;
    if ($169) {
      $p_0 = $25;
      $psize_0 = $26;
      label = 56;
      break;
    } else {
      label = 50;
      break;
    }
   case 50:
    $171 = $168;
    $172 = HEAP32[1331243] | 0;
    $173 = $171 >>> 0 < $172 >>> 0;
    if ($173) {
      label = 52;
      break;
    } else {
      label = 51;
      break;
    }
   case 51:
    $175 = $R_1 + 20 | 0;
    HEAP32[$175 >> 2] = $168;
    $176 = $168 + 24 | 0;
    HEAP32[$176 >> 2] = $R_1;
    $p_0 = $25;
    $psize_0 = $26;
    label = 56;
    break;
   case 52:
    _abort();
   case 53:
    _abort();
   case 54:
    $_sum233 = $14 - 4 | 0;
    $180 = $mem + $_sum233 | 0;
    $181 = $180;
    $182 = HEAP32[$181 >> 2] | 0;
    $183 = $182 & 3;
    $184 = ($183 | 0) == 3;
    if ($184) {
      label = 55;
      break;
    } else {
      $p_0 = $25;
      $psize_0 = $26;
      label = 56;
      break;
    }
   case 55:
    HEAP32[1331241] = $26;
    $186 = HEAP32[$181 >> 2] | 0;
    $187 = $186 & -2;
    HEAP32[$181 >> 2] = $187;
    $188 = $26 | 1;
    $_sum256 = $_sum232 + 4 | 0;
    $189 = $mem + $_sum256 | 0;
    $190 = $189;
    HEAP32[$190 >> 2] = $188;
    $191 = $15;
    HEAP32[$191 >> 2] = $26;
    label = 141;
    break;
   case 56:
    $193 = $p_0;
    $194 = $193 >>> 0 < $15 >>> 0;
    if ($194) {
      label = 57;
      break;
    } else {
      label = 140;
      break;
    }
   case 57:
    $_sum255 = $14 - 4 | 0;
    $196 = $mem + $_sum255 | 0;
    $197 = $196;
    $198 = HEAP32[$197 >> 2] | 0;
    $199 = $198 & 1;
    $200 = ($199 | 0) == 0;
    if ($200) {
      label = 140;
      break;
    } else {
      label = 58;
      break;
    }
   case 58:
    $202 = $198 & 2;
    $203 = ($202 | 0) == 0;
    if ($203) {
      label = 59;
      break;
    } else {
      label = 114;
      break;
    }
   case 59:
    $205 = HEAP32[1331245] | 0;
    $206 = ($16 | 0) == ($205 | 0);
    if ($206) {
      label = 60;
      break;
    } else {
      label = 64;
      break;
    }
   case 60:
    $208 = HEAP32[1331242] | 0;
    $209 = $208 + $psize_0 | 0;
    HEAP32[1331242] = $209;
    HEAP32[1331245] = $p_0;
    $210 = $209 | 1;
    $211 = $p_0 + 4 | 0;
    HEAP32[$211 >> 2] = $210;
    $212 = HEAP32[1331244] | 0;
    $213 = ($p_0 | 0) == ($212 | 0);
    if ($213) {
      label = 61;
      break;
    } else {
      label = 62;
      break;
    }
   case 61:
    HEAP32[1331244] = 0;
    HEAP32[1331241] = 0;
    label = 62;
    break;
   case 62:
    $216 = HEAP32[1331246] | 0;
    $217 = $209 >>> 0 > $216 >>> 0;
    if ($217) {
      label = 63;
      break;
    } else {
      label = 141;
      break;
    }
   case 63:
    $219 = _sys_trim(0) | 0;
    label = 141;
    break;
   case 64:
    $221 = HEAP32[1331244] | 0;
    $222 = ($16 | 0) == ($221 | 0);
    if ($222) {
      label = 65;
      break;
    } else {
      label = 66;
      break;
    }
   case 65:
    $224 = HEAP32[1331241] | 0;
    $225 = $224 + $psize_0 | 0;
    HEAP32[1331241] = $225;
    HEAP32[1331244] = $p_0;
    $226 = $225 | 1;
    $227 = $p_0 + 4 | 0;
    HEAP32[$227 >> 2] = $226;
    $228 = $193 + $225 | 0;
    $229 = $228;
    HEAP32[$229 >> 2] = $225;
    label = 141;
    break;
   case 66:
    $231 = $198 & -8;
    $232 = $231 + $psize_0 | 0;
    $233 = $198 >>> 3;
    $234 = $198 >>> 0 < 256;
    if ($234) {
      label = 67;
      break;
    } else {
      label = 78;
      break;
    }
   case 67:
    $236 = $mem + $14 | 0;
    $237 = $236;
    $238 = HEAP32[$237 >> 2] | 0;
    $_sum253254 = $14 | 4;
    $239 = $mem + $_sum253254 | 0;
    $240 = $239;
    $241 = HEAP32[$240 >> 2] | 0;
    $242 = $233 << 1;
    $243 = 5324996 + ($242 << 2) | 0;
    $244 = $243;
    $245 = ($238 | 0) == ($244 | 0);
    if ($245) {
      label = 70;
      break;
    } else {
      label = 68;
      break;
    }
   case 68:
    $247 = $238;
    $248 = HEAP32[1331243] | 0;
    $249 = $247 >>> 0 < $248 >>> 0;
    if ($249) {
      label = 77;
      break;
    } else {
      label = 69;
      break;
    }
   case 69:
    $251 = $238 + 12 | 0;
    $252 = HEAP32[$251 >> 2] | 0;
    $253 = ($252 | 0) == ($16 | 0);
    if ($253) {
      label = 70;
      break;
    } else {
      label = 77;
      break;
    }
   case 70:
    $254 = ($241 | 0) == ($238 | 0);
    if ($254) {
      label = 71;
      break;
    } else {
      label = 72;
      break;
    }
   case 71:
    $256 = 1 << $233;
    $257 = $256 ^ -1;
    $258 = HEAP32[1331239] | 0;
    $259 = $258 & $257;
    HEAP32[1331239] = $259;
    label = 112;
    break;
   case 72:
    $261 = ($241 | 0) == ($244 | 0);
    if ($261) {
      label = 75;
      break;
    } else {
      label = 73;
      break;
    }
   case 73:
    $263 = $241;
    $264 = HEAP32[1331243] | 0;
    $265 = $263 >>> 0 < $264 >>> 0;
    if ($265) {
      label = 76;
      break;
    } else {
      label = 74;
      break;
    }
   case 74:
    $267 = $241 + 8 | 0;
    $268 = HEAP32[$267 >> 2] | 0;
    $269 = ($268 | 0) == ($16 | 0);
    if ($269) {
      label = 75;
      break;
    } else {
      label = 76;
      break;
    }
   case 75:
    $270 = $238 + 12 | 0;
    HEAP32[$270 >> 2] = $241;
    $271 = $241 + 8 | 0;
    HEAP32[$271 >> 2] = $238;
    label = 112;
    break;
   case 76:
    _abort();
   case 77:
    _abort();
   case 78:
    $273 = $15;
    $_sum235 = $14 + 16 | 0;
    $274 = $mem + $_sum235 | 0;
    $275 = $274;
    $276 = HEAP32[$275 >> 2] | 0;
    $_sum236237 = $14 | 4;
    $277 = $mem + $_sum236237 | 0;
    $278 = $277;
    $279 = HEAP32[$278 >> 2] | 0;
    $280 = ($279 | 0) == ($273 | 0);
    if ($280) {
      label = 84;
      break;
    } else {
      label = 79;
      break;
    }
   case 79:
    $282 = $mem + $14 | 0;
    $283 = $282;
    $284 = HEAP32[$283 >> 2] | 0;
    $285 = $284;
    $286 = HEAP32[1331243] | 0;
    $287 = $285 >>> 0 < $286 >>> 0;
    if ($287) {
      label = 83;
      break;
    } else {
      label = 80;
      break;
    }
   case 80:
    $289 = $284 + 12 | 0;
    $290 = HEAP32[$289 >> 2] | 0;
    $291 = ($290 | 0) == ($273 | 0);
    if ($291) {
      label = 81;
      break;
    } else {
      label = 83;
      break;
    }
   case 81:
    $293 = $279 + 8 | 0;
    $294 = HEAP32[$293 >> 2] | 0;
    $295 = ($294 | 0) == ($273 | 0);
    if ($295) {
      label = 82;
      break;
    } else {
      label = 83;
      break;
    }
   case 82:
    HEAP32[$289 >> 2] = $279;
    HEAP32[$293 >> 2] = $284;
    $R7_1 = $279;
    label = 92;
    break;
   case 83:
    _abort();
   case 84:
    $_sum239 = $14 + 12 | 0;
    $298 = $mem + $_sum239 | 0;
    $299 = $298;
    $300 = HEAP32[$299 >> 2] | 0;
    $301 = ($300 | 0) == 0;
    if ($301) {
      label = 85;
      break;
    } else {
      $R7_0 = $300;
      $RP9_0 = $299;
      label = 86;
      break;
    }
   case 85:
    $_sum238 = $14 + 8 | 0;
    $303 = $mem + $_sum238 | 0;
    $304 = $303;
    $305 = HEAP32[$304 >> 2] | 0;
    $306 = ($305 | 0) == 0;
    if ($306) {
      $R7_1 = 0;
      label = 92;
      break;
    } else {
      $R7_0 = $305;
      $RP9_0 = $304;
      label = 86;
      break;
    }
   case 86:
    $307 = $R7_0 + 20 | 0;
    $308 = HEAP32[$307 >> 2] | 0;
    $309 = ($308 | 0) == 0;
    if ($309) {
      label = 87;
      break;
    } else {
      $CP10_0 = $307;
      label = 88;
      break;
    }
   case 87:
    $311 = $R7_0 + 16 | 0;
    $312 = HEAP32[$311 >> 2] | 0;
    $313 = ($312 | 0) == 0;
    if ($313) {
      label = 89;
      break;
    } else {
      $CP10_0 = $311;
      label = 88;
      break;
    }
   case 88:
    $314 = HEAP32[$CP10_0 >> 2] | 0;
    $R7_0 = $314;
    $RP9_0 = $CP10_0;
    label = 86;
    break;
   case 89:
    $316 = $RP9_0;
    $317 = HEAP32[1331243] | 0;
    $318 = $316 >>> 0 < $317 >>> 0;
    if ($318) {
      label = 91;
      break;
    } else {
      label = 90;
      break;
    }
   case 90:
    HEAP32[$RP9_0 >> 2] = 0;
    $R7_1 = $R7_0;
    label = 92;
    break;
   case 91:
    _abort();
   case 92:
    $322 = ($276 | 0) == 0;
    if ($322) {
      label = 112;
      break;
    } else {
      label = 93;
      break;
    }
   case 93:
    $_sum248 = $14 + 20 | 0;
    $324 = $mem + $_sum248 | 0;
    $325 = $324;
    $326 = HEAP32[$325 >> 2] | 0;
    $327 = 5325260 + ($326 << 2) | 0;
    $328 = HEAP32[$327 >> 2] | 0;
    $329 = ($273 | 0) == ($328 | 0);
    if ($329) {
      label = 94;
      break;
    } else {
      label = 96;
      break;
    }
   case 94:
    HEAP32[$327 >> 2] = $R7_1;
    $cond284 = ($R7_1 | 0) == 0;
    if ($cond284) {
      label = 95;
      break;
    } else {
      label = 102;
      break;
    }
   case 95:
    $331 = HEAP32[$325 >> 2] | 0;
    $332 = 1 << $331;
    $333 = $332 ^ -1;
    $334 = HEAP32[1331240] | 0;
    $335 = $334 & $333;
    HEAP32[1331240] = $335;
    label = 112;
    break;
   case 96:
    $337 = $276;
    $338 = HEAP32[1331243] | 0;
    $339 = $337 >>> 0 < $338 >>> 0;
    if ($339) {
      label = 100;
      break;
    } else {
      label = 97;
      break;
    }
   case 97:
    $341 = $276 + 16 | 0;
    $342 = HEAP32[$341 >> 2] | 0;
    $343 = ($342 | 0) == ($273 | 0);
    if ($343) {
      label = 98;
      break;
    } else {
      label = 99;
      break;
    }
   case 98:
    HEAP32[$341 >> 2] = $R7_1;
    label = 101;
    break;
   case 99:
    $346 = $276 + 20 | 0;
    HEAP32[$346 >> 2] = $R7_1;
    label = 101;
    break;
   case 100:
    _abort();
   case 101:
    $349 = ($R7_1 | 0) == 0;
    if ($349) {
      label = 112;
      break;
    } else {
      label = 102;
      break;
    }
   case 102:
    $351 = $R7_1;
    $352 = HEAP32[1331243] | 0;
    $353 = $351 >>> 0 < $352 >>> 0;
    if ($353) {
      label = 111;
      break;
    } else {
      label = 103;
      break;
    }
   case 103:
    $355 = $R7_1 + 24 | 0;
    HEAP32[$355 >> 2] = $276;
    $_sum249 = $14 + 8 | 0;
    $356 = $mem + $_sum249 | 0;
    $357 = $356;
    $358 = HEAP32[$357 >> 2] | 0;
    $359 = ($358 | 0) == 0;
    if ($359) {
      label = 107;
      break;
    } else {
      label = 104;
      break;
    }
   case 104:
    $361 = $358;
    $362 = HEAP32[1331243] | 0;
    $363 = $361 >>> 0 < $362 >>> 0;
    if ($363) {
      label = 106;
      break;
    } else {
      label = 105;
      break;
    }
   case 105:
    $365 = $R7_1 + 16 | 0;
    HEAP32[$365 >> 2] = $358;
    $366 = $358 + 24 | 0;
    HEAP32[$366 >> 2] = $R7_1;
    label = 107;
    break;
   case 106:
    _abort();
   case 107:
    $_sum250 = $14 + 12 | 0;
    $369 = $mem + $_sum250 | 0;
    $370 = $369;
    $371 = HEAP32[$370 >> 2] | 0;
    $372 = ($371 | 0) == 0;
    if ($372) {
      label = 112;
      break;
    } else {
      label = 108;
      break;
    }
   case 108:
    $374 = $371;
    $375 = HEAP32[1331243] | 0;
    $376 = $374 >>> 0 < $375 >>> 0;
    if ($376) {
      label = 110;
      break;
    } else {
      label = 109;
      break;
    }
   case 109:
    $378 = $R7_1 + 20 | 0;
    HEAP32[$378 >> 2] = $371;
    $379 = $371 + 24 | 0;
    HEAP32[$379 >> 2] = $R7_1;
    label = 112;
    break;
   case 110:
    _abort();
   case 111:
    _abort();
   case 112:
    $383 = $232 | 1;
    $384 = $p_0 + 4 | 0;
    HEAP32[$384 >> 2] = $383;
    $385 = $193 + $232 | 0;
    $386 = $385;
    HEAP32[$386 >> 2] = $232;
    $387 = HEAP32[1331244] | 0;
    $388 = ($p_0 | 0) == ($387 | 0);
    if ($388) {
      label = 113;
      break;
    } else {
      $psize_1 = $232;
      label = 115;
      break;
    }
   case 113:
    HEAP32[1331241] = $232;
    label = 141;
    break;
   case 114:
    $391 = $198 & -2;
    HEAP32[$197 >> 2] = $391;
    $392 = $psize_0 | 1;
    $393 = $p_0 + 4 | 0;
    HEAP32[$393 >> 2] = $392;
    $394 = $193 + $psize_0 | 0;
    $395 = $394;
    HEAP32[$395 >> 2] = $psize_0;
    $psize_1 = $psize_0;
    label = 115;
    break;
   case 115:
    $397 = $psize_1 >>> 3;
    $398 = $psize_1 >>> 0 < 256;
    if ($398) {
      label = 116;
      break;
    } else {
      label = 121;
      break;
    }
   case 116:
    $400 = $397 << 1;
    $401 = 5324996 + ($400 << 2) | 0;
    $402 = $401;
    $403 = HEAP32[1331239] | 0;
    $404 = 1 << $397;
    $405 = $403 & $404;
    $406 = ($405 | 0) == 0;
    if ($406) {
      label = 117;
      break;
    } else {
      label = 118;
      break;
    }
   case 117:
    $408 = $403 | $404;
    HEAP32[1331239] = $408;
    $F16_0 = $402;
    label = 120;
    break;
   case 118:
    $_sum247 = $400 + 2 | 0;
    $410 = 5324996 + ($_sum247 << 2) | 0;
    $411 = HEAP32[$410 >> 2] | 0;
    $412 = $411;
    $413 = HEAP32[1331243] | 0;
    $414 = $412 >>> 0 < $413 >>> 0;
    if ($414) {
      label = 119;
      break;
    } else {
      $F16_0 = $411;
      label = 120;
      break;
    }
   case 119:
    _abort();
   case 120:
    $_sum246 = $400 + 2 | 0;
    $417 = 5324996 + ($_sum246 << 2) | 0;
    HEAP32[$417 >> 2] = $p_0;
    $418 = $F16_0 + 12 | 0;
    HEAP32[$418 >> 2] = $p_0;
    $419 = $p_0 + 8 | 0;
    HEAP32[$419 >> 2] = $F16_0;
    $420 = $p_0 + 12 | 0;
    HEAP32[$420 >> 2] = $402;
    label = 141;
    break;
   case 121:
    $422 = $p_0;
    $423 = $psize_1 >>> 8;
    $424 = ($423 | 0) == 0;
    if ($424) {
      $I18_0 = 0;
      label = 124;
      break;
    } else {
      label = 122;
      break;
    }
   case 122:
    $426 = $psize_1 >>> 0 > 16777215;
    if ($426) {
      $I18_0 = 31;
      label = 124;
      break;
    } else {
      label = 123;
      break;
    }
   case 123:
    $428 = $423 + 1048320 | 0;
    $429 = $428 >>> 16;
    $430 = $429 & 8;
    $431 = $423 << $430;
    $432 = $431 + 520192 | 0;
    $433 = $432 >>> 16;
    $434 = $433 & 4;
    $435 = $434 | $430;
    $436 = $431 << $434;
    $437 = $436 + 245760 | 0;
    $438 = $437 >>> 16;
    $439 = $438 & 2;
    $440 = $435 | $439;
    $441 = 14 - $440 | 0;
    $442 = $436 << $439;
    $443 = $442 >>> 15;
    $444 = $441 + $443 | 0;
    $445 = $444 << 1;
    $446 = $444 + 7 | 0;
    $447 = $psize_1 >>> ($446 >>> 0);
    $448 = $447 & 1;
    $449 = $448 | $445;
    $I18_0 = $449;
    label = 124;
    break;
   case 124:
    $451 = 5325260 + ($I18_0 << 2) | 0;
    $452 = $p_0 + 28 | 0;
    $I18_0_c = $I18_0;
    HEAP32[$452 >> 2] = $I18_0_c;
    $453 = $p_0 + 20 | 0;
    HEAP32[$453 >> 2] = 0;
    $454 = $p_0 + 16 | 0;
    HEAP32[$454 >> 2] = 0;
    $455 = HEAP32[1331240] | 0;
    $456 = 1 << $I18_0;
    $457 = $455 & $456;
    $458 = ($457 | 0) == 0;
    if ($458) {
      label = 125;
      break;
    } else {
      label = 126;
      break;
    }
   case 125:
    $460 = $455 | $456;
    HEAP32[1331240] = $460;
    HEAP32[$451 >> 2] = $422;
    $461 = $p_0 + 24 | 0;
    $_c = $451;
    HEAP32[$461 >> 2] = $_c;
    $462 = $p_0 + 12 | 0;
    HEAP32[$462 >> 2] = $p_0;
    $463 = $p_0 + 8 | 0;
    HEAP32[$463 >> 2] = $p_0;
    label = 138;
    break;
   case 126:
    $465 = HEAP32[$451 >> 2] | 0;
    $466 = ($I18_0 | 0) == 31;
    if ($466) {
      $471 = 0;
      label = 128;
      break;
    } else {
      label = 127;
      break;
    }
   case 127:
    $468 = $I18_0 >>> 1;
    $469 = 25 - $468 | 0;
    $471 = $469;
    label = 128;
    break;
   case 128:
    $472 = $psize_1 << $471;
    $K19_0 = $472;
    $T_0 = $465;
    label = 129;
    break;
   case 129:
    $474 = $T_0 + 4 | 0;
    $475 = HEAP32[$474 >> 2] | 0;
    $476 = $475 & -8;
    $477 = ($476 | 0) == ($psize_1 | 0);
    if ($477) {
      label = 134;
      break;
    } else {
      label = 130;
      break;
    }
   case 130:
    $479 = $K19_0 >>> 31;
    $480 = $T_0 + 16 + ($479 << 2) | 0;
    $481 = HEAP32[$480 >> 2] | 0;
    $482 = ($481 | 0) == 0;
    $483 = $K19_0 << 1;
    if ($482) {
      label = 131;
      break;
    } else {
      $K19_0 = $483;
      $T_0 = $481;
      label = 129;
      break;
    }
   case 131:
    $485 = $480;
    $486 = HEAP32[1331243] | 0;
    $487 = $485 >>> 0 < $486 >>> 0;
    if ($487) {
      label = 133;
      break;
    } else {
      label = 132;
      break;
    }
   case 132:
    HEAP32[$480 >> 2] = $422;
    $489 = $p_0 + 24 | 0;
    $T_0_c243 = $T_0;
    HEAP32[$489 >> 2] = $T_0_c243;
    $490 = $p_0 + 12 | 0;
    HEAP32[$490 >> 2] = $p_0;
    $491 = $p_0 + 8 | 0;
    HEAP32[$491 >> 2] = $p_0;
    label = 138;
    break;
   case 133:
    _abort();
   case 134:
    $494 = $T_0 + 8 | 0;
    $495 = HEAP32[$494 >> 2] | 0;
    $496 = $T_0;
    $497 = HEAP32[1331243] | 0;
    $498 = $496 >>> 0 < $497 >>> 0;
    if ($498) {
      label = 137;
      break;
    } else {
      label = 135;
      break;
    }
   case 135:
    $500 = $495;
    $501 = $500 >>> 0 < $497 >>> 0;
    if ($501) {
      label = 137;
      break;
    } else {
      label = 136;
      break;
    }
   case 136:
    $503 = $495 + 12 | 0;
    HEAP32[$503 >> 2] = $422;
    HEAP32[$494 >> 2] = $422;
    $504 = $p_0 + 8 | 0;
    $_c242 = $495;
    HEAP32[$504 >> 2] = $_c242;
    $505 = $p_0 + 12 | 0;
    $T_0_c = $T_0;
    HEAP32[$505 >> 2] = $T_0_c;
    $506 = $p_0 + 24 | 0;
    HEAP32[$506 >> 2] = 0;
    label = 138;
    break;
   case 137:
    _abort();
   case 138:
    $508 = HEAP32[1331247] | 0;
    $509 = $508 - 1 | 0;
    HEAP32[1331247] = $509;
    $510 = ($509 | 0) == 0;
    if ($510) {
      label = 139;
      break;
    } else {
      label = 141;
      break;
    }
   case 139:
    _release_unused_segments();
    label = 141;
    break;
   case 140:
    _abort();
   case 141:
    return;
  }
}
function _release_unused_segments() {
  var $sp_0_in = 0, $sp_0 = 0, $2 = 0, $3 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $sp_0_in = 5325412;
    label = 2;
    break;
   case 2:
    $sp_0 = HEAP32[$sp_0_in >> 2] | 0;
    $2 = ($sp_0 | 0) == 0;
    $3 = $sp_0 + 8 | 0;
    if ($2) {
      label = 3;
      break;
    } else {
      $sp_0_in = $3;
      label = 2;
      break;
    }
   case 3:
    HEAP32[1331247] = -1;
    return;
  }
}
function _sys_trim($pad) {
  $pad = $pad | 0;
  var $1 = 0, $2 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $_neg = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $_ = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $or_cond = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $phitmp = 0, $57 = 0, $58 = 0, $59 = 0, $released_2 = 0, $62 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[1312822] | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    _init_mparams();
    label = 3;
    break;
   case 3:
    $5 = $pad >>> 0 < 4294967232;
    if ($5) {
      label = 4;
      break;
    } else {
      $released_2 = 0;
      label = 13;
      break;
    }
   case 4:
    $7 = HEAP32[1331245] | 0;
    $8 = ($7 | 0) == 0;
    if ($8) {
      $released_2 = 0;
      label = 13;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $10 = $pad + 40 | 0;
    $11 = HEAP32[1331242] | 0;
    $12 = $11 >>> 0 > $10 >>> 0;
    if ($12) {
      label = 6;
      break;
    } else {
      label = 11;
      break;
    }
   case 6:
    $14 = HEAP32[1312824] | 0;
    $_neg = -40 - $pad | 0;
    $15 = $_neg - 1 | 0;
    $16 = $15 + $11 | 0;
    $17 = $16 + $14 | 0;
    $18 = ($17 >>> 0) / ($14 >>> 0) >>> 0;
    $19 = $18 - 1 | 0;
    $20 = Math_imul($19, $14);
    $21 = $7;
    $22 = _segment_holding($21) | 0;
    $23 = $22 + 12 | 0;
    $24 = HEAP32[$23 >> 2] | 0;
    $25 = $24 & 8;
    $26 = ($25 | 0) == 0;
    if ($26) {
      label = 7;
      break;
    } else {
      label = 11;
      break;
    }
   case 7:
    $28 = _sbrk(0) | 0;
    $29 = $22 | 0;
    $30 = HEAP32[$29 >> 2] | 0;
    $31 = $22 + 4 | 0;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $30 + $32 | 0;
    $34 = ($28 | 0) == ($33 | 0);
    if ($34) {
      label = 8;
      break;
    } else {
      label = 11;
      break;
    }
   case 8:
    $36 = -2147483648 - $14 | 0;
    $37 = $20 >>> 0 > 2147483646;
    $_ = $37 ? $36 : $20;
    $38 = -$_ | 0;
    $39 = _sbrk($38 | 0) | 0;
    $40 = _sbrk(0) | 0;
    $41 = ($39 | 0) != -1;
    $42 = $40 >>> 0 < $28 >>> 0;
    $or_cond = $41 & $42;
    if ($or_cond) {
      label = 9;
      break;
    } else {
      label = 11;
      break;
    }
   case 9:
    $44 = $28;
    $45 = $40;
    $46 = $44 - $45 | 0;
    $47 = ($28 | 0) == ($40 | 0);
    if ($47) {
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $49 = $22 + 4 | 0;
    $50 = HEAP32[$49 >> 2] | 0;
    $51 = $50 - $46 | 0;
    HEAP32[$49 >> 2] = $51;
    $52 = HEAP32[1331347] | 0;
    $53 = $52 - $46 | 0;
    HEAP32[1331347] = $53;
    $54 = HEAP32[1331245] | 0;
    $55 = HEAP32[1331242] | 0;
    $56 = $55 - $46 | 0;
    _init_top($54, $56);
    $phitmp = ($28 | 0) != ($40 | 0);
    $released_2 = $phitmp;
    label = 13;
    break;
   case 11:
    $57 = HEAP32[1331242] | 0;
    $58 = HEAP32[1331246] | 0;
    $59 = $57 >>> 0 > $58 >>> 0;
    if ($59) {
      label = 12;
      break;
    } else {
      $released_2 = 0;
      label = 13;
      break;
    }
   case 12:
    HEAP32[1331246] = -1;
    $released_2 = 0;
    label = 13;
    break;
   case 13:
    $62 = $released_2 & 1;
    return $62 | 0;
  }
  return 0;
}
function _realloc($oldmem, $bytes) {
  $oldmem = $oldmem | 0;
  $bytes = $bytes | 0;
  var $1 = 0, $3 = 0, $5 = 0, $7 = 0, $9 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $mem_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = ($oldmem | 0) == 0;
    if ($1) {
      label = 2;
      break;
    } else {
      label = 3;
      break;
    }
   case 2:
    $3 = _malloc($bytes) | 0;
    $mem_0 = $3;
    label = 11;
    break;
   case 3:
    $5 = $bytes >>> 0 > 4294967231;
    if ($5) {
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $7 = ___errno_location() | 0;
    HEAP32[$7 >> 2] = 12;
    $mem_0 = 0;
    label = 11;
    break;
   case 5:
    $9 = $bytes >>> 0 < 11;
    if ($9) {
      $14 = 16;
      label = 7;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $11 = $bytes + 11 | 0;
    $12 = $11 & -8;
    $14 = $12;
    label = 7;
    break;
   case 7:
    $15 = $oldmem - 8 | 0;
    $16 = $15;
    $17 = _try_realloc_chunk($16, $14) | 0;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 9;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $20 = $17 + 8 | 0;
    $21 = $20;
    $mem_0 = $21;
    label = 11;
    break;
   case 9:
    $23 = _malloc($bytes) | 0;
    $24 = ($23 | 0) == 0;
    if ($24) {
      $mem_0 = 0;
      label = 11;
      break;
    } else {
      label = 10;
      break;
    }
   case 10:
    $26 = $oldmem - 4 | 0;
    $27 = $26;
    $28 = HEAP32[$27 >> 2] | 0;
    $29 = $28 & -8;
    $30 = $28 & 3;
    $31 = ($30 | 0) == 0;
    $32 = $31 ? 8 : 4;
    $33 = $29 - $32 | 0;
    $34 = $33 >>> 0 < $bytes >>> 0;
    $35 = $34 ? $33 : $bytes;
    _memcpy($23 | 0, $oldmem | 0, $35 | 0);
    _free($oldmem);
    $mem_0 = $23;
    label = 11;
    break;
   case 11:
    return $mem_0 | 0;
  }
  return 0;
}
function _try_realloc_chunk($p, $nb) {
  $p = $p | 0;
  $nb = $nb | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $or_cond = 0, $_sum2728 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, $24 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $_sum23 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $_sum22 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $60 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $_sum19 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $_sum20 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $82 = 0, $83 = 0, $84 = 0, $_sum17 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $storemerge21 = 0, $storemerge = 0, $91 = 0, $92 = 0, $94 = 0, $95 = 0, $96 = 0, $98 = 0, $99 = 0, $100 = 0, $_sum15 = 0, $102 = 0, $103 = 0, $104 = 0, $_sum16 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $113 = 0, $114 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $126 = 0, $128 = 0, $129 = 0, $130 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $138 = 0, $_sum = 0, $139 = 0, $140 = 0, $141 = 0, $_sum2 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $_sum14 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $153 = 0, $154 = 0, $155 = 0, $157 = 0, $158 = 0, $159 = 0, $_sum4 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $_sum3 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $RP_0 = 0, $R_0 = 0, $171 = 0, $172 = 0, $173 = 0, $175 = 0, $176 = 0, $177 = 0, $CP_0 = 0, $178 = 0, $180 = 0, $181 = 0, $182 = 0, $R_1 = 0, $186 = 0, $_sum11 = 0, $188 = 0, $189 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $cond = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $201 = 0, $202 = 0, $203 = 0, $205 = 0, $206 = 0, $207 = 0, $210 = 0, $213 = 0, $215 = 0, $216 = 0, $217 = 0, $219 = 0, $_sum12 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $225 = 0, $226 = 0, $227 = 0, $229 = 0, $230 = 0, $_sum13 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $238 = 0, $239 = 0, $240 = 0, $242 = 0, $243 = 0, $247 = 0, $249 = 0, $250 = 0, $251 = 0, $252 = 0, $_sum910 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $258 = 0, $259 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $_sum5 = 0, $264 = 0, $265 = 0, $266 = 0, $_sum78 = 0, $267 = 0, $268 = 0, $269 = 0, $270 = 0, $newp_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $p + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 & -8;
    $4 = $p;
    $5 = $4 + $3 | 0;
    $6 = $5;
    $7 = HEAP32[1331243] | 0;
    $8 = $4 >>> 0 < $7 >>> 0;
    if ($8) {
      label = 69;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $10 = $2 & 3;
    $11 = ($10 | 0) != 1;
    $12 = $4 >>> 0 < $5 >>> 0;
    $or_cond = $11 & $12;
    if ($or_cond) {
      label = 3;
      break;
    } else {
      label = 69;
      break;
    }
   case 3:
    $_sum2728 = $3 | 4;
    $14 = $4 + $_sum2728 | 0;
    $15 = $14;
    $16 = HEAP32[$15 >> 2] | 0;
    $17 = $16 & 1;
    $18 = ($17 | 0) == 0;
    if ($18) {
      label = 69;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $20 = ($10 | 0) == 0;
    if ($20) {
      label = 5;
      break;
    } else {
      label = 6;
      break;
    }
   case 5:
    $22 = _mmap_resize($p, $nb) | 0;
    $newp_0 = $22;
    label = 70;
    break;
   case 6:
    $24 = $3 >>> 0 < $nb >>> 0;
    if ($24) {
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $26 = $3 - $nb | 0;
    $27 = $26 >>> 0 > 15;
    if ($27) {
      label = 8;
      break;
    } else {
      $newp_0 = $p;
      label = 70;
      break;
    }
   case 8:
    $29 = $4 + $nb | 0;
    $30 = $29;
    $31 = $2 & 1;
    $32 = $31 | $nb;
    $33 = $32 | 2;
    HEAP32[$1 >> 2] = $33;
    $_sum23 = $nb + 4 | 0;
    $34 = $4 + $_sum23 | 0;
    $35 = $34;
    $36 = $26 | 3;
    HEAP32[$35 >> 2] = $36;
    $37 = HEAP32[$15 >> 2] | 0;
    $38 = $37 | 1;
    HEAP32[$15 >> 2] = $38;
    _dispose_chunk($30, $26);
    $newp_0 = $p;
    label = 70;
    break;
   case 9:
    $40 = HEAP32[1331245] | 0;
    $41 = ($6 | 0) == ($40 | 0);
    if ($41) {
      label = 10;
      break;
    } else {
      label = 12;
      break;
    }
   case 10:
    $43 = HEAP32[1331242] | 0;
    $44 = $43 + $3 | 0;
    $45 = $44 >>> 0 > $nb >>> 0;
    if ($45) {
      label = 11;
      break;
    } else {
      $newp_0 = 0;
      label = 70;
      break;
    }
   case 11:
    $47 = $44 - $nb | 0;
    $48 = $4 + $nb | 0;
    $49 = $48;
    $50 = $2 & 1;
    $51 = $50 | $nb;
    $52 = $51 | 2;
    HEAP32[$1 >> 2] = $52;
    $_sum22 = $nb + 4 | 0;
    $53 = $4 + $_sum22 | 0;
    $54 = $53;
    $55 = $47 | 1;
    HEAP32[$54 >> 2] = $55;
    HEAP32[1331245] = $49;
    HEAP32[1331242] = $47;
    $newp_0 = $p;
    label = 70;
    break;
   case 12:
    $57 = HEAP32[1331244] | 0;
    $58 = ($6 | 0) == ($57 | 0);
    if ($58) {
      label = 13;
      break;
    } else {
      label = 18;
      break;
    }
   case 13:
    $60 = HEAP32[1331241] | 0;
    $61 = $60 + $3 | 0;
    $62 = $61 >>> 0 < $nb >>> 0;
    if ($62) {
      $newp_0 = 0;
      label = 70;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $64 = $61 - $nb | 0;
    $65 = $64 >>> 0 > 15;
    if ($65) {
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 15:
    $67 = $4 + $nb | 0;
    $68 = $67;
    $69 = $4 + $61 | 0;
    $70 = $2 & 1;
    $71 = $70 | $nb;
    $72 = $71 | 2;
    HEAP32[$1 >> 2] = $72;
    $_sum19 = $nb + 4 | 0;
    $73 = $4 + $_sum19 | 0;
    $74 = $73;
    $75 = $64 | 1;
    HEAP32[$74 >> 2] = $75;
    $76 = $69;
    HEAP32[$76 >> 2] = $64;
    $_sum20 = $61 + 4 | 0;
    $77 = $4 + $_sum20 | 0;
    $78 = $77;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = $79 & -2;
    HEAP32[$78 >> 2] = $80;
    $storemerge = $68;
    $storemerge21 = $64;
    label = 17;
    break;
   case 16:
    $82 = $2 & 1;
    $83 = $82 | $61;
    $84 = $83 | 2;
    HEAP32[$1 >> 2] = $84;
    $_sum17 = $61 + 4 | 0;
    $85 = $4 + $_sum17 | 0;
    $86 = $85;
    $87 = HEAP32[$86 >> 2] | 0;
    $88 = $87 | 1;
    HEAP32[$86 >> 2] = $88;
    $storemerge = 0;
    $storemerge21 = 0;
    label = 17;
    break;
   case 17:
    HEAP32[1331241] = $storemerge21;
    HEAP32[1331244] = $storemerge;
    $newp_0 = $p;
    label = 70;
    break;
   case 18:
    $91 = $16 & 2;
    $92 = ($91 | 0) == 0;
    if ($92) {
      label = 19;
      break;
    } else {
      $newp_0 = 0;
      label = 70;
      break;
    }
   case 19:
    $94 = $16 & -8;
    $95 = $94 + $3 | 0;
    $96 = $95 >>> 0 < $nb >>> 0;
    if ($96) {
      $newp_0 = 0;
      label = 70;
      break;
    } else {
      label = 20;
      break;
    }
   case 20:
    $98 = $95 - $nb | 0;
    $99 = $16 >>> 3;
    $100 = $16 >>> 0 < 256;
    if ($100) {
      label = 21;
      break;
    } else {
      label = 32;
      break;
    }
   case 21:
    $_sum15 = $3 + 8 | 0;
    $102 = $4 + $_sum15 | 0;
    $103 = $102;
    $104 = HEAP32[$103 >> 2] | 0;
    $_sum16 = $3 + 12 | 0;
    $105 = $4 + $_sum16 | 0;
    $106 = $105;
    $107 = HEAP32[$106 >> 2] | 0;
    $108 = $99 << 1;
    $109 = 5324996 + ($108 << 2) | 0;
    $110 = $109;
    $111 = ($104 | 0) == ($110 | 0);
    if ($111) {
      label = 24;
      break;
    } else {
      label = 22;
      break;
    }
   case 22:
    $113 = $104;
    $114 = $113 >>> 0 < $7 >>> 0;
    if ($114) {
      label = 31;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $116 = $104 + 12 | 0;
    $117 = HEAP32[$116 >> 2] | 0;
    $118 = ($117 | 0) == ($6 | 0);
    if ($118) {
      label = 24;
      break;
    } else {
      label = 31;
      break;
    }
   case 24:
    $119 = ($107 | 0) == ($104 | 0);
    if ($119) {
      label = 25;
      break;
    } else {
      label = 26;
      break;
    }
   case 25:
    $121 = 1 << $99;
    $122 = $121 ^ -1;
    $123 = HEAP32[1331239] | 0;
    $124 = $123 & $122;
    HEAP32[1331239] = $124;
    label = 66;
    break;
   case 26:
    $126 = ($107 | 0) == ($110 | 0);
    if ($126) {
      label = 29;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $128 = $107;
    $129 = HEAP32[1331243] | 0;
    $130 = $128 >>> 0 < $129 >>> 0;
    if ($130) {
      label = 30;
      break;
    } else {
      label = 28;
      break;
    }
   case 28:
    $132 = $107 + 8 | 0;
    $133 = HEAP32[$132 >> 2] | 0;
    $134 = ($133 | 0) == ($6 | 0);
    if ($134) {
      label = 29;
      break;
    } else {
      label = 30;
      break;
    }
   case 29:
    $135 = $104 + 12 | 0;
    HEAP32[$135 >> 2] = $107;
    $136 = $107 + 8 | 0;
    HEAP32[$136 >> 2] = $104;
    label = 66;
    break;
   case 30:
    _abort();
    return 0;
    return 0;
   case 31:
    _abort();
    return 0;
    return 0;
   case 32:
    $138 = $5;
    $_sum = $3 + 24 | 0;
    $139 = $4 + $_sum | 0;
    $140 = $139;
    $141 = HEAP32[$140 >> 2] | 0;
    $_sum2 = $3 + 12 | 0;
    $142 = $4 + $_sum2 | 0;
    $143 = $142;
    $144 = HEAP32[$143 >> 2] | 0;
    $145 = ($144 | 0) == ($138 | 0);
    if ($145) {
      label = 38;
      break;
    } else {
      label = 33;
      break;
    }
   case 33:
    $_sum14 = $3 + 8 | 0;
    $147 = $4 + $_sum14 | 0;
    $148 = $147;
    $149 = HEAP32[$148 >> 2] | 0;
    $150 = $149;
    $151 = $150 >>> 0 < $7 >>> 0;
    if ($151) {
      label = 37;
      break;
    } else {
      label = 34;
      break;
    }
   case 34:
    $153 = $149 + 12 | 0;
    $154 = HEAP32[$153 >> 2] | 0;
    $155 = ($154 | 0) == ($138 | 0);
    if ($155) {
      label = 35;
      break;
    } else {
      label = 37;
      break;
    }
   case 35:
    $157 = $144 + 8 | 0;
    $158 = HEAP32[$157 >> 2] | 0;
    $159 = ($158 | 0) == ($138 | 0);
    if ($159) {
      label = 36;
      break;
    } else {
      label = 37;
      break;
    }
   case 36:
    HEAP32[$153 >> 2] = $144;
    HEAP32[$157 >> 2] = $149;
    $R_1 = $144;
    label = 46;
    break;
   case 37:
    _abort();
    return 0;
    return 0;
   case 38:
    $_sum4 = $3 + 20 | 0;
    $162 = $4 + $_sum4 | 0;
    $163 = $162;
    $164 = HEAP32[$163 >> 2] | 0;
    $165 = ($164 | 0) == 0;
    if ($165) {
      label = 39;
      break;
    } else {
      $R_0 = $164;
      $RP_0 = $163;
      label = 40;
      break;
    }
   case 39:
    $_sum3 = $3 + 16 | 0;
    $167 = $4 + $_sum3 | 0;
    $168 = $167;
    $169 = HEAP32[$168 >> 2] | 0;
    $170 = ($169 | 0) == 0;
    if ($170) {
      $R_1 = 0;
      label = 46;
      break;
    } else {
      $R_0 = $169;
      $RP_0 = $168;
      label = 40;
      break;
    }
   case 40:
    $171 = $R_0 + 20 | 0;
    $172 = HEAP32[$171 >> 2] | 0;
    $173 = ($172 | 0) == 0;
    if ($173) {
      label = 41;
      break;
    } else {
      $CP_0 = $171;
      label = 42;
      break;
    }
   case 41:
    $175 = $R_0 + 16 | 0;
    $176 = HEAP32[$175 >> 2] | 0;
    $177 = ($176 | 0) == 0;
    if ($177) {
      label = 43;
      break;
    } else {
      $CP_0 = $175;
      label = 42;
      break;
    }
   case 42:
    $178 = HEAP32[$CP_0 >> 2] | 0;
    $R_0 = $178;
    $RP_0 = $CP_0;
    label = 40;
    break;
   case 43:
    $180 = $RP_0;
    $181 = HEAP32[1331243] | 0;
    $182 = $180 >>> 0 < $181 >>> 0;
    if ($182) {
      label = 45;
      break;
    } else {
      label = 44;
      break;
    }
   case 44:
    HEAP32[$RP_0 >> 2] = 0;
    $R_1 = $R_0;
    label = 46;
    break;
   case 45:
    _abort();
    return 0;
    return 0;
   case 46:
    $186 = ($141 | 0) == 0;
    if ($186) {
      label = 66;
      break;
    } else {
      label = 47;
      break;
    }
   case 47:
    $_sum11 = $3 + 28 | 0;
    $188 = $4 + $_sum11 | 0;
    $189 = $188;
    $190 = HEAP32[$189 >> 2] | 0;
    $191 = 5325260 + ($190 << 2) | 0;
    $192 = HEAP32[$191 >> 2] | 0;
    $193 = ($138 | 0) == ($192 | 0);
    if ($193) {
      label = 48;
      break;
    } else {
      label = 50;
      break;
    }
   case 48:
    HEAP32[$191 >> 2] = $R_1;
    $cond = ($R_1 | 0) == 0;
    if ($cond) {
      label = 49;
      break;
    } else {
      label = 56;
      break;
    }
   case 49:
    $195 = HEAP32[$189 >> 2] | 0;
    $196 = 1 << $195;
    $197 = $196 ^ -1;
    $198 = HEAP32[1331240] | 0;
    $199 = $198 & $197;
    HEAP32[1331240] = $199;
    label = 66;
    break;
   case 50:
    $201 = $141;
    $202 = HEAP32[1331243] | 0;
    $203 = $201 >>> 0 < $202 >>> 0;
    if ($203) {
      label = 54;
      break;
    } else {
      label = 51;
      break;
    }
   case 51:
    $205 = $141 + 16 | 0;
    $206 = HEAP32[$205 >> 2] | 0;
    $207 = ($206 | 0) == ($138 | 0);
    if ($207) {
      label = 52;
      break;
    } else {
      label = 53;
      break;
    }
   case 52:
    HEAP32[$205 >> 2] = $R_1;
    label = 55;
    break;
   case 53:
    $210 = $141 + 20 | 0;
    HEAP32[$210 >> 2] = $R_1;
    label = 55;
    break;
   case 54:
    _abort();
    return 0;
    return 0;
   case 55:
    $213 = ($R_1 | 0) == 0;
    if ($213) {
      label = 66;
      break;
    } else {
      label = 56;
      break;
    }
   case 56:
    $215 = $R_1;
    $216 = HEAP32[1331243] | 0;
    $217 = $215 >>> 0 < $216 >>> 0;
    if ($217) {
      label = 65;
      break;
    } else {
      label = 57;
      break;
    }
   case 57:
    $219 = $R_1 + 24 | 0;
    HEAP32[$219 >> 2] = $141;
    $_sum12 = $3 + 16 | 0;
    $220 = $4 + $_sum12 | 0;
    $221 = $220;
    $222 = HEAP32[$221 >> 2] | 0;
    $223 = ($222 | 0) == 0;
    if ($223) {
      label = 61;
      break;
    } else {
      label = 58;
      break;
    }
   case 58:
    $225 = $222;
    $226 = HEAP32[1331243] | 0;
    $227 = $225 >>> 0 < $226 >>> 0;
    if ($227) {
      label = 60;
      break;
    } else {
      label = 59;
      break;
    }
   case 59:
    $229 = $R_1 + 16 | 0;
    HEAP32[$229 >> 2] = $222;
    $230 = $222 + 24 | 0;
    HEAP32[$230 >> 2] = $R_1;
    label = 61;
    break;
   case 60:
    _abort();
    return 0;
    return 0;
   case 61:
    $_sum13 = $3 + 20 | 0;
    $233 = $4 + $_sum13 | 0;
    $234 = $233;
    $235 = HEAP32[$234 >> 2] | 0;
    $236 = ($235 | 0) == 0;
    if ($236) {
      label = 66;
      break;
    } else {
      label = 62;
      break;
    }
   case 62:
    $238 = $235;
    $239 = HEAP32[1331243] | 0;
    $240 = $238 >>> 0 < $239 >>> 0;
    if ($240) {
      label = 64;
      break;
    } else {
      label = 63;
      break;
    }
   case 63:
    $242 = $R_1 + 20 | 0;
    HEAP32[$242 >> 2] = $235;
    $243 = $235 + 24 | 0;
    HEAP32[$243 >> 2] = $R_1;
    label = 66;
    break;
   case 64:
    _abort();
    return 0;
    return 0;
   case 65:
    _abort();
    return 0;
    return 0;
   case 66:
    $247 = $98 >>> 0 < 16;
    if ($247) {
      label = 67;
      break;
    } else {
      label = 68;
      break;
    }
   case 67:
    $249 = HEAP32[$1 >> 2] | 0;
    $250 = $249 & 1;
    $251 = $95 | $250;
    $252 = $251 | 2;
    HEAP32[$1 >> 2] = $252;
    $_sum910 = $95 | 4;
    $253 = $4 + $_sum910 | 0;
    $254 = $253;
    $255 = HEAP32[$254 >> 2] | 0;
    $256 = $255 | 1;
    HEAP32[$254 >> 2] = $256;
    $newp_0 = $p;
    label = 70;
    break;
   case 68:
    $258 = $4 + $nb | 0;
    $259 = $258;
    $260 = HEAP32[$1 >> 2] | 0;
    $261 = $260 & 1;
    $262 = $261 | $nb;
    $263 = $262 | 2;
    HEAP32[$1 >> 2] = $263;
    $_sum5 = $nb + 4 | 0;
    $264 = $4 + $_sum5 | 0;
    $265 = $264;
    $266 = $98 | 3;
    HEAP32[$265 >> 2] = $266;
    $_sum78 = $95 | 4;
    $267 = $4 + $_sum78 | 0;
    $268 = $267;
    $269 = HEAP32[$268 >> 2] | 0;
    $270 = $269 | 1;
    HEAP32[$268 >> 2] = $270;
    _dispose_chunk($259, $98);
    $newp_0 = $p;
    label = 70;
    break;
   case 69:
    _abort();
    return 0;
    return 0;
   case 70:
    return $newp_0 | 0;
  }
  return 0;
}
function _init_mparams() {
  var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $10 = 0, $11 = 0, $12 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[1312822] | 0;
    $2 = ($1 | 0) == 0;
    if ($2) {
      label = 2;
      break;
    } else {
      label = 5;
      break;
    }
   case 2:
    $4 = _sysconf(8) | 0;
    $5 = $4 - 1 | 0;
    $6 = $5 & $4;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    _abort();
   case 4:
    HEAP32[1312824] = $4;
    HEAP32[1312823] = $4;
    HEAP32[1312825] = -1;
    HEAP32[1312826] = 2097152;
    HEAP32[1312827] = 0;
    HEAP32[1331350] = 0;
    $10 = _time(0) | 0;
    $11 = $10 & -16;
    $12 = $11 ^ 1431655768;
    HEAP32[1312822] = $12;
    label = 5;
    break;
   case 5:
    return;
  }
}
function _mmap_resize($oldp, $nb) {
  $oldp = $oldp | 0;
  $nb = $nb | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $oldp + 4 | 0;
    $2 = HEAP32[$1 >> 2] | 0;
    $3 = $2 & -8;
    $4 = $nb >>> 0 < 256;
    if ($4) {
      $_0 = 0;
      label = 5;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = $nb + 4 | 0;
    $7 = $3 >>> 0 < $6 >>> 0;
    if ($7) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $9 = $3 - $nb | 0;
    $10 = HEAP32[1312824] | 0;
    $11 = $10 << 1;
    $12 = $9 >>> 0 > $11 >>> 0;
    if ($12) {
      label = 4;
      break;
    } else {
      $_0 = $oldp;
      label = 5;
      break;
    }
   case 4:
    $_0 = 0;
    label = 5;
    break;
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function _segment_holding($addr) {
  $addr = $addr | 0;
  var $sp_0 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $_0 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $sp_0 = 5325404;
    label = 2;
    break;
   case 2:
    $2 = $sp_0 | 0;
    $3 = HEAP32[$2 >> 2] | 0;
    $4 = $3 >>> 0 > $addr >>> 0;
    if ($4) {
      label = 4;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $6 = $sp_0 + 4 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $3 + $7 | 0;
    $9 = $8 >>> 0 > $addr >>> 0;
    if ($9) {
      $_0 = $sp_0;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $11 = $sp_0 + 8 | 0;
    $12 = HEAP32[$11 >> 2] | 0;
    $13 = ($12 | 0) == 0;
    if ($13) {
      $_0 = 0;
      label = 5;
      break;
    } else {
      $sp_0 = $12;
      label = 2;
      break;
    }
   case 5:
    return $_0 | 0;
  }
  return 0;
}
function _dispose_chunk($p, $psize) {
  $p = $p | 0;
  $psize = $psize | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $_sum30 = 0, $27 = 0, $28 = 0, $29 = 0, $_sum31 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $63 = 0, $_sum22 = 0, $64 = 0, $65 = 0, $66 = 0, $_sum23 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $_sum29 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $80 = 0, $82 = 0, $83 = 0, $84 = 0, $_sum24 = 0, $_sum25 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $RP_0 = 0, $R_0 = 0, $96 = 0, $97 = 0, $98 = 0, $100 = 0, $101 = 0, $102 = 0, $CP_0 = 0, $103 = 0, $105 = 0, $106 = 0, $107 = 0, $R_1 = 0, $111 = 0, $_sum26 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $cond = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $126 = 0, $127 = 0, $128 = 0, $130 = 0, $131 = 0, $132 = 0, $135 = 0, $138 = 0, $140 = 0, $141 = 0, $142 = 0, $144 = 0, $_sum27 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $150 = 0, $151 = 0, $152 = 0, $154 = 0, $155 = 0, $_sum28 = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $163 = 0, $164 = 0, $165 = 0, $167 = 0, $168 = 0, $_sum = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $178 = 0, $179 = 0, $180 = 0, $_sum20 = 0, $181 = 0, $182 = 0, $183 = 0, $_0277 = 0, $_0 = 0, $186 = 0, $187 = 0, $_sum1 = 0, $189 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $195 = 0, $196 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $206 = 0, $207 = 0, $209 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $217 = 0, $218 = 0, $219 = 0, $220 = 0, $_sum18 = 0, $222 = 0, $223 = 0, $224 = 0, $_sum19 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $230 = 0, $231 = 0, $233 = 0, $234 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $246 = 0, $248 = 0, $249 = 0, $250 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $258 = 0, $_sum2 = 0, $259 = 0, $260 = 0, $261 = 0, $_sum3 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $_sum17 = 0, $267 = 0, $268 = 0, $269 = 0, $270 = 0, $271 = 0, $273 = 0, $274 = 0, $275 = 0, $277 = 0, $278 = 0, $279 = 0, $_sum5 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $_sum4 = 0, $287 = 0, $288 = 0, $289 = 0, $290 = 0, $RP9_0 = 0, $R7_0 = 0, $291 = 0, $292 = 0, $293 = 0, $295 = 0, $296 = 0, $297 = 0, $CP10_0 = 0, $298 = 0, $300 = 0, $301 = 0, $302 = 0, $R7_1 = 0, $306 = 0, $_sum14 = 0, $308 = 0, $309 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $cond46 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $321 = 0, $322 = 0, $323 = 0, $325 = 0, $326 = 0, $327 = 0, $330 = 0, $333 = 0, $335 = 0, $336 = 0, $337 = 0, $339 = 0, $_sum15 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $345 = 0, $346 = 0, $347 = 0, $349 = 0, $350 = 0, $_sum16 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $358 = 0, $359 = 0, $360 = 0, $362 = 0, $363 = 0, $367 = 0, $368 = 0, $369 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $380 = 0, $381 = 0, $_1 = 0, $383 = 0, $384 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $390 = 0, $391 = 0, $392 = 0, $394 = 0, $_sum13 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $400 = 0, $F16_0 = 0, $_sum12 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $408 = 0, $409 = 0, $410 = 0, $412 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $I19_0 = 0, $437 = 0, $438 = 0, $I19_0_c = 0, $439 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $446 = 0, $447 = 0, $_c = 0, $448 = 0, $449 = 0, $451 = 0, $452 = 0, $454 = 0, $455 = 0, $457 = 0, $458 = 0, $T_0 = 0, $K20_0 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $471 = 0, $472 = 0, $473 = 0, $475 = 0, $T_0_c9 = 0, $476 = 0, $477 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $486 = 0, $487 = 0, $489 = 0, $490 = 0, $_c8 = 0, $491 = 0, $T_0_c = 0, $492 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $p;
    $2 = $1 + $psize | 0;
    $3 = $2;
    $4 = $p + 4 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $5 & 1;
    $7 = ($6 | 0) == 0;
    if ($7) {
      label = 2;
      break;
    } else {
      $_0 = $p;
      $_0277 = $psize;
      label = 54;
      break;
    }
   case 2:
    $9 = $p | 0;
    $10 = HEAP32[$9 >> 2] | 0;
    $11 = $5 & 3;
    $12 = ($11 | 0) == 0;
    if ($12) {
      label = 134;
      break;
    } else {
      label = 3;
      break;
    }
   case 3:
    $14 = -$10 | 0;
    $15 = $1 + $14 | 0;
    $16 = $15;
    $17 = $10 + $psize | 0;
    $18 = HEAP32[1331243] | 0;
    $19 = $15 >>> 0 < $18 >>> 0;
    if ($19) {
      label = 53;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $21 = HEAP32[1331244] | 0;
    $22 = ($16 | 0) == ($21 | 0);
    if ($22) {
      label = 51;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $24 = $10 >>> 3;
    $25 = $10 >>> 0 < 256;
    if ($25) {
      label = 6;
      break;
    } else {
      label = 17;
      break;
    }
   case 6:
    $_sum30 = 8 - $10 | 0;
    $27 = $1 + $_sum30 | 0;
    $28 = $27;
    $29 = HEAP32[$28 >> 2] | 0;
    $_sum31 = 12 - $10 | 0;
    $30 = $1 + $_sum31 | 0;
    $31 = $30;
    $32 = HEAP32[$31 >> 2] | 0;
    $33 = $24 << 1;
    $34 = 5324996 + ($33 << 2) | 0;
    $35 = $34;
    $36 = ($29 | 0) == ($35 | 0);
    if ($36) {
      label = 9;
      break;
    } else {
      label = 7;
      break;
    }
   case 7:
    $38 = $29;
    $39 = $38 >>> 0 < $18 >>> 0;
    if ($39) {
      label = 16;
      break;
    } else {
      label = 8;
      break;
    }
   case 8:
    $41 = $29 + 12 | 0;
    $42 = HEAP32[$41 >> 2] | 0;
    $43 = ($42 | 0) == ($16 | 0);
    if ($43) {
      label = 9;
      break;
    } else {
      label = 16;
      break;
    }
   case 9:
    $44 = ($32 | 0) == ($29 | 0);
    if ($44) {
      label = 10;
      break;
    } else {
      label = 11;
      break;
    }
   case 10:
    $46 = 1 << $24;
    $47 = $46 ^ -1;
    $48 = HEAP32[1331239] | 0;
    $49 = $48 & $47;
    HEAP32[1331239] = $49;
    $_0 = $16;
    $_0277 = $17;
    label = 54;
    break;
   case 11:
    $51 = ($32 | 0) == ($35 | 0);
    if ($51) {
      label = 14;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $53 = $32;
    $54 = HEAP32[1331243] | 0;
    $55 = $53 >>> 0 < $54 >>> 0;
    if ($55) {
      label = 15;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $57 = $32 + 8 | 0;
    $58 = HEAP32[$57 >> 2] | 0;
    $59 = ($58 | 0) == ($16 | 0);
    if ($59) {
      label = 14;
      break;
    } else {
      label = 15;
      break;
    }
   case 14:
    $60 = $29 + 12 | 0;
    HEAP32[$60 >> 2] = $32;
    $61 = $32 + 8 | 0;
    HEAP32[$61 >> 2] = $29;
    $_0 = $16;
    $_0277 = $17;
    label = 54;
    break;
   case 15:
    _abort();
   case 16:
    _abort();
   case 17:
    $63 = $15;
    $_sum22 = 24 - $10 | 0;
    $64 = $1 + $_sum22 | 0;
    $65 = $64;
    $66 = HEAP32[$65 >> 2] | 0;
    $_sum23 = 12 - $10 | 0;
    $67 = $1 + $_sum23 | 0;
    $68 = $67;
    $69 = HEAP32[$68 >> 2] | 0;
    $70 = ($69 | 0) == ($63 | 0);
    if ($70) {
      label = 23;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $_sum29 = 8 - $10 | 0;
    $72 = $1 + $_sum29 | 0;
    $73 = $72;
    $74 = HEAP32[$73 >> 2] | 0;
    $75 = $74;
    $76 = $75 >>> 0 < $18 >>> 0;
    if ($76) {
      label = 22;
      break;
    } else {
      label = 19;
      break;
    }
   case 19:
    $78 = $74 + 12 | 0;
    $79 = HEAP32[$78 >> 2] | 0;
    $80 = ($79 | 0) == ($63 | 0);
    if ($80) {
      label = 20;
      break;
    } else {
      label = 22;
      break;
    }
   case 20:
    $82 = $69 + 8 | 0;
    $83 = HEAP32[$82 >> 2] | 0;
    $84 = ($83 | 0) == ($63 | 0);
    if ($84) {
      label = 21;
      break;
    } else {
      label = 22;
      break;
    }
   case 21:
    HEAP32[$78 >> 2] = $69;
    HEAP32[$82 >> 2] = $74;
    $R_1 = $69;
    label = 31;
    break;
   case 22:
    _abort();
   case 23:
    $_sum24 = 16 - $10 | 0;
    $_sum25 = $_sum24 + 4 | 0;
    $87 = $1 + $_sum25 | 0;
    $88 = $87;
    $89 = HEAP32[$88 >> 2] | 0;
    $90 = ($89 | 0) == 0;
    if ($90) {
      label = 24;
      break;
    } else {
      $R_0 = $89;
      $RP_0 = $88;
      label = 25;
      break;
    }
   case 24:
    $92 = $1 + $_sum24 | 0;
    $93 = $92;
    $94 = HEAP32[$93 >> 2] | 0;
    $95 = ($94 | 0) == 0;
    if ($95) {
      $R_1 = 0;
      label = 31;
      break;
    } else {
      $R_0 = $94;
      $RP_0 = $93;
      label = 25;
      break;
    }
   case 25:
    $96 = $R_0 + 20 | 0;
    $97 = HEAP32[$96 >> 2] | 0;
    $98 = ($97 | 0) == 0;
    if ($98) {
      label = 26;
      break;
    } else {
      $CP_0 = $96;
      label = 27;
      break;
    }
   case 26:
    $100 = $R_0 + 16 | 0;
    $101 = HEAP32[$100 >> 2] | 0;
    $102 = ($101 | 0) == 0;
    if ($102) {
      label = 28;
      break;
    } else {
      $CP_0 = $100;
      label = 27;
      break;
    }
   case 27:
    $103 = HEAP32[$CP_0 >> 2] | 0;
    $R_0 = $103;
    $RP_0 = $CP_0;
    label = 25;
    break;
   case 28:
    $105 = $RP_0;
    $106 = HEAP32[1331243] | 0;
    $107 = $105 >>> 0 < $106 >>> 0;
    if ($107) {
      label = 30;
      break;
    } else {
      label = 29;
      break;
    }
   case 29:
    HEAP32[$RP_0 >> 2] = 0;
    $R_1 = $R_0;
    label = 31;
    break;
   case 30:
    _abort();
   case 31:
    $111 = ($66 | 0) == 0;
    if ($111) {
      $_0 = $16;
      $_0277 = $17;
      label = 54;
      break;
    } else {
      label = 32;
      break;
    }
   case 32:
    $_sum26 = 28 - $10 | 0;
    $113 = $1 + $_sum26 | 0;
    $114 = $113;
    $115 = HEAP32[$114 >> 2] | 0;
    $116 = 5325260 + ($115 << 2) | 0;
    $117 = HEAP32[$116 >> 2] | 0;
    $118 = ($63 | 0) == ($117 | 0);
    if ($118) {
      label = 33;
      break;
    } else {
      label = 35;
      break;
    }
   case 33:
    HEAP32[$116 >> 2] = $R_1;
    $cond = ($R_1 | 0) == 0;
    if ($cond) {
      label = 34;
      break;
    } else {
      label = 41;
      break;
    }
   case 34:
    $120 = HEAP32[$114 >> 2] | 0;
    $121 = 1 << $120;
    $122 = $121 ^ -1;
    $123 = HEAP32[1331240] | 0;
    $124 = $123 & $122;
    HEAP32[1331240] = $124;
    $_0 = $16;
    $_0277 = $17;
    label = 54;
    break;
   case 35:
    $126 = $66;
    $127 = HEAP32[1331243] | 0;
    $128 = $126 >>> 0 < $127 >>> 0;
    if ($128) {
      label = 39;
      break;
    } else {
      label = 36;
      break;
    }
   case 36:
    $130 = $66 + 16 | 0;
    $131 = HEAP32[$130 >> 2] | 0;
    $132 = ($131 | 0) == ($63 | 0);
    if ($132) {
      label = 37;
      break;
    } else {
      label = 38;
      break;
    }
   case 37:
    HEAP32[$130 >> 2] = $R_1;
    label = 40;
    break;
   case 38:
    $135 = $66 + 20 | 0;
    HEAP32[$135 >> 2] = $R_1;
    label = 40;
    break;
   case 39:
    _abort();
   case 40:
    $138 = ($R_1 | 0) == 0;
    if ($138) {
      $_0 = $16;
      $_0277 = $17;
      label = 54;
      break;
    } else {
      label = 41;
      break;
    }
   case 41:
    $140 = $R_1;
    $141 = HEAP32[1331243] | 0;
    $142 = $140 >>> 0 < $141 >>> 0;
    if ($142) {
      label = 50;
      break;
    } else {
      label = 42;
      break;
    }
   case 42:
    $144 = $R_1 + 24 | 0;
    HEAP32[$144 >> 2] = $66;
    $_sum27 = 16 - $10 | 0;
    $145 = $1 + $_sum27 | 0;
    $146 = $145;
    $147 = HEAP32[$146 >> 2] | 0;
    $148 = ($147 | 0) == 0;
    if ($148) {
      label = 46;
      break;
    } else {
      label = 43;
      break;
    }
   case 43:
    $150 = $147;
    $151 = HEAP32[1331243] | 0;
    $152 = $150 >>> 0 < $151 >>> 0;
    if ($152) {
      label = 45;
      break;
    } else {
      label = 44;
      break;
    }
   case 44:
    $154 = $R_1 + 16 | 0;
    HEAP32[$154 >> 2] = $147;
    $155 = $147 + 24 | 0;
    HEAP32[$155 >> 2] = $R_1;
    label = 46;
    break;
   case 45:
    _abort();
   case 46:
    $_sum28 = $_sum27 + 4 | 0;
    $158 = $1 + $_sum28 | 0;
    $159 = $158;
    $160 = HEAP32[$159 >> 2] | 0;
    $161 = ($160 | 0) == 0;
    if ($161) {
      $_0 = $16;
      $_0277 = $17;
      label = 54;
      break;
    } else {
      label = 47;
      break;
    }
   case 47:
    $163 = $160;
    $164 = HEAP32[1331243] | 0;
    $165 = $163 >>> 0 < $164 >>> 0;
    if ($165) {
      label = 49;
      break;
    } else {
      label = 48;
      break;
    }
   case 48:
    $167 = $R_1 + 20 | 0;
    HEAP32[$167 >> 2] = $160;
    $168 = $160 + 24 | 0;
    HEAP32[$168 >> 2] = $R_1;
    $_0 = $16;
    $_0277 = $17;
    label = 54;
    break;
   case 49:
    _abort();
   case 50:
    _abort();
   case 51:
    $_sum = $psize + 4 | 0;
    $172 = $1 + $_sum | 0;
    $173 = $172;
    $174 = HEAP32[$173 >> 2] | 0;
    $175 = $174 & 3;
    $176 = ($175 | 0) == 3;
    if ($176) {
      label = 52;
      break;
    } else {
      $_0 = $16;
      $_0277 = $17;
      label = 54;
      break;
    }
   case 52:
    HEAP32[1331241] = $17;
    $178 = HEAP32[$173 >> 2] | 0;
    $179 = $178 & -2;
    HEAP32[$173 >> 2] = $179;
    $180 = $17 | 1;
    $_sum20 = 4 - $10 | 0;
    $181 = $1 + $_sum20 | 0;
    $182 = $181;
    HEAP32[$182 >> 2] = $180;
    $183 = $2;
    HEAP32[$183 >> 2] = $17;
    label = 134;
    break;
   case 53:
    _abort();
   case 54:
    $186 = HEAP32[1331243] | 0;
    $187 = $2 >>> 0 < $186 >>> 0;
    if ($187) {
      label = 133;
      break;
    } else {
      label = 55;
      break;
    }
   case 55:
    $_sum1 = $psize + 4 | 0;
    $189 = $1 + $_sum1 | 0;
    $190 = $189;
    $191 = HEAP32[$190 >> 2] | 0;
    $192 = $191 & 2;
    $193 = ($192 | 0) == 0;
    if ($193) {
      label = 56;
      break;
    } else {
      label = 109;
      break;
    }
   case 56:
    $195 = HEAP32[1331245] | 0;
    $196 = ($3 | 0) == ($195 | 0);
    if ($196) {
      label = 57;
      break;
    } else {
      label = 59;
      break;
    }
   case 57:
    $198 = HEAP32[1331242] | 0;
    $199 = $198 + $_0277 | 0;
    HEAP32[1331242] = $199;
    HEAP32[1331245] = $_0;
    $200 = $199 | 1;
    $201 = $_0 + 4 | 0;
    HEAP32[$201 >> 2] = $200;
    $202 = HEAP32[1331244] | 0;
    $203 = ($_0 | 0) == ($202 | 0);
    if ($203) {
      label = 58;
      break;
    } else {
      label = 134;
      break;
    }
   case 58:
    HEAP32[1331244] = 0;
    HEAP32[1331241] = 0;
    label = 134;
    break;
   case 59:
    $206 = HEAP32[1331244] | 0;
    $207 = ($3 | 0) == ($206 | 0);
    if ($207) {
      label = 60;
      break;
    } else {
      label = 61;
      break;
    }
   case 60:
    $209 = HEAP32[1331241] | 0;
    $210 = $209 + $_0277 | 0;
    HEAP32[1331241] = $210;
    HEAP32[1331244] = $_0;
    $211 = $210 | 1;
    $212 = $_0 + 4 | 0;
    HEAP32[$212 >> 2] = $211;
    $213 = $_0;
    $214 = $213 + $210 | 0;
    $215 = $214;
    HEAP32[$215 >> 2] = $210;
    label = 134;
    break;
   case 61:
    $217 = $191 & -8;
    $218 = $217 + $_0277 | 0;
    $219 = $191 >>> 3;
    $220 = $191 >>> 0 < 256;
    if ($220) {
      label = 62;
      break;
    } else {
      label = 73;
      break;
    }
   case 62:
    $_sum18 = $psize + 8 | 0;
    $222 = $1 + $_sum18 | 0;
    $223 = $222;
    $224 = HEAP32[$223 >> 2] | 0;
    $_sum19 = $psize + 12 | 0;
    $225 = $1 + $_sum19 | 0;
    $226 = $225;
    $227 = HEAP32[$226 >> 2] | 0;
    $228 = $219 << 1;
    $229 = 5324996 + ($228 << 2) | 0;
    $230 = $229;
    $231 = ($224 | 0) == ($230 | 0);
    if ($231) {
      label = 65;
      break;
    } else {
      label = 63;
      break;
    }
   case 63:
    $233 = $224;
    $234 = $233 >>> 0 < $186 >>> 0;
    if ($234) {
      label = 72;
      break;
    } else {
      label = 64;
      break;
    }
   case 64:
    $236 = $224 + 12 | 0;
    $237 = HEAP32[$236 >> 2] | 0;
    $238 = ($237 | 0) == ($3 | 0);
    if ($238) {
      label = 65;
      break;
    } else {
      label = 72;
      break;
    }
   case 65:
    $239 = ($227 | 0) == ($224 | 0);
    if ($239) {
      label = 66;
      break;
    } else {
      label = 67;
      break;
    }
   case 66:
    $241 = 1 << $219;
    $242 = $241 ^ -1;
    $243 = HEAP32[1331239] | 0;
    $244 = $243 & $242;
    HEAP32[1331239] = $244;
    label = 107;
    break;
   case 67:
    $246 = ($227 | 0) == ($230 | 0);
    if ($246) {
      label = 70;
      break;
    } else {
      label = 68;
      break;
    }
   case 68:
    $248 = $227;
    $249 = HEAP32[1331243] | 0;
    $250 = $248 >>> 0 < $249 >>> 0;
    if ($250) {
      label = 71;
      break;
    } else {
      label = 69;
      break;
    }
   case 69:
    $252 = $227 + 8 | 0;
    $253 = HEAP32[$252 >> 2] | 0;
    $254 = ($253 | 0) == ($3 | 0);
    if ($254) {
      label = 70;
      break;
    } else {
      label = 71;
      break;
    }
   case 70:
    $255 = $224 + 12 | 0;
    HEAP32[$255 >> 2] = $227;
    $256 = $227 + 8 | 0;
    HEAP32[$256 >> 2] = $224;
    label = 107;
    break;
   case 71:
    _abort();
   case 72:
    _abort();
   case 73:
    $258 = $2;
    $_sum2 = $psize + 24 | 0;
    $259 = $1 + $_sum2 | 0;
    $260 = $259;
    $261 = HEAP32[$260 >> 2] | 0;
    $_sum3 = $psize + 12 | 0;
    $262 = $1 + $_sum3 | 0;
    $263 = $262;
    $264 = HEAP32[$263 >> 2] | 0;
    $265 = ($264 | 0) == ($258 | 0);
    if ($265) {
      label = 79;
      break;
    } else {
      label = 74;
      break;
    }
   case 74:
    $_sum17 = $psize + 8 | 0;
    $267 = $1 + $_sum17 | 0;
    $268 = $267;
    $269 = HEAP32[$268 >> 2] | 0;
    $270 = $269;
    $271 = $270 >>> 0 < $186 >>> 0;
    if ($271) {
      label = 78;
      break;
    } else {
      label = 75;
      break;
    }
   case 75:
    $273 = $269 + 12 | 0;
    $274 = HEAP32[$273 >> 2] | 0;
    $275 = ($274 | 0) == ($258 | 0);
    if ($275) {
      label = 76;
      break;
    } else {
      label = 78;
      break;
    }
   case 76:
    $277 = $264 + 8 | 0;
    $278 = HEAP32[$277 >> 2] | 0;
    $279 = ($278 | 0) == ($258 | 0);
    if ($279) {
      label = 77;
      break;
    } else {
      label = 78;
      break;
    }
   case 77:
    HEAP32[$273 >> 2] = $264;
    HEAP32[$277 >> 2] = $269;
    $R7_1 = $264;
    label = 87;
    break;
   case 78:
    _abort();
   case 79:
    $_sum5 = $psize + 20 | 0;
    $282 = $1 + $_sum5 | 0;
    $283 = $282;
    $284 = HEAP32[$283 >> 2] | 0;
    $285 = ($284 | 0) == 0;
    if ($285) {
      label = 80;
      break;
    } else {
      $R7_0 = $284;
      $RP9_0 = $283;
      label = 81;
      break;
    }
   case 80:
    $_sum4 = $psize + 16 | 0;
    $287 = $1 + $_sum4 | 0;
    $288 = $287;
    $289 = HEAP32[$288 >> 2] | 0;
    $290 = ($289 | 0) == 0;
    if ($290) {
      $R7_1 = 0;
      label = 87;
      break;
    } else {
      $R7_0 = $289;
      $RP9_0 = $288;
      label = 81;
      break;
    }
   case 81:
    $291 = $R7_0 + 20 | 0;
    $292 = HEAP32[$291 >> 2] | 0;
    $293 = ($292 | 0) == 0;
    if ($293) {
      label = 82;
      break;
    } else {
      $CP10_0 = $291;
      label = 83;
      break;
    }
   case 82:
    $295 = $R7_0 + 16 | 0;
    $296 = HEAP32[$295 >> 2] | 0;
    $297 = ($296 | 0) == 0;
    if ($297) {
      label = 84;
      break;
    } else {
      $CP10_0 = $295;
      label = 83;
      break;
    }
   case 83:
    $298 = HEAP32[$CP10_0 >> 2] | 0;
    $R7_0 = $298;
    $RP9_0 = $CP10_0;
    label = 81;
    break;
   case 84:
    $300 = $RP9_0;
    $301 = HEAP32[1331243] | 0;
    $302 = $300 >>> 0 < $301 >>> 0;
    if ($302) {
      label = 86;
      break;
    } else {
      label = 85;
      break;
    }
   case 85:
    HEAP32[$RP9_0 >> 2] = 0;
    $R7_1 = $R7_0;
    label = 87;
    break;
   case 86:
    _abort();
   case 87:
    $306 = ($261 | 0) == 0;
    if ($306) {
      label = 107;
      break;
    } else {
      label = 88;
      break;
    }
   case 88:
    $_sum14 = $psize + 28 | 0;
    $308 = $1 + $_sum14 | 0;
    $309 = $308;
    $310 = HEAP32[$309 >> 2] | 0;
    $311 = 5325260 + ($310 << 2) | 0;
    $312 = HEAP32[$311 >> 2] | 0;
    $313 = ($258 | 0) == ($312 | 0);
    if ($313) {
      label = 89;
      break;
    } else {
      label = 91;
      break;
    }
   case 89:
    HEAP32[$311 >> 2] = $R7_1;
    $cond46 = ($R7_1 | 0) == 0;
    if ($cond46) {
      label = 90;
      break;
    } else {
      label = 97;
      break;
    }
   case 90:
    $315 = HEAP32[$309 >> 2] | 0;
    $316 = 1 << $315;
    $317 = $316 ^ -1;
    $318 = HEAP32[1331240] | 0;
    $319 = $318 & $317;
    HEAP32[1331240] = $319;
    label = 107;
    break;
   case 91:
    $321 = $261;
    $322 = HEAP32[1331243] | 0;
    $323 = $321 >>> 0 < $322 >>> 0;
    if ($323) {
      label = 95;
      break;
    } else {
      label = 92;
      break;
    }
   case 92:
    $325 = $261 + 16 | 0;
    $326 = HEAP32[$325 >> 2] | 0;
    $327 = ($326 | 0) == ($258 | 0);
    if ($327) {
      label = 93;
      break;
    } else {
      label = 94;
      break;
    }
   case 93:
    HEAP32[$325 >> 2] = $R7_1;
    label = 96;
    break;
   case 94:
    $330 = $261 + 20 | 0;
    HEAP32[$330 >> 2] = $R7_1;
    label = 96;
    break;
   case 95:
    _abort();
   case 96:
    $333 = ($R7_1 | 0) == 0;
    if ($333) {
      label = 107;
      break;
    } else {
      label = 97;
      break;
    }
   case 97:
    $335 = $R7_1;
    $336 = HEAP32[1331243] | 0;
    $337 = $335 >>> 0 < $336 >>> 0;
    if ($337) {
      label = 106;
      break;
    } else {
      label = 98;
      break;
    }
   case 98:
    $339 = $R7_1 + 24 | 0;
    HEAP32[$339 >> 2] = $261;
    $_sum15 = $psize + 16 | 0;
    $340 = $1 + $_sum15 | 0;
    $341 = $340;
    $342 = HEAP32[$341 >> 2] | 0;
    $343 = ($342 | 0) == 0;
    if ($343) {
      label = 102;
      break;
    } else {
      label = 99;
      break;
    }
   case 99:
    $345 = $342;
    $346 = HEAP32[1331243] | 0;
    $347 = $345 >>> 0 < $346 >>> 0;
    if ($347) {
      label = 101;
      break;
    } else {
      label = 100;
      break;
    }
   case 100:
    $349 = $R7_1 + 16 | 0;
    HEAP32[$349 >> 2] = $342;
    $350 = $342 + 24 | 0;
    HEAP32[$350 >> 2] = $R7_1;
    label = 102;
    break;
   case 101:
    _abort();
   case 102:
    $_sum16 = $psize + 20 | 0;
    $353 = $1 + $_sum16 | 0;
    $354 = $353;
    $355 = HEAP32[$354 >> 2] | 0;
    $356 = ($355 | 0) == 0;
    if ($356) {
      label = 107;
      break;
    } else {
      label = 103;
      break;
    }
   case 103:
    $358 = $355;
    $359 = HEAP32[1331243] | 0;
    $360 = $358 >>> 0 < $359 >>> 0;
    if ($360) {
      label = 105;
      break;
    } else {
      label = 104;
      break;
    }
   case 104:
    $362 = $R7_1 + 20 | 0;
    HEAP32[$362 >> 2] = $355;
    $363 = $355 + 24 | 0;
    HEAP32[$363 >> 2] = $R7_1;
    label = 107;
    break;
   case 105:
    _abort();
   case 106:
    _abort();
   case 107:
    $367 = $218 | 1;
    $368 = $_0 + 4 | 0;
    HEAP32[$368 >> 2] = $367;
    $369 = $_0;
    $370 = $369 + $218 | 0;
    $371 = $370;
    HEAP32[$371 >> 2] = $218;
    $372 = HEAP32[1331244] | 0;
    $373 = ($_0 | 0) == ($372 | 0);
    if ($373) {
      label = 108;
      break;
    } else {
      $_1 = $218;
      label = 110;
      break;
    }
   case 108:
    HEAP32[1331241] = $218;
    label = 134;
    break;
   case 109:
    $376 = $191 & -2;
    HEAP32[$190 >> 2] = $376;
    $377 = $_0277 | 1;
    $378 = $_0 + 4 | 0;
    HEAP32[$378 >> 2] = $377;
    $379 = $_0;
    $380 = $379 + $_0277 | 0;
    $381 = $380;
    HEAP32[$381 >> 2] = $_0277;
    $_1 = $_0277;
    label = 110;
    break;
   case 110:
    $383 = $_1 >>> 3;
    $384 = $_1 >>> 0 < 256;
    if ($384) {
      label = 111;
      break;
    } else {
      label = 116;
      break;
    }
   case 111:
    $386 = $383 << 1;
    $387 = 5324996 + ($386 << 2) | 0;
    $388 = $387;
    $389 = HEAP32[1331239] | 0;
    $390 = 1 << $383;
    $391 = $389 & $390;
    $392 = ($391 | 0) == 0;
    if ($392) {
      label = 112;
      break;
    } else {
      label = 113;
      break;
    }
   case 112:
    $394 = $389 | $390;
    HEAP32[1331239] = $394;
    $F16_0 = $388;
    label = 115;
    break;
   case 113:
    $_sum13 = $386 + 2 | 0;
    $396 = 5324996 + ($_sum13 << 2) | 0;
    $397 = HEAP32[$396 >> 2] | 0;
    $398 = $397;
    $399 = HEAP32[1331243] | 0;
    $400 = $398 >>> 0 < $399 >>> 0;
    if ($400) {
      label = 114;
      break;
    } else {
      $F16_0 = $397;
      label = 115;
      break;
    }
   case 114:
    _abort();
   case 115:
    $_sum12 = $386 + 2 | 0;
    $403 = 5324996 + ($_sum12 << 2) | 0;
    HEAP32[$403 >> 2] = $_0;
    $404 = $F16_0 + 12 | 0;
    HEAP32[$404 >> 2] = $_0;
    $405 = $_0 + 8 | 0;
    HEAP32[$405 >> 2] = $F16_0;
    $406 = $_0 + 12 | 0;
    HEAP32[$406 >> 2] = $388;
    label = 134;
    break;
   case 116:
    $408 = $_0;
    $409 = $_1 >>> 8;
    $410 = ($409 | 0) == 0;
    if ($410) {
      $I19_0 = 0;
      label = 119;
      break;
    } else {
      label = 117;
      break;
    }
   case 117:
    $412 = $_1 >>> 0 > 16777215;
    if ($412) {
      $I19_0 = 31;
      label = 119;
      break;
    } else {
      label = 118;
      break;
    }
   case 118:
    $414 = $409 + 1048320 | 0;
    $415 = $414 >>> 16;
    $416 = $415 & 8;
    $417 = $409 << $416;
    $418 = $417 + 520192 | 0;
    $419 = $418 >>> 16;
    $420 = $419 & 4;
    $421 = $420 | $416;
    $422 = $417 << $420;
    $423 = $422 + 245760 | 0;
    $424 = $423 >>> 16;
    $425 = $424 & 2;
    $426 = $421 | $425;
    $427 = 14 - $426 | 0;
    $428 = $422 << $425;
    $429 = $428 >>> 15;
    $430 = $427 + $429 | 0;
    $431 = $430 << 1;
    $432 = $430 + 7 | 0;
    $433 = $_1 >>> ($432 >>> 0);
    $434 = $433 & 1;
    $435 = $434 | $431;
    $I19_0 = $435;
    label = 119;
    break;
   case 119:
    $437 = 5325260 + ($I19_0 << 2) | 0;
    $438 = $_0 + 28 | 0;
    $I19_0_c = $I19_0;
    HEAP32[$438 >> 2] = $I19_0_c;
    $439 = $_0 + 20 | 0;
    HEAP32[$439 >> 2] = 0;
    $440 = $_0 + 16 | 0;
    HEAP32[$440 >> 2] = 0;
    $441 = HEAP32[1331240] | 0;
    $442 = 1 << $I19_0;
    $443 = $441 & $442;
    $444 = ($443 | 0) == 0;
    if ($444) {
      label = 120;
      break;
    } else {
      label = 121;
      break;
    }
   case 120:
    $446 = $441 | $442;
    HEAP32[1331240] = $446;
    HEAP32[$437 >> 2] = $408;
    $447 = $_0 + 24 | 0;
    $_c = $437;
    HEAP32[$447 >> 2] = $_c;
    $448 = $_0 + 12 | 0;
    HEAP32[$448 >> 2] = $_0;
    $449 = $_0 + 8 | 0;
    HEAP32[$449 >> 2] = $_0;
    label = 134;
    break;
   case 121:
    $451 = HEAP32[$437 >> 2] | 0;
    $452 = ($I19_0 | 0) == 31;
    if ($452) {
      $457 = 0;
      label = 123;
      break;
    } else {
      label = 122;
      break;
    }
   case 122:
    $454 = $I19_0 >>> 1;
    $455 = 25 - $454 | 0;
    $457 = $455;
    label = 123;
    break;
   case 123:
    $458 = $_1 << $457;
    $K20_0 = $458;
    $T_0 = $451;
    label = 124;
    break;
   case 124:
    $460 = $T_0 + 4 | 0;
    $461 = HEAP32[$460 >> 2] | 0;
    $462 = $461 & -8;
    $463 = ($462 | 0) == ($_1 | 0);
    if ($463) {
      label = 129;
      break;
    } else {
      label = 125;
      break;
    }
   case 125:
    $465 = $K20_0 >>> 31;
    $466 = $T_0 + 16 + ($465 << 2) | 0;
    $467 = HEAP32[$466 >> 2] | 0;
    $468 = ($467 | 0) == 0;
    $469 = $K20_0 << 1;
    if ($468) {
      label = 126;
      break;
    } else {
      $K20_0 = $469;
      $T_0 = $467;
      label = 124;
      break;
    }
   case 126:
    $471 = $466;
    $472 = HEAP32[1331243] | 0;
    $473 = $471 >>> 0 < $472 >>> 0;
    if ($473) {
      label = 128;
      break;
    } else {
      label = 127;
      break;
    }
   case 127:
    HEAP32[$466 >> 2] = $408;
    $475 = $_0 + 24 | 0;
    $T_0_c9 = $T_0;
    HEAP32[$475 >> 2] = $T_0_c9;
    $476 = $_0 + 12 | 0;
    HEAP32[$476 >> 2] = $_0;
    $477 = $_0 + 8 | 0;
    HEAP32[$477 >> 2] = $_0;
    label = 134;
    break;
   case 128:
    _abort();
   case 129:
    $480 = $T_0 + 8 | 0;
    $481 = HEAP32[$480 >> 2] | 0;
    $482 = $T_0;
    $483 = HEAP32[1331243] | 0;
    $484 = $482 >>> 0 < $483 >>> 0;
    if ($484) {
      label = 132;
      break;
    } else {
      label = 130;
      break;
    }
   case 130:
    $486 = $481;
    $487 = $486 >>> 0 < $483 >>> 0;
    if ($487) {
      label = 132;
      break;
    } else {
      label = 131;
      break;
    }
   case 131:
    $489 = $481 + 12 | 0;
    HEAP32[$489 >> 2] = $408;
    HEAP32[$480 >> 2] = $408;
    $490 = $_0 + 8 | 0;
    $_c8 = $481;
    HEAP32[$490 >> 2] = $_c8;
    $491 = $_0 + 12 | 0;
    $T_0_c = $T_0;
    HEAP32[$491 >> 2] = $T_0_c;
    $492 = $_0 + 24 | 0;
    HEAP32[$492 >> 2] = 0;
    label = 134;
    break;
   case 132:
    _abort();
   case 133:
    _abort();
   case 134:
    return;
  }
}
function _init_top($p, $psize) {
  $p = $p | 0;
  $psize = $psize | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $_sum = 0, $15 = 0, $16 = 0, $_sum2 = 0, $17 = 0, $18 = 0, $19 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $p;
    $2 = $p + 8 | 0;
    $3 = $2;
    $4 = $3 & 7;
    $5 = ($4 | 0) == 0;
    if ($5) {
      $10 = 0;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $7 = -$3 | 0;
    $8 = $7 & 7;
    $10 = $8;
    label = 3;
    break;
   case 3:
    $11 = $1 + $10 | 0;
    $12 = $11;
    $13 = $psize - $10 | 0;
    HEAP32[1331245] = $12;
    HEAP32[1331242] = $13;
    $14 = $13 | 1;
    $_sum = $10 + 4 | 0;
    $15 = $1 + $_sum | 0;
    $16 = $15;
    HEAP32[$16 >> 2] = $14;
    $_sum2 = $psize + 4 | 0;
    $17 = $1 + $_sum2 | 0;
    $18 = $17;
    HEAP32[$18 >> 2] = 40;
    $19 = HEAP32[1312826] | 0;
    HEAP32[1331246] = $19;
    return;
  }
}
function _init_bins() {
  var $i_02 = 0, $2 = 0, $3 = 0, $4 = 0, $_sum = 0, $5 = 0, $_sum1 = 0, $6 = 0, $7 = 0, $exitcond = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $i_02 = 0;
    label = 2;
    break;
   case 2:
    $2 = $i_02 << 1;
    $3 = 5324996 + ($2 << 2) | 0;
    $4 = $3;
    $_sum = $2 + 3 | 0;
    $5 = 5324996 + ($_sum << 2) | 0;
    HEAP32[$5 >> 2] = $4;
    $_sum1 = $2 + 2 | 0;
    $6 = 5324996 + ($_sum1 << 2) | 0;
    HEAP32[$6 >> 2] = $4;
    $7 = $i_02 + 1 | 0;
    $exitcond = ($7 | 0) == 32;
    if ($exitcond) {
      label = 3;
      break;
    } else {
      $i_02 = $7;
      label = 2;
      break;
    }
   case 3:
    return;
  }
}
function _prepend_alloc($newbase, $oldbase, $nb) {
  $newbase = $newbase | 0;
  $oldbase = $oldbase | 0;
  $nb = $nb | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $_sum = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $_sum1 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $35 = 0, $36 = 0, $_sum42 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, $_sum40 = 0, $46 = 0, $47 = 0, $_sum41 = 0, $48 = 0, $49 = 0, $_sum2 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $59 = 0, $_sum3738 = 0, $61 = 0, $62 = 0, $63 = 0, $_sum39 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $72 = 0, $73 = 0, $74 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $86 = 0, $88 = 0, $89 = 0, $90 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $98 = 0, $_sum34 = 0, $99 = 0, $100 = 0, $101 = 0, $_sum5 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $_sum3536 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $114 = 0, $115 = 0, $116 = 0, $118 = 0, $119 = 0, $120 = 0, $_sum67 = 0, $_sum8 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $RP_0 = 0, $R_0 = 0, $132 = 0, $133 = 0, $134 = 0, $136 = 0, $137 = 0, $138 = 0, $CP_0 = 0, $139 = 0, $141 = 0, $142 = 0, $143 = 0, $R_1 = 0, $147 = 0, $_sum30 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $cond = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $162 = 0, $163 = 0, $164 = 0, $166 = 0, $167 = 0, $168 = 0, $171 = 0, $174 = 0, $176 = 0, $177 = 0, $178 = 0, $180 = 0, $_sum3132 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $186 = 0, $187 = 0, $188 = 0, $190 = 0, $191 = 0, $_sum33 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $199 = 0, $200 = 0, $201 = 0, $203 = 0, $204 = 0, $_sum9 = 0, $208 = 0, $209 = 0, $210 = 0, $qsize_0 = 0, $oldfirst_0 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $_sum10 = 0, $216 = 0, $217 = 0, $_sum11 = 0, $218 = 0, $219 = 0, $220 = 0, $221 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $231 = 0, $_sum29 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $F4_0 = 0, $_sum26 = 0, $240 = 0, $241 = 0, $_sum27 = 0, $242 = 0, $243 = 0, $_sum28 = 0, $244 = 0, $245 = 0, $247 = 0, $248 = 0, $249 = 0, $251 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $I7_0 = 0, $276 = 0, $_sum12 = 0, $277 = 0, $278 = 0, $_sum13 = 0, $279 = 0, $_sum14 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $288 = 0, $289 = 0, $_sum15 = 0, $290 = 0, $291 = 0, $_sum16 = 0, $292 = 0, $293 = 0, $_sum17 = 0, $294 = 0, $295 = 0, $297 = 0, $298 = 0, $300 = 0, $301 = 0, $303 = 0, $304 = 0, $T_0 = 0, $K8_0 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $317 = 0, $318 = 0, $319 = 0, $_sum23 = 0, $321 = 0, $322 = 0, $_sum24 = 0, $323 = 0, $324 = 0, $_sum25 = 0, $325 = 0, $326 = 0, $329 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $335 = 0, $336 = 0, $338 = 0, $_sum20 = 0, $339 = 0, $340 = 0, $_sum21 = 0, $341 = 0, $342 = 0, $_sum22 = 0, $343 = 0, $344 = 0, $_sum1819 = 0, $346 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = $newbase + 8 | 0;
    $2 = $1;
    $3 = $2 & 7;
    $4 = ($3 | 0) == 0;
    if ($4) {
      $9 = 0;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $6 = -$2 | 0;
    $7 = $6 & 7;
    $9 = $7;
    label = 3;
    break;
   case 3:
    $10 = $newbase + $9 | 0;
    $11 = $oldbase + 8 | 0;
    $12 = $11;
    $13 = $12 & 7;
    $14 = ($13 | 0) == 0;
    if ($14) {
      $19 = 0;
      label = 5;
      break;
    } else {
      label = 4;
      break;
    }
   case 4:
    $16 = -$12 | 0;
    $17 = $16 & 7;
    $19 = $17;
    label = 5;
    break;
   case 5:
    $20 = $oldbase + $19 | 0;
    $21 = $20;
    $22 = $20;
    $23 = $10;
    $24 = $22 - $23 | 0;
    $_sum = $9 + $nb | 0;
    $25 = $newbase + $_sum | 0;
    $26 = $25;
    $27 = $24 - $nb | 0;
    $28 = $nb | 3;
    $_sum1 = $9 + 4 | 0;
    $29 = $newbase + $_sum1 | 0;
    $30 = $29;
    HEAP32[$30 >> 2] = $28;
    $31 = HEAP32[1331245] | 0;
    $32 = ($21 | 0) == ($31 | 0);
    if ($32) {
      label = 6;
      break;
    } else {
      label = 7;
      break;
    }
   case 6:
    $34 = HEAP32[1331242] | 0;
    $35 = $34 + $27 | 0;
    HEAP32[1331242] = $35;
    HEAP32[1331245] = $26;
    $36 = $35 | 1;
    $_sum42 = $_sum + 4 | 0;
    $37 = $newbase + $_sum42 | 0;
    $38 = $37;
    HEAP32[$38 >> 2] = $36;
    label = 80;
    break;
   case 7:
    $40 = HEAP32[1331244] | 0;
    $41 = ($21 | 0) == ($40 | 0);
    if ($41) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $43 = HEAP32[1331241] | 0;
    $44 = $43 + $27 | 0;
    HEAP32[1331241] = $44;
    HEAP32[1331244] = $26;
    $45 = $44 | 1;
    $_sum40 = $_sum + 4 | 0;
    $46 = $newbase + $_sum40 | 0;
    $47 = $46;
    HEAP32[$47 >> 2] = $45;
    $_sum41 = $44 + $_sum | 0;
    $48 = $newbase + $_sum41 | 0;
    $49 = $48;
    HEAP32[$49 >> 2] = $44;
    label = 80;
    break;
   case 9:
    $_sum2 = $19 + 4 | 0;
    $51 = $oldbase + $_sum2 | 0;
    $52 = $51;
    $53 = HEAP32[$52 >> 2] | 0;
    $54 = $53 & 3;
    $55 = ($54 | 0) == 1;
    if ($55) {
      label = 10;
      break;
    } else {
      $oldfirst_0 = $21;
      $qsize_0 = $27;
      label = 57;
      break;
    }
   case 10:
    $57 = $53 & -8;
    $58 = $53 >>> 3;
    $59 = $53 >>> 0 < 256;
    if ($59) {
      label = 11;
      break;
    } else {
      label = 22;
      break;
    }
   case 11:
    $_sum3738 = $19 | 8;
    $61 = $oldbase + $_sum3738 | 0;
    $62 = $61;
    $63 = HEAP32[$62 >> 2] | 0;
    $_sum39 = $19 + 12 | 0;
    $64 = $oldbase + $_sum39 | 0;
    $65 = $64;
    $66 = HEAP32[$65 >> 2] | 0;
    $67 = $58 << 1;
    $68 = 5324996 + ($67 << 2) | 0;
    $69 = $68;
    $70 = ($63 | 0) == ($69 | 0);
    if ($70) {
      label = 14;
      break;
    } else {
      label = 12;
      break;
    }
   case 12:
    $72 = $63;
    $73 = HEAP32[1331243] | 0;
    $74 = $72 >>> 0 < $73 >>> 0;
    if ($74) {
      label = 21;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $76 = $63 + 12 | 0;
    $77 = HEAP32[$76 >> 2] | 0;
    $78 = ($77 | 0) == ($21 | 0);
    if ($78) {
      label = 14;
      break;
    } else {
      label = 21;
      break;
    }
   case 14:
    $79 = ($66 | 0) == ($63 | 0);
    if ($79) {
      label = 15;
      break;
    } else {
      label = 16;
      break;
    }
   case 15:
    $81 = 1 << $58;
    $82 = $81 ^ -1;
    $83 = HEAP32[1331239] | 0;
    $84 = $83 & $82;
    HEAP32[1331239] = $84;
    label = 56;
    break;
   case 16:
    $86 = ($66 | 0) == ($69 | 0);
    if ($86) {
      label = 19;
      break;
    } else {
      label = 17;
      break;
    }
   case 17:
    $88 = $66;
    $89 = HEAP32[1331243] | 0;
    $90 = $88 >>> 0 < $89 >>> 0;
    if ($90) {
      label = 20;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $92 = $66 + 8 | 0;
    $93 = HEAP32[$92 >> 2] | 0;
    $94 = ($93 | 0) == ($21 | 0);
    if ($94) {
      label = 19;
      break;
    } else {
      label = 20;
      break;
    }
   case 19:
    $95 = $63 + 12 | 0;
    HEAP32[$95 >> 2] = $66;
    $96 = $66 + 8 | 0;
    HEAP32[$96 >> 2] = $63;
    label = 56;
    break;
   case 20:
    _abort();
    return 0;
    return 0;
   case 21:
    _abort();
    return 0;
    return 0;
   case 22:
    $98 = $20;
    $_sum34 = $19 | 24;
    $99 = $oldbase + $_sum34 | 0;
    $100 = $99;
    $101 = HEAP32[$100 >> 2] | 0;
    $_sum5 = $19 + 12 | 0;
    $102 = $oldbase + $_sum5 | 0;
    $103 = $102;
    $104 = HEAP32[$103 >> 2] | 0;
    $105 = ($104 | 0) == ($98 | 0);
    if ($105) {
      label = 28;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    $_sum3536 = $19 | 8;
    $107 = $oldbase + $_sum3536 | 0;
    $108 = $107;
    $109 = HEAP32[$108 >> 2] | 0;
    $110 = $109;
    $111 = HEAP32[1331243] | 0;
    $112 = $110 >>> 0 < $111 >>> 0;
    if ($112) {
      label = 27;
      break;
    } else {
      label = 24;
      break;
    }
   case 24:
    $114 = $109 + 12 | 0;
    $115 = HEAP32[$114 >> 2] | 0;
    $116 = ($115 | 0) == ($98 | 0);
    if ($116) {
      label = 25;
      break;
    } else {
      label = 27;
      break;
    }
   case 25:
    $118 = $104 + 8 | 0;
    $119 = HEAP32[$118 >> 2] | 0;
    $120 = ($119 | 0) == ($98 | 0);
    if ($120) {
      label = 26;
      break;
    } else {
      label = 27;
      break;
    }
   case 26:
    HEAP32[$114 >> 2] = $104;
    HEAP32[$118 >> 2] = $109;
    $R_1 = $104;
    label = 36;
    break;
   case 27:
    _abort();
    return 0;
    return 0;
   case 28:
    $_sum67 = $19 | 16;
    $_sum8 = $_sum67 + 4 | 0;
    $123 = $oldbase + $_sum8 | 0;
    $124 = $123;
    $125 = HEAP32[$124 >> 2] | 0;
    $126 = ($125 | 0) == 0;
    if ($126) {
      label = 29;
      break;
    } else {
      $R_0 = $125;
      $RP_0 = $124;
      label = 30;
      break;
    }
   case 29:
    $128 = $oldbase + $_sum67 | 0;
    $129 = $128;
    $130 = HEAP32[$129 >> 2] | 0;
    $131 = ($130 | 0) == 0;
    if ($131) {
      $R_1 = 0;
      label = 36;
      break;
    } else {
      $R_0 = $130;
      $RP_0 = $129;
      label = 30;
      break;
    }
   case 30:
    $132 = $R_0 + 20 | 0;
    $133 = HEAP32[$132 >> 2] | 0;
    $134 = ($133 | 0) == 0;
    if ($134) {
      label = 31;
      break;
    } else {
      $CP_0 = $132;
      label = 32;
      break;
    }
   case 31:
    $136 = $R_0 + 16 | 0;
    $137 = HEAP32[$136 >> 2] | 0;
    $138 = ($137 | 0) == 0;
    if ($138) {
      label = 33;
      break;
    } else {
      $CP_0 = $136;
      label = 32;
      break;
    }
   case 32:
    $139 = HEAP32[$CP_0 >> 2] | 0;
    $R_0 = $139;
    $RP_0 = $CP_0;
    label = 30;
    break;
   case 33:
    $141 = $RP_0;
    $142 = HEAP32[1331243] | 0;
    $143 = $141 >>> 0 < $142 >>> 0;
    if ($143) {
      label = 35;
      break;
    } else {
      label = 34;
      break;
    }
   case 34:
    HEAP32[$RP_0 >> 2] = 0;
    $R_1 = $R_0;
    label = 36;
    break;
   case 35:
    _abort();
    return 0;
    return 0;
   case 36:
    $147 = ($101 | 0) == 0;
    if ($147) {
      label = 56;
      break;
    } else {
      label = 37;
      break;
    }
   case 37:
    $_sum30 = $19 + 28 | 0;
    $149 = $oldbase + $_sum30 | 0;
    $150 = $149;
    $151 = HEAP32[$150 >> 2] | 0;
    $152 = 5325260 + ($151 << 2) | 0;
    $153 = HEAP32[$152 >> 2] | 0;
    $154 = ($98 | 0) == ($153 | 0);
    if ($154) {
      label = 38;
      break;
    } else {
      label = 40;
      break;
    }
   case 38:
    HEAP32[$152 >> 2] = $R_1;
    $cond = ($R_1 | 0) == 0;
    if ($cond) {
      label = 39;
      break;
    } else {
      label = 46;
      break;
    }
   case 39:
    $156 = HEAP32[$150 >> 2] | 0;
    $157 = 1 << $156;
    $158 = $157 ^ -1;
    $159 = HEAP32[1331240] | 0;
    $160 = $159 & $158;
    HEAP32[1331240] = $160;
    label = 56;
    break;
   case 40:
    $162 = $101;
    $163 = HEAP32[1331243] | 0;
    $164 = $162 >>> 0 < $163 >>> 0;
    if ($164) {
      label = 44;
      break;
    } else {
      label = 41;
      break;
    }
   case 41:
    $166 = $101 + 16 | 0;
    $167 = HEAP32[$166 >> 2] | 0;
    $168 = ($167 | 0) == ($98 | 0);
    if ($168) {
      label = 42;
      break;
    } else {
      label = 43;
      break;
    }
   case 42:
    HEAP32[$166 >> 2] = $R_1;
    label = 45;
    break;
   case 43:
    $171 = $101 + 20 | 0;
    HEAP32[$171 >> 2] = $R_1;
    label = 45;
    break;
   case 44:
    _abort();
    return 0;
    return 0;
   case 45:
    $174 = ($R_1 | 0) == 0;
    if ($174) {
      label = 56;
      break;
    } else {
      label = 46;
      break;
    }
   case 46:
    $176 = $R_1;
    $177 = HEAP32[1331243] | 0;
    $178 = $176 >>> 0 < $177 >>> 0;
    if ($178) {
      label = 55;
      break;
    } else {
      label = 47;
      break;
    }
   case 47:
    $180 = $R_1 + 24 | 0;
    HEAP32[$180 >> 2] = $101;
    $_sum3132 = $19 | 16;
    $181 = $oldbase + $_sum3132 | 0;
    $182 = $181;
    $183 = HEAP32[$182 >> 2] | 0;
    $184 = ($183 | 0) == 0;
    if ($184) {
      label = 51;
      break;
    } else {
      label = 48;
      break;
    }
   case 48:
    $186 = $183;
    $187 = HEAP32[1331243] | 0;
    $188 = $186 >>> 0 < $187 >>> 0;
    if ($188) {
      label = 50;
      break;
    } else {
      label = 49;
      break;
    }
   case 49:
    $190 = $R_1 + 16 | 0;
    HEAP32[$190 >> 2] = $183;
    $191 = $183 + 24 | 0;
    HEAP32[$191 >> 2] = $R_1;
    label = 51;
    break;
   case 50:
    _abort();
    return 0;
    return 0;
   case 51:
    $_sum33 = $_sum3132 + 4 | 0;
    $194 = $oldbase + $_sum33 | 0;
    $195 = $194;
    $196 = HEAP32[$195 >> 2] | 0;
    $197 = ($196 | 0) == 0;
    if ($197) {
      label = 56;
      break;
    } else {
      label = 52;
      break;
    }
   case 52:
    $199 = $196;
    $200 = HEAP32[1331243] | 0;
    $201 = $199 >>> 0 < $200 >>> 0;
    if ($201) {
      label = 54;
      break;
    } else {
      label = 53;
      break;
    }
   case 53:
    $203 = $R_1 + 20 | 0;
    HEAP32[$203 >> 2] = $196;
    $204 = $196 + 24 | 0;
    HEAP32[$204 >> 2] = $R_1;
    label = 56;
    break;
   case 54:
    _abort();
    return 0;
    return 0;
   case 55:
    _abort();
    return 0;
    return 0;
   case 56:
    $_sum9 = $57 | $19;
    $208 = $oldbase + $_sum9 | 0;
    $209 = $208;
    $210 = $57 + $27 | 0;
    $oldfirst_0 = $209;
    $qsize_0 = $210;
    label = 57;
    break;
   case 57:
    $212 = $oldfirst_0 + 4 | 0;
    $213 = HEAP32[$212 >> 2] | 0;
    $214 = $213 & -2;
    HEAP32[$212 >> 2] = $214;
    $215 = $qsize_0 | 1;
    $_sum10 = $_sum + 4 | 0;
    $216 = $newbase + $_sum10 | 0;
    $217 = $216;
    HEAP32[$217 >> 2] = $215;
    $_sum11 = $qsize_0 + $_sum | 0;
    $218 = $newbase + $_sum11 | 0;
    $219 = $218;
    HEAP32[$219 >> 2] = $qsize_0;
    $220 = $qsize_0 >>> 3;
    $221 = $qsize_0 >>> 0 < 256;
    if ($221) {
      label = 58;
      break;
    } else {
      label = 63;
      break;
    }
   case 58:
    $223 = $220 << 1;
    $224 = 5324996 + ($223 << 2) | 0;
    $225 = $224;
    $226 = HEAP32[1331239] | 0;
    $227 = 1 << $220;
    $228 = $226 & $227;
    $229 = ($228 | 0) == 0;
    if ($229) {
      label = 59;
      break;
    } else {
      label = 60;
      break;
    }
   case 59:
    $231 = $226 | $227;
    HEAP32[1331239] = $231;
    $F4_0 = $225;
    label = 62;
    break;
   case 60:
    $_sum29 = $223 + 2 | 0;
    $233 = 5324996 + ($_sum29 << 2) | 0;
    $234 = HEAP32[$233 >> 2] | 0;
    $235 = $234;
    $236 = HEAP32[1331243] | 0;
    $237 = $235 >>> 0 < $236 >>> 0;
    if ($237) {
      label = 61;
      break;
    } else {
      $F4_0 = $234;
      label = 62;
      break;
    }
   case 61:
    _abort();
    return 0;
    return 0;
   case 62:
    $_sum26 = $223 + 2 | 0;
    $240 = 5324996 + ($_sum26 << 2) | 0;
    HEAP32[$240 >> 2] = $26;
    $241 = $F4_0 + 12 | 0;
    HEAP32[$241 >> 2] = $26;
    $_sum27 = $_sum + 8 | 0;
    $242 = $newbase + $_sum27 | 0;
    $243 = $242;
    HEAP32[$243 >> 2] = $F4_0;
    $_sum28 = $_sum + 12 | 0;
    $244 = $newbase + $_sum28 | 0;
    $245 = $244;
    HEAP32[$245 >> 2] = $225;
    label = 80;
    break;
   case 63:
    $247 = $25;
    $248 = $qsize_0 >>> 8;
    $249 = ($248 | 0) == 0;
    if ($249) {
      $I7_0 = 0;
      label = 66;
      break;
    } else {
      label = 64;
      break;
    }
   case 64:
    $251 = $qsize_0 >>> 0 > 16777215;
    if ($251) {
      $I7_0 = 31;
      label = 66;
      break;
    } else {
      label = 65;
      break;
    }
   case 65:
    $253 = $248 + 1048320 | 0;
    $254 = $253 >>> 16;
    $255 = $254 & 8;
    $256 = $248 << $255;
    $257 = $256 + 520192 | 0;
    $258 = $257 >>> 16;
    $259 = $258 & 4;
    $260 = $259 | $255;
    $261 = $256 << $259;
    $262 = $261 + 245760 | 0;
    $263 = $262 >>> 16;
    $264 = $263 & 2;
    $265 = $260 | $264;
    $266 = 14 - $265 | 0;
    $267 = $261 << $264;
    $268 = $267 >>> 15;
    $269 = $266 + $268 | 0;
    $270 = $269 << 1;
    $271 = $269 + 7 | 0;
    $272 = $qsize_0 >>> ($271 >>> 0);
    $273 = $272 & 1;
    $274 = $273 | $270;
    $I7_0 = $274;
    label = 66;
    break;
   case 66:
    $276 = 5325260 + ($I7_0 << 2) | 0;
    $_sum12 = $_sum + 28 | 0;
    $277 = $newbase + $_sum12 | 0;
    $278 = $277;
    HEAP32[$278 >> 2] = $I7_0;
    $_sum13 = $_sum + 16 | 0;
    $279 = $newbase + $_sum13 | 0;
    $_sum14 = $_sum + 20 | 0;
    $280 = $newbase + $_sum14 | 0;
    $281 = $280;
    HEAP32[$281 >> 2] = 0;
    $282 = $279;
    HEAP32[$282 >> 2] = 0;
    $283 = HEAP32[1331240] | 0;
    $284 = 1 << $I7_0;
    $285 = $283 & $284;
    $286 = ($285 | 0) == 0;
    if ($286) {
      label = 67;
      break;
    } else {
      label = 68;
      break;
    }
   case 67:
    $288 = $283 | $284;
    HEAP32[1331240] = $288;
    HEAP32[$276 >> 2] = $247;
    $289 = $276;
    $_sum15 = $_sum + 24 | 0;
    $290 = $newbase + $_sum15 | 0;
    $291 = $290;
    HEAP32[$291 >> 2] = $289;
    $_sum16 = $_sum + 12 | 0;
    $292 = $newbase + $_sum16 | 0;
    $293 = $292;
    HEAP32[$293 >> 2] = $247;
    $_sum17 = $_sum + 8 | 0;
    $294 = $newbase + $_sum17 | 0;
    $295 = $294;
    HEAP32[$295 >> 2] = $247;
    label = 80;
    break;
   case 68:
    $297 = HEAP32[$276 >> 2] | 0;
    $298 = ($I7_0 | 0) == 31;
    if ($298) {
      $303 = 0;
      label = 70;
      break;
    } else {
      label = 69;
      break;
    }
   case 69:
    $300 = $I7_0 >>> 1;
    $301 = 25 - $300 | 0;
    $303 = $301;
    label = 70;
    break;
   case 70:
    $304 = $qsize_0 << $303;
    $K8_0 = $304;
    $T_0 = $297;
    label = 71;
    break;
   case 71:
    $306 = $T_0 + 4 | 0;
    $307 = HEAP32[$306 >> 2] | 0;
    $308 = $307 & -8;
    $309 = ($308 | 0) == ($qsize_0 | 0);
    if ($309) {
      label = 76;
      break;
    } else {
      label = 72;
      break;
    }
   case 72:
    $311 = $K8_0 >>> 31;
    $312 = $T_0 + 16 + ($311 << 2) | 0;
    $313 = HEAP32[$312 >> 2] | 0;
    $314 = ($313 | 0) == 0;
    $315 = $K8_0 << 1;
    if ($314) {
      label = 73;
      break;
    } else {
      $K8_0 = $315;
      $T_0 = $313;
      label = 71;
      break;
    }
   case 73:
    $317 = $312;
    $318 = HEAP32[1331243] | 0;
    $319 = $317 >>> 0 < $318 >>> 0;
    if ($319) {
      label = 75;
      break;
    } else {
      label = 74;
      break;
    }
   case 74:
    HEAP32[$312 >> 2] = $247;
    $_sum23 = $_sum + 24 | 0;
    $321 = $newbase + $_sum23 | 0;
    $322 = $321;
    HEAP32[$322 >> 2] = $T_0;
    $_sum24 = $_sum + 12 | 0;
    $323 = $newbase + $_sum24 | 0;
    $324 = $323;
    HEAP32[$324 >> 2] = $247;
    $_sum25 = $_sum + 8 | 0;
    $325 = $newbase + $_sum25 | 0;
    $326 = $325;
    HEAP32[$326 >> 2] = $247;
    label = 80;
    break;
   case 75:
    _abort();
    return 0;
    return 0;
   case 76:
    $329 = $T_0 + 8 | 0;
    $330 = HEAP32[$329 >> 2] | 0;
    $331 = $T_0;
    $332 = HEAP32[1331243] | 0;
    $333 = $331 >>> 0 < $332 >>> 0;
    if ($333) {
      label = 79;
      break;
    } else {
      label = 77;
      break;
    }
   case 77:
    $335 = $330;
    $336 = $335 >>> 0 < $332 >>> 0;
    if ($336) {
      label = 79;
      break;
    } else {
      label = 78;
      break;
    }
   case 78:
    $338 = $330 + 12 | 0;
    HEAP32[$338 >> 2] = $247;
    HEAP32[$329 >> 2] = $247;
    $_sum20 = $_sum + 8 | 0;
    $339 = $newbase + $_sum20 | 0;
    $340 = $339;
    HEAP32[$340 >> 2] = $330;
    $_sum21 = $_sum + 12 | 0;
    $341 = $newbase + $_sum21 | 0;
    $342 = $341;
    HEAP32[$342 >> 2] = $T_0;
    $_sum22 = $_sum + 24 | 0;
    $343 = $newbase + $_sum22 | 0;
    $344 = $343;
    HEAP32[$344 >> 2] = 0;
    label = 80;
    break;
   case 79:
    _abort();
    return 0;
    return 0;
   case 80:
    $_sum1819 = $9 | 8;
    $346 = $newbase + $_sum1819 | 0;
    return $346 | 0;
  }
  return 0;
}
function _add_segment($tbase, $tsize) {
  $tbase = $tbase | 0;
  $tsize = $tsize | 0;
  var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_sum = 0, $_sum1 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $17 = 0, $_sum2 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $_sum3 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $62 = 0, $_sum11 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $F_0 = 0, $_sum10 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $76 = 0, $77 = 0, $78 = 0, $80 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $I1_0 = 0, $105 = 0, $106 = 0, $I1_0_c = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $114 = 0, $115 = 0, $_c = 0, $116 = 0, $117 = 0, $119 = 0, $120 = 0, $122 = 0, $123 = 0, $125 = 0, $126 = 0, $T_0 = 0, $K2_0 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $139 = 0, $140 = 0, $141 = 0, $143 = 0, $T_0_c7 = 0, $144 = 0, $145 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $152 = 0, $154 = 0, $155 = 0, $157 = 0, $158 = 0, $_c6 = 0, $159 = 0, $T_0_c = 0, $160 = 0, label = 0;
  label = 1;
  while (1) switch (label | 0) {
   case 1:
    $1 = HEAP32[1331245] | 0;
    $2 = $1;
    $3 = _segment_holding($2) | 0;
    $4 = $3 | 0;
    $5 = HEAP32[$4 >> 2] | 0;
    $6 = $3 + 4 | 0;
    $7 = HEAP32[$6 >> 2] | 0;
    $8 = $5 + $7 | 0;
    $_sum = $7 - 47 | 0;
    $_sum1 = $7 - 39 | 0;
    $9 = $5 + $_sum1 | 0;
    $10 = $9;
    $11 = $10 & 7;
    $12 = ($11 | 0) == 0;
    if ($12) {
      $17 = 0;
      label = 3;
      break;
    } else {
      label = 2;
      break;
    }
   case 2:
    $14 = -$10 | 0;
    $15 = $14 & 7;
    $17 = $15;
    label = 3;
    break;
   case 3:
    $_sum2 = $_sum + $17 | 0;
    $18 = $5 + $_sum2 | 0;
    $19 = $1 + 16 | 0;
    $20 = $19;
    $21 = $18 >>> 0 < $20 >>> 0;
    $22 = $21 ? $2 : $18;
    $23 = $22 + 8 | 0;
    $24 = $23;
    $25 = $tbase;
    $26 = $tsize - 40 | 0;
    _init_top($25, $26);
    $27 = $22 + 4 | 0;
    $28 = $27;
    HEAP32[$28 >> 2] = 27;
    _memcpy($23 | 0, 5325404, 16);
    HEAP32[1331351] = $tbase;
    HEAP32[1331352] = $tsize;
    HEAP32[1331354] = 0;
    HEAP32[1331353] = $24;
    $29 = $22 + 28 | 0;
    $30 = $29;
    HEAP32[$30 >> 2] = 7;
    $31 = $22 + 32 | 0;
    $32 = $31 >>> 0 < $8 >>> 0;
    if ($32) {
      $33 = $30;
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 4:
    $34 = $33 + 4 | 0;
    HEAP32[$34 >> 2] = 7;
    $35 = $33 + 8 | 0;
    $36 = $35;
    $37 = $36 >>> 0 < $8 >>> 0;
    if ($37) {
      $33 = $34;
      label = 4;
      break;
    } else {
      label = 5;
      break;
    }
   case 5:
    $38 = ($22 | 0) == ($2 | 0);
    if ($38) {
      label = 29;
      break;
    } else {
      label = 6;
      break;
    }
   case 6:
    $40 = $22;
    $41 = $1;
    $42 = $40 - $41 | 0;
    $43 = $2 + $42 | 0;
    $_sum3 = $42 + 4 | 0;
    $44 = $2 + $_sum3 | 0;
    $45 = $44;
    $46 = HEAP32[$45 >> 2] | 0;
    $47 = $46 & -2;
    HEAP32[$45 >> 2] = $47;
    $48 = $42 | 1;
    $49 = $1 + 4 | 0;
    HEAP32[$49 >> 2] = $48;
    $50 = $43;
    HEAP32[$50 >> 2] = $42;
    $51 = $42 >>> 3;
    $52 = $42 >>> 0 < 256;
    if ($52) {
      label = 7;
      break;
    } else {
      label = 12;
      break;
    }
   case 7:
    $54 = $51 << 1;
    $55 = 5324996 + ($54 << 2) | 0;
    $56 = $55;
    $57 = HEAP32[1331239] | 0;
    $58 = 1 << $51;
    $59 = $57 & $58;
    $60 = ($59 | 0) == 0;
    if ($60) {
      label = 8;
      break;
    } else {
      label = 9;
      break;
    }
   case 8:
    $62 = $57 | $58;
    HEAP32[1331239] = $62;
    $F_0 = $56;
    label = 11;
    break;
   case 9:
    $_sum11 = $54 + 2 | 0;
    $64 = 5324996 + ($_sum11 << 2) | 0;
    $65 = HEAP32[$64 >> 2] | 0;
    $66 = $65;
    $67 = HEAP32[1331243] | 0;
    $68 = $66 >>> 0 < $67 >>> 0;
    if ($68) {
      label = 10;
      break;
    } else {
      $F_0 = $65;
      label = 11;
      break;
    }
   case 10:
    _abort();
   case 11:
    $_sum10 = $54 + 2 | 0;
    $71 = 5324996 + ($_sum10 << 2) | 0;
    HEAP32[$71 >> 2] = $1;
    $72 = $F_0 + 12 | 0;
    HEAP32[$72 >> 2] = $1;
    $73 = $1 + 8 | 0;
    HEAP32[$73 >> 2] = $F_0;
    $74 = $1 + 12 | 0;
    HEAP32[$74 >> 2] = $56;
    label = 29;
    break;
   case 12:
    $76 = $1;
    $77 = $42 >>> 8;
    $78 = ($77 | 0) == 0;
    if ($78) {
      $I1_0 = 0;
      label = 15;
      break;
    } else {
      label = 13;
      break;
    }
   case 13:
    $80 = $42 >>> 0 > 16777215;
    if ($80) {
      $I1_0 = 31;
      label = 15;
      break;
    } else {
      label = 14;
      break;
    }
   case 14:
    $82 = $77 + 1048320 | 0;
    $83 = $82 >>> 16;
    $84 = $83 & 8;
    $85 = $77 << $84;
    $86 = $85 + 520192 | 0;
    $87 = $86 >>> 16;
    $88 = $87 & 4;
    $89 = $88 | $84;
    $90 = $85 << $88;
    $91 = $90 + 245760 | 0;
    $92 = $91 >>> 16;
    $93 = $92 & 2;
    $94 = $89 | $93;
    $95 = 14 - $94 | 0;
    $96 = $90 << $93;
    $97 = $96 >>> 15;
    $98 = $95 + $97 | 0;
    $99 = $98 << 1;
    $100 = $98 + 7 | 0;
    $101 = $42 >>> ($100 >>> 0);
    $102 = $101 & 1;
    $103 = $102 | $99;
    $I1_0 = $103;
    label = 15;
    break;
   case 15:
    $105 = 5325260 + ($I1_0 << 2) | 0;
    $106 = $1 + 28 | 0;
    $I1_0_c = $I1_0;
    HEAP32[$106 >> 2] = $I1_0_c;
    $107 = $1 + 20 | 0;
    HEAP32[$107 >> 2] = 0;
    $108 = $1 + 16 | 0;
    HEAP32[$108 >> 2] = 0;
    $109 = HEAP32[1331240] | 0;
    $110 = 1 << $I1_0;
    $111 = $109 & $110;
    $112 = ($111 | 0) == 0;
    if ($112) {
      label = 16;
      break;
    } else {
      label = 17;
      break;
    }
   case 16:
    $114 = $109 | $110;
    HEAP32[1331240] = $114;
    HEAP32[$105 >> 2] = $76;
    $115 = $1 + 24 | 0;
    $_c = $105;
    HEAP32[$115 >> 2] = $_c;
    $116 = $1 + 12 | 0;
    HEAP32[$116 >> 2] = $1;
    $117 = $1 + 8 | 0;
    HEAP32[$117 >> 2] = $1;
    label = 29;
    break;
   case 17:
    $119 = HEAP32[$105 >> 2] | 0;
    $120 = ($I1_0 | 0) == 31;
    if ($120) {
      $125 = 0;
      label = 19;
      break;
    } else {
      label = 18;
      break;
    }
   case 18:
    $122 = $I1_0 >>> 1;
    $123 = 25 - $122 | 0;
    $125 = $123;
    label = 19;
    break;
   case 19:
    $126 = $42 << $125;
    $K2_0 = $126;
    $T_0 = $119;
    label = 20;
    break;
   case 20:
    $128 = $T_0 + 4 | 0;
    $129 = HEAP32[$128 >> 2] | 0;
    $130 = $129 & -8;
    $131 = ($130 | 0) == ($42 | 0);
    if ($131) {
      label = 25;
      break;
    } else {
      label = 21;
      break;
    }
   case 21:
    $133 = $K2_0 >>> 31;
    $134 = $T_0 + 16 + ($133 << 2) | 0;
    $135 = HEAP32[$134 >> 2] | 0;
    $136 = ($135 | 0) == 0;
    $137 = $K2_0 << 1;
    if ($136) {
      label = 22;
      break;
    } else {
      $K2_0 = $137;
      $T_0 = $135;
      label = 20;
      break;
    }
   case 22:
    $139 = $134;
    $140 = HEAP32[1331243] | 0;
    $141 = $139 >>> 0 < $140 >>> 0;
    if ($141) {
      label = 24;
      break;
    } else {
      label = 23;
      break;
    }
   case 23:
    HEAP32[$134 >> 2] = $76;
    $143 = $1 + 24 | 0;
    $T_0_c7 = $T_0;
    HEAP32[$143 >> 2] = $T_0_c7;
    $144 = $1 + 12 | 0;
    HEAP32[$144 >> 2] = $1;
    $145 = $1 + 8 | 0;
    HEAP32[$145 >> 2] = $1;
    label = 29;
    break;
   case 24:
    _abort();
   case 25:
    $148 = $T_0 + 8 | 0;
    $149 = HEAP32[$148 >> 2] | 0;
    $150 = $T_0;
    $151 = HEAP32[1331243] | 0;
    $152 = $150 >>> 0 < $151 >>> 0;
    if ($152) {
      label = 28;
      break;
    } else {
      label = 26;
      break;
    }
   case 26:
    $154 = $149;
    $155 = $154 >>> 0 < $151 >>> 0;
    if ($155) {
      label = 28;
      break;
    } else {
      label = 27;
      break;
    }
   case 27:
    $157 = $149 + 12 | 0;
    HEAP32[$157 >> 2] = $76;
    HEAP32[$148 >> 2] = $76;
    $158 = $1 + 8 | 0;
    $_c6 = $149;
    HEAP32[$158 >> 2] = $_c6;
    $159 = $1 + 12 | 0;
    $T_0_c = $T_0;
    HEAP32[$159 >> 2] = $T_0_c;
    $160 = $1 + 24 | 0;
    HEAP32[$160 >> 2] = 0;
    label = 29;
    break;
   case 28:
    _abort();
   case 29:
    return;
  }
}
function _strlen(ptr) {
  ptr = ptr | 0;
  var curr = 0;
  curr = ptr;
  while (HEAP8[curr] | 0 != 0) {
    curr = curr + 1 | 0;
  }
  return curr - ptr | 0;
}
function _memcpy(dest, src, num) {
  dest = dest | 0;
  src = src | 0;
  num = num | 0;
  var ret = 0;
  ret = dest | 0;
  if ((dest & 3) == (src & 3)) {
    while (dest & 3) {
      if ((num | 0) == 0) return ret | 0;
      HEAP8[dest] = HEAP8[src] | 0;
      dest = dest + 1 | 0;
      src = src + 1 | 0;
      num = num - 1 | 0;
    }
    while ((num | 0) >= 4) {
      HEAP32[dest >> 2] = HEAP32[src >> 2] | 0;
      dest = dest + 4 | 0;
      src = src + 4 | 0;
      num = num - 4 | 0;
    }
  }
  while ((num | 0) > 0) {
    HEAP8[dest] = HEAP8[src] | 0;
    dest = dest + 1 | 0;
    src = src + 1 | 0;
    num = num - 1 | 0;
  }
  return ret | 0;
}
function _memmove(dest, src, num) {
  dest = dest | 0;
  src = src | 0;
  num = num | 0;
  if ((src | 0) < (dest | 0) & (dest | 0) < (src + num | 0)) {
    src = src + num | 0;
    dest = dest + num | 0;
    while ((num | 0) > 0) {
      dest = dest - 1 | 0;
      src = src - 1 | 0;
      num = num - 1 | 0;
      HEAP8[dest] = HEAP8[src] | 0;
    }
  } else {
    _memcpy(dest, src, num);
  }
}
function _saveSetjmp(env, label, table) {
  env = env | 0;
  label = label | 0;
  table = table | 0;
  var i = 0;
  setjmpId = setjmpId + 1 | 0;
  HEAP32[env >> 2] = setjmpId;
  while ((i | 0) < 10) {
    if ((HEAP32[table + i * 4 >> 2] | 0) == 0) {
      HEAP32[table + i * 4 >> 2] = setjmpId;
      HEAP32[table + (i * 4 + 4) >> 2] = label;
      HEAP32[table + (i * 4 + 8) >> 2] = 0;
      return 0;
    }
    i = i + 2 | 0;
  }
  abort(987);
  return 0;
}
function _testSetjmp(id, table) {
  id = id | 0;
  table = table | 0;
  var i = 0, curr = 0;
  while ((i | 0) < 10) {
    curr = HEAP32[table + i * 4 >> 2] | 0;
    if ((curr | 0) == 0) break;
    if ((curr | 0) == (id | 0)) {
      return HEAP32[table + (i * 4 + 4) >> 2] | 0;
    }
    i = i + 2 | 0;
  }
  return 0;
}
function _memset(ptr, value, num) {
  ptr = ptr | 0;
  value = value | 0;
  num = num | 0;
  var stop = 0, value4 = 0, stop4 = 0, unaligned = 0;
  stop = ptr + num | 0;
  if ((num | 0) >= 20) {
    value = value & 255;
    unaligned = ptr & 3;
    value4 = value | value << 8 | value << 16 | value << 24;
    stop4 = stop & ~3;
    if (unaligned) {
      unaligned = ptr + 4 - unaligned | 0;
      while ((ptr | 0) < (unaligned | 0)) {
        HEAP8[ptr] = value;
        ptr = ptr + 1 | 0;
      }
    }
    while ((ptr | 0) < (stop4 | 0)) {
      HEAP32[ptr >> 2] = value4;
      ptr = ptr + 4 | 0;
    }
  }
  while ((ptr | 0) < (stop | 0)) {
    HEAP8[ptr] = value;
    ptr = ptr + 1 | 0;
  }
}
function _strncpy(pdest, psrc, num) {
  pdest = pdest | 0;
  psrc = psrc | 0;
  num = num | 0;
  var padding = 0, i = 0;
  while ((i | 0) < (num | 0)) {
    HEAP8[pdest + i | 0] = padding ? 0 : HEAP8[psrc + i | 0] | 0;
    padding = padding ? 1 : (HEAP8[psrc + i | 0] | 0) == 0;
    i = i + 1 | 0;
  }
  return pdest | 0;
}
function _strcat(pdest, psrc) {
  pdest = pdest | 0;
  psrc = psrc | 0;
  var i = 0;
  pdest = pdest + _strlen(pdest) | 0;
  do {
    HEAP8[pdest + i | 0] = HEAP8[psrc + i | 0];
    i = i + 1 | 0;
  } while ((HEAP8[psrc + (i - 1) | 0] | 0) != 0);
  return pdest | 0;
}
function _memcmp(p1, p2, num) {
  p1 = p1 | 0;
  p2 = p2 | 0;
  num = num | 0;
  var i = 0, v1 = 0, v2 = 0;
  while ((i | 0) < (num | 0)) {
    v1 = HEAPU8[p1 + i | 0] | 0;
    v2 = HEAPU8[p2 + i | 0] | 0;
    if ((v1 | 0) != (v2 | 0)) return ((v1 | 0) > (v2 | 0) ? 1 : -1) | 0;
    i = i + 1 | 0;
  }
  return 0;
}
function dynCall_iiii(index, a1, a2, a3) {
  index = index | 0;
  a1 = a1 | 0;
  a2 = a2 | 0;
  a3 = a3 | 0;
  return FUNCTION_TABLE_iiii[index & 1023](a1 | 0, a2 | 0, a3 | 0) | 0;
}
function dynCall_viiiii(index, a1, a2, a3, a4, a5) {
  index = index | 0;
  a1 = a1 | 0;
  a2 = a2 | 0;
  a3 = a3 | 0;
  a4 = a4 | 0;
  a5 = a5 | 0;
  FUNCTION_TABLE_viiiii[index & 1023](a1 | 0, a2 | 0, a3 | 0, a4 | 0, a5 | 0);
}
function dynCall_vi(index, a1) {
  index = index | 0;
  a1 = a1 | 0;
  FUNCTION_TABLE_vi[index & 1023](a1 | 0);
}
function dynCall_vii(index, a1, a2) {
  index = index | 0;
  a1 = a1 | 0;
  a2 = a2 | 0;
  FUNCTION_TABLE_vii[index & 1023](a1 | 0, a2 | 0);
}
function dynCall_iiiiiii(index, a1, a2, a3, a4, a5, a6) {
  index = index | 0;
  a1 = a1 | 0;
  a2 = a2 | 0;
  a3 = a3 | 0;
  a4 = a4 | 0;
  a5 = a5 | 0;
  a6 = a6 | 0;
  return FUNCTION_TABLE_iiiiiii[index & 1023](a1 | 0, a2 | 0, a3 | 0, a4 | 0, a5 | 0, a6 | 0) | 0;
}
function dynCall_ii(index, a1) {
  index = index | 0;
  a1 = a1 | 0;
  return FUNCTION_TABLE_ii[index & 1023](a1 | 0) | 0;
}
function dynCall_iiiiiiiiii(index, a1, a2, a3, a4, a5, a6, a7, a8, a9) {
  index = index | 0;
  a1 = a1 | 0;
  a2 = a2 | 0;
  a3 = a3 | 0;
  a4 = a4 | 0;
  a5 = a5 | 0;
  a6 = a6 | 0;
  a7 = a7 | 0;
  a8 = a8 | 0;
  a9 = a9 | 0;
  return FUNCTION_TABLE_iiiiiiiiii[index & 1023](a1 | 0, a2 | 0, a3 | 0, a4 | 0, a5 | 0, a6 | 0, a7 | 0, a8 | 0, a9 | 0) | 0;
}
function dynCall_viii(index, a1, a2, a3) {
  index = index | 0;
  a1 = a1 | 0;
  a2 = a2 | 0;
  a3 = a3 | 0;
  FUNCTION_TABLE_viii[index & 1023](a1 | 0, a2 | 0, a3 | 0);
}
function dynCall_v(index) {
  index = index | 0;
  FUNCTION_TABLE_v[index & 1023]();
}
function dynCall_iiiii(index, a1, a2, a3, a4) {
  index = index | 0;
  a1 = a1 | 0;
  a2 = a2 | 0;
  a3 = a3 | 0;
  a4 = a4 | 0;
  return FUNCTION_TABLE_iiiii[index & 1023](a1 | 0, a2 | 0, a3 | 0, a4 | 0) | 0;
}
function dynCall_iiiiiiii(index, a1, a2, a3, a4, a5, a6, a7) {
  index = index | 0;
  a1 = a1 | 0;
  a2 = a2 | 0;
  a3 = a3 | 0;
  a4 = a4 | 0;
  a5 = a5 | 0;
  a6 = a6 | 0;
  a7 = a7 | 0;
  return FUNCTION_TABLE_iiiiiiii[index & 1023](a1 | 0, a2 | 0, a3 | 0, a4 | 0, a5 | 0, a6 | 0, a7 | 0) | 0;
}
function dynCall_viiiiii(index, a1, a2, a3, a4, a5, a6) {
  index = index | 0;
  a1 = a1 | 0;
  a2 = a2 | 0;
  a3 = a3 | 0;
  a4 = a4 | 0;
  a5 = a5 | 0;
  a6 = a6 | 0;
  FUNCTION_TABLE_viiiiii[index & 1023](a1 | 0, a2 | 0, a3 | 0, a4 | 0, a5 | 0, a6 | 0);
}
function dynCall_iii(index, a1, a2) {
  index = index | 0;
  a1 = a1 | 0;
  a2 = a2 | 0;
  return FUNCTION_TABLE_iii[index & 1023](a1 | 0, a2 | 0) | 0;
}
function dynCall_iiiiii(index, a1, a2, a3, a4, a5) {
  index = index | 0;
  a1 = a1 | 0;
  a2 = a2 | 0;
  a3 = a3 | 0;
  a4 = a4 | 0;
  a5 = a5 | 0;
  return FUNCTION_TABLE_iiiiii[index & 1023](a1 | 0, a2 | 0, a3 | 0, a4 | 0, a5 | 0) | 0;
}
function dynCall_viiii(index, a1, a2, a3, a4) {
  index = index | 0;
  a1 = a1 | 0;
  a2 = a2 | 0;
  a3 = a3 | 0;
  a4 = a4 | 0;
  FUNCTION_TABLE_viiii[index & 1023](a1 | 0, a2 | 0, a3 | 0, a4 | 0);
}
function b0(p0, p1, p2) {
  p0 = p0 | 0;
  p1 = p1 | 0;
  p2 = p2 | 0;
  abort(0);
  return 0;
}
function b1(p0, p1, p2, p3, p4) {
  p0 = p0 | 0;
  p1 = p1 | 0;
  p2 = p2 | 0;
  p3 = p3 | 0;
  p4 = p4 | 0;
  abort(1);
}
function b2(p0) {
  p0 = p0 | 0;
  abort(2);
}
function b3(p0, p1) {
  p0 = p0 | 0;
  p1 = p1 | 0;
  abort(3);
}
function b4(p0, p1, p2, p3, p4, p5) {
  p0 = p0 | 0;
  p1 = p1 | 0;
  p2 = p2 | 0;
  p3 = p3 | 0;
  p4 = p4 | 0;
  p5 = p5 | 0;
  abort(4);
  return 0;
}
function b5(p0) {
  p0 = p0 | 0;
  abort(5);
  return 0;
}
function b6(p0, p1, p2, p3, p4, p5, p6, p7, p8) {
  p0 = p0 | 0;
  p1 = p1 | 0;
  p2 = p2 | 0;
  p3 = p3 | 0;
  p4 = p4 | 0;
  p5 = p5 | 0;
  p6 = p6 | 0;
  p7 = p7 | 0;
  p8 = p8 | 0;
  abort(6);
  return 0;
}
function b7(p0, p1, p2) {
  p0 = p0 | 0;
  p1 = p1 | 0;
  p2 = p2 | 0;
  abort(7);
}
function b8() {
  abort(8);
}
function b9(p0, p1, p2, p3) {
  p0 = p0 | 0;
  p1 = p1 | 0;
  p2 = p2 | 0;
  p3 = p3 | 0;
  abort(9);
  return 0;
}
function b10(p0, p1, p2, p3, p4, p5, p6) {
  p0 = p0 | 0;
  p1 = p1 | 0;
  p2 = p2 | 0;
  p3 = p3 | 0;
  p4 = p4 | 0;
  p5 = p5 | 0;
  p6 = p6 | 0;
  abort(10);
  return 0;
}
function b11(p0, p1, p2, p3, p4, p5) {
  p0 = p0 | 0;
  p1 = p1 | 0;
  p2 = p2 | 0;
  p3 = p3 | 0;
  p4 = p4 | 0;
  p5 = p5 | 0;
  abort(11);
}
function b12(p0, p1) {
  p0 = p0 | 0;
  p1 = p1 | 0;
  abort(12);
  return 0;
}
function b13(p0, p1, p2, p3, p4) {
  p0 = p0 | 0;
  p1 = p1 | 0;
  p2 = p2 | 0;
  p3 = p3 | 0;
  p4 = p4 | 0;
  abort(13);
  return 0;
}
function b14(p0, p1, p2, p3) {
  p0 = p0 | 0;
  p1 = p1 | 0;
  p2 = p2 | 0;
  p3 = p3 | 0;
  abort(14);
}
// EMSCRIPTEN_END_FUNCS
  var FUNCTION_TABLE_iiii = [b0,b0,b0,b0,_Round_Super,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,_Round_Up_To_Grid,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,_pcf_get_bdf_property,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,_t1_get_index,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,_t1_builder_add_point1,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,_sfnt_get_charset_id,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,_t1_builder_start_point,b0,b0,b0,b0,b0,_tt_face_set_sbit_strike
  ,b0,b0,b0,_pfr_extra_item_load_bitmap_info,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,_t1_decoder_parse_charstrings,b0,_tt_face_find_bdf_prop,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,_af_indic_hints_apply,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,_gray_conic_to
  ,b0,b0,b0,_Round_To_Grid,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,_pcf_get_charset_id
  ,b0,b0,b0,b0,b0,_T1_Set_MM_Blend,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,_Round_To_Double_Grid,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,_tt_face_load_charmap_stub,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,_tt_face_get_kerning,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,_tt_face_load_hmtx,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,_Round_To_Half_Grid,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,_tt_cmap14_char_variants
  ,b0,_T1_Set_Var_Design,b0,b0,b0,b0,b0,b0,b0,_tt_face_load_hhea
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,_Round_None,b0,b0,b0,b0
  ,b0,b0,b0,_tt_load_sbit_metrics,b0,_tt_face_load_directory_stub,b0,b0,b0,_Dual_Project
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,_ft_gzip_alloc,b0,b0,b0,b0,b0,b0,b0,_pfr_extra_item_load_kerning_pairs
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,_af_latin_hints_apply,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,_cid_get_cid_from_glyph_index
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,_pfr_extra_item_load_font_id
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,_tt_face_load_strike_metrics,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,_Round_Down_To_Grid,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,_pfr_get_advance,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,_tt_cmap14_variant_chars,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,_tt_face_get_ps_name
  ,b0,b0,b0,b0,b0,_bdf_get_bdf_property,b0,b0,b0,_FT_Outline_Decompose
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,_T1_Set_MM_Design,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,_pfr_extra_item_load_stem_snaps,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,_cff_get_cid_from_glyph_index,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,_bdf_get_charset_id
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,_TT_Set_Var_Design,b0,_Project_y,b0,_Project_x,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,_psh_globals_new,b0,b0,b0,b0
  ,b0,_ft_raster1_set_mode,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,_tt_cmap14_char_var_isdefault,b0,b0,b0,_Project,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,_af_cjk_hints_apply,b0,b0,b0,_ps_parser_to_coord_array
  ,b0,b0,b0,b0,b0,_TT_Set_MM_Blend,b0,_tt_face_get_location,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,_ft_stub_set_pixel_sizes,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,_ft_smooth_set_mode,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,_ps_table_new,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,_Round_Super_45,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
  ,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0];
  var FUNCTION_TABLE_viiiii = [b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,_t1_builder_init,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1];
  var FUNCTION_TABLE_vi = [b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,_tt_cmap14_done,b2,b2,b2,b2,b2,b2,b2,_ps_table_done
  ,b2,b2,b2,b2,b2,b2,b2,_afm_parser_done,b2,b2
  ,b2,b2,b2,_T42_GlyphSlot_Done,b2,_af_face_globals_free,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,_pfr_face_done,b2,b2,b2,b2
  ,b2,b2,b2,_t1_cmap_unicode_done,b2,_psh_globals_destroy,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,_gray_record_cell,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,_gray_raster_done
  ,b2,_tt_size_done,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,_T1_Face_Done
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,_pcf_cmap_done
  ,b2,_t1_cmap_custom_done,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,_cid_slot_done,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,_cid_face_done,b2,_FNT_Face_Done
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,_Split_Conic,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,_sfnt_done_face,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,_tt_face_free_ps_names,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,_cid_size_done,b2,b2,b2,b2,b2,_T1_Driver_Done,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,_t2_hints_open,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,_tt_face_free_eblc,b2,_af_autofitter_done,b2,b2
  ,b2,b2,b2,_pfr_cmap_done,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,_T42_Driver_Done,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,_t1_cmap_std_done
  ,b2,_ps_parser_skip_spaces,b2,b2,b2,b2,b2,b2,b2,_ps_parser_skip_PS_token
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,_ft_black_done,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,_cff_size_done,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,_cff_face_done,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,_T42_Face_Done,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,_cff_driver_done,b2,b2,b2,b2
  ,b2,_cff_cmap_unicode_done,b2,b2,b2,b2,b2,_ft_gzip_stream_close,b2,b2
  ,b2,_ps_table_release,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,_tt_face_done,b2,_ps_parser_done,b2,b2,b2,b2,b2,b2
  ,b2,_tt_face_free_sbit_stub,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,_Split_Cubic,b2,_TT_Forget_Glyph_Frame
  ,b2,b2,b2,b2,b2,_ps_hinter_done,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,_T1_GlyphSlot_Done,b2,b2
  ,b2,b2,b2,b2,b2,_cid_driver_done,b2,b2,b2,b2
  ,b2,b2,b2,_tt_face_free_name,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,_tt_face_free_hdmx_stub,b2,b2,b2,_t1_decoder_done,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,_pfr_slot_done,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,_bdf_cmap_done,b2,_BDF_Face_Done
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,_PCF_Face_Done,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,_t1_builder_close_contour
  ,b2,b2,b2,b2,b2,_t1_builder_done,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,_cff_cmap_encoding_done,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,_Vertical_Sweep_Step,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,_T1_Size_Done,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,_T42_Size_Done,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,_tt_driver_done,b2,_ft_lzw_stream_close,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,_memory_stream_close,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,_t1_hints_open,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,_cff_slot_done
  ,b2,b2,b2,b2,b2,_Horizontal_Sweep_Step,b2,b2,b2,b2
  ,b2,_ft_ansi_stream_close,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
  ,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2];
  var FUNCTION_TABLE_vii = [b3,b3,_ps_hints_t1reset,b3,b3,b3,_parse_font_matrix,b3,b3,b3,b3
  ,b3,b3,b3,_t42_parse_encoding,b3,b3,b3,b3,b3,_t42_parse_charstrings
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,_parse_blend_design_map
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,_af_indic_metrics_scale,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,_af_cjk_metrics_scale,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,_t42_parse_sfnts,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,_ps_parser_to_token,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,_parse_encoding,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,_parse_private,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,_parse_weight_vector,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,_parse_charstrings,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,_ft_gzip_free,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,_ft_free,b3,b3,b3,_parse_blend_design_positions
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,_af_latin_metrics_scale,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,_parse_buildchar,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,_t42_parse_font_matrix,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,_parse_subrs,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,_parse_blend_axis_types,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3];
  var FUNCTION_TABLE_iiiiiii = [b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,_ps_unicodes_init,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,_tt_find_sbit_image,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4];
  var FUNCTION_TABLE_ii = [b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,_cff_cmap_encoding_init,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,_cff_driver_init,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,_T1_Size_Init,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,_TT_RunIns,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,_cff_parse_private_dict,b5,b5,b5,b5
  ,b5,_ps_get_macintosh_name,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,_pfr_cmap_init,b5,_ft_smooth_init,b5,_t1_builder_add_contour,b5,b5,b5,b5
  ,b5,_tt_size_init,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,_t1_get_ps_name
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,_t1_ps_has_glyph_names,b5,b5,b5,_cff_size_init
  ,b5,b5,b5,b5,b5,_cff_slot_init,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,_T42_GlyphSlot_Init,b5,b5,b5,b5,b5,b5,b5,_ps_parser_to_int
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,_T42_Driver_Init,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,_t1_cmap_standard_init
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,_cid_size_init,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,_cff_get_ps_name
  ,b5,_t1_cmap_expert_init,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,_ft_raster1_init,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,_cff_cmap_unicode_init
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,_FNT_Size_Select,b5,b5,b5,_T42_Size_Init,b5,_fnt_cmap_init,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,_t1_cmap_custom_init,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,_pshinter_get_globals_funcs,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,_cff_parse_font_bbox,b5,b5,b5,b5,b5,_T1_Driver_Init
  ,b5,b5,b5,b5,b5,b5,b5,_cff_ps_has_glyph_names,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,_pshinter_get_t2_funcs
  ,b5,b5,b5,_t42_ps_has_glyph_names,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,_pshinter_get_t1_funcs
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,_t1_cmap_unicode_init,b5,_T1_GlyphSlot_Init,b5,b5,b5,_ps_hinter_init,b5,b5
  ,b5,_cid_slot_init,b5,b5,b5,b5,b5,_cff_parse_cid_ros,b5,b5
  ,b5,_TT_Load_Composite_Glyph,b5,b5,b5,b5,b5,b5,b5,_TT_Load_Glyph_Header
  ,b5,b5,b5,b5,b5,_cid_get_postscript_name,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,_tt_slot_init,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,_TT_Load_Simple_Glyph,b5,b5,b5,_ps_get_standard_strings,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,_af_autofitter_init
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,_afm_parser_parse,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,_cff_parse_font_matrix,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,_cid_driver_init,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,_ps_unicode_value,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,_t42_get_ps_font_name,b5,b5,b5,b5,b5,b5
  ,b5,_sfnt_get_ps_name,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,_pfr_slot_init
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,_tt_driver_init,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
  ,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5];
  var FUNCTION_TABLE_iiiiiiiiii = [b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,_t1_decoder_init,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
  ,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6];
  var FUNCTION_TABLE_viii = [b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,_Write_CVT
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,_destroy_size,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,_t1_hints_stem,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,_ft_black_set_mode,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,_Write_CVT_Stretched,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,_Horizontal_Sweep_Init
  ,b7,b7,b7,_Move_CVT,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,_Move_CVT_Stretched
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,_ft_raster1_get_cbox,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,_t1_decrypt,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,_gray_raster_reset,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,_ft_smooth_get_cbox,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,_Vertical_Sweep_Init,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,_ft_black_reset,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,_destroy_face,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,_ps_hints_t1stem3,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,_ps_hints_t2counter,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7];
  var FUNCTION_TABLE_v = [b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
  ,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8];
  var FUNCTION_TABLE_iiiii = [b9,b9,b9,b9,b9,b9,b9,b9,_ft_realloc,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,_BDF_Glyph_Load
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,_ft_ansi_stream_io,b9,_cff_get_glyph_name,b9,b9,b9,b9,b9,b9
  ,b9,_ft_smooth_render,b9,_afm_parser_init,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,_cff_get_ros,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,_ft_smooth_transform,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,_ft_raster1_transform,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,_ft_raster1_render,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,_cid_get_ros,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,_ps_parser_to_fixed_array
  ,b9,_tt_get_kerning,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,_tt_face_load_sfnt_header_stub,b9,b9,b9,_Load_Glyph
  ,b9,b9,b9,_ps_hints_apply,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,_TT_Access_Glyph_Frame,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,_cid_slot_load_glyph,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,_gray_cubic_to,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,_ft_smooth_render_lcd_v,b9,b9,b9,_ps_table_add,b9,b9
  ,b9,b9,b9,_Get_Kerning,b9,_tt_face_goto_table,b9,b9,b9,_T42_GlyphSlot_Load
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,_FNT_Load_Glyph,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,_T1_Load_Glyph,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,_FT_CMap_New,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,_ft_gzip_stream_io,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,_PCF_Glyph_Load,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,_cff_get_kerning,b9,_tt_face_set_sbit_strike_stub,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,_t1_get_glyph_name212,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,_sfnt_get_glyph_name,b9,b9,b9,_pfr_get_kerning
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,_ft_lzw_stream_io,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,_tt_cmap14_char_var_index,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,_t42_get_glyph_name,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,_pfr_face_get_kerning,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,_T1_Get_Track_Kerning
  ,b9,b9,b9,b9,b9,b9,b9,_pfr_slot_load,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,_Load_Glyph433,b9,b9,b9,b9,b9,b9,b9,_ft_smooth_render_lcd
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
  ,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9];
  var FUNCTION_TABLE_iiiiiiii = [b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,_tt_face_load_sbit_image,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10];
  var FUNCTION_TABLE_viiiiii = [b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,_Horizontal_Sweep_Span,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,_Vertical_Sweep_Drop,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,_Horizontal_Sweep_Drop,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,_Vertical_Sweep_Span,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11];
  var FUNCTION_TABLE_iii = [b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,_T1_Get_Multi_Master
  ,b12,b12,b12,b12,b12,b12,b12,_gray_raster_new,b12,b12
  ,b12,b12,b12,b12,b12,_ps_parser_to_fixed,b12,_T1_Get_MM_Var,b12,b12
  ,b12,b12,b12,_tt_face_load_bhed,b12,b12,b12,b12,b12,b12
  ,b12,_t1_ps_get_font_extra,b12,b12,b12,b12,b12,_sfnt_get_interface,b12,_BDF_Size_Select
  ,b12,b12,b12,b12,b12,b12,b12,_t1_cmap_custom_char_next,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,_tt_cmap2_char_next,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,_tt_face_load_pclt,b12,b12
  ,b12,b12,b12,b12,b12,_ps_unicodes_char_next,b12,b12,b12,_ft_black_new
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,_tt_cmap4_char_index,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,_tt_cmap13_init,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,_cff_ps_get_font_info,b12,_tt_cmap12_char_index,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,_bdf_cmap_init,b12,_tt_cmap8_char_index
  ,b12,b12,b12,b12,b12,b12,b12,_tt_name_entry_ascii_from_other,b12,_cff_cmap_encoding_char_index
  ,b12,b12,b12,_t42_ps_get_font_info,b12,_tt_cmap12_get_info,b12,b12,b12,b12
  ,b12,b12,b12,_tt_cmap6_get_info,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,_gray_raster_render
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,_tt_cmap2_validate,b12,b12,b12,_af_dummy_hints_init,b12,b12
  ,b12,b12,b12,b12,b12,_tt_cmap4_validate,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,_tt_face_load_font_dir,b12,_ft_black_render,b12,b12
  ,b12,b12,b12,b12,b12,_cff_size_select,b12,b12,b12,b12
  ,b12,_t1_cmap_unicode_char_next,b12,b12,b12,b12,b12,_PCF_Size_Request,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,_tt_size_select,b12,b12,b12,b12,b12,_cid_ps_get_font_info
  ,b12,b12,b12,b12,b12,b12,b12,_cid_get_is_cid,b12,_t1_cmap_custom_char_index
  ,b12,b12,b12,b12,b12,_tt_face_load_hdmx_stub,b12,b12,b12,_tt_cmap10_validate
  ,b12,_tt_cmap10_char_index,b12,b12,b12,_tt_cmap14_validate,b12,_cid_load_glyph,b12,b12
  ,b12,b12,b12,_bdf_cmap_char_next,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,_T1_Read_Metrics,b12,b12,b12,b12
  ,b12,b12,b12,_ft_alloc,b12,_t42_ps_get_font_extra,b12,_tt_cmap2_get_info,b12,b12
  ,b12,b12,b12,_ps_hints_close,b12,b12,b12,b12,b12,b12
  ,b12,_t1_cmap_std_char_index,b12,b12,b12,_tt_cmap0_get_info,b12,_fnt_cmap_char_next,b12,_t1_cmap_std_char_next
  ,b12,_winfnt_get_header,b12,_cff_cmap_encoding_char_next,b12,_sfnt_get_name_index,b12,_parse_fd_array,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,_tt_cmap12_validate,b12,_parse_font_matrix283
  ,b12,b12,b12,_tt_face_load_name,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,_bdf_cmap_char_index,b12,_tt_cmap13_get_info,b12,b12,b12,_t1_cmap_unicode_char_index,b12,_tt_cmap13_char_index
  ,b12,_tt_cmap4_init,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,_tt_face_load_head,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,_cid_get_interface
  ,b12,b12,b12,b12,b12,_tt_cmap8_validate,b12,_pcf_cmap_init,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,_ft_raccess_sort_ref_by_id,b12,_tt_face_load_cmap
  ,b12,b12,b12,_tt_cmap0_validate,b12,_tt_cmap13_char_next,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,_tt_cmap14_variants,b12,_pcf_cmap_char_next
  ,b12,b12,b12,b12,b12,_tt_cmap4_get_info,b12,_cff_get_name_index,b12,b12
  ,b12,b12,b12,b12,b12,_af_dummy_hints_apply,b12,b12,b12,_T1_Parse_Glyph
  ,b12,_tt_cmap0_char_index,b12,b12,b12,_tt_cmap6_char_next,b12,_tt_cmap4_char_next,b12,b12
  ,b12,b12,b12,_cid_size_request,b12,_T1_Size_Request,b12,b12,b12,b12
  ,b12,_t1_builder_check_points,b12,b12,b12,b12,b12,_t1_get_glyph_name,b12,b12
  ,b12,b12,b12,b12,b12,_t1_ps_get_font_info,b12,b12,b12,_afm_compare_kern_pairs
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,_tt_face_load_eblc
  ,b12,b12,b12,b12,b12,_cff_size_request,b12,_t1_get_name_index,b12,_af_indic_metrics_init
  ,b12,_af_cjk_hints_init,b12,b12,b12,_tt_cmap14_init,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,_af_latin_metrics_init,b12,_tt_face_load_gasp
  ,b12,_psnames_get_service,b12,b12,b12,b12,b12,_cff_get_is_cid,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,_cid_ps_get_font_extra,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,_tt_cmap8_char_next,b12,b12,b12,_PCF_Size_Select,b12,b12
  ,b12,_tt_face_free_charmap_stub,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,_compare_kern_pairs,b12,b12,b12,_cff_cmap_unicode_char_index,b12,_T42_Size_Select
  ,b12,_tt_size_request,b12,b12,b12,b12,b12,_Read_CVT,b12,_gray_move_to
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,_cff_cmap_unicode_char_next,b12,_tt_face_load_sbit_stub,b12,_tt_cmap_init,b12,_t42_ps_get_font_private,b12,_tt_get_cmap_info
  ,b12,_tt_face_load_os2,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,_pcf_cmap_char_index,b12,b12,b12,_Get_Interface,b12,b12
  ,b12,_tt_cmap2_char_index,b12,_tt_cmap13_validate,b12,b12,b12,_compare_uni_maps,b12,_pfr_cmap_char_next
  ,b12,b12,b12,_t1_ps_get_font_private,b12,b12,b12,_tt_cmap12_init,b12,b12
  ,b12,_af_latin_hints_init,b12,_ps_unicodes_char_index,b12,b12,b12,_parse_expansion_factor,b12,b12
  ,b12,b12,b12,b12,b12,_get_sfnt_table,b12,_tt_face_load_kern,b12,_cff_sid_to_glyph_name
  ,b12,b12,b12,_tt_cmap14_char_next,b12,_tt_face_load_post,b12,_tt_get_interface,b12,_bdf_driver_requester
  ,b12,b12,b12,b12,b12,b12,b12,_BDF_Size_Request,b12,_cff_get_interface
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,_T42_Get_Interface
  ,b12,b12,b12,b12,b12,_tt_cmap8_get_info,b12,b12,b12,_tt_face_load_maxp
  ,b12,_af_indic_hints_init,b12,b12,b12,_gray_line_to,b12,b12,b12,_pfr_cmap_char_index
  ,b12,_TT_Get_MM_Var,b12,b12,b12,b12,b12,_pcf_driver_requester,b12,_T42_Size_Request
  ,b12,b12,b12,b12,b12,b12,b12,_by_encoding,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,_cff_get_cmap_info,b12,_pfr_get_service,b12,_Read_CVT_Stretched
  ,b12,b12,b12,_winfnt_get_service,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,_tt_cmap12_char_next,b12,b12,b12,b12,b12,_tt_name_entry_ascii_from_utf16
  ,b12,b12,b12,b12,b12,_tt_cmap6_validate,b12,_af_cjk_metrics_init,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,_tt_cmap10_get_info,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,_FNT_Size_Request
  ,b12,b12,b12,_tt_cmap14_char_index,b12,b12,b12,b12,b12,_tt_cmap14_get_info
  ,b12,_t42_get_name_index,b12,b12,b12,_tt_cmap6_char_index,b12,b12,b12,b12
  ,b12,b12,b12,_tt_cmap10_char_next,b12,b12,b12,_tt_cmap0_char_next,b12,b12
  ,b12,b12,b12,_fnt_cmap_char_index,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
  ,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12];
  var FUNCTION_TABLE_iiiiii = [b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,_raccess_guess_darwin_ufs_export,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,_tt_face_load_any,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,_T42_Face_Init,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,_raccess_guess_darwin_newvfs,b13,b13,b13,b13,b13,b13
  ,b13,__bdf_parse_properties,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,__bdf_parse_glyphs,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,_psh_globals_set_scale,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,_T1_Get_Advances,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,_raccess_guess_vfat,b13,_ft_stub_set_char_sizes,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,_ps_parser_load_field,b13,b13,b13,b13,b13,b13
  ,b13,__bdf_parse_start,b13,b13,b13,b13,b13,b13,b13,_raccess_guess_darwin_hfsplus
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,_tt_face_get_metrics,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,_cff_get_advances
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,_af_autofitter_load_glyph,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,_sfnt_load_face
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,_ps_parser_load_field_table,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,_cff_face_init,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,_FNT_Face_Init,b13,b13,b13,_tt_get_advances,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,_raccess_guess_linux_cap,b13,b13,b13,_pfr_get_metrics
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,_T1_Face_Init
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,_pfr_face_init,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,_raccess_guess_apple_double,b13,_sfnt_table_info,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,_tt_face_init,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,_PCF_Face_Init
  ,b13,b13,b13,_raccess_guess_linux_netatalk,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,_raccess_guess_apple_single,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,_ps_parser_to_bytes,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,_raccess_guess_linux_double
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,_cid_face_init,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,_sfnt_init_face,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,_BDF_Face_Init,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13];
  var FUNCTION_TABLE_viiii = [b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,_ft_validator_init
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,_ps_hints_t2mask,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,_ps_parser_to_token_array
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,_Direct_Move_Orig
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,_gray_render_span,b14,_t1_builder_add_point,b14,b14,b14,b14
  ,b14,_Direct_Move,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,_Direct_Move_Orig_X,b14,_Direct_Move_Orig_Y,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,_ps_parser_init,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,_Direct_Move_Y,b14,_Direct_Move_X,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,_t2_hints_stems
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
  ,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14];
  return { _testSetjmp: _testSetjmp, _saveSetjmp: _saveSetjmp, _strcat: _strcat, _free: _free, _main: _main, _memcmp: _memcmp, _strncpy: _strncpy, _memmove: _memmove, _realloc: _realloc, _strlen: _strlen, _memset: _memset, _malloc: _malloc, _memcpy: _memcpy, stackAlloc: stackAlloc, stackSave: stackSave, stackRestore: stackRestore, setThrew: setThrew, setTempRet0: setTempRet0, setTempRet1: setTempRet1, setTempRet2: setTempRet2, setTempRet3: setTempRet3, setTempRet4: setTempRet4, setTempRet5: setTempRet5, setTempRet6: setTempRet6, setTempRet7: setTempRet7, setTempRet8: setTempRet8, setTempRet9: setTempRet9, dynCall_iiii: dynCall_iiii, dynCall_viiiii: dynCall_viiiii, dynCall_vi: dynCall_vi, dynCall_vii: dynCall_vii, dynCall_iiiiiii: dynCall_iiiiiii, dynCall_ii: dynCall_ii, dynCall_iiiiiiiiii: dynCall_iiiiiiiiii, dynCall_viii: dynCall_viii, dynCall_v: dynCall_v, dynCall_iiiii: dynCall_iiiii, dynCall_iiiiiiii: dynCall_iiiiiiii, dynCall_viiiiii: dynCall_viiiiii, dynCall_iii: dynCall_iii, dynCall_iiiiii: dynCall_iiiiii, dynCall_viiii: dynCall_viiii };
})
// EMSCRIPTEN_END_ASM
({ Math: Math, Int8Array: Int8Array, Int16Array: Int16Array, Int32Array: Int32Array, Uint8Array: Uint8Array, Uint16Array: Uint16Array, Uint32Array: Uint32Array, Float32Array: Float32Array, Float64Array: Float64Array }, { abort: abort, assert: assert, asmPrintInt: asmPrintInt, asmPrintFloat: asmPrintFloat, copyTempDouble: copyTempDouble, copyTempFloat: copyTempFloat, min: Math_min, invoke_iiii: invoke_iiii, invoke_viiiii: invoke_viiiii, invoke_vi: invoke_vi, invoke_vii: invoke_vii, invoke_iiiiiii: invoke_iiiiiii, invoke_ii: invoke_ii, invoke_iiiiiiiiii: invoke_iiiiiiiiii, invoke_viii: invoke_viii, invoke_v: invoke_v, invoke_iiiii: invoke_iiiii, invoke_iiiiiiii: invoke_iiiiiiii, invoke_viiiiii: invoke_viiiiii, invoke_iii: invoke_iii, invoke_iiiiii: invoke_iiiiii, invoke_viiii: invoke_viiii, _strncmp: _strncmp, _lseek: _lseek, _pread: _pread, _snprintf: _snprintf, _fclose: _fclose, _abort: _abort, _fprintf: _fprintf, _printf: _printf, _close: _close, _fopen: _fopen, __reallyNegative: __reallyNegative, _strtol: _strtol, _fputc: _fputc, _sysconf: _sysconf, _open: _open, ___setErrNo: ___setErrNo, _fwrite: _fwrite, _fseek: _fseek, _qsort: _qsort, _write: _write, _ftell: _ftell, _exit: _exit, _sprintf: _sprintf, _strrchr: _strrchr, _sin: _sin, _fread: _fread, _longjmp: _longjmp, _read: _read, _llvm_uadd_with_overflow_i32: _llvm_uadd_with_overflow_i32, __formatString: __formatString, _atoi: _atoi, _cos: _cos, _pwrite: _pwrite, _strstr: _strstr, _sbrk: _sbrk, _fsync: _fsync, ___errno_location: ___errno_location, _isspace: _isspace, __parseInt: __parseInt, _time: _time, __exit: __exit, _strcmp: _strcmp, _memchr: _memchr, STACKTOP: STACKTOP, STACK_MAX: STACK_MAX, tempDoublePtr: tempDoublePtr, ABORT: ABORT, NaN: NaN, Infinity: Infinity, _stderr: _stderr, _stdout: _stdout }, buffer);
var _testSetjmp = Module["_testSetjmp"] = asm._testSetjmp;
var _saveSetjmp = Module["_saveSetjmp"] = asm._saveSetjmp;
var _strcat = Module["_strcat"] = asm._strcat;
var _free = Module["_free"] = asm._free;
var _main = Module["_main"] = asm._main;
var _memcmp = Module["_memcmp"] = asm._memcmp;
var _strncpy = Module["_strncpy"] = asm._strncpy;
var _memmove = Module["_memmove"] = asm._memmove;
var _realloc = Module["_realloc"] = asm._realloc;
var _strlen = Module["_strlen"] = asm._strlen;
var _memset = Module["_memset"] = asm._memset;
var _malloc = Module["_malloc"] = asm._malloc;
var _memcpy = Module["_memcpy"] = asm._memcpy;
var dynCall_iiii = Module["dynCall_iiii"] = asm.dynCall_iiii;
var dynCall_viiiii = Module["dynCall_viiiii"] = asm.dynCall_viiiii;
var dynCall_vi = Module["dynCall_vi"] = asm.dynCall_vi;
var dynCall_vii = Module["dynCall_vii"] = asm.dynCall_vii;
var dynCall_iiiiiii = Module["dynCall_iiiiiii"] = asm.dynCall_iiiiiii;
var dynCall_ii = Module["dynCall_ii"] = asm.dynCall_ii;
var dynCall_iiiiiiiiii = Module["dynCall_iiiiiiiiii"] = asm.dynCall_iiiiiiiiii;
var dynCall_viii = Module["dynCall_viii"] = asm.dynCall_viii;
var dynCall_v = Module["dynCall_v"] = asm.dynCall_v;
var dynCall_iiiii = Module["dynCall_iiiii"] = asm.dynCall_iiiii;
var dynCall_iiiiiiii = Module["dynCall_iiiiiiii"] = asm.dynCall_iiiiiiii;
var dynCall_viiiiii = Module["dynCall_viiiiii"] = asm.dynCall_viiiiii;
var dynCall_iii = Module["dynCall_iii"] = asm.dynCall_iii;
var dynCall_iiiiii = Module["dynCall_iiiiii"] = asm.dynCall_iiiiii;
var dynCall_viiii = Module["dynCall_viiii"] = asm.dynCall_viiii;
Runtime.stackAlloc = function(size) { return asm.stackAlloc(size) };
Runtime.stackSave = function() { return asm.stackSave() };
Runtime.stackRestore = function(top) { asm.stackRestore(top) };
// Warning: printing of i64 values may be slightly rounded! No deep i64 math used, so precise i64 code not included
var i64Math = null;
// === Auto-generated postamble setup entry stuff ===
Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(!Module['preRun'] || Module['preRun'].length == 0, 'cannot call main when preRun functions remain to be called');
  args = args || [];
  ensureInitRuntime();
  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString("/bin/this.program"), 'i8', ALLOC_STATIC) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_STATIC));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_STATIC);
  var ret;
  var initialStackTop = STACKTOP;
  try {
    ret = Module['_main'](argc, argv, 0);
  }
  catch(e) {
    if (e.name == 'ExitStatus') {
      return e.status;
    } else if (e == 'SimulateInfiniteLoop') {
      Module['noExitRuntime'] = true;
    } else {
      throw e;
    }
  } finally {
    STACKTOP = initialStackTop;
  }
  return ret;
}
function run(args) {
  args = args || Module['arguments'];
  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return 0;
  }
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    var toRun = Module['preRun'];
    Module['preRun'] = [];
    for (var i = toRun.length-1; i >= 0; i--) {
      toRun[i]();
    }
    if (runDependencies > 0) {
      // a preRun added a dependency, run will be called later
      return 0;
    }
  }
  function doRun() {
    ensureInitRuntime();
    preMain();
    var ret = 0;
    calledRun = true;
    if (Module['_main'] && shouldRunNow) {
      ret = Module.callMain(args);
      if (!Module['noExitRuntime']) {
        exitRuntime();
      }
    }
    if (Module['postRun']) {
      if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
      while (Module['postRun'].length > 0) {
        Module['postRun'].pop()();
      }
    }
    return ret;
  }
  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      doRun();
    }, 1);
    return 0;
  } else {
    return doRun();
  }
}
Module['run'] = Module.run = run;
FS.createDataFile('/', 'font.ttf', [0, 1, 0, 0, 0, 19, 1, 0, 0, 4, 0, 48, 70, 70, 84, 77, 77, 252, 131, 182, 0, 2, 21, 60, 0, 0, 0, 28, 71, 68, 69, 70, 2, 207, 0, 4, 0, 2, 4, 132, 0, 0, 0, 32, 71, 80, 79, 83, 50, 107, 108, 237, 0, 2, 4, 244, 0, 0, 16, 72, 71, 83, 85, 66, 147, 60, 130, 75, 0, 2, 4, 164, 0, 0, 0, 80, 79, 83, 47, 50, 248, 70, 135, 149, 0, 0, 1, 184, 0, 0, 0, 96, 99, 109, 97, 112, 9, 102, 162, 14, 0, 0, 12, 148, 0, 0, 7, 2, 99, 118, 116, 32, 95, 226, 95, 128, 0, 0, 30, 140, 0, 0, 2, 74, 102, 112, 103, 109, 115, 211, 35, 176, 0, 0, 19, 152, 0, 0, 7, 5, 103, 97, 115, 112, 0, 17, 0, 9, 0, 2, 4, 116, 0, 0, 0, 16, 103, 108, 121, 102, 84, 38, 251, 98, 0, 0, 38, 32, 0, 1, 171, 220, 104, 101, 97, 100, 247, 19, 195, 240, 0, 0, 1, 60, 0, 0, 0, 54, 104, 104, 101, 97, 14, 138, 8, 92, 0, 0, 1, 116, 0, 0, 0, 36, 104, 109, 116, 120, 163, 114, 242, 117, 0, 0, 2, 24, 0, 0, 10, 122, 107, 101, 114, 110, 198, 26, 210, 123, 0, 1, 209, 252, 0, 0, 21, 90, 108, 111, 99, 97, 188, 142, 93, 148, 0, 0, 32, 216, 0, 0, 5, 70, 109, 97, 120, 112, 7, 227, 8, 167, 0, 0, 1, 152, 0, 0, 0, 32, 110, 97, 109, 101, 210, 9, 166, 107, 0, 1, 231, 88, 0, 0, 8, 121, 112, 111, 115, 116, 0, 162, 37, 184, 0, 1, 239, 212, 0, 0, 20, 158, 112, 114, 101, 112, 59, 235, 12, 109, 0, 0, 26, 160, 0, 0, 3, 233, 0, 1, 0, 0, 0, 1, 15, 92, 119, 169, 227, 201, 95, 15, 60, 245, 0, 31, 8, 0, 0, 0, 0, 0, 200, 108, 180, 224, 0, 0, 0, 0, 200, 108, 180, 224, 254, 135, 253, 147, 8, 127, 8, 68, 0, 1, 0, 8, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 7, 62, 254, 78, 0, 67, 8, 235, 254, 135, 254, 135, 8, 127, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 155, 0, 1, 0, 0, 2, 162, 1, 82, 0, 84, 0, 130, 0, 5, 0, 2, 0, 16, 0, 47, 0, 90, 0, 0, 4, 122, 6, 161, 0, 3, 0, 1, 0, 3, 4, 230, 2, 188, 0, 5, 0, 8, 5, 154, 5, 51, 0, 0, 1, 27, 5, 154, 5, 51, 0, 0, 3, 209, 0, 102, 2, 18, 8, 5, 2, 11, 7, 4, 2, 2, 2, 2, 2, 4, 160, 0, 2, 175, 80, 0, 120, 251, 0, 0, 0, 0, 0, 0, 0, 0, 49, 65, 83, 67, 0, 32, 0, 33, 251, 2, 5, 211, 254, 81, 1, 51, 7, 62, 1, 178, 96, 0, 0, 159, 223, 215, 0, 0, 4, 58, 5, 129, 0, 0, 0, 32, 0, 2, 2, 236, 0, 68, 0, 0, 0, 0, 2, 170, 0, 0, 2, 57, 0, 0, 2, 170, 0, 193, 3, 203, 0, 135, 4, 115, 0, 35, 4, 115, 0, 27, 7, 29, 0, 51, 5, 199, 0, 90, 1, 231, 0, 109, 2, 170, 0, 102, 2, 170, 0, 2, 3, 29, 0, 6, 4, 172, 0, 86, 2, 57, 0, 139, 2, 170, 0, 80, 2, 57, 0, 139, 2, 57, 0, 20, 4, 115, 0, 81, 4, 115, 0, 129, 4, 115, 0, 71, 4, 115, 0, 47, 4, 115, 0, 31, 4, 115, 0, 63, 4, 115, 0, 75, 4, 115, 0, 88, 4, 115, 0, 65, 4, 115, 0, 71, 2, 170, 0, 197, 2, 170, 0, 195, 4, 172, 0, 86, 4, 172, 0, 85, 4, 172, 0, 86, 4, 227, 0, 94, 7, 205, 0, 117, 5, 199, 0, 51, 5, 199, 0, 137, 5, 199, 0, 84, 5, 199, 0, 137, 5, 86, 0, 137, 4, 227, 0, 137, 6, 57, 0, 84, 5, 199, 0, 137, 2, 57, 0, 137, 4, 115, 0, 31, 5, 199, 0, 137, 4, 227, 0, 137, 6, 170, 0, 137, 5, 199, 0, 137, 6, 57, 0, 84, 5, 86, 0, 137, 6, 57, 0, 84, 5, 199, 0, 137, 5, 86, 0, 59, 4, 227, 0, 23, 5, 199, 0, 123, 5, 86, 0, 14, 7, 141, 0, 2, 5, 86, 0, 18, 5, 86, 0, 35, 4, 227, 0, 61, 2, 170, 0, 115, 2, 57, 0, 21, 2, 170, 0, 25, 4, 172, 0, 45, 4, 115, 255, 236, 2, 170, 0, 66, 4, 115, 0, 60, 4, 227, 0, 135, 4, 115, 0, 80, 4, 227, 0, 84, 4, 115, 0, 80, 2, 170, 0, 35, 4, 227, 0, 84, 4, 227, 0, 143, 2, 57, 0, 143, 2, 57, 255, 224, 4, 115, 0, 143, 2, 57, 0, 143, 7, 29, 0, 135, 4, 227, 0, 135, 4, 227, 0, 80, 4, 227, 0, 135, 4, 227, 0, 84, 3, 29, 0, 135, 4, 115, 0, 72, 2, 170, 0, 25, 4, 227, 0, 127, 4, 115, 0, 8, 6, 57, 255, 250, 4, 115, 0, 14, 4, 115, 0, 16, 4, 0, 0, 68, 3, 29, 0, 33, 2, 61, 0, 156, 3, 29, 0, 43, 4, 172, 0, 81, 2, 170, 0, 194, 4, 115, 0, 51, 4, 115, 0, 21, 4, 115, 0, 57, 4, 115, 0, 8, 2, 61, 0, 156, 4, 115, 0, 53, 2, 170, 0, 16, 5, 229, 0, 32, 2, 246, 0, 45, 4, 115, 0, 92, 4, 172, 0, 84, 5, 229, 0, 32, 4, 107, 255, 239, 3, 51, 0, 90, 4, 100, 0, 49, 2, 170, 0, 51, 2, 170, 0, 44, 2, 170, 0, 87, 4, 156, 0, 134, 4, 115, 0, 71, 2, 57, 0, 141, 2, 170, 0, 96, 2, 170, 0, 82, 2, 236, 0, 45, 4, 115, 0, 93, 6, 172, 0, 94, 6, 172, 0, 94, 6, 172, 0, 103, 4, 227, 0, 114, 5, 199, 0, 51, 5, 199, 0, 51, 5, 199, 0, 51, 5, 199, 0, 51, 5, 199, 0, 51, 5, 199, 0, 51, 8, 0, 0, 4, 5, 199, 0, 84, 5, 86, 0, 137, 5, 86, 0, 137, 5, 86, 0, 137, 5, 86, 0, 137, 2, 57, 255, 216, 2, 57, 0, 104, 2, 57, 255, 171, 2, 57, 255, 215, 5, 199, 0, 8, 5, 199, 0, 137, 6, 57, 0, 84, 6, 57, 0, 84, 6, 57, 0, 84, 6, 57, 0, 84, 6, 57, 0, 84, 4, 172, 0, 86, 6, 57, 0, 84, 5, 199, 0, 123, 5, 199, 0, 123, 5, 199, 0, 123, 5, 199, 0, 123, 5, 86, 0, 35, 5, 86, 0, 137, 4, 227, 0, 143, 4, 115, 0, 52, 4, 115, 0, 52, 4, 115, 0, 52, 4, 115, 0, 52, 4, 115, 0, 52, 4, 115, 0, 52, 7, 29, 0, 66, 4, 115, 0, 80, 4, 115, 0, 80, 4, 115, 0, 80, 4, 115, 0, 80, 4, 115, 0, 80, 2, 57, 255, 192, 2, 57, 0, 114, 2, 57, 255, 173, 2, 57, 255, 216, 4, 227, 0, 80, 4, 227, 0, 135, 4, 227, 0, 80, 4, 227, 0, 80, 4, 227, 0, 80, 4, 227, 0, 80, 4, 227, 0, 80, 4, 100, 0, 49, 4, 227, 0, 1, 4, 227, 0, 127, 4, 227, 0, 127, 4, 227, 0, 127, 4, 227, 0, 127, 4, 115, 0, 16, 4, 227, 0, 143, 4, 115, 0, 16, 5, 199, 0, 51, 4, 115, 0, 60, 5, 199, 0, 51, 4, 115, 0, 60, 5, 199, 0, 51, 4, 115, 0, 60, 5, 199, 0, 84, 4, 115, 0, 80, 5, 199, 0, 84, 4, 115, 0, 80, 5, 199, 0, 84, 4, 115, 0, 80, 5, 199, 0, 84, 4, 115, 0, 80, 5, 199, 0, 137, 5, 192, 0, 84, 5, 199, 0, 8, 4, 227, 0, 84, 5, 86, 0, 137, 4, 115, 0, 80, 5, 86, 0, 137, 4, 115, 0, 80, 5, 86, 0, 137, 4, 115, 0, 80, 5, 86, 0, 137, 4, 115, 0, 80, 5, 86, 0, 137, 4, 115, 0, 80, 6, 57, 0, 84, 4, 227, 0, 84, 6, 57, 0, 84, 4, 227, 0, 84, 6, 57, 0, 84, 4, 227, 0, 84, 6, 57, 0, 84, 4, 227, 0, 84, 5, 199, 0, 137, 4, 227, 0, 143, 5, 199, 0, 14, 4, 227, 0, 10, 2, 57, 255, 153, 2, 57, 255, 153, 2, 57, 255, 236, 2, 57, 255, 236, 2, 57, 255, 188, 2, 57, 255, 189, 2, 57, 0, 88, 2, 57, 0, 69, 2, 57, 0, 137, 2, 57, 0, 145, 6, 71, 0, 137, 4, 115, 0, 143, 4, 115, 0, 31, 2, 57, 255, 166, 5, 199, 0, 137, 4, 115, 0, 143, 4, 115, 0, 143, 4, 227, 0, 137, 2, 57, 0, 106, 4, 227, 0, 137, 2, 57, 0, 143, 4, 227, 0, 137, 3, 21, 0, 143, 4, 227, 0, 137, 3, 213, 0, 143, 4, 227, 0, 0, 2, 57, 0, 18, 5, 199, 0, 137, 4, 227, 0, 135, 5, 199, 0, 137, 4, 227, 0, 135, 5, 199, 0, 137, 4, 227, 0, 135, 5, 171, 255, 234, 5, 201, 0, 133, 4, 227, 0, 135, 6, 57, 0, 84, 4, 227, 0, 80, 6, 57, 0, 84, 4, 227, 0, 80, 6, 57, 0, 84, 4, 227, 0, 80, 8, 0, 0, 84, 7, 141, 0, 80, 5, 199, 0, 137, 3, 29, 0, 135, 5, 199, 0, 137, 3, 29, 0, 135, 5, 199, 0, 137, 3, 29, 0, 56, 5, 86, 0, 59, 4, 115, 0, 72, 5, 86, 0, 59, 4, 115, 0, 72, 5, 86, 0, 59, 4, 115, 0, 72, 5, 86, 0, 59, 4, 115, 0, 72, 4, 227, 0, 23, 2, 170, 0, 25, 4, 227, 0, 23, 3, 213, 0, 25, 4, 227, 0, 23, 2, 170, 0, 25, 5, 199, 0, 123, 4, 227, 0, 127, 5, 199, 0, 123, 4, 227, 0, 127, 5, 199, 0, 123, 4, 227, 0, 127, 5, 199, 0, 123, 4, 227, 0, 127, 5, 199, 0, 123, 4, 227, 0, 127, 5, 199, 0, 123, 4, 227, 0, 127, 7, 141, 0, 2, 6, 57, 255, 250, 5, 86, 0, 35, 4, 115, 0, 16, 5, 86, 0, 35, 4, 227, 0, 61, 4, 0, 0, 68, 4, 227, 0, 61, 4, 0, 0, 68, 4, 227, 0, 61, 4, 0, 0, 68, 2, 57, 0, 142, 4, 115, 0, 168, 5, 199, 0, 51, 4, 115, 0, 60, 8, 0, 0, 4, 7, 29, 0, 66, 6, 57, 0, 84, 4, 227, 0, 1, 5, 86, 0, 59, 4, 115, 0, 72, 4, 227, 0, 23, 2, 170, 0, 25, 2, 170, 0, 0, 2, 170, 0, 0, 2, 170, 0, 36, 2, 170, 255, 199, 2, 170, 0, 200, 2, 170, 0, 39, 2, 170, 0, 76, 2, 170, 255, 242, 2, 170, 255, 164, 2, 170, 0, 185, 3, 184, 0, 110, 5, 199, 0, 36, 2, 170, 0, 197, 6, 211, 0, 46, 7, 63, 0, 36, 3, 202, 0, 36, 6, 153, 255, 230, 7, 107, 0, 128, 6, 180, 255, 208, 2, 57, 255, 169, 5, 199, 0, 51, 5, 199, 0, 137, 4, 207, 0, 137, 5, 192, 0, 83, 5, 86, 0, 137, 4, 227, 0, 61, 5, 199, 0, 137, 6, 57, 0, 84, 2, 57, 0, 137, 5, 199, 0, 137, 5, 86, 0, 14, 6, 170, 0, 137, 5, 199, 0, 137, 5, 38, 0, 84, 6, 57, 0, 84, 5, 199, 0, 137, 5, 86, 0, 137, 4, 205, 0, 90, 4, 227, 0, 23, 5, 86, 0, 35, 6, 145, 0, 63, 5, 86, 0, 18, 6, 121, 0, 96, 6, 106, 0, 83, 2, 57, 255, 215, 5, 86, 0, 35, 4, 235, 0, 80, 3, 156, 0, 77, 4, 227, 0, 107, 2, 57, 0, 137, 4, 168, 0, 127, 4, 235, 0, 80, 4, 226, 0, 142, 4, 115, 0, 8, 4, 218, 0, 86, 3, 204, 0, 77, 3, 175, 0, 66, 4, 227, 0, 107, 4, 83, 0, 90, 2, 57, 0, 137, 4, 118, 0, 143, 4, 115, 0, 9, 4, 229, 0, 144, 4, 115, 0, 0, 3, 144, 0, 66, 4, 227, 0, 80, 6, 32, 0, 42, 4, 243, 0, 121, 4, 41, 0, 79, 5, 121, 0, 80, 3, 146, 0, 18, 4, 168, 0, 127, 5, 185, 0, 80, 4, 155, 0, 13, 6, 7, 0, 129, 6, 194, 0, 81, 2, 57, 255, 217, 4, 168, 0, 127, 4, 227, 0, 80, 4, 168, 0, 127, 6, 194, 0, 81, 5, 90, 0, 137, 7, 21, 0, 23, 4, 137, 0, 137, 5, 177, 0, 84, 5, 86, 0, 59, 2, 57, 0, 137, 2, 53, 255, 213, 4, 115, 0, 31, 8, 192, 0, 8, 8, 128, 0, 137, 7, 0, 0, 23, 4, 226, 0, 137, 4, 250, 255, 249, 5, 192, 0, 137, 5, 199, 0, 51, 5, 192, 0, 137, 5, 199, 0, 137, 4, 137, 0, 137, 5, 179, 0, 18, 5, 86, 0, 137, 7, 59, 255, 250, 5, 3, 0, 46, 5, 192, 0, 136, 5, 192, 0, 136, 4, 226, 0, 137, 5, 157, 0, 8, 6, 170, 0, 137, 5, 199, 0, 137, 6, 57, 0, 84, 5, 192, 0, 137, 5, 86, 0, 137, 5, 199, 0, 84, 4, 227, 0, 23, 4, 250, 0, 1, 6, 212, 0, 71, 5, 86, 0, 18, 5, 216, 0, 137, 5, 159, 0, 110, 8, 10, 0, 137, 8, 39, 0, 137, 6, 245, 0, 22, 7, 213, 0, 137, 5, 192, 0, 137, 5, 177, 0, 54, 8, 64, 0, 137, 5, 192, 0, 35, 4, 115, 0, 60, 4, 241, 0, 94, 4, 235, 0, 143, 3, 85, 0, 143, 5, 20, 0, 14, 4, 115, 0, 80, 5, 172, 255, 239, 3, 250, 0, 53, 4, 235, 0, 142, 4, 235, 0, 142, 4, 1, 0, 142, 5, 21, 0, 21, 5, 235, 0, 143, 4, 213, 0, 143, 4, 227, 0, 80, 4, 213, 0, 143, 4, 227, 0, 135, 4, 115, 0, 80, 3, 235, 0, 58, 4, 115, 0, 16, 7, 0, 0, 82, 4, 115, 0, 14, 4, 235, 0, 143, 4, 165, 0, 83, 6, 171, 0, 143, 6, 192, 0, 143, 5, 213, 0, 38, 6, 213, 0, 143, 4, 235, 0, 143, 4, 107, 0, 52, 6, 213, 0, 143, 4, 171, 255, 255, 4, 115, 0, 80, 4, 227, 0, 10, 3, 85, 0, 143, 4, 107, 0, 80, 4, 115, 0, 72, 2, 57, 0, 143, 2, 64, 255, 218, 2, 57, 255, 224, 7, 192, 0, 21, 7, 64, 0, 143, 4, 227, 0, 10, 4, 1, 0, 142, 4, 115, 0, 16, 4, 213, 0, 143, 3, 229, 0, 137, 3, 147, 0, 143, 7, 141, 0, 2, 6, 57, 255, 250, 7, 141, 0, 2, 6, 57, 255, 250, 7, 141, 0, 2, 6, 57, 255, 250, 5, 86, 0, 35, 4, 115, 0, 16, 2, 170, 0, 80, 2, 170, 0, 80, 4, 115, 0, 62, 8, 0, 0, 0, 8, 0, 0, 0, 4, 107, 255, 236, 2, 57, 0, 139, 2, 57, 0, 139, 2, 57, 0, 138, 2, 57, 0, 139, 4, 0, 0, 151, 4, 0, 0, 151, 4, 0, 0, 151, 4, 115, 0, 138, 4, 115, 0, 136, 2, 205, 0, 65, 8, 0, 0, 225, 8, 0, 0, 41, 1, 235, 0, 85, 3, 213, 0, 85, 2, 170, 0, 92, 2, 170, 0, 93, 4, 213, 0, 193, 2, 170, 255, 126, 1, 86, 254, 135, 3, 43, 0, 108, 4, 115, 0, 7, 4, 115, 0, 21, 8, 192, 0, 158, 4, 115, 0, 10, 7, 21, 0, 54, 3, 233, 0, 41, 8, 235, 0, 137, 8, 0, 0, 125, 6, 37, 0, 85, 4, 205, 0, 88, 6, 172, 0, 114, 6, 172, 0, 84, 6, 172, 0, 103, 6, 172, 0, 163, 8, 0, 1, 162, 4, 0, 1, 16, 8, 0, 1, 162, 4, 0, 1, 16, 8, 0, 1, 162, 4, 0, 1, 16, 4, 0, 1, 16, 3, 244, 0, 53, 4, 229, 0, 43, 6, 150, 0, 204, 5, 180, 0, 134, 4, 172, 0, 85, 4, 100, 0, 2, 5, 180, 0, 72, 7, 213, 1, 152, 5, 199, 1, 25, 2, 49, 255, 127, 4, 100, 0, 43, 4, 100, 0, 29, 4, 171, 0, 100, 4, 100, 0, 49, 4, 100, 0, 49, 4, 213, 0, 157, 4, 172, 0, 100, 4, 213, 2, 34, 4, 213, 1, 5, 5, 171, 255, 246, 5, 0, 1, 216, 5, 171, 2, 141, 5, 171, 255, 246, 5, 171, 2, 141, 5, 171, 255, 246, 5, 171, 2, 141, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 1, 217, 5, 171, 2, 141, 5, 171, 1, 217, 5, 171, 1, 217, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 2, 141, 5, 171, 1, 217, 5, 171, 1, 217, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 2, 141, 5, 171, 1, 217, 5, 171, 1, 217, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 255, 246, 5, 171, 0, 0, 5, 171, 0, 0, 5, 171, 0, 0, 5, 171, 0, 0, 5, 171, 2, 213, 5, 171, 0, 103, 5, 171, 0, 0, 5, 213, 0, 0, 4, 213, 0, 123, 4, 213, 0, 6, 2, 214, 0, 109, 2, 214, 0, 109, 8, 0, 0, 0, 7, 235, 1, 158, 7, 235, 1, 145, 7, 235, 1, 158, 7, 235, 1, 145, 3, 244, 0, 3, 4, 213, 0, 167, 4, 213, 0, 178, 4, 213, 0, 41, 4, 213, 0, 41, 2, 214, 0, 115, 8, 43, 1, 177, 8, 107, 1, 209, 7, 85, 1, 70, 6, 0, 1, 218, 6, 0, 1, 81, 4, 64, 0, 59, 5, 64, 0, 60, 4, 192, 0, 102, 4, 21, 0, 66, 4, 0, 0, 196, 6, 0, 1, 16, 4, 227, 0, 35, 4, 227, 0, 35, 2, 170, 0, 140, 2, 170, 0, 141, 2, 170, 0, 103, 2, 170, 0, 35, 2, 170, 0, 53, 2, 170, 0, 43, 2, 170, 0, 45, 2, 170, 255, 189, 1, 199, 0, 113, 1, 199, 0, 103, 2, 170, 0, 87, 0, 87, 255, 229, 255, 229, 0, 15, 255, 207, 255, 174, 255, 251, 0, 0, 0, 0, 0, 3, 0, 0, 0, 3, 0, 0, 0, 28, 0, 1, 0, 0, 0, 0, 4, 248, 0, 3, 0, 1, 0, 0, 0, 28, 0, 4, 4, 220, 0, 0, 0, 194, 0, 128, 0, 6, 0, 66, 0, 126, 1, 127, 1, 146, 1, 255, 2, 27, 2, 199, 2, 201, 2, 221, 3, 126, 3, 138, 3, 140, 3, 161, 3, 206, 4, 12, 4, 79, 4, 92, 4, 95, 4, 145, 30, 133, 30, 243, 32, 17, 32, 21, 32, 30, 32, 34, 32, 38, 32, 48, 32, 51, 32, 58, 32, 60, 32, 62, 32, 68, 32, 127, 32, 164, 32, 167, 32, 172, 33, 5, 33, 19, 33, 22, 33, 34, 33, 38, 33, 46, 33, 94, 33, 149, 33, 168, 34, 2, 34, 6, 34, 15, 34, 18, 34, 21, 34, 26, 34, 31, 34, 41, 34, 43, 34, 72, 34, 97, 34, 101, 35, 2, 35, 16, 35, 33, 37, 0, 37, 2, 37, 12, 37, 16, 37, 20, 37, 24, 37, 28, 37, 36, 37, 44, 37, 52, 37, 60, 37, 108, 37, 128, 37, 132, 37, 136, 37, 140, 37, 147, 37, 161, 37, 172, 37, 178, 37, 186, 37, 188, 37, 196, 37, 203, 37, 207, 37, 217, 37, 230, 38, 60, 38, 64, 38, 66, 38, 96, 38, 99, 38, 102, 38, 107, 240, 2, 240, 5, 251, 2, 255, 255, 0, 0, 0, 32, 0, 160, 1, 146, 1, 250, 2, 24, 2, 198, 2, 201, 2, 216, 3, 126, 3, 132, 3, 140, 3, 142, 3, 163, 4, 1, 4, 14, 4, 81, 4, 94, 4, 144, 30, 128, 30, 242, 32, 16, 32, 19, 32, 23, 32, 32, 32, 38, 32, 48, 32, 50, 32, 57, 32, 60, 32, 62, 32, 68, 32, 127, 32, 163, 32, 167, 32, 172, 33, 5, 33, 19, 33, 22, 33, 34, 33, 38, 33, 46, 33, 91, 33, 144, 33, 168, 34, 2, 34, 6, 34, 15, 34, 17, 34, 21, 34, 25, 34, 30, 34, 41, 34, 43, 34, 72, 34, 96, 34, 100, 35, 2, 35, 16, 35, 32, 37, 0, 37, 2, 37, 12, 37, 16, 37, 20, 37, 24, 37, 28, 37, 36, 37, 44, 37, 52, 37, 60, 37, 80, 37, 128, 37, 132, 37, 136, 37, 140, 37, 144, 37, 160, 37, 170, 37, 178, 37, 186, 37, 188, 37, 196, 37, 202, 37, 207, 37, 216, 37, 230, 38, 58, 38, 64, 38, 66, 38, 96, 38, 99, 38, 101, 38, 106, 240, 1, 240, 5, 251, 1, 255, 255, 255, 227, 0, 0, 255, 174, 255, 71, 255, 47, 254, 133, 254, 132, 254, 118, 252, 160, 253, 208, 253, 207, 253, 206, 253, 205, 253, 155, 253, 154, 253, 153, 253, 152, 253, 104, 227, 122, 227, 14, 225, 242, 225, 241, 225, 240, 225, 239, 225, 236, 225, 227, 225, 226, 225, 221, 225, 220, 225, 219, 225, 214, 225, 156, 225, 121, 225, 119, 225, 115, 225, 27, 225, 14, 225, 12, 225, 1, 224, 254, 224, 247, 224, 203, 224, 154, 224, 136, 224, 47, 224, 44, 224, 36, 224, 35, 224, 5, 0, 0, 224, 25, 224, 16, 224, 15, 223, 243, 223, 220, 223, 218, 223, 62, 223, 49, 223, 34, 221, 68, 221, 67, 221, 58, 221, 55, 221, 52, 221, 49, 221, 46, 221, 39, 221, 32, 221, 25, 221, 18, 220, 255, 220, 236, 220, 233, 220, 230, 220, 227, 220, 224, 220, 212, 220, 204, 220, 199, 220, 192, 220, 191, 220, 184, 220, 179, 220, 176, 220, 168, 220, 156, 220, 73, 220, 70, 220, 69, 220, 40, 220, 38, 220, 37, 220, 34, 18, 141, 18, 139, 7, 141, 0, 1, 0, 0, 0, 192, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 32, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 16, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 128, 0, 129, 0, 130, 0, 131, 0, 132, 0, 133, 0, 134, 0, 135, 0, 136, 0, 137, 0, 138, 0, 139, 0, 140, 0, 141, 0, 142, 0, 143, 0, 144, 0, 145, 0, 146, 0, 147, 0, 148, 0, 149, 0, 150, 0, 151, 0, 152, 0, 153, 0, 154, 0, 155, 0, 156, 0, 157, 0, 158, 0, 159, 0, 160, 0, 161, 0, 162, 0, 163, 0, 164, 0, 165, 0, 166, 0, 167, 0, 168, 0, 169, 0, 170, 0, 171, 0, 172, 0, 173, 0, 174, 0, 175, 0, 176, 0, 177, 0, 178, 0, 179, 0, 180, 0, 181, 0, 182, 0, 183, 0, 184, 0, 185, 0, 186, 0, 187, 0, 188, 0, 189, 0, 190, 0, 191, 0, 192, 0, 193, 0, 194, 0, 195, 0, 196, 0, 197, 0, 198, 0, 199, 0, 200, 0, 201, 0, 202, 0, 203, 0, 204, 0, 205, 0, 206, 0, 207, 0, 208, 0, 209, 0, 210, 0, 211, 0, 212, 0, 213, 0, 214, 0, 215, 0, 216, 0, 217, 0, 218, 0, 219, 0, 220, 0, 221, 0, 222, 0, 223, 0, 224, 0, 225, 0, 226, 0, 227, 0, 228, 0, 229, 0, 230, 0, 231, 0, 232, 0, 233, 0, 234, 0, 235, 0, 236, 0, 237, 0, 238, 0, 239, 0, 240, 0, 241, 0, 242, 0, 243, 0, 244, 0, 245, 0, 246, 0, 247, 0, 248, 0, 249, 0, 250, 0, 251, 0, 252, 0, 253, 0, 254, 0, 255, 1, 0, 1, 1, 1, 2, 1, 3, 1, 4, 1, 5, 1, 6, 1, 7, 1, 8, 1, 9, 1, 10, 1, 11, 1, 12, 1, 13, 1, 14, 1, 15, 1, 16, 1, 17, 1, 18, 1, 19, 1, 20, 1, 21, 1, 22, 1, 23, 1, 24, 1, 25, 1, 26, 1, 27, 1, 28, 1, 29, 1, 30, 1, 31, 1, 32, 1, 33, 1, 34, 1, 35, 1, 36, 1, 37, 1, 38, 1, 39, 1, 40, 1, 41, 1, 42, 1, 43, 1, 44, 1, 45, 1, 46, 1, 47, 1, 48, 1, 49, 1, 50, 1, 51, 1, 52, 1, 53, 1, 54, 1, 55, 1, 56, 1, 57, 1, 58, 1, 59, 1, 60, 1, 61, 1, 62, 1, 63, 0, 119, 2, 54, 0, 6, 2, 10, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 3, 0, 4, 0, 5, 0, 6, 0, 7, 0, 8, 0, 9, 0, 10, 0, 11, 0, 12, 0, 13, 0, 14, 0, 15, 0, 16, 0, 17, 0, 18, 0, 19, 0, 20, 0, 21, 0, 22, 0, 23, 0, 24, 0, 25, 0, 26, 0, 27, 0, 28, 0, 29, 0, 30, 0, 31, 0, 32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 0, 0, 132, 0, 133, 0, 135, 0, 137, 0, 145, 0, 150, 0, 156, 0, 161, 0, 160, 0, 162, 0, 164, 0, 163, 0, 165, 0, 167, 0, 169, 0, 168, 0, 170, 0, 171, 0, 173, 0, 172, 0, 174, 0, 175, 0, 177, 0, 179, 0, 178, 0, 180, 0, 182, 0, 181, 0, 186, 0, 185, 0, 187, 0, 188, 2, 15, 0, 112, 0, 99, 0, 100, 0, 104, 2, 17, 0, 118, 0, 159, 0, 110, 0, 106, 2, 35, 0, 116, 0, 105, 2, 60, 0, 134, 0, 152, 2, 55, 0, 113, 2, 62, 2, 63, 0, 102, 0, 117, 2, 49, 2, 52, 2, 51, 1, 141, 2, 58, 0, 107, 0, 122, 1, 118, 0, 166, 0, 184, 0, 127, 0, 98, 0, 109, 2, 54, 1, 64, 2, 59, 2, 50, 0, 108, 0, 123, 2, 18, 0, 3, 0, 128, 0, 131, 0, 149, 1, 18, 1, 19, 2, 4, 2, 5, 2, 12, 2, 13, 2, 8, 2, 9, 0, 183, 2, 125, 0, 191, 1, 56, 2, 26, 2, 31, 2, 22, 2, 23, 2, 142, 2, 143, 2, 16, 0, 119, 2, 10, 2, 14, 2, 19, 0, 130, 0, 138, 0, 129, 0, 139, 0, 136, 0, 141, 0, 142, 0, 143, 0, 140, 0, 147, 0, 148, 0, 0, 0, 146, 0, 154, 0, 155, 0, 153, 0, 241, 1, 75, 1, 82, 0, 111, 1, 78, 1, 79, 1, 80, 0, 120, 1, 83, 1, 81, 1, 76, 0, 0, 64, 69, 89, 88, 85, 84, 83, 82, 81, 80, 79, 78, 77, 76, 75, 74, 73, 72, 71, 70, 69, 68, 67, 66, 65, 64, 63, 62, 61, 60, 59, 58, 57, 56, 55, 54, 53, 49, 48, 47, 46, 45, 44, 40, 39, 38, 37, 36, 35, 34, 33, 31, 24, 20, 17, 16, 15, 14, 13, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 1, 0, 44, 69, 35, 70, 96, 32, 176, 38, 96, 176, 4, 38, 35, 72, 72, 45, 44, 69, 35, 70, 35, 97, 32, 176, 38, 97, 176, 4, 38, 35, 72, 72, 45, 44, 69, 35, 70, 96, 176, 32, 97, 32, 176, 70, 96, 176, 4, 38, 35, 72, 72, 45, 44, 69, 35, 70, 35, 97, 176, 32, 96, 32, 176, 38, 97, 176, 32, 97, 176, 4, 38, 35, 72, 72, 45, 44, 69, 35, 70, 96, 176, 64, 97, 32, 176, 102, 96, 176, 4, 38, 35, 72, 72, 45, 44, 69, 35, 70, 35, 97, 176, 64, 96, 32, 176, 38, 97, 176, 64, 97, 176, 4, 38, 35, 72, 72, 45, 44, 1, 16, 32, 60, 0, 60, 45, 44, 32, 69, 35, 32, 176, 205, 68, 35, 32, 184, 1, 90, 81, 88, 35, 32, 176, 141, 68, 35, 89, 32, 176, 237, 81, 88, 35, 32, 176, 77, 68, 35, 89, 32, 176, 4, 38, 81, 88, 35, 32, 176, 13, 68, 35, 89, 33, 33, 45, 44, 32, 32, 69, 24, 104, 68, 32, 176, 1, 96, 32, 69, 176, 70, 118, 104, 138, 69, 96, 68, 45, 44, 1, 177, 11, 10, 67, 35, 67, 101, 10, 45, 44, 0, 177, 10, 11, 67, 35, 67, 11, 45, 44, 0, 176, 40, 35, 112, 177, 1, 40, 62, 1, 176, 40, 35, 112, 177, 2, 40, 69, 58, 177, 2, 0, 8, 13, 45, 44, 32, 69, 176, 3, 37, 69, 97, 100, 176, 80, 81, 88, 69, 68, 27, 33, 33, 89, 45, 44, 73, 176, 14, 35, 68, 45, 44, 32, 69, 176, 0, 67, 96, 68, 45, 44, 1, 176, 6, 67, 176, 7, 67, 101, 10, 45, 44, 32, 105, 176, 64, 97, 176, 0, 139, 32, 177, 44, 192, 138, 140, 184, 16, 0, 98, 96, 43, 12, 100, 35, 100, 97, 92, 88, 176, 3, 97, 89, 45, 44, 138, 3, 69, 138, 138, 135, 176, 17, 43, 176, 41, 35, 68, 176, 41, 122, 228, 24, 45, 44, 69, 101, 176, 44, 35, 68, 69, 176, 43, 35, 68, 45, 44, 75, 82, 88, 69, 68, 27, 33, 33, 89, 45, 44, 75, 81, 88, 69, 68, 27, 33, 33, 89, 45, 44, 1, 176, 5, 37, 16, 35, 32, 138, 245, 0, 176, 1, 96, 35, 237, 236, 45, 44, 1, 176, 5, 37, 16, 35, 32, 138, 245, 0, 176, 1, 97, 35, 237, 236, 45, 44, 1, 176, 6, 37, 16, 245, 0, 237, 236, 45, 44, 70, 35, 70, 96, 138, 138, 70, 35, 32, 70, 138, 96, 138, 97, 184, 255, 128, 98, 35, 32, 16, 35, 138, 177, 12, 12, 138, 112, 69, 96, 32, 176, 0, 80, 88, 176, 1, 97, 184, 255, 186, 139, 27, 176, 70, 140, 89, 176, 16, 96, 104, 1, 58, 45, 44, 32, 69, 176, 3, 37, 70, 82, 75, 176, 19, 81, 91, 88, 176, 2, 37, 70, 32, 104, 97, 176, 3, 37, 176, 3, 37, 63, 35, 33, 56, 27, 33, 17, 89, 45, 44, 32, 69, 176, 3, 37, 70, 80, 88, 176, 2, 37, 70, 32, 104, 97, 176, 3, 37, 176, 3, 37, 63, 35, 33, 56, 27, 33, 17, 89, 45, 44, 0, 176, 7, 67, 176, 6, 67, 11, 45, 44, 33, 33, 12, 100, 35, 100, 139, 184, 64, 0, 98, 45, 44, 33, 176, 128, 81, 88, 12, 100, 35, 100, 139, 184, 32, 0, 98, 27, 178, 0, 64, 47, 43, 89, 176, 2, 96, 45, 44, 33, 176, 192, 81, 88, 12, 100, 35, 100, 139, 184, 21, 85, 98, 27, 178, 0, 128, 47, 43, 89, 176, 2, 96, 45, 44, 12, 100, 35, 100, 139, 184, 64, 0, 98, 96, 35, 33, 45, 44, 75, 83, 88, 138, 176, 4, 37, 73, 100, 35, 69, 105, 176, 64, 139, 97, 176, 128, 98, 176, 32, 97, 106, 176, 14, 35, 68, 35, 16, 176, 14, 246, 27, 33, 35, 138, 18, 17, 32, 57, 47, 89, 45, 44, 75, 83, 88, 32, 176, 3, 37, 73, 100, 105, 32, 176, 5, 38, 176, 6, 37, 73, 100, 35, 97, 176, 128, 98, 176, 32, 97, 106, 176, 14, 35, 68, 176, 4, 38, 16, 176, 14, 246, 138, 16, 176, 14, 35, 68, 176, 14, 246, 176, 14, 35, 68, 176, 14, 237, 27, 138, 176, 4, 38, 17, 18, 32, 57, 35, 32, 57, 47, 47, 89, 45, 44, 69, 35, 69, 96, 35, 69, 96, 35, 69, 96, 35, 118, 104, 24, 176, 128, 98, 32, 45, 44, 176, 72, 43, 45, 44, 32, 69, 176, 0, 84, 88, 176, 64, 68, 32, 69, 176, 64, 97, 68, 27, 33, 33, 89, 45, 44, 69, 177, 48, 47, 69, 35, 69, 97, 96, 176, 1, 96, 105, 68, 45, 44, 75, 81, 88, 176, 47, 35, 112, 176, 20, 35, 66, 27, 33, 33, 89, 45, 44, 75, 81, 88, 32, 176, 3, 37, 69, 105, 83, 88, 68, 27, 33, 33, 89, 27, 33, 33, 89, 45, 44, 69, 176, 20, 67, 176, 0, 96, 99, 176, 1, 96, 105, 68, 45, 44, 176, 47, 69, 68, 45, 44, 69, 35, 32, 69, 138, 96, 68, 45, 44, 69, 35, 69, 96, 68, 45, 44, 75, 35, 81, 88, 185, 0, 51, 255, 224, 177, 52, 32, 27, 179, 51, 0, 52, 0, 89, 68, 68, 45, 44, 176, 22, 67, 88, 176, 3, 38, 69, 138, 88, 100, 102, 176, 31, 96, 27, 100, 176, 32, 96, 102, 32, 88, 27, 33, 176, 64, 89, 176, 1, 97, 89, 35, 88, 101, 89, 176, 41, 35, 68, 35, 16, 176, 41, 224, 27, 33, 33, 33, 33, 33, 89, 45, 44, 176, 2, 67, 84, 88, 75, 83, 35, 75, 81, 90, 88, 56, 27, 33, 33, 89, 27, 33, 33, 33, 33, 89, 45, 44, 176, 22, 67, 88, 176, 4, 37, 69, 100, 176, 32, 96, 102, 32, 88, 27, 33, 176, 64, 89, 176, 1, 97, 35, 88, 27, 101, 89, 176, 41, 35, 68, 176, 5, 37, 176, 8, 37, 8, 32, 88, 2, 27, 3, 89, 176, 4, 37, 16, 176, 5, 37, 32, 70, 176, 4, 37, 35, 66, 60, 176, 4, 37, 176, 7, 37, 8, 176, 7, 37, 16, 176, 6, 37, 32, 70, 176, 4, 37, 176, 1, 96, 35, 66, 60, 32, 88, 1, 27, 0, 89, 176, 4, 37, 16, 176, 5, 37, 176, 41, 224, 176, 41, 32, 69, 101, 68, 176, 7, 37, 16, 176, 6, 37, 176, 41, 224, 176, 5, 37, 176, 8, 37, 8, 32, 88, 2, 27, 3, 89, 176, 5, 37, 176, 3, 37, 67, 72, 176, 4, 37, 176, 7, 37, 8, 176, 6, 37, 176, 3, 37, 176, 1, 96, 67, 72, 27, 33, 89, 33, 33, 33, 33, 33, 33, 33, 45, 44, 2, 176, 4, 37, 32, 32, 70, 176, 4, 37, 35, 66, 176, 5, 37, 8, 176, 3, 37, 69, 72, 33, 33, 33, 33, 45, 44, 2, 176, 3, 37, 32, 176, 4, 37, 8, 176, 2, 37, 67, 72, 33, 33, 33, 45, 44, 69, 35, 32, 69, 24, 32, 176, 0, 80, 32, 88, 35, 101, 35, 89, 35, 104, 32, 176, 64, 80, 88, 33, 176, 64, 89, 35, 88, 101, 89, 138, 96, 68, 45, 44, 75, 83, 35, 75, 81, 90, 88, 32, 69, 138, 96, 68, 27, 33, 33, 89, 45, 44, 75, 84, 88, 32, 69, 138, 96, 68, 27, 33, 33, 89, 45, 44, 75, 83, 35, 75, 81, 90, 88, 56, 27, 33, 33, 89, 45, 44, 176, 0, 33, 75, 84, 88, 56, 27, 33, 33, 89, 45, 44, 176, 2, 67, 84, 88, 176, 70, 43, 27, 33, 33, 33, 33, 89, 45, 44, 176, 2, 67, 84, 88, 176, 71, 43, 27, 33, 33, 33, 89, 45, 44, 176, 2, 67, 84, 88, 176, 72, 43, 27, 33, 33, 33, 33, 89, 45, 44, 176, 2, 67, 84, 88, 176, 73, 43, 27, 33, 33, 33, 89, 45, 44, 32, 138, 8, 35, 75, 83, 138, 75, 81, 90, 88, 35, 56, 27, 33, 33, 89, 45, 44, 0, 176, 2, 37, 73, 176, 0, 83, 88, 32, 176, 64, 56, 17, 27, 33, 89, 45, 44, 1, 70, 35, 70, 96, 35, 70, 97, 35, 32, 16, 32, 70, 138, 97, 184, 255, 128, 98, 138, 177, 64, 64, 138, 112, 69, 96, 104, 58, 45, 44, 32, 138, 35, 73, 100, 138, 35, 83, 88, 60, 27, 33, 89, 45, 44, 75, 82, 88, 125, 27, 122, 89, 45, 44, 176, 18, 0, 75, 1, 75, 84, 66, 45, 44, 177, 2, 0, 66, 177, 35, 1, 136, 81, 177, 64, 1, 136, 83, 90, 88, 185, 16, 0, 0, 32, 136, 84, 88, 178, 2, 1, 2, 67, 96, 66, 89, 177, 36, 1, 136, 81, 88, 185, 32, 0, 0, 64, 136, 84, 88, 178, 2, 2, 2, 67, 96, 66, 177, 36, 1, 136, 84, 88, 178, 2, 32, 2, 67, 96, 66, 0, 75, 1, 75, 82, 88, 178, 2, 8, 2, 67, 96, 66, 89, 27, 185, 64, 0, 0, 128, 136, 84, 88, 178, 2, 4, 2, 67, 96, 66, 89, 185, 64, 0, 0, 128, 99, 184, 1, 0, 136, 84, 88, 178, 2, 8, 2, 67, 96, 66, 89, 185, 64, 0, 1, 0, 99, 184, 2, 0, 136, 84, 88, 178, 2, 16, 2, 67, 96, 66, 89, 185, 64, 0, 2, 0, 99, 184, 4, 0, 136, 84, 88, 178, 2, 64, 2, 67, 96, 66, 89, 89, 89, 89, 89, 45, 44, 69, 24, 104, 35, 75, 81, 88, 35, 32, 69, 32, 100, 176, 64, 80, 88, 124, 89, 104, 138, 96, 89, 68, 45, 44, 176, 0, 22, 176, 2, 37, 176, 2, 37, 1, 176, 1, 35, 62, 0, 176, 2, 35, 62, 177, 1, 2, 6, 12, 176, 10, 35, 101, 66, 176, 11, 35, 66, 1, 176, 1, 35, 63, 0, 176, 2, 35, 63, 177, 1, 2, 6, 12, 176, 6, 35, 101, 66, 176, 7, 35, 66, 176, 1, 22, 1, 45, 44, 122, 138, 16, 69, 35, 245, 24, 45, 0, 0, 0, 191, 0, 80, 1, 7, 0, 1, 0, 47, 1, 7, 0, 1, 0, 175, 1, 4, 64, 71, 1, 208, 253, 1, 191, 253, 1, 16, 253, 1, 111, 251, 1, 64, 251, 1, 128, 245, 144, 245, 160, 245, 3, 241, 240, 53, 31, 47, 240, 159, 240, 2, 95, 239, 1, 47, 239, 95, 239, 111, 239, 159, 239, 223, 239, 5, 230, 228, 32, 31, 229, 228, 61, 31, 226, 224, 39, 31, 225, 224, 61, 31, 223, 61, 221, 85, 222, 61, 3, 85, 221, 184, 1, 30, 178, 60, 31, 47, 65, 11, 1, 30, 0, 1, 0, 16, 1, 30, 0, 32, 1, 30, 0, 64, 1, 30, 0, 3, 255, 192, 1, 30, 64, 40, 25, 28, 70, 220, 3, 255, 31, 0, 219, 1, 218, 4, 60, 31, 212, 210, 28, 31, 211, 210, 38, 31, 96, 209, 144, 209, 192, 209, 3, 96, 209, 144, 209, 176, 209, 192, 209, 224, 209, 5, 184, 255, 192, 179, 209, 25, 29, 70, 184, 255, 192, 180, 209, 10, 13, 70, 15, 184, 1, 22, 64, 15, 1, 191, 190, 38, 31, 64, 187, 41, 65, 70, 64, 187, 34, 39, 70, 184, 1, 33, 64, 35, 182, 61, 31, 0, 184, 1, 184, 183, 10, 31, 0, 183, 1, 0, 183, 32, 183, 64, 183, 96, 183, 112, 183, 5, 64, 183, 96, 183, 144, 183, 208, 183, 240, 183, 5, 184, 1, 32, 64, 13, 72, 61, 31, 0, 181, 96, 181, 2, 160, 181, 208, 181, 2, 184, 255, 192, 64, 14, 181, 11, 14, 70, 15, 178, 95, 178, 2, 177, 3, 60, 31, 47, 65, 11, 1, 25, 0, 63, 1, 25, 0, 79, 1, 25, 0, 3, 0, 143, 1, 25, 0, 1, 0, 64, 1, 25, 64, 40, 38, 41, 70, 31, 175, 47, 175, 63, 175, 159, 175, 4, 15, 175, 1, 64, 175, 14, 22, 70, 0, 173, 112, 173, 128, 173, 3, 224, 173, 240, 173, 2, 171, 170, 53, 31, 170, 80, 38, 31, 185, 1, 27, 1, 26, 178, 60, 31, 0, 184, 1, 26, 182, 1, 15, 169, 1, 15, 168, 1, 188, 1, 23, 1, 19, 0, 60, 0, 31, 1, 21, 64, 135, 80, 60, 31, 158, 155, 39, 31, 157, 155, 39, 31, 156, 155, 39, 31, 128, 155, 1, 152, 70, 40, 31, 159, 151, 175, 151, 2, 150, 70, 53, 31, 15, 148, 31, 148, 2, 147, 144, 38, 31, 146, 145, 38, 31, 143, 140, 11, 31, 142, 140, 38, 31, 15, 141, 31, 141, 2, 95, 141, 111, 141, 127, 141, 255, 141, 4, 64, 141, 19, 23, 70, 15, 140, 1, 64, 140, 11, 15, 70, 15, 137, 31, 137, 2, 134, 133, 15, 31, 95, 133, 1, 54, 130, 70, 130, 2, 118, 80, 38, 31, 117, 80, 38, 31, 116, 80, 38, 31, 115, 80, 38, 31, 41, 112, 1, 27, 112, 1, 3, 112, 1, 244, 112, 1, 214, 112, 230, 112, 2, 104, 112, 1, 89, 112, 1, 184, 255, 240, 64, 116, 112, 10, 13, 70, 111, 110, 72, 31, 110, 70, 50, 31, 26, 1, 24, 85, 25, 51, 24, 85, 7, 51, 3, 85, 6, 3, 255, 31, 97, 80, 38, 31, 96, 95, 50, 31, 95, 80, 38, 31, 94, 90, 72, 31, 92, 70, 39, 31, 91, 90, 120, 31, 90, 70, 49, 31, 19, 50, 18, 85, 5, 1, 3, 85, 4, 50, 3, 85, 111, 3, 1, 15, 3, 63, 3, 2, 95, 83, 1, 64, 83, 40, 44, 70, 64, 83, 30, 34, 70, 64, 83, 19, 24, 70, 82, 81, 40, 31, 81, 79, 28, 31, 80, 79, 28, 31, 25, 79, 41, 79, 2, 89, 79, 105, 79, 2, 184, 1, 18, 64, 41, 70, 37, 31, 73, 70, 25, 31, 72, 70, 33, 31, 71, 70, 53, 31, 248, 70, 1, 152, 70, 1, 22, 50, 21, 85, 17, 1, 15, 85, 16, 50, 15, 85, 2, 1, 0, 85, 1, 0, 255, 31, 184, 1, 17, 178, 27, 9, 31, 184, 1, 16, 64, 61, 27, 9, 31, 16, 27, 64, 27, 2, 16, 27, 32, 27, 48, 27, 112, 27, 4, 31, 15, 63, 15, 95, 15, 127, 15, 4, 15, 15, 47, 15, 79, 15, 111, 15, 143, 15, 223, 15, 255, 15, 7, 63, 15, 95, 15, 127, 15, 239, 15, 4, 111, 0, 1, 95, 0, 1, 128, 22, 1, 5, 1, 184, 1, 144, 177, 84, 83, 43, 43, 75, 184, 7, 255, 82, 75, 176, 7, 80, 91, 176, 1, 136, 176, 37, 83, 176, 1, 136, 176, 64, 81, 90, 176, 6, 136, 176, 0, 85, 90, 91, 88, 177, 1, 1, 142, 89, 133, 141, 141, 0, 66, 29, 75, 176, 50, 83, 88, 176, 96, 29, 89, 75, 176, 100, 83, 88, 176, 64, 29, 89, 75, 176, 128, 83, 88, 176, 16, 29, 177, 22, 0, 66, 89, 115, 116, 115, 116, 117, 115, 116, 43, 43, 43, 43, 43, 43, 43, 1, 115, 116, 43, 43, 43, 43, 0, 115, 116, 43, 43, 43, 43, 43, 43, 115, 115, 117, 43, 43, 43, 1, 43, 43, 43, 0, 43, 43, 43, 43, 43, 43, 43, 43, 1, 43, 43, 43, 115, 115, 115, 115, 116, 116, 116, 0, 43, 43, 43, 43, 1, 115, 115, 43, 115, 0, 43, 115, 43, 116, 117, 43, 43, 43, 43, 115, 1, 43, 115, 43, 0, 115, 43, 43, 43, 43, 43, 115, 115, 115, 43, 1, 43, 43, 0, 115, 116, 43, 115, 116, 43, 115, 116, 43, 115, 1, 43, 115, 116, 43, 0, 115, 116, 117, 43, 116, 43, 43, 43, 1, 43, 0, 115, 43, 43, 115, 116, 1, 43, 43, 0, 43, 115, 43, 43, 115, 117, 43, 43, 43, 1, 43, 43, 0, 43, 43, 115, 116, 1, 115, 43, 0, 115, 115, 115, 115, 115, 115, 1, 115, 115, 115, 24, 0, 0, 0, 5, 204, 5, 204, 0, 125, 5, 129, 0, 21, 0, 121, 5, 129, 0, 21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 58, 0, 20, 0, 119, 0, 0, 255, 236, 0, 0, 0, 0, 255, 236, 0, 0, 0, 0, 255, 236, 0, 0, 254, 87, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 1, 25, 1, 37, 0, 245, 0, 235, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 193, 0, 211, 0, 186, 0, 176, 0, 207, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 39, 1, 41, 1, 6, 0, 0, 1, 18, 0, 228, 0, 244, 0, 198, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 25, 1, 31, 1, 76, 0, 0, 0, 0, 0, 223, 0, 209, 0, 197, 0, 181, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 169, 1, 253, 0, 216, 1, 25, 0, 128, 0, 183, 1, 253, 0, 0, 0, 0, 1, 63, 0, 219, 1, 93, 1, 37, 0, 170, 0, 128, 0, 117, 0, 141, 1, 252, 1, 121, 1, 33, 0, 160, 1, 16, 0, 0, 0, 0, 1, 49, 1, 25, 1, 14, 1, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 61, 1, 255, 0, 224, 1, 6, 0, 148, 0, 224, 0, 148, 1, 68, 0, 224, 5, 115, 3, 25, 0, 0, 0, 216, 2, 197, 0, 156, 3, 129, 2, 205, 0, 203, 0, 244, 0, 78, 2, 141, 0, 0, 0, 255, 0, 215, 0, 204, 1, 48, 1, 69, 0, 115, 0, 180, 0, 166, 0, 0, 0, 0, 0, 115, 0, 128, 0, 141, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 162, 0, 152, 0, 131, 0, 141, 0, 0, 0, 0, 0, 0, 0, 0, 5, 174, 254, 188, 5, 129, 2, 182, 0, 17, 255, 246, 0, 182, 0, 188, 0, 198, 0, 0, 0, 127, 0, 138, 0, 96, 0, 0, 0, 0, 0, 0, 0, 0, 0, 240, 1, 238, 1, 144, 0, 0, 2, 25, 1, 8, 1, 21, 0, 0, 0, 0, 0, 0, 0, 190, 0, 0, 0, 0, 0, 0, 0, 0, 7, 72, 3, 106, 2, 182, 2, 2, 253, 147, 0, 0, 0, 145, 0, 103, 0, 145, 0, 97, 1, 217, 0, 0, 2, 141, 3, 65, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 170, 254, 111, 254, 104, 1, 5, 0, 147, 0, 152, 0, 226, 1, 81, 0, 143, 0, 190, 0, 174, 254, 185, 254, 164, 0, 94, 0, 175, 2, 213, 0, 85, 0, 242, 0, 166, 0, 68, 5, 17, 1, 169, 0, 0, 0, 0, 0, 44, 0, 44, 0, 44, 0, 44, 1, 70, 1, 120, 2, 42, 3, 50, 5, 148, 6, 112, 6, 154, 6, 214, 7, 26, 7, 94, 7, 160, 7, 204, 7, 224, 7, 252, 8, 36, 8, 118, 8, 182, 9, 4, 9, 146, 9, 250, 10, 122, 10, 250, 11, 48, 11, 212, 12, 90, 13, 48, 14, 26, 14, 98, 14, 154, 14, 226, 15, 64, 16, 72, 17, 228, 18, 88, 18, 202, 19, 36, 19, 100, 19, 154, 20, 24, 20, 88, 20, 154, 20, 218, 21, 74, 21, 106, 22, 230, 23, 68, 23, 192, 24, 20, 24, 168, 25, 18, 25, 160, 26, 204, 27, 28, 27, 146, 29, 56, 29, 160, 30, 140, 30, 220, 31, 4, 31, 42, 31, 82, 31, 138, 31, 160, 31, 202, 32, 110, 32, 226, 33, 48, 33, 160, 34, 4, 34, 90, 34, 230, 35, 74, 35, 134, 36, 6, 36, 106, 36, 154, 37, 64, 37, 166, 37, 238, 38, 108, 38, 218, 39, 54, 39, 214, 40, 38, 40, 126, 40, 162, 40, 248, 41, 116, 41, 172, 41, 234, 42, 86, 42, 124, 42, 232, 43, 60, 44, 12, 44, 104, 44, 250, 45, 118, 46, 28, 46, 80, 47, 54, 47, 122, 48, 52, 48, 214, 49, 54, 49, 100, 50, 20, 50, 42, 50, 140, 50, 230, 51, 62, 51, 192, 51, 230, 52, 70, 52, 144, 52, 170, 53, 56, 53, 120, 53, 220, 54, 58, 54, 88, 54, 110, 54, 140, 54, 244, 55, 12, 55, 36, 55, 60, 55, 84, 55, 110, 55, 134, 55, 254, 56, 18, 56, 42, 56, 66, 56, 90, 56, 116, 56, 140, 56, 162, 56, 186, 56, 210, 57, 68, 57, 92, 57, 116, 57, 140, 57, 164, 57, 188, 57, 214, 58, 54, 58, 254, 59, 22, 59, 46, 59, 70, 59, 96, 59, 120, 59, 200, 60, 96, 60, 120, 60, 144, 60, 168, 60, 192, 60, 218, 60, 244, 61, 198, 61, 218, 61, 242, 62, 10, 62, 34, 62, 60, 62, 84, 62, 106, 62, 128, 62, 152, 63, 60, 63, 84, 63, 108, 63, 132, 63, 156, 63, 180, 63, 206, 64, 16, 64, 156, 64, 168, 64, 180, 64, 192, 64, 204, 64, 216, 65, 74, 65, 86, 65, 110, 65, 134, 65, 158, 65, 182, 65, 202, 65, 224, 65, 248, 66, 16, 66, 40, 66, 64, 66, 88, 66, 108, 66, 132, 66, 156, 66, 180, 66, 202, 66, 210, 67, 102, 67, 126, 67, 150, 67, 174, 67, 198, 67, 222, 67, 242, 68, 8, 68, 34, 68, 58, 68, 82, 68, 106, 68, 130, 68, 154, 68, 178, 68, 202, 68, 222, 68, 242, 69, 12, 69, 36, 69, 60, 69, 152, 70, 24, 70, 46, 70, 68, 70, 92, 70, 114, 70, 136, 70, 158, 70, 178, 70, 198, 70, 222, 71, 10, 71, 36, 71, 70, 71, 94, 72, 34, 72, 58, 72, 78, 72, 172, 72, 196, 72, 218, 72, 238, 73, 0, 73, 22, 73, 44, 73, 64, 73, 88, 73, 150, 73, 236, 74, 4, 74, 28, 74, 48, 74, 68, 74, 92, 74, 116, 74, 164, 75, 30, 75, 156, 75, 180, 75, 204, 75, 228, 75, 252, 76, 22, 76, 48, 76, 182, 77, 72, 77, 96, 77, 120, 77, 140, 77, 160, 77, 184, 77, 208, 77, 232, 78, 0, 78, 24, 78, 48, 78, 68, 78, 88, 78, 112, 78, 136, 78, 148, 78, 160, 78, 184, 78, 208, 80, 20, 80, 120, 80, 144, 80, 156, 80, 180, 80, 192, 80, 216, 80, 228, 80, 254, 81, 10, 81, 36, 81, 48, 81, 72, 81, 84, 81, 108, 81, 120, 81, 144, 81, 156, 81, 182, 81, 206, 81, 230, 81, 254, 82, 18, 82, 42, 82, 66, 82, 146, 82, 232, 83, 20, 83, 66, 83, 90, 83, 114, 83, 138, 83, 162, 83, 174, 83, 186, 83, 198, 83, 210, 84, 36, 84, 118, 84, 172, 85, 42, 85, 66, 85, 162, 86, 18, 86, 180, 86, 236, 87, 24, 87, 104, 90, 166, 90, 174, 90, 210, 90, 246, 91, 34, 91, 82, 91, 134, 91, 182, 91, 204, 91, 212, 91, 220, 92, 0, 92, 86, 92, 94, 92, 102, 92, 110, 92, 250, 93, 2, 93, 10, 93, 128, 93, 136, 93, 144, 93, 210, 93, 218, 94, 2, 94, 10, 94, 76, 94, 84, 94, 92, 96, 34, 96, 42, 97, 250, 98, 132, 98, 156, 98, 182, 98, 206, 101, 214, 101, 238, 102, 4, 102, 30, 102, 162, 103, 48, 104, 42, 104, 182, 105, 56, 105, 204, 106, 52, 106, 150, 106, 236, 107, 74, 108, 90, 108, 216, 110, 42, 110, 230, 110, 238, 111, 102, 111, 202, 112, 70, 112, 180, 113, 32, 113, 116, 114, 216, 115, 110, 116, 228, 118, 122, 118, 148, 118, 174, 118, 198, 118, 222, 118, 246, 120, 34, 120, 166, 124, 4, 124, 132, 124, 140, 124, 148, 125, 172, 125, 180, 126, 58, 126, 150, 126, 232, 127, 0, 127, 24, 128, 40, 128, 48, 128, 136, 128, 144, 128, 178, 129, 6, 129, 14, 130, 216, 131, 110, 131, 202, 131, 226, 132, 62, 132, 148, 132, 156, 132, 164, 132, 172, 132, 210, 132, 218, 132, 226, 132, 234, 133, 94, 134, 216, 134, 224, 135, 36, 135, 106, 136, 188, 138, 80, 138, 154, 138, 240, 139, 66, 139, 192, 140, 64, 140, 168, 140, 176, 141, 38, 141, 154, 141, 200, 142, 50, 142, 58, 143, 128, 144, 12, 144, 100, 144, 124, 144, 216, 145, 50, 146, 80, 146, 148, 146, 156, 146, 208, 146, 216, 146, 224, 148, 114, 148, 122, 150, 108, 150, 116, 150, 174, 150, 248, 152, 112, 153, 236, 154, 62, 154, 170, 155, 0, 155, 104, 155, 214, 156, 56, 156, 82, 156, 246, 157, 14, 157, 116, 157, 124, 157, 188, 159, 138, 159, 146, 160, 40, 160, 146, 161, 24, 161, 48, 161, 60, 162, 178, 162, 224, 163, 24, 163, 48, 163, 60, 163, 84, 163, 96, 163, 122, 163, 134, 163, 158, 163, 170, 163, 198, 163, 226, 163, 246, 164, 10, 164, 30, 164, 42, 164, 102, 164, 152, 164, 212, 165, 4, 165, 98, 165, 186, 166, 40, 166, 96, 166, 184, 166, 246, 167, 54, 169, 200, 169, 232, 169, 252, 170, 48, 170, 100, 170, 122, 170, 144, 170, 178, 171, 0, 171, 88, 172, 8, 174, 84, 175, 8, 175, 234, 176, 116, 177, 44, 177, 186, 178, 70, 178, 174, 178, 208, 178, 240, 179, 16, 179, 56, 179, 102, 179, 148, 179, 194, 179, 240, 180, 56, 180, 128, 180, 208, 181, 94, 181, 218, 182, 0, 182, 98, 182, 122, 182, 228, 183, 130, 183, 154, 183, 208, 184, 48, 184, 208, 185, 82, 185, 142, 185, 236, 186, 72, 186, 118, 186, 156, 186, 210, 187, 16, 187, 40, 187, 66, 187, 100, 187, 134, 187, 168, 187, 202, 187, 240, 188, 22, 188, 60, 188, 98, 188, 148, 188, 186, 188, 228, 189, 18, 189, 66, 189, 124, 189, 170, 189, 218, 190, 20, 190, 66, 190, 114, 190, 172, 190, 218, 191, 10, 191, 68, 191, 120, 191, 174, 191, 242, 192, 38, 192, 94, 192, 164, 192, 218, 193, 14, 193, 84, 193, 138, 193, 190, 194, 6, 194, 78, 194, 152, 194, 244, 195, 12, 195, 36, 195, 60, 195, 84, 195, 108, 197, 132, 199, 96, 201, 32, 201, 46, 201, 78, 201, 106, 201, 146, 201, 160, 201, 174, 201, 188, 201, 202, 201, 216, 202, 34, 202, 116, 202, 166, 202, 216, 203, 42, 203, 108, 204, 28, 204, 156, 205, 76, 205, 198, 206, 94, 206, 190, 207, 68, 207, 152, 207, 210, 208, 30, 208, 148, 209, 6, 209, 108, 209, 182, 209, 214, 210, 2, 210, 86, 210, 202, 210, 252, 211, 144, 211, 228, 212, 14, 212, 50, 212, 84, 212, 116, 212, 186, 212, 240, 213, 24, 213, 116, 213, 164, 213, 238, 0, 0, 0, 2, 0, 68, 0, 0, 2, 100, 5, 85, 0, 3, 0, 7, 0, 46, 177, 1, 0, 47, 60, 178, 7, 4, 34, 237, 50, 177, 6, 5, 220, 60, 178, 3, 2, 34, 237, 50, 0, 177, 3, 0, 47, 60, 178, 5, 4, 34, 237, 50, 178, 7, 6, 35, 252, 60, 178, 1, 2, 34, 237, 50, 51, 17, 33, 17, 37, 33, 17, 33, 68, 2, 32, 254, 36, 1, 152, 254, 104, 5, 85, 250, 171, 68, 4, 205, 0, 0, 0, 2, 0, 193, 0, 0, 1, 231, 5, 129, 0, 3, 0, 7, 2, 6, 64, 91, 3, 2, 7, 150, 6, 4, 22, 4, 2, 11, 4, 4, 9, 8, 153, 9, 169, 9, 2, 86, 9, 102, 9, 2, 25, 9, 1, 134, 9, 150, 9, 198, 9, 214, 9, 246, 9, 5, 57, 9, 73, 9, 89, 9, 3, 6, 9, 1, 203, 153, 9, 201, 9, 2, 70, 9, 118, 9, 134, 9, 3, 198, 9, 214, 9, 230, 9, 3, 25, 9, 73, 9, 153, 9, 169, 9, 4, 4, 9, 1, 244, 9, 1, 182, 9, 214, 9, 230, 9, 3, 9, 184, 255, 128, 64, 19, 161, 165, 72, 70, 9, 86, 9, 2, 52, 9, 1, 38, 9, 1, 2, 9, 1, 155, 9, 184, 255, 192, 64, 11, 151, 154, 72, 196, 9, 212, 9, 228, 9, 3, 9, 184, 255, 64, 182, 143, 147, 72, 100, 9, 1, 9, 184, 255, 64, 64, 46, 137, 141, 72, 4, 9, 1, 244, 9, 1, 224, 9, 1, 194, 9, 210, 9, 2, 176, 9, 1, 130, 9, 146, 9, 162, 9, 3, 84, 9, 100, 9, 116, 9, 3, 70, 9, 1, 34, 9, 50, 9, 2, 22, 9, 1, 9, 184, 255, 128, 64, 73, 112, 120, 72, 114, 9, 1, 68, 9, 84, 9, 100, 9, 3, 50, 9, 1, 20, 9, 36, 9, 2, 2, 9, 1, 104, 228, 9, 244, 9, 2, 210, 9, 1, 166, 9, 182, 9, 198, 9, 3, 114, 9, 130, 9, 146, 9, 3, 68, 9, 84, 9, 100, 9, 3, 54, 9, 1, 32, 9, 1, 20, 9, 1, 6, 9, 1, 246, 9, 1, 226, 9, 1, 9, 184, 255, 128, 64, 40, 80, 85, 72, 54, 9, 86, 9, 102, 9, 118, 9, 4, 34, 9, 1, 1, 0, 9, 16, 9, 2, 240, 9, 1, 212, 9, 228, 9, 2, 192, 9, 1, 148, 9, 164, 9, 180, 9, 3, 9, 184, 255, 128, 64, 24, 59, 63, 72, 4, 9, 20, 9, 36, 9, 3, 56, 228, 9, 244, 9, 2, 176, 9, 192, 9, 208, 9, 3, 9, 184, 255, 192, 64, 45, 44, 49, 72, 32, 9, 1, 20, 9, 1, 0, 9, 1, 240, 9, 1, 148, 9, 196, 9, 212, 9, 228, 9, 4, 96, 9, 112, 9, 2, 68, 9, 84, 9, 116, 9, 132, 9, 148, 9, 180, 9, 196, 9, 7, 9, 184, 255, 192, 64, 18, 23, 28, 72, 16, 9, 1, 2, 0, 9, 1, 7, 1, 1, 2, 3, 5, 157, 4, 0, 47, 237, 63, 57, 47, 1, 94, 93, 95, 93, 43, 93, 113, 113, 113, 114, 114, 114, 43, 114, 114, 94, 93, 43, 93, 93, 93, 93, 113, 95, 113, 113, 43, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 43, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 43, 114, 43, 114, 43, 94, 93, 93, 93, 93, 43, 93, 93, 113, 113, 113, 114, 114, 94, 93, 93, 93, 113, 113, 113, 17, 18, 57, 47, 94, 93, 237, 51, 50, 49, 48, 1, 35, 3, 33, 1, 17, 33, 17, 1, 199, 230, 32, 1, 38, 254, 218, 1, 32, 1, 170, 3, 215, 250, 127, 1, 14, 254, 242, 0, 0, 0, 2, 0, 135, 3, 130, 3, 68, 5, 129, 0, 3, 0, 7, 0, 54, 64, 35, 2, 152, 143, 3, 1, 47, 3, 159, 3, 2, 0, 3, 1, 3, 7, 152, 207, 6, 1, 0, 6, 32, 6, 48, 6, 64, 6, 4, 6, 4, 0, 169, 6, 2, 3, 0, 63, 51, 237, 50, 1, 47, 93, 113, 237, 47, 93, 93, 113, 237, 49, 48, 1, 35, 3, 33, 1, 35, 3, 33, 3, 39, 219, 27, 1, 19, 254, 57, 219, 27, 1, 17, 3, 130, 1, 255, 254, 1, 1, 255, 0, 0, 0, 2, 0, 35, 0, 0, 4, 82, 5, 115, 0, 27, 0, 31, 0, 242, 181, 26, 32, 9, 0, 77, 16, 184, 255, 192, 179, 10, 0, 77, 12, 184, 255, 224, 64, 38, 9, 10, 0, 76, 4, 1, 0, 25, 24, 5, 24, 22, 31, 30, 7, 6, 23, 6, 8, 29, 28, 21, 20, 9, 20, 18, 15, 14, 11, 10, 19, 10, 5, 1, 82, 23, 6, 23, 184, 1, 20, 64, 12, 24, 5, 20, 24, 24, 5, 19, 1, 82, 9, 20, 9, 184, 1, 20, 64, 19, 10, 19, 20, 10, 19, 9, 10, 20, 6, 20, 6, 10, 27, 3, 24, 33, 16, 12, 10, 184, 255, 192, 64, 50, 10, 13, 72, 10, 8, 4, 12, 174, 13, 29, 1, 13, 28, 0, 16, 174, 17, 25, 21, 17, 15, 13, 175, 13, 2, 207, 13, 255, 13, 2, 15, 17, 79, 17, 175, 17, 3, 207, 17, 1, 13, 17, 13, 17, 5, 23, 19, 177, 10, 5, 0, 47, 51, 63, 51, 18, 57, 57, 47, 47, 93, 113, 93, 113, 17, 51, 51, 16, 237, 50, 50, 17, 51, 51, 16, 237, 50, 50, 1, 47, 43, 51, 51, 16, 204, 50, 50, 17, 57, 57, 47, 47, 16, 0, 193, 135, 5, 43, 135, 43, 196, 135, 24, 16, 43, 135, 43, 196, 49, 48, 16, 135, 192, 192, 192, 192, 16, 135, 192, 192, 192, 192, 16, 135, 192, 192, 192, 192, 16, 135, 192, 192, 192, 192, 1, 43, 43, 43, 1, 3, 51, 21, 35, 3, 35, 19, 33, 3, 35, 19, 35, 53, 51, 19, 35, 53, 51, 19, 51, 3, 33, 19, 51, 3, 51, 21, 33, 3, 33, 19, 3, 141, 69, 215, 246, 82, 156, 80, 254, 205, 80, 153, 79, 155, 188, 70, 207, 238, 84, 153, 82, 1, 51, 84, 156, 84, 164, 253, 111, 72, 1, 53, 70, 3, 94, 254, 180, 149, 254, 131, 1, 125, 254, 131, 1, 125, 149, 1, 76, 148, 1, 129, 254, 127, 1, 129, 254, 127, 148, 254, 180, 1, 76, 0, 0, 0, 0, 3, 0, 27, 255, 104, 4, 86, 5, 240, 0, 53, 0, 64, 0, 73, 1, 53, 185, 0, 45, 255, 192, 179, 11, 15, 72, 46, 184, 255, 192, 64, 14, 11, 15, 72, 20, 64, 11, 15, 72, 19, 64, 11, 15, 72, 52, 184, 255, 208, 64, 9, 10, 0, 77, 26, 32, 10, 0, 77, 39, 184, 255, 232, 64, 9, 9, 0, 77, 20, 64, 9, 0, 77, 50, 184, 255, 248, 180, 9, 10, 0, 76, 2, 184, 255, 232, 64, 26, 9, 10, 0, 76, 30, 8, 9, 10, 0, 76, 45, 35, 54, 34, 34, 13, 0, 71, 6, 7, 19, 7, 42, 110, 41, 59, 184, 255, 248, 181, 12, 15, 72, 59, 110, 28, 184, 255, 192, 64, 17, 25, 28, 72, 0, 7, 1, 28, 7, 41, 41, 7, 28, 3, 13, 65, 110, 0, 184, 255, 192, 64, 91, 38, 53, 72, 0, 75, 14, 110, 175, 13, 191, 13, 2, 13, 64, 22, 28, 72, 13, 64, 14, 17, 72, 13, 71, 19, 116, 8, 0, 14, 16, 14, 48, 14, 64, 14, 128, 14, 144, 14, 6, 14, 14, 5, 8, 20, 70, 46, 64, 45, 54, 8, 12, 15, 72, 54, 117, 33, 29, 42, 1, 11, 42, 1, 42, 42, 36, 70, 64, 33, 192, 33, 1, 96, 8, 112, 8, 128, 8, 3, 160, 8, 176, 8, 2, 8, 33, 8, 33, 6, 34, 6, 0, 47, 47, 18, 57, 57, 47, 47, 93, 113, 93, 18, 57, 57, 50, 50, 47, 93, 93, 16, 237, 43, 50, 17, 51, 17, 51, 17, 51, 51, 47, 93, 16, 237, 50, 1, 47, 43, 43, 93, 237, 16, 222, 43, 237, 18, 23, 57, 47, 47, 47, 93, 43, 237, 43, 16, 237, 17, 51, 16, 205, 50, 17, 18, 57, 47, 51, 205, 50, 49, 48, 43, 43, 0, 43, 1, 43, 43, 43, 43, 43, 43, 43, 43, 1, 20, 14, 2, 7, 21, 35, 53, 46, 3, 39, 37, 30, 3, 23, 17, 46, 1, 35, 46, 3, 53, 52, 62, 2, 55, 53, 51, 21, 30, 3, 23, 5, 46, 1, 39, 17, 22, 50, 23, 30, 3, 1, 14, 3, 21, 20, 30, 2, 23, 1, 52, 46, 2, 39, 17, 62, 1, 4, 86, 56, 117, 182, 126, 109, 114, 169, 119, 73, 18, 1, 0, 8, 31, 54, 83, 61, 3, 24, 4, 78, 150, 117, 72, 66, 119, 165, 98, 109, 107, 150, 104, 64, 21, 254, 248, 15, 87, 80, 5, 11, 6, 86, 165, 129, 79, 253, 178, 53, 71, 44, 18, 28, 50, 68, 40, 1, 74, 34, 60, 81, 46, 106, 115, 1, 156, 85, 139, 101, 59, 5, 175, 172, 4, 54, 98, 141, 91, 47, 48, 79, 58, 37, 6, 1, 135, 2, 5, 18, 53, 91, 139, 104, 91, 131, 86, 44, 4, 134, 134, 4, 48, 87, 127, 84, 39, 87, 95, 11, 254, 160, 2, 2, 20, 54, 92, 145, 2, 159, 4, 28, 43, 55, 30, 43, 55, 36, 25, 13, 254, 58, 49, 61, 38, 25, 13, 254, 145, 7, 86, 0, 0, 5, 0, 51, 255, 240, 6, 231, 5, 145, 0, 19, 0, 23, 0, 43, 0, 63, 0, 83, 3, 213, 185, 0, 27, 255, 232, 64, 17, 9, 10, 0, 76, 41, 24, 9, 10, 0, 76, 37, 24, 9, 10, 0, 76, 31, 184, 255, 232, 180, 9, 10, 0, 76, 18, 184, 255, 232, 64, 17, 9, 10, 0, 76, 12, 24, 9, 10, 0, 76, 8, 24, 9, 10, 0, 76, 2, 184, 255, 232, 64, 16, 9, 10, 0, 76, 9, 22, 1, 22, 23, 6, 20, 1, 3, 20, 21, 21, 184, 255, 240, 64, 52, 23, 16, 231, 23, 247, 23, 2, 7, 23, 1, 8, 21, 1, 10, 23, 21, 23, 21, 39, 0, 54, 180, 8, 10, 1, 10, 181, 44, 180, 24, 0, 40, 0, 2, 0, 64, 20, 25, 72, 0, 85, 64, 180, 7, 29, 1, 13, 29, 181, 74, 180, 39, 184, 255, 192, 64, 255, 20, 25, 72, 39, 64, 16, 19, 72, 39, 226, 85, 1, 209, 85, 1, 194, 85, 1, 179, 85, 1, 164, 85, 1, 149, 85, 1, 114, 85, 130, 85, 2, 97, 85, 1, 80, 85, 1, 65, 85, 1, 50, 85, 1, 19, 85, 35, 85, 2, 4, 85, 1, 241, 85, 1, 210, 85, 226, 85, 2, 179, 85, 195, 85, 2, 162, 85, 1, 147, 85, 1, 132, 85, 1, 117, 85, 1, 102, 85, 1, 65, 85, 81, 85, 2, 50, 85, 1, 35, 85, 1, 20, 85, 1, 3, 85, 1, 199, 227, 85, 243, 85, 2, 212, 85, 1, 177, 85, 193, 85, 2, 162, 85, 1, 131, 85, 147, 85, 2, 116, 85, 1, 99, 85, 1, 84, 85, 1, 69, 85, 1, 54, 85, 1, 33, 85, 1, 18, 85, 1, 3, 85, 1, 244, 85, 1, 213, 85, 229, 85, 2, 195, 85, 1, 180, 85, 1, 165, 85, 1, 145, 85, 1, 130, 85, 1, 115, 85, 1, 98, 85, 1, 83, 85, 1, 68, 85, 1, 53, 85, 1, 38, 85, 1, 5, 85, 21, 85, 2, 241, 85, 1, 226, 85, 1, 211, 85, 1, 196, 85, 1, 181, 85, 1, 164, 85, 1, 149, 85, 1, 134, 85, 1, 117, 85, 1, 97, 85, 1, 66, 85, 82, 85, 2, 51, 85, 1, 36, 85, 1, 21, 85, 1, 6, 85, 1, 151, 247, 85, 1, 230, 85, 1, 212, 85, 1, 193, 85, 1, 178, 85, 1, 163, 85, 1, 64, 255, 132, 85, 148, 85, 2, 117, 85, 1, 102, 85, 1, 71, 85, 87, 85, 2, 50, 85, 1, 33, 85, 1, 18, 85, 1, 3, 85, 1, 244, 85, 1, 229, 85, 1, 214, 85, 1, 199, 85, 1, 182, 85, 1, 167, 85, 1, 148, 85, 1, 131, 85, 1, 84, 85, 100, 85, 116, 85, 3, 69, 85, 1, 38, 85, 54, 85, 2, 23, 85, 1, 244, 85, 1, 227, 85, 1, 0, 208, 85, 1, 194, 85, 1, 164, 85, 180, 85, 2, 146, 85, 1, 132, 85, 1, 118, 85, 1, 96, 85, 1, 82, 85, 1, 48, 85, 64, 85, 2, 34, 85, 1, 4, 85, 20, 85, 2, 103, 214, 85, 230, 85, 246, 85, 3, 192, 85, 1, 178, 85, 1, 160, 85, 1, 146, 85, 1, 132, 85, 1, 114, 85, 1, 100, 85, 1, 86, 85, 1, 18, 85, 34, 85, 50, 85, 3, 4, 85, 1, 226, 85, 242, 85, 2, 212, 85, 1, 182, 85, 198, 85, 2, 146, 85, 1, 132, 85, 1, 102, 85, 118, 85, 2, 80, 85, 1, 66, 85, 1, 52, 85, 1, 38, 85, 1, 2, 85, 1, 242, 85, 1, 228, 85, 1, 198, 85, 214, 85, 2, 164, 85, 180, 85, 2, 134, 85, 150, 85, 2, 98, 85, 1, 84, 85, 1, 38, 85, 54, 85, 70, 85, 3, 20, 85, 1, 6, 85, 1, 55, 194, 85, 210, 85, 2, 164, 85, 180, 85, 2, 150, 85, 1, 121, 85, 1, 102, 181, 85, 1, 73, 85, 1, 85, 184, 255, 128, 64, 91, 39, 42, 72, 246, 85, 1, 185, 85, 217, 85, 2, 162, 85, 1, 132, 85, 148, 85, 2, 102, 85, 118, 85, 2, 57, 85, 1, 32, 85, 1, 18, 85, 1, 1, 0, 85, 1, 224, 85, 240, 85, 2, 212, 85, 1, 171, 85, 187, 85, 2, 159, 85, 1, 80, 85, 96, 85, 112, 85, 3, 68, 85, 1, 27, 85, 1, 15, 85, 1, 7, 2, 79, 182, 34, 183, 69, 182, 24, 7, 22, 6, 49, 182, 15, 183, 59, 182, 5, 25, 21, 24, 0, 63, 63, 237, 244, 237, 63, 63, 237, 244, 237, 1, 95, 94, 93, 93, 93, 93, 93, 93, 93, 93, 113, 95, 113, 113, 113, 113, 113, 113, 113, 113, 43, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 95, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 47, 43, 43, 237, 244, 94, 93, 237, 16, 222, 43, 93, 237, 244, 93, 237, 17, 18, 57, 57, 47, 47, 94, 93, 93, 113, 56, 56, 17, 51, 95, 93, 17, 51, 93, 49, 48, 43, 43, 43, 43, 43, 43, 43, 43, 1, 20, 14, 2, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 30, 2, 1, 35, 1, 51, 37, 50, 30, 2, 21, 20, 14, 2, 35, 34, 46, 2, 53, 52, 62, 2, 1, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 1, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 6, 231, 56, 96, 129, 73, 75, 129, 95, 55, 55, 96, 131, 76, 72, 128, 95, 55, 251, 65, 206, 3, 152, 209, 251, 213, 72, 128, 96, 56, 56, 97, 130, 74, 73, 129, 95, 55, 54, 96, 131, 4, 196, 17, 34, 50, 34, 37, 53, 34, 17, 16, 35, 52, 36, 33, 51, 35, 18, 252, 15, 17, 34, 50, 34, 37, 54, 34, 17, 17, 35, 52, 36, 34, 51, 35, 17, 1, 176, 125, 172, 105, 46, 46, 105, 172, 125, 132, 173, 103, 41, 41, 103, 173, 253, 204, 5, 129, 16, 41, 102, 173, 132, 125, 172, 106, 46, 46, 105, 172, 126, 132, 173, 102, 41, 252, 31, 87, 114, 67, 27, 27, 68, 114, 86, 84, 111, 68, 28, 28, 67, 112, 2, 117, 86, 113, 67, 27, 28, 67, 113, 85, 84, 112, 68, 29, 28, 68, 113, 0, 3, 0, 90, 255, 236, 5, 135, 5, 137, 0, 56, 0, 70, 0, 84, 0, 197, 64, 31, 46, 24, 9, 10, 0, 76, 71, 40, 9, 10, 0, 76, 73, 24, 9, 10, 0, 76, 27, 24, 9, 10, 0, 76, 6, 40, 9, 10, 0, 76, 16, 184, 255, 232, 64, 45, 9, 10, 0, 76, 10, 24, 9, 10, 0, 76, 63, 73, 8, 57, 73, 18, 29, 73, 30, 47, 26, 71, 23, 66, 74, 5, 7, 8, 33, 18, 30, 30, 64, 11, 14, 72, 47, 18, 79, 18, 2, 48, 8, 1, 8, 184, 255, 192, 64, 14, 14, 24, 72, 8, 18, 30, 30, 18, 8, 3, 0, 39, 86, 77, 184, 1, 18, 64, 35, 48, 0, 1, 0, 74, 23, 5, 66, 4, 13, 36, 82, 79, 52, 47, 71, 33, 26, 4, 52, 95, 29, 111, 29, 2, 29, 29, 13, 42, 52, 22, 60, 82, 13, 4, 0, 63, 237, 63, 51, 18, 57, 47, 93, 18, 23, 57, 16, 237, 50, 17, 23, 57, 1, 47, 93, 237, 16, 206, 17, 23, 57, 47, 47, 47, 43, 93, 93, 43, 17, 18, 57, 17, 23, 57, 16, 237, 16, 237, 16, 237, 49, 48, 43, 43, 43, 43, 43, 43, 43, 19, 52, 62, 2, 55, 46, 1, 53, 52, 62, 2, 51, 50, 30, 2, 21, 20, 14, 2, 7, 30, 1, 23, 62, 1, 55, 23, 14, 1, 7, 30, 1, 51, 50, 54, 55, 21, 6, 35, 34, 46, 2, 39, 14, 3, 35, 34, 46, 2, 1, 52, 38, 35, 34, 6, 21, 20, 22, 23, 62, 3, 3, 46, 1, 39, 14, 1, 21, 20, 30, 2, 51, 50, 54, 90, 51, 90, 124, 73, 32, 42, 40, 90, 144, 103, 81, 133, 96, 53, 66, 109, 142, 75, 51, 122, 71, 56, 76, 26, 209, 34, 94, 65, 45, 90, 43, 32, 59, 26, 55, 76, 51, 94, 84, 72, 29, 33, 81, 95, 109, 61, 126, 184, 118, 57, 3, 12, 76, 65, 77, 81, 31, 23, 51, 90, 66, 38, 82, 77, 138, 57, 83, 89, 31, 60, 91, 60, 65, 105, 1, 129, 79, 128, 104, 83, 34, 65, 148, 66, 66, 118, 89, 52, 39, 76, 110, 72, 73, 113, 91, 75, 35, 90, 167, 79, 85, 179, 99, 70, 117, 206, 97, 38, 35, 8, 8, 203, 22, 20, 33, 44, 24, 25, 47, 36, 21, 62, 108, 148, 3, 52, 57, 72, 86, 71, 48, 100, 45, 22, 45, 53, 62, 252, 191, 86, 188, 103, 39, 114, 81, 46, 80, 59, 34, 48, 0, 1, 0, 109, 3, 130, 1, 125, 5, 129, 0, 3, 0, 54, 64, 13, 3, 152, 128, 2, 144, 2, 160, 2, 3, 144, 2, 1, 2, 184, 255, 192, 179, 28, 31, 72, 2, 184, 255, 192, 64, 11, 11, 14, 72, 2, 2, 4, 5, 0, 169, 2, 3, 0, 63, 237, 17, 18, 1, 57, 47, 43, 43, 93, 113, 237, 49, 48, 1, 35, 3, 33, 1, 98, 219, 26, 1, 16, 3, 130, 1, 255, 0, 0, 0, 1, 0, 102, 254, 87, 2, 168, 5, 204, 0, 21, 0, 46, 64, 16, 0, 241, 21, 10, 241, 96, 11, 1, 112, 11, 1, 11, 11, 16, 241, 5, 184, 255, 192, 183, 10, 13, 72, 5, 10, 0, 0, 27, 0, 63, 63, 1, 47, 43, 237, 51, 47, 93, 113, 237, 212, 237, 49, 48, 1, 46, 3, 53, 52, 62, 2, 55, 33, 14, 3, 21, 20, 30, 2, 23, 1, 143, 77, 112, 73, 35, 35, 73, 112, 77, 1, 25, 80, 114, 73, 34, 34, 73, 114, 80, 254, 87, 111, 220, 232, 251, 142, 143, 249, 231, 219, 111, 116, 226, 232, 245, 135, 136, 245, 232, 225, 117, 0, 0, 0, 1, 0, 2, 254, 87, 2, 68, 5, 204, 0, 21, 0, 63, 64, 41, 21, 241, 0, 11, 241, 111, 10, 1, 127, 10, 1, 10, 10, 16, 241, 96, 5, 144, 5, 2, 79, 5, 1, 239, 5, 1, 48, 5, 160, 5, 2, 15, 5, 31, 5, 2, 5, 10, 0, 0, 27, 0, 63, 63, 1, 47, 93, 93, 93, 113, 113, 237, 50, 47, 93, 113, 237, 212, 237, 49, 48, 19, 62, 3, 53, 52, 46, 2, 39, 33, 30, 3, 21, 20, 14, 2, 7, 2, 80, 114, 73, 34, 34, 73, 114, 80, 1, 25, 77, 112, 73, 35, 35, 73, 112, 77, 254, 87, 117, 225, 232, 245, 136, 135, 245, 232, 226, 116, 111, 219, 231, 249, 143, 142, 251, 232, 220, 111, 0, 0, 0, 1, 0, 6, 2, 135, 3, 27, 5, 129, 0, 14, 0, 75, 64, 43, 8, 11, 4, 1, 1, 3, 14, 6, 13, 9, 11, 7, 2, 10, 0, 2, 16, 2, 2, 2, 4, 8, 3, 9, 2, 10, 1, 11, 11, 10, 9, 6, 8, 5, 13, 7, 0, 5, 1, 5, 5, 13, 3, 0, 63, 51, 47, 93, 51, 18, 23, 57, 17, 51, 17, 51, 17, 51, 17, 51, 1, 47, 93, 47, 18, 23, 57, 17, 51, 17, 51, 49, 48, 1, 55, 23, 7, 23, 7, 39, 7, 39, 55, 39, 55, 23, 3, 51, 1, 236, 235, 68, 250, 186, 184, 146, 149, 186, 190, 250, 68, 239, 18, 215, 4, 111, 104, 197, 61, 213, 121, 252, 252, 123, 211, 61, 197, 104, 1, 18, 0, 1, 0, 86, 0, 161, 4, 89, 4, 177, 0, 11, 0, 81, 64, 44, 11, 14, 1, 4, 2, 14, 15, 4, 31, 4, 2, 18, 3, 4, 9, 1, 170, 64, 6, 2, 2, 12, 13, 2, 14, 4, 7, 5, 14, 48, 7, 1, 144, 7, 160, 7, 2, 7, 0, 4, 173, 9, 5, 178, 0, 63, 51, 237, 50, 198, 93, 113, 43, 0, 24, 16, 77, 230, 17, 18, 1, 57, 47, 51, 26, 237, 50, 198, 95, 94, 93, 43, 1, 24, 16, 77, 230, 49, 48, 1, 17, 35, 17, 33, 53, 33, 17, 51, 17, 33, 21, 2, 199, 226, 254, 113, 1, 143, 226, 1, 146, 2, 57, 254, 104, 1, 152, 224, 1, 152, 254, 104, 224, 0, 0, 0, 0, 1, 0, 139, 254, 195, 1, 176, 1, 49, 0, 14, 0, 34, 64, 18, 5, 6, 12, 11, 151, 0, 150, 32, 12, 48, 12, 2, 12, 13, 155, 6, 168, 12, 0, 47, 230, 237, 1, 47, 93, 253, 237, 16, 198, 50, 49, 48, 37, 20, 14, 2, 7, 35, 62, 3, 53, 35, 17, 33, 1, 176, 15, 28, 40, 25, 185, 29, 48, 36, 20, 129, 1, 33, 66, 67, 110, 93, 78, 35, 35, 78, 82, 82, 40, 1, 49, 0, 0, 1, 0, 80, 1, 153, 2, 88, 2, 141, 0, 3, 0, 15, 181, 2, 0, 0, 186, 1, 188, 0, 63, 237, 1, 47, 47, 49, 48, 19, 53, 33, 21, 80, 2, 8, 1, 153, 244, 244, 0, 1, 0, 139, 0, 0, 1, 172, 1, 49, 0, 3, 0, 28, 64, 14, 3, 150, 32, 0, 48, 0, 2, 0, 0, 5, 4, 1, 155, 0, 0, 47, 237, 17, 18, 1, 57, 47, 93, 237, 49, 48, 51, 17, 33, 17, 139, 1, 33, 1, 49, 254, 207, 0, 0, 0, 0, 1, 0, 20, 255, 215, 2, 37, 5, 204, 0, 3, 0, 48, 185, 0, 3, 255, 240, 64, 18, 10, 0, 77, 1, 8, 9, 10, 0, 76, 1, 2, 16, 16, 2, 1, 2, 3, 0, 184, 255, 240, 179, 0, 1, 0, 0, 0, 47, 63, 1, 47, 56, 50, 47, 93, 56, 51, 49, 48, 43, 43, 23, 1, 51, 1, 20, 1, 35, 238, 254, 226, 41, 5, 245, 250, 11, 0, 0, 0, 0, 2, 0, 81, 255, 236, 4, 31, 5, 150, 0, 19, 0, 39, 0, 38, 64, 21, 20, 110, 207, 0, 1, 0, 41, 30, 110, 64, 10, 1, 10, 25, 115, 15, 7, 35, 115, 5, 25, 0, 63, 237, 63, 237, 1, 47, 93, 237, 16, 222, 113, 237, 49, 48, 1, 20, 2, 14, 1, 35, 34, 46, 1, 2, 53, 52, 18, 62, 1, 51, 50, 30, 1, 18, 5, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 4, 31, 74, 131, 179, 106, 106, 178, 128, 72, 71, 130, 181, 110, 103, 177, 129, 73, 254, 230, 22, 48, 77, 55, 59, 80, 49, 21, 22, 48, 78, 57, 55, 78, 50, 23, 2, 193, 202, 254, 235, 171, 75, 74, 171, 1, 21, 203, 213, 1, 23, 166, 67, 67, 166, 254, 233, 213, 149, 195, 115, 46, 47, 116, 195, 147, 145, 194, 117, 48, 48, 117, 194, 0, 0, 1, 0, 129, 0, 0, 4, 58, 5, 129, 0, 10, 0, 83, 64, 31, 36, 5, 52, 5, 68, 5, 3, 43, 3, 59, 3, 75, 3, 3, 9, 9, 8, 110, 2, 4, 15, 1, 111, 1, 207, 1, 3, 1, 1, 6, 2, 184, 255, 192, 64, 17, 10, 13, 72, 2, 2, 11, 12, 5, 4, 3, 6, 6, 8, 1, 116, 0, 24, 0, 63, 237, 50, 63, 51, 205, 50, 17, 18, 1, 57, 47, 43, 51, 51, 47, 93, 51, 16, 237, 50, 47, 49, 48, 0, 93, 93, 51, 53, 33, 17, 5, 53, 37, 33, 17, 33, 21, 129, 1, 93, 254, 174, 1, 97, 1, 10, 1, 67, 209, 3, 193, 211, 221, 229, 251, 80, 209, 0, 1, 0, 71, 0, 0, 4, 33, 5, 150, 0, 34, 0, 55, 64, 29, 8, 111, 25, 25, 33, 36, 14, 110, 15, 15, 32, 112, 95, 0, 1, 0, 8, 0, 20, 14, 14, 11, 115, 20, 7, 32, 115, 0, 24, 0, 63, 237, 63, 237, 51, 47, 17, 18, 57, 1, 47, 93, 237, 51, 47, 237, 16, 206, 50, 47, 237, 49, 48, 51, 53, 62, 5, 53, 52, 38, 35, 34, 6, 7, 37, 62, 3, 51, 50, 30, 2, 21, 20, 14, 4, 7, 33, 21, 71, 48, 138, 151, 149, 119, 74, 94, 91, 90, 95, 14, 254, 229, 10, 62, 115, 173, 120, 114, 176, 120, 62, 78, 122, 149, 140, 115, 28, 2, 142, 195, 105, 169, 141, 121, 113, 114, 64, 94, 90, 97, 97, 16, 83, 146, 110, 63, 53, 102, 147, 94, 99, 160, 135, 118, 112, 114, 65, 231, 0, 0, 0, 1, 0, 47, 255, 233, 4, 41, 5, 150, 0, 59, 0, 117, 64, 75, 38, 110, 39, 55, 26, 32, 111, 49, 39, 26, 49, 49, 26, 39, 3, 10, 19, 111, 0, 61, 11, 111, 10, 64, 14, 21, 72, 10, 54, 25, 115, 26, 26, 16, 44, 79, 38, 159, 38, 2, 38, 38, 35, 115, 44, 7, 16, 115, 5, 32, 11, 96, 11, 112, 11, 176, 11, 192, 11, 5, 48, 11, 64, 11, 128, 11, 144, 11, 208, 11, 5, 11, 11, 5, 25, 0, 63, 51, 47, 93, 113, 16, 237, 63, 237, 51, 47, 93, 17, 18, 57, 47, 237, 57, 1, 47, 43, 237, 16, 222, 237, 18, 23, 57, 47, 47, 47, 16, 237, 18, 57, 16, 237, 49, 48, 1, 20, 14, 2, 35, 34, 46, 2, 39, 37, 30, 3, 51, 50, 54, 53, 52, 46, 2, 43, 1, 53, 51, 50, 62, 2, 53, 52, 38, 35, 34, 6, 7, 37, 62, 3, 51, 50, 30, 2, 21, 20, 14, 2, 7, 21, 30, 3, 4, 41, 63, 126, 187, 124, 138, 189, 121, 61, 9, 1, 30, 6, 33, 56, 81, 55, 101, 112, 53, 81, 94, 42, 98, 92, 42, 87, 70, 44, 97, 93, 87, 107, 8, 254, 231, 12, 85, 129, 168, 94, 124, 178, 114, 54, 36, 73, 114, 78, 87, 128, 82, 40, 1, 135, 96, 153, 108, 57, 70, 115, 146, 75, 25, 45, 75, 54, 29, 100, 103, 63, 76, 41, 14, 227, 16, 42, 75, 58, 87, 99, 96, 88, 20, 99, 146, 96, 47, 60, 102, 136, 77, 62, 107, 85, 61, 15, 4, 10, 59, 88, 111, 0, 0, 0, 2, 0, 31, 0, 0, 4, 104, 5, 129, 0, 10, 0, 23, 0, 118, 64, 58, 22, 63, 5, 111, 5, 2, 15, 5, 31, 5, 63, 5, 79, 5, 111, 5, 143, 5, 159, 5, 175, 5, 207, 5, 223, 5, 255, 5, 11, 63, 5, 79, 5, 111, 5, 255, 5, 4, 5, 64, 18, 22, 72, 5, 5, 10, 8, 1, 110, 23, 6, 128, 2, 1, 144, 2, 1, 2, 184, 255, 192, 64, 20, 10, 15, 72, 2, 2, 24, 25, 0, 4, 116, 8, 5, 22, 22, 1, 16, 6, 6, 1, 24, 0, 63, 63, 51, 18, 57, 47, 51, 51, 237, 50, 17, 18, 1, 57, 47, 43, 93, 113, 51, 51, 237, 50, 50, 51, 47, 43, 93, 113, 114, 51, 49, 48, 1, 17, 33, 17, 33, 53, 1, 33, 17, 51, 21, 1, 52, 62, 2, 55, 14, 3, 7, 1, 33, 3, 172, 254, 244, 253, 127, 2, 83, 1, 58, 188, 254, 56, 1, 3, 3, 2, 5, 22, 27, 29, 11, 254, 185, 1, 156, 1, 31, 254, 225, 1, 31, 211, 3, 143, 252, 111, 209, 2, 158, 17, 55, 58, 53, 15, 11, 41, 47, 46, 17, 254, 15, 0, 0, 1, 0, 63, 255, 236, 4, 58, 5, 129, 0, 40, 0, 130, 185, 0, 33, 255, 224, 181, 10, 0, 77, 32, 33, 33, 184, 255, 224, 64, 15, 16, 25, 72, 29, 27, 33, 3, 28, 31, 28, 31, 10, 19, 111, 0, 184, 255, 192, 64, 52, 38, 53, 72, 0, 42, 11, 110, 95, 10, 111, 10, 2, 10, 28, 28, 24, 115, 143, 36, 223, 36, 2, 239, 36, 1, 36, 36, 16, 32, 116, 29, 6, 16, 115, 5, 63, 11, 143, 11, 223, 11, 3, 239, 11, 1, 64, 11, 1, 11, 11, 5, 25, 0, 63, 51, 47, 93, 93, 113, 16, 237, 63, 237, 18, 57, 47, 93, 113, 237, 51, 47, 1, 47, 93, 237, 16, 222, 43, 237, 18, 57, 57, 47, 47, 23, 51, 43, 17, 51, 49, 48, 0, 43, 1, 20, 14, 2, 35, 34, 46, 2, 39, 37, 30, 3, 51, 50, 54, 53, 52, 46, 2, 35, 34, 6, 7, 33, 19, 33, 21, 33, 3, 62, 1, 51, 50, 30, 2, 4, 58, 67, 132, 195, 128, 118, 176, 121, 69, 13, 1, 25, 8, 29, 52, 76, 54, 105, 125, 31, 57, 83, 53, 70, 90, 31, 254, 238, 49, 3, 79, 253, 176, 23, 42, 128, 85, 104, 164, 114, 60, 1, 213, 106, 179, 131, 73, 57, 101, 136, 78, 23, 33, 62, 48, 29, 134, 126, 56, 90, 64, 34, 53, 38, 3, 25, 209, 254, 156, 37, 53, 68, 122, 171, 0, 0, 0, 2, 0, 75, 255, 236, 4, 41, 5, 150, 0, 30, 0, 48, 0, 105, 185, 0, 21, 255, 248, 64, 11, 10, 0, 77, 17, 110, 16, 16, 8, 31, 110, 0, 184, 255, 192, 64, 49, 38, 41, 72, 0, 50, 23, 41, 111, 223, 8, 239, 8, 255, 8, 3, 8, 36, 116, 23, 16, 26, 1, 223, 26, 239, 26, 2, 80, 26, 96, 26, 2, 26, 26, 46, 20, 115, 11, 80, 17, 1, 17, 17, 11, 7, 46, 115, 5, 25, 0, 63, 237, 63, 51, 47, 93, 16, 237, 18, 57, 47, 93, 93, 113, 51, 237, 1, 47, 113, 237, 50, 16, 222, 43, 237, 18, 57, 47, 237, 49, 48, 43, 1, 20, 14, 2, 35, 34, 0, 17, 16, 0, 51, 50, 30, 2, 23, 5, 46, 1, 35, 34, 6, 21, 62, 1, 51, 50, 30, 2, 5, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 54, 4, 41, 60, 119, 178, 117, 249, 254, 245, 1, 15, 252, 84, 138, 108, 76, 23, 254, 247, 20, 90, 60, 113, 129, 45, 160, 101, 93, 151, 107, 58, 254, 230, 26, 53, 78, 51, 37, 74, 58, 36, 30, 55, 78, 49, 95, 106, 1, 205, 106, 177, 127, 71, 1, 93, 1, 87, 1, 121, 1, 125, 35, 78, 123, 88, 37, 74, 65, 226, 230, 75, 80, 61, 115, 166, 112, 57, 91, 64, 35, 24, 53, 82, 58, 60, 104, 77, 43, 135, 0, 0, 0, 0, 1, 0, 88, 0, 0, 4, 25, 5, 129, 0, 14, 0, 46, 64, 26, 10, 24, 10, 0, 77, 5, 111, 6, 6, 12, 11, 0, 16, 48, 12, 64, 12, 2, 12, 0, 12, 115, 13, 6, 5, 24, 0, 63, 63, 237, 50, 1, 47, 93, 16, 206, 50, 17, 57, 47, 237, 49, 48, 43, 1, 6, 10, 2, 21, 33, 52, 26, 2, 55, 33, 53, 33, 4, 25, 95, 169, 126, 73, 254, 219, 79, 136, 180, 100, 253, 68, 3, 193, 4, 162, 150, 254, 230, 254, 227, 254, 211, 168, 167, 1, 45, 1, 30, 1, 23, 145, 231, 0, 3, 0, 65, 255, 236, 4, 52, 5, 150, 0, 41, 0, 61, 0, 81, 0, 101, 64, 24, 15, 21, 62, 111, 0, 52, 111, 21, 36, 72, 42, 111, 31, 95, 31, 111, 31, 2, 21, 31, 21, 31, 10, 0, 184, 255, 192, 64, 33, 38, 47, 72, 0, 83, 72, 111, 95, 10, 111, 10, 2, 10, 64, 38, 47, 72, 10, 36, 15, 67, 117, 57, 57, 77, 47, 117, 26, 7, 77, 117, 5, 25, 0, 63, 237, 63, 237, 18, 57, 47, 237, 57, 57, 1, 47, 43, 93, 237, 16, 206, 43, 17, 57, 57, 47, 47, 113, 16, 237, 18, 57, 16, 237, 16, 237, 17, 57, 49, 48, 1, 20, 14, 2, 35, 34, 46, 2, 53, 52, 62, 2, 55, 53, 46, 3, 53, 52, 62, 2, 51, 50, 30, 2, 21, 20, 14, 2, 7, 21, 30, 3, 1, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 19, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 4, 52, 60, 124, 190, 131, 130, 191, 125, 60, 48, 80, 104, 55, 59, 94, 66, 35, 61, 118, 175, 115, 123, 179, 116, 56, 35, 66, 95, 60, 62, 107, 78, 44, 254, 188, 18, 42, 71, 54, 52, 70, 42, 18, 15, 40, 72, 57, 60, 73, 38, 12, 33, 19, 49, 86, 66, 60, 81, 49, 21, 21, 51, 84, 63, 63, 82, 48, 19, 1, 141, 91, 153, 111, 62, 62, 111, 152, 90, 77, 119, 86, 51, 9, 4, 13, 60, 84, 103, 56, 84, 138, 98, 53, 55, 99, 138, 83, 55, 103, 84, 58, 12, 4, 10, 53, 85, 119, 2, 56, 42, 71, 51, 29, 29, 51, 71, 42, 37, 72, 57, 36, 36, 58, 72, 253, 184, 43, 80, 61, 37, 37, 62, 81, 45, 53, 88, 63, 34, 35, 64, 89, 0, 0, 0, 0, 2, 0, 71, 255, 236, 4, 39, 5, 150, 0, 36, 0, 56, 0, 98, 64, 62, 14, 8, 10, 0, 77, 17, 37, 111, 0, 9, 110, 8, 8, 27, 208, 0, 224, 0, 240, 0, 3, 0, 58, 47, 111, 95, 27, 1, 27, 64, 38, 41, 72, 27, 52, 116, 17, 111, 22, 1, 15, 22, 31, 22, 2, 22, 22, 12, 42, 115, 32, 7, 12, 115, 3, 0, 9, 1, 9, 9, 3, 25, 0, 63, 51, 47, 113, 16, 237, 63, 237, 18, 57, 47, 93, 113, 51, 237, 1, 47, 43, 93, 237, 16, 206, 113, 17, 57, 47, 237, 16, 237, 50, 49, 48, 43, 1, 16, 0, 35, 34, 46, 2, 39, 37, 30, 1, 51, 50, 62, 2, 55, 14, 3, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 30, 1, 18, 37, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 4, 39, 254, 238, 252, 91, 145, 108, 75, 22, 1, 8, 20, 91, 69, 57, 90, 64, 35, 1, 20, 66, 83, 94, 48, 92, 150, 106, 57, 67, 126, 183, 116, 122, 187, 126, 65, 254, 215, 27, 54, 78, 51, 47, 74, 52, 27, 26, 50, 76, 49, 39, 75, 59, 36, 2, 215, 254, 137, 254, 140, 38, 80, 126, 87, 37, 75, 72, 54, 110, 169, 115, 39, 60, 40, 21, 65, 122, 173, 109, 112, 176, 121, 63, 83, 173, 254, 247, 15, 60, 105, 77, 44, 35, 66, 94, 59, 55, 95, 69, 39, 28, 56, 85, 0, 0, 0, 0, 2, 0, 197, 0, 0, 1, 229, 4, 10, 0, 3, 0, 7, 1, 127, 64, 255, 3, 7, 150, 0, 0, 4, 16, 4, 2, 11, 4, 80, 9, 96, 9, 2, 15, 9, 31, 9, 2, 192, 9, 208, 9, 224, 9, 3, 79, 9, 95, 9, 2, 0, 9, 48, 9, 2, 206, 223, 9, 239, 9, 255, 9, 3, 160, 9, 176, 9, 192, 9, 3, 63, 9, 111, 9, 2, 16, 9, 32, 9, 2, 224, 9, 1, 159, 9, 175, 9, 2, 80, 9, 96, 9, 128, 9, 3, 15, 9, 31, 9, 2, 239, 9, 1, 192, 9, 208, 9, 2, 79, 9, 95, 9, 2, 0, 9, 16, 9, 48, 9, 3, 155, 223, 9, 239, 9, 255, 9, 3, 160, 9, 176, 9, 192, 9, 3, 63, 9, 111, 9, 2, 16, 9, 32, 9, 2, 224, 9, 1, 143, 9, 159, 9, 175, 9, 3, 80, 9, 96, 9, 2, 9, 64, 118, 121, 72, 192, 9, 208, 9, 2, 79, 9, 95, 9, 143, 9, 3, 0, 9, 48, 9, 2, 104, 175, 9, 191, 9, 207, 9, 3, 112, 9, 128, 9, 144, 9, 3, 15, 9, 63, 9, 2, 255, 9, 1, 224, 9, 1, 95, 9, 111, 9, 127, 9, 3, 32, 9, 48, 9, 2, 191, 9, 223, 9, 239, 9, 3, 144, 9, 160, 9, 2, 31, 9, 47, 9, 2, 0, 9, 1, 56, 224, 9, 240, 9, 2, 9, 64, 46, 49, 72, 80, 9, 96, 9, 2, 31, 9, 1, 223, 9, 239, 9, 2, 144, 9, 192, 9, 2, 63, 9, 79, 64, 53, 9, 95, 9, 3, 0, 9, 16, 9, 32, 9, 3, 159, 9, 191, 9, 207, 9, 3, 64, 9, 80, 9, 112, 9, 128, 9, 4, 15, 9, 1, 7, 0, 156, 63, 1, 95, 1, 127, 1, 159, 1, 191, 1, 5, 1, 64, 22, 34, 72, 1, 5, 156, 4, 0, 47, 237, 47, 43, 93, 237, 1, 94, 93, 93, 93, 113, 113, 113, 113, 114, 114, 43, 114, 94, 93, 93, 93, 93, 113, 113, 113, 113, 114, 114, 114, 94, 93, 93, 93, 43, 113, 113, 113, 114, 114, 114, 114, 94, 93, 93, 93, 93, 113, 113, 113, 113, 114, 114, 114, 114, 94, 93, 93, 93, 113, 113, 47, 94, 93, 196, 253, 196, 49, 48, 19, 17, 33, 17, 1, 17, 33, 17, 197, 1, 32, 254, 224, 1, 32, 2, 240, 1, 26, 254, 230, 253, 16, 1, 25, 254, 231, 0, 0, 0, 2, 0, 195, 254, 195, 1, 231, 4, 10, 0, 3, 0, 18, 1, 142, 64, 255, 2, 150, 1, 9, 10, 16, 15, 151, 4, 150, 1, 0, 16, 16, 16, 2, 11, 16, 80, 20, 96, 20, 2, 15, 20, 31, 20, 2, 192, 20, 208, 20, 224, 20, 3, 79, 20, 95, 20, 2, 0, 20, 48, 20, 2, 206, 223, 20, 239, 20, 255, 20, 3, 160, 20, 176, 20, 192, 20, 3, 63, 20, 111, 20, 2, 16, 20, 32, 20, 2, 224, 20, 1, 159, 20, 175, 20, 2, 80, 20, 96, 20, 128, 20, 3, 15, 20, 31, 20, 2, 239, 20, 1, 192, 20, 208, 20, 2, 79, 20, 95, 20, 2, 0, 20, 16, 20, 48, 20, 3, 155, 223, 20, 239, 20, 255, 20, 3, 160, 20, 176, 20, 192, 20, 3, 63, 20, 111, 20, 2, 16, 20, 32, 20, 2, 224, 20, 1, 143, 20, 159, 20, 175, 20, 3, 80, 20, 96, 20, 2, 20, 64, 118, 121, 72, 192, 20, 208, 20, 2, 79, 20, 95, 20, 143, 20, 3, 0, 20, 48, 20, 2, 104, 175, 20, 191, 20, 207, 20, 3, 112, 20, 128, 20, 144, 20, 3, 15, 20, 63, 20, 2, 255, 20, 1, 224, 20, 1, 95, 20, 111, 20, 127, 20, 3, 32, 20, 48, 20, 2, 191, 20, 223, 20, 239, 20, 3, 144, 20, 160, 20, 2, 31, 20, 47, 20, 2, 0, 20, 1, 56, 224, 20, 240, 20, 2, 20, 64, 46, 49, 72, 80, 20, 96, 20, 2, 31, 20, 1, 223, 20, 239, 20, 2, 144, 64, 62, 20, 192, 20, 2, 63, 20, 79, 20, 95, 20, 3, 0, 20, 16, 20, 32, 20, 3, 159, 20, 191, 20, 207, 20, 3, 64, 20, 80, 20, 112, 20, 128, 20, 4, 15, 20, 1, 7, 0, 156, 63, 1, 95, 1, 127, 1, 159, 1, 191, 1, 5, 1, 64, 22, 34, 72, 1, 17, 156, 10, 168, 16, 0, 47, 230, 237, 47, 43, 93, 237, 1, 94, 93, 93, 93, 113, 113, 113, 113, 114, 114, 43, 114, 94, 93, 93, 93, 93, 113, 113, 113, 113, 114, 114, 114, 94, 93, 93, 93, 43, 113, 113, 113, 114, 114, 114, 114, 94, 93, 93, 93, 93, 113, 113, 113, 113, 114, 114, 114, 114, 94, 93, 93, 93, 113, 113, 47, 94, 93, 196, 253, 237, 16, 198, 50, 16, 237, 49, 48, 19, 17, 33, 25, 1, 20, 14, 2, 7, 35, 62, 3, 53, 35, 17, 33, 199, 1, 32, 15, 28, 40, 25, 184, 28, 49, 36, 20, 129, 1, 32, 2, 240, 1, 26, 254, 230, 253, 82, 67, 110, 93, 78, 35, 35, 78, 82, 82, 40, 1, 25, 0, 0, 0, 0, 1, 0, 86, 0, 125, 4, 89, 4, 205, 0, 6, 0, 104, 64, 56, 0, 1, 82, 5, 4, 5, 176, 6, 0, 20, 6, 0, 5, 6, 1, 2, 1, 82, 3, 4, 1, 4, 3, 176, 2, 1, 20, 2, 1, 3, 2, 6, 8, 4, 0, 1, 0, 4, 4, 2, 5, 63, 6, 1, 6, 3, 95, 2, 1, 32, 2, 1, 15, 2, 1, 2, 0, 47, 93, 93, 93, 51, 47, 93, 51, 18, 57, 61, 47, 51, 51, 1, 24, 47, 51, 16, 222, 212, 193, 135, 4, 43, 16, 1, 193, 135, 4, 43, 16, 196, 16, 1, 193, 135, 4, 24, 43, 135, 43, 196, 49, 48, 19, 17, 1, 21, 9, 1, 21, 86, 4, 3, 252, 191, 3, 65, 2, 4, 1, 66, 1, 135, 228, 254, 187, 254, 188, 227, 0, 2, 0, 85, 1, 35, 4, 88, 4, 41, 0, 3, 0, 7, 0, 72, 64, 51, 7, 2, 9, 4, 64, 1, 1, 1, 5, 173, 223, 4, 1, 15, 4, 31, 4, 63, 4, 79, 4, 143, 4, 5, 4, 64, 20, 25, 72, 4, 0, 173, 48, 1, 112, 1, 2, 32, 1, 64, 1, 96, 1, 112, 1, 160, 1, 192, 1, 6, 1, 0, 47, 93, 113, 237, 47, 43, 93, 113, 237, 1, 47, 93, 51, 16, 206, 50, 49, 48, 19, 53, 33, 21, 1, 53, 33, 21, 85, 4, 3, 251, 253, 4, 3, 3, 74, 223, 223, 253, 217, 221, 221, 0, 0, 1, 0, 86, 0, 125, 4, 89, 4, 205, 0, 6, 0, 104, 64, 56, 6, 1, 82, 1, 2, 1, 176, 0, 6, 20, 0, 6, 1, 0, 5, 4, 1, 82, 3, 2, 5, 2, 3, 176, 4, 5, 20, 4, 5, 3, 4, 2, 6, 8, 4, 0, 6, 5, 2, 2, 3, 95, 4, 1, 32, 4, 1, 15, 4, 1, 4, 1, 63, 0, 1, 0, 0, 47, 93, 50, 47, 93, 93, 93, 51, 57, 61, 47, 51, 51, 1, 24, 47, 196, 16, 206, 50, 16, 193, 135, 4, 43, 16, 1, 193, 135, 4, 43, 16, 196, 16, 1, 193, 135, 4, 24, 43, 135, 43, 196, 49, 48, 55, 53, 9, 1, 53, 1, 17, 86, 3, 64, 252, 192, 4, 3, 125, 227, 1, 68, 1, 69, 228, 254, 121, 254, 190, 0, 0, 2, 0, 94, 0, 0, 4, 109, 5, 150, 0, 35, 0, 39, 0, 66, 64, 31, 9, 39, 150, 10, 36, 36, 26, 17, 150, 0, 41, 25, 150, 32, 26, 48, 26, 2, 26, 17, 31, 10, 10, 31, 37, 157, 36, 21, 25, 25, 20, 184, 1, 21, 177, 31, 4, 0, 63, 237, 51, 47, 63, 237, 17, 57, 47, 18, 57, 1, 47, 93, 237, 16, 222, 237, 17, 57, 47, 51, 237, 50, 49, 48, 1, 20, 14, 6, 7, 33, 62, 5, 53, 52, 38, 35, 34, 14, 2, 7, 37, 62, 3, 51, 50, 30, 2, 1, 17, 33, 17, 4, 109, 35, 58, 74, 78, 75, 60, 38, 2, 254, 245, 5, 63, 90, 102, 87, 57, 115, 106, 51, 86, 65, 42, 6, 254, 227, 12, 75, 130, 189, 125, 120, 188, 131, 69, 253, 73, 1, 33, 4, 2, 66, 100, 79, 63, 56, 54, 61, 73, 48, 85, 121, 90, 71, 74, 87, 60, 88, 102, 31, 56, 80, 48, 12, 89, 156, 116, 68, 56, 105, 150, 251, 161, 1, 14, 254, 242, 0, 0, 2, 0, 117, 254, 188, 7, 86, 5, 174, 0, 95, 0, 120, 0, 208, 64, 23, 44, 24, 10, 0, 77, 7, 24, 9, 0, 77, 8, 40, 9, 10, 0, 76, 8, 40, 9, 10, 0, 76, 35, 184, 255, 232, 179, 9, 0, 77, 114, 184, 255, 232, 64, 33, 9, 0, 77, 21, 24, 9, 10, 0, 76, 72, 72, 10, 0, 108, 210, 24, 35, 39, 212, 10, 96, 34, 10, 24, 10, 24, 10, 84, 47, 210, 0, 122, 59, 184, 255, 232, 182, 9, 10, 0, 76, 59, 210, 84, 184, 255, 192, 64, 56, 9, 12, 72, 84, 71, 71, 77, 42, 111, 213, 19, 5, 19, 101, 213, 34, 29, 33, 29, 175, 19, 191, 19, 207, 19, 3, 0, 29, 1, 48, 29, 64, 29, 224, 29, 240, 29, 4, 19, 29, 19, 29, 66, 52, 16, 10, 0, 77, 52, 213, 91, 218, 66, 213, 77, 219, 0, 63, 237, 63, 237, 43, 18, 57, 57, 47, 47, 93, 113, 93, 17, 51, 16, 196, 237, 17, 51, 16, 237, 50, 18, 57, 47, 1, 47, 43, 237, 43, 16, 214, 237, 17, 57, 57, 47, 47, 17, 51, 51, 16, 237, 50, 16, 237, 17, 18, 57, 47, 49, 48, 0, 43, 43, 1, 43, 43, 0, 43, 1, 43, 43, 1, 20, 14, 2, 35, 34, 46, 2, 53, 52, 54, 55, 35, 14, 3, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 22, 23, 51, 55, 51, 3, 14, 1, 21, 20, 22, 51, 50, 62, 2, 53, 52, 46, 2, 35, 34, 14, 4, 21, 20, 30, 4, 51, 50, 62, 2, 55, 23, 14, 3, 35, 34, 46, 4, 53, 52, 18, 62, 2, 36, 51, 50, 4, 22, 18, 5, 52, 46, 2, 35, 34, 14, 4, 21, 20, 22, 51, 50, 62, 2, 55, 62, 3, 7, 86, 76, 131, 175, 99, 42, 71, 50, 28, 3, 3, 6, 21, 70, 91, 109, 59, 95, 127, 76, 32, 68, 128, 186, 118, 102, 130, 32, 6, 39, 156, 117, 17, 20, 47, 31, 59, 111, 88, 53, 82, 160, 236, 154, 133, 224, 181, 137, 93, 47, 34, 69, 105, 142, 181, 110, 86, 160, 147, 135, 61, 62, 60, 138, 162, 188, 110, 130, 220, 177, 134, 90, 45, 63, 119, 171, 217, 1, 3, 146, 203, 1, 41, 193, 93, 253, 121, 31, 56, 78, 48, 55, 92, 72, 54, 35, 18, 97, 100, 48, 95, 84, 69, 21, 5, 9, 7, 4, 2, 213, 144, 239, 172, 96, 21, 43, 65, 43, 14, 38, 15, 44, 86, 67, 42, 68, 110, 138, 69, 115, 220, 172, 105, 93, 81, 152, 254, 6, 79, 124, 37, 50, 42, 76, 136, 188, 112, 126, 216, 158, 90, 63, 114, 158, 189, 214, 114, 87, 163, 142, 118, 84, 47, 24, 42, 57, 32, 122, 34, 64, 49, 30, 57, 103, 144, 174, 200, 107, 139, 1, 0, 220, 180, 128, 70, 118, 200, 254, 248, 151, 47, 79, 57, 32, 41, 70, 93, 106, 112, 53, 114, 132, 46, 89, 131, 84, 18, 43, 42, 38, 0, 2, 0, 51, 0, 0, 5, 145, 5, 129, 0, 7, 0, 20, 2, 226, 64, 79, 19, 2, 3, 5, 1, 82, 3, 13, 3, 94, 4, 5, 20, 4, 5, 3, 4, 20, 1, 0, 6, 1, 82, 0, 13, 0, 94, 7, 6, 20, 7, 6, 13, 4, 7, 64, 19, 22, 72, 7, 7, 23, 7, 2, 11, 7, 22, 199, 22, 215, 22, 2, 152, 22, 1, 134, 22, 1, 7, 22, 23, 22, 39, 22, 87, 22, 119, 22, 5, 151, 22, 167, 22, 183, 22, 231, 22, 4, 22, 184, 255, 192, 64, 255, 202, 205, 72, 8, 22, 1, 200, 199, 22, 215, 22, 231, 22, 3, 152, 22, 1, 134, 22, 1, 119, 22, 1, 40, 22, 1, 7, 22, 23, 22, 2, 247, 22, 1, 200, 22, 1, 183, 22, 1, 166, 22, 1, 151, 22, 1, 120, 22, 1, 71, 22, 1, 183, 22, 231, 22, 2, 136, 22, 152, 22, 2, 103, 22, 119, 22, 2, 56, 22, 1, 23, 22, 1, 6, 22, 1, 152, 246, 22, 1, 212, 22, 228, 22, 2, 197, 22, 1, 182, 22, 1, 147, 22, 163, 22, 2, 132, 22, 1, 101, 22, 117, 22, 2, 84, 22, 1, 67, 22, 1, 36, 22, 52, 22, 2, 21, 22, 1, 6, 22, 1, 244, 22, 1, 229, 22, 1, 212, 22, 1, 181, 22, 197, 22, 2, 164, 22, 1, 149, 22, 1, 134, 22, 1, 100, 22, 116, 22, 2, 67, 22, 83, 22, 2, 52, 22, 1, 37, 22, 1, 22, 22, 1, 2, 22, 1, 243, 22, 1, 212, 22, 228, 22, 2, 197, 22, 1, 182, 22, 1, 147, 22, 163, 22, 2, 132, 22, 1, 117, 22, 1, 102, 22, 1, 84, 22, 1, 69, 22, 1, 36, 22, 52, 22, 2, 21, 22, 1, 4, 22, 1, 104, 229, 22, 245, 22, 2, 212, 22, 1, 197, 22, 1, 179, 22, 1, 0, 160, 22, 1, 146, 22, 1, 116, 22, 132, 22, 2, 98, 22, 1, 80, 22, 1, 50, 22, 66, 22, 2, 36, 22, 1, 22, 22, 1, 64, 215, 2, 22, 1, 240, 22, 1, 226, 22, 1, 196, 22, 212, 22, 2, 178, 22, 1, 164, 22, 1, 144, 22, 1, 130, 22, 1, 116, 22, 1, 82, 22, 98, 22, 2, 68, 22, 1, 54, 22, 1, 36, 22, 1, 16, 22, 1, 2, 22, 1, 228, 22, 244, 22, 2, 214, 22, 1, 196, 22, 1, 162, 22, 178, 22, 2, 148, 22, 1, 118, 22, 134, 22, 2, 100, 22, 1, 82, 22, 1, 52, 22, 68, 22, 2, 38, 22, 1, 20, 22, 1, 6, 22, 1, 56, 242, 22, 1, 228, 22, 1, 214, 22, 1, 194, 22, 1, 180, 22, 1, 166, 22, 1, 132, 22, 1, 118, 22, 1, 84, 22, 100, 22, 2, 38, 22, 70, 22, 2, 18, 22, 1, 1, 0, 22, 1, 196, 22, 244, 22, 2, 160, 22, 176, 22, 2, 100, 22, 116, 22, 148, 22, 3, 80, 22, 1, 20, 22, 52, 22, 68, 22, 3, 132, 22, 148, 22, 180, 22, 196, 22, 228, 22, 5, 112, 22, 1, 68, 22, 100, 22, 2, 16, 22, 1, 2, 0, 22, 1, 8, 176, 4, 192, 4, 208, 4, 3, 4, 7, 1, 2, 95, 20, 25, 13, 1, 13, 5, 19, 19, 6, 5, 3, 4, 0, 18, 0, 63, 50, 63, 51, 57, 47, 18, 57, 93, 51, 237, 50, 47, 1, 47, 93, 94, 93, 95, 93, 93, 93, 93, 113, 113, 113, 113, 113, 114, 95, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 95, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 94, 93, 43, 93, 113, 113, 113, 113, 16, 214, 94, 93, 43, 17, 57, 135, 43, 135, 43, 196, 16, 192, 192, 16, 0, 193, 135, 5, 24, 43, 135, 43, 196, 16, 192, 192, 49, 48, 33, 3, 33, 3, 33, 1, 33, 9, 1, 46, 3, 39, 14, 3, 7, 3, 33, 4, 109, 125, 253, 231, 125, 254, 217, 2, 2, 1, 92, 2, 0, 253, 146, 12, 23, 17, 11, 1, 1, 10, 17, 23, 12, 139, 1, 149, 1, 104, 254, 152, 5, 129, 250, 127, 3, 219, 35, 71, 59, 38, 2, 3, 38, 58, 71, 35, 254, 107, 0, 0, 0, 3, 0, 137, 0, 0, 5, 106, 5, 129, 0, 18, 0, 27, 0, 40, 0, 100, 64, 22, 16, 35, 19, 91, 95, 13, 111, 13, 2, 13, 13, 35, 28, 90, 0, 42, 32, 42, 48, 42, 2, 42, 184, 255, 192, 64, 39, 28, 35, 72, 24, 35, 90, 32, 6, 48, 6, 2, 6, 16, 34, 95, 16, 24, 1, 95, 24, 111, 24, 143, 24, 3, 239, 24, 1, 24, 24, 35, 23, 95, 7, 3, 35, 95, 6, 18, 0, 63, 237, 63, 237, 18, 57, 47, 93, 113, 114, 237, 57, 1, 47, 93, 237, 50, 43, 93, 16, 222, 237, 18, 57, 47, 93, 237, 18, 57, 49, 48, 1, 20, 14, 2, 35, 33, 17, 33, 50, 30, 2, 21, 20, 6, 7, 30, 1, 1, 52, 38, 35, 33, 17, 33, 50, 54, 19, 52, 46, 2, 35, 33, 17, 33, 50, 62, 2, 5, 106, 86, 149, 198, 111, 253, 63, 2, 133, 125, 195, 134, 69, 133, 136, 171, 179, 254, 134, 121, 119, 254, 176, 1, 82, 125, 113, 82, 44, 77, 103, 60, 254, 138, 1, 129, 58, 100, 73, 42, 1, 146, 107, 153, 97, 45, 5, 129, 43, 88, 133, 90, 120, 165, 29, 20, 175, 1, 213, 95, 80, 254, 163, 87, 254, 9, 56, 76, 46, 20, 254, 108, 19, 47, 80, 0, 0, 1, 0, 84, 255, 236, 5, 143, 5, 150, 0, 41, 0, 99, 185, 0, 40, 255, 248, 180, 9, 10, 0, 76, 34, 184, 255, 248, 64, 55, 9, 10, 0, 76, 27, 92, 26, 26, 5, 92, 6, 43, 48, 43, 1, 37, 91, 48, 16, 1, 15, 16, 31, 16, 2, 16, 32, 95, 21, 27, 27, 21, 4, 32, 5, 48, 5, 2, 32, 5, 96, 5, 160, 5, 224, 5, 240, 5, 5, 5, 5, 0, 95, 11, 19, 0, 63, 237, 51, 47, 93, 113, 63, 51, 47, 16, 237, 1, 47, 93, 93, 237, 93, 16, 222, 237, 51, 47, 237, 49, 48, 43, 43, 37, 50, 62, 2, 55, 5, 14, 3, 35, 34, 36, 38, 2, 53, 52, 18, 54, 36, 51, 50, 30, 2, 23, 5, 46, 3, 35, 34, 14, 2, 21, 20, 30, 2, 3, 27, 83, 121, 89, 59, 19, 1, 1, 31, 100, 150, 207, 140, 183, 254, 244, 175, 85, 85, 172, 1, 7, 178, 138, 207, 151, 99, 28, 254, 252, 14, 58, 89, 120, 76, 107, 154, 99, 47, 47, 100, 157, 212, 47, 76, 96, 49, 97, 76, 146, 112, 69, 109, 195, 1, 12, 159, 165, 1, 10, 187, 101, 58, 105, 143, 86, 71, 45, 83, 64, 39, 69, 128, 179, 111, 110, 183, 132, 74, 0, 0, 2, 0, 137, 0, 0, 5, 113, 5, 129, 0, 12, 0, 25, 0, 88, 185, 0, 24, 255, 224, 180, 9, 10, 0, 76, 24, 184, 255, 232, 64, 49, 8, 0, 77, 15, 32, 10, 0, 77, 15, 56, 9, 0, 77, 15, 24, 8, 0, 77, 13, 91, 0, 27, 144, 27, 1, 48, 27, 64, 27, 2, 20, 90, 0, 6, 48, 6, 64, 6, 3, 8, 6, 19, 95, 7, 3, 20, 95, 6, 18, 0, 63, 237, 63, 237, 1, 47, 94, 93, 237, 93, 113, 16, 222, 237, 49, 48, 0, 43, 43, 43, 43, 43, 1, 20, 2, 14, 1, 35, 33, 17, 33, 50, 4, 22, 18, 5, 52, 46, 2, 43, 1, 17, 51, 50, 62, 2, 5, 113, 106, 184, 251, 145, 253, 198, 1, 254, 164, 1, 18, 198, 110, 254, 215, 67, 120, 167, 101, 209, 250, 89, 151, 111, 63, 2, 203, 176, 254, 245, 180, 92, 5, 129, 82, 170, 254, 250, 180, 123, 176, 113, 54, 252, 71, 62, 123, 182, 0, 0, 0, 1, 0, 137, 0, 0, 5, 6, 5, 129, 0, 11, 0, 82, 64, 53, 15, 3, 1, 7, 3, 7, 3, 9, 10, 13, 32, 13, 48, 13, 64, 13, 3, 5, 9, 90, 32, 0, 48, 0, 2, 0, 8, 95, 95, 5, 111, 5, 143, 5, 223, 5, 255, 5, 5, 239, 5, 1, 5, 5, 9, 4, 95, 1, 3, 9, 95, 0, 18, 0, 63, 237, 63, 237, 18, 57, 47, 93, 113, 237, 1, 47, 93, 237, 50, 93, 16, 206, 17, 57, 57, 47, 47, 113, 49, 48, 51, 17, 33, 21, 33, 17, 33, 21, 33, 17, 33, 21, 137, 4, 84, 252, 211, 2, 240, 253, 16, 3, 86, 5, 129, 228, 254, 158, 228, 254, 141, 228, 0, 1, 0, 137, 0, 0, 4, 152, 5, 129, 0, 9, 0, 63, 64, 38, 3, 3, 5, 8, 11, 32, 11, 48, 11, 2, 1, 5, 90, 32, 6, 48, 6, 2, 6, 4, 95, 47, 1, 1, 1, 64, 14, 49, 72, 1, 1, 5, 0, 95, 7, 3, 5, 18, 0, 63, 63, 237, 18, 57, 47, 43, 93, 237, 1, 47, 93, 237, 50, 93, 16, 206, 17, 57, 47, 49, 48, 1, 17, 33, 21, 33, 17, 33, 17, 33, 21, 1, 176, 2, 209, 253, 47, 254, 217, 4, 15, 4, 157, 254, 76, 228, 253, 251, 5, 129, 228, 0, 0, 1, 0, 84, 255, 236, 5, 186, 5, 150, 0, 45, 0, 112, 185, 0, 44, 255, 232, 179, 10, 0, 77, 44, 184, 255, 248, 179, 9, 0, 77, 38, 184, 255, 232, 179, 10, 0, 77, 38, 184, 255, 248, 64, 47, 9, 0, 77, 31, 92, 30, 7, 30, 7, 30, 41, 6, 92, 9, 47, 32, 47, 48, 47, 2, 41, 91, 48, 20, 1, 15, 20, 31, 20, 2, 20, 7, 95, 8, 8, 0, 36, 95, 25, 31, 31, 25, 4, 0, 95, 15, 19, 0, 63, 237, 63, 51, 47, 16, 237, 18, 57, 47, 237, 1, 47, 93, 93, 237, 93, 16, 222, 237, 18, 57, 57, 47, 47, 16, 237, 49, 48, 43, 43, 43, 43, 37, 50, 62, 2, 55, 53, 33, 53, 33, 17, 14, 3, 35, 34, 36, 38, 2, 53, 52, 18, 54, 36, 51, 50, 30, 2, 23, 5, 46, 3, 35, 34, 14, 2, 21, 20, 30, 2, 3, 38, 64, 118, 101, 81, 26, 254, 168, 2, 102, 48, 136, 170, 201, 113, 187, 254, 242, 174, 83, 88, 179, 1, 15, 183, 133, 207, 155, 105, 31, 254, 240, 18, 60, 89, 117, 75, 110, 160, 104, 50, 51, 105, 160, 211, 20, 33, 43, 23, 195, 218, 253, 250, 49, 89, 67, 40, 109, 195, 1, 12, 159, 165, 1, 10, 187, 101, 52, 96, 135, 84, 82, 44, 79, 59, 35, 69, 128, 179, 111, 110, 184, 132, 74, 0, 0, 0, 0, 1, 0, 137, 0, 0, 5, 61, 5, 129, 0, 11, 0, 77, 64, 51, 8, 0, 90, 223, 11, 1, 11, 13, 80, 13, 96, 13, 112, 13, 3, 128, 13, 144, 13, 2, 48, 13, 64, 13, 176, 13, 208, 13, 4, 7, 3, 90, 0, 4, 48, 4, 64, 4, 3, 8, 4, 2, 96, 7, 7, 9, 5, 3, 4, 0, 18, 0, 63, 50, 63, 51, 57, 47, 237, 1, 47, 94, 93, 237, 50, 93, 113, 114, 16, 222, 113, 237, 50, 49, 48, 33, 17, 33, 17, 33, 17, 33, 17, 33, 17, 33, 17, 4, 22, 253, 154, 254, 217, 1, 39, 2, 102, 1, 39, 2, 92, 253, 164, 5, 129, 253, 207, 2, 49, 250, 127, 0, 0, 1, 0, 137, 0, 0, 1, 176, 5, 129, 0, 3, 0, 105, 64, 24, 96, 5, 1, 32, 5, 48, 5, 64, 5, 112, 5, 128, 5, 192, 5, 208, 5, 7, 224, 5, 240, 5, 2, 5, 184, 255, 192, 64, 11, 49, 52, 72, 159, 5, 1, 0, 5, 1, 17, 5, 184, 255, 192, 64, 37, 20, 23, 72, 3, 90, 0, 0, 16, 0, 32, 0, 3, 68, 0, 0, 192, 0, 208, 0, 224, 0, 4, 240, 0, 1, 32, 0, 48, 0, 224, 0, 3, 0, 1, 3, 0, 18, 0, 63, 63, 1, 47, 93, 113, 114, 94, 93, 237, 43, 94, 93, 93, 43, 93, 113, 114, 49, 48, 51, 17, 33, 17, 137, 1, 39, 5, 129, 250, 127, 0, 0, 0, 1, 0, 31, 255, 236, 3, 231, 5, 129, 0, 23, 0, 48, 64, 26, 16, 16, 5, 15, 90, 18, 25, 48, 25, 112, 25, 2, 6, 90, 5, 16, 95, 17, 3, 11, 95, 0, 6, 6, 0, 19, 0, 63, 50, 47, 16, 237, 63, 237, 1, 47, 237, 113, 16, 222, 237, 17, 57, 47, 49, 48, 5, 34, 46, 2, 39, 37, 30, 3, 51, 50, 54, 53, 17, 33, 53, 33, 17, 20, 14, 2, 2, 12, 106, 166, 122, 79, 20, 1, 37, 10, 36, 51, 66, 39, 88, 91, 254, 231, 2, 63, 62, 121, 177, 20, 44, 96, 153, 109, 43, 59, 81, 51, 23, 118, 110, 2, 227, 231, 252, 61, 107, 173, 121, 65, 0, 0, 0, 1, 0, 137, 0, 0, 5, 180, 5, 129, 0, 11, 0, 166, 64, 21, 1, 0, 1, 82, 1, 2, 0, 94, 11, 10, 20, 11, 11, 10, 68, 7, 1, 73, 1, 1, 10, 184, 255, 224, 179, 10, 0, 77, 10, 184, 255, 224, 179, 10, 0, 77, 10, 184, 255, 248, 64, 27, 9, 0, 77, 8, 32, 9, 10, 0, 76, 0, 24, 9, 10, 0, 76, 10, 1, 11, 8, 9, 16, 9, 9, 0, 11, 16, 11, 184, 255, 192, 64, 23, 9, 12, 72, 11, 11, 13, 32, 13, 48, 13, 2, 7, 3, 90, 32, 4, 48, 4, 2, 4, 2, 7, 10, 184, 255, 224, 64, 13, 9, 0, 77, 10, 1, 7, 1, 8, 5, 3, 4, 0, 18, 0, 63, 50, 63, 51, 57, 57, 17, 51, 43, 17, 51, 1, 47, 93, 237, 50, 93, 17, 51, 47, 43, 56, 51, 51, 47, 56, 51, 17, 57, 57, 49, 48, 43, 43, 43, 43, 0, 43, 93, 93, 135, 5, 16, 43, 8, 43, 16, 196, 33, 1, 7, 17, 33, 17, 33, 17, 1, 33, 9, 1, 4, 88, 254, 6, 174, 254, 217, 1, 39, 2, 123, 1, 88, 253, 166, 2, 139, 2, 135, 133, 253, 254, 5, 129, 253, 129, 2, 127, 253, 172, 252, 211, 0, 1, 0, 137, 0, 0, 4, 164, 5, 129, 0, 5, 0, 34, 64, 19, 4, 7, 80, 7, 1, 3, 90, 32, 0, 48, 0, 2, 0, 1, 3, 3, 95, 0, 18, 0, 63, 237, 63, 1, 47, 93, 237, 93, 16, 206, 49, 48, 51, 17, 33, 17, 33, 21, 137, 1, 39, 2, 244, 5, 129, 251, 99, 228, 0, 1, 0, 137, 0, 0, 6, 33, 5, 129, 0, 48, 2, 91, 182, 46, 32, 9, 10, 0, 76, 32, 184, 255, 224, 64, 11, 9, 10, 0, 76, 15, 8, 9, 10, 0, 76, 14, 184, 255, 248, 64, 255, 9, 10, 0, 76, 15, 14, 38, 38, 30, 46, 6, 0, 92, 48, 50, 203, 50, 1, 189, 50, 1, 1, 139, 50, 1, 127, 50, 1, 59, 50, 75, 50, 107, 50, 3, 47, 50, 1, 27, 50, 1, 251, 50, 1, 239, 50, 1, 171, 50, 203, 50, 2, 159, 50, 1, 91, 50, 123, 50, 139, 50, 3, 79, 50, 1, 59, 50, 1, 47, 50, 1, 11, 50, 1, 199, 235, 50, 1, 223, 50, 1, 155, 50, 187, 50, 203, 50, 3, 143, 50, 1, 75, 50, 123, 50, 2, 63, 50, 1, 11, 50, 43, 50, 2, 251, 50, 1, 239, 50, 1, 187, 50, 219, 50, 2, 159, 50, 175, 50, 2, 132, 50, 1, 107, 50, 1, 95, 50, 1, 75, 50, 1, 52, 50, 1, 27, 50, 1, 15, 50, 1, 244, 50, 1, 203, 50, 1, 191, 50, 1, 164, 50, 1, 123, 50, 139, 50, 2, 111, 50, 1, 84, 50, 1, 59, 50, 1, 47, 50, 1, 4, 50, 1, 151, 235, 50, 1, 223, 50, 1, 203, 50, 1, 180, 50, 1, 155, 50, 1, 143, 50, 1, 11, 50, 43, 50, 75, 50, 123, 50, 4, 27, 50, 59, 50, 75, 50, 107, 50, 139, 50, 187, 50, 219, 50, 251, 50, 8, 251, 50, 1, 239, 50, 1, 196, 50, 1, 171, 50, 1, 159, 50, 1, 139, 50, 1, 116, 50, 1, 91, 50, 1, 79, 50, 1, 52, 50, 1, 11, 50, 1, 103, 255, 50, 1, 64, 175, 228, 50, 1, 187, 50, 203, 50, 2, 175, 50, 1, 148, 50, 1, 123, 50, 1, 111, 50, 1, 68, 50, 1, 43, 50, 1, 31, 50, 1, 11, 50, 1, 244, 50, 1, 219, 50, 1, 207, 50, 1, 27, 50, 59, 50, 75, 50, 107, 50, 139, 50, 187, 50, 6, 59, 50, 91, 50, 123, 50, 139, 50, 171, 50, 203, 50, 251, 50, 7, 47, 50, 1, 4, 50, 1, 55, 203, 50, 235, 50, 2, 180, 50, 1, 155, 50, 1, 116, 50, 1, 75, 50, 1, 36, 50, 1, 11, 50, 1, 251, 50, 1, 212, 50, 1, 187, 50, 1, 175, 50, 1, 132, 50, 1, 107, 50, 1, 95, 50, 1, 2, 64, 50, 1, 31, 50, 63, 50, 2, 224, 50, 240, 50, 2, 207, 50, 1, 160, 50, 1, 63, 50, 79, 50, 127, 50, 3, 0, 50, 32, 50, 2, 7, 32, 23, 29, 92, 32, 30, 48, 30, 2, 30, 6, 23, 38, 23, 38, 46, 31, 3, 30, 15, 0, 18, 0, 63, 50, 50, 63, 51, 57, 57, 47, 47, 51, 1, 47, 93, 237, 50, 50, 94, 93, 93, 93, 93, 93, 113, 113, 95, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 95, 113, 113, 16, 222, 237, 50, 50, 18, 57, 17, 51, 51, 49, 48, 43, 43, 43, 43, 33, 17, 52, 54, 55, 54, 55, 6, 7, 14, 3, 7, 3, 35, 3, 46, 3, 39, 38, 39, 22, 23, 30, 1, 21, 17, 33, 17, 33, 19, 30, 1, 23, 22, 23, 54, 55, 62, 3, 55, 19, 33, 17, 5, 27, 3, 2, 3, 2, 21, 19, 8, 18, 17, 16, 6, 254, 210, 254, 6, 15, 17, 18, 9, 20, 22, 3, 3, 2, 4, 254, 250, 1, 139, 252, 10, 23, 11, 12, 14, 14, 13, 6, 12, 12, 12, 5, 248, 1, 137, 3, 86, 51, 108, 45, 53, 50, 79, 71, 30, 64, 60, 52, 19, 252, 238, 3, 18, 19, 52, 60, 64, 30, 71, 79, 58, 56, 48, 106, 39, 252, 170, 5, 129, 252, 236, 31, 90, 42, 49, 53, 52, 48, 21, 44, 42, 38, 15, 3, 25, 250, 127, 0, 0, 1, 0, 137, 0, 0, 5, 61, 5, 129, 0, 19, 0, 112, 64, 36, 0, 24, 9, 17, 72, 0, 11, 17, 92, 207, 18, 1, 18, 21, 64, 21, 80, 21, 96, 21, 3, 112, 21, 128, 21, 2, 32, 21, 48, 21, 160, 21, 192, 21, 4, 10, 184, 255, 232, 64, 14, 9, 17, 72, 10, 1, 7, 92, 32, 8, 48, 8, 2, 8, 11, 184, 255, 224, 64, 20, 9, 10, 0, 76, 1, 32, 9, 10, 0, 76, 1, 11, 1, 11, 17, 9, 3, 8, 0, 18, 0, 63, 50, 63, 51, 57, 57, 47, 47, 43, 43, 1, 47, 93, 237, 50, 50, 43, 93, 113, 114, 16, 222, 113, 237, 50, 50, 43, 49, 48, 33, 1, 22, 23, 30, 1, 21, 17, 33, 17, 33, 1, 38, 39, 46, 1, 53, 17, 33, 17, 3, 227, 253, 154, 5, 4, 4, 5, 254, 250, 1, 81, 2, 111, 5, 4, 4, 5, 1, 6, 4, 61, 44, 44, 38, 88, 40, 252, 193, 5, 129, 251, 186, 42, 46, 39, 98, 50, 3, 51, 250, 127, 0, 2, 0, 84, 255, 236, 5, 227, 5, 150, 0, 19, 0, 39, 0, 119, 185, 0, 38, 255, 200, 179, 10, 0, 77, 38, 184, 255, 224, 179, 9, 0, 77, 32, 184, 255, 224, 179, 10, 0, 77, 32, 184, 255, 216, 64, 62, 9, 0, 77, 28, 24, 10, 0, 77, 22, 24, 10, 0, 77, 20, 91, 191, 0, 207, 0, 2, 0, 41, 48, 41, 64, 41, 96, 41, 112, 41, 128, 41, 160, 41, 6, 32, 41, 240, 41, 2, 30, 91, 192, 10, 1, 48, 10, 1, 15, 10, 31, 10, 2, 10, 25, 95, 15, 4, 35, 95, 5, 19, 0, 63, 237, 63, 237, 1, 47, 93, 93, 113, 237, 93, 113, 16, 222, 113, 237, 49, 48, 0, 43, 43, 43, 43, 43, 43, 1, 20, 2, 6, 4, 35, 34, 36, 38, 2, 53, 52, 18, 54, 36, 51, 50, 4, 22, 18, 5, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 5, 227, 98, 184, 254, 247, 167, 177, 254, 247, 178, 89, 93, 181, 1, 9, 172, 172, 1, 9, 181, 94, 254, 211, 53, 104, 153, 101, 103, 155, 104, 52, 53, 104, 154, 101, 108, 156, 101, 48, 2, 199, 165, 254, 242, 192, 104, 109, 195, 1, 12, 159, 165, 1, 10, 187, 101, 102, 188, 254, 247, 164, 111, 179, 128, 69, 69, 128, 179, 111, 110, 183, 132, 74, 75, 133, 183, 0, 2, 0, 137, 0, 0, 5, 16, 5, 129, 0, 14, 0, 25, 0, 78, 185, 0, 12, 255, 248, 64, 47, 9, 0, 77, 15, 91, 0, 27, 48, 27, 96, 27, 112, 27, 128, 27, 4, 31, 27, 1, 20, 7, 90, 32, 8, 48, 8, 2, 8, 6, 95, 47, 20, 1, 20, 64, 14, 33, 72, 20, 20, 7, 19, 95, 9, 3, 7, 18, 0, 63, 63, 237, 18, 57, 47, 43, 93, 237, 1, 47, 93, 237, 50, 113, 113, 16, 222, 237, 49, 48, 0, 43, 1, 20, 14, 2, 35, 33, 17, 33, 17, 33, 50, 30, 2, 5, 52, 38, 35, 33, 17, 33, 50, 62, 2, 5, 16, 61, 126, 194, 133, 254, 162, 254, 217, 2, 121, 135, 198, 130, 63, 254, 215, 131, 131, 254, 207, 1, 57, 66, 95, 63, 30, 3, 195, 91, 169, 130, 77, 254, 16, 5, 129, 65, 118, 164, 104, 109, 113, 254, 55, 34, 62, 87, 0, 0, 0, 2, 0, 84, 254, 109, 5, 227, 5, 150, 0, 36, 0, 56, 0, 128, 64, 9, 54, 8, 9, 0, 77, 25, 54, 1, 50, 184, 255, 248, 64, 74, 9, 0, 77, 21, 50, 1, 22, 44, 1, 25, 40, 1, 24, 19, 1, 31, 14, 1, 5, 91, 22, 14, 22, 14, 27, 37, 91, 191, 0, 1, 0, 58, 48, 58, 64, 58, 96, 58, 112, 58, 128, 58, 5, 32, 58, 240, 58, 2, 47, 91, 48, 27, 1, 15, 27, 31, 27, 2, 27, 42, 95, 32, 4, 10, 95, 17, 17, 52, 95, 22, 5, 5, 22, 19, 0, 63, 51, 47, 16, 237, 51, 47, 237, 63, 237, 1, 47, 93, 93, 237, 93, 113, 16, 222, 113, 237, 18, 57, 57, 47, 47, 237, 49, 48, 93, 93, 93, 93, 93, 43, 93, 43, 1, 20, 14, 2, 7, 30, 3, 51, 50, 54, 55, 7, 14, 1, 35, 34, 46, 2, 39, 46, 3, 53, 52, 18, 54, 36, 51, 50, 4, 22, 18, 5, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 5, 227, 71, 135, 194, 124, 20, 54, 68, 80, 46, 29, 60, 30, 2, 54, 118, 70, 95, 142, 105, 73, 27, 150, 225, 150, 75, 93, 181, 1, 9, 172, 172, 1, 9, 181, 94, 254, 211, 53, 104, 153, 101, 103, 155, 104, 52, 53, 104, 154, 101, 108, 156, 101, 48, 2, 199, 141, 237, 183, 121, 25, 58, 73, 41, 15, 5, 5, 202, 12, 16, 57, 103, 145, 88, 14, 118, 190, 252, 147, 165, 1, 10, 187, 101, 102, 188, 254, 247, 164, 111, 179, 128, 69, 69, 128, 179, 111, 110, 184, 132, 74, 75, 133, 184, 0, 2, 0, 137, 0, 0, 5, 157, 5, 129, 0, 17, 0, 28, 0, 112, 64, 75, 0, 40, 9, 10, 0, 76, 1, 16, 3, 18, 91, 11, 0, 17, 16, 15, 17, 31, 17, 2, 17, 17, 63, 11, 79, 11, 2, 11, 30, 112, 30, 1, 32, 30, 48, 30, 160, 30, 3, 23, 3, 90, 32, 4, 48, 4, 2, 4, 16, 2, 95, 95, 23, 111, 23, 127, 23, 175, 23, 4, 23, 64, 22, 33, 72, 23, 23, 0, 22, 95, 5, 3, 4, 0, 18, 0, 63, 50, 63, 237, 18, 57, 47, 43, 93, 237, 57, 1, 47, 93, 237, 50, 93, 113, 16, 206, 113, 50, 47, 93, 56, 51, 16, 237, 18, 57, 57, 49, 48, 43, 33, 1, 33, 17, 33, 17, 33, 50, 30, 2, 21, 20, 14, 2, 7, 9, 1, 52, 38, 35, 33, 17, 33, 50, 62, 2, 4, 81, 254, 185, 254, 166, 254, 217, 2, 192, 132, 197, 132, 65, 47, 83, 114, 67, 1, 125, 254, 145, 135, 125, 254, 134, 1, 130, 66, 95, 61, 30, 2, 23, 253, 233, 5, 129, 59, 109, 155, 97, 79, 131, 102, 69, 16, 253, 176, 3, 209, 103, 100, 254, 96, 31, 57, 78, 0, 1, 0, 59, 255, 236, 5, 6, 5, 150, 0, 61, 0, 109, 185, 0, 59, 255, 232, 64, 66, 9, 0, 77, 33, 16, 9, 0, 77, 42, 90, 41, 50, 90, 31, 41, 31, 41, 31, 10, 19, 90, 0, 63, 11, 90, 15, 10, 31, 10, 79, 10, 95, 10, 111, 10, 5, 10, 19, 50, 5, 45, 95, 36, 42, 42, 36, 4, 16, 95, 5, 16, 11, 32, 11, 48, 11, 3, 48, 11, 64, 11, 2, 11, 11, 5, 19, 0, 63, 51, 47, 93, 113, 16, 237, 63, 51, 47, 16, 237, 18, 57, 57, 1, 47, 93, 237, 16, 222, 237, 18, 57, 57, 47, 47, 16, 237, 16, 237, 49, 48, 43, 43, 1, 20, 14, 2, 35, 34, 46, 2, 39, 37, 30, 3, 51, 50, 54, 53, 52, 46, 2, 39, 46, 5, 53, 52, 62, 2, 51, 50, 30, 2, 23, 5, 46, 1, 35, 34, 14, 2, 21, 20, 30, 2, 23, 30, 5, 5, 6, 70, 147, 229, 158, 140, 214, 153, 95, 21, 1, 29, 12, 46, 81, 121, 86, 150, 159, 64, 106, 138, 75, 60, 120, 109, 94, 69, 39, 84, 149, 206, 122, 138, 197, 133, 77, 18, 254, 226, 22, 135, 126, 78, 103, 61, 26, 50, 90, 125, 75, 66, 130, 118, 102, 75, 43, 1, 150, 96, 157, 112, 61, 50, 98, 145, 94, 47, 47, 78, 57, 31, 91, 97, 58, 74, 48, 32, 15, 14, 30, 42, 58, 85, 114, 77, 105, 150, 95, 44, 43, 88, 133, 89, 39, 91, 92, 27, 46, 61, 34, 52, 67, 45, 31, 16, 14, 31, 42, 60, 87, 120, 0, 0, 0, 0, 1, 0, 23, 0, 0, 4, 205, 5, 129, 0, 7, 2, 48, 64, 127, 7, 14, 1, 2, 4, 14, 11, 4, 1, 111, 107, 4, 1, 11, 4, 43, 4, 123, 4, 139, 4, 155, 4, 5, 59, 11, 4, 27, 4, 91, 4, 107, 4, 171, 4, 187, 4, 6, 59, 4, 123, 4, 139, 4, 203, 4, 219, 4, 5, 27, 4, 43, 4, 59, 4, 91, 4, 107, 4, 123, 4, 171, 4, 235, 4, 251, 4, 9, 4, 1, 90, 203, 2, 219, 2, 235, 2, 3, 180, 2, 1, 11, 2, 75, 2, 91, 2, 155, 2, 4, 139, 2, 187, 2, 203, 2, 3, 2, 64, 42, 52, 72, 4, 2, 20, 2, 2, 11, 2, 144, 9, 1, 4, 9, 116, 9, 132, 9, 3, 164, 9, 180, 9, 244, 9, 3, 9, 184, 255, 192, 64, 255, 222, 225, 72, 107, 9, 123, 9, 2, 84, 9, 1, 59, 9, 1, 4, 9, 36, 9, 2, 204, 240, 9, 1, 212, 9, 228, 9, 2, 187, 9, 1, 132, 9, 148, 9, 164, 9, 3, 107, 9, 1, 84, 9, 1, 59, 9, 1, 4, 9, 20, 9, 2, 219, 9, 235, 9, 2, 176, 9, 192, 9, 2, 36, 9, 84, 9, 100, 9, 116, 9, 164, 9, 5, 251, 9, 1, 224, 9, 1, 212, 9, 1, 171, 9, 1, 148, 9, 1, 91, 9, 1, 68, 9, 1, 27, 9, 43, 9, 2, 4, 9, 1, 154, 251, 9, 1, 132, 9, 180, 9, 212, 9, 3, 91, 9, 1, 52, 9, 1, 11, 9, 1, 187, 9, 1, 64, 9, 80, 9, 2, 4, 9, 36, 9, 52, 9, 3, 228, 9, 244, 9, 2, 192, 9, 1, 164, 9, 180, 9, 2, 139, 9, 1, 112, 9, 1, 84, 9, 100, 9, 2, 59, 9, 1, 4, 9, 36, 9, 2, 104, 251, 9, 1, 228, 9, 1, 203, 9, 1, 144, 9, 160, 9, 2, 4, 9, 52, 9, 68, 9, 84, 9, 132, 9, 5, 244, 9, 1, 203, 9, 219, 9, 2, 180, 9, 1, 139, 9, 1, 116, 9, 1, 59, 9, 91, 9, 2, 36, 9, 1, 11, 9, 1, 235, 9, 251, 9, 2, 208, 9, 1, 196, 9, 1, 155, 9, 1, 68, 9, 1, 11, 9, 27, 9, 2, 55, 244, 9, 1, 123, 9, 139, 9, 155, 9, 64, 59, 187, 9, 203, 9, 5, 111, 9, 1, 43, 9, 59, 9, 75, 9, 3, 4, 9, 1, 11, 9, 75, 9, 91, 9, 139, 9, 171, 9, 219, 9, 6, 255, 9, 1, 2, 143, 9, 207, 9, 223, 9, 3, 0, 9, 32, 9, 48, 9, 112, 9, 4, 7, 0, 4, 95, 5, 3, 1, 18, 0, 63, 63, 237, 50, 1, 94, 93, 93, 95, 93, 113, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 43, 93, 113, 113, 47, 94, 93, 43, 93, 113, 114, 114, 237, 198, 93, 113, 114, 94, 93, 114, 94, 93, 43, 1, 24, 16, 77, 230, 49, 48, 1, 17, 33, 17, 33, 53, 33, 21, 3, 5, 254, 217, 254, 57, 4, 182, 4, 157, 251, 99, 4, 157, 228, 228, 0, 0, 0, 1, 0, 123, 255, 236, 5, 74, 5, 129, 0, 25, 0, 75, 64, 53, 19, 90, 224, 20, 240, 20, 2, 20, 27, 64, 27, 80, 27, 96, 27, 3, 112, 27, 128, 27, 2, 32, 27, 48, 27, 160, 27, 192, 27, 4, 7, 90, 15, 6, 1, 239, 6, 255, 6, 2, 32, 6, 48, 6, 2, 6, 19, 6, 3, 13, 95, 0, 19, 0, 63, 237, 63, 51, 1, 47, 93, 93, 114, 237, 93, 113, 114, 16, 222, 93, 237, 49, 48, 5, 34, 46, 2, 53, 17, 33, 17, 20, 30, 2, 51, 50, 62, 2, 53, 17, 33, 17, 20, 14, 2, 2, 211, 132, 220, 159, 89, 1, 39, 44, 82, 116, 71, 72, 121, 87, 48, 1, 39, 94, 168, 231, 20, 63, 133, 208, 144, 3, 113, 252, 166, 89, 129, 83, 39, 41, 86, 132, 91, 3, 80, 252, 158, 145, 212, 139, 67, 0, 0, 0, 0, 1, 0, 14, 0, 0, 5, 72, 5, 129, 0, 16, 0, 163, 181, 15, 16, 10, 0, 77, 3, 184, 255, 240, 64, 15, 9, 10, 0, 76, 1, 32, 10, 0, 77, 1, 24, 9, 0, 77, 0, 184, 255, 240, 179, 10, 0, 77, 0, 184, 255, 232, 64, 49, 9, 0, 77, 192, 18, 1, 159, 18, 1, 96, 18, 1, 47, 18, 1, 1, 0, 9, 9, 2, 15, 16, 16, 47, 16, 95, 16, 2, 112, 16, 160, 16, 176, 16, 224, 16, 4, 16, 16, 48, 16, 96, 16, 192, 16, 4, 16, 3, 2, 184, 255, 240, 64, 33, 63, 2, 111, 2, 127, 2, 159, 2, 175, 2, 191, 2, 239, 2, 255, 2, 8, 15, 2, 31, 2, 159, 2, 3, 2, 9, 9, 1, 15, 2, 3, 1, 18, 0, 63, 63, 51, 18, 57, 47, 1, 47, 93, 113, 56, 51, 47, 93, 113, 114, 56, 51, 18, 57, 17, 51, 51, 93, 93, 93, 93, 49, 48, 43, 43, 43, 43, 43, 43, 41, 1, 1, 33, 1, 30, 1, 23, 22, 23, 54, 55, 62, 1, 55, 1, 33, 3, 66, 254, 213, 253, 247, 1, 52, 1, 34, 14, 26, 11, 12, 11, 10, 11, 10, 27, 14, 1, 33, 1, 49, 5, 129, 252, 119, 45, 94, 39, 46, 42, 41, 45, 38, 95, 47, 3, 137, 0, 0, 0, 1, 0, 2, 0, 0, 7, 139, 5, 129, 0, 48, 2, 166, 185, 0, 33, 255, 232, 64, 17, 9, 10, 0, 76, 32, 24, 9, 10, 0, 76, 47, 24, 9, 10, 0, 76, 18, 184, 255, 232, 180, 9, 10, 0, 76, 15, 184, 255, 240, 64, 17, 9, 10, 0, 76, 16, 40, 9, 10, 0, 76, 1, 16, 9, 10, 0, 76, 0, 184, 255, 216, 64, 32, 9, 10, 0, 76, 1, 0, 41, 33, 32, 7, 16, 15, 24, 24, 7, 41, 3, 17, 47, 48, 16, 6, 48, 22, 48, 2, 11, 48, 48, 50, 18, 17, 184, 255, 240, 64, 255, 121, 17, 185, 17, 2, 153, 17, 217, 17, 2, 139, 17, 1, 9, 17, 73, 17, 2, 36, 17, 107, 50, 1, 57, 50, 89, 50, 2, 43, 50, 1, 25, 50, 1, 233, 50, 1, 198, 50, 1, 73, 50, 105, 50, 137, 50, 169, 50, 4, 59, 50, 1, 9, 50, 41, 50, 2, 207, 9, 50, 1, 87, 139, 50, 1, 121, 50, 1, 102, 50, 1, 73, 50, 1, 59, 50, 1, 38, 50, 1, 9, 50, 1, 198, 251, 50, 1, 201, 50, 233, 50, 2, 187, 50, 1, 137, 50, 169, 50, 2, 123, 50, 1, 25, 50, 57, 50, 89, 50, 105, 50, 4, 217, 50, 249, 50, 2, 203, 50, 1, 153, 50, 185, 50, 2, 139, 50, 1, 125, 50, 1, 1, 91, 50, 1, 63, 50, 79, 50, 2, 36, 50, 1, 11, 50, 1, 107, 50, 139, 50, 171, 50, 203, 50, 235, 50, 5, 95, 50, 1, 27, 50, 43, 50, 75, 50, 3, 15, 50, 1, 150, 4, 50, 1, 87, 180, 50, 1, 155, 50, 1, 143, 50, 1, 116, 50, 1, 91, 50, 1, 79, 50, 1, 27, 50, 59, 50, 2, 15, 50, 1, 219, 50, 251, 50, 2, 207, 50, 1, 107, 50, 139, 50, 171, 50, 3, 95, 50, 1, 52, 50, 1, 27, 50, 1, 244, 50, 1, 219, 50, 1, 207, 50, 1, 180, 50, 1, 139, 50, 1, 4, 50, 36, 50, 68, 50, 100, 50, 4, 106, 251, 50, 1, 212, 50, 64, 164, 1, 187, 50, 1, 144, 50, 1, 132, 50, 1, 107, 50, 1, 80, 50, 1, 68, 50, 1, 43, 50, 1, 4, 50, 1, 235, 50, 1, 196, 50, 1, 139, 50, 171, 50, 2, 20, 50, 52, 50, 84, 50, 116, 50, 4, 251, 50, 1, 212, 50, 1, 187, 50, 1, 175, 50, 1, 148, 50, 1, 123, 50, 1, 111, 50, 1, 80, 50, 1, 68, 50, 1, 43, 50, 1, 4, 50, 1, 57, 180, 50, 212, 50, 244, 50, 3, 155, 50, 1, 116, 50, 1, 75, 50, 91, 50, 2, 48, 50, 1, 36, 50, 1, 11, 50, 1, 240, 50, 1, 2, 224, 50, 1, 207, 50, 1, 160, 50, 1, 79, 50, 111, 50, 143, 50, 3, 16, 50, 1, 240, 50, 1, 223, 50, 1, 176, 50, 1, 159, 50, 1, 112, 50, 1, 15, 50, 79, 50, 95, 50, 3, 8, 41, 24, 7, 24, 7, 47, 32, 17, 3, 16, 0, 18, 0, 63, 50, 63, 51, 51, 57, 57, 47, 47, 51, 1, 94, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 95, 113, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 94, 93, 93, 93, 93, 113, 113, 113, 113, 95, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 94, 93, 94, 93, 93, 93, 93, 93, 113, 113, 113, 113, 47, 94, 93, 93, 93, 113, 56, 51, 17, 51, 47, 94, 93, 56, 51, 18, 23, 57, 17, 51, 51, 17, 51, 51, 17, 51, 51, 49, 48, 43, 43, 43, 43, 43, 43, 43, 43, 41, 1, 3, 46, 1, 39, 38, 39, 6, 7, 14, 3, 7, 3, 33, 1, 33, 19, 30, 1, 23, 22, 23, 54, 55, 62, 3, 55, 19, 33, 19, 30, 3, 23, 22, 23, 54, 55, 62, 1, 55, 19, 33, 6, 31, 254, 162, 191, 9, 21, 9, 11, 9, 11, 11, 5, 10, 11, 9, 5, 190, 254, 162, 254, 149, 1, 43, 176, 15, 26, 11, 12, 10, 15, 14, 6, 14, 13, 13, 5, 174, 1, 74, 178, 6, 12, 12, 12, 5, 12, 12, 12, 13, 11, 28, 14, 170, 1, 43, 3, 47, 37, 102, 48, 55, 59, 59, 56, 24, 51, 49, 44, 18, 252, 209, 5, 129, 252, 240, 64, 124, 49, 57, 52, 74, 70, 30, 64, 62, 57, 23, 2, 238, 253, 18, 24, 59, 63, 63, 30, 70, 71, 56, 60, 51, 122, 57, 3, 16, 0, 0, 0, 0, 1, 0, 18, 0, 0, 5, 68, 5, 129, 0, 11, 0, 142, 64, 23, 23, 6, 1, 23, 2, 1, 24, 0, 1, 7, 4, 10, 3, 1, 1, 11, 8, 9, 9, 16, 6, 5, 5, 184, 255, 240, 64, 43, 176, 9, 1, 9, 5, 9, 5, 0, 11, 16, 47, 11, 95, 11, 143, 11, 3, 15, 11, 63, 11, 111, 11, 159, 11, 207, 11, 255, 11, 6, 223, 11, 1, 16, 11, 32, 11, 48, 11, 3, 11, 2, 3, 184, 255, 240, 64, 18, 15, 3, 31, 3, 2, 3, 10, 7, 1, 4, 4, 3, 8, 5, 3, 3, 0, 18, 0, 63, 50, 63, 51, 18, 57, 25, 47, 51, 51, 51, 1, 24, 47, 93, 56, 50, 47, 93, 93, 113, 114, 56, 51, 57, 57, 47, 47, 113, 56, 17, 51, 56, 17, 51, 17, 57, 17, 23, 51, 49, 48, 93, 93, 93, 33, 9, 1, 33, 9, 1, 33, 9, 1, 33, 9, 1, 4, 14, 254, 158, 254, 158, 254, 200, 1, 232, 254, 65, 1, 56, 1, 57, 1, 57, 1, 54, 254, 84, 1, 213, 2, 49, 253, 207, 2, 229, 2, 156, 254, 14, 1, 242, 253, 100, 253, 27, 0, 1, 0, 35, 0, 0, 5, 53, 5, 129, 0, 8, 1, 167, 64, 13, 6, 2, 7, 8, 16, 8, 14, 1, 2, 4, 14, 5, 4, 184, 255, 240, 64, 255, 11, 4, 27, 4, 75, 4, 91, 4, 139, 4, 155, 4, 203, 4, 219, 4, 8, 11, 4, 27, 4, 43, 4, 75, 4, 91, 4, 107, 4, 139, 4, 155, 4, 171, 4, 203, 4, 219, 4, 11, 4, 1, 90, 4, 2, 20, 2, 164, 2, 3, 11, 2, 43, 10, 59, 10, 91, 10, 3, 20, 10, 1, 11, 10, 59, 10, 75, 10, 107, 10, 123, 10, 187, 10, 203, 10, 251, 10, 8, 206, 27, 10, 43, 10, 59, 10, 107, 10, 155, 10, 171, 10, 251, 10, 7, 187, 10, 219, 10, 235, 10, 3, 148, 10, 1, 75, 10, 123, 10, 2, 11, 10, 123, 10, 139, 10, 187, 10, 235, 10, 251, 10, 6, 156, 251, 10, 1, 228, 10, 1, 11, 10, 27, 10, 59, 10, 75, 10, 139, 10, 155, 10, 203, 10, 7, 244, 10, 1, 91, 10, 171, 10, 219, 10, 3, 4, 10, 36, 10, 52, 10, 3, 4, 10, 20, 10, 52, 10, 68, 10, 116, 10, 132, 10, 164, 10, 196, 10, 244, 10, 9, 108, 164, 10, 180, 10, 212, 10, 228, 10, 4, 139, 10, 1, 112, 10, 1, 2, 0, 10, 48, 10, 96, 10, 3, 176, 10, 224, 10, 240, 10, 3, 159, 10, 1, 0, 10, 64, 10, 112, 10, 128, 10, 4, 240, 10, 1, 223, 10, 1, 0, 10, 16, 10, 48, 10, 128, 10, 144, 10, 192, 10, 6, 58, 255, 10, 1, 160, 10, 208, 10, 224, 10, 3, 127, 64, 68, 10, 1, 32, 10, 80, 10, 2, 15, 10, 1, 176, 10, 224, 10, 240, 10, 3, 143, 10, 1, 96, 10, 112, 10, 2, 79, 10, 1, 48, 10, 1, 31, 10, 1, 192, 10, 240, 10, 2, 159, 10, 1, 112, 10, 128, 10, 2, 95, 10, 1, 0, 10, 48, 10, 64, 10, 3, 6, 6, 0, 3, 3, 1, 8, 4, 7, 1, 18, 0, 63, 63, 51, 18, 57, 47, 51, 51, 47, 1, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 94, 93, 93, 93, 113, 113, 113, 114, 95, 114, 114, 114, 94, 93, 113, 113, 113, 114, 114, 114, 94, 93, 113, 113, 113, 114, 94, 93, 113, 113, 47, 94, 93, 237, 198, 93, 113, 56, 50, 43, 1, 24, 16, 77, 230, 56, 50, 18, 57, 49, 48, 1, 17, 33, 17, 1, 33, 9, 1, 33, 3, 63, 254, 218, 254, 10, 1, 53, 1, 82, 1, 86, 1, 53, 2, 66, 253, 190, 2, 66, 3, 63, 253, 172, 2, 84, 0, 1, 0, 61, 0, 0, 4, 168, 5, 129, 0, 9, 0, 112, 185, 0, 8, 255, 224, 179, 10, 0, 77, 8, 184, 255, 240, 64, 16, 9, 0, 77, 3, 40, 10, 0, 77, 3, 32, 9, 0, 77, 3, 7, 4, 184, 255, 192, 64, 15, 18, 26, 72, 4, 7, 4, 7, 1, 0, 11, 143, 11, 1, 2, 11, 184, 255, 192, 64, 25, 13, 25, 72, 8, 15, 1, 31, 1, 2, 1, 64, 13, 16, 72, 1, 7, 4, 95, 5, 3, 2, 8, 95, 1, 18, 0, 63, 237, 50, 63, 237, 50, 1, 47, 43, 93, 51, 43, 95, 113, 16, 206, 17, 57, 57, 47, 47, 43, 17, 51, 49, 48, 43, 43, 43, 43, 41, 1, 53, 1, 33, 53, 33, 21, 1, 33, 4, 168, 251, 149, 2, 250, 253, 82, 3, 246, 253, 6, 3, 35, 209, 3, 201, 231, 205, 252, 51, 0, 0, 0, 0, 1, 0, 115, 254, 87, 2, 145, 5, 204, 0, 7, 0, 43, 64, 25, 6, 16, 2, 1, 2, 2, 5, 240, 31, 0, 1, 32, 0, 48, 0, 2, 0, 4, 245, 1, 0, 5, 245, 0, 27, 0, 63, 237, 63, 237, 1, 47, 93, 113, 237, 51, 47, 93, 196, 49, 48, 19, 17, 33, 21, 33, 17, 33, 21, 115, 2, 30, 254, 236, 1, 20, 254, 87, 7, 117, 190, 250, 8, 191, 0, 1, 0, 21, 255, 215, 2, 38, 5, 205, 0, 3, 0, 44, 64, 19, 0, 16, 10, 0, 77, 0, 8, 9, 0, 77, 0, 3, 16, 16, 3, 1, 3, 2, 1, 184, 255, 240, 179, 1, 1, 0, 0, 0, 47, 63, 1, 47, 56, 51, 47, 93, 56, 51, 49, 48, 43, 43, 5, 1, 51, 1, 1, 51, 254, 226, 238, 1, 35, 41, 5, 246, 250, 10, 0, 0, 0, 1, 0, 25, 254, 87, 2, 55, 5, 204, 0, 7, 0, 41, 64, 24, 4, 31, 0, 1, 0, 0, 7, 240, 32, 2, 48, 2, 64, 2, 3, 2, 4, 245, 5, 0, 1, 245, 0, 27, 0, 63, 237, 63, 237, 1, 47, 93, 237, 50, 47, 93, 196, 49, 48, 19, 53, 33, 17, 33, 53, 33, 17, 25, 1, 22, 254, 234, 2, 30, 254, 87, 191, 5, 248, 190, 248, 139, 0, 0, 0, 1, 0, 45, 2, 2, 4, 127, 5, 129, 0, 6, 0, 69, 185, 0, 5, 255, 232, 64, 20, 10, 0, 77, 4, 24, 10, 0, 77, 5, 4, 1, 1, 3, 0, 6, 16, 6, 8, 2, 3, 184, 255, 240, 64, 12, 3, 64, 14, 22, 72, 3, 3, 0, 0, 1, 4, 3, 0, 63, 51, 51, 47, 50, 1, 47, 43, 56, 51, 16, 206, 56, 50, 17, 57, 61, 47, 51, 51, 49, 48, 43, 43, 9, 2, 35, 1, 33, 1, 3, 154, 254, 186, 254, 188, 227, 1, 135, 1, 66, 1, 137, 2, 2, 2, 240, 253, 16, 3, 127, 252, 129, 0, 1, 255, 236, 255, 6, 4, 133, 255, 84, 0, 3, 0, 18, 183, 2, 0, 0, 187, 0, 1, 1, 1, 0, 47, 114, 237, 1, 47, 47, 49, 48, 7, 53, 33, 21, 20, 4, 153, 250, 78, 78, 0, 0, 0, 1, 0, 66, 4, 159, 2, 63, 5, 222, 0, 5, 0, 48, 64, 33, 0, 131, 5, 132, 3, 130, 112, 2, 160, 2, 2, 2, 3, 140, 15, 0, 1, 15, 0, 47, 0, 63, 0, 95, 0, 127, 0, 159, 0, 239, 0, 7, 0, 0, 47, 93, 113, 237, 1, 47, 93, 237, 253, 237, 49, 48, 9, 1, 53, 33, 19, 21, 1, 150, 254, 172, 1, 2, 251, 4, 159, 1, 20, 43, 254, 224, 31, 0, 0, 2, 0, 60, 255, 236, 4, 128, 4, 78, 0, 53, 0, 68, 0, 137, 182, 49, 24, 9, 12, 0, 76, 31, 184, 255, 240, 64, 37, 9, 0, 77, 7, 16, 9, 0, 77, 3, 24, 9, 11, 0, 76, 54, 50, 11, 70, 34, 192, 41, 208, 41, 2, 41, 41, 34, 70, 191, 70, 1, 79, 70, 1, 22, 71, 23, 184, 255, 192, 64, 41, 21, 24, 72, 23, 23, 60, 71, 5, 64, 13, 16, 72, 5, 55, 82, 10, 10, 28, 63, 31, 22, 47, 22, 127, 22, 143, 22, 4, 22, 22, 17, 81, 28, 16, 39, 63, 79, 50, 47, 0, 22, 0, 63, 50, 50, 237, 50, 63, 237, 51, 47, 93, 17, 18, 57, 47, 237, 1, 47, 43, 237, 51, 47, 43, 237, 93, 113, 16, 204, 50, 47, 93, 16, 237, 50, 50, 49, 48, 43, 43, 43, 43, 5, 34, 46, 2, 53, 52, 62, 2, 63, 1, 53, 52, 46, 2, 35, 34, 14, 2, 7, 37, 62, 3, 51, 50, 30, 2, 21, 17, 20, 30, 2, 51, 50, 55, 21, 14, 3, 35, 34, 38, 39, 35, 14, 1, 19, 7, 14, 3, 21, 20, 22, 51, 50, 62, 2, 53, 1, 137, 78, 123, 86, 46, 67, 116, 156, 88, 233, 21, 40, 59, 38, 35, 55, 40, 25, 5, 254, 219, 12, 64, 113, 165, 111, 101, 158, 110, 58, 7, 19, 35, 28, 32, 30, 25, 40, 40, 45, 30, 106, 101, 10, 6, 56, 175, 202, 144, 45, 81, 61, 36, 71, 59, 54, 88, 61, 34, 20, 43, 83, 122, 78, 96, 131, 81, 37, 1, 4, 55, 59, 79, 50, 21, 14, 35, 59, 45, 14, 71, 117, 86, 47, 50, 99, 144, 95, 254, 118, 38, 60, 41, 21, 6, 152, 6, 10, 6, 4, 104, 101, 101, 112, 2, 9, 2, 2, 11, 35, 66, 57, 77, 75, 46, 75, 98, 51, 0, 2, 0, 135, 255, 236, 4, 143, 5, 204, 0, 36, 0, 52, 0, 77, 64, 20, 37, 71, 207, 0, 223, 0, 2, 0, 54, 112, 54, 1, 22, 10, 45, 70, 208, 20, 1, 20, 184, 255, 192, 179, 36, 40, 72, 20, 184, 255, 192, 64, 18, 9, 12, 72, 20, 40, 79, 28, 32, 16, 21, 0, 17, 21, 50, 79, 10, 5, 22, 0, 63, 51, 237, 63, 63, 63, 51, 237, 1, 47, 43, 43, 93, 237, 50, 50, 113, 16, 222, 113, 237, 49, 48, 1, 20, 14, 2, 35, 34, 46, 2, 39, 35, 20, 14, 2, 7, 33, 62, 1, 53, 17, 33, 17, 20, 6, 7, 6, 7, 51, 62, 1, 51, 50, 30, 2, 5, 52, 38, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 54, 4, 143, 49, 102, 157, 107, 48, 96, 86, 72, 26, 2, 3, 4, 5, 2, 254, 239, 3, 5, 1, 25, 1, 1, 1, 1, 4, 51, 178, 117, 104, 150, 97, 46, 254, 219, 108, 113, 43, 84, 66, 40, 40, 64, 84, 43, 107, 116, 2, 33, 123, 207, 151, 84, 20, 46, 74, 54, 21, 54, 51, 40, 8, 35, 129, 83, 4, 213, 254, 98, 32, 61, 26, 30, 27, 112, 96, 83, 149, 204, 121, 184, 178, 34, 85, 143, 109, 106, 140, 84, 34, 177, 0, 1, 0, 80, 255, 236, 4, 55, 4, 78, 0, 32, 0, 55, 64, 30, 16, 70, 15, 15, 27, 70, 79, 28, 1, 28, 34, 22, 71, 5, 19, 79, 10, 16, 16, 10, 16, 64, 27, 1, 27, 27, 24, 79, 0, 22, 0, 63, 237, 51, 47, 93, 63, 51, 47, 16, 237, 1, 47, 237, 16, 222, 93, 237, 51, 47, 237, 49, 48, 5, 34, 46, 2, 53, 52, 62, 2, 51, 50, 30, 2, 23, 5, 46, 1, 35, 34, 6, 21, 16, 51, 50, 54, 55, 5, 14, 3, 2, 82, 129, 193, 128, 64, 70, 132, 193, 123, 105, 163, 118, 73, 14, 254, 229, 12, 96, 88, 113, 104, 221, 80, 108, 13, 1, 26, 10, 71, 121, 172, 20, 80, 146, 205, 124, 135, 211, 145, 76, 56, 97, 132, 76, 14, 83, 99, 186, 177, 254, 138, 101, 100, 13, 75, 137, 105, 63, 0, 2, 0, 84, 255, 236, 4, 92, 5, 204, 0, 36, 0, 53, 0, 68, 64, 42, 31, 5, 37, 70, 223, 33, 1, 33, 64, 36, 40, 72, 33, 55, 112, 55, 1, 47, 71, 192, 14, 208, 14, 2, 48, 14, 1, 14, 31, 0, 42, 79, 24, 19, 16, 49, 79, 5, 9, 22, 0, 21, 0, 63, 63, 51, 237, 63, 51, 237, 63, 1, 47, 93, 113, 237, 113, 16, 222, 43, 93, 237, 50, 50, 49, 48, 33, 46, 3, 53, 35, 14, 1, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 30, 2, 23, 51, 52, 38, 52, 38, 53, 17, 33, 17, 20, 22, 23, 1, 52, 46, 2, 35, 34, 14, 2, 21, 16, 51, 50, 62, 2, 3, 76, 2, 5, 5, 3, 4, 49, 175, 122, 102, 149, 97, 47, 49, 102, 157, 108, 53, 98, 84, 68, 24, 2, 1, 1, 1, 25, 6, 2, 254, 227, 40, 65, 83, 43, 54, 83, 57, 29, 221, 42, 84, 66, 41, 8, 41, 52, 54, 21, 105, 91, 84, 150, 205, 121, 123, 206, 149, 84, 22, 46, 72, 51, 10, 39, 50, 54, 25, 1, 139, 251, 32, 79, 123, 34, 2, 35, 107, 141, 83, 33, 42, 90, 140, 99, 254, 144, 36, 86, 145, 0, 0, 0, 0, 2, 0, 80, 255, 236, 4, 45, 4, 78, 0, 30, 0, 39, 0, 79, 182, 25, 70, 26, 26, 37, 70, 16, 184, 255, 192, 64, 39, 39, 43, 72, 16, 41, 47, 41, 79, 41, 95, 41, 111, 41, 159, 41, 5, 36, 17, 71, 5, 17, 82, 36, 36, 22, 31, 82, 10, 16, 22, 81, 0, 16, 25, 1, 25, 25, 0, 22, 0, 63, 50, 47, 93, 16, 237, 63, 237, 18, 57, 47, 237, 1, 47, 237, 50, 93, 16, 222, 43, 237, 51, 47, 237, 49, 48, 5, 34, 46, 2, 53, 52, 62, 2, 51, 50, 30, 2, 29, 1, 33, 20, 30, 2, 51, 50, 54, 55, 5, 14, 3, 3, 34, 14, 2, 7, 33, 46, 1, 2, 74, 117, 187, 132, 70, 83, 141, 184, 102, 128, 181, 116, 54, 253, 74, 24, 54, 86, 61, 74, 94, 20, 1, 9, 18, 65, 108, 161, 115, 43, 75, 55, 34, 2, 1, 164, 8, 110, 20, 69, 141, 213, 143, 155, 212, 131, 58, 89, 160, 223, 135, 8, 68, 117, 85, 49, 63, 66, 23, 46, 104, 87, 57, 3, 177, 29, 63, 100, 70, 131, 131, 0, 1, 0, 35, 0, 0, 2, 174, 5, 204, 0, 27, 0, 87, 185, 0, 10, 255, 224, 64, 29, 9, 10, 0, 76, 191, 29, 1, 128, 29, 1, 27, 27, 95, 15, 1, 15, 15, 25, 1, 70, 2, 6, 2, 4, 4, 48, 2, 1, 2, 184, 255, 192, 64, 16, 16, 19, 72, 2, 19, 81, 12, 0, 0, 4, 79, 25, 5, 15, 1, 21, 0, 63, 63, 51, 237, 50, 63, 237, 1, 47, 43, 113, 51, 47, 17, 51, 16, 237, 50, 50, 47, 93, 51, 47, 93, 113, 49, 48, 0, 43, 1, 17, 33, 17, 35, 53, 51, 53, 52, 62, 2, 51, 50, 22, 23, 21, 46, 1, 35, 34, 14, 2, 29, 1, 51, 21, 1, 217, 254, 232, 158, 158, 30, 72, 122, 91, 48, 93, 37, 18, 45, 19, 39, 51, 29, 12, 213, 3, 124, 252, 132, 3, 124, 190, 113, 62, 105, 78, 44, 10, 6, 181, 4, 5, 16, 32, 49, 32, 85, 190, 0, 0, 2, 0, 84, 254, 78, 4, 90, 4, 79, 0, 51, 0, 69, 0, 84, 64, 51, 36, 14, 52, 70, 223, 47, 1, 47, 64, 36, 40, 72, 47, 71, 112, 71, 1, 6, 70, 5, 5, 62, 71, 192, 28, 208, 28, 2, 48, 28, 1, 28, 42, 15, 57, 79, 36, 33, 16, 65, 79, 19, 23, 21, 9, 81, 0, 6, 6, 0, 27, 0, 63, 50, 47, 16, 237, 63, 51, 237, 63, 51, 237, 63, 1, 47, 93, 113, 237, 51, 47, 237, 113, 16, 222, 43, 93, 237, 50, 50, 49, 48, 1, 34, 46, 2, 39, 37, 30, 1, 51, 50, 62, 2, 53, 60, 1, 55, 54, 53, 35, 14, 1, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 22, 23, 51, 52, 62, 2, 55, 33, 14, 1, 21, 17, 20, 14, 2, 19, 52, 46, 2, 35, 34, 14, 2, 21, 20, 22, 51, 50, 62, 2, 2, 84, 107, 163, 115, 69, 13, 1, 25, 15, 99, 80, 50, 83, 59, 33, 1, 1, 2, 49, 177, 122, 103, 149, 98, 47, 50, 103, 157, 108, 108, 171, 48, 5, 3, 4, 5, 2, 1, 10, 2, 4, 68, 131, 191, 113, 40, 64, 83, 42, 54, 83, 58, 30, 112, 111, 42, 83, 66, 40, 254, 78, 43, 77, 107, 64, 33, 65, 74, 28, 67, 110, 81, 28, 58, 24, 28, 26, 105, 94, 81, 145, 201, 121, 125, 203, 146, 79, 92, 103, 21, 55, 51, 40, 7, 36, 130, 84, 252, 225, 118, 175, 116, 58, 3, 222, 102, 136, 82, 34, 42, 88, 136, 94, 175, 178, 33, 83, 138, 0, 1, 0, 143, 0, 0, 4, 100, 5, 204, 0, 31, 0, 97, 185, 0, 5, 255, 224, 64, 38, 8, 0, 77, 10, 70, 224, 9, 240, 9, 2, 9, 33, 144, 33, 160, 33, 2, 112, 33, 144, 33, 160, 33, 176, 33, 240, 33, 5, 239, 33, 1, 26, 22, 70, 208, 23, 1, 23, 184, 255, 192, 179, 36, 40, 72, 23, 184, 255, 192, 64, 14, 8, 12, 72, 23, 24, 0, 23, 9, 21, 31, 16, 80, 3, 16, 0, 63, 237, 51, 63, 51, 63, 1, 47, 43, 43, 93, 237, 50, 93, 113, 114, 16, 222, 93, 237, 49, 48, 0, 43, 1, 62, 1, 51, 50, 30, 2, 21, 17, 33, 17, 52, 46, 2, 35, 34, 14, 2, 21, 17, 33, 17, 33, 17, 20, 14, 2, 7, 1, 164, 57, 172, 119, 98, 135, 85, 38, 254, 232, 20, 46, 74, 53, 51, 83, 60, 33, 254, 231, 1, 25, 2, 3, 2, 1, 3, 98, 124, 112, 64, 112, 152, 88, 253, 82, 2, 94, 63, 105, 75, 42, 45, 83, 115, 69, 253, 189, 5, 204, 254, 107, 32, 65, 57, 46, 13, 0, 0, 0, 0, 2, 0, 143, 0, 0, 1, 168, 5, 204, 0, 3, 0, 7, 0, 79, 64, 54, 1, 5, 70, 2, 191, 6, 1, 112, 6, 1, 223, 6, 1, 6, 9, 64, 9, 80, 9, 2, 160, 9, 176, 9, 2, 127, 9, 1, 96, 9, 1, 31, 9, 1, 239, 9, 1, 128, 9, 176, 9, 192, 9, 208, 9, 4, 5, 15, 4, 21, 0, 83, 1, 0, 0, 63, 237, 63, 63, 1, 93, 93, 113, 113, 113, 113, 114, 16, 222, 93, 113, 113, 50, 237, 50, 49, 48, 19, 53, 33, 21, 1, 17, 33, 17, 143, 1, 25, 254, 231, 1, 25, 4, 253, 207, 207, 251, 3, 4, 58, 251, 198, 0, 2, 255, 224, 254, 87, 1, 169, 5, 204, 0, 3, 0, 23, 0, 172, 64, 133, 22, 32, 9, 10, 0, 76, 8, 8, 1, 17, 70, 2, 143, 18, 1, 175, 18, 191, 18, 239, 18, 255, 18, 4, 96, 18, 1, 207, 18, 1, 0, 18, 1, 10, 18, 25, 176, 25, 192, 25, 2, 175, 25, 1, 16, 25, 64, 25, 80, 25, 128, 25, 4, 80, 25, 96, 25, 144, 25, 208, 25, 4, 239, 25, 1, 0, 25, 16, 25, 64, 25, 80, 25, 112, 25, 128, 25, 144, 25, 176, 25, 192, 25, 9, 56, 207, 25, 223, 25, 255, 25, 3, 96, 25, 160, 25, 2, 15, 25, 63, 25, 127, 25, 159, 25, 191, 25, 5, 160, 25, 208, 25, 224, 25, 3, 15, 25, 31, 25, 63, 25, 3, 7, 17, 15, 11, 80, 4, 27, 0, 83, 1, 0, 0, 63, 237, 63, 237, 63, 1, 94, 93, 93, 113, 114, 114, 94, 93, 93, 113, 114, 114, 114, 16, 222, 94, 93, 93, 113, 113, 114, 50, 237, 50, 50, 47, 49, 48, 0, 43, 19, 53, 33, 21, 1, 34, 38, 39, 53, 30, 1, 51, 50, 62, 2, 53, 17, 33, 17, 20, 14, 2, 144, 1, 25, 254, 225, 56, 83, 31, 13, 26, 12, 39, 48, 28, 10, 1, 25, 32, 69, 109, 4, 253, 207, 207, 249, 90, 5, 4, 198, 2, 2, 16, 38, 62, 46, 4, 118, 251, 70, 65, 108, 80, 44, 0, 0, 0, 0, 1, 0, 143, 0, 0, 4, 117, 5, 204, 0, 11, 0, 142, 64, 36, 28, 0, 1, 26, 1, 1, 87, 10, 103, 10, 2, 5, 10, 1, 10, 8, 1, 10, 1, 11, 8, 9, 38, 0, 54, 0, 70, 0, 150, 0, 4, 9, 0, 11, 16, 11, 184, 255, 192, 64, 16, 9, 12, 72, 11, 11, 13, 47, 13, 1, 7, 3, 70, 208, 4, 1, 4, 184, 255, 192, 179, 36, 40, 72, 4, 184, 255, 192, 64, 28, 9, 12, 72, 4, 123, 1, 139, 1, 2, 1, 32, 19, 25, 72, 2, 7, 10, 1, 1, 7, 7, 8, 15, 5, 0, 4, 0, 21, 0, 63, 50, 63, 63, 57, 47, 57, 17, 51, 17, 51, 43, 93, 1, 47, 43, 43, 93, 237, 50, 93, 17, 51, 47, 43, 56, 51, 51, 93, 17, 51, 17, 57, 57, 49, 48, 93, 93, 93, 93, 93, 33, 1, 7, 17, 33, 17, 33, 17, 1, 33, 9, 1, 3, 66, 254, 223, 121, 254, 231, 1, 25, 1, 130, 1, 46, 254, 132, 1, 153, 1, 234, 84, 254, 106, 5, 204, 252, 174, 1, 192, 254, 90, 253, 108, 0, 1, 0, 143, 0, 0, 1, 168, 5, 204, 0, 3, 0, 69, 64, 48, 1, 70, 191, 2, 1, 112, 2, 1, 223, 2, 1, 2, 5, 64, 5, 80, 5, 2, 160, 5, 176, 5, 2, 127, 5, 1, 96, 5, 1, 31, 5, 1, 239, 5, 1, 128, 5, 176, 5, 192, 5, 208, 5, 4, 1, 0, 0, 21, 0, 63, 63, 1, 93, 93, 113, 113, 113, 113, 114, 16, 222, 93, 113, 113, 237, 49, 48, 51, 17, 33, 17, 143, 1, 25, 5, 204, 250, 52, 0, 0, 0, 1, 0, 135, 0, 0, 6, 158, 4, 79, 0, 57, 0, 168, 185, 0, 40, 255, 240, 180, 9, 10, 0, 76, 31, 184, 255, 224, 64, 85, 9, 10, 0, 76, 32, 57, 70, 0, 0, 13, 45, 70, 228, 44, 244, 44, 2, 44, 59, 84, 59, 132, 59, 212, 59, 228, 59, 4, 59, 59, 1, 155, 59, 187, 59, 219, 59, 3, 84, 59, 1, 59, 59, 1, 47, 59, 1, 2, 31, 59, 1, 0, 59, 1, 176, 59, 208, 59, 224, 59, 3, 159, 59, 1, 96, 59, 128, 59, 2, 47, 59, 1, 25, 12, 70, 0, 13, 32, 13, 48, 13, 208, 13, 4, 13, 184, 255, 192, 64, 19, 36, 40, 72, 13, 51, 6, 80, 25, 33, 38, 3, 29, 16, 19, 15, 45, 13, 0, 21, 0, 63, 50, 50, 63, 63, 23, 51, 237, 50, 1, 47, 43, 93, 237, 50, 93, 93, 93, 93, 113, 113, 95, 113, 113, 113, 113, 114, 114, 16, 222, 93, 237, 17, 57, 47, 237, 50, 49, 48, 0, 43, 43, 33, 17, 52, 46, 2, 35, 34, 14, 2, 21, 17, 33, 17, 52, 46, 2, 39, 33, 30, 3, 21, 51, 62, 1, 51, 50, 22, 23, 51, 62, 3, 51, 50, 30, 2, 21, 17, 33, 17, 52, 46, 2, 35, 34, 14, 2, 7, 17, 3, 12, 17, 39, 63, 45, 43, 70, 51, 28, 254, 231, 1, 3, 2, 2, 1, 12, 2, 4, 4, 3, 4, 52, 155, 108, 124, 151, 26, 6, 29, 67, 81, 95, 56, 89, 123, 77, 35, 254, 233, 17, 39, 63, 45, 42, 69, 51, 28, 2, 2, 95, 63, 105, 75, 42, 45, 83, 115, 69, 253, 188, 3, 72, 35, 74, 67, 53, 13, 12, 53, 64, 64, 22, 124, 112, 121, 115, 67, 90, 55, 24, 64, 112, 152, 88, 253, 81, 2, 95, 63, 105, 75, 42, 43, 79, 110, 67, 253, 175, 0, 0, 0, 1, 0, 135, 0, 0, 4, 100, 4, 79, 0, 35, 0, 97, 185, 0, 31, 255, 224, 64, 38, 8, 0, 77, 0, 70, 224, 35, 240, 35, 2, 35, 37, 144, 37, 160, 37, 2, 112, 37, 144, 37, 160, 37, 176, 37, 240, 37, 5, 239, 37, 1, 25, 12, 70, 208, 13, 1, 13, 184, 255, 192, 179, 36, 40, 72, 13, 184, 255, 192, 64, 14, 8, 12, 72, 13, 25, 6, 80, 29, 16, 19, 15, 13, 0, 21, 0, 63, 50, 63, 63, 237, 51, 1, 47, 43, 43, 93, 237, 50, 93, 113, 114, 16, 222, 93, 237, 49, 48, 0, 43, 33, 17, 52, 46, 2, 35, 34, 14, 2, 21, 17, 33, 17, 52, 46, 2, 39, 33, 30, 3, 21, 51, 62, 1, 51, 50, 30, 2, 21, 17, 3, 76, 20, 46, 74, 53, 51, 83, 60, 33, 254, 231, 1, 3, 2, 2, 1, 12, 2, 4, 4, 3, 4, 57, 172, 119, 98, 135, 85, 38, 2, 95, 63, 105, 75, 42, 45, 83, 115, 69, 253, 188, 3, 72, 35, 74, 67, 53, 13, 12, 53, 64, 64, 22, 124, 112, 64, 112, 152, 88, 253, 81, 0, 0, 2, 0, 80, 255, 236, 4, 147, 4, 78, 0, 19, 0, 35, 0, 36, 64, 20, 20, 71, 0, 37, 96, 37, 112, 37, 2, 26, 71, 10, 23, 79, 15, 16, 31, 79, 5, 22, 0, 63, 237, 63, 237, 1, 47, 237, 113, 16, 222, 237, 49, 48, 1, 20, 14, 2, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 30, 2, 5, 52, 38, 35, 34, 6, 21, 20, 30, 2, 51, 50, 62, 2, 4, 147, 69, 138, 206, 137, 132, 202, 137, 70, 67, 136, 206, 138, 146, 206, 131, 61, 254, 218, 126, 120, 124, 132, 35, 64, 90, 54, 62, 97, 66, 34, 2, 30, 124, 206, 149, 83, 82, 148, 207, 125, 121, 205, 150, 84, 84, 149, 205, 122, 193, 174, 176, 191, 97, 140, 90, 43, 43, 90, 140, 0, 0, 2, 0, 135, 254, 87, 4, 143, 4, 81, 0, 36, 0, 54, 0, 93, 185, 0, 34, 255, 224, 64, 28, 8, 0, 77, 3, 32, 8, 0, 77, 37, 71, 207, 0, 223, 0, 2, 0, 56, 112, 56, 1, 45, 28, 17, 70, 208, 18, 1, 18, 184, 255, 192, 179, 36, 40, 72, 18, 184, 255, 192, 64, 18, 8, 12, 72, 18, 40, 79, 28, 32, 16, 22, 15, 17, 27, 50, 79, 10, 5, 22, 0, 63, 51, 237, 63, 63, 63, 51, 237, 1, 47, 43, 43, 93, 237, 50, 50, 113, 16, 222, 113, 237, 49, 48, 0, 43, 43, 1, 20, 14, 2, 35, 34, 46, 2, 39, 35, 30, 3, 21, 17, 33, 17, 52, 38, 39, 33, 30, 3, 21, 51, 62, 1, 51, 50, 30, 2, 5, 52, 38, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 4, 143, 49, 102, 157, 107, 48, 95, 86, 73, 26, 6, 1, 2, 2, 1, 254, 231, 5, 3, 1, 17, 2, 5, 3, 2, 4, 51, 178, 117, 103, 150, 97, 47, 254, 219, 112, 111, 42, 83, 65, 41, 40, 65, 82, 42, 54, 84, 57, 30, 2, 34, 123, 208, 150, 85, 20, 45, 73, 54, 5, 40, 53, 59, 25, 254, 97, 4, 234, 83, 130, 36, 7, 40, 52, 56, 21, 107, 92, 84, 148, 205, 122, 185, 179, 35, 85, 143, 109, 106, 141, 84, 35, 43, 91, 142, 0, 0, 0, 2, 0, 84, 254, 87, 4, 90, 4, 79, 0, 33, 0, 50, 0, 68, 64, 42, 34, 12, 19, 70, 223, 18, 1, 18, 64, 36, 40, 72, 18, 52, 112, 52, 1, 44, 71, 192, 0, 208, 0, 2, 48, 0, 1, 0, 46, 79, 25, 29, 22, 19, 27, 14, 15, 39, 79, 8, 5, 16, 0, 63, 51, 237, 63, 63, 63, 51, 237, 1, 47, 93, 113, 237, 113, 16, 222, 43, 93, 237, 50, 50, 49, 48, 19, 52, 62, 2, 51, 50, 22, 23, 52, 62, 2, 55, 33, 14, 1, 21, 17, 33, 17, 52, 54, 55, 54, 55, 35, 14, 1, 35, 34, 46, 2, 37, 52, 46, 2, 35, 34, 14, 2, 21, 16, 51, 50, 62, 2, 84, 50, 103, 157, 108, 108, 171, 48, 3, 5, 5, 2, 1, 14, 2, 4, 254, 233, 2, 1, 1, 1, 2, 49, 182, 122, 102, 149, 97, 47, 2, 235, 40, 64, 83, 42, 54, 83, 58, 30, 223, 42, 83, 66, 40, 2, 28, 123, 207, 149, 84, 92, 103, 21, 55, 51, 40, 7, 36, 130, 83, 251, 22, 1, 194, 28, 54, 23, 26, 24, 105, 95, 84, 150, 205, 127, 108, 140, 83, 33, 42, 90, 140, 98, 254, 144, 36, 86, 144, 0, 0, 0, 1, 0, 135, 0, 0, 2, 254, 4, 79, 0, 29, 0, 94, 185, 0, 15, 255, 232, 180, 9, 10, 0, 76, 21, 184, 255, 192, 64, 28, 9, 12, 72, 21, 21, 31, 127, 31, 159, 31, 2, 208, 31, 1, 47, 31, 95, 31, 175, 31, 3, 12, 29, 70, 208, 0, 1, 0, 184, 255, 192, 179, 36, 40, 72, 0, 184, 255, 192, 64, 13, 9, 12, 72, 0, 25, 80, 12, 18, 16, 7, 15, 0, 21, 0, 63, 63, 63, 51, 237, 1, 47, 43, 43, 93, 237, 50, 93, 93, 113, 17, 51, 47, 43, 49, 48, 0, 43, 51, 17, 52, 46, 2, 39, 33, 30, 3, 21, 51, 62, 3, 51, 50, 22, 23, 21, 46, 1, 35, 34, 6, 21, 17, 143, 1, 3, 2, 2, 1, 12, 2, 4, 4, 3, 4, 21, 42, 57, 80, 59, 25, 49, 13, 27, 55, 38, 105, 117, 3, 60, 35, 78, 71, 57, 13, 12, 59, 70, 69, 21, 59, 93, 65, 35, 9, 6, 235, 6, 9, 170, 167, 253, 237, 0, 0, 1, 0, 72, 255, 236, 4, 31, 4, 79, 0, 59, 0, 152, 185, 0, 58, 255, 232, 64, 10, 9, 0, 77, 33, 16, 9, 10, 0, 76, 2, 184, 255, 240, 64, 10, 9, 0, 77, 50, 70, 31, 42, 70, 41, 31, 184, 255, 192, 64, 70, 25, 32, 72, 31, 41, 31, 41, 10, 21, 70, 207, 0, 223, 0, 2, 79, 0, 1, 0, 61, 80, 61, 1, 48, 61, 176, 61, 2, 64, 61, 1, 47, 61, 1, 11, 70, 10, 50, 21, 5, 47, 81, 36, 210, 42, 1, 112, 42, 1, 31, 42, 47, 42, 2, 42, 42, 36, 16, 16, 81, 5, 16, 11, 32, 11, 2, 11, 11, 5, 22, 0, 63, 51, 47, 93, 16, 237, 63, 51, 47, 93, 93, 93, 16, 237, 18, 57, 57, 1, 47, 237, 93, 93, 113, 114, 16, 222, 93, 113, 237, 18, 57, 57, 47, 47, 43, 16, 237, 16, 237, 49, 48, 43, 43, 43, 1, 20, 14, 2, 35, 34, 46, 2, 39, 55, 30, 3, 51, 50, 62, 2, 53, 52, 46, 2, 39, 46, 3, 53, 52, 62, 2, 51, 50, 30, 2, 23, 7, 46, 3, 35, 34, 6, 21, 20, 30, 2, 23, 30, 3, 4, 31, 65, 124, 180, 115, 103, 166, 125, 84, 21, 247, 12, 42, 62, 83, 53, 48, 83, 61, 34, 49, 85, 115, 65, 68, 132, 104, 64, 60, 116, 171, 111, 88, 152, 120, 81, 16, 249, 7, 36, 53, 70, 42, 100, 100, 41, 75, 103, 61, 75, 145, 113, 69, 1, 60, 78, 124, 87, 47, 30, 69, 110, 81, 37, 45, 56, 30, 10, 11, 27, 49, 37, 42, 49, 31, 23, 15, 15, 42, 72, 111, 85, 77, 121, 85, 45, 33, 71, 110, 78, 26, 39, 51, 30, 11, 51, 60, 37, 44, 29, 21, 15, 16, 43, 75, 118, 0, 0, 0, 1, 0, 25, 255, 238, 2, 145, 5, 56, 0, 23, 0, 84, 64, 51, 2, 40, 9, 10, 0, 76, 12, 12, 95, 20, 1, 20, 20, 10, 14, 70, 3, 7, 3, 5, 5, 79, 3, 95, 3, 111, 3, 3, 3, 64, 38, 44, 72, 160, 3, 1, 3, 13, 5, 79, 6, 10, 6, 8, 8, 6, 15, 17, 79, 0, 22, 0, 63, 237, 63, 51, 47, 17, 51, 16, 237, 50, 1, 47, 93, 43, 113, 51, 47, 17, 51, 16, 237, 50, 50, 47, 93, 51, 47, 49, 48, 43, 5, 34, 38, 53, 17, 35, 53, 51, 55, 51, 21, 51, 21, 35, 17, 20, 22, 51, 50, 54, 55, 21, 14, 1, 1, 164, 124, 134, 137, 151, 88, 176, 205, 205, 60, 63, 26, 42, 26, 52, 116, 18, 135, 137, 2, 126, 190, 254, 254, 190, 253, 206, 79, 75, 8, 6, 174, 17, 17, 0, 0, 0, 0, 1, 0, 127, 255, 236, 4, 92, 4, 58, 0, 27, 0, 85, 0, 177, 21, 8, 63, 177, 2, 8, 63, 176, 11, 205, 177, 7, 15, 63, 176, 16, 51, 1, 176, 28, 47, 176, 6, 214, 176, 9, 205, 176, 9, 16, 176, 15, 220, 177, 24, 27, 50, 50, 176, 18, 205, 176, 18, 16, 176, 23, 205, 176, 23, 47, 176, 18, 16, 176, 29, 214, 177, 23, 15, 17, 18, 176, 0, 57, 0, 177, 11, 21, 17, 18, 176, 23, 57, 176, 7, 17, 177, 0, 27, 57, 57, 48, 49, 37, 6, 35, 34, 39, 38, 53, 17, 33, 17, 16, 51, 50, 55, 54, 53, 17, 33, 17, 20, 23, 33, 46, 1, 47, 1, 38, 53, 3, 63, 107, 241, 184, 91, 81, 1, 25, 192, 101, 63, 63, 1, 25, 8, 254, 244, 1, 5, 2, 2, 2, 215, 235, 120, 105, 190, 2, 175, 253, 161, 254, 227, 86, 88, 138, 2, 68, 252, 184, 138, 104, 12, 53, 32, 64, 32, 22, 0, 1, 0, 8, 0, 0, 4, 106, 4, 58, 0, 6, 0, 30, 0, 177, 4, 8, 63, 177, 5, 15, 63, 176, 1, 51, 1, 176, 7, 47, 176, 8, 214, 0, 177, 5, 4, 17, 18, 176, 0, 57, 48, 49, 37, 1, 33, 1, 33, 1, 33, 2, 53, 1, 15, 1, 38, 254, 113, 254, 176, 254, 125, 1, 41, 227, 3, 87, 251, 198, 4, 58, 0, 1, 255, 250, 0, 0, 6, 61, 4, 58, 0, 12, 0, 108, 0, 177, 10, 8, 63, 177, 7, 9, 51, 51, 177, 11, 15, 63, 178, 1, 2, 4, 51, 51, 51, 1, 176, 13, 47, 176, 14, 214, 176, 54, 26, 185, 62, 13, 240, 82, 10, 176, 1, 46, 14, 176, 0, 192, 177, 8, 79, 249, 5, 176, 9, 192, 185, 193, 234, 240, 118, 10, 176, 7, 46, 177, 9, 8, 8, 176, 8, 192, 14, 177, 3, 79, 249, 5, 176, 2, 192, 3, 0, 178, 0, 3, 8, 46, 46, 46, 1, 182, 0, 1, 2, 3, 7, 8, 9, 46, 46, 46, 46, 46, 46, 46, 176, 64, 26, 0, 48, 49, 1, 19, 33, 27, 1, 33, 1, 33, 11, 1, 33, 1, 33, 1, 180, 209, 1, 45, 207, 184, 1, 4, 254, 228, 254, 215, 219, 226, 254, 215, 254, 232, 1, 8, 0, 255, 3, 59, 252, 197, 3, 59, 251, 198, 3, 114, 252, 142, 4, 58, 0, 1, 0, 14, 0, 0, 4, 100, 4, 58, 0, 11, 0, 186, 182, 8, 24, 9, 10, 0, 76, 6, 184, 255, 232, 180, 9, 10, 0, 76, 2, 184, 255, 232, 64, 51, 9, 10, 0, 76, 0, 24, 9, 10, 0, 76, 7, 3, 8, 10, 11, 6, 11, 1, 9, 2, 4, 3, 8, 1, 10, 9, 2, 9, 7, 4, 3, 8, 3, 7, 4, 10, 3, 1, 1, 11, 3, 8, 9, 0, 9, 11, 16, 144, 11, 1, 11, 184, 255, 192, 64, 11, 10, 13, 72, 11, 11, 13, 6, 5, 5, 2, 3, 184, 255, 240, 64, 29, 79, 3, 159, 3, 2, 3, 240, 13, 1, 224, 13, 1, 79, 13, 159, 13, 2, 1, 7, 10, 3, 4, 4, 8, 5, 15, 3, 0, 21, 0, 63, 50, 63, 51, 57, 25, 47, 23, 51, 1, 93, 93, 113, 24, 47, 93, 56, 51, 51, 17, 51, 17, 51, 47, 43, 93, 56, 51, 51, 17, 51, 17, 18, 57, 17, 23, 51, 16, 135, 192, 192, 16, 135, 192, 192, 2, 8, 192, 8, 192, 16, 135, 192, 8, 192, 49, 48, 1, 43, 43, 43, 43, 33, 11, 1, 33, 9, 1, 33, 27, 1, 33, 9, 1, 3, 51, 252, 254, 254, 213, 1, 140, 254, 135, 1, 47, 231, 230, 1, 49, 254, 135, 1, 143, 1, 136, 254, 120, 2, 47, 2, 11, 254, 158, 1, 98, 253, 248, 253, 206, 0, 1, 0, 16, 254, 87, 4, 104, 4, 58, 0, 19, 0, 35, 0, 185, 0, 7, 1, 36, 63, 176, 12, 205, 177, 18, 15, 63, 176, 1, 51, 1, 176, 20, 47, 176, 21, 214, 0, 177, 18, 12, 17, 18, 176, 0, 57, 48, 49, 37, 19, 33, 1, 6, 7, 6, 35, 34, 39, 53, 22, 50, 54, 55, 54, 63, 1, 1, 33, 2, 72, 250, 1, 38, 254, 84, 81, 87, 95, 154, 101, 76, 53, 85, 64, 26, 51, 41, 18, 254, 84, 1, 41, 241, 3, 73, 251, 141, 197, 82, 89, 13, 200, 8, 18, 21, 42, 102, 48, 4, 47, 0, 0, 1, 0, 68, 0, 0, 3, 199, 4, 58, 0, 9, 0, 80, 64, 50, 2, 71, 6, 7, 71, 1, 239, 6, 255, 6, 2, 3, 6, 3, 6, 1, 8, 8, 11, 64, 11, 1, 192, 11, 208, 11, 2, 127, 11, 1, 15, 1, 31, 1, 79, 1, 95, 1, 4, 1, 6, 3, 80, 4, 15, 1, 7, 80, 0, 21, 0, 63, 237, 50, 63, 237, 50, 1, 47, 93, 93, 113, 114, 16, 206, 47, 17, 57, 57, 47, 47, 93, 16, 237, 16, 237, 49, 48, 51, 53, 1, 33, 53, 33, 21, 1, 33, 21, 68, 2, 28, 254, 13, 3, 41, 253, 231, 2, 74, 199, 2, 168, 203, 201, 253, 92, 205, 0, 0, 1, 0, 33, 254, 87, 2, 242, 5, 204, 0, 45, 0, 87, 64, 54, 2, 40, 9, 10, 0, 76, 19, 40, 9, 10, 0, 76, 33, 11, 22, 44, 44, 28, 40, 240, 5, 95, 11, 1, 11, 11, 17, 143, 5, 159, 5, 175, 5, 3, 48, 5, 80, 5, 2, 5, 34, 11, 245, 12, 12, 43, 24, 245, 21, 0, 43, 245, 0, 27, 0, 63, 237, 63, 237, 18, 57, 47, 237, 57, 1, 47, 93, 93, 51, 51, 47, 93, 16, 237, 50, 50, 47, 51, 17, 57, 49, 48, 43, 0, 43, 1, 34, 46, 2, 53, 17, 52, 46, 2, 39, 53, 62, 3, 53, 17, 52, 54, 59, 1, 21, 35, 34, 6, 21, 17, 20, 14, 2, 7, 21, 30, 3, 21, 17, 20, 22, 59, 1, 21, 2, 45, 69, 109, 77, 40, 32, 60, 85, 52, 53, 85, 59, 32, 157, 138, 197, 58, 91, 81, 33, 56, 76, 42, 43, 76, 56, 32, 81, 91, 58, 254, 87, 42, 77, 111, 69, 1, 72, 63, 87, 54, 24, 1, 195, 2, 25, 54, 87, 63, 1, 72, 146, 153, 190, 104, 105, 254, 211, 51, 85, 64, 43, 9, 4, 10, 43, 65, 83, 51, 254, 211, 106, 103, 191, 0, 0, 1, 0, 156, 254, 57, 1, 162, 5, 204, 0, 3, 0, 46, 178, 3, 171, 0, 184, 255, 192, 64, 16, 9, 14, 72, 0, 64, 5, 80, 5, 128, 5, 144, 5, 160, 5, 5, 5, 184, 255, 192, 181, 27, 30, 72, 1, 0, 0, 0, 47, 63, 1, 43, 93, 47, 43, 237, 49, 48, 19, 17, 33, 17, 156, 1, 6, 254, 57, 7, 147, 248, 109, 0, 0, 0, 0, 1, 0, 43, 254, 87, 2, 254, 5, 204, 0, 45, 0, 90, 185, 0, 41, 255, 216, 180, 9, 10, 0, 76, 25, 184, 255, 216, 64, 44, 9, 10, 0, 76, 10, 4, 80, 32, 1, 32, 32, 27, 39, 240, 4, 21, 0, 0, 16, 48, 4, 64, 4, 2, 15, 4, 31, 4, 2, 4, 10, 33, 245, 32, 32, 22, 0, 245, 45, 27, 21, 245, 22, 0, 0, 63, 237, 63, 237, 17, 57, 47, 237, 57, 1, 47, 93, 93, 51, 51, 47, 51, 16, 237, 50, 50, 47, 93, 18, 57, 49, 48, 43, 43, 23, 51, 50, 54, 53, 17, 52, 62, 2, 55, 53, 46, 3, 53, 17, 52, 38, 43, 1, 53, 51, 50, 22, 21, 17, 20, 30, 2, 23, 21, 14, 3, 21, 17, 20, 14, 2, 43, 1, 43, 57, 93, 79, 33, 56, 75, 43, 42, 75, 57, 33, 79, 93, 57, 197, 138, 157, 33, 60, 85, 53, 53, 85, 60, 33, 40, 77, 109, 69, 197, 234, 103, 106, 1, 45, 51, 83, 65, 43, 10, 4, 9, 43, 64, 85, 51, 1, 45, 105, 104, 190, 153, 146, 254, 184, 63, 87, 54, 25, 2, 195, 1, 24, 54, 87, 63, 254, 184, 69, 111, 77, 42, 0, 1, 0, 81, 2, 4, 4, 95, 3, 72, 0, 31, 0, 66, 64, 18, 2, 16, 10, 0, 77, 30, 48, 9, 10, 0, 76, 29, 48, 9, 10, 0, 76, 12, 184, 255, 192, 64, 22, 9, 10, 0, 76, 13, 48, 9, 10, 0, 76, 26, 33, 11, 26, 6, 173, 15, 175, 23, 173, 11, 0, 0, 47, 50, 237, 253, 237, 51, 1, 47, 16, 206, 49, 48, 43, 0, 43, 43, 43, 43, 1, 34, 38, 39, 46, 1, 35, 34, 14, 2, 7, 53, 62, 1, 51, 50, 30, 2, 23, 30, 1, 51, 50, 54, 55, 21, 14, 3, 3, 84, 75, 145, 75, 66, 109, 46, 39, 67, 61, 58, 30, 51, 136, 84, 41, 82, 80, 78, 38, 45, 107, 48, 68, 128, 52, 32, 61, 63, 70, 2, 4, 42, 26, 23, 24, 12, 23, 32, 21, 213, 38, 46, 13, 21, 27, 13, 16, 27, 50, 42, 219, 22, 31, 19, 8, 0, 0, 0, 0, 2, 0, 194, 254, 185, 1, 232, 4, 58, 0, 3, 0, 7, 1, 115, 64, 255, 7, 4, 2, 150, 4, 1, 20, 1, 2, 11, 1, 1, 9, 8, 59, 9, 75, 9, 91, 9, 123, 9, 139, 9, 187, 9, 6, 11, 9, 43, 9, 59, 9, 107, 9, 251, 9, 5, 202, 27, 9, 171, 9, 235, 9, 251, 9, 4, 91, 9, 155, 9, 171, 9, 187, 9, 219, 9, 235, 9, 6, 11, 9, 91, 9, 107, 9, 139, 9, 155, 9, 203, 9, 6, 154, 27, 9, 43, 9, 75, 9, 91, 9, 139, 9, 5, 203, 9, 1, 9, 64, 210, 214, 72, 9, 64, 190, 193, 72, 9, 64, 169, 172, 72, 9, 64, 148, 151, 72, 180, 9, 1, 59, 9, 1, 9, 64, 127, 130, 72, 9, 64, 118, 121, 72, 127, 9, 1, 100, 9, 1, 11, 9, 43, 9, 59, 9, 75, 9, 4, 105, 251, 9, 1, 212, 9, 1, 9, 64, 97, 100, 72, 116, 9, 132, 9, 2, 59, 9, 1, 32, 9, 1, 11, 9, 1, 251, 9, 1, 228, 9, 1, 128, 9, 1, 91, 9, 107, 9, 123, 9, 3, 36, 9, 52, 9, 2, 235, 9, 1, 212, 9, 1, 187, 9, 1, 148, 9, 164, 9, 2, 48, 9, 1, 36, 9, 1, 11, 9, 27, 9, 2, 56, 148, 9, 164, 9, 228, 9, 244, 9, 4, 123, 9, 139, 9, 2, 84, 9, 100, 9, 2, 27, 9, 1, 240, 9, 1, 2, 224, 9, 1, 223, 9, 1, 64, 9, 80, 9, 144, 9, 192, 9, 4, 63, 64, 31, 9, 1, 0, 9, 16, 9, 32, 9, 3, 207, 9, 1, 0, 9, 64, 9, 80, 9, 112, 9, 128, 9, 144, 9, 176, 9, 7, 7, 5, 5, 4, 184, 1, 26, 179, 0, 157, 1, 15, 0, 63, 237, 63, 57, 47, 1, 94, 93, 93, 113, 113, 113, 113, 113, 95, 113, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 114, 114, 114, 114, 43, 114, 114, 94, 93, 93, 93, 43, 43, 113, 113, 43, 43, 43, 43, 113, 114, 94, 93, 113, 114, 94, 93, 113, 17, 18, 57, 47, 94, 93, 237, 51, 50, 49, 48, 19, 17, 33, 17, 1, 19, 51, 19, 200, 1, 32, 254, 218, 32, 230, 32, 3, 44, 1, 14, 254, 242, 251, 141, 3, 213, 252, 43, 0, 0, 2, 0, 51, 255, 225, 4, 68, 5, 129, 0, 7, 0, 36, 0, 58, 0, 177, 27, 3, 63, 1, 176, 37, 47, 176, 22, 214, 176, 5, 205, 176, 5, 16, 176, 17, 220, 177, 0, 26, 50, 50, 176, 16, 205, 177, 8, 28, 50, 50, 176, 16, 16, 176, 10, 220, 176, 34, 50, 176, 11, 205, 176, 33, 50, 176, 11, 16, 176, 38, 214, 0, 48, 49, 1, 17, 6, 7, 6, 16, 23, 22, 23, 54, 55, 5, 6, 7, 6, 7, 21, 35, 53, 38, 39, 38, 53, 52, 55, 54, 55, 53, 51, 21, 22, 23, 22, 23, 5, 38, 39, 1, 250, 67, 41, 64, 66, 42, 226, 120, 21, 1, 27, 21, 105, 113, 185, 162, 222, 120, 113, 119, 117, 219, 162, 175, 110, 103, 27, 254, 230, 23, 110, 1, 96, 2, 169, 21, 60, 92, 254, 174, 91, 57, 21, 44, 152, 12, 146, 101, 109, 21, 191, 189, 21, 145, 135, 227, 233, 142, 140, 24, 184, 184, 19, 100, 93, 145, 14, 136, 41, 0, 0, 0, 0, 1, 0, 21, 0, 0, 4, 94, 5, 150, 0, 48, 0, 155, 64, 31, 3, 16, 9, 0, 77, 20, 40, 9, 10, 0, 76, 37, 0, 35, 39, 110, 16, 12, 28, 110, 41, 27, 1, 27, 12, 27, 12, 6, 48, 110, 0, 184, 255, 192, 64, 55, 38, 53, 72, 41, 0, 1, 0, 50, 14, 14, 6, 64, 38, 60, 72, 6, 64, 14, 31, 72, 6, 38, 14, 117, 35, 47, 15, 127, 15, 175, 15, 3, 15, 64, 22, 25, 72, 15, 15, 44, 31, 117, 22, 28, 28, 22, 7, 7, 44, 116, 6, 64, 48, 1, 48, 184, 255, 192, 182, 18, 21, 72, 48, 48, 6, 24, 0, 63, 51, 47, 43, 93, 16, 237, 50, 63, 51, 47, 16, 237, 18, 57, 47, 43, 93, 51, 237, 50, 1, 47, 43, 43, 51, 47, 16, 222, 93, 43, 237, 18, 57, 57, 47, 47, 93, 237, 16, 196, 253, 196, 18, 57, 49, 48, 43, 0, 43, 1, 14, 3, 35, 33, 53, 62, 3, 61, 1, 35, 53, 51, 53, 52, 62, 2, 51, 50, 30, 2, 23, 7, 46, 1, 35, 34, 6, 29, 1, 33, 21, 33, 21, 20, 14, 2, 7, 33, 50, 54, 55, 4, 94, 13, 60, 98, 134, 87, 253, 74, 39, 66, 46, 26, 188, 178, 48, 103, 161, 114, 96, 136, 95, 61, 19, 233, 21, 82, 66, 91, 80, 1, 30, 254, 226, 25, 46, 68, 43, 1, 124, 104, 107, 17, 1, 107, 73, 132, 99, 59, 205, 22, 52, 71, 96, 66, 92, 170, 248, 92, 151, 107, 58, 41, 76, 107, 67, 47, 77, 70, 115, 125, 225, 170, 90, 59, 93, 73, 56, 24, 99, 94, 0, 2, 0, 57, 0, 170, 4, 57, 4, 172, 0, 34, 0, 54, 0, 84, 64, 52, 14, 22, 45, 170, 31, 18, 1, 192, 18, 208, 18, 2, 18, 56, 4, 31, 35, 170, 16, 0, 1, 207, 0, 223, 0, 2, 0, 0, 32, 0, 2, 0, 23, 79, 30, 1, 30, 40, 173, 79, 26, 1, 26, 26, 13, 5, 50, 173, 207, 9, 1, 9, 0, 47, 93, 237, 198, 50, 51, 47, 93, 237, 198, 93, 50, 1, 47, 93, 113, 114, 237, 198, 50, 16, 220, 113, 114, 237, 198, 50, 49, 48, 19, 52, 54, 55, 39, 55, 23, 62, 1, 51, 50, 22, 23, 55, 23, 7, 30, 1, 21, 20, 6, 7, 23, 7, 39, 6, 35, 34, 38, 39, 7, 39, 55, 46, 1, 55, 20, 30, 2, 51, 50, 62, 2, 53, 52, 46, 2, 35, 34, 14, 2, 134, 31, 29, 133, 157, 131, 48, 112, 60, 60, 111, 48, 135, 158, 136, 29, 31, 30, 28, 134, 158, 133, 100, 121, 60, 112, 48, 135, 157, 135, 28, 30, 226, 33, 57, 76, 43, 43, 75, 57, 33, 33, 57, 75, 43, 43, 76, 57, 33, 2, 172, 60, 112, 49, 133, 156, 133, 28, 31, 30, 29, 135, 158, 135, 48, 111, 60, 60, 109, 48, 133, 160, 135, 59, 29, 28, 137, 158, 137, 48, 111, 62, 43, 76, 57, 33, 33, 57, 76, 43, 43, 76, 57, 33, 33, 57, 76, 0, 1, 0, 8, 0, 0, 4, 106, 5, 129, 0, 22, 0, 246, 179, 0, 20, 1, 0, 184, 255, 232, 64, 21, 10, 0, 77, 17, 24, 10, 0, 77, 12, 16, 5, 1, 16, 1, 22, 4, 19, 1, 9, 19, 18, 184, 255, 240, 64, 101, 15, 18, 1, 59, 15, 18, 31, 18, 175, 18, 3, 47, 18, 143, 18, 2, 79, 18, 143, 18, 159, 18, 223, 18, 4, 18, 18, 9, 11, 21, 1, 9, 21, 22, 16, 112, 22, 240, 22, 2, 80, 22, 208, 22, 224, 22, 3, 0, 22, 16, 22, 80, 22, 96, 22, 160, 22, 240, 22, 6, 12, 22, 22, 20, 4, 0, 8, 92, 17, 13, 0, 9, 1, 59, 0, 9, 16, 9, 160, 9, 3, 32, 9, 128, 9, 2, 48, 9, 64, 9, 144, 9, 208, 9, 4, 9, 9, 23, 24, 7, 11, 184, 1, 19, 180, 12, 4, 12, 3, 15, 184, 1, 19, 64, 22, 16, 20, 0, 16, 79, 12, 1, 15, 12, 31, 12, 2, 12, 16, 12, 16, 8, 21, 18, 3, 8, 18, 0, 63, 63, 51, 18, 57, 57, 47, 47, 93, 113, 17, 51, 51, 16, 237, 50, 17, 51, 16, 237, 50, 17, 18, 1, 57, 47, 93, 113, 114, 94, 93, 51, 51, 237, 50, 50, 57, 50, 47, 94, 93, 113, 114, 56, 51, 94, 93, 17, 51, 47, 93, 113, 114, 94, 93, 56, 51, 94, 93, 18, 57, 57, 17, 51, 17, 51, 49, 48, 43, 43, 0, 93, 1, 33, 21, 33, 21, 33, 21, 33, 21, 33, 53, 33, 53, 33, 55, 33, 53, 33, 1, 33, 9, 1, 33, 2, 254, 1, 20, 254, 174, 1, 82, 254, 174, 254, 240, 254, 176, 1, 80, 2, 254, 174, 1, 20, 254, 148, 1, 33, 1, 14, 1, 18, 1, 33, 2, 179, 146, 162, 147, 236, 236, 147, 162, 146, 2, 206, 253, 172, 2, 84, 0, 0, 0, 2, 0, 156, 254, 57, 1, 162, 5, 174, 0, 3, 0, 7, 0, 61, 180, 7, 2, 171, 4, 1, 184, 255, 192, 64, 16, 9, 14, 72, 1, 64, 9, 80, 9, 128, 9, 144, 9, 160, 9, 5, 9, 184, 255, 192, 64, 11, 27, 30, 72, 5, 0, 5, 0, 1, 4, 1, 0, 0, 63, 47, 18, 57, 57, 47, 47, 1, 43, 93, 47, 43, 50, 237, 50, 49, 48, 19, 17, 33, 17, 1, 17, 33, 17, 156, 1, 6, 254, 250, 1, 6, 2, 164, 3, 10, 252, 246, 251, 149, 3, 11, 252, 245, 0, 2, 0, 53, 255, 27, 4, 32, 5, 147, 0, 75, 0, 93, 0, 202, 185, 0, 86, 255, 224, 179, 10, 0, 77, 87, 184, 255, 224, 180, 9, 10, 0, 76, 31, 184, 255, 224, 64, 11, 9, 10, 0, 76, 70, 24, 9, 10, 0, 76, 36, 184, 255, 232, 64, 32, 9, 10, 0, 76, 74, 40, 9, 10, 0, 76, 68, 81, 73, 76, 72, 24, 53, 72, 34, 6, 72, 5, 14, 72, 73, 89, 29, 34, 84, 72, 63, 73, 184, 255, 192, 64, 31, 18, 26, 72, 34, 5, 73, 63, 63, 73, 5, 34, 4, 44, 24, 95, 45, 72, 44, 64, 14, 19, 72, 44, 81, 68, 89, 29, 68, 29, 0, 50, 184, 1, 15, 64, 17, 39, 16, 45, 224, 45, 2, 45, 45, 32, 39, 48, 39, 64, 39, 3, 39, 11, 184, 1, 15, 183, 0, 240, 6, 1, 6, 6, 0, 4, 0, 63, 50, 47, 93, 16, 237, 47, 93, 51, 47, 93, 16, 237, 18, 57, 57, 17, 51, 17, 51, 1, 47, 43, 237, 16, 206, 17, 23, 57, 47, 47, 47, 47, 43, 16, 237, 17, 57, 57, 16, 237, 16, 237, 16, 237, 16, 237, 17, 57, 57, 49, 48, 43, 43, 43, 43, 0, 43, 43, 1, 50, 30, 2, 23, 7, 46, 3, 35, 34, 6, 21, 20, 30, 2, 23, 30, 3, 21, 20, 14, 2, 7, 30, 3, 21, 20, 14, 2, 35, 34, 46, 2, 39, 55, 30, 3, 51, 50, 54, 53, 52, 46, 2, 39, 46, 3, 53, 52, 62, 2, 55, 46, 3, 53, 52, 54, 1, 52, 46, 2, 39, 14, 1, 21, 20, 30, 2, 23, 62, 3, 2, 63, 87, 153, 120, 81, 15, 239, 7, 39, 57, 73, 41, 112, 105, 46, 78, 103, 57, 85, 151, 112, 66, 26, 51, 73, 47, 41, 67, 47, 26, 58, 120, 182, 124, 103, 167, 127, 85, 21, 237, 11, 46, 68, 88, 53, 122, 126, 42, 84, 126, 84, 63, 134, 109, 71, 30, 56, 79, 48, 38, 69, 51, 30, 235, 1, 211, 32, 71, 111, 78, 93, 100, 48, 81, 105, 56, 41, 72, 52, 30, 5, 147, 31, 66, 104, 73, 25, 34, 49, 31, 15, 59, 65, 39, 53, 38, 27, 13, 19, 48, 74, 108, 80, 44, 81, 69, 54, 15, 18, 48, 61, 79, 50, 78, 127, 90, 49, 30, 68, 110, 80, 37, 45, 60, 36, 14, 65, 80, 45, 58, 41, 33, 20, 15, 45, 72, 107, 78, 49, 80, 63, 48, 16, 16, 49, 65, 80, 48, 149, 164, 252, 197, 39, 54, 41, 31, 15, 11, 73, 69, 39, 53, 37, 27, 13, 2, 17, 34, 52, 0, 0, 2, 0, 16, 4, 175, 2, 155, 5, 138, 0, 3, 0, 7, 0, 99, 64, 74, 16, 9, 1, 32, 9, 80, 9, 128, 9, 176, 9, 224, 9, 5, 0, 9, 48, 9, 96, 9, 144, 9, 192, 9, 240, 9, 6, 65, 0, 133, 95, 3, 1, 3, 3, 7, 133, 4, 5, 1, 141, 4, 111, 0, 1, 15, 0, 47, 0, 63, 0, 95, 0, 127, 0, 239, 0, 6, 0, 64, 43, 60, 72, 0, 64, 33, 41, 72, 0, 64, 26, 29, 72, 0, 0, 47, 43, 43, 43, 93, 113, 50, 237, 50, 1, 47, 237, 51, 47, 93, 237, 94, 93, 113, 114, 49, 48, 1, 53, 51, 21, 33, 53, 51, 21, 1, 194, 217, 253, 117, 214, 4, 175, 219, 219, 219, 219, 0, 0, 3, 0, 32, 255, 240, 5, 198, 5, 150, 0, 25, 0, 47, 0, 89, 0, 129, 64, 83, 71, 24, 9, 10, 0, 76, 67, 24, 9, 10, 0, 76, 48, 196, 69, 59, 59, 79, 79, 69, 95, 69, 111, 69, 3, 69, 79, 69, 79, 14, 26, 195, 15, 0, 31, 0, 2, 0, 91, 38, 195, 14, 58, 53, 202, 64, 85, 202, 74, 80, 80, 74, 64, 64, 80, 64, 96, 64, 3, 64, 74, 1, 15, 74, 31, 74, 2, 255, 74, 1, 64, 74, 64, 74, 43, 31, 200, 21, 4, 43, 200, 7, 19, 0, 63, 237, 63, 237, 18, 57, 57, 47, 47, 93, 113, 114, 113, 17, 51, 47, 16, 237, 16, 237, 51, 1, 47, 237, 16, 222, 93, 237, 17, 57, 57, 47, 47, 93, 17, 51, 47, 16, 237, 49, 48, 43, 43, 1, 20, 14, 4, 35, 34, 46, 4, 53, 52, 62, 4, 51, 50, 4, 22, 18, 7, 52, 46, 2, 35, 34, 14, 4, 21, 20, 30, 2, 51, 50, 62, 2, 37, 20, 30, 2, 51, 50, 62, 2, 55, 23, 14, 3, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 30, 2, 23, 7, 46, 3, 35, 34, 14, 2, 5, 198, 52, 94, 131, 161, 185, 100, 99, 185, 160, 133, 94, 52, 52, 94, 132, 161, 184, 100, 150, 1, 7, 197, 113, 112, 96, 166, 222, 127, 84, 155, 136, 110, 80, 43, 96, 165, 221, 126, 127, 222, 166, 96, 252, 202, 27, 56, 84, 57, 41, 64, 48, 33, 10, 160, 20, 57, 84, 116, 79, 104, 152, 100, 48, 48, 98, 149, 100, 78, 116, 83, 57, 19, 156, 10, 32, 47, 62, 41, 58, 84, 53, 25, 2, 195, 100, 185, 161, 131, 94, 52, 52, 94, 131, 161, 185, 100, 100, 184, 161, 132, 94, 52, 114, 196, 254, 249, 150, 126, 221, 165, 96, 44, 79, 111, 135, 155, 84, 127, 222, 166, 96, 96, 166, 222, 129, 62, 104, 75, 42, 26, 42, 51, 24, 47, 43, 85, 68, 41, 63, 113, 156, 92, 96, 154, 107, 58, 37, 63, 83, 46, 41, 24, 46, 37, 22, 39, 72, 101, 0, 2, 0, 45, 2, 213, 2, 246, 5, 139, 0, 50, 0, 65, 0, 138, 185, 0, 29, 255, 224, 64, 31, 9, 10, 0, 76, 5, 24, 9, 10, 0, 76, 2, 40, 9, 10, 0, 76, 20, 225, 21, 21, 3, 9, 56, 224, 40, 224, 32, 240, 32, 2, 32, 184, 255, 192, 64, 52, 26, 30, 72, 15, 32, 1, 32, 67, 63, 225, 111, 3, 127, 3, 2, 3, 64, 18, 22, 72, 3, 57, 230, 9, 9, 51, 26, 63, 20, 1, 15, 20, 159, 20, 2, 20, 64, 15, 19, 72, 20, 20, 15, 228, 26, 222, 47, 35, 51, 228, 44, 0, 184, 1, 30, 0, 63, 50, 237, 50, 51, 63, 237, 51, 47, 43, 113, 114, 17, 18, 57, 47, 237, 1, 47, 43, 93, 237, 16, 220, 93, 43, 93, 50, 237, 50, 17, 57, 47, 237, 49, 48, 43, 43, 43, 1, 34, 38, 53, 52, 62, 2, 63, 1, 53, 52, 46, 2, 35, 34, 14, 2, 7, 39, 62, 3, 51, 50, 30, 2, 29, 1, 20, 22, 51, 50, 62, 2, 55, 21, 14, 1, 35, 34, 38, 39, 35, 14, 1, 39, 50, 62, 2, 61, 1, 7, 14, 3, 21, 20, 22, 1, 1, 97, 115, 46, 78, 103, 57, 147, 16, 28, 38, 22, 21, 37, 30, 21, 3, 190, 8, 43, 75, 106, 69, 65, 105, 76, 41, 18, 33, 4, 14, 14, 13, 4, 29, 63, 27, 71, 81, 5, 3, 34, 111, 6, 35, 55, 38, 20, 92, 31, 54, 41, 24, 46, 2, 213, 105, 97, 60, 80, 49, 21, 1, 2, 42, 35, 46, 27, 11, 8, 21, 36, 29, 9, 43, 74, 55, 31, 28, 59, 88, 60, 237, 48, 49, 1, 2, 1, 1, 109, 8, 10, 73, 61, 65, 72, 131, 30, 46, 57, 28, 27, 2, 1, 7, 21, 39, 33, 41, 44, 0, 0, 0, 0, 2, 0, 92, 0, 141, 4, 23, 3, 172, 0, 8, 0, 17, 0, 113, 64, 72, 3, 235, 4, 0, 235, 8, 236, 6, 235, 31, 2, 1, 95, 2, 127, 2, 2, 2, 64, 29, 32, 72, 32, 2, 1, 2, 12, 235, 13, 9, 235, 17, 236, 15, 235, 64, 31, 11, 1, 11, 64, 29, 32, 72, 32, 11, 48, 11, 64, 11, 96, 11, 4, 31, 11, 1, 11, 12, 3, 237, 10, 11, 15, 2, 1, 9, 0, 237, 32, 15, 6, 239, 0, 25, 63, 51, 26, 237, 50, 51, 51, 17, 51, 51, 237, 50, 1, 24, 47, 93, 93, 43, 113, 26, 237, 253, 237, 212, 237, 47, 93, 43, 93, 113, 237, 253, 237, 212, 237, 49, 48, 37, 1, 53, 1, 51, 21, 3, 1, 21, 33, 1, 53, 1, 51, 21, 3, 1, 21, 3, 39, 255, 0, 1, 0, 238, 254, 1, 0, 253, 71, 254, 254, 1, 2, 236, 254, 1, 0, 141, 1, 105, 71, 1, 111, 37, 254, 146, 254, 151, 35, 1, 105, 71, 1, 111, 37, 254, 146, 254, 151, 35, 0, 0, 0, 1, 0, 84, 0, 141, 4, 87, 3, 25, 0, 5, 0, 59, 64, 43, 1, 170, 4, 7, 2, 15, 0, 31, 0, 95, 0, 111, 0, 175, 0, 191, 0, 6, 47, 0, 127, 0, 191, 0, 207, 0, 4, 63, 0, 143, 0, 159, 0, 175, 0, 223, 0, 5, 0, 2, 173, 3, 178, 0, 63, 253, 198, 93, 113, 114, 1, 47, 16, 222, 237, 49, 48, 37, 17, 33, 53, 33, 17, 3, 119, 252, 221, 4, 3, 141, 1, 172, 224, 253, 116, 0, 0, 4, 0, 32, 255, 240, 5, 198, 5, 150, 0, 25, 0, 47, 0, 61, 0, 70, 0, 148, 185, 0, 56, 255, 216, 64, 65, 9, 10, 0, 76, 59, 24, 9, 10, 0, 76, 49, 60, 57, 67, 51, 196, 52, 48, 61, 16, 61, 61, 57, 196, 62, 52, 62, 52, 62, 14, 26, 195, 15, 0, 31, 0, 2, 0, 72, 38, 195, 14, 48, 52, 60, 50, 201, 67, 66, 201, 53, 95, 53, 111, 53, 2, 53, 64, 23, 26, 72, 112, 52, 1, 52, 184, 255, 192, 64, 19, 26, 31, 72, 52, 67, 53, 53, 67, 52, 3, 43, 31, 200, 21, 4, 43, 200, 7, 19, 0, 63, 237, 63, 237, 18, 23, 57, 47, 47, 47, 43, 93, 43, 113, 16, 237, 16, 237, 57, 17, 51, 1, 47, 237, 16, 222, 93, 237, 17, 57, 57, 47, 47, 16, 237, 50, 47, 56, 51, 16, 237, 50, 17, 57, 57, 49, 48, 0, 43, 1, 43, 1, 20, 14, 4, 35, 34, 46, 4, 53, 52, 62, 4, 51, 50, 4, 22, 18, 7, 52, 46, 2, 35, 34, 14, 4, 21, 20, 30, 2, 51, 50, 62, 2, 1, 3, 35, 17, 35, 17, 33, 50, 22, 21, 20, 6, 7, 19, 3, 52, 38, 43, 1, 21, 51, 50, 54, 5, 198, 52, 94, 131, 161, 185, 100, 99, 185, 160, 133, 94, 52, 52, 94, 132, 161, 184, 100, 150, 1, 7, 197, 113, 112, 96, 166, 222, 127, 84, 155, 136, 110, 80, 43, 96, 165, 221, 126, 127, 222, 166, 96, 254, 69, 178, 117, 178, 1, 74, 153, 152, 96, 78, 213, 219, 75, 69, 133, 144, 66, 67, 2, 195, 100, 185, 161, 131, 94, 52, 52, 94, 131, 161, 185, 100, 100, 184, 161, 132, 94, 52, 114, 196, 254, 249, 150, 126, 221, 165, 96, 44, 79, 111, 135, 155, 84, 127, 222, 166, 96, 96, 166, 222, 254, 229, 1, 57, 254, 199, 3, 47, 129, 113, 94, 118, 25, 254, 176, 2, 59, 57, 60, 246, 71, 0, 0, 0, 1, 255, 239, 5, 172, 4, 124, 6, 10, 0, 3, 0, 17, 178, 1, 0, 2, 185, 1, 28, 0, 1, 0, 47, 237, 1, 47, 47, 49, 48, 1, 33, 53, 33, 4, 124, 251, 115, 4, 141, 5, 172, 94, 0, 2, 0, 90, 3, 27, 2, 219, 5, 145, 0, 19, 0, 39, 0, 79, 185, 0, 18, 255, 232, 180, 9, 10, 0, 76, 2, 184, 255, 232, 64, 44, 9, 10, 0, 76, 12, 24, 9, 10, 0, 76, 8, 24, 9, 10, 0, 76, 20, 172, 0, 0, 30, 172, 48, 10, 64, 10, 96, 10, 112, 10, 144, 10, 192, 10, 6, 10, 35, 174, 5, 5, 25, 174, 15, 4, 0, 63, 237, 51, 47, 237, 1, 47, 93, 237, 51, 47, 237, 49, 48, 43, 43, 43, 43, 1, 20, 14, 2, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 30, 2, 7, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 2, 219, 51, 87, 117, 66, 66, 117, 87, 50, 50, 87, 117, 66, 66, 117, 87, 51, 158, 25, 44, 59, 35, 35, 60, 45, 26, 26, 45, 60, 35, 35, 59, 44, 25, 4, 86, 66, 115, 85, 49, 49, 85, 115, 66, 67, 115, 85, 48, 48, 85, 115, 67, 35, 61, 45, 25, 25, 45, 61, 35, 34, 61, 46, 27, 27, 46, 61, 0, 0, 2, 0, 49, 0, 0, 4, 52, 4, 246, 0, 11, 0, 15, 0, 117, 64, 69, 15, 10, 14, 10, 9, 1, 170, 2, 64, 12, 5, 5, 2, 14, 15, 5, 31, 5, 47, 5, 95, 5, 111, 5, 127, 5, 6, 13, 3, 5, 6, 2, 2, 17, 16, 13, 173, 12, 2, 14, 0, 4, 173, 5, 64, 9, 5, 7, 5, 14, 207, 7, 1, 7, 64, 29, 33, 72, 7, 192, 5, 1, 95, 5, 1, 64, 5, 1, 5, 0, 47, 93, 93, 93, 198, 43, 93, 43, 17, 0, 51, 26, 24, 16, 77, 253, 50, 230, 47, 237, 17, 18, 1, 57, 47, 51, 196, 95, 94, 93, 43, 1, 16, 24, 196, 26, 16, 77, 253, 50, 50, 244, 196, 49, 48, 1, 17, 35, 17, 33, 53, 33, 17, 51, 17, 33, 21, 1, 53, 33, 21, 2, 162, 224, 254, 111, 1, 145, 224, 1, 146, 251, 253, 4, 3, 2, 195, 254, 171, 1, 85, 223, 1, 84, 254, 172, 223, 253, 61, 223, 223, 0, 0, 1, 0, 51, 2, 182, 2, 127, 5, 146, 0, 33, 0, 75, 185, 0, 22, 255, 216, 64, 42, 9, 10, 0, 76, 8, 226, 24, 24, 15, 32, 31, 32, 2, 32, 35, 13, 226, 14, 14, 31, 226, 0, 8, 0, 19, 95, 13, 111, 13, 127, 13, 3, 13, 13, 11, 228, 19, 222, 31, 229, 0, 221, 0, 63, 237, 63, 237, 51, 47, 93, 17, 18, 57, 1, 47, 237, 51, 47, 237, 16, 206, 93, 50, 47, 237, 49, 48, 43, 19, 39, 62, 5, 53, 52, 38, 35, 34, 7, 39, 62, 3, 51, 50, 30, 2, 21, 20, 14, 4, 7, 33, 21, 53, 2, 25, 75, 84, 84, 67, 42, 39, 42, 85, 10, 194, 6, 43, 72, 102, 66, 71, 105, 69, 34, 44, 68, 83, 77, 63, 14, 1, 106, 2, 182, 121, 53, 81, 64, 54, 51, 56, 34, 42, 49, 98, 5, 46, 80, 60, 34, 32, 56, 77, 45, 53, 80, 64, 53, 51, 52, 31, 138, 0, 0, 0, 0, 1, 0, 44, 2, 172, 2, 126, 5, 146, 0, 53, 0, 109, 64, 66, 34, 225, 35, 48, 22, 28, 225, 45, 35, 22, 45, 45, 22, 35, 3, 8, 15, 225, 0, 55, 9, 225, 8, 48, 21, 228, 22, 22, 12, 40, 15, 34, 159, 34, 2, 255, 34, 1, 34, 64, 15, 19, 72, 34, 34, 31, 228, 40, 222, 12, 228, 3, 128, 9, 1, 80, 9, 96, 9, 112, 9, 3, 9, 9, 3, 223, 0, 63, 51, 47, 93, 113, 16, 237, 63, 237, 51, 47, 43, 93, 113, 17, 18, 57, 47, 237, 57, 1, 47, 237, 16, 222, 237, 18, 23, 57, 47, 47, 47, 16, 237, 18, 57, 16, 237, 49, 48, 1, 20, 6, 35, 34, 46, 2, 39, 55, 30, 1, 51, 50, 54, 53, 52, 46, 2, 43, 1, 53, 51, 50, 62, 2, 53, 52, 38, 35, 34, 6, 7, 39, 62, 3, 51, 50, 30, 2, 21, 20, 6, 7, 21, 30, 3, 2, 126, 150, 138, 84, 113, 71, 33, 5, 189, 5, 55, 54, 49, 53, 27, 41, 49, 22, 56, 51, 23, 45, 36, 23, 46, 43, 42, 51, 5, 186, 6, 50, 77, 99, 57, 68, 102, 67, 34, 73, 79, 45, 65, 41, 20, 3, 127, 99, 112, 36, 59, 74, 39, 12, 45, 48, 47, 49, 31, 37, 19, 6, 126, 8, 20, 35, 27, 39, 44, 44, 45, 12, 51, 77, 51, 25, 29, 51, 69, 39, 64, 91, 16, 2, 5, 31, 46, 57, 0, 0, 0, 1, 0, 87, 4, 159, 2, 85, 5, 222, 0, 5, 0, 42, 64, 28, 2, 130, 3, 132, 5, 131, 0, 2, 140, 15, 5, 1, 15, 5, 47, 5, 63, 5, 95, 5, 127, 5, 159, 5, 239, 5, 7, 5, 0, 47, 93, 113, 237, 1, 47, 237, 253, 237, 49, 48, 19, 53, 19, 33, 21, 1, 87, 252, 1, 2, 254, 172, 4, 159, 31, 1, 32, 43, 254, 236, 0, 1, 0, 134, 254, 86, 4, 33, 4, 58, 0, 39, 0, 71, 64, 23, 3, 31, 70, 239, 34, 255, 34, 2, 34, 41, 21, 9, 17, 70, 224, 18, 240, 18, 2, 224, 18, 1, 18, 184, 255, 192, 64, 17, 9, 12, 72, 18, 32, 19, 15, 18, 27, 26, 80, 12, 3, 9, 22, 0, 21, 0, 63, 63, 51, 51, 237, 63, 63, 51, 1, 47, 43, 93, 113, 237, 50, 50, 16, 222, 113, 237, 50, 49, 48, 33, 46, 1, 53, 35, 14, 3, 35, 34, 38, 39, 35, 30, 1, 21, 17, 33, 17, 33, 17, 20, 30, 2, 51, 50, 62, 2, 53, 17, 33, 17, 20, 30, 2, 23, 3, 21, 3, 10, 3, 19, 43, 49, 58, 33, 52, 81, 23, 4, 3, 1, 254, 231, 1, 25, 16, 40, 67, 52, 50, 68, 42, 18, 1, 25, 1, 3, 3, 1, 23, 78, 43, 49, 64, 37, 14, 48, 42, 32, 55, 28, 254, 131, 5, 228, 253, 163, 64, 104, 75, 41, 45, 81, 115, 70, 2, 66, 252, 184, 34, 73, 67, 54, 14, 0, 0, 0, 0, 1, 0, 71, 254, 248, 4, 47, 5, 129, 0, 19, 0, 79, 64, 43, 14, 8, 9, 0, 77, 5, 151, 0, 6, 1, 6, 6, 1, 79, 12, 95, 12, 2, 12, 19, 2, 151, 159, 1, 1, 48, 1, 96, 1, 128, 1, 3, 1, 0, 7, 16, 7, 2, 7, 7, 1, 0, 4, 184, 1, 23, 179, 17, 3, 6, 1, 0, 47, 51, 63, 237, 50, 18, 57, 47, 93, 1, 47, 93, 93, 237, 51, 47, 93, 18, 57, 47, 93, 237, 49, 48, 43, 1, 17, 35, 17, 35, 17, 35, 17, 34, 46, 2, 53, 52, 62, 2, 51, 33, 21, 3, 172, 156, 195, 155, 81, 133, 96, 53, 50, 95, 138, 88, 2, 117, 4, 242, 250, 6, 5, 250, 250, 6, 3, 190, 45, 88, 134, 88, 84, 133, 93, 50, 143, 0, 0, 0, 0, 1, 0, 141, 2, 19, 1, 173, 3, 68, 0, 3, 0, 22, 64, 11, 3, 150, 32, 0, 48, 0, 2, 0, 1, 155, 0, 0, 47, 237, 1, 47, 93, 237, 49, 48, 19, 17, 33, 17, 141, 1, 32, 2, 19, 1, 49, 254, 207, 0, 0, 0, 0, 1, 0, 96, 254, 87, 1, 244, 0, 0, 0, 25, 0, 204, 185, 0, 25, 255, 216, 179, 10, 0, 77, 2, 184, 255, 232, 64, 37, 10, 0, 77, 20, 64, 9, 0, 77, 22, 23, 23, 21, 20, 20, 7, 14, 136, 11, 0, 75, 0, 2, 0, 52, 7, 1, 11, 7, 1, 10, 7, 20, 27, 36, 27, 2, 27, 184, 255, 192, 64, 47, 95, 100, 72, 224, 27, 1, 2, 32, 27, 48, 27, 80, 27, 96, 27, 4, 0, 27, 48, 27, 96, 27, 112, 27, 4, 59, 0, 27, 112, 27, 160, 27, 176, 27, 4, 128, 27, 176, 27, 192, 27, 224, 27, 240, 27, 5, 27, 184, 255, 192, 179, 83, 88, 72, 27, 184, 255, 192, 179, 68, 74, 72, 27, 184, 255, 192, 64, 33, 53, 56, 72, 31, 27, 1, 0, 27, 1, 144, 27, 192, 27, 240, 27, 3, 47, 27, 1, 0, 27, 1, 8, 23, 17, 17, 5, 21, 21, 11, 146, 5, 27, 0, 63, 237, 63, 18, 57, 47, 205, 1, 94, 93, 93, 93, 113, 113, 43, 43, 43, 113, 114, 94, 93, 113, 95, 113, 43, 114, 47, 94, 93, 93, 47, 93, 237, 18, 57, 47, 51, 51, 17, 51, 49, 48, 43, 43, 43, 5, 20, 14, 2, 35, 34, 39, 53, 30, 1, 51, 50, 54, 53, 52, 38, 35, 42, 1, 7, 55, 51, 7, 30, 1, 1, 244, 31, 71, 116, 85, 45, 56, 25, 42, 17, 75, 62, 56, 66, 13, 25, 14, 62, 143, 33, 94, 91, 235, 39, 70, 51, 30, 6, 118, 5, 2, 37, 32, 35, 34, 2, 172, 82, 5, 82, 0, 1, 0, 82, 2, 182, 2, 106, 5, 134, 0, 10, 0, 84, 185, 0, 5, 255, 224, 64, 32, 17, 21, 72, 3, 32, 17, 21, 72, 143, 9, 1, 9, 9, 8, 224, 2, 4, 1, 1, 6, 2, 2, 11, 12, 5, 32, 4, 48, 4, 2, 4, 3, 184, 255, 224, 64, 11, 11, 16, 72, 3, 6, 220, 8, 1, 228, 0, 221, 0, 63, 237, 50, 63, 51, 43, 205, 93, 50, 17, 18, 1, 57, 47, 51, 51, 47, 51, 16, 237, 50, 47, 93, 49, 48, 0, 43, 43, 19, 53, 51, 17, 7, 53, 55, 51, 17, 51, 21, 82, 184, 173, 180, 175, 170, 2, 182, 121, 1, 212, 108, 122, 117, 253, 169, 121, 0, 0, 0, 2, 0, 45, 2, 213, 2, 201, 5, 139, 0, 19, 0, 39, 0, 81, 185, 0, 17, 255, 232, 180, 9, 10, 0, 76, 13, 184, 255, 232, 64, 41, 9, 10, 0, 76, 7, 24, 9, 10, 0, 76, 3, 24, 9, 10, 0, 76, 20, 226, 15, 0, 1, 0, 41, 30, 226, 127, 10, 1, 10, 64, 18, 22, 72, 10, 25, 229, 15, 222, 35, 229, 5, 184, 1, 30, 0, 63, 237, 63, 237, 1, 47, 43, 93, 237, 16, 222, 93, 237, 49, 48, 0, 43, 43, 43, 43, 1, 20, 14, 2, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 30, 2, 7, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 2, 201, 43, 85, 126, 84, 80, 123, 84, 43, 41, 83, 126, 84, 88, 127, 81, 38, 200, 17, 33, 49, 33, 33, 51, 35, 19, 19, 35, 48, 29, 33, 52, 35, 19, 4, 49, 77, 128, 92, 51, 51, 91, 128, 78, 75, 127, 92, 52, 52, 92, 127, 75, 59, 78, 47, 19, 20, 47, 78, 58, 60, 80, 48, 20, 20, 48, 80, 0, 0, 0, 0, 2, 0, 93, 0, 141, 4, 24, 3, 172, 0, 8, 0, 17, 0, 113, 64, 36, 11, 235, 15, 236, 9, 14, 235, 13, 17, 235, 176, 9, 1, 32, 9, 128, 9, 2, 9, 2, 235, 6, 236, 0, 5, 235, 4, 8, 235, 64, 128, 0, 176, 0, 2, 0, 184, 255, 192, 64, 28, 11, 17, 72, 31, 0, 1, 0, 17, 8, 237, 16, 15, 11, 6, 7, 11, 3, 14, 5, 237, 32, 16, 15, 11, 11, 6, 2, 239, 0, 25, 63, 17, 51, 17, 51, 51, 26, 237, 50, 23, 51, 17, 51, 51, 237, 50, 1, 24, 47, 93, 43, 113, 26, 237, 212, 237, 16, 253, 237, 47, 93, 113, 237, 212, 237, 16, 253, 237, 49, 48, 55, 53, 1, 3, 53, 51, 1, 21, 1, 51, 53, 1, 3, 53, 51, 1, 21, 1, 93, 1, 0, 254, 238, 1, 0, 255, 0, 219, 1, 0, 254, 236, 1, 2, 254, 254, 141, 35, 1, 105, 1, 110, 37, 254, 145, 71, 254, 151, 35, 1, 105, 1, 110, 37, 254, 145, 71, 254, 151, 255, 255, 0, 94, 0, 0, 6, 75, 5, 134, 16, 38, 0, 121, 12, 0, 16, 39, 2, 26, 2, 208, 0, 0, 17, 7, 2, 147, 3, 178, 253, 75, 0, 26, 64, 15, 3, 2, 17, 24, 1, 112, 12, 1, 64, 12, 1, 16, 12, 1, 12, 17, 93, 93, 93, 53, 0, 63, 53, 53, 255, 255, 0, 94, 255, 255, 6, 76, 5, 134, 16, 38, 0, 121, 12, 0, 16, 39, 2, 26, 2, 188, 0, 0, 17, 7, 0, 114, 3, 205, 253, 73, 0, 7, 178, 2, 15, 24, 0, 63, 53, 0, 0, 0, 255, 255, 0, 103, 0, 0, 6, 75, 5, 146, 16, 39, 2, 26, 2, 208, 0, 0, 16, 39, 2, 147, 3, 178, 253, 75, 17, 6, 0, 115, 59, 0, 0, 26, 64, 15, 1, 2, 6, 24, 0, 112, 1, 1, 64, 1, 1, 16, 1, 1, 1, 17, 93, 93, 93, 53, 0, 63, 53, 53, 0, 2, 0, 114, 254, 164, 4, 129, 4, 58, 0, 35, 0, 39, 0, 87, 181, 34, 24, 9, 0, 77, 3, 184, 255, 240, 64, 31, 9, 0, 77, 10, 36, 150, 9, 39, 39, 0, 25, 150, 26, 41, 17, 150, 32, 0, 48, 0, 2, 0, 17, 31, 10, 10, 38, 31, 25, 25, 20, 186, 1, 21, 0, 31, 1, 27, 179, 38, 157, 39, 15, 0, 63, 237, 63, 237, 51, 47, 17, 18, 57, 47, 18, 57, 1, 47, 93, 237, 16, 222, 237, 17, 57, 47, 51, 237, 50, 49, 48, 0, 43, 1, 43, 55, 52, 62, 6, 55, 33, 14, 5, 21, 20, 22, 51, 50, 62, 2, 55, 5, 14, 3, 35, 34, 46, 2, 1, 17, 33, 17, 114, 35, 58, 74, 78, 75, 60, 38, 2, 1, 11, 5, 63, 90, 102, 87, 57, 115, 106, 51, 86, 65, 42, 6, 1, 29, 12, 75, 130, 189, 125, 120, 188, 131, 69, 2, 183, 254, 223, 56, 66, 100, 79, 63, 56, 54, 61, 73, 48, 85, 120, 91, 71, 74, 86, 61, 88, 102, 31, 56, 80, 48, 12, 89, 156, 116, 68, 56, 105, 150, 4, 95, 254, 242, 1, 14, 0, 0, 255, 255, 0, 51, 0, 0, 5, 145, 7, 23, 18, 38, 0, 36, 0, 0, 17, 7, 2, 154, 1, 86, 0, 0, 0, 21, 180, 2, 21, 5, 38, 2, 184, 255, 202, 180, 22, 25, 4, 7, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 51, 0, 0, 5, 145, 7, 23, 18, 38, 0, 36, 0, 0, 17, 7, 2, 155, 1, 230, 0, 0, 0, 19, 64, 11, 2, 21, 5, 38, 2, 90, 21, 24, 4, 7, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 51, 0, 0, 5, 145, 7, 43, 18, 38, 0, 36, 0, 0, 17, 7, 2, 156, 1, 141, 0, 0, 0, 19, 64, 11, 2, 22, 5, 38, 2, 0, 27, 21, 4, 7, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 51, 0, 0, 5, 145, 7, 31, 18, 38, 0, 36, 0, 0, 17, 7, 2, 159, 1, 141, 0, 0, 0, 19, 64, 11, 2, 21, 5, 38, 2, 0, 32, 48, 4, 7, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 51, 0, 0, 5, 145, 6, 213, 18, 38, 0, 36, 0, 0, 17, 7, 2, 158, 1, 143, 0, 0, 0, 23, 64, 13, 3, 2, 21, 5, 38, 3, 2, 1, 25, 23, 4, 7, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 0, 255, 255, 0, 51, 0, 0, 5, 145, 7, 14, 18, 38, 0, 36, 0, 0, 17, 7, 1, 80, 1, 190, 0, 162, 0, 22, 64, 12, 3, 2, 56, 3, 3, 2, 1, 31, 21, 4, 7, 37, 1, 43, 53, 53, 0, 63, 53, 53, 0, 2, 0, 4, 0, 0, 7, 176, 5, 129, 0, 15, 0, 24, 0, 146, 64, 91, 9, 13, 90, 0, 24, 0, 23, 2, 3, 5, 1, 82, 3, 17, 3, 94, 4, 5, 20, 4, 4, 5, 17, 4, 27, 7, 1, 43, 11, 59, 11, 75, 11, 3, 0, 11, 7, 7, 11, 0, 3, 4, 14, 26, 143, 26, 1, 2, 63, 26, 95, 26, 111, 26, 3, 4, 2, 95, 23, 12, 95, 9, 95, 9, 111, 9, 143, 9, 223, 9, 255, 9, 5, 239, 9, 1, 23, 9, 23, 9, 13, 8, 17, 95, 5, 3, 13, 95, 3, 0, 18, 0, 63, 50, 237, 63, 237, 50, 18, 57, 57, 47, 47, 93, 113, 16, 237, 16, 237, 1, 47, 93, 95, 113, 16, 206, 17, 23, 57, 47, 47, 47, 93, 113, 18, 57, 135, 16, 43, 135, 43, 196, 16, 192, 192, 17, 1, 51, 24, 16, 237, 50, 49, 48, 33, 17, 33, 3, 33, 1, 33, 21, 33, 17, 33, 21, 33, 17, 33, 21, 1, 35, 14, 3, 7, 3, 33, 3, 163, 254, 62, 172, 254, 207, 2, 188, 4, 199, 253, 67, 2, 127, 253, 129, 2, 230, 251, 243, 61, 4, 26, 30, 29, 7, 191, 1, 92, 1, 104, 254, 152, 5, 129, 227, 254, 157, 221, 254, 133, 227, 4, 168, 9, 56, 67, 62, 15, 254, 111, 0, 0, 0, 255, 255, 0, 84, 254, 87, 5, 143, 5, 150, 18, 38, 0, 38, 0, 0, 17, 7, 0, 120, 1, 233, 0, 0, 0, 11, 182, 1, 33, 49, 42, 16, 6, 37, 1, 43, 53, 0, 0, 0, 255, 255, 0, 137, 0, 0, 5, 6, 7, 23, 18, 38, 0, 40, 0, 0, 17, 7, 2, 154, 1, 53, 0, 0, 0, 21, 180, 1, 12, 5, 38, 1, 184, 255, 195, 180, 13, 16, 0, 10, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 137, 0, 0, 5, 6, 7, 23, 18, 38, 0, 40, 0, 0, 17, 7, 2, 155, 1, 174, 0, 0, 0, 19, 64, 11, 1, 12, 5, 38, 1, 60, 12, 15, 0, 10, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 137, 0, 0, 5, 6, 7, 43, 18, 38, 0, 40, 0, 0, 17, 7, 2, 156, 1, 115, 0, 0, 0, 19, 64, 11, 1, 13, 5, 38, 1, 1, 18, 12, 0, 10, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 137, 0, 0, 5, 6, 6, 213, 18, 38, 0, 40, 0, 0, 17, 7, 2, 158, 1, 115, 0, 0, 0, 23, 64, 13, 2, 1, 12, 5, 38, 2, 1, 0, 16, 14, 0, 10, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 0, 255, 255, 255, 216, 0, 0, 1, 213, 7, 23, 18, 38, 0, 44, 0, 0, 17, 6, 2, 154, 129, 0, 0, 21, 180, 1, 4, 5, 38, 1, 184, 255, 186, 180, 5, 8, 0, 2, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 104, 0, 0, 2, 102, 7, 23, 18, 38, 0, 44, 0, 0, 17, 6, 2, 155, 17, 0, 0, 19, 64, 11, 1, 4, 5, 38, 1, 74, 4, 7, 0, 2, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 255, 171, 0, 0, 2, 140, 7, 43, 18, 38, 0, 44, 0, 0, 17, 6, 2, 156, 198, 0, 0, 21, 180, 1, 5, 5, 38, 1, 184, 255, 255, 180, 10, 4, 0, 2, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 255, 215, 0, 0, 2, 98, 6, 213, 18, 38, 0, 44, 0, 0, 17, 6, 2, 158, 200, 0, 0, 23, 64, 13, 2, 1, 4, 5, 38, 2, 1, 0, 8, 6, 0, 2, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 2, 0, 8, 0, 0, 5, 113, 5, 129, 0, 16, 0, 33, 0, 117, 64, 78, 31, 16, 9, 10, 0, 76, 20, 16, 9, 10, 0, 76, 26, 26, 28, 17, 91, 0, 35, 128, 35, 1, 24, 28, 90, 6, 10, 6, 8, 8, 6, 27, 8, 95, 24, 47, 9, 127, 9, 175, 9, 3, 9, 64, 51, 54, 72, 9, 64, 43, 49, 72, 9, 64, 36, 41, 72, 9, 64, 29, 34, 72, 9, 64, 22, 26, 72, 9, 9, 28, 23, 95, 11, 3, 28, 95, 6, 18, 0, 63, 237, 63, 237, 18, 57, 47, 43, 43, 43, 43, 43, 93, 51, 237, 50, 1, 47, 51, 47, 17, 51, 16, 237, 50, 113, 16, 222, 237, 18, 57, 47, 49, 48, 43, 43, 1, 20, 2, 14, 1, 35, 33, 17, 35, 53, 51, 17, 33, 50, 4, 22, 18, 5, 52, 46, 2, 43, 1, 17, 33, 21, 33, 17, 51, 50, 62, 2, 5, 113, 106, 184, 251, 145, 253, 198, 129, 129, 1, 254, 164, 1, 18, 198, 110, 254, 215, 67, 120, 167, 101, 209, 1, 100, 254, 156, 250, 89, 151, 111, 63, 2, 203, 176, 254, 245, 180, 92, 2, 82, 219, 2, 84, 82, 170, 254, 250, 180, 123, 175, 112, 53, 254, 147, 219, 254, 149, 61, 122, 181, 0, 255, 255, 0, 137, 0, 0, 5, 61, 7, 31, 18, 38, 0, 49, 0, 0, 17, 7, 2, 159, 1, 142, 0, 0, 0, 19, 64, 11, 1, 20, 5, 38, 1, 0, 31, 47, 8, 18, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 84, 255, 236, 5, 227, 7, 23, 18, 38, 0, 50, 0, 0, 17, 7, 2, 154, 1, 204, 0, 0, 0, 19, 64, 11, 2, 40, 5, 38, 2, 6, 41, 44, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 84, 255, 236, 5, 227, 7, 23, 18, 38, 0, 50, 0, 0, 17, 7, 2, 155, 2, 26, 0, 0, 0, 19, 64, 11, 2, 40, 5, 38, 2, 84, 40, 43, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 84, 255, 236, 5, 227, 7, 43, 18, 38, 0, 50, 0, 0, 17, 7, 2, 156, 1, 197, 0, 0, 0, 21, 180, 2, 41, 5, 38, 2, 184, 255, 255, 180, 46, 40, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 84, 255, 236, 5, 227, 7, 31, 18, 38, 0, 50, 0, 0, 17, 7, 2, 159, 1, 190, 0, 0, 0, 21, 180, 2, 40, 5, 38, 2, 184, 255, 248, 180, 51, 67, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 84, 255, 236, 5, 227, 6, 213, 18, 38, 0, 50, 0, 0, 17, 7, 2, 158, 1, 198, 0, 0, 0, 25, 182, 3, 2, 40, 5, 38, 3, 2, 184, 255, 255, 180, 44, 42, 10, 0, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 1, 0, 86, 0, 168, 4, 86, 4, 170, 0, 11, 0, 125, 185, 0, 4, 255, 232, 64, 23, 20, 33, 72, 35, 4, 51, 4, 67, 4, 3, 10, 24, 20, 33, 72, 44, 10, 60, 10, 76, 10, 3, 7, 184, 255, 232, 64, 59, 20, 33, 72, 35, 7, 51, 7, 67, 7, 3, 1, 24, 20, 33, 72, 44, 1, 60, 1, 76, 1, 3, 4, 32, 10, 48, 10, 80, 10, 3, 10, 7, 16, 1, 32, 1, 64, 1, 96, 1, 112, 1, 144, 1, 192, 1, 7, 0, 1, 32, 1, 160, 1, 192, 1, 240, 1, 5, 1, 184, 255, 192, 180, 13, 16, 72, 1, 178, 0, 25, 63, 43, 93, 113, 51, 1, 47, 93, 51, 49, 48, 93, 43, 93, 43, 0, 93, 43, 93, 43, 19, 9, 1, 55, 9, 1, 23, 9, 1, 7, 9, 1, 86, 1, 100, 254, 160, 158, 1, 96, 1, 96, 158, 254, 160, 1, 96, 158, 254, 160, 254, 156, 1, 70, 1, 102, 1, 96, 156, 254, 162, 1, 96, 158, 254, 158, 254, 162, 160, 1, 98, 254, 154, 0, 3, 0, 84, 255, 183, 5, 228, 5, 193, 0, 26, 0, 38, 0, 50, 0, 232, 185, 0, 48, 255, 240, 64, 19, 10, 0, 77, 42, 16, 9, 0, 77, 36, 16, 10, 0, 77, 36, 8, 9, 0, 77, 30, 184, 255, 248, 64, 9, 9, 0, 77, 25, 24, 9, 0, 77, 16, 184, 255, 240, 179, 10, 0, 77, 16, 184, 255, 232, 64, 10, 9, 0, 77, 15, 32, 9, 10, 0, 76, 12, 184, 255, 240, 64, 14, 9, 0, 77, 2, 16, 10, 0, 77, 2, 32, 9, 0, 77, 1, 184, 255, 232, 179, 10, 0, 77, 1, 184, 255, 240, 64, 10, 9, 0, 77, 25, 16, 9, 10, 0, 76, 12, 184, 255, 232, 179, 10, 0, 77, 12, 184, 255, 240, 64, 59, 9, 0, 77, 30, 43, 31, 42, 4, 39, 27, 91, 15, 12, 25, 1, 4, 4, 14, 18, 52, 39, 91, 0, 48, 4, 1, 15, 4, 31, 4, 2, 4, 31, 42, 30, 43, 4, 46, 34, 95, 23, 12, 15, 1, 25, 4, 23, 9, 26, 26, 23, 19, 46, 95, 9, 13, 13, 9, 4, 0, 63, 51, 47, 16, 237, 63, 51, 47, 17, 18, 23, 57, 16, 237, 17, 23, 57, 1, 47, 93, 93, 51, 237, 16, 222, 50, 17, 23, 57, 237, 17, 23, 57, 49, 48, 0, 43, 43, 43, 1, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 23, 55, 38, 2, 53, 52, 18, 54, 36, 51, 50, 22, 23, 55, 51, 7, 22, 18, 21, 20, 2, 6, 4, 35, 34, 39, 7, 1, 52, 38, 39, 1, 30, 1, 51, 50, 62, 2, 37, 20, 22, 23, 1, 46, 1, 35, 34, 14, 2, 147, 154, 109, 108, 93, 181, 1, 9, 172, 103, 177, 74, 82, 193, 142, 112, 114, 98, 184, 254, 246, 167, 212, 148, 91, 3, 97, 43, 43, 253, 227, 43, 107, 63, 108, 157, 101, 48, 252, 198, 41, 43, 2, 27, 45, 102, 62, 103, 155, 104, 52, 73, 218, 99, 1, 33, 178, 165, 1, 10, 187, 101, 39, 35, 117, 203, 94, 254, 227, 180, 165, 254, 242, 192, 104, 77, 129, 3, 15, 100, 165, 62, 252, 252, 26, 29, 75, 133, 184, 108, 99, 168, 65, 3, 0, 25, 26, 69, 128, 179, 0, 255, 255, 0, 123, 255, 236, 5, 74, 7, 23, 18, 38, 0, 56, 0, 0, 17, 7, 2, 154, 1, 73, 0, 0, 0, 21, 180, 1, 26, 5, 38, 1, 184, 255, 188, 180, 27, 30, 5, 20, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 123, 255, 236, 5, 74, 7, 23, 18, 38, 0, 56, 0, 0, 17, 7, 2, 155, 1, 249, 0, 0, 0, 19, 64, 11, 1, 26, 5, 38, 1, 108, 26, 29, 5, 20, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 123, 255, 236, 5, 74, 7, 43, 18, 38, 0, 56, 0, 0, 17, 7, 2, 156, 1, 139, 0, 0, 0, 21, 180, 1, 27, 5, 38, 1, 184, 255, 254, 180, 32, 26, 5, 20, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 123, 255, 236, 5, 74, 6, 213, 18, 38, 0, 56, 0, 0, 17, 7, 2, 158, 1, 142, 0, 0, 0, 23, 64, 13, 2, 1, 26, 5, 38, 2, 1, 0, 30, 28, 5, 20, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 0, 255, 255, 0, 35, 0, 0, 5, 53, 7, 23, 18, 38, 0, 60, 0, 0, 17, 7, 2, 155, 1, 181, 0, 0, 0, 19, 64, 11, 1, 9, 5, 38, 1, 95, 9, 12, 4, 8, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 0, 2, 0, 137, 0, 0, 5, 16, 5, 129, 0, 16, 0, 27, 0, 66, 64, 39, 17, 91, 0, 29, 22, 11, 7, 90, 32, 8, 48, 8, 2, 8, 6, 95, 22, 21, 95, 11, 95, 22, 111, 22, 2, 95, 11, 111, 11, 2, 22, 11, 22, 11, 7, 9, 3, 7, 18, 0, 63, 63, 18, 57, 57, 47, 47, 93, 93, 16, 237, 16, 237, 1, 47, 93, 237, 50, 50, 16, 222, 237, 49, 48, 1, 20, 14, 2, 35, 33, 17, 33, 17, 33, 21, 33, 50, 30, 2, 5, 52, 38, 35, 33, 17, 33, 50, 62, 2, 5, 16, 61, 126, 194, 133, 254, 162, 254, 217, 1, 39, 1, 82, 135, 198, 130, 63, 254, 215, 131, 131, 254, 207, 1, 57, 66, 95, 63, 30, 2, 225, 91, 165, 124, 74, 254, 229, 5, 129, 233, 63, 115, 162, 103, 110, 124, 254, 37, 36, 65, 88, 0, 0, 1, 0, 143, 255, 236, 4, 169, 5, 204, 0, 63, 0, 135, 185, 0, 62, 255, 240, 64, 11, 9, 10, 0, 76, 27, 16, 9, 10, 0, 76, 2, 184, 255, 240, 64, 44, 9, 10, 0, 76, 57, 70, 24, 31, 70, 50, 8, 64, 11, 14, 72, 50, 64, 9, 15, 72, 8, 24, 50, 50, 24, 8, 3, 39, 17, 70, 0, 65, 159, 65, 1, 80, 65, 1, 38, 70, 208, 39, 1, 39, 184, 255, 192, 179, 36, 40, 72, 39, 184, 255, 192, 64, 18, 9, 12, 72, 39, 17, 57, 31, 3, 5, 34, 80, 45, 0, 39, 14, 79, 5, 22, 0, 63, 237, 196, 63, 237, 18, 23, 57, 1, 47, 43, 43, 93, 237, 93, 93, 16, 222, 237, 18, 23, 57, 47, 47, 47, 43, 43, 16, 237, 16, 237, 49, 48, 43, 43, 43, 1, 20, 14, 2, 35, 34, 38, 39, 53, 30, 3, 51, 50, 54, 53, 52, 46, 4, 53, 52, 62, 4, 53, 52, 38, 35, 34, 6, 21, 17, 33, 17, 52, 62, 2, 51, 50, 30, 2, 21, 20, 14, 4, 21, 20, 30, 4, 4, 169, 44, 95, 146, 102, 71, 129, 62, 24, 60, 62, 61, 25, 81, 74, 50, 75, 88, 75, 50, 33, 50, 57, 50, 33, 93, 88, 103, 108, 254, 231, 60, 123, 186, 126, 114, 168, 109, 53, 33, 50, 59, 50, 33, 50, 74, 88, 74, 50, 1, 56, 73, 122, 88, 49, 20, 23, 206, 11, 21, 17, 10, 69, 57, 46, 68, 59, 57, 73, 95, 66, 46, 69, 58, 50, 53, 62, 40, 65, 78, 127, 141, 252, 11, 3, 239, 111, 177, 123, 66, 54, 91, 122, 68, 54, 85, 68, 54, 45, 41, 20, 28, 49, 55, 65, 85, 113, 255, 255, 0, 52, 255, 236, 4, 120, 5, 222, 18, 38, 0, 68, 248, 0, 17, 7, 0, 67, 0, 174, 0, 0, 0, 21, 180, 2, 69, 17, 38, 2, 184, 255, 153, 180, 70, 73, 5, 41, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 52, 255, 236, 4, 120, 5, 222, 18, 38, 0, 68, 248, 0, 17, 7, 0, 116, 1, 32, 0, 0, 0, 19, 64, 11, 2, 69, 17, 38, 2, 32, 69, 72, 5, 41, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 52, 255, 236, 4, 120, 5, 249, 18, 38, 0, 68, 248, 0, 17, 7, 1, 75, 0, 199, 0, 0, 0, 21, 180, 2, 70, 17, 38, 2, 184, 255, 226, 180, 75, 69, 5, 41, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 52, 255, 236, 4, 120, 5, 196, 18, 38, 0, 68, 248, 0, 17, 7, 1, 82, 0, 176, 0, 0, 0, 21, 180, 2, 69, 17, 38, 2, 184, 255, 210, 180, 80, 96, 5, 41, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 52, 255, 236, 4, 120, 5, 138, 18, 38, 0, 68, 248, 0, 17, 7, 0, 105, 0, 215, 0, 0, 0, 25, 182, 3, 2, 69, 17, 38, 3, 2, 184, 255, 215, 180, 73, 71, 5, 41, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 255, 255, 0, 52, 255, 236, 4, 120, 6, 149, 18, 38, 0, 68, 248, 0, 17, 7, 1, 80, 1, 10, 0, 41, 0, 25, 182, 3, 2, 74, 17, 38, 3, 2, 184, 255, 217, 180, 79, 69, 5, 41, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 3, 0, 66, 255, 236, 6, 200, 4, 78, 0, 61, 0, 76, 0, 85, 0, 175, 64, 13, 15, 24, 9, 10, 0, 76, 11, 24, 9, 10, 0, 76, 38, 184, 255, 224, 64, 38, 9, 10, 0, 76, 3, 38, 82, 48, 71, 19, 68, 68, 13, 47, 56, 70, 57, 57, 83, 70, 191, 47, 207, 47, 223, 47, 3, 47, 87, 95, 87, 1, 32, 87, 1, 30, 71, 31, 184, 255, 192, 64, 55, 21, 24, 72, 31, 31, 74, 71, 79, 13, 95, 13, 111, 13, 3, 13, 68, 48, 81, 19, 82, 82, 62, 77, 25, 81, 36, 41, 36, 31, 30, 47, 30, 127, 30, 143, 30, 4, 30, 30, 36, 16, 53, 62, 79, 8, 16, 56, 32, 56, 2, 56, 56, 0, 8, 22, 0, 63, 51, 51, 47, 93, 16, 237, 50, 63, 51, 47, 93, 17, 51, 16, 237, 50, 18, 57, 47, 51, 237, 50, 1, 47, 93, 237, 51, 47, 43, 237, 93, 93, 16, 222, 113, 237, 51, 47, 237, 17, 18, 57, 47, 51, 237, 50, 57, 57, 49, 48, 0, 43, 1, 43, 43, 5, 34, 38, 39, 14, 3, 35, 34, 46, 2, 53, 52, 62, 2, 63, 1, 53, 52, 46, 2, 35, 34, 14, 2, 7, 37, 62, 3, 51, 50, 23, 62, 1, 51, 50, 30, 2, 29, 1, 33, 20, 30, 2, 51, 50, 54, 55, 5, 14, 3, 37, 50, 62, 2, 61, 1, 7, 14, 3, 21, 20, 22, 1, 34, 14, 2, 7, 33, 46, 1, 4, 229, 151, 220, 63, 29, 77, 101, 127, 79, 79, 126, 88, 47, 69, 120, 160, 91, 240, 22, 43, 63, 40, 37, 59, 42, 27, 5, 254, 219, 12, 65, 114, 166, 114, 217, 116, 69, 173, 96, 128, 181, 116, 54, 253, 74, 26, 55, 85, 59, 74, 94, 20, 1, 9, 18, 65, 108, 161, 252, 152, 57, 92, 66, 35, 152, 48, 85, 64, 38, 75, 3, 51, 43, 75, 55, 34, 2, 1, 164, 8, 110, 20, 113, 116, 50, 84, 61, 34, 43, 83, 122, 78, 96, 130, 81, 37, 2, 4, 55, 59, 79, 50, 21, 14, 35, 59, 45, 14, 71, 117, 86, 47, 107, 57, 50, 89, 160, 223, 135, 19, 65, 113, 83, 47, 63, 66, 23, 46, 104, 87, 57, 196, 49, 79, 101, 51, 45, 2, 2, 11, 35, 66, 57, 77, 75, 2, 237, 29, 63, 100, 70, 131, 131, 0, 0, 0, 255, 255, 0, 80, 254, 87, 4, 55, 4, 78, 18, 38, 0, 70, 0, 0, 17, 7, 0, 120, 1, 35, 0, 0, 0, 11, 182, 1, 9, 40, 33, 5, 28, 37, 1, 43, 53, 0, 0, 0, 255, 255, 0, 80, 255, 236, 4, 45, 5, 222, 18, 38, 0, 72, 0, 0, 17, 7, 0, 67, 0, 221, 0, 0, 0, 21, 180, 2, 40, 17, 38, 2, 184, 255, 223, 180, 41, 44, 5, 15, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 80, 255, 236, 4, 45, 5, 222, 18, 38, 0, 72, 0, 0, 17, 7, 0, 116, 1, 75, 0, 0, 0, 19, 64, 11, 2, 40, 17, 38, 2, 98, 40, 43, 5, 15, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 80, 255, 236, 4, 45, 5, 249, 18, 38, 0, 72, 0, 0, 17, 7, 1, 75, 0, 223, 0, 0, 0, 19, 64, 11, 2, 41, 17, 38, 2, 17, 46, 40, 5, 15, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 80, 255, 236, 4, 45, 5, 138, 18, 38, 0, 72, 0, 0, 17, 7, 0, 105, 0, 244, 0, 0, 0, 23, 64, 13, 3, 2, 40, 17, 38, 3, 2, 11, 44, 42, 5, 15, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 0, 255, 255, 255, 192, 0, 0, 1, 189, 5, 222, 18, 38, 0, 241, 0, 0, 17, 7, 0, 67, 255, 126, 0, 0, 0, 21, 180, 1, 4, 17, 38, 1, 184, 255, 161, 180, 5, 8, 0, 2, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 114, 0, 0, 2, 112, 5, 222, 18, 38, 0, 241, 0, 0, 17, 6, 0, 116, 27, 0, 0, 19, 64, 11, 1, 4, 17, 38, 1, 83, 4, 7, 0, 2, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 255, 173, 0, 0, 2, 142, 5, 249, 18, 38, 0, 241, 0, 0, 17, 6, 1, 75, 173, 0, 0, 19, 64, 11, 1, 5, 17, 38, 1, 0, 10, 4, 0, 2, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 255, 216, 0, 0, 2, 99, 5, 138, 18, 38, 0, 241, 0, 0, 17, 6, 0, 105, 200, 0, 0, 23, 64, 13, 2, 1, 4, 17, 38, 2, 1, 0, 8, 6, 0, 2, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 2, 0, 80, 255, 238, 4, 147, 5, 223, 0, 39, 0, 53, 0, 167, 185, 0, 2, 255, 248, 64, 11, 9, 10, 0, 76, 28, 64, 9, 10, 0, 76, 1, 184, 255, 216, 180, 9, 10, 0, 76, 37, 184, 255, 240, 180, 9, 10, 0, 76, 31, 184, 255, 208, 64, 24, 9, 10, 0, 76, 24, 46, 40, 71, 6, 0, 37, 27, 30, 4, 33, 39, 15, 28, 31, 28, 2, 28, 28, 33, 184, 255, 192, 64, 44, 9, 15, 72, 33, 39, 33, 39, 16, 6, 55, 46, 71, 16, 37, 30, 0, 27, 4, 28, 39, 38, 38, 33, 29, 28, 24, 43, 79, 21, 80, 21, 96, 21, 2, 28, 21, 28, 21, 33, 0, 51, 79, 11, 22, 0, 63, 237, 63, 57, 57, 47, 47, 93, 16, 237, 57, 17, 51, 17, 51, 47, 51, 18, 23, 57, 1, 47, 237, 16, 206, 17, 57, 57, 47, 47, 43, 51, 47, 93, 17, 18, 23, 57, 16, 237, 17, 57, 49, 48, 43, 0, 43, 1, 43, 0, 43, 43, 1, 30, 3, 29, 1, 20, 14, 2, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 22, 23, 46, 1, 39, 5, 53, 55, 46, 1, 39, 33, 30, 1, 23, 37, 21, 3, 52, 38, 35, 34, 6, 21, 20, 30, 2, 51, 50, 54, 3, 88, 69, 116, 84, 46, 68, 137, 206, 137, 132, 202, 138, 71, 67, 136, 206, 138, 46, 90, 27, 34, 70, 46, 254, 220, 166, 57, 133, 68, 1, 37, 40, 81, 39, 1, 12, 100, 126, 120, 124, 132, 35, 64, 90, 54, 125, 134, 4, 242, 70, 161, 181, 202, 111, 4, 122, 204, 147, 82, 73, 131, 183, 110, 107, 181, 132, 74, 17, 15, 72, 110, 53, 122, 184, 70, 46, 88, 42, 20, 46, 28, 113, 188, 252, 186, 160, 143, 146, 157, 80, 115, 75, 35, 144, 0, 0, 255, 255, 0, 135, 0, 0, 4, 100, 5, 196, 18, 38, 0, 81, 0, 0, 17, 7, 1, 82, 1, 10, 0, 0, 0, 19, 64, 11, 1, 36, 17, 38, 1, 12, 47, 63, 19, 34, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 80, 255, 236, 4, 147, 5, 222, 18, 38, 0, 82, 0, 0, 17, 7, 0, 67, 1, 6, 0, 0, 0, 21, 180, 2, 36, 17, 38, 2, 184, 255, 213, 180, 37, 40, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 80, 255, 236, 4, 147, 5, 222, 18, 38, 0, 82, 0, 0, 17, 7, 0, 116, 1, 122, 0, 0, 0, 19, 64, 11, 2, 36, 17, 38, 2, 94, 36, 39, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 80, 255, 236, 4, 147, 5, 249, 18, 38, 0, 82, 0, 0, 17, 7, 1, 75, 1, 0, 0, 0, 0, 21, 180, 2, 37, 17, 38, 2, 184, 255, 255, 180, 42, 36, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 80, 255, 236, 4, 147, 5, 196, 18, 38, 0, 82, 0, 0, 17, 7, 1, 82, 0, 248, 0, 0, 0, 21, 180, 2, 36, 17, 38, 2, 184, 255, 255, 180, 47, 63, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 80, 255, 236, 4, 147, 5, 138, 18, 38, 0, 82, 0, 0, 17, 7, 0, 105, 1, 28, 0, 0, 0, 23, 64, 13, 3, 2, 36, 17, 38, 3, 2, 0, 40, 38, 10, 0, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 0, 0, 3, 0, 49, 0, 170, 4, 52, 4, 170, 0, 3, 0, 7, 0, 11, 0, 77, 64, 40, 6, 14, 2, 5, 1, 14, 15, 5, 1, 19, 3, 5, 1, 10, 2, 170, 9, 1, 1, 12, 13, 9, 173, 64, 8, 14, 4, 1, 5, 14, 0, 173, 160, 1, 1, 1, 4, 173, 5, 178, 0, 63, 237, 214, 93, 237, 43, 0, 24, 16, 77, 246, 26, 237, 17, 18, 1, 57, 47, 196, 253, 196, 16, 198, 95, 94, 93, 43, 1, 24, 16, 77, 230, 49, 48, 1, 53, 51, 21, 1, 53, 33, 21, 1, 53, 51, 21, 1, 186, 238, 253, 137, 4, 3, 253, 134, 238, 3, 193, 233, 233, 254, 120, 224, 224, 254, 113, 233, 233, 0, 0, 0, 0, 3, 0, 1, 255, 201, 4, 218, 4, 109, 0, 27, 0, 35, 0, 47, 0, 128, 185, 0, 26, 255, 208, 64, 17, 9, 10, 0, 76, 12, 48, 9, 10, 0, 76, 7, 32, 9, 10, 0, 76, 21, 184, 255, 208, 64, 11, 9, 10, 0, 76, 8, 32, 9, 10, 0, 76, 22, 184, 255, 232, 179, 10, 0, 77, 22, 184, 255, 224, 64, 40, 9, 0, 77, 39, 31, 40, 30, 4, 28, 36, 71, 25, 22, 8, 11, 4, 14, 24, 0, 49, 28, 71, 10, 14, 40, 30, 39, 31, 4, 43, 33, 79, 23, 19, 16, 43, 79, 9, 5, 22, 0, 63, 51, 237, 63, 51, 237, 17, 23, 57, 1, 47, 51, 237, 16, 222, 50, 17, 23, 57, 237, 17, 23, 57, 49, 48, 0, 43, 43, 43, 43, 43, 1, 43, 43, 1, 20, 14, 2, 35, 34, 38, 39, 7, 35, 55, 46, 1, 53, 52, 62, 2, 51, 50, 22, 23, 55, 51, 7, 30, 1, 5, 20, 23, 1, 38, 35, 34, 6, 5, 52, 38, 39, 1, 30, 1, 51, 50, 62, 2, 4, 147, 69, 138, 206, 137, 99, 161, 64, 113, 183, 197, 59, 59, 67, 136, 206, 138, 104, 163, 63, 101, 184, 184, 59, 54, 252, 228, 17, 1, 151, 60, 108, 124, 132, 1, 246, 8, 8, 254, 105, 32, 82, 50, 62, 97, 66, 34, 2, 30, 124, 206, 149, 83, 46, 43, 124, 215, 73, 193, 116, 121, 205, 150, 84, 43, 40, 114, 206, 74, 196, 115, 92, 71, 1, 205, 69, 176, 191, 47, 81, 34, 254, 52, 37, 35, 43, 90, 140, 255, 255, 0, 127, 255, 236, 4, 92, 5, 222, 18, 38, 0, 88, 0, 0, 16, 7, 0, 67, 0, 217, 0, 0, 255, 255, 0, 127, 255, 236, 4, 92, 5, 222, 18, 38, 0, 88, 0, 0, 16, 7, 0, 116, 1, 120, 0, 0, 255, 255, 0, 127, 255, 236, 4, 92, 5, 249, 18, 38, 0, 88, 0, 0, 16, 7, 1, 75, 0, 252, 0, 0, 255, 255, 0, 127, 255, 236, 4, 92, 5, 138, 18, 38, 0, 88, 0, 0, 16, 7, 0, 105, 1, 26, 0, 0, 255, 255, 0, 16, 254, 87, 4, 104, 5, 222, 18, 38, 0, 92, 0, 0, 16, 7, 0, 116, 1, 70, 0, 0, 0, 2, 0, 143, 254, 87, 4, 143, 5, 204, 0, 34, 0, 50, 0, 79, 64, 17, 35, 71, 207, 16, 223, 16, 2, 16, 52, 43, 1, 33, 70, 208, 34, 1, 34, 184, 255, 192, 179, 36, 40, 72, 34, 184, 255, 192, 64, 23, 9, 12, 72, 34, 48, 79, 26, 21, 22, 38, 79, 7, 11, 64, 53, 59, 72, 11, 16, 33, 27, 0, 0, 0, 63, 63, 63, 43, 51, 237, 63, 51, 237, 1, 47, 43, 43, 93, 237, 50, 50, 16, 222, 113, 237, 49, 48, 19, 33, 17, 20, 6, 7, 6, 7, 51, 62, 1, 51, 50, 30, 2, 21, 20, 14, 2, 35, 34, 46, 2, 39, 35, 30, 3, 21, 17, 33, 1, 52, 38, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 54, 143, 1, 25, 1, 1, 1, 1, 4, 51, 178, 117, 103, 150, 97, 47, 49, 102, 157, 107, 48, 95, 86, 73, 26, 6, 1, 2, 2, 1, 254, 231, 2, 219, 111, 112, 42, 83, 65, 41, 40, 65, 82, 42, 108, 117, 5, 204, 254, 50, 30, 60, 24, 28, 26, 107, 92, 80, 142, 195, 116, 117, 198, 144, 81, 20, 45, 73, 54, 5, 40, 53, 59, 25, 254, 97, 3, 177, 172, 166, 32, 79, 134, 101, 99, 131, 78, 32, 165, 0, 255, 255, 0, 16, 254, 87, 4, 104, 5, 138, 18, 38, 0, 92, 0, 0, 16, 7, 0, 105, 0, 241, 0, 0, 255, 255, 0, 51, 0, 0, 5, 145, 6, 169, 18, 38, 0, 36, 0, 0, 17, 7, 1, 77, 1, 140, 1, 78, 0, 19, 64, 11, 2, 23, 5, 38, 2, 0, 21, 22, 4, 7, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 60, 255, 236, 4, 128, 5, 91, 18, 38, 0, 68, 0, 0, 17, 7, 1, 77, 0, 243, 0, 0, 0, 21, 180, 2, 71, 17, 38, 2, 184, 255, 235, 180, 69, 70, 5, 41, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 51, 0, 0, 5, 145, 7, 16, 18, 38, 0, 36, 0, 0, 17, 7, 2, 161, 1, 134, 0, 0, 0, 19, 64, 11, 2, 21, 5, 38, 2, 1, 26, 38, 4, 7, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 60, 255, 236, 4, 128, 5, 226, 18, 38, 0, 68, 0, 0, 17, 7, 1, 78, 1, 27, 0, 0, 0, 21, 180, 2, 69, 17, 38, 2, 184, 255, 230, 180, 74, 86, 5, 41, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 51, 254, 98, 5, 145, 5, 129, 18, 38, 0, 36, 0, 0, 17, 7, 1, 81, 3, 181, 0, 11, 0, 14, 185, 0, 2, 255, 167, 180, 32, 32, 7, 7, 37, 1, 43, 53, 255, 255, 0, 60, 254, 87, 4, 128, 4, 78, 18, 38, 0, 68, 0, 0, 17, 7, 1, 81, 2, 97, 0, 0, 0, 18, 179, 2, 15, 80, 1, 184, 255, 100, 180, 80, 80, 41, 41, 37, 1, 43, 93, 53, 255, 255, 0, 84, 255, 236, 5, 143, 7, 23, 18, 38, 0, 38, 0, 0, 17, 7, 2, 155, 2, 53, 0, 0, 0, 19, 64, 11, 1, 42, 5, 38, 1, 153, 42, 45, 16, 6, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 80, 255, 236, 4, 55, 5, 222, 18, 38, 0, 70, 0, 0, 17, 7, 0, 116, 1, 103, 0, 0, 0, 19, 64, 11, 1, 33, 17, 38, 1, 121, 33, 36, 5, 28, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 84, 255, 236, 5, 143, 7, 43, 18, 38, 0, 38, 0, 0, 17, 7, 2, 156, 1, 204, 0, 0, 0, 19, 64, 11, 1, 43, 5, 38, 1, 48, 48, 42, 16, 6, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 80, 255, 236, 4, 55, 5, 249, 18, 38, 0, 70, 0, 0, 17, 7, 1, 75, 0, 230, 0, 0, 0, 19, 64, 11, 1, 34, 17, 38, 1, 19, 39, 33, 5, 28, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 84, 255, 236, 5, 143, 6, 218, 18, 38, 0, 38, 0, 0, 17, 7, 1, 79, 1, 190, 1, 14, 0, 19, 64, 11, 1, 42, 5, 38, 1, 33, 42, 44, 16, 6, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 80, 255, 236, 4, 55, 5, 204, 18, 38, 0, 70, 0, 0, 17, 7, 1, 79, 1, 4, 0, 0, 0, 11, 182, 1, 21, 33, 35, 5, 28, 37, 1, 43, 53, 0, 0, 0, 255, 255, 0, 84, 255, 236, 5, 143, 7, 43, 18, 38, 0, 38, 0, 0, 17, 7, 2, 157, 1, 184, 0, 0, 0, 19, 64, 11, 1, 42, 5, 38, 1, 28, 44, 50, 16, 6, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 80, 255, 236, 4, 55, 5, 249, 18, 38, 0, 70, 0, 0, 17, 7, 1, 76, 0, 214, 0, 0, 0, 19, 64, 11, 1, 33, 17, 38, 1, 3, 35, 41, 5, 28, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 137, 0, 0, 5, 113, 7, 43, 18, 38, 0, 39, 0, 0, 17, 7, 2, 157, 1, 102, 0, 0, 0, 21, 180, 2, 26, 5, 38, 2, 184, 255, 191, 180, 28, 34, 6, 0, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 84, 255, 236, 5, 193, 5, 204, 16, 38, 0, 71, 0, 0, 17, 7, 2, 152, 4, 91, 0, 75, 0, 18, 64, 10, 2, 65, 0, 2, 120, 64, 64, 32, 32, 37, 1, 43, 53, 0, 63, 53, 255, 255, 0, 8, 0, 0, 5, 113, 5, 129, 16, 6, 0, 144, 0, 0, 0, 2, 0, 84, 255, 236, 4, 217, 5, 204, 0, 44, 0, 61, 0, 124, 64, 55, 44, 44, 25, 41, 16, 0, 45, 70, 7, 4, 4, 3, 223, 7, 1, 7, 64, 36, 40, 72, 7, 63, 143, 63, 1, 55, 71, 192, 25, 208, 25, 2, 48, 25, 1, 25, 6, 43, 82, 44, 3, 44, 50, 81, 30, 35, 30, 0, 30, 16, 30, 32, 30, 3, 30, 184, 255, 192, 64, 17, 14, 17, 72, 44, 30, 44, 30, 1, 57, 79, 16, 20, 22, 11, 21, 1, 0, 0, 63, 63, 63, 51, 237, 17, 57, 57, 47, 47, 43, 93, 17, 51, 16, 237, 17, 51, 16, 237, 50, 1, 47, 93, 113, 237, 113, 16, 206, 43, 93, 50, 50, 47, 16, 237, 50, 50, 50, 17, 57, 47, 49, 48, 1, 53, 33, 21, 51, 21, 35, 17, 20, 22, 23, 33, 46, 3, 53, 35, 14, 1, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 30, 2, 23, 51, 52, 38, 52, 38, 61, 1, 33, 53, 1, 52, 46, 2, 35, 34, 14, 2, 21, 16, 51, 50, 62, 2, 3, 59, 1, 26, 132, 132, 6, 2, 254, 240, 2, 5, 5, 3, 4, 49, 176, 122, 102, 149, 97, 47, 49, 102, 157, 108, 53, 98, 84, 68, 24, 2, 1, 1, 254, 226, 1, 34, 40, 65, 83, 43, 54, 83, 57, 29, 221, 42, 84, 66, 41, 5, 65, 139, 139, 170, 252, 85, 79, 123, 34, 8, 41, 52, 54, 21, 105, 91, 81, 144, 198, 118, 119, 199, 143, 80, 22, 46, 72, 51, 10, 39, 50, 54, 25, 126, 170, 252, 208, 104, 133, 78, 30, 39, 84, 134, 95, 254, 162, 33, 82, 137, 255, 255, 0, 137, 0, 0, 5, 6, 6, 169, 18, 38, 0, 40, 0, 0, 17, 7, 1, 77, 1, 94, 1, 78, 0, 21, 180, 1, 14, 5, 38, 1, 184, 255, 237, 180, 12, 13, 0, 10, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 80, 255, 236, 4, 45, 5, 91, 18, 38, 0, 72, 0, 0, 17, 7, 1, 77, 0, 245, 0, 0, 0, 19, 64, 11, 2, 42, 17, 38, 2, 12, 40, 41, 5, 15, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 137, 0, 0, 5, 6, 7, 16, 18, 38, 0, 40, 0, 0, 17, 7, 2, 161, 1, 97, 0, 0, 0, 21, 180, 1, 12, 5, 38, 1, 184, 255, 247, 180, 17, 29, 0, 10, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 80, 255, 236, 4, 45, 5, 226, 18, 38, 0, 72, 0, 0, 17, 7, 1, 78, 1, 16, 0, 0, 0, 21, 180, 2, 40, 17, 38, 2, 184, 255, 251, 180, 45, 57, 5, 15, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 137, 0, 0, 5, 6, 6, 218, 18, 38, 0, 40, 0, 0, 17, 7, 1, 79, 1, 109, 1, 14, 0, 21, 180, 1, 12, 5, 38, 1, 184, 255, 250, 180, 12, 14, 0, 10, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 80, 255, 236, 4, 45, 5, 204, 18, 38, 0, 72, 0, 0, 17, 7, 1, 79, 0, 241, 0, 0, 0, 11, 182, 2, 7, 40, 42, 5, 15, 37, 1, 43, 53, 0, 0, 0, 255, 255, 0, 137, 254, 87, 5, 6, 5, 129, 18, 38, 0, 40, 0, 0, 17, 7, 1, 81, 2, 237, 0, 0, 0, 18, 179, 1, 15, 23, 1, 184, 255, 106, 180, 23, 23, 10, 10, 37, 1, 43, 93, 53, 255, 255, 0, 80, 254, 104, 4, 45, 4, 78, 18, 38, 0, 72, 0, 0, 17, 7, 1, 81, 1, 207, 0, 17, 0, 23, 180, 2, 51, 51, 29, 2, 184, 255, 244, 180, 51, 51, 29, 29, 37, 1, 43, 53, 0, 16, 60, 47, 53, 0, 0, 0, 255, 255, 0, 137, 0, 0, 5, 6, 7, 43, 18, 38, 0, 40, 0, 0, 17, 7, 2, 157, 1, 111, 0, 0, 0, 21, 180, 1, 12, 5, 38, 1, 184, 255, 253, 180, 14, 20, 0, 10, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 80, 255, 236, 4, 45, 5, 249, 18, 38, 0, 72, 0, 0, 17, 7, 1, 76, 0, 216, 0, 0, 0, 19, 64, 11, 2, 40, 17, 38, 2, 10, 42, 48, 5, 15, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 84, 255, 236, 5, 186, 7, 43, 18, 38, 0, 42, 0, 0, 17, 7, 2, 156, 1, 199, 0, 0, 0, 19, 64, 11, 1, 47, 5, 38, 1, 21, 52, 46, 20, 9, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 84, 254, 78, 4, 90, 5, 249, 18, 38, 0, 74, 0, 0, 17, 7, 1, 75, 0, 233, 0, 0, 0, 19, 64, 11, 2, 71, 17, 38, 2, 2, 76, 70, 28, 43, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 84, 255, 236, 5, 186, 7, 16, 18, 38, 0, 42, 0, 0, 17, 7, 2, 161, 1, 205, 0, 0, 0, 19, 64, 11, 1, 46, 5, 38, 1, 35, 51, 63, 20, 9, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 84, 254, 78, 4, 90, 5, 226, 18, 38, 0, 74, 0, 0, 17, 7, 1, 78, 1, 54, 0, 0, 0, 19, 64, 11, 2, 70, 17, 38, 2, 8, 75, 87, 28, 43, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 84, 255, 236, 5, 186, 6, 218, 18, 38, 0, 42, 0, 0, 17, 7, 1, 79, 1, 211, 1, 14, 0, 19, 64, 11, 1, 46, 5, 38, 1, 32, 46, 48, 20, 9, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 84, 254, 78, 4, 90, 5, 204, 18, 38, 0, 74, 0, 0, 17, 7, 1, 79, 1, 29, 0, 0, 0, 11, 182, 2, 26, 70, 72, 28, 43, 37, 1, 43, 53, 0, 0, 0, 255, 255, 0, 84, 254, 57, 5, 186, 5, 150, 18, 38, 0, 42, 0, 0, 17, 7, 2, 146, 2, 78, 0, 0, 0, 11, 182, 1, 40, 56, 46, 20, 9, 37, 1, 43, 53, 0, 0, 0, 255, 255, 0, 84, 254, 78, 4, 90, 6, 73, 16, 38, 0, 74, 0, 0, 17, 7, 2, 153, 1, 137, 0, 0, 0, 25, 64, 16, 2, 79, 17, 38, 2, 19, 70, 78, 28, 43, 37, 82, 64, 33, 33, 72, 43, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 137, 0, 0, 5, 61, 7, 43, 18, 38, 0, 43, 0, 0, 17, 7, 2, 156, 1, 147, 0, 0, 0, 19, 64, 11, 1, 13, 5, 38, 1, 5, 18, 12, 4, 10, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 143, 0, 0, 4, 100, 7, 122, 18, 38, 0, 75, 0, 0, 17, 7, 2, 156, 1, 46, 0, 79, 0, 19, 64, 11, 1, 33, 2, 38, 1, 10, 38, 32, 23, 8, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 0, 2, 0, 14, 0, 0, 5, 185, 5, 129, 0, 19, 0, 23, 0, 106, 64, 65, 20, 12, 0, 90, 17, 15, 19, 25, 64, 25, 80, 25, 96, 25, 3, 112, 25, 128, 25, 2, 32, 25, 48, 25, 160, 25, 192, 25, 4, 23, 11, 3, 90, 6, 8, 32, 4, 48, 4, 2, 4, 22, 18, 6, 95, 7, 15, 11, 7, 2, 96, 23, 127, 7, 1, 7, 23, 7, 23, 13, 9, 3, 4, 0, 18, 0, 63, 50, 63, 51, 57, 57, 47, 47, 93, 16, 237, 17, 51, 51, 16, 237, 50, 50, 1, 47, 93, 51, 51, 237, 50, 50, 93, 113, 114, 16, 222, 50, 50, 237, 50, 50, 49, 48, 33, 17, 33, 17, 33, 17, 35, 53, 51, 53, 33, 21, 33, 53, 33, 21, 51, 21, 35, 17, 1, 53, 33, 21, 4, 33, 253, 143, 254, 217, 123, 123, 1, 39, 2, 113, 1, 28, 124, 124, 254, 228, 253, 143, 2, 92, 253, 164, 4, 21, 170, 194, 194, 194, 194, 170, 251, 235, 3, 80, 197, 197, 0, 1, 0, 10, 0, 0, 4, 100, 5, 204, 0, 39, 0, 136, 185, 0, 5, 255, 224, 182, 8, 0, 77, 144, 31, 1, 31, 184, 255, 192, 64, 40, 9, 13, 72, 31, 31, 22, 10, 70, 224, 9, 240, 9, 2, 9, 41, 144, 41, 160, 41, 2, 112, 41, 240, 41, 2, 239, 41, 1, 33, 30, 22, 70, 23, 25, 25, 27, 208, 23, 1, 23, 184, 255, 192, 179, 36, 40, 72, 23, 184, 255, 192, 181, 8, 12, 72, 23, 33, 25, 184, 1, 15, 64, 14, 30, 26, 26, 3, 28, 0, 23, 9, 21, 16, 80, 0, 3, 15, 0, 63, 51, 237, 63, 51, 63, 18, 57, 47, 51, 237, 50, 1, 47, 43, 43, 93, 51, 51, 47, 16, 237, 50, 50, 93, 113, 114, 16, 222, 93, 237, 18, 57, 47, 43, 93, 49, 48, 0, 43, 1, 62, 1, 51, 50, 30, 2, 21, 17, 33, 17, 52, 46, 2, 35, 34, 14, 2, 21, 17, 33, 17, 35, 53, 51, 53, 33, 21, 33, 21, 33, 21, 20, 14, 2, 7, 1, 164, 57, 172, 119, 98, 135, 85, 38, 254, 232, 20, 46, 74, 53, 51, 83, 60, 33, 254, 231, 133, 133, 1, 25, 1, 50, 254, 206, 2, 3, 2, 1, 3, 58, 124, 112, 64, 112, 152, 88, 253, 122, 2, 54, 63, 105, 75, 42, 45, 83, 115, 69, 253, 229, 4, 151, 170, 139, 139, 170, 136, 32, 65, 57, 46, 13, 0, 0, 0, 255, 255, 255, 153, 0, 0, 2, 165, 7, 31, 18, 38, 0, 44, 0, 0, 17, 6, 2, 159, 202, 0, 0, 19, 64, 11, 1, 4, 5, 38, 1, 2, 15, 31, 0, 2, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 255, 153, 0, 0, 2, 165, 5, 196, 18, 38, 0, 241, 0, 0, 17, 6, 1, 82, 167, 0, 0, 19, 64, 11, 1, 4, 17, 38, 1, 1, 15, 31, 0, 2, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 255, 236, 0, 0, 2, 80, 6, 169, 18, 38, 0, 44, 0, 0, 17, 7, 1, 77, 255, 200, 1, 78, 0, 19, 64, 11, 1, 6, 5, 38, 1, 1, 4, 5, 0, 2, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 255, 236, 0, 0, 2, 80, 5, 91, 18, 38, 0, 241, 0, 0, 17, 6, 1, 77, 200, 0, 0, 19, 64, 11, 1, 6, 17, 38, 1, 0, 4, 5, 0, 2, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 255, 188, 0, 0, 2, 128, 7, 16, 18, 38, 0, 44, 0, 0, 17, 6, 2, 161, 193, 0, 0, 19, 64, 11, 1, 4, 5, 38, 1, 1, 9, 21, 0, 2, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 255, 189, 0, 0, 2, 129, 5, 226, 18, 38, 0, 241, 0, 0, 17, 6, 1, 78, 246, 0, 0, 19, 64, 11, 1, 4, 17, 38, 1, 1, 9, 21, 0, 2, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 88, 254, 87, 1, 220, 5, 129, 18, 38, 0, 44, 0, 0, 17, 6, 1, 81, 12, 0, 0, 14, 185, 0, 1, 255, 223, 180, 15, 15, 2, 2, 37, 1, 43, 53, 0, 0, 255, 255, 0, 69, 254, 87, 1, 201, 5, 204, 18, 38, 0, 76, 0, 0, 17, 6, 1, 81, 249, 0, 0, 14, 185, 0, 2, 255, 212, 180, 19, 19, 7, 7, 37, 1, 43, 53, 0, 0, 255, 255, 0, 137, 0, 0, 1, 176, 6, 218, 18, 38, 0, 44, 0, 0, 17, 7, 1, 79, 255, 202, 1, 14, 0, 19, 64, 11, 1, 4, 5, 38, 1, 2, 4, 6, 0, 2, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 0, 1, 0, 145, 0, 0, 1, 170, 4, 58, 0, 3, 0, 63, 64, 43, 1, 70, 191, 2, 1, 112, 2, 1, 223, 2, 1, 2, 5, 160, 5, 176, 5, 2, 127, 5, 1, 96, 5, 1, 31, 5, 1, 239, 5, 1, 128, 5, 176, 5, 192, 5, 208, 5, 4, 1, 15, 0, 21, 0, 63, 63, 1, 93, 93, 113, 113, 113, 113, 16, 222, 93, 113, 113, 237, 49, 48, 51, 17, 33, 17, 145, 1, 25, 4, 58, 251, 198, 255, 255, 0, 137, 255, 236, 5, 187, 5, 129, 16, 38, 0, 44, 0, 0, 17, 7, 0, 45, 1, 212, 0, 0, 0, 26, 64, 17, 1, 255, 22, 1, 239, 22, 1, 192, 22, 1, 111, 22, 1, 48, 22, 1, 22, 17, 93, 93, 93, 93, 93, 53, 255, 255, 0, 143, 254, 87, 3, 226, 5, 204, 16, 38, 0, 76, 0, 0, 17, 7, 0, 77, 2, 57, 0, 0, 0, 41, 185, 0, 33, 255, 192, 64, 24, 12, 12, 72, 3, 2, 207, 22, 1, 175, 22, 1, 127, 22, 1, 64, 22, 1, 16, 22, 1, 0, 22, 1, 22, 17, 93, 93, 93, 93, 93, 93, 53, 53, 43, 0, 255, 255, 0, 31, 255, 236, 4, 34, 7, 43, 18, 38, 0, 45, 0, 0, 17, 7, 2, 156, 1, 92, 0, 0, 0, 19, 64, 11, 1, 25, 5, 38, 1, 174, 30, 24, 5, 18, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 0, 2, 255, 166, 254, 87, 2, 135, 5, 249, 0, 9, 0, 29, 1, 37, 64, 232, 28, 32, 9, 10, 0, 76, 22, 9, 38, 9, 54, 9, 3, 9, 25, 8, 41, 8, 57, 8, 3, 8, 3, 3, 1, 22, 5, 38, 5, 54, 5, 3, 5, 131, 95, 6, 111, 6, 2, 63, 6, 207, 6, 2, 6, 64, 34, 37, 72, 16, 6, 1, 6, 6, 14, 14, 23, 70, 143, 24, 1, 175, 24, 191, 24, 239, 24, 255, 24, 4, 96, 24, 1, 207, 24, 1, 0, 24, 1, 10, 24, 31, 176, 31, 192, 31, 2, 175, 31, 1, 16, 31, 64, 31, 80, 31, 128, 31, 4, 80, 31, 96, 31, 144, 31, 208, 31, 4, 239, 31, 1, 0, 31, 16, 31, 64, 31, 80, 31, 112, 31, 128, 31, 144, 31, 176, 31, 192, 31, 9, 56, 207, 31, 223, 31, 255, 31, 3, 96, 31, 160, 31, 2, 15, 31, 63, 31, 127, 31, 159, 31, 191, 31, 5, 160, 31, 208, 31, 224, 31, 3, 15, 31, 31, 31, 63, 31, 3, 7, 41, 2, 57, 2, 73, 2, 3, 2, 131, 0, 1, 32, 1, 48, 1, 128, 1, 4, 48, 1, 96, 1, 112, 1, 144, 1, 160, 1, 192, 1, 240, 1, 7, 1, 23, 15, 17, 80, 10, 27, 3, 8, 142, 6, 15, 1, 1, 15, 1, 47, 1, 63, 1, 95, 1, 127, 1, 159, 1, 239, 1, 7, 1, 0, 47, 93, 113, 51, 237, 50, 63, 237, 63, 1, 47, 93, 113, 237, 93, 94, 93, 93, 113, 114, 114, 94, 93, 93, 113, 114, 114, 114, 16, 222, 94, 93, 93, 113, 113, 114, 237, 50, 47, 50, 47, 93, 43, 93, 113, 237, 93, 18, 57, 17, 51, 93, 51, 93, 49, 48, 0, 43, 1, 21, 35, 39, 35, 7, 35, 53, 1, 51, 1, 34, 38, 39, 53, 30, 1, 51, 50, 62, 2, 53, 17, 33, 17, 20, 14, 2, 2, 135, 159, 203, 4, 211, 160, 1, 2, 229, 254, 253, 56, 83, 31, 13, 26, 12, 39, 48, 28, 10, 1, 25, 32, 69, 109, 4, 187, 28, 192, 192, 28, 1, 62, 248, 94, 5, 4, 198, 2, 2, 16, 38, 62, 46, 4, 118, 251, 70, 65, 108, 80, 44, 0, 255, 255, 0, 137, 254, 57, 5, 180, 5, 129, 18, 38, 0, 46, 0, 0, 17, 7, 2, 146, 2, 15, 0, 0, 0, 21, 180, 1, 23, 20, 39, 1, 184, 255, 210, 180, 22, 12, 4, 11, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 143, 254, 57, 4, 117, 5, 204, 18, 38, 0, 78, 0, 0, 17, 7, 2, 146, 1, 121, 0, 0, 0, 14, 185, 0, 1, 255, 217, 180, 22, 12, 4, 11, 37, 1, 43, 53, 0, 1, 0, 143, 0, 0, 4, 117, 4, 58, 0, 11, 0, 128, 185, 0, 9, 255, 248, 64, 14, 10, 0, 77, 0, 40, 10, 0, 77, 1, 24, 10, 0, 77, 10, 184, 255, 232, 64, 16, 9, 0, 77, 8, 24, 9, 0, 77, 1, 10, 11, 8, 9, 9, 0, 11, 184, 255, 192, 64, 15, 9, 12, 72, 11, 16, 11, 11, 13, 7, 3, 70, 208, 4, 1, 4, 184, 255, 192, 179, 36, 40, 72, 4, 184, 255, 192, 64, 16, 9, 12, 72, 4, 2, 7, 10, 1, 7, 1, 8, 5, 15, 4, 0, 21, 0, 63, 50, 63, 51, 57, 57, 17, 51, 17, 51, 1, 47, 43, 43, 93, 237, 50, 17, 51, 47, 56, 43, 51, 51, 17, 51, 17, 57, 57, 49, 48, 43, 43, 43, 43, 43, 33, 1, 7, 17, 33, 17, 33, 17, 1, 33, 9, 1, 3, 66, 254, 223, 121, 254, 231, 1, 25, 1, 130, 1, 46, 254, 132, 1, 153, 1, 234, 84, 254, 106, 4, 58, 254, 64, 1, 192, 254, 90, 253, 108, 0, 0, 255, 255, 0, 137, 0, 0, 4, 164, 7, 23, 18, 38, 0, 47, 0, 0, 17, 7, 2, 155, 0, 173, 0, 0, 0, 21, 180, 1, 6, 5, 38, 1, 184, 255, 109, 180, 6, 9, 0, 4, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 106, 0, 0, 2, 104, 7, 102, 18, 38, 0, 79, 0, 0, 17, 6, 2, 155, 19, 79, 0, 19, 64, 11, 1, 4, 2, 38, 1, 77, 4, 7, 0, 2, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 137, 254, 57, 4, 164, 5, 129, 18, 38, 0, 47, 0, 0, 17, 7, 2, 146, 1, 153, 0, 0, 0, 14, 185, 0, 1, 255, 228, 180, 16, 6, 0, 4, 37, 1, 43, 53, 255, 255, 0, 143, 254, 57, 1, 168, 5, 204, 18, 38, 0, 79, 0, 0, 17, 6, 2, 146, 58, 0, 0, 11, 182, 1, 0, 14, 4, 0, 2, 37, 1, 43, 53, 0, 255, 255, 0, 137, 0, 0, 4, 164, 5, 129, 16, 38, 0, 47, 0, 0, 17, 7, 2, 152, 2, 114, 0, 0, 0, 18, 64, 10, 1, 17, 3, 1, 199, 16, 6, 0, 4, 37, 1, 43, 53, 0, 63, 53, 255, 255, 0, 143, 0, 0, 3, 22, 5, 204, 16, 38, 0, 79, 0, 0, 17, 7, 2, 152, 1, 176, 0, 75, 0, 18, 64, 10, 1, 15, 0, 1, 121, 14, 14, 2, 2, 37, 1, 43, 53, 0, 63, 53, 255, 255, 0, 137, 0, 0, 4, 164, 5, 129, 18, 38, 0, 47, 0, 0, 17, 7, 1, 79, 1, 213, 253, 142, 0, 11, 182, 1, 147, 6, 8, 0, 4, 37, 1, 43, 53, 0, 0, 0, 255, 255, 0, 143, 0, 0, 3, 113, 5, 204, 16, 38, 0, 79, 0, 0, 17, 7, 1, 79, 1, 144, 253, 142, 0, 19, 185, 0, 9, 255, 192, 179, 17, 17, 72, 9, 184, 255, 192, 178, 16, 16, 72, 43, 43, 0, 0, 0, 0, 1, 0, 0, 0, 0, 4, 164, 5, 129, 0, 13, 0, 69, 64, 38, 31, 8, 47, 8, 63, 8, 3, 8, 8, 11, 12, 15, 7, 11, 90, 0, 2, 2, 4, 0, 9, 3, 1, 10, 4, 7, 4, 2, 8, 2, 8, 2, 5, 3, 11, 95, 0, 18, 0, 63, 237, 63, 57, 57, 47, 47, 18, 23, 57, 50, 51, 1, 47, 51, 51, 47, 16, 237, 50, 16, 206, 17, 57, 47, 93, 49, 48, 51, 17, 7, 53, 55, 17, 33, 17, 37, 21, 5, 17, 33, 21, 137, 137, 137, 1, 39, 1, 51, 254, 205, 2, 244, 1, 227, 65, 225, 66, 2, 188, 253, 209, 147, 223, 147, 254, 116, 231, 0, 0, 1, 0, 18, 0, 0, 2, 41, 5, 204, 0, 11, 0, 122, 64, 80, 15, 4, 1, 224, 4, 240, 4, 2, 4, 4, 6, 2, 70, 1, 239, 10, 1, 10, 10, 9, 191, 1, 1, 112, 1, 1, 223, 1, 1, 1, 13, 160, 13, 176, 13, 2, 127, 13, 1, 96, 13, 1, 31, 13, 1, 239, 13, 1, 128, 13, 176, 13, 192, 13, 208, 13, 4, 58, 11, 1, 11, 53, 5, 1, 5, 3, 0, 6, 9, 4, 4, 10, 4, 10, 4, 1, 7, 0, 1, 21, 0, 63, 63, 18, 57, 57, 47, 47, 18, 23, 57, 50, 93, 51, 93, 1, 93, 93, 113, 113, 113, 113, 16, 206, 93, 113, 113, 50, 50, 47, 93, 16, 237, 50, 50, 47, 93, 114, 49, 48, 1, 17, 33, 17, 7, 53, 55, 17, 33, 17, 55, 21, 1, 168, 254, 231, 125, 125, 1, 25, 129, 2, 205, 253, 51, 2, 49, 69, 215, 69, 2, 196, 253, 216, 74, 213, 255, 255, 0, 137, 0, 0, 5, 61, 7, 23, 18, 38, 0, 49, 0, 0, 17, 7, 2, 155, 1, 231, 0, 0, 0, 19, 64, 11, 1, 20, 5, 38, 1, 90, 20, 23, 8, 18, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 135, 0, 0, 4, 100, 5, 222, 18, 38, 0, 81, 0, 0, 17, 7, 0, 116, 1, 132, 0, 0, 0, 19, 64, 11, 1, 36, 17, 38, 1, 100, 36, 39, 19, 34, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 137, 254, 57, 5, 61, 5, 129, 18, 38, 0, 49, 0, 0, 17, 7, 2, 146, 1, 252, 0, 0, 0, 14, 185, 0, 1, 255, 251, 180, 30, 20, 8, 18, 37, 1, 43, 53, 255, 255, 0, 135, 254, 57, 4, 100, 4, 79, 18, 38, 0, 81, 0, 0, 17, 7, 2, 146, 1, 155, 0, 0, 0, 11, 182, 1, 7, 46, 36, 19, 34, 37, 1, 43, 53, 0, 0, 0, 255, 255, 0, 137, 0, 0, 5, 61, 7, 43, 18, 38, 0, 49, 0, 0, 17, 7, 2, 157, 1, 136, 0, 0, 0, 21, 180, 1, 20, 5, 38, 1, 184, 255, 251, 180, 22, 28, 8, 18, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 135, 0, 0, 4, 100, 5, 249, 18, 38, 0, 81, 0, 0, 17, 7, 1, 76, 0, 242, 0, 0, 0, 21, 180, 1, 36, 17, 38, 1, 184, 255, 237, 180, 38, 44, 19, 34, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 255, 234, 0, 0, 5, 44, 5, 129, 16, 39, 0, 81, 0, 200, 0, 0, 17, 7, 2, 9, 255, 95, 0, 0, 0, 66, 185, 0, 1, 255, 182, 64, 43, 36, 36, 14, 14, 37, 0, 192, 0, 1, 175, 0, 1, 127, 0, 1, 32, 0, 1, 16, 0, 1, 15, 0, 1, 224, 0, 1, 160, 0, 1, 112, 0, 1, 111, 0, 1, 63, 0, 1, 0, 0, 1, 0, 17, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 53, 43, 53, 0, 0, 0, 1, 0, 133, 255, 236, 5, 75, 5, 149, 0, 57, 0, 80, 185, 0, 56, 255, 248, 64, 46, 9, 10, 0, 76, 15, 5, 31, 5, 2, 5, 5, 28, 16, 90, 53, 59, 41, 28, 90, 32, 29, 48, 29, 2, 29, 41, 22, 95, 47, 4, 36, 3, 29, 18, 11, 95, 0, 0, 6, 16, 6, 2, 6, 6, 0, 19, 0, 63, 50, 47, 93, 16, 237, 63, 63, 63, 237, 50, 1, 47, 93, 237, 50, 16, 222, 237, 17, 57, 47, 93, 49, 48, 43, 5, 34, 46, 2, 39, 55, 30, 3, 51, 50, 62, 2, 53, 17, 52, 46, 2, 35, 34, 14, 2, 21, 17, 33, 17, 52, 46, 2, 39, 33, 30, 3, 21, 51, 62, 3, 51, 50, 30, 2, 21, 17, 20, 14, 2, 3, 136, 74, 115, 92, 72, 32, 202, 17, 37, 44, 52, 31, 54, 67, 36, 12, 32, 67, 103, 71, 76, 134, 99, 57, 254, 217, 1, 1, 1, 1, 1, 32, 2, 4, 3, 2, 4, 32, 97, 123, 145, 81, 117, 168, 106, 50, 42, 103, 174, 20, 23, 45, 67, 43, 171, 22, 42, 33, 20, 45, 86, 128, 82, 1, 39, 94, 134, 85, 39, 59, 99, 131, 72, 252, 185, 4, 68, 37, 92, 90, 76, 22, 22, 63, 69, 69, 28, 62, 100, 70, 39, 64, 133, 204, 139, 254, 165, 130, 208, 146, 78, 0, 0, 0, 0, 1, 0, 135, 254, 87, 4, 100, 4, 79, 0, 51, 0, 103, 64, 43, 50, 32, 9, 10, 0, 76, 3, 25, 13, 70, 224, 46, 240, 46, 2, 46, 53, 144, 53, 160, 53, 2, 112, 53, 144, 53, 160, 53, 176, 53, 240, 53, 5, 239, 53, 1, 37, 24, 70, 208, 25, 1, 25, 184, 255, 192, 179, 36, 40, 72, 25, 184, 255, 192, 64, 17, 9, 12, 72, 25, 37, 18, 80, 41, 16, 32, 15, 25, 21, 7, 80, 0, 27, 0, 63, 237, 63, 63, 63, 237, 51, 1, 47, 43, 43, 93, 237, 50, 93, 113, 114, 16, 222, 93, 237, 17, 57, 49, 48, 0, 43, 1, 34, 38, 39, 53, 30, 1, 51, 50, 62, 2, 53, 17, 52, 46, 2, 35, 34, 14, 2, 21, 17, 33, 17, 52, 46, 2, 39, 33, 30, 3, 21, 51, 62, 1, 51, 50, 30, 2, 21, 17, 20, 14, 2, 3, 69, 56, 83, 31, 13, 26, 12, 39, 49, 28, 10, 20, 46, 74, 53, 51, 83, 60, 33, 254, 231, 1, 3, 2, 2, 1, 12, 2, 4, 4, 3, 4, 57, 172, 119, 98, 135, 85, 38, 32, 69, 109, 254, 87, 5, 4, 198, 2, 2, 16, 38, 62, 46, 2, 155, 63, 105, 75, 42, 45, 83, 115, 69, 253, 188, 3, 72, 35, 74, 67, 53, 13, 12, 53, 64, 64, 22, 124, 112, 64, 112, 152, 88, 252, 209, 65, 108, 80, 44, 0, 255, 255, 0, 84, 255, 236, 5, 227, 6, 169, 18, 38, 0, 50, 0, 0, 17, 7, 1, 77, 1, 198, 1, 78, 0, 19, 64, 11, 2, 42, 5, 38, 2, 0, 40, 41, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 80, 255, 236, 4, 147, 5, 91, 18, 38, 0, 82, 0, 0, 17, 7, 1, 77, 1, 32, 0, 0, 0, 19, 64, 11, 2, 38, 17, 38, 2, 4, 36, 37, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 84, 255, 236, 5, 227, 7, 16, 18, 38, 0, 50, 0, 0, 17, 7, 2, 161, 1, 181, 0, 0, 0, 21, 180, 2, 40, 5, 38, 2, 184, 255, 247, 180, 45, 57, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 80, 255, 236, 4, 147, 5, 226, 18, 38, 0, 82, 0, 0, 17, 7, 1, 78, 1, 80, 0, 0, 0, 19, 64, 11, 2, 36, 17, 38, 2, 7, 41, 53, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 84, 255, 236, 5, 227, 7, 24, 18, 38, 0, 50, 0, 0, 17, 7, 2, 160, 2, 49, 0, 0, 0, 23, 64, 13, 3, 2, 40, 5, 38, 3, 2, 111, 41, 50, 10, 0, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 0, 255, 255, 0, 80, 255, 236, 4, 147, 5, 204, 18, 38, 0, 82, 0, 0, 17, 7, 1, 83, 1, 129, 0, 0, 0, 23, 64, 13, 3, 2, 36, 17, 38, 3, 2, 100, 37, 46, 10, 0, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 0, 0, 2, 0, 84, 255, 246, 7, 176, 5, 140, 0, 26, 0, 43, 0, 129, 185, 0, 38, 255, 232, 179, 10, 0, 77, 32, 184, 255, 232, 64, 75, 10, 0, 77, 20, 24, 91, 43, 22, 59, 22, 75, 22, 3, 43, 22, 18, 18, 22, 43, 3, 8, 25, 45, 143, 45, 1, 2, 45, 64, 12, 15, 72, 35, 91, 48, 8, 1, 15, 8, 31, 8, 2, 8, 23, 95, 95, 20, 111, 20, 143, 20, 223, 20, 255, 20, 5, 239, 20, 1, 20, 20, 40, 13, 30, 19, 95, 13, 16, 3, 40, 24, 95, 3, 0, 18, 0, 63, 50, 237, 50, 63, 51, 237, 50, 17, 18, 57, 47, 93, 113, 237, 1, 47, 93, 93, 237, 43, 95, 113, 16, 206, 17, 23, 57, 47, 47, 47, 93, 237, 50, 49, 48, 43, 43, 33, 14, 1, 35, 34, 36, 38, 2, 53, 52, 18, 54, 36, 51, 50, 22, 23, 33, 21, 33, 17, 33, 21, 33, 17, 33, 21, 1, 46, 1, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 54, 55, 3, 224, 38, 107, 54, 177, 254, 247, 178, 89, 93, 181, 1, 9, 172, 56, 99, 48, 3, 161, 253, 101, 2, 94, 253, 162, 2, 196, 252, 19, 30, 94, 44, 103, 155, 104, 52, 53, 105, 154, 100, 46, 86, 38, 2, 8, 106, 191, 1, 9, 159, 165, 1, 7, 183, 98, 7, 4, 227, 254, 157, 221, 254, 133, 227, 4, 145, 8, 11, 66, 124, 176, 111, 110, 180, 129, 70, 6, 14, 0, 0, 0, 3, 0, 80, 255, 236, 7, 75, 4, 78, 0, 42, 0, 58, 0, 67, 0, 95, 64, 16, 3, 19, 64, 29, 71, 43, 43, 11, 28, 37, 70, 38, 38, 65, 70, 28, 184, 255, 192, 64, 34, 39, 46, 72, 28, 69, 128, 69, 1, 49, 71, 11, 29, 81, 64, 64, 54, 59, 46, 79, 22, 16, 16, 34, 54, 79, 6, 16, 37, 1, 37, 37, 0, 6, 22, 0, 63, 51, 51, 47, 93, 16, 237, 50, 63, 51, 237, 50, 18, 57, 47, 237, 1, 47, 237, 93, 16, 222, 43, 237, 51, 47, 237, 17, 18, 57, 47, 237, 50, 57, 57, 49, 48, 5, 34, 38, 39, 14, 1, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 22, 23, 62, 1, 51, 50, 30, 2, 29, 1, 33, 20, 30, 2, 51, 50, 54, 55, 5, 14, 3, 1, 52, 38, 35, 34, 6, 21, 20, 30, 2, 51, 50, 62, 2, 1, 34, 14, 2, 7, 33, 46, 1, 5, 104, 118, 185, 66, 69, 196, 129, 132, 202, 137, 70, 67, 136, 206, 138, 134, 194, 66, 71, 190, 106, 128, 181, 116, 54, 253, 74, 26, 55, 85, 59, 74, 94, 20, 1, 9, 18, 65, 108, 161, 253, 146, 126, 120, 124, 132, 35, 64, 90, 54, 62, 97, 66, 34, 1, 251, 43, 75, 55, 34, 2, 1, 164, 8, 110, 20, 79, 80, 76, 83, 82, 148, 207, 125, 121, 205, 150, 84, 80, 73, 81, 72, 89, 160, 223, 135, 19, 65, 113, 83, 47, 63, 66, 23, 46, 104, 87, 57, 2, 50, 193, 174, 176, 191, 97, 140, 90, 43, 43, 90, 140, 1, 224, 29, 63, 100, 70, 131, 131, 255, 255, 0, 137, 0, 0, 5, 157, 7, 23, 18, 38, 0, 53, 0, 0, 17, 7, 2, 155, 1, 205, 0, 0, 0, 19, 64, 11, 2, 29, 5, 38, 2, 16, 29, 32, 4, 17, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 135, 0, 0, 3, 11, 5, 222, 18, 38, 0, 85, 0, 0, 17, 7, 0, 116, 0, 182, 0, 0, 0, 19, 64, 11, 1, 30, 17, 38, 1, 73, 30, 33, 6, 21, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 137, 254, 57, 5, 157, 5, 129, 18, 38, 0, 53, 0, 0, 17, 7, 2, 146, 2, 5, 0, 0, 0, 14, 185, 0, 2, 255, 212, 180, 39, 29, 4, 17, 37, 1, 43, 53, 255, 255, 0, 135, 254, 57, 2, 254, 4, 79, 18, 38, 0, 85, 0, 0, 17, 6, 2, 146, 57, 0, 0, 14, 185, 0, 1, 255, 88, 180, 40, 30, 6, 21, 37, 1, 43, 53, 0, 0, 255, 255, 0, 137, 0, 0, 5, 157, 7, 43, 18, 38, 0, 53, 0, 0, 17, 7, 2, 157, 1, 102, 0, 0, 0, 21, 180, 2, 29, 5, 38, 2, 184, 255, 169, 180, 31, 37, 4, 17, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 56, 0, 0, 3, 25, 5, 249, 18, 38, 0, 85, 0, 0, 17, 6, 1, 76, 56, 0, 0, 21, 180, 1, 30, 17, 38, 1, 184, 255, 230, 180, 32, 38, 6, 21, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 59, 255, 236, 5, 6, 7, 23, 18, 38, 0, 54, 0, 0, 17, 7, 2, 155, 1, 212, 0, 0, 0, 19, 64, 11, 1, 62, 5, 38, 1, 137, 62, 65, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 72, 255, 236, 4, 31, 5, 222, 18, 38, 0, 86, 0, 0, 17, 7, 0, 116, 1, 57, 0, 0, 0, 19, 64, 11, 1, 60, 17, 38, 1, 91, 60, 63, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 59, 255, 236, 5, 6, 7, 43, 18, 38, 0, 54, 0, 0, 17, 7, 2, 156, 1, 113, 0, 0, 0, 19, 64, 11, 1, 63, 5, 38, 1, 38, 68, 62, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 72, 255, 236, 4, 31, 5, 249, 18, 38, 0, 86, 0, 0, 17, 7, 1, 75, 0, 198, 0, 0, 0, 19, 64, 11, 1, 61, 17, 38, 1, 3, 66, 60, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 59, 254, 87, 5, 6, 5, 150, 18, 38, 0, 54, 0, 0, 17, 7, 0, 120, 1, 166, 0, 0, 0, 11, 182, 1, 47, 69, 62, 10, 0, 37, 1, 43, 53, 0, 0, 0, 255, 255, 0, 72, 254, 87, 4, 31, 4, 79, 18, 38, 0, 86, 0, 0, 17, 7, 0, 120, 1, 30, 0, 0, 0, 11, 182, 1, 20, 67, 60, 10, 0, 37, 1, 43, 53, 0, 0, 0, 255, 255, 0, 59, 255, 236, 5, 6, 7, 43, 18, 38, 0, 54, 0, 0, 17, 7, 2, 157, 1, 90, 0, 0, 0, 19, 64, 11, 1, 62, 5, 38, 1, 15, 64, 70, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 72, 255, 236, 4, 31, 5, 249, 18, 38, 0, 86, 0, 0, 17, 7, 1, 76, 0, 205, 0, 0, 0, 19, 64, 11, 1, 60, 17, 38, 1, 10, 62, 68, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 23, 254, 87, 4, 205, 5, 129, 16, 39, 0, 120, 1, 67, 0, 0, 18, 6, 0, 55, 0, 0, 255, 255, 0, 25, 254, 87, 2, 145, 5, 56, 16, 39, 0, 120, 0, 156, 0, 0, 18, 6, 0, 87, 0, 0, 255, 255, 0, 23, 0, 0, 4, 205, 7, 43, 18, 38, 0, 55, 0, 0, 17, 7, 2, 157, 1, 33, 0, 0, 0, 19, 64, 11, 1, 8, 5, 38, 1, 4, 10, 16, 4, 6, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 25, 255, 238, 3, 213, 5, 204, 16, 38, 0, 87, 0, 0, 17, 7, 2, 152, 2, 111, 0, 75, 0, 20, 64, 13, 1, 32, 34, 1, 0, 34, 1, 91, 34, 34, 11, 11, 37, 1, 43, 93, 93, 53, 0, 0, 0, 1, 0, 23, 0, 0, 4, 205, 5, 129, 0, 15, 2, 79, 64, 135, 2, 15, 5, 9, 6, 12, 15, 14, 5, 6, 12, 14, 11, 12, 1, 111, 107, 12, 1, 11, 12, 43, 12, 123, 12, 139, 12, 155, 12, 5, 59, 11, 12, 27, 12, 91, 12, 107, 12, 171, 12, 187, 12, 6, 59, 12, 123, 12, 139, 12, 203, 12, 219, 12, 5, 27, 12, 43, 12, 59, 12, 91, 12, 107, 12, 123, 12, 171, 12, 235, 12, 251, 12, 9, 12, 1, 5, 90, 10, 203, 6, 219, 6, 235, 6, 3, 180, 6, 1, 11, 6, 75, 6, 91, 6, 155, 6, 4, 139, 6, 187, 6, 203, 6, 3, 6, 64, 42, 52, 72, 4, 6, 20, 6, 2, 11, 6, 144, 17, 1, 4, 17, 116, 17, 132, 17, 3, 164, 17, 180, 17, 244, 17, 3, 17, 184, 255, 192, 64, 255, 222, 225, 72, 107, 17, 123, 17, 2, 84, 17, 1, 59, 17, 1, 4, 17, 36, 17, 2, 204, 240, 17, 1, 212, 17, 228, 17, 2, 187, 17, 1, 132, 17, 148, 17, 164, 17, 3, 107, 17, 1, 84, 17, 1, 59, 17, 1, 4, 17, 20, 17, 2, 219, 17, 235, 17, 2, 176, 17, 192, 17, 2, 36, 17, 84, 17, 100, 17, 116, 17, 164, 17, 5, 251, 17, 1, 224, 17, 1, 212, 17, 1, 171, 17, 1, 148, 17, 1, 91, 17, 1, 68, 17, 1, 27, 17, 43, 17, 2, 4, 17, 1, 154, 251, 17, 1, 132, 17, 180, 17, 212, 17, 3, 91, 17, 1, 52, 17, 1, 11, 17, 1, 187, 17, 1, 64, 17, 80, 17, 2, 4, 17, 36, 17, 52, 17, 3, 228, 17, 244, 17, 2, 192, 17, 1, 164, 17, 180, 17, 2, 139, 17, 1, 112, 17, 1, 84, 17, 100, 17, 2, 59, 17, 1, 4, 17, 36, 17, 2, 104, 251, 17, 1, 228, 17, 1, 203, 17, 1, 144, 17, 160, 17, 2, 4, 17, 52, 17, 68, 17, 84, 17, 132, 17, 5, 244, 17, 1, 203, 17, 219, 17, 2, 180, 17, 1, 139, 17, 1, 116, 17, 1, 59, 17, 91, 17, 2, 36, 17, 1, 11, 17, 1, 235, 17, 251, 17, 2, 208, 17, 1, 196, 17, 1, 155, 17, 1, 68, 17, 1, 11, 17, 27, 17, 2, 55, 244, 17, 1, 123, 17, 139, 17, 155, 17, 64, 67, 187, 17, 203, 17, 5, 111, 17, 1, 43, 17, 59, 17, 75, 17, 3, 4, 17, 1, 11, 17, 75, 17, 91, 17, 139, 17, 171, 17, 219, 17, 6, 255, 17, 1, 2, 143, 17, 207, 17, 223, 17, 3, 0, 17, 32, 17, 48, 17, 112, 17, 4, 7, 0, 12, 95, 13, 4, 8, 95, 1, 9, 9, 5, 13, 3, 5, 18, 0, 63, 63, 18, 57, 47, 51, 237, 50, 16, 237, 50, 1, 94, 93, 93, 95, 93, 113, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 43, 93, 113, 113, 47, 94, 93, 43, 93, 113, 114, 114, 51, 237, 50, 198, 93, 113, 114, 94, 93, 114, 94, 93, 43, 1, 24, 16, 77, 230, 17, 18, 57, 17, 18, 57, 49, 48, 1, 17, 51, 21, 35, 17, 33, 17, 35, 53, 51, 17, 33, 53, 33, 21, 3, 5, 228, 228, 254, 217, 227, 227, 254, 57, 4, 182, 4, 157, 254, 147, 190, 253, 142, 2, 114, 190, 1, 109, 228, 228, 0, 0, 1, 0, 25, 255, 238, 2, 145, 5, 56, 0, 31, 0, 113, 64, 72, 2, 40, 9, 10, 0, 76, 19, 19, 16, 16, 95, 28, 1, 28, 14, 18, 28, 3, 22, 70, 3, 6, 9, 7, 11, 9, 3, 79, 3, 95, 3, 111, 3, 3, 3, 64, 38, 44, 72, 160, 3, 1, 3, 17, 9, 79, 10, 14, 10, 12, 12, 10, 15, 21, 5, 79, 18, 223, 6, 1, 127, 6, 191, 6, 239, 6, 3, 6, 25, 79, 0, 22, 0, 63, 237, 47, 93, 113, 51, 237, 50, 63, 51, 47, 17, 51, 16, 237, 50, 1, 47, 93, 43, 113, 23, 51, 47, 50, 16, 237, 23, 50, 47, 93, 51, 47, 51, 47, 49, 48, 43, 5, 34, 38, 61, 1, 35, 53, 51, 53, 35, 53, 51, 55, 51, 21, 51, 21, 35, 21, 51, 21, 35, 21, 20, 22, 51, 50, 54, 55, 21, 14, 1, 1, 164, 124, 134, 127, 127, 137, 151, 88, 176, 205, 205, 185, 185, 60, 63, 26, 42, 26, 52, 116, 18, 135, 137, 219, 190, 229, 190, 254, 254, 190, 229, 190, 143, 79, 75, 8, 6, 174, 17, 17, 255, 255, 0, 123, 255, 236, 5, 74, 7, 31, 18, 38, 0, 56, 0, 0, 17, 7, 2, 159, 1, 141, 0, 0, 0, 19, 64, 11, 1, 26, 5, 38, 1, 0, 37, 53, 5, 20, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 127, 255, 236, 4, 92, 5, 196, 18, 38, 0, 88, 0, 0, 16, 7, 1, 82, 0, 243, 0, 0, 255, 255, 0, 123, 255, 236, 5, 74, 6, 164, 18, 38, 0, 56, 0, 0, 17, 7, 1, 77, 1, 141, 1, 73, 0, 19, 64, 11, 1, 28, 5, 38, 1, 0, 26, 27, 5, 20, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 127, 255, 236, 4, 92, 5, 91, 18, 38, 0, 88, 0, 0, 16, 7, 1, 77, 1, 20, 0, 0, 255, 255, 0, 123, 255, 236, 5, 74, 7, 16, 18, 38, 0, 56, 0, 0, 17, 7, 2, 161, 1, 134, 0, 0, 0, 19, 64, 11, 1, 26, 5, 38, 1, 0, 31, 43, 5, 20, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 127, 255, 236, 4, 92, 5, 226, 18, 38, 0, 88, 0, 0, 16, 7, 1, 78, 1, 71, 0, 0, 255, 255, 0, 123, 255, 236, 5, 74, 7, 186, 18, 38, 0, 56, 0, 0, 17, 7, 1, 80, 1, 191, 1, 78, 0, 23, 64, 13, 2, 1, 31, 5, 38, 2, 1, 1, 36, 26, 5, 20, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 0, 255, 255, 0, 127, 255, 236, 4, 92, 6, 108, 18, 38, 0, 88, 0, 0, 16, 7, 1, 80, 1, 72, 0, 0, 255, 255, 0, 123, 255, 236, 5, 74, 7, 24, 18, 38, 0, 56, 0, 0, 17, 7, 2, 160, 1, 219, 0, 0, 0, 23, 64, 13, 2, 1, 26, 5, 38, 2, 1, 82, 27, 36, 5, 20, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 0, 255, 255, 0, 127, 255, 236, 4, 99, 5, 204, 18, 38, 0, 88, 0, 0, 16, 7, 1, 83, 1, 93, 0, 0, 255, 255, 0, 123, 254, 87, 5, 74, 5, 129, 18, 38, 0, 56, 0, 0, 17, 7, 1, 81, 2, 32, 0, 0, 0, 21, 64, 13, 1, 37, 64, 41, 49, 72, 1, 70, 37, 37, 25, 25, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 127, 254, 87, 4, 92, 4, 58, 18, 38, 0, 88, 0, 0, 16, 7, 1, 81, 2, 133, 0, 0, 255, 255, 0, 2, 0, 0, 7, 139, 7, 43, 18, 38, 0, 58, 0, 0, 17, 7, 2, 156, 2, 115, 0, 0, 0, 19, 64, 11, 1, 50, 5, 38, 1, 2, 55, 49, 17, 48, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 255, 250, 0, 0, 6, 61, 5, 249, 18, 38, 0, 90, 0, 0, 16, 7, 1, 75, 1, 173, 0, 0, 255, 255, 0, 35, 0, 0, 5, 53, 7, 43, 18, 38, 0, 60, 0, 0, 17, 7, 2, 156, 1, 87, 0, 0, 0, 19, 64, 11, 1, 10, 5, 38, 1, 0, 15, 9, 4, 8, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 16, 254, 87, 4, 104, 5, 249, 18, 38, 0, 92, 0, 0, 16, 7, 1, 75, 0, 212, 0, 0, 255, 255, 0, 35, 0, 0, 5, 53, 6, 213, 18, 38, 0, 60, 0, 0, 17, 7, 2, 158, 1, 82, 0, 0, 0, 25, 182, 2, 1, 9, 5, 38, 2, 1, 184, 255, 251, 180, 13, 11, 4, 8, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 255, 255, 0, 61, 0, 0, 4, 168, 7, 23, 18, 38, 0, 61, 0, 0, 17, 7, 2, 155, 1, 130, 0, 0, 0, 19, 64, 11, 1, 10, 5, 38, 1, 101, 10, 13, 1, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 68, 0, 0, 3, 199, 5, 222, 18, 38, 0, 93, 0, 0, 17, 7, 0, 116, 0, 249, 0, 0, 0, 19, 64, 11, 1, 10, 17, 38, 1, 73, 10, 13, 0, 8, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 61, 0, 0, 4, 168, 6, 218, 18, 38, 0, 61, 0, 0, 17, 7, 1, 79, 1, 40, 1, 14, 0, 19, 64, 11, 1, 10, 5, 38, 1, 10, 10, 12, 1, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 68, 0, 0, 3, 199, 5, 204, 18, 38, 0, 93, 0, 0, 17, 7, 1, 79, 0, 189, 0, 0, 0, 11, 182, 1, 12, 10, 12, 0, 8, 37, 1, 43, 53, 0, 0, 0, 255, 255, 0, 61, 0, 0, 4, 168, 7, 43, 18, 38, 0, 61, 0, 0, 17, 7, 2, 157, 1, 45, 0, 0, 0, 19, 64, 11, 1, 10, 5, 38, 1, 16, 12, 18, 1, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 68, 0, 0, 3, 199, 5, 249, 18, 38, 0, 93, 0, 0, 17, 7, 1, 76, 0, 143, 0, 0, 0, 21, 180, 1, 10, 17, 38, 1, 184, 255, 250, 180, 12, 18, 0, 8, 37, 1, 43, 53, 0, 43, 53, 0, 0, 1, 0, 142, 0, 0, 2, 123, 5, 204, 0, 19, 0, 91, 185, 0, 3, 255, 224, 64, 61, 9, 10, 0, 76, 8, 8, 18, 70, 176, 19, 192, 19, 2, 127, 19, 1, 32, 19, 48, 19, 208, 19, 3, 19, 64, 21, 80, 21, 2, 160, 21, 176, 21, 2, 127, 21, 1, 96, 21, 1, 31, 21, 1, 239, 21, 1, 128, 21, 176, 21, 192, 21, 208, 21, 4, 18, 21, 12, 81, 5, 1, 0, 63, 237, 63, 1, 93, 93, 113, 113, 113, 113, 114, 47, 93, 113, 113, 237, 50, 47, 49, 48, 0, 43, 19, 52, 62, 2, 51, 50, 22, 23, 21, 46, 1, 35, 34, 14, 2, 21, 17, 33, 142, 30, 72, 122, 91, 48, 93, 37, 18, 45, 19, 39, 51, 29, 12, 254, 232, 4, 171, 62, 105, 78, 44, 10, 6, 181, 4, 5, 16, 32, 49, 32, 251, 113, 0, 0, 0, 0, 1, 0, 168, 254, 87, 4, 9, 5, 174, 0, 29, 0, 75, 185, 0, 13, 255, 224, 64, 40, 9, 10, 0, 76, 10, 29, 9, 12, 110, 18, 16, 15, 15, 14, 29, 31, 13, 14, 12, 16, 117, 9, 32, 17, 80, 17, 96, 17, 112, 17, 4, 17, 17, 13, 5, 117, 24, 7, 13, 27, 0, 63, 63, 237, 18, 57, 47, 93, 51, 237, 50, 1, 47, 51, 16, 206, 17, 57, 47, 51, 51, 237, 50, 17, 57, 49, 48, 43, 1, 46, 3, 35, 34, 6, 15, 1, 51, 7, 35, 3, 33, 19, 35, 55, 51, 55, 62, 3, 51, 50, 30, 2, 23, 3, 225, 9, 27, 28, 27, 11, 65, 57, 12, 20, 212, 36, 213, 251, 254, 231, 251, 158, 37, 158, 27, 11, 49, 86, 130, 92, 23, 51, 49, 44, 15, 4, 223, 3, 6, 5, 3, 66, 61, 107, 190, 251, 15, 4, 241, 190, 135, 62, 105, 78, 44, 5, 8, 11, 6, 0, 0, 255, 255, 0, 51, 0, 0, 5, 145, 8, 68, 18, 38, 0, 36, 0, 0, 16, 39, 1, 80, 1, 190, 0, 147, 17, 7, 2, 155, 1, 243, 1, 45, 0, 51, 64, 33, 4, 80, 66, 1, 64, 66, 1, 48, 66, 1, 32, 66, 1, 66, 3, 2, 56, 3, 4, 103, 61, 64, 4, 7, 37, 3, 2, 1, 31, 21, 4, 7, 37, 1, 43, 53, 53, 43, 53, 0, 63, 53, 53, 17, 93, 93, 93, 93, 53, 0, 0, 0, 255, 255, 0, 60, 255, 236, 4, 128, 7, 220, 18, 38, 0, 68, 0, 0, 16, 39, 1, 80, 1, 20, 0, 0, 17, 7, 0, 116, 1, 99, 1, 254, 0, 55, 64, 28, 4, 80, 114, 1, 64, 114, 1, 48, 114, 1, 32, 114, 1, 114, 3, 2, 74, 17, 38, 4, 91, 109, 112, 5, 41, 37, 3, 2, 184, 255, 219, 180, 79, 69, 5, 41, 37, 1, 43, 53, 53, 43, 53, 0, 43, 53, 53, 17, 93, 93, 93, 93, 53, 0, 0, 0, 255, 255, 0, 4, 0, 0, 7, 176, 7, 23, 18, 38, 0, 134, 0, 0, 17, 7, 2, 155, 3, 228, 0, 0, 0, 21, 180, 2, 25, 5, 38, 2, 184, 1, 96, 180, 25, 28, 4, 14, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 66, 255, 236, 6, 200, 5, 222, 18, 38, 0, 166, 0, 0, 17, 7, 0, 116, 2, 175, 0, 0, 0, 19, 64, 11, 3, 86, 17, 38, 3, 128, 86, 89, 13, 46, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 84, 255, 183, 5, 228, 7, 23, 18, 38, 0, 152, 0, 0, 17, 7, 2, 155, 2, 26, 0, 0, 0, 19, 64, 11, 3, 51, 5, 38, 3, 84, 51, 54, 4, 18, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 1, 255, 201, 4, 218, 5, 222, 18, 38, 0, 184, 0, 0, 17, 7, 0, 116, 1, 122, 0, 0, 0, 19, 64, 11, 3, 48, 17, 38, 3, 98, 48, 51, 10, 24, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 59, 254, 57, 5, 6, 5, 150, 16, 39, 2, 146, 1, 223, 0, 0, 18, 6, 0, 54, 0, 0, 255, 255, 0, 72, 254, 57, 4, 31, 4, 79, 16, 39, 2, 146, 1, 107, 0, 0, 18, 6, 0, 86, 0, 0, 255, 255, 0, 23, 254, 57, 4, 205, 5, 129, 16, 39, 2, 146, 1, 150, 0, 0, 18, 6, 0, 55, 0, 0, 255, 255, 0, 25, 254, 57, 2, 145, 5, 56, 16, 39, 2, 146, 0, 138, 0, 0, 18, 6, 0, 87, 0, 0, 0, 1, 0, 0, 4, 159, 2, 225, 5, 249, 0, 9, 0, 121, 64, 61, 38, 9, 54, 9, 70, 9, 3, 41, 8, 57, 8, 73, 8, 3, 9, 8, 3, 3, 1, 38, 5, 54, 5, 70, 5, 3, 5, 131, 6, 41, 2, 57, 2, 73, 2, 3, 2, 131, 0, 1, 32, 1, 48, 1, 3, 16, 1, 64, 1, 112, 1, 160, 1, 192, 1, 208, 1, 240, 1, 7, 1, 184, 255, 192, 64, 27, 30, 37, 72, 1, 3, 8, 142, 6, 15, 1, 1, 15, 1, 47, 1, 63, 1, 95, 1, 127, 1, 159, 1, 239, 1, 7, 1, 0, 47, 93, 113, 51, 237, 50, 1, 47, 43, 93, 113, 237, 93, 47, 237, 93, 18, 57, 17, 51, 51, 93, 93, 49, 48, 1, 21, 35, 39, 35, 7, 35, 53, 1, 51, 2, 225, 159, 203, 4, 211, 160, 1, 2, 229, 4, 187, 28, 192, 192, 28, 1, 62, 0, 0, 1, 0, 0, 4, 159, 2, 225, 5, 249, 0, 9, 0, 121, 64, 51, 41, 1, 57, 1, 73, 1, 3, 38, 0, 54, 0, 70, 0, 3, 1, 0, 5, 5, 3, 41, 7, 57, 7, 73, 7, 3, 7, 131, 0, 8, 32, 8, 48, 8, 3, 16, 8, 64, 8, 112, 8, 160, 8, 192, 8, 208, 8, 240, 8, 7, 8, 184, 255, 192, 64, 37, 30, 60, 72, 8, 38, 4, 54, 4, 70, 4, 3, 4, 131, 3, 7, 4, 142, 5, 15, 0, 1, 15, 0, 47, 0, 63, 0, 95, 0, 127, 0, 159, 0, 239, 0, 7, 0, 0, 47, 93, 113, 50, 237, 50, 1, 47, 237, 93, 47, 43, 93, 113, 237, 93, 18, 57, 17, 51, 51, 93, 93, 49, 48, 1, 35, 1, 53, 51, 23, 51, 55, 51, 21, 1, 231, 229, 254, 254, 160, 211, 4, 203, 159, 4, 159, 1, 61, 29, 193, 193, 29, 0, 0, 1, 0, 36, 4, 179, 2, 136, 5, 91, 0, 3, 0, 81, 64, 64, 32, 1, 80, 1, 128, 1, 3, 48, 1, 80, 1, 96, 1, 144, 1, 192, 1, 240, 1, 6, 47, 1, 95, 1, 143, 1, 191, 1, 239, 1, 5, 1, 0, 1, 144, 111, 2, 143, 2, 159, 2, 3, 15, 2, 47, 2, 63, 2, 95, 2, 127, 2, 5, 2, 64, 36, 39, 72, 2, 64, 26, 29, 72, 2, 0, 47, 43, 43, 93, 113, 237, 1, 47, 47, 93, 113, 114, 49, 48, 19, 33, 21, 33, 36, 2, 100, 253, 156, 5, 91, 168, 0, 0, 1, 255, 199, 4, 159, 2, 139, 5, 226, 0, 21, 0, 180, 64, 148, 16, 23, 32, 23, 64, 23, 80, 23, 112, 23, 128, 23, 160, 23, 7, 80, 23, 128, 23, 176, 23, 224, 23, 4, 95, 23, 143, 23, 2, 0, 23, 16, 23, 2, 56, 64, 23, 112, 23, 160, 23, 208, 23, 224, 23, 5, 31, 23, 79, 23, 2, 239, 23, 1, 0, 23, 48, 23, 96, 23, 144, 23, 160, 23, 5, 8, 16, 131, 15, 17, 31, 17, 79, 17, 127, 17, 175, 17, 5, 15, 17, 31, 17, 63, 17, 79, 17, 127, 17, 143, 17, 175, 17, 191, 17, 223, 17, 239, 17, 10, 191, 17, 223, 17, 239, 17, 3, 144, 17, 1, 15, 17, 31, 17, 2, 17, 6, 131, 5, 64, 18, 53, 72, 5, 16, 5, 140, 11, 144, 15, 0, 1, 15, 0, 47, 0, 63, 0, 95, 0, 127, 0, 159, 0, 239, 0, 7, 0, 0, 47, 93, 113, 237, 237, 50, 1, 47, 43, 237, 47, 93, 93, 93, 113, 114, 237, 94, 93, 93, 113, 114, 94, 93, 93, 113, 114, 49, 48, 1, 34, 46, 2, 39, 51, 30, 3, 51, 50, 62, 2, 55, 51, 14, 3, 1, 39, 80, 126, 89, 52, 5, 163, 8, 36, 50, 63, 34, 36, 63, 50, 34, 7, 164, 8, 51, 87, 126, 4, 159, 51, 89, 117, 66, 39, 62, 42, 23, 23, 42, 62, 39, 66, 117, 89, 51, 0, 0, 1, 0, 200, 4, 253, 1, 225, 5, 204, 0, 3, 0, 23, 64, 10, 3, 70, 0, 0, 4, 5, 0, 83, 1, 0, 0, 63, 237, 17, 18, 1, 57, 47, 237, 49, 48, 19, 53, 33, 21, 200, 1, 25, 4, 253, 207, 207, 0, 2, 0, 39, 4, 112, 2, 35, 6, 108, 0, 19, 0, 39, 0, 76, 185, 0, 18, 255, 232, 180, 9, 10, 0, 76, 2, 184, 255, 232, 64, 42, 9, 10, 0, 76, 12, 24, 9, 10, 0, 76, 8, 24, 9, 10, 0, 76, 20, 135, 0, 137, 30, 135, 95, 10, 143, 10, 159, 10, 3, 10, 64, 20, 25, 72, 10, 25, 148, 15, 148, 35, 145, 5, 0, 47, 237, 244, 237, 1, 47, 43, 93, 237, 244, 237, 49, 48, 43, 43, 43, 43, 1, 20, 14, 2, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 30, 2, 7, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 2, 35, 40, 69, 93, 52, 52, 93, 69, 40, 40, 69, 93, 52, 52, 93, 69, 40, 127, 20, 34, 47, 26, 26, 46, 34, 19, 19, 34, 46, 26, 26, 47, 34, 20, 5, 110, 53, 93, 69, 39, 39, 69, 93, 53, 52, 93, 69, 40, 40, 69, 93, 52, 26, 45, 34, 20, 20, 34, 45, 26, 27, 47, 34, 20, 20, 34, 47, 0, 1, 0, 76, 254, 87, 1, 208, 0, 21, 0, 22, 0, 149, 64, 109, 7, 24, 10, 0, 77, 3, 24, 10, 0, 77, 11, 16, 11, 11, 11, 20, 75, 20, 91, 20, 3, 20, 14, 136, 11, 5, 1, 10, 5, 219, 24, 1, 180, 24, 1, 27, 24, 75, 24, 2, 244, 24, 1, 91, 24, 139, 24, 2, 52, 24, 1, 203, 24, 1, 116, 24, 1, 11, 24, 1, 55, 203, 24, 1, 24, 64, 44, 49, 72, 79, 24, 1, 2, 15, 24, 31, 24, 2, 143, 24, 1, 15, 24, 63, 24, 143, 24, 159, 24, 207, 24, 5, 7, 24, 64, 34, 37, 72, 24, 64, 24, 28, 72, 10, 21, 17, 145, 0, 27, 0, 63, 237, 63, 1, 43, 43, 94, 93, 113, 114, 95, 114, 43, 114, 94, 93, 93, 93, 113, 113, 113, 114, 114, 114, 47, 94, 93, 237, 47, 93, 57, 47, 56, 49, 48, 43, 43, 1, 34, 46, 2, 53, 52, 62, 2, 55, 51, 14, 1, 21, 20, 22, 51, 50, 54, 55, 21, 6, 1, 57, 51, 87, 63, 36, 32, 48, 55, 23, 153, 63, 66, 49, 45, 31, 53, 28, 63, 254, 87, 25, 51, 74, 50, 48, 81, 62, 43, 12, 42, 115, 53, 42, 51, 14, 13, 137, 33, 0, 0, 1, 255, 242, 4, 159, 2, 254, 5, 196, 0, 31, 0, 226, 185, 0, 30, 255, 216, 64, 22, 9, 10, 0, 76, 14, 24, 9, 10, 0, 76, 68, 27, 100, 27, 116, 27, 148, 27, 164, 27, 5, 27, 184, 255, 192, 64, 109, 21, 31, 72, 11, 27, 1, 9, 27, 11, 36, 33, 52, 33, 2, 16, 33, 1, 4, 33, 1, 244, 33, 1, 224, 33, 1, 196, 33, 212, 33, 2, 176, 33, 1, 148, 33, 164, 33, 2, 128, 33, 1, 100, 33, 116, 33, 2, 80, 33, 1, 52, 33, 68, 33, 2, 32, 33, 1, 4, 33, 20, 33, 2, 240, 33, 1, 212, 33, 228, 33, 2, 192, 33, 1, 164, 33, 180, 33, 2, 144, 33, 1, 116, 33, 132, 33, 2, 96, 33, 1, 68, 33, 84, 33, 2, 48, 33, 1, 20, 33, 36, 33, 2, 0, 33, 1, 65, 2, 33, 184, 255, 192, 64, 30, 54, 64, 72, 26, 5, 144, 16, 143, 21, 144, 10, 15, 0, 1, 15, 0, 47, 0, 63, 0, 95, 0, 127, 0, 159, 0, 239, 0, 7, 0, 0, 47, 93, 113, 50, 237, 253, 237, 51, 1, 43, 95, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 47, 47, 94, 93, 43, 93, 49, 48, 43, 43, 1, 34, 46, 2, 35, 34, 14, 2, 7, 35, 62, 3, 51, 50, 30, 2, 51, 50, 62, 2, 55, 51, 14, 3, 2, 31, 44, 89, 84, 75, 30, 26, 34, 21, 12, 5, 137, 3, 16, 47, 86, 73, 45, 90, 84, 73, 29, 25, 33, 23, 13, 5, 135, 2, 16, 46, 86, 4, 159, 38, 47, 38, 17, 32, 45, 29, 45, 102, 88, 58, 38, 47, 38, 17, 32, 46, 28, 45, 102, 88, 58, 0, 0, 0, 0, 2, 255, 164, 4, 160, 3, 6, 5, 204, 0, 5, 0, 11, 0, 61, 64, 40, 9, 130, 10, 132, 6, 131, 15, 7, 1, 7, 3, 130, 4, 132, 0, 131, 1, 9, 3, 140, 6, 15, 0, 1, 15, 0, 47, 0, 63, 0, 95, 0, 127, 0, 159, 0, 239, 0, 7, 0, 0, 47, 93, 113, 50, 237, 50, 1, 47, 237, 253, 237, 47, 93, 237, 253, 237, 49, 48, 19, 35, 53, 19, 51, 21, 19, 35, 53, 19, 51, 21, 50, 142, 225, 235, 88, 142, 225, 235, 4, 160, 34, 1, 10, 43, 254, 255, 34, 1, 10, 43, 0, 0, 0, 0, 1, 0, 185, 4, 159, 1, 255, 5, 228, 0, 5, 0, 52, 64, 35, 2, 130, 15, 3, 1, 3, 3, 5, 0, 0, 16, 0, 2, 0, 2, 140, 15, 5, 1, 15, 5, 47, 5, 63, 5, 95, 5, 127, 5, 159, 5, 239, 5, 7, 5, 0, 47, 93, 113, 237, 1, 47, 93, 205, 51, 47, 93, 237, 49, 48, 19, 53, 19, 33, 21, 3, 185, 69, 1, 1, 221, 4, 159, 33, 1, 36, 37, 254, 224, 0, 0, 0, 0, 3, 0, 110, 4, 166, 3, 74, 6, 85, 0, 5, 0, 9, 0, 13, 0, 104, 177, 6, 9, 184, 255, 192, 64, 32, 9, 20, 72, 9, 9, 0, 13, 10, 10, 2, 130, 15, 3, 31, 3, 2, 3, 3, 5, 0, 0, 16, 0, 32, 0, 3, 0, 11, 7, 141, 10, 6, 184, 255, 192, 64, 30, 25, 35, 72, 6, 2, 64, 19, 22, 72, 2, 140, 15, 5, 1, 15, 5, 47, 5, 63, 5, 95, 5, 127, 5, 159, 5, 239, 5, 7, 5, 0, 47, 93, 113, 237, 43, 212, 43, 50, 237, 50, 1, 47, 93, 205, 51, 47, 93, 237, 51, 47, 205, 17, 51, 47, 43, 205, 49, 48, 1, 53, 19, 51, 21, 3, 37, 53, 51, 21, 33, 53, 51, 21, 1, 105, 59, 237, 181, 254, 146, 200, 1, 76, 200, 4, 166, 33, 1, 142, 37, 254, 118, 41, 222, 222, 222, 222, 255, 255, 0, 36, 0, 0, 5, 145, 5, 130, 16, 38, 0, 36, 0, 0, 17, 7, 1, 84, 255, 107, 255, 158, 6, 96, 179, 2, 23, 3, 2, 184, 255, 53, 181, 24, 24, 5, 5, 37, 28, 184, 255, 192, 179, 229, 229, 72, 28, 184, 255, 192, 179, 228, 228, 72, 28, 184, 255, 128, 179, 224, 224, 72, 28, 184, 255, 192, 179, 223, 223, 72, 28, 184, 255, 192, 179, 221, 221, 72, 28, 184, 255, 192, 179, 220, 220, 72, 28, 184, 255, 192, 179, 218, 218, 72, 28, 184, 255, 192, 179, 217, 217, 72, 28, 184, 255, 192, 179, 216, 216, 72, 28, 184, 255, 192, 179, 215, 215, 72, 28, 184, 255, 192, 64, 9, 214, 214, 72, 28, 64, 212, 212, 72, 28, 184, 255, 192, 179, 211, 211, 72, 28, 184, 255, 128, 179, 210, 210, 72, 28, 184, 255, 192, 179, 209, 209, 72, 28, 184, 255, 128, 179, 205, 205, 72, 28, 184, 255, 192, 179, 204, 204, 72, 28, 184, 255, 192, 179, 203, 203, 72, 28, 184, 255, 192, 179, 202, 202, 72, 28, 184, 255, 192, 179, 198, 198, 72, 28, 184, 255, 192, 179, 197, 197, 72, 28, 184, 255, 192, 179, 196, 196, 72, 28, 184, 255, 192, 64, 9, 195, 195, 72, 28, 64, 193, 193, 72, 28, 184, 255, 128, 179, 192, 192, 72, 28, 184, 255, 192, 179, 191, 191, 72, 28, 184, 255, 192, 64, 9, 190, 190, 72, 28, 64, 186, 186, 72, 28, 184, 255, 128, 179, 185, 185, 72, 28, 184, 255, 192, 179, 184, 184, 72, 28, 184, 255, 192, 179, 183, 183, 72, 28, 184, 255, 192, 179, 179, 179, 72, 28, 184, 255, 128, 179, 178, 178, 72, 28, 184, 255, 192, 179, 177, 177, 72, 28, 184, 255, 192, 179, 172, 172, 72, 28, 184, 255, 192, 179, 170, 170, 72, 28, 184, 255, 192, 179, 166, 166, 72, 28, 184, 255, 192, 179, 165, 165, 72, 28, 184, 255, 192, 64, 9, 163, 163, 72, 28, 64, 161, 161, 72, 28, 184, 255, 192, 179, 160, 160, 72, 28, 184, 255, 128, 179, 159, 159, 72, 28, 184, 255, 128, 179, 158, 158, 72, 28, 184, 255, 192, 179, 157, 157, 72, 28, 184, 255, 128, 179, 156, 156, 72, 28, 184, 255, 192, 179, 155, 155, 72, 28, 184, 255, 192, 179, 154, 154, 72, 28, 184, 255, 128, 179, 153, 153, 72, 28, 184, 255, 128, 179, 152, 152, 72, 28, 184, 255, 128, 179, 151, 151, 72, 28, 184, 255, 0, 179, 150, 150, 72, 28, 184, 255, 0, 179, 149, 149, 72, 28, 184, 255, 64, 179, 148, 148, 72, 28, 184, 255, 128, 179, 147, 147, 72, 28, 184, 254, 192, 179, 146, 146, 72, 28, 184, 254, 192, 179, 145, 145, 72, 28, 184, 255, 0, 179, 144, 144, 72, 28, 184, 255, 64, 179, 143, 143, 72, 28, 184, 255, 64, 179, 142, 142, 72, 28, 184, 255, 0, 179, 141, 141, 72, 28, 184, 254, 192, 179, 140, 140, 72, 28, 184, 255, 0, 179, 139, 139, 72, 28, 184, 255, 0, 179, 138, 138, 72, 28, 184, 255, 64, 179, 137, 137, 72, 28, 184, 255, 128, 179, 136, 136, 72, 28, 184, 255, 0, 179, 135, 135, 72, 28, 184, 255, 64, 179, 134, 134, 72, 28, 184, 255, 0, 179, 133, 133, 72, 28, 184, 255, 64, 179, 132, 132, 72, 28, 184, 255, 64, 179, 131, 131, 72, 28, 184, 255, 0, 179, 130, 130, 72, 28, 184, 255, 64, 179, 129, 129, 72, 28, 184, 255, 128, 179, 128, 128, 72, 28, 184, 255, 0, 179, 127, 127, 72, 28, 184, 255, 0, 179, 126, 126, 72, 28, 184, 254, 192, 179, 125, 125, 72, 28, 184, 254, 192, 179, 124, 124, 72, 28, 184, 255, 0, 179, 123, 123, 72, 28, 184, 255, 64, 179, 122, 122, 72, 28, 184, 255, 128, 179, 121, 121, 72, 28, 184, 254, 128, 179, 120, 120, 72, 28, 184, 254, 192, 179, 119, 119, 72, 28, 184, 255, 0, 179, 118, 118, 72, 28, 184, 255, 0, 179, 117, 117, 72, 28, 184, 255, 64, 179, 116, 116, 72, 28, 184, 255, 128, 179, 115, 115, 72, 28, 184, 254, 192, 179, 114, 114, 72, 28, 184, 254, 192, 179, 113, 113, 72, 28, 184, 255, 0, 179, 112, 112, 72, 28, 184, 255, 64, 179, 111, 111, 72, 28, 184, 255, 128, 179, 110, 110, 72, 28, 184, 255, 0, 179, 109, 109, 72, 28, 184, 255, 64, 179, 108, 108, 72, 28, 184, 255, 0, 179, 107, 107, 72, 28, 184, 255, 0, 179, 106, 106, 72, 28, 184, 255, 64, 179, 105, 105, 72, 28, 184, 255, 0, 179, 104, 104, 72, 28, 184, 255, 64, 179, 103, 103, 72, 28, 184, 255, 64, 179, 102, 102, 72, 28, 184, 255, 0, 179, 101, 101, 72, 28, 184, 255, 64, 179, 100, 100, 72, 28, 184, 254, 192, 179, 99, 99, 72, 28, 184, 255, 0, 179, 98, 98, 72, 28, 184, 255, 64, 179, 97, 97, 72, 28, 184, 255, 128, 179, 96, 96, 72, 28, 184, 255, 128, 179, 95, 95, 72, 28, 184, 255, 64, 179, 94, 94, 72, 28, 184, 255, 0, 179, 93, 93, 72, 28, 184, 255, 64, 179, 92, 92, 72, 28, 184, 255, 64, 179, 91, 91, 72, 28, 184, 255, 128, 179, 90, 90, 72, 28, 184, 255, 192, 179, 89, 89, 72, 28, 184, 255, 64, 179, 88, 88, 72, 28, 184, 255, 0, 179, 87, 87, 72, 28, 184, 255, 64, 179, 86, 86, 72, 28, 184, 255, 128, 179, 85, 85, 72, 28, 184, 255, 128, 179, 84, 84, 72, 28, 184, 255, 64, 179, 83, 83, 72, 28, 184, 255, 128, 179, 82, 82, 72, 28, 184, 255, 0, 179, 81, 81, 72, 28, 184, 255, 64, 179, 80, 80, 72, 28, 184, 255, 128, 179, 79, 79, 72, 28, 184, 255, 64, 179, 78, 78, 72, 28, 184, 255, 64, 179, 77, 77, 72, 28, 184, 255, 128, 179, 76, 76, 72, 28, 184, 255, 192, 179, 75, 75, 72, 28, 184, 255, 128, 179, 74, 74, 72, 28, 184, 255, 0, 179, 73, 73, 72, 28, 184, 255, 64, 179, 72, 72, 72, 28, 184, 255, 128, 179, 71, 71, 72, 28, 184, 255, 128, 179, 70, 70, 72, 28, 184, 255, 192, 179, 69, 69, 72, 28, 184, 255, 128, 179, 68, 68, 72, 28, 184, 255, 64, 179, 67, 67, 72, 28, 184, 255, 64, 179, 66, 66, 72, 28, 184, 255, 128, 179, 65, 65, 72, 28, 184, 255, 192, 179, 64, 64, 72, 28, 184, 255, 192, 179, 63, 63, 72, 28, 184, 255, 128, 179, 62, 62, 72, 28, 184, 255, 64, 179, 61, 61, 72, 28, 184, 255, 128, 179, 60, 60, 72, 28, 184, 255, 128, 179, 59, 59, 72, 28, 184, 255, 192, 179, 58, 58, 72, 28, 184, 255, 128, 179, 57, 57, 72, 28, 184, 255, 192, 179, 56, 56, 72, 28, 184, 255, 64, 179, 55, 55, 72, 28, 184, 255, 128, 179, 54, 54, 72, 28, 184, 255, 192, 179, 53, 53, 72, 28, 184, 255, 64, 179, 52, 52, 72, 28, 184, 255, 128, 179, 51, 51, 72, 28, 184, 255, 192, 179, 50, 50, 72, 28, 184, 255, 128, 179, 48, 48, 72, 28, 184, 255, 192, 179, 47, 47, 72, 28, 184, 255, 128, 179, 46, 46, 72, 28, 184, 255, 128, 179, 45, 45, 72, 28, 184, 255, 192, 179, 44, 44, 72, 28, 184, 255, 192, 179, 42, 42, 72, 28, 184, 255, 64, 179, 41, 41, 72, 28, 184, 255, 128, 179, 40, 40, 72, 28, 184, 255, 192, 179, 39, 39, 72, 28, 184, 255, 192, 179, 36, 36, 72, 28, 184, 255, 128, 179, 35, 35, 72, 28, 184, 255, 128, 179, 34, 34, 72, 28, 184, 255, 192, 179, 33, 33, 72, 28, 184, 255, 192, 179, 31, 31, 72, 28, 184, 255, 192, 179, 30, 30, 72, 28, 184, 255, 128, 179, 29, 29, 72, 28, 184, 255, 192, 179, 28, 28, 72, 28, 184, 255, 192, 179, 27, 27, 72, 28, 184, 255, 192, 179, 25, 25, 72, 28, 184, 255, 192, 179, 22, 22, 72, 28, 184, 255, 192, 179, 20, 20, 72, 28, 184, 255, 192, 179, 19, 19, 72, 28, 184, 255, 192, 179, 17, 17, 72, 28, 184, 255, 192, 179, 16, 16, 72, 28, 184, 255, 128, 179, 15, 15, 72, 28, 184, 255, 192, 179, 14, 14, 72, 28, 184, 255, 192, 179, 12, 12, 72, 28, 184, 255, 128, 179, 9, 9, 72, 28, 184, 255, 192, 178, 8, 8, 72, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 1, 43, 53, 0, 63, 53, 0, 0, 255, 255, 0, 197, 2, 19, 1, 229, 3, 68, 18, 6, 2, 145, 56, 0, 255, 255, 0, 46, 0, 0, 6, 131, 5, 130, 16, 39, 0, 40, 1, 125, 0, 0, 17, 7, 1, 84, 255, 117, 255, 158, 0, 44, 179, 1, 14, 3, 1, 184, 255, 110, 64, 22, 15, 15, 1, 1, 37, 0, 160, 0, 1, 143, 0, 1, 79, 0, 1, 63, 0, 1, 47, 0, 1, 0, 17, 93, 93, 93, 93, 93, 53, 43, 53, 0, 63, 53, 255, 255, 0, 36, 0, 0, 6, 181, 5, 130, 16, 39, 0, 43, 1, 120, 0, 0, 17, 7, 1, 84, 255, 107, 255, 158, 0, 44, 179, 1, 14, 3, 1, 184, 255, 105, 64, 22, 15, 15, 4, 4, 37, 0, 207, 0, 1, 175, 0, 1, 79, 0, 1, 63, 0, 1, 47, 0, 1, 0, 17, 93, 93, 93, 93, 93, 53, 43, 53, 0, 63, 53, 255, 255, 0, 36, 0, 0, 3, 65, 5, 130, 16, 39, 0, 44, 1, 145, 0, 0, 17, 7, 1, 84, 255, 107, 255, 158, 0, 60, 179, 1, 6, 3, 1, 184, 255, 80, 64, 34, 7, 7, 0, 0, 37, 0, 240, 0, 1, 239, 0, 1, 207, 0, 1, 223, 0, 1, 143, 0, 1, 127, 0, 1, 64, 0, 1, 63, 0, 1, 0, 0, 1, 0, 17, 93, 93, 93, 93, 93, 93, 93, 93, 93, 53, 43, 53, 0, 63, 53, 255, 255, 255, 230, 255, 236, 6, 67, 5, 150, 16, 38, 0, 50, 96, 0, 17, 7, 1, 84, 255, 45, 255, 158, 0, 67, 180, 2, 42, 3, 2, 40, 184, 255, 192, 178, 9, 17, 72, 184, 255, 50, 64, 32, 40, 40, 10, 10, 37, 1, 0, 111, 0, 1, 111, 0, 1, 95, 0, 1, 79, 0, 1, 63, 0, 1, 15, 0, 1, 255, 0, 1, 96, 0, 1, 0, 17, 93, 93, 113, 113, 113, 113, 113, 113, 53, 53, 43, 43, 53, 0, 63, 53, 0, 0, 0, 255, 255, 0, 128, 0, 0, 7, 73, 5, 130, 16, 39, 0, 60, 2, 20, 0, 0, 17, 6, 1, 84, 199, 158, 0, 76, 182, 1, 11, 3, 1, 0, 12, 1, 184, 255, 143, 64, 43, 12, 12, 4, 4, 37, 0, 255, 0, 1, 208, 0, 1, 207, 0, 1, 191, 0, 1, 144, 0, 1, 143, 0, 1, 127, 0, 1, 80, 0, 1, 79, 0, 1, 63, 0, 1, 16, 0, 1, 15, 0, 1, 0, 17, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 53, 43, 93, 53, 0, 63, 53, 0, 0, 255, 255, 255, 208, 0, 0, 6, 97, 5, 150, 16, 38, 1, 118, 74, 0, 17, 7, 1, 84, 255, 23, 255, 158, 0, 69, 64, 16, 1, 56, 3, 1, 64, 54, 1, 48, 54, 1, 32, 54, 1, 16, 54, 1, 184, 255, 23, 64, 28, 54, 54, 49, 49, 37, 0, 223, 0, 1, 143, 0, 1, 208, 0, 1, 128, 0, 1, 112, 0, 1, 79, 0, 1, 15, 0, 1, 0, 17, 93, 93, 93, 93, 93, 113, 113, 53, 43, 93, 93, 93, 93, 53, 0, 63, 53, 0, 255, 255, 255, 169, 0, 0, 2, 133, 6, 85, 18, 38, 1, 134, 0, 0, 17, 7, 1, 85, 255, 59, 0, 0, 0, 18, 178, 3, 2, 1, 184, 255, 217, 180, 20, 26, 5, 13, 37, 1, 43, 53, 53, 53, 255, 255, 0, 51, 0, 0, 5, 145, 5, 129, 18, 6, 0, 36, 0, 0, 255, 255, 0, 137, 0, 0, 5, 106, 5, 129, 18, 6, 0, 37, 0, 0, 0, 1, 0, 137, 0, 1, 4, 174, 5, 129, 0, 5, 0, 36, 64, 21, 32, 0, 48, 0, 2, 0, 7, 3, 90, 32, 4, 48, 4, 2, 4, 2, 95, 5, 3, 3, 18, 0, 63, 63, 237, 1, 47, 93, 237, 16, 198, 93, 49, 48, 1, 21, 33, 17, 33, 17, 4, 174, 253, 2, 254, 217, 5, 129, 228, 251, 100, 5, 128, 0, 0, 0, 0, 2, 0, 83, 0, 0, 5, 108, 5, 129, 0, 5, 0, 18, 0, 91, 64, 52, 8, 1, 1, 2, 1, 82, 6, 12, 6, 94, 3, 2, 20, 3, 3, 2, 1, 1, 82, 18, 12, 18, 94, 0, 1, 20, 0, 0, 1, 2, 1, 12, 12, 0, 6, 3, 20, 18, 31, 0, 1, 0, 12, 1, 3, 0, 6, 96, 4, 18, 1, 3, 0, 63, 63, 237, 50, 50, 17, 57, 1, 47, 93, 51, 16, 206, 50, 17, 57, 17, 51, 51, 49, 48, 135, 16, 43, 135, 43, 196, 135, 24, 16, 43, 135, 43, 196, 1, 93, 55, 1, 5, 1, 21, 33, 37, 1, 46, 3, 39, 14, 3, 7, 1, 84, 1, 227, 1, 89, 1, 220, 250, 231, 3, 235, 254, 246, 15, 29, 23, 14, 2, 1, 16, 22, 29, 15, 254, 249, 226, 4, 159, 1, 251, 98, 226, 244, 2, 186, 41, 81, 69, 49, 7, 7, 50, 70, 82, 40, 253, 72, 0, 0, 0, 255, 255, 0, 137, 0, 0, 5, 6, 5, 129, 18, 6, 0, 40, 0, 0, 255, 255, 0, 61, 0, 0, 4, 168, 5, 129, 18, 6, 0, 61, 0, 0, 255, 255, 0, 137, 0, 0, 5, 61, 5, 129, 18, 6, 0, 43, 0, 0, 0, 3, 0, 84, 255, 236, 5, 227, 5, 150, 0, 3, 0, 23, 0, 43, 0, 137, 181, 27, 40, 10, 0, 77, 31, 184, 255, 232, 64, 14, 10, 0, 77, 41, 16, 10, 0, 77, 41, 8, 9, 0, 77, 37, 184, 255, 232, 179, 10, 0, 77, 37, 184, 255, 248, 64, 66, 9, 0, 77, 0, 1, 34, 24, 91, 4, 45, 48, 45, 64, 45, 96, 45, 112, 45, 128, 45, 160, 45, 6, 32, 45, 240, 45, 2, 34, 91, 48, 14, 1, 15, 14, 31, 14, 2, 14, 3, 95, 95, 0, 111, 0, 143, 0, 223, 0, 255, 0, 5, 239, 0, 1, 0, 0, 39, 29, 95, 19, 4, 39, 95, 9, 19, 0, 63, 237, 63, 237, 18, 57, 47, 93, 113, 237, 1, 47, 93, 93, 237, 93, 113, 16, 222, 237, 17, 57, 57, 49, 48, 43, 43, 43, 43, 43, 43, 1, 33, 21, 33, 37, 20, 2, 6, 4, 35, 34, 36, 38, 2, 53, 52, 18, 54, 36, 51, 50, 4, 22, 18, 5, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 1, 246, 2, 75, 253, 181, 3, 237, 98, 184, 254, 247, 167, 177, 254, 247, 178, 89, 93, 181, 1, 9, 172, 172, 1, 9, 181, 94, 254, 211, 53, 104, 153, 101, 103, 155, 104, 52, 53, 104, 154, 101, 108, 156, 101, 48, 3, 59, 228, 112, 165, 254, 242, 192, 104, 109, 195, 1, 12, 159, 165, 1, 10, 187, 101, 102, 188, 254, 247, 164, 111, 179, 128, 69, 69, 128, 179, 111, 110, 183, 132, 74, 75, 133, 183, 255, 255, 0, 137, 0, 0, 1, 176, 5, 129, 18, 6, 0, 44, 0, 0, 255, 255, 0, 137, 0, 0, 5, 180, 5, 129, 18, 6, 0, 46, 0, 0, 0, 1, 0, 14, 0, 1, 5, 72, 5, 130, 0, 16, 0, 164, 64, 49, 15, 1, 82, 13, 7, 13, 94, 14, 15, 20, 14, 15, 13, 14, 16, 0, 1, 82, 1, 7, 16, 7, 1, 94, 0, 16, 20, 0, 16, 1, 16, 15, 7, 7, 14, 1, 0, 16, 0, 0, 1, 0, 0, 32, 0, 48, 0, 3, 0, 184, 255, 192, 179, 37, 41, 72, 0, 184, 255, 192, 64, 20, 28, 35, 72, 0, 0, 18, 192, 18, 1, 159, 18, 1, 96, 18, 1, 47, 18, 1, 13, 14, 184, 255, 240, 64, 20, 15, 14, 1, 14, 64, 37, 41, 72, 14, 64, 28, 35, 72, 14, 7, 15, 3, 14, 0, 18, 0, 63, 50, 63, 57, 1, 47, 43, 43, 113, 56, 51, 93, 93, 93, 93, 17, 51, 47, 43, 43, 93, 113, 56, 50, 18, 57, 17, 51, 51, 0, 193, 135, 5, 43, 16, 0, 193, 135, 5, 43, 16, 196, 16, 0, 193, 135, 5, 24, 43, 135, 43, 196, 49, 48, 37, 33, 1, 46, 1, 39, 38, 39, 6, 7, 14, 1, 7, 1, 33, 1, 33, 5, 72, 254, 207, 254, 223, 14, 27, 10, 11, 10, 11, 12, 11, 26, 14, 254, 222, 254, 204, 2, 9, 1, 43, 1, 3, 117, 48, 94, 38, 45, 41, 42, 46, 39, 94, 45, 252, 139, 5, 129, 255, 255, 0, 137, 0, 0, 6, 33, 5, 129, 18, 6, 0, 48, 0, 0, 255, 255, 0, 137, 0, 0, 5, 61, 5, 129, 18, 6, 0, 49, 0, 0, 0, 3, 0, 84, 0, 0, 4, 211, 5, 129, 0, 3, 0, 7, 0, 11, 0, 76, 64, 11, 3, 11, 8, 2, 2, 8, 11, 3, 4, 7, 4, 184, 255, 192, 64, 32, 23, 28, 72, 4, 13, 7, 64, 23, 28, 72, 48, 7, 1, 15, 7, 31, 7, 2, 7, 10, 95, 11, 11, 0, 7, 95, 6, 18, 3, 95, 0, 3, 0, 63, 237, 63, 237, 17, 57, 47, 237, 1, 47, 93, 93, 43, 16, 206, 43, 17, 23, 57, 47, 47, 47, 47, 49, 48, 19, 33, 21, 33, 1, 21, 33, 53, 1, 21, 33, 53, 119, 4, 57, 251, 199, 4, 92, 251, 129, 3, 228, 252, 183, 5, 129, 228, 252, 71, 228, 228, 2, 87, 228, 228, 0, 0, 255, 255, 0, 84, 255, 236, 5, 227, 5, 150, 18, 6, 0, 50, 0, 0, 0, 1, 0, 137, 0, 0, 5, 61, 5, 129, 0, 7, 0, 39, 64, 22, 0, 90, 207, 7, 1, 7, 9, 3, 90, 32, 4, 48, 4, 2, 4, 2, 96, 5, 3, 4, 0, 18, 0, 63, 50, 63, 237, 1, 47, 93, 237, 16, 222, 113, 237, 49, 48, 33, 17, 33, 17, 33, 17, 33, 17, 4, 32, 253, 143, 254, 218, 4, 180, 4, 141, 251, 115, 5, 129, 250, 127, 0, 0, 0, 255, 255, 0, 137, 0, 0, 5, 16, 5, 129, 18, 6, 0, 51, 0, 0, 0, 1, 0, 90, 0, 0, 4, 143, 5, 129, 0, 12, 0, 77, 64, 43, 2, 92, 15, 8, 31, 8, 2, 8, 6, 8, 6, 1, 11, 14, 7, 91, 3, 10, 90, 48, 1, 1, 15, 1, 31, 1, 2, 1, 3, 7, 95, 4, 9, 8, 2, 2, 4, 3, 1, 10, 95, 0, 18, 0, 63, 237, 50, 63, 57, 25, 47, 51, 51, 24, 16, 237, 50, 1, 47, 93, 93, 237, 214, 237, 16, 206, 17, 57, 57, 47, 47, 93, 237, 49, 48, 51, 53, 9, 1, 53, 33, 21, 33, 1, 21, 1, 33, 21, 90, 1, 192, 254, 81, 3, 231, 253, 71, 1, 115, 254, 118, 3, 13, 234, 1, 251, 1, 179, 233, 228, 254, 139, 134, 254, 66, 228, 255, 255, 0, 23, 0, 0, 4, 205, 5, 129, 18, 6, 0, 55, 0, 0, 255, 255, 0, 35, 0, 0, 5, 53, 5, 129, 18, 6, 0, 60, 0, 0, 0, 3, 0, 63, 255, 245, 6, 83, 5, 139, 0, 10, 0, 40, 0, 51, 2, 245, 64, 255, 27, 5, 40, 92, 47, 24, 11, 11, 18, 0, 91, 33, 53, 167, 53, 183, 53, 215, 53, 3, 136, 53, 1, 119, 53, 1, 102, 53, 1, 39, 53, 71, 53, 87, 53, 3, 6, 53, 1, 229, 53, 245, 53, 2, 214, 53, 1, 199, 53, 1, 168, 53, 1, 150, 53, 1, 133, 53, 1, 118, 53, 1, 103, 53, 1, 56, 53, 72, 53, 2, 37, 53, 1, 22, 53, 1, 7, 53, 1, 200, 216, 53, 1, 201, 53, 1, 180, 53, 1, 165, 53, 1, 134, 53, 150, 53, 2, 119, 53, 1, 88, 53, 1, 69, 53, 1, 38, 53, 54, 53, 2, 23, 53, 1, 248, 53, 1, 231, 53, 1, 213, 53, 1, 198, 53, 1, 183, 53, 1, 152, 53, 1, 137, 53, 1, 119, 53, 1, 102, 53, 1, 87, 53, 1, 70, 53, 1, 39, 53, 55, 53, 2, 6, 53, 1, 245, 53, 1, 230, 53, 1, 199, 53, 215, 53, 2, 168, 53, 1, 151, 53, 1, 118, 53, 134, 53, 2, 103, 53, 1, 72, 53, 1, 57, 53, 1, 22, 53, 38, 53, 2, 7, 53, 1, 152, 216, 53, 248, 53, 2, 196, 53, 1, 181, 53, 1, 166, 53, 1, 151, 53, 1, 104, 53, 1, 85, 53, 1, 70, 53, 1, 55, 53, 1, 8, 53, 1, 249, 53, 1, 230, 53, 1, 199, 53, 215, 53, 2, 168, 53, 1, 151, 53, 1, 98, 53, 114, 53, 2, 83, 53, 1, 68, 53, 1, 64, 255, 53, 53, 1, 22, 53, 38, 53, 2, 5, 53, 1, 243, 53, 1, 228, 53, 1, 213, 53, 1, 182, 53, 198, 53, 2, 167, 53, 1, 150, 53, 1, 132, 53, 1, 117, 53, 1, 86, 53, 102, 53, 2, 71, 53, 1, 54, 53, 1, 39, 53, 1, 21, 53, 1, 3, 53, 1, 103, 244, 53, 1, 229, 53, 1, 214, 53, 1, 197, 53, 1, 182, 53, 1, 163, 53, 1, 0, 144, 53, 1, 130, 53, 1, 116, 53, 1, 102, 53, 1, 82, 53, 1, 68, 53, 1, 48, 53, 1, 34, 53, 1, 20, 53, 1, 6, 53, 1, 246, 53, 1, 228, 53, 1, 214, 53, 1, 180, 53, 1, 166, 53, 1, 146, 53, 1, 132, 53, 1, 114, 53, 1, 100, 53, 1, 86, 53, 1, 64, 53, 1, 50, 53, 1, 36, 53, 1, 22, 53, 1, 4, 53, 1, 230, 53, 246, 53, 2, 210, 53, 1, 196, 53, 1, 182, 53, 1, 148, 53, 164, 53, 2, 134, 53, 1, 100, 53, 1, 86, 53, 1, 52, 53, 1, 34, 53, 1, 20, 53, 1, 6, 53, 1, 55, 226, 53, 242, 53, 2, 212, 53, 1, 194, 53, 1, 1, 176, 53, 1, 164, 53, 1, 112, 53, 1, 100, 53, 1, 80, 53, 1, 68, 53, 1, 27, 53, 1, 4, 53, 1, 84, 53, 116, 53, 132, 53, 180, 53, 212, 53, 228, 53, 6, 59, 53, 1, 32, 53, 1, 20, 53, 1, 244, 53, 1, 219, 64, 53, 53, 1, 148, 53, 196, 53, 2, 91, 53, 107, 53, 123, 53, 3, 52, 53, 1, 16, 53, 1, 2, 0, 53, 1, 7, 41, 91, 15, 18, 31, 18, 79, 18, 95, 18, 111, 18, 5, 18, 4, 48, 95, 27, 24, 25, 4, 5, 47, 95, 39, 12, 11, 19, 0, 63, 221, 50, 237, 50, 63, 221, 50, 253, 196, 1, 47, 93, 237, 94, 93, 95, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 95, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 95, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 16, 222, 237, 18, 57, 47, 51, 51, 237, 50, 50, 49, 48, 1, 52, 38, 43, 1, 17, 51, 50, 62, 2, 1, 53, 35, 34, 46, 2, 53, 52, 62, 2, 59, 1, 53, 33, 21, 51, 50, 30, 2, 21, 20, 14, 2, 43, 1, 21, 1, 20, 30, 2, 59, 1, 17, 35, 34, 6, 5, 42, 158, 165, 19, 26, 84, 119, 77, 36, 253, 148, 54, 148, 220, 146, 71, 74, 149, 224, 150, 42, 1, 22, 42, 150, 224, 149, 74, 71, 146, 219, 149, 54, 253, 148, 36, 77, 119, 84, 26, 19, 165, 158, 2, 218, 152, 170, 253, 113, 50, 89, 122, 253, 99, 199, 88, 150, 198, 110, 119, 195, 138, 75, 158, 158, 75, 138, 195, 119, 110, 198, 150, 88, 199, 2, 229, 72, 122, 89, 50, 2, 143, 170, 0, 0, 0, 255, 255, 0, 18, 0, 0, 5, 68, 5, 129, 18, 6, 0, 59, 0, 0, 0, 1, 0, 96, 0, 0, 6, 25, 5, 129, 0, 35, 3, 50, 64, 255, 200, 37, 216, 37, 232, 37, 3, 185, 37, 1, 170, 37, 1, 155, 37, 1, 137, 37, 1, 104, 37, 120, 37, 2, 89, 37, 1, 74, 37, 1, 41, 37, 57, 37, 2, 7, 37, 1, 216, 37, 232, 37, 2, 201, 37, 1, 186, 37, 1, 120, 37, 136, 37, 168, 37, 3, 105, 37, 1, 90, 37, 1, 75, 37, 1, 57, 37, 1, 24, 37, 1, 9, 37, 1, 199, 250, 37, 1, 219, 37, 235, 37, 2, 183, 37, 199, 37, 2, 136, 37, 152, 37, 2, 121, 37, 1, 106, 37, 1, 40, 37, 56, 37, 2, 25, 37, 1, 10, 37, 1, 200, 37, 232, 37, 248, 37, 3, 185, 37, 1, 170, 37, 1, 155, 37, 1, 56, 37, 72, 37, 104, 37, 136, 37, 4, 41, 37, 1, 7, 37, 1, 216, 37, 1, 201, 37, 1, 186, 37, 1, 120, 37, 168, 37, 2, 105, 37, 1, 90, 37, 1, 75, 37, 1, 24, 37, 1, 9, 37, 1, 151, 250, 37, 1, 232, 37, 1, 217, 37, 1, 183, 37, 199, 37, 2, 136, 37, 1, 121, 37, 1, 106, 37, 1, 40, 37, 1, 25, 37, 1, 10, 37, 1, 251, 37, 1, 231, 37, 1, 200, 37, 1, 185, 37, 1, 170, 37, 1, 136, 37, 1, 115, 37, 1, 0, 96, 37, 1, 66, 37, 82, 37, 2, 52, 37, 1, 6, 37, 38, 37, 2, 226, 37, 242, 37, 2, 212, 37, 1, 198, 37, 1, 169, 37, 1, 64, 255, 150, 37, 1, 130, 37, 1, 116, 37, 1, 102, 37, 1, 20, 37, 1, 2, 37, 1, 103, 242, 37, 1, 228, 37, 1, 182, 37, 198, 37, 214, 37, 3, 146, 37, 162, 37, 2, 132, 37, 1, 70, 37, 86, 37, 118, 37, 3, 50, 37, 1, 36, 37, 1, 22, 37, 1, 230, 37, 1, 201, 37, 1, 166, 37, 182, 37, 2, 148, 37, 1, 134, 37, 1, 116, 37, 1, 102, 37, 1, 66, 37, 1, 52, 37, 1, 6, 37, 38, 37, 2, 246, 37, 1, 212, 37, 1, 150, 37, 166, 37, 198, 37, 3, 121, 37, 1, 86, 37, 102, 37, 2, 36, 37, 1, 6, 37, 22, 37, 2, 55, 242, 37, 1, 1, 224, 37, 1, 212, 37, 1, 192, 37, 1, 164, 37, 180, 37, 2, 139, 37, 1, 116, 37, 1, 80, 37, 1, 68, 37, 1, 43, 37, 1, 31, 37, 1, 4, 37, 1, 228, 37, 1, 203, 37, 1, 180, 37, 1, 144, 37, 1, 84, 37, 100, 37, 132, 37, 3, 59, 37, 1, 36, 37, 1, 0, 37, 1, 244, 37, 1, 219, 37, 1, 148, 37, 1, 123, 37, 1, 4, 37, 20, 37, 52, 37, 84, 37, 100, 37, 5, 7, 21, 1, 90, 18, 2, 2, 9, 27, 90, 4, 30, 1, 196, 30, 212, 30, 2, 139, 30, 1, 100, 30, 1, 11, 30, 27, 30, 75, 30, 3, 58, 240, 30, 1, 212, 30, 228, 30, 2, 192, 30, 1, 164, 30, 64, 109, 180, 30, 2, 144, 30, 1, 68, 30, 116, 30, 132, 30, 3, 32, 30, 1, 20, 30, 1, 251, 30, 1, 239, 30, 1, 180, 30, 212, 30, 2, 155, 30, 1, 36, 30, 52, 30, 84, 30, 100, 30, 132, 30, 5, 11, 30, 1, 244, 30, 1, 208, 30, 1, 2, 192, 30, 1, 175, 30, 1, 96, 30, 1, 79, 30, 1, 0, 30, 32, 30, 48, 30, 3, 10, 30, 37, 12, 90, 0, 9, 1, 68, 112, 9, 1, 32, 9, 48, 9, 2, 15, 9, 31, 9, 2, 9, 21, 18, 95, 0, 3, 3, 1, 28, 19, 10, 3, 1, 18, 0, 63, 63, 51, 51, 18, 57, 47, 51, 237, 50, 1, 47, 93, 93, 113, 94, 93, 237, 16, 222, 94, 93, 93, 93, 93, 93, 95, 93, 93, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 113, 237, 17, 57, 47, 51, 237, 50, 94, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 95, 114, 94, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 95, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 49, 48, 1, 17, 33, 17, 35, 34, 46, 2, 53, 17, 33, 17, 20, 30, 2, 59, 1, 17, 33, 17, 51, 50, 62, 2, 53, 17, 33, 17, 20, 14, 2, 35, 3, 200, 254, 233, 40, 144, 209, 135, 65, 1, 23, 35, 74, 115, 81, 9, 1, 23, 9, 81, 115, 74, 35, 1, 23, 65, 135, 209, 144, 1, 171, 254, 85, 1, 171, 67, 131, 194, 127, 1, 207, 254, 45, 80, 112, 70, 32, 2, 249, 253, 7, 32, 70, 112, 80, 1, 211, 254, 49, 127, 194, 131, 67, 0, 0, 1, 0, 83, 0, 0, 6, 23, 5, 150, 0, 53, 0, 113, 185, 0, 29, 255, 240, 64, 66, 10, 0, 77, 25, 16, 10, 0, 77, 44, 36, 10, 18, 64, 36, 96, 36, 2, 79, 18, 111, 18, 2, 36, 18, 36, 18, 49, 22, 91, 5, 5, 207, 16, 1, 16, 55, 32, 90, 176, 49, 1, 49, 49, 192, 38, 1, 15, 38, 31, 38, 2, 38, 19, 19, 35, 35, 15, 38, 95, 18, 37, 18, 27, 95, 0, 4, 0, 63, 237, 63, 51, 237, 50, 50, 47, 51, 47, 1, 47, 93, 113, 50, 47, 113, 237, 16, 206, 113, 50, 47, 237, 18, 57, 57, 47, 47, 93, 93, 17, 51, 17, 51, 49, 48, 43, 43, 1, 50, 4, 30, 1, 21, 20, 14, 2, 7, 54, 55, 62, 1, 51, 33, 21, 33, 17, 62, 1, 53, 52, 46, 2, 35, 34, 14, 2, 21, 20, 22, 23, 17, 33, 53, 33, 50, 22, 23, 22, 23, 46, 3, 53, 52, 62, 1, 36, 3, 53, 165, 1, 7, 184, 98, 48, 104, 161, 113, 31, 32, 27, 62, 26, 1, 20, 253, 97, 181, 162, 55, 105, 154, 98, 99, 153, 106, 55, 163, 181, 253, 101, 1, 18, 26, 62, 27, 32, 30, 112, 161, 102, 48, 98, 184, 1, 7, 5, 150, 82, 156, 223, 141, 102, 177, 153, 128, 51, 3, 3, 2, 3, 228, 1, 53, 86, 231, 148, 101, 158, 108, 57, 57, 108, 158, 101, 148, 231, 86, 254, 203, 228, 3, 2, 3, 3, 51, 128, 153, 178, 102, 141, 223, 155, 82, 0, 0, 0, 255, 255, 255, 215, 0, 0, 2, 98, 6, 213, 18, 38, 0, 44, 0, 0, 17, 6, 2, 158, 200, 0, 0, 23, 64, 13, 2, 1, 4, 5, 38, 2, 1, 0, 8, 6, 0, 2, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 255, 255, 0, 35, 0, 0, 5, 53, 6, 213, 18, 38, 0, 60, 0, 0, 17, 7, 2, 158, 1, 82, 0, 0, 0, 25, 182, 2, 1, 9, 5, 38, 2, 1, 184, 255, 251, 180, 13, 11, 4, 8, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 255, 255, 0, 80, 255, 236, 4, 214, 5, 228, 18, 38, 1, 126, 0, 0, 17, 7, 1, 84, 1, 78, 0, 0, 0, 19, 64, 11, 2, 58, 17, 38, 2, 23, 58, 61, 8, 21, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 77, 255, 236, 3, 171, 5, 228, 16, 38, 1, 130, 0, 0, 17, 7, 1, 84, 0, 238, 0, 0, 5, 245, 64, 12, 1, 56, 17, 38, 1, 78, 56, 59, 14, 4, 37, 63, 184, 1, 128, 179, 229, 229, 72, 63, 184, 1, 64, 179, 228, 228, 72, 63, 184, 1, 128, 179, 227, 227, 72, 63, 184, 1, 64, 179, 226, 226, 72, 63, 184, 1, 64, 179, 225, 225, 72, 63, 184, 1, 64, 179, 224, 224, 72, 63, 184, 1, 64, 179, 223, 223, 72, 63, 184, 1, 64, 179, 222, 222, 72, 63, 184, 1, 64, 179, 221, 221, 72, 63, 184, 1, 64, 179, 220, 220, 72, 63, 184, 1, 64, 179, 219, 219, 72, 63, 184, 1, 64, 179, 218, 218, 72, 63, 184, 1, 64, 179, 217, 217, 72, 63, 184, 1, 128, 179, 216, 216, 72, 63, 184, 1, 64, 179, 215, 215, 72, 63, 184, 1, 64, 179, 214, 214, 72, 63, 184, 1, 64, 179, 213, 213, 72, 63, 184, 1, 64, 179, 212, 212, 72, 63, 184, 1, 64, 179, 211, 211, 72, 63, 184, 1, 64, 179, 210, 210, 72, 63, 184, 1, 64, 179, 209, 209, 72, 63, 184, 1, 64, 179, 208, 208, 72, 63, 184, 1, 64, 179, 207, 207, 72, 63, 184, 1, 64, 179, 206, 206, 72, 63, 184, 1, 64, 179, 205, 205, 72, 63, 184, 1, 64, 179, 204, 204, 72, 63, 184, 1, 0, 179, 203, 203, 72, 63, 184, 1, 64, 179, 202, 202, 72, 63, 184, 1, 0, 179, 201, 201, 72, 63, 184, 1, 64, 179, 200, 200, 72, 63, 184, 1, 0, 179, 199, 199, 72, 63, 184, 1, 64, 179, 198, 198, 72, 63, 184, 1, 64, 179, 197, 197, 72, 63, 184, 1, 64, 179, 196, 196, 72, 63, 184, 1, 64, 179, 195, 195, 72, 63, 184, 1, 0, 179, 194, 194, 72, 63, 184, 1, 64, 179, 193, 193, 72, 63, 184, 1, 0, 179, 192, 192, 72, 63, 184, 1, 64, 179, 191, 191, 72, 63, 184, 1, 0, 179, 190, 190, 72, 63, 184, 1, 64, 179, 189, 189, 72, 63, 184, 1, 0, 179, 188, 188, 72, 63, 184, 1, 64, 179, 187, 187, 72, 63, 184, 1, 0, 179, 186, 186, 72, 63, 184, 1, 64, 179, 185, 185, 72, 63, 184, 1, 0, 179, 184, 184, 72, 63, 184, 1, 0, 179, 183, 183, 72, 63, 184, 1, 0, 179, 182, 182, 72, 63, 184, 1, 0, 179, 181, 181, 72, 63, 184, 1, 0, 179, 180, 180, 72, 63, 184, 1, 0, 179, 179, 179, 72, 63, 184, 1, 0, 179, 178, 178, 72, 63, 184, 1, 0, 179, 177, 177, 72, 63, 184, 1, 64, 179, 176, 176, 72, 63, 184, 1, 0, 179, 175, 175, 72, 63, 184, 1, 0, 179, 174, 174, 72, 63, 184, 1, 0, 179, 173, 173, 72, 63, 184, 1, 0, 179, 172, 172, 72, 63, 184, 1, 0, 179, 171, 171, 72, 63, 184, 1, 0, 179, 170, 170, 72, 63, 184, 1, 0, 179, 169, 169, 72, 63, 184, 1, 0, 179, 168, 168, 72, 63, 184, 1, 0, 179, 167, 167, 72, 63, 184, 1, 0, 179, 166, 166, 72, 63, 184, 1, 0, 179, 165, 165, 72, 63, 184, 1, 0, 64, 9, 164, 164, 72, 63, 192, 163, 163, 72, 63, 184, 1, 0, 64, 9, 162, 162, 72, 63, 192, 161, 161, 72, 63, 184, 1, 0, 64, 9, 160, 160, 72, 63, 192, 159, 159, 72, 63, 184, 1, 0, 179, 158, 158, 72, 63, 184, 1, 0, 179, 157, 157, 72, 63, 184, 1, 0, 179, 156, 156, 72, 63, 184, 1, 0, 179, 155, 155, 72, 63, 184, 1, 0, 179, 154, 154, 72, 63, 184, 1, 0, 64, 9, 153, 153, 72, 63, 192, 152, 152, 72, 63, 184, 1, 0, 64, 9, 151, 151, 72, 63, 192, 150, 150, 72, 63, 184, 1, 0, 64, 9, 149, 149, 72, 63, 192, 148, 148, 72, 63, 184, 1, 0, 64, 9, 147, 147, 72, 63, 192, 146, 146, 72, 63, 184, 1, 0, 64, 34, 145, 145, 72, 63, 192, 144, 144, 72, 63, 192, 143, 143, 72, 63, 192, 142, 142, 72, 63, 192, 141, 141, 72, 63, 192, 140, 140, 72, 63, 192, 139, 139, 72, 63, 184, 1, 0, 64, 9, 138, 138, 72, 63, 192, 137, 137, 72, 63, 184, 1, 0, 64, 9, 136, 136, 72, 63, 192, 135, 135, 72, 63, 184, 1, 0, 64, 255, 134, 134, 72, 63, 192, 133, 133, 72, 63, 192, 132, 132, 72, 63, 192, 131, 131, 72, 63, 192, 130, 130, 72, 63, 192, 129, 129, 72, 63, 192, 128, 128, 72, 63, 192, 127, 127, 72, 63, 192, 126, 126, 72, 63, 192, 125, 125, 72, 63, 192, 124, 124, 72, 63, 128, 123, 123, 72, 63, 192, 122, 122, 72, 63, 128, 121, 121, 72, 63, 192, 120, 120, 72, 63, 128, 119, 119, 72, 63, 192, 118, 118, 72, 63, 192, 117, 117, 72, 63, 192, 116, 116, 72, 63, 192, 115, 115, 72, 63, 192, 114, 114, 72, 63, 192, 113, 113, 72, 63, 128, 112, 112, 72, 63, 192, 111, 111, 72, 63, 128, 110, 110, 72, 63, 192, 109, 109, 72, 63, 128, 108, 108, 72, 63, 192, 107, 107, 72, 63, 128, 106, 106, 72, 63, 192, 105, 105, 72, 63, 128, 104, 104, 72, 63, 192, 103, 103, 72, 63, 128, 102, 102, 72, 63, 128, 101, 101, 72, 63, 128, 100, 100, 72, 63, 128, 99, 99, 72, 63, 192, 98, 98, 72, 63, 128, 97, 97, 72, 63, 192, 96, 96, 72, 63, 128, 95, 95, 72, 63, 192, 94, 94, 72, 63, 128, 93, 93, 72, 63, 128, 92, 92, 72, 63, 128, 91, 91, 72, 63, 128, 90, 90, 72, 63, 128, 89, 89, 72, 63, 128, 88, 88, 72, 63, 128, 87, 87, 72, 63, 128, 86, 86, 72, 63, 128, 85, 85, 72, 63, 128, 84, 84, 72, 63, 128, 64, 255, 83, 83, 72, 63, 128, 82, 82, 72, 63, 64, 81, 81, 72, 63, 128, 80, 80, 72, 63, 128, 79, 79, 72, 63, 128, 78, 78, 72, 63, 128, 77, 77, 72, 63, 128, 76, 76, 72, 63, 128, 75, 75, 72, 63, 128, 74, 74, 72, 63, 128, 73, 73, 72, 63, 128, 72, 72, 72, 63, 128, 71, 71, 72, 63, 64, 70, 70, 72, 63, 128, 69, 69, 72, 63, 64, 68, 68, 72, 63, 128, 67, 67, 72, 63, 64, 66, 66, 72, 63, 128, 65, 65, 72, 63, 64, 64, 64, 72, 63, 128, 63, 63, 72, 63, 64, 62, 62, 72, 63, 64, 61, 61, 72, 63, 64, 60, 60, 72, 63, 64, 59, 59, 72, 63, 128, 58, 58, 72, 63, 64, 57, 57, 72, 63, 128, 56, 56, 72, 63, 64, 55, 55, 72, 63, 128, 54, 54, 72, 63, 64, 53, 53, 72, 63, 128, 52, 52, 72, 63, 64, 51, 51, 72, 63, 64, 50, 50, 72, 63, 64, 49, 49, 72, 63, 64, 48, 48, 72, 63, 64, 47, 47, 72, 63, 64, 46, 46, 72, 63, 64, 45, 45, 72, 63, 64, 44, 44, 72, 63, 64, 43, 43, 72, 63, 64, 42, 42, 72, 63, 64, 40, 40, 72, 63, 64, 39, 39, 72, 63, 64, 38, 38, 72, 63, 64, 37, 37, 72, 63, 64, 36, 36, 72, 63, 64, 35, 35, 72, 63, 64, 34, 34, 72, 63, 64, 33, 33, 72, 63, 64, 32, 32, 72, 63, 64, 64, 53, 31, 31, 72, 63, 64, 29, 29, 72, 63, 64, 27, 27, 72, 63, 64, 25, 25, 72, 63, 64, 23, 23, 72, 63, 64, 21, 21, 72, 63, 64, 20, 20, 72, 63, 64, 18, 18, 72, 63, 64, 16, 16, 72, 63, 64, 14, 14, 72, 63, 64, 12, 12, 72, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 107, 254, 88, 4, 100, 5, 228, 18, 38, 1, 132, 0, 0, 17, 7, 1, 84, 1, 127, 0, 0, 0, 19, 64, 11, 1, 36, 17, 38, 1, 115, 36, 39, 17, 34, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 137, 0, 0, 1, 246, 5, 228, 18, 38, 1, 134, 0, 0, 17, 6, 1, 84, 247, 0, 0, 19, 64, 11, 1, 14, 17, 38, 1, 21, 14, 17, 5, 13, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 127, 255, 236, 4, 84, 6, 85, 18, 38, 1, 146, 0, 0, 17, 7, 1, 85, 0, 128, 0, 0, 0, 25, 181, 3, 2, 1, 3, 2, 1, 184, 255, 243, 180, 36, 42, 8, 0, 37, 1, 43, 53, 53, 53, 0, 53, 53, 53, 0, 0, 2, 0, 80, 255, 236, 4, 214, 4, 78, 0, 37, 0, 57, 0, 90, 64, 28, 34, 40, 10, 0, 77, 34, 16, 9, 0, 77, 0, 16, 26, 70, 32, 48, 48, 48, 2, 48, 48, 8, 21, 32, 31, 31, 20, 21, 184, 255, 192, 64, 23, 9, 12, 72, 21, 21, 59, 38, 71, 8, 32, 21, 20, 15, 53, 79, 16, 11, 16, 43, 79, 0, 5, 22, 0, 63, 51, 237, 63, 51, 237, 63, 63, 1, 47, 237, 17, 51, 47, 43, 51, 51, 17, 51, 17, 18, 57, 47, 93, 237, 57, 57, 49, 48, 43, 43, 37, 14, 3, 35, 34, 2, 17, 16, 18, 51, 50, 30, 2, 23, 51, 62, 1, 55, 33, 14, 3, 7, 30, 3, 23, 33, 46, 3, 39, 1, 20, 30, 2, 51, 50, 62, 2, 55, 46, 3, 35, 34, 14, 2, 3, 92, 26, 65, 85, 111, 72, 212, 209, 227, 220, 73, 117, 91, 66, 21, 3, 11, 40, 24, 1, 9, 26, 54, 48, 35, 6, 8, 26, 36, 42, 24, 254, 242, 13, 23, 18, 13, 4, 254, 23, 20, 44, 69, 48, 39, 76, 63, 47, 10, 9, 35, 55, 77, 51, 48, 72, 46, 23, 237, 56, 94, 69, 38, 1, 19, 1, 25, 1, 28, 1, 26, 39, 69, 93, 54, 55, 127, 53, 47, 133, 144, 144, 58, 77, 151, 141, 130, 57, 32, 66, 63, 55, 21, 1, 46, 97, 138, 89, 42, 45, 92, 139, 93, 74, 133, 100, 59, 40, 88, 140, 0, 0, 0, 0, 2, 0, 142, 254, 87, 4, 157, 5, 204, 0, 32, 0, 62, 0, 108, 185, 0, 21, 255, 240, 180, 9, 10, 0, 76, 2, 184, 255, 240, 64, 27, 9, 10, 0, 76, 49, 13, 52, 70, 23, 64, 9, 15, 72, 23, 23, 13, 43, 70, 0, 64, 33, 13, 70, 208, 14, 1, 14, 184, 255, 192, 179, 36, 40, 72, 14, 184, 255, 192, 64, 20, 9, 12, 72, 14, 28, 48, 79, 49, 49, 38, 57, 80, 18, 0, 13, 27, 38, 79, 5, 22, 0, 63, 237, 63, 63, 237, 18, 57, 47, 237, 57, 1, 47, 43, 43, 93, 237, 50, 16, 222, 237, 18, 57, 47, 43, 237, 18, 57, 49, 48, 43, 43, 1, 20, 14, 2, 35, 34, 38, 39, 35, 30, 1, 21, 17, 33, 17, 52, 54, 51, 50, 30, 2, 21, 20, 14, 2, 7, 30, 3, 5, 30, 3, 51, 50, 62, 2, 53, 52, 46, 2, 35, 53, 62, 1, 53, 52, 46, 2, 35, 34, 14, 2, 21, 4, 157, 52, 111, 171, 119, 101, 147, 55, 9, 5, 3, 254, 230, 249, 247, 108, 166, 113, 57, 35, 61, 81, 46, 57, 115, 92, 58, 253, 11, 22, 57, 65, 70, 34, 58, 88, 59, 30, 36, 80, 126, 89, 127, 113, 21, 44, 67, 47, 54, 80, 53, 26, 1, 149, 88, 155, 116, 66, 55, 39, 57, 92, 53, 254, 215, 5, 172, 237, 220, 47, 90, 130, 82, 73, 111, 82, 56, 18, 11, 55, 93, 137, 244, 17, 30, 23, 13, 35, 65, 91, 56, 56, 94, 68, 39, 198, 22, 114, 99, 36, 63, 47, 26, 31, 69, 111, 79, 0, 1, 0, 8, 254, 88, 4, 107, 4, 58, 0, 24, 1, 154, 181, 13, 24, 10, 0, 77, 1, 184, 255, 216, 64, 24, 10, 0, 77, 24, 15, 7, 20, 7, 7, 23, 7, 2, 9, 3, 7, 14, 9, 21, 1, 10, 21, 21, 13, 14, 184, 255, 192, 64, 255, 9, 13, 72, 14, 16, 14, 14, 26, 107, 26, 1, 84, 26, 1, 11, 26, 43, 26, 75, 26, 155, 26, 251, 26, 5, 207, 20, 26, 52, 26, 132, 26, 148, 26, 164, 26, 228, 26, 6, 244, 26, 1, 219, 26, 1, 164, 26, 196, 26, 2, 235, 26, 1, 212, 26, 1, 123, 26, 155, 26, 2, 100, 26, 1, 11, 26, 43, 26, 2, 157, 27, 26, 43, 26, 75, 26, 107, 26, 155, 26, 171, 26, 187, 26, 7, 91, 26, 107, 26, 139, 26, 155, 26, 187, 26, 219, 26, 251, 26, 7, 79, 26, 1, 11, 26, 59, 26, 2, 255, 26, 1, 187, 26, 1, 132, 26, 1, 75, 26, 91, 26, 107, 26, 3, 52, 26, 1, 11, 26, 1, 108, 43, 26, 59, 26, 75, 26, 139, 26, 155, 26, 219, 26, 251, 26, 7, 155, 26, 171, 26, 187, 26, 219, 26, 235, 26, 5, 100, 26, 116, 26, 132, 26, 3, 75, 26, 1, 20, 26, 1, 187, 26, 1, 132, 26, 1, 75, 26, 91, 26, 2, 52, 26, 1, 11, 26, 1, 58, 139, 26, 155, 26, 171, 26, 235, 26, 4, 116, 26, 1, 75, 26, 91, 26, 2, 4, 26, 1, 224, 26, 1, 2, 208, 26, 1, 175, 26, 1, 32, 26, 64, 26, 112, 26, 128, 26, 4, 224, 26, 240, 26, 2, 191, 26, 1, 144, 26, 160, 26, 2, 79, 26, 111, 26, 2, 32, 26, 1, 31, 26, 1, 0, 26, 1, 7, 177, 1, 0, 184, 255, 240, 64, 17, 79, 0, 1, 0, 15, 64, 9, 0, 77, 15, 7, 24, 20, 27, 13, 0, 15, 0, 63, 50, 63, 47, 51, 51, 43, 1, 47, 93, 56, 50, 94, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 95, 113, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 113, 113, 113, 113, 114, 94, 93, 93, 93, 93, 93, 93, 113, 113, 113, 114, 94, 93, 93, 93, 93, 93, 113, 113, 113, 114, 94, 93, 113, 113, 17, 51, 47, 56, 43, 51, 57, 47, 94, 93, 18, 57, 95, 94, 93, 51, 17, 51, 51, 49, 48, 43, 43, 19, 33, 19, 30, 3, 23, 62, 3, 55, 19, 33, 1, 14, 3, 7, 33, 62, 1, 55, 8, 1, 42, 212, 3, 17, 18, 15, 1, 4, 16, 18, 18, 7, 201, 1, 39, 254, 117, 21, 37, 31, 25, 9, 254, 222, 20, 53, 28, 4, 58, 253, 128, 9, 62, 77, 79, 27, 31, 73, 71, 63, 21, 2, 123, 251, 252, 55, 110, 117, 126, 70, 134, 213, 88, 0, 0, 0, 2, 0, 86, 255, 236, 4, 132, 5, 204, 0, 19, 0, 50, 0, 127, 185, 0, 25, 255, 224, 183, 9, 10, 0, 76, 46, 5, 0, 25, 184, 255, 208, 64, 32, 9, 10, 0, 76, 25, 0, 47, 16, 47, 2, 47, 50, 47, 50, 41, 0, 71, 31, 52, 10, 71, 48, 41, 1, 41, 46, 64, 14, 17, 72, 46, 5, 184, 255, 192, 64, 16, 14, 17, 72, 79, 5, 1, 5, 24, 9, 10, 0, 76, 5, 5, 15, 47, 184, 255, 192, 64, 13, 9, 10, 0, 76, 47, 20, 79, 48, 0, 15, 79, 36, 22, 0, 63, 237, 63, 237, 50, 43, 18, 57, 47, 43, 93, 43, 51, 43, 1, 47, 93, 237, 16, 222, 237, 18, 57, 57, 47, 47, 93, 51, 43, 18, 57, 57, 49, 48, 0, 43, 1, 52, 46, 2, 39, 14, 3, 21, 20, 30, 2, 51, 50, 62, 2, 3, 34, 46, 2, 39, 1, 30, 3, 21, 20, 14, 2, 35, 34, 46, 2, 53, 52, 62, 2, 55, 1, 53, 33, 21, 3, 98, 32, 55, 72, 40, 67, 107, 76, 41, 28, 58, 89, 61, 70, 97, 60, 27, 132, 13, 39, 43, 39, 13, 1, 67, 58, 92, 63, 33, 71, 138, 201, 129, 127, 198, 135, 71, 73, 127, 169, 96, 254, 200, 3, 85, 1, 231, 69, 117, 102, 88, 40, 24, 76, 105, 134, 83, 66, 112, 81, 46, 47, 82, 115, 3, 106, 2, 2, 2, 1, 254, 219, 53, 114, 128, 146, 84, 108, 185, 134, 76, 69, 129, 186, 117, 110, 172, 132, 95, 33, 1, 58, 147, 190, 0, 0, 0, 1, 0, 77, 255, 236, 3, 171, 4, 78, 0, 55, 0, 104, 64, 63, 27, 24, 9, 10, 0, 76, 12, 24, 9, 10, 0, 76, 42, 70, 19, 48, 25, 48, 35, 35, 48, 25, 3, 14, 0, 4, 16, 4, 2, 4, 4, 57, 53, 71, 79, 14, 1, 14, 19, 48, 47, 47, 0, 39, 82, 30, 43, 36, 1, 36, 36, 30, 16, 0, 81, 9, 16, 3, 1, 3, 3, 9, 22, 0, 63, 51, 47, 93, 16, 237, 63, 51, 47, 93, 16, 237, 18, 57, 47, 205, 57, 1, 47, 93, 237, 17, 51, 47, 93, 18, 23, 57, 47, 47, 47, 18, 57, 237, 49, 48, 43, 43, 37, 50, 54, 55, 23, 14, 3, 35, 34, 46, 2, 53, 52, 62, 2, 55, 53, 46, 3, 53, 52, 62, 2, 51, 50, 30, 2, 23, 7, 46, 1, 35, 34, 6, 21, 20, 30, 2, 51, 21, 34, 14, 2, 21, 20, 22, 2, 14, 75, 137, 58, 143, 33, 77, 103, 137, 92, 107, 158, 104, 51, 42, 77, 106, 63, 61, 95, 65, 34, 56, 108, 157, 102, 70, 114, 94, 78, 34, 162, 42, 101, 69, 84, 88, 51, 88, 120, 69, 66, 123, 94, 56, 85, 168, 77, 60, 140, 34, 66, 52, 33, 47, 84, 116, 70, 57, 93, 66, 40, 5, 2, 6, 42, 66, 87, 51, 63, 106, 77, 44, 19, 40, 65, 45, 123, 57, 56, 65, 57, 48, 59, 32, 10, 177, 7, 31, 65, 58, 72, 74, 0, 0, 0, 1, 0, 66, 254, 111, 3, 143, 5, 204, 0, 54, 0, 141, 185, 0, 3, 255, 248, 64, 15, 10, 0, 77, 37, 24, 10, 0, 77, 29, 32, 9, 10, 0, 76, 8, 184, 255, 232, 179, 10, 0, 77, 7, 184, 255, 232, 64, 18, 9, 0, 77, 38, 48, 64, 30, 60, 72, 48, 48, 10, 16, 45, 48, 45, 2, 45, 184, 255, 192, 64, 41, 15, 18, 72, 45, 45, 31, 16, 16, 21, 70, 10, 64, 13, 18, 72, 10, 56, 0, 70, 79, 31, 95, 31, 111, 31, 3, 31, 64, 39, 60, 72, 31, 48, 45, 81, 0, 21, 15, 46, 0, 15, 184, 1, 16, 0, 63, 63, 18, 57, 57, 237, 50, 1, 47, 43, 93, 237, 16, 222, 43, 237, 50, 47, 17, 57, 47, 43, 93, 17, 51, 47, 43, 51, 49, 48, 0, 43, 1, 43, 43, 43, 0, 43, 1, 20, 30, 2, 23, 30, 3, 21, 20, 14, 2, 7, 39, 62, 3, 53, 52, 46, 2, 39, 46, 3, 53, 52, 62, 4, 55, 53, 14, 3, 35, 33, 53, 33, 21, 14, 5, 1, 68, 40, 71, 97, 56, 54, 115, 94, 60, 20, 29, 32, 13, 183, 9, 19, 16, 11, 35, 65, 92, 58, 64, 133, 108, 68, 46, 80, 107, 123, 131, 64, 12, 34, 36, 34, 11, 254, 197, 2, 189, 62, 131, 123, 108, 81, 47, 1, 166, 56, 69, 43, 29, 16, 15, 38, 67, 107, 84, 42, 87, 81, 68, 21, 74, 15, 37, 40, 42, 21, 37, 51, 36, 27, 15, 14, 39, 74, 122, 96, 80, 167, 169, 167, 160, 148, 65, 4, 1, 1, 1, 1, 189, 190, 61, 140, 149, 155, 152, 148, 0, 0, 0, 0, 1, 0, 107, 254, 88, 4, 100, 4, 78, 0, 35, 0, 98, 185, 0, 32, 255, 232, 64, 39, 9, 10, 0, 76, 0, 70, 224, 35, 240, 35, 2, 35, 37, 144, 37, 160, 37, 2, 112, 37, 144, 37, 160, 37, 176, 37, 240, 37, 5, 239, 37, 1, 23, 12, 70, 208, 13, 1, 13, 184, 255, 192, 179, 36, 40, 72, 13, 184, 255, 192, 64, 15, 9, 12, 72, 13, 23, 6, 80, 29, 16, 17, 15, 13, 21, 0, 27, 0, 63, 63, 63, 63, 237, 51, 1, 47, 43, 43, 93, 237, 50, 93, 113, 114, 16, 222, 93, 237, 49, 48, 43, 1, 17, 52, 46, 2, 35, 34, 14, 2, 21, 17, 33, 17, 52, 38, 39, 33, 30, 3, 21, 51, 62, 3, 51, 50, 30, 2, 21, 17, 3, 77, 19, 44, 71, 52, 53, 87, 61, 33, 254, 230, 22, 14, 1, 13, 9, 14, 10, 5, 3, 27, 64, 84, 108, 72, 93, 133, 85, 41, 254, 88, 4, 29, 75, 101, 61, 26, 41, 80, 115, 75, 253, 187, 3, 83, 68, 121, 42, 21, 48, 49, 47, 20, 47, 76, 53, 29, 44, 92, 144, 101, 251, 135, 0, 0, 0, 0, 3, 0, 90, 255, 236, 3, 249, 5, 203, 0, 15, 0, 26, 0, 37, 0, 67, 64, 17, 33, 21, 70, 0, 64, 34, 38, 72, 0, 39, 32, 22, 70, 48, 8, 1, 8, 184, 255, 192, 64, 20, 34, 38, 72, 8, 22, 79, 47, 32, 1, 32, 32, 16, 27, 81, 11, 0, 16, 81, 3, 22, 0, 63, 237, 63, 237, 18, 57, 47, 113, 237, 1, 47, 43, 93, 237, 50, 16, 222, 43, 237, 50, 49, 48, 1, 16, 2, 35, 34, 46, 1, 2, 53, 16, 18, 51, 50, 30, 1, 18, 1, 50, 62, 2, 55, 33, 30, 3, 19, 34, 14, 2, 7, 33, 46, 3, 3, 249, 240, 228, 108, 171, 118, 62, 233, 232, 121, 175, 112, 54, 254, 45, 39, 68, 52, 32, 2, 254, 135, 2, 32, 51, 65, 41, 39, 68, 51, 32, 2, 1, 122, 2, 31, 49, 66, 2, 221, 254, 131, 254, 140, 92, 186, 1, 27, 192, 1, 118, 1, 120, 93, 188, 254, 231, 253, 9, 47, 111, 186, 138, 138, 185, 112, 47, 4, 114, 45, 108, 179, 134, 134, 179, 108, 45, 0, 0, 1, 0, 137, 0, 0, 1, 243, 4, 58, 0, 13, 0, 119, 64, 90, 10, 48, 9, 10, 0, 76, 3, 48, 9, 10, 0, 76, 13, 64, 9, 12, 72, 13, 13, 6, 70, 15, 7, 63, 7, 79, 7, 3, 62, 127, 7, 191, 7, 239, 7, 3, 175, 7, 191, 7, 207, 7, 255, 7, 4, 112, 7, 1, 207, 7, 223, 7, 2, 0, 7, 16, 7, 2, 7, 15, 160, 15, 176, 15, 2, 127, 15, 1, 96, 15, 1, 31, 15, 1, 239, 15, 1, 128, 15, 176, 15, 192, 15, 208, 15, 4, 6, 15, 0, 21, 0, 63, 63, 1, 93, 93, 113, 113, 113, 113, 16, 222, 93, 93, 113, 113, 114, 94, 93, 237, 51, 47, 43, 49, 48, 43, 43, 51, 46, 3, 53, 17, 33, 17, 20, 30, 2, 23, 199, 15, 24, 15, 8, 1, 26, 12, 21, 29, 18, 16, 53, 64, 70, 33, 3, 78, 252, 169, 32, 64, 60, 51, 20, 0, 0, 0, 0, 1, 0, 143, 0, 0, 4, 117, 4, 58, 0, 11, 0, 128, 185, 0, 9, 255, 248, 64, 14, 10, 0, 77, 0, 40, 10, 0, 77, 1, 24, 10, 0, 77, 10, 184, 255, 232, 64, 16, 9, 0, 77, 8, 24, 9, 0, 77, 1, 10, 11, 8, 9, 9, 0, 11, 184, 255, 192, 64, 15, 9, 12, 72, 11, 16, 11, 11, 13, 7, 3, 70, 208, 4, 1, 4, 184, 255, 192, 179, 36, 40, 72, 4, 184, 255, 192, 64, 16, 9, 12, 72, 4, 2, 7, 10, 1, 7, 1, 8, 5, 15, 4, 0, 21, 0, 63, 50, 63, 51, 57, 57, 17, 51, 17, 51, 1, 47, 43, 43, 93, 237, 50, 17, 51, 47, 56, 43, 51, 51, 17, 51, 17, 57, 57, 49, 48, 43, 43, 43, 43, 43, 33, 1, 7, 17, 33, 17, 33, 17, 1, 33, 9, 1, 3, 74, 254, 221, 127, 254, 231, 1, 25, 1, 141, 1, 35, 254, 132, 1, 153, 1, 199, 106, 254, 163, 4, 58, 254, 18, 1, 238, 254, 50, 253, 148, 0, 0, 0, 1, 0, 9, 0, 0, 4, 84, 6, 1, 0, 35, 1, 173, 185, 0, 35, 255, 240, 64, 9, 10, 0, 77, 20, 16, 10, 0, 77, 14, 184, 255, 224, 64, 9, 10, 0, 77, 2, 32, 10, 0, 77, 33, 184, 255, 240, 64, 17, 9, 0, 77, 35, 17, 9, 7, 9, 1, 10, 3, 9, 16, 27, 27, 15, 16, 184, 255, 240, 64, 9, 11, 16, 1, 13, 16, 1, 0, 16, 0, 184, 255, 192, 64, 255, 9, 13, 72, 0, 0, 37, 107, 37, 1, 84, 37, 1, 11, 37, 43, 37, 75, 37, 155, 37, 251, 37, 5, 207, 20, 37, 52, 37, 132, 37, 148, 37, 164, 37, 228, 37, 6, 244, 37, 1, 219, 37, 1, 164, 37, 196, 37, 2, 235, 37, 1, 212, 37, 1, 123, 37, 155, 37, 2, 100, 37, 1, 11, 37, 43, 37, 2, 157, 27, 37, 43, 37, 75, 37, 107, 37, 155, 37, 171, 37, 187, 37, 7, 91, 37, 107, 37, 139, 37, 155, 37, 187, 37, 203, 37, 219, 37, 251, 37, 8, 79, 37, 1, 11, 37, 59, 37, 2, 255, 37, 1, 187, 37, 1, 132, 37, 1, 75, 37, 91, 37, 107, 37, 3, 52, 37, 1, 11, 37, 1, 108, 43, 37, 59, 37, 75, 37, 139, 37, 155, 37, 219, 37, 251, 37, 7, 155, 37, 171, 37, 187, 37, 219, 37, 235, 37, 5, 100, 37, 116, 37, 132, 37, 3, 75, 37, 1, 20, 37, 1, 187, 37, 1, 132, 37, 1, 75, 37, 91, 37, 2, 52, 37, 1, 11, 37, 1, 58, 139, 37, 155, 37, 171, 37, 235, 37, 4, 116, 37, 1, 75, 37, 91, 37, 2, 4, 37, 1, 224, 37, 1, 2, 208, 37, 1, 175, 37, 1, 32, 37, 64, 37, 112, 37, 128, 37, 4, 224, 37, 240, 37, 2, 191, 37, 1, 144, 37, 160, 37, 2, 79, 37, 111, 37, 2, 32, 37, 1, 31, 37, 1, 0, 37, 1, 7, 64, 10, 9, 17, 17, 0, 23, 80, 30, 16, 0, 21, 0, 63, 50, 47, 237, 18, 57, 47, 51, 1, 94, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 95, 113, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 113, 113, 113, 113, 114, 94, 93, 93, 93, 93, 93, 93, 113, 113, 113, 114, 94, 93, 93, 93, 93, 93, 113, 113, 113, 114, 94, 93, 113, 113, 17, 51, 47, 43, 56, 50, 47, 94, 93, 56, 51, 57, 47, 17, 57, 95, 94, 93, 17, 51, 51, 49, 48, 43, 43, 43, 43, 43, 41, 1, 3, 46, 5, 39, 14, 3, 7, 3, 33, 1, 39, 46, 3, 35, 34, 6, 7, 39, 62, 1, 51, 50, 30, 2, 23, 4, 84, 254, 218, 136, 4, 13, 16, 18, 14, 11, 2, 7, 27, 32, 33, 13, 182, 254, 215, 1, 218, 26, 27, 44, 43, 48, 32, 20, 54, 19, 48, 31, 99, 57, 81, 116, 89, 71, 34, 1, 206, 13, 45, 57, 62, 58, 48, 14, 27, 87, 95, 91, 30, 254, 83, 3, 238, 73, 69, 96, 61, 27, 11, 8, 194, 11, 19, 43, 92, 142, 98, 0, 0, 0, 1, 0, 144, 254, 96, 4, 93, 4, 58, 0, 39, 0, 134, 64, 35, 3, 31, 70, 223, 34, 239, 34, 2, 34, 64, 64, 68, 72, 34, 64, 50, 53, 72, 34, 64, 36, 40, 72, 34, 41, 21, 9, 17, 70, 208, 18, 224, 18, 2, 18, 184, 255, 192, 179, 64, 68, 72, 18, 184, 255, 192, 179, 50, 53, 72, 18, 184, 255, 192, 179, 36, 40, 72, 18, 184, 255, 192, 64, 36, 9, 12, 72, 18, 144, 41, 160, 41, 2, 112, 41, 144, 41, 160, 41, 176, 41, 240, 41, 5, 239, 41, 1, 32, 19, 15, 18, 27, 26, 80, 12, 3, 9, 22, 0, 21, 0, 63, 63, 51, 51, 237, 63, 63, 51, 1, 93, 113, 114, 47, 43, 43, 43, 43, 93, 237, 50, 50, 16, 222, 43, 43, 43, 93, 237, 50, 49, 48, 33, 46, 3, 53, 35, 14, 1, 35, 34, 38, 39, 35, 30, 1, 21, 17, 33, 17, 33, 17, 20, 30, 2, 51, 50, 62, 2, 53, 17, 33, 17, 20, 30, 2, 23, 3, 81, 1, 5, 4, 3, 3, 38, 122, 86, 52, 87, 23, 4, 3, 1, 254, 231, 1, 25, 19, 43, 70, 52, 50, 80, 58, 31, 1, 25, 1, 3, 3, 1, 12, 44, 53, 54, 21, 99, 105, 48, 42, 32, 55, 28, 254, 141, 5, 218, 253, 163, 64, 104, 75, 41, 45, 81, 115, 70, 2, 66, 252, 184, 34, 73, 67, 54, 14, 0, 1, 0, 0, 0, 0, 4, 23, 4, 58, 0, 20, 2, 86, 185, 0, 9, 255, 208, 179, 10, 0, 77, 8, 184, 255, 192, 179, 10, 0, 77, 7, 184, 255, 240, 64, 26, 10, 0, 77, 10, 24, 9, 10, 0, 76, 3, 24, 9, 0, 77, 6, 32, 9, 0, 77, 6, 5, 9, 9, 0, 8, 7, 184, 255, 240, 64, 26, 7, 14, 70, 0, 0, 22, 185, 22, 1, 102, 22, 1, 9, 22, 73, 22, 2, 185, 22, 1, 150, 22, 166, 22, 2, 22, 184, 255, 192, 64, 113, 205, 209, 72, 9, 22, 1, 202, 201, 22, 1, 6, 22, 86, 22, 118, 22, 150, 22, 4, 54, 22, 70, 22, 86, 22, 198, 22, 230, 22, 5, 34, 22, 1, 4, 22, 20, 22, 2, 246, 22, 1, 226, 22, 1, 212, 22, 1, 194, 22, 1, 160, 22, 176, 22, 2, 146, 22, 1, 132, 22, 1, 112, 22, 1, 82, 22, 98, 22, 2, 68, 22, 1, 48, 22, 1, 18, 22, 34, 22, 2, 4, 22, 1, 151, 226, 22, 242, 22, 2, 196, 22, 212, 22, 2, 162, 22, 178, 22, 2, 132, 22, 148, 22, 2, 114, 22, 1, 84, 22, 100, 22, 2, 22, 184, 255, 64, 64, 255, 136, 139, 72, 0, 22, 1, 240, 22, 1, 226, 22, 1, 212, 22, 1, 192, 22, 1, 162, 22, 178, 22, 2, 148, 22, 1, 128, 22, 1, 98, 22, 114, 22, 2, 84, 22, 1, 66, 22, 1, 52, 22, 1, 38, 22, 1, 18, 22, 1, 4, 22, 1, 244, 22, 1, 230, 22, 1, 210, 22, 1, 1, 192, 22, 1, 164, 22, 180, 22, 2, 128, 22, 144, 22, 2, 100, 22, 116, 22, 2, 64, 22, 80, 22, 2, 52, 22, 1, 16, 22, 1, 4, 22, 1, 103, 244, 22, 1, 208, 22, 224, 22, 2, 180, 22, 196, 22, 2, 160, 22, 1, 132, 22, 148, 22, 2, 96, 22, 1, 68, 22, 84, 22, 2, 32, 22, 1, 20, 22, 1, 212, 22, 228, 22, 2, 203, 22, 1, 144, 22, 160, 22, 2, 132, 22, 1, 96, 22, 112, 22, 2, 68, 22, 84, 22, 2, 32, 22, 48, 22, 2, 20, 22, 1, 240, 22, 1, 212, 22, 228, 22, 2, 176, 22, 1, 100, 22, 116, 22, 148, 22, 164, 22, 4, 64, 22, 1, 36, 22, 52, 22, 2, 0, 22, 1, 55, 2, 112, 22, 128, 22, 176, 22, 192, 22, 240, 22, 5, 95, 22, 1, 0, 22, 16, 22, 64, 22, 3, 208, 22, 1, 175, 22, 1, 144, 22, 1, 111, 22, 1, 80, 22, 1, 47, 22, 63, 22, 2, 127, 22, 143, 22, 191, 22, 239, 22, 255, 22, 5, 80, 22, 1, 15, 22, 31, 64, 11, 22, 63, 22, 3, 7, 17, 7, 15, 9, 6, 21, 0, 63, 51, 63, 51, 1, 94, 93, 93, 93, 113, 113, 113, 113, 113, 113, 114, 114, 114, 95, 94, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 95, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 43, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 114, 114, 94, 93, 43, 93, 93, 113, 113, 113, 16, 206, 47, 237, 47, 56, 51, 18, 57, 17, 51, 51, 49, 48, 43, 43, 43, 43, 43, 43, 1, 20, 14, 2, 7, 33, 1, 33, 1, 62, 3, 53, 52, 38, 39, 33, 30, 1, 4, 23, 63, 108, 141, 78, 254, 245, 254, 122, 1, 41, 1, 5, 56, 79, 50, 23, 29, 20, 1, 24, 23, 27, 3, 78, 99, 218, 221, 214, 94, 4, 58, 252, 181, 80, 148, 145, 147, 78, 81, 119, 45, 45, 113, 0, 0, 1, 0, 66, 254, 111, 3, 143, 5, 204, 0, 72, 0, 176, 185, 0, 8, 255, 224, 64, 22, 10, 0, 77, 60, 32, 9, 10, 0, 76, 44, 32, 9, 10, 0, 76, 29, 32, 9, 10, 0, 76, 7, 184, 255, 248, 64, 22, 9, 0, 77, 62, 70, 42, 47, 57, 36, 42, 67, 57, 64, 11, 60, 72, 128, 54, 144, 54, 2, 42, 184, 255, 192, 64, 59, 9, 14, 72, 54, 42, 67, 57, 57, 67, 42, 54, 4, 31, 10, 16, 16, 21, 70, 0, 10, 16, 10, 32, 10, 3, 10, 74, 0, 70, 79, 31, 95, 31, 111, 31, 3, 31, 64, 39, 60, 72, 31, 57, 54, 79, 55, 36, 68, 79, 62, 55, 0, 21, 67, 67, 15, 55, 0, 15, 184, 1, 16, 0, 63, 63, 18, 57, 47, 57, 57, 18, 57, 237, 57, 16, 237, 50, 1, 47, 43, 93, 237, 16, 214, 93, 237, 50, 47, 17, 18, 23, 57, 47, 47, 47, 47, 43, 93, 43, 17, 18, 57, 17, 51, 16, 237, 49, 48, 0, 43, 1, 43, 43, 43, 43, 1, 20, 30, 2, 23, 30, 3, 21, 20, 14, 2, 7, 39, 62, 3, 53, 52, 46, 2, 39, 46, 3, 53, 52, 62, 2, 55, 53, 46, 3, 53, 52, 62, 2, 55, 53, 14, 3, 43, 1, 53, 33, 21, 14, 3, 21, 20, 30, 2, 23, 21, 14, 3, 1, 68, 40, 71, 97, 56, 54, 115, 94, 60, 20, 29, 32, 13, 183, 9, 19, 16, 11, 35, 65, 92, 58, 64, 133, 108, 68, 52, 111, 176, 124, 67, 119, 87, 51, 50, 79, 97, 47, 12, 68, 80, 76, 18, 76, 2, 142, 69, 130, 101, 61, 53, 89, 115, 61, 100, 161, 113, 61, 1, 164, 53, 68, 45, 30, 15, 15, 38, 67, 107, 84, 42, 87, 81, 68, 21, 74, 15, 37, 40, 42, 21, 37, 51, 36, 27, 15, 14, 39, 74, 122, 96, 76, 152, 129, 95, 19, 2, 5, 34, 60, 86, 55, 57, 82, 58, 35, 9, 8, 1, 2, 3, 2, 191, 185, 7, 28, 48, 74, 54, 51, 65, 40, 20, 5, 191, 12, 36, 65, 103, 0, 0, 0, 255, 255, 0, 80, 255, 236, 4, 147, 4, 78, 18, 6, 0, 82, 0, 0, 0, 1, 0, 42, 255, 236, 5, 233, 4, 58, 0, 40, 0, 117, 182, 13, 40, 9, 10, 0, 76, 21, 184, 255, 232, 64, 68, 9, 10, 0, 76, 8, 8, 1, 48, 39, 1, 39, 39, 1, 16, 70, 29, 29, 23, 14, 70, 223, 1, 1, 0, 1, 1, 1, 42, 15, 32, 31, 32, 63, 32, 3, 32, 64, 18, 22, 72, 32, 32, 22, 70, 0, 23, 16, 23, 48, 23, 80, 23, 96, 23, 5, 23, 16, 0, 29, 79, 38, 15, 23, 21, 4, 79, 11, 22, 0, 63, 237, 63, 63, 237, 50, 50, 1, 47, 93, 237, 51, 47, 43, 93, 16, 220, 93, 93, 237, 17, 57, 47, 237, 17, 51, 47, 93, 18, 57, 47, 49, 48, 43, 43, 1, 17, 20, 22, 51, 50, 54, 55, 23, 14, 1, 35, 34, 38, 53, 17, 33, 21, 20, 14, 2, 7, 33, 62, 3, 61, 1, 34, 6, 7, 53, 62, 3, 51, 33, 21, 4, 216, 56, 48, 26, 52, 20, 20, 44, 115, 64, 141, 137, 254, 149, 13, 24, 32, 19, 254, 225, 19, 36, 29, 17, 97, 149, 36, 15, 44, 49, 51, 23, 5, 9, 3, 124, 253, 179, 72, 55, 8, 4, 184, 10, 14, 149, 136, 2, 115, 124, 130, 218, 186, 160, 74, 76, 163, 184, 212, 125, 132, 17, 20, 198, 7, 11, 7, 4, 190, 0, 0, 0, 0, 2, 0, 121, 254, 87, 4, 163, 4, 79, 0, 26, 0, 45, 0, 61, 64, 21, 27, 71, 0, 47, 38, 15, 71, 15, 16, 1, 239, 16, 255, 16, 2, 16, 64, 36, 42, 72, 16, 184, 255, 192, 64, 14, 9, 12, 72, 16, 32, 79, 22, 16, 15, 27, 41, 79, 5, 22, 0, 63, 237, 63, 63, 237, 1, 47, 43, 43, 93, 113, 237, 50, 16, 222, 237, 49, 48, 1, 20, 14, 2, 35, 34, 46, 2, 39, 35, 30, 1, 21, 17, 33, 17, 52, 62, 2, 51, 50, 30, 2, 5, 52, 46, 2, 35, 34, 14, 2, 21, 17, 30, 1, 51, 50, 62, 2, 4, 163, 64, 119, 170, 107, 55, 91, 77, 62, 26, 4, 2, 2, 254, 217, 69, 132, 191, 121, 114, 201, 150, 88, 254, 218, 37, 68, 95, 57, 59, 83, 53, 25, 52, 132, 77, 53, 81, 54, 28, 2, 4, 118, 197, 142, 79, 21, 37, 50, 29, 30, 55, 32, 254, 87, 3, 238, 119, 193, 136, 74, 79, 150, 218, 130, 90, 142, 99, 52, 46, 87, 125, 79, 254, 240, 57, 69, 50, 91, 130, 0, 0, 0, 0, 1, 0, 79, 254, 111, 3, 216, 4, 79, 0, 57, 0, 87, 182, 32, 16, 9, 10, 0, 76, 9, 184, 255, 232, 64, 9, 10, 0, 77, 54, 16, 10, 0, 77, 3, 184, 255, 240, 64, 27, 10, 0, 77, 45, 45, 35, 12, 18, 18, 23, 70, 12, 59, 0, 70, 35, 0, 23, 17, 51, 79, 42, 46, 46, 42, 16, 17, 184, 1, 16, 0, 63, 63, 51, 47, 16, 237, 18, 57, 57, 1, 47, 237, 16, 222, 237, 50, 47, 17, 18, 57, 47, 49, 48, 0, 43, 43, 1, 43, 43, 1, 20, 30, 2, 23, 30, 5, 21, 20, 14, 2, 7, 39, 62, 3, 53, 52, 46, 2, 39, 46, 5, 53, 52, 62, 4, 51, 50, 22, 23, 7, 46, 3, 35, 34, 14, 4, 1, 84, 44, 77, 106, 62, 40, 83, 79, 70, 52, 31, 22, 33, 37, 14, 178, 9, 19, 16, 11, 42, 76, 103, 62, 45, 93, 88, 76, 58, 33, 22, 50, 82, 121, 162, 105, 115, 177, 59, 139, 18, 42, 50, 58, 34, 55, 85, 65, 45, 28, 13, 1, 189, 58, 74, 51, 37, 21, 12, 24, 32, 43, 64, 88, 61, 39, 82, 76, 64, 20, 74, 15, 36, 40, 42, 21, 37, 50, 36, 27, 15, 12, 28, 43, 61, 89, 122, 81, 59, 145, 150, 143, 111, 67, 75, 66, 149, 19, 36, 28, 17, 48, 77, 100, 104, 100, 0, 0, 0, 0, 2, 0, 80, 255, 236, 5, 81, 4, 58, 0, 28, 0, 47, 0, 82, 64, 14, 34, 23, 40, 29, 71, 0, 16, 16, 0, 64, 23, 60, 72, 0, 184, 255, 192, 64, 36, 10, 13, 72, 0, 49, 40, 71, 15, 10, 31, 10, 2, 143, 10, 191, 10, 223, 10, 239, 10, 4, 10, 64, 28, 60, 72, 10, 17, 35, 79, 15, 15, 43, 79, 5, 22, 0, 63, 237, 63, 237, 50, 1, 47, 43, 93, 113, 237, 16, 206, 43, 43, 50, 47, 16, 237, 18, 57, 57, 49, 48, 1, 20, 14, 2, 35, 34, 46, 2, 53, 52, 62, 2, 51, 33, 21, 35, 34, 46, 2, 39, 21, 30, 3, 5, 52, 46, 2, 39, 35, 34, 14, 2, 21, 20, 22, 51, 50, 62, 2, 4, 146, 68, 135, 203, 136, 136, 205, 138, 69, 95, 169, 235, 140, 2, 130, 195, 10, 39, 47, 49, 19, 31, 60, 48, 29, 254, 218, 17, 28, 37, 20, 74, 68, 118, 88, 51, 125, 121, 65, 95, 64, 31, 1, 202, 105, 176, 126, 71, 74, 139, 202, 129, 144, 210, 138, 66, 190, 1, 2, 2, 1, 4, 40, 94, 108, 124, 36, 63, 114, 101, 86, 36, 45, 91, 138, 94, 177, 175, 44, 83, 118, 0, 0, 1, 0, 18, 255, 235, 3, 112, 4, 58, 0, 33, 0, 114, 64, 85, 31, 40, 9, 10, 0, 76, 47, 5, 63, 5, 175, 5, 3, 5, 5, 32, 70, 15, 24, 24, 32, 13, 48, 13, 128, 13, 144, 13, 160, 13, 5, 13, 13, 15, 15, 111, 15, 127, 15, 143, 15, 4, 159, 15, 255, 15, 2, 127, 15, 159, 15, 175, 15, 223, 15, 239, 15, 5, 0, 15, 1, 15, 35, 96, 35, 112, 35, 144, 35, 160, 35, 208, 35, 224, 35, 6, 20, 79, 29, 22, 14, 0, 79, 11, 15, 0, 63, 237, 50, 63, 237, 1, 93, 16, 204, 93, 93, 113, 114, 50, 47, 93, 57, 47, 16, 237, 50, 47, 93, 49, 48, 43, 1, 34, 14, 2, 7, 53, 62, 3, 51, 33, 21, 33, 17, 20, 30, 2, 51, 50, 54, 55, 23, 14, 3, 35, 34, 38, 53, 17, 1, 14, 39, 79, 69, 53, 12, 12, 43, 51, 54, 23, 2, 167, 254, 207, 16, 29, 43, 27, 17, 48, 16, 24, 17, 50, 55, 55, 22, 155, 144, 3, 124, 6, 11, 13, 7, 198, 6, 11, 8, 4, 190, 253, 188, 40, 52, 31, 12, 5, 3, 178, 5, 10, 8, 5, 140, 132, 2, 129, 0, 1, 0, 127, 255, 236, 4, 84, 4, 58, 0, 29, 0, 75, 64, 37, 7, 16, 9, 0, 77, 24, 19, 70, 0, 31, 144, 31, 160, 31, 2, 112, 31, 144, 31, 160, 31, 176, 31, 240, 31, 5, 239, 31, 1, 11, 70, 239, 8, 255, 8, 2, 8, 184, 255, 192, 64, 11, 9, 12, 72, 8, 24, 9, 15, 14, 80, 5, 22, 0, 63, 237, 63, 51, 1, 47, 43, 93, 237, 93, 113, 114, 16, 222, 237, 50, 49, 48, 43, 1, 20, 14, 2, 35, 34, 38, 53, 17, 33, 17, 20, 22, 51, 50, 62, 2, 53, 52, 46, 2, 39, 33, 30, 3, 4, 84, 59, 125, 194, 136, 240, 227, 1, 25, 95, 108, 59, 82, 52, 23, 23, 36, 44, 21, 1, 30, 20, 42, 35, 22, 2, 59, 136, 219, 154, 82, 221, 232, 2, 137, 253, 146, 136, 137, 46, 101, 158, 111, 63, 138, 129, 112, 37, 40, 113, 134, 149, 0, 0, 2, 0, 80, 254, 87, 5, 106, 4, 82, 0, 37, 0, 47, 2, 56, 64, 199, 19, 24, 45, 5, 70, 29, 8, 8, 0, 24, 70, 13, 38, 70, 0, 49, 217, 49, 1, 164, 49, 180, 49, 196, 49, 3, 118, 49, 150, 49, 2, 84, 49, 1, 70, 49, 1, 36, 49, 52, 49, 2, 6, 49, 22, 49, 2, 226, 49, 1, 196, 49, 212, 49, 2, 150, 49, 166, 49, 182, 49, 3, 121, 49, 1, 102, 49, 1, 84, 49, 1, 70, 49, 1, 9, 49, 1, 200, 228, 49, 244, 49, 2, 198, 49, 214, 49, 2, 153, 49, 1, 100, 49, 116, 49, 132, 49, 3, 54, 49, 86, 49, 2, 20, 49, 1, 2, 49, 1, 244, 49, 1, 230, 49, 1, 169, 49, 185, 49, 2, 148, 49, 1, 118, 49, 134, 49, 2, 73, 49, 1, 18, 49, 34, 49, 2, 4, 49, 1, 246, 49, 1, 228, 49, 1, 214, 49, 1, 178, 49, 1, 164, 49, 1, 118, 49, 150, 49, 2, 66, 49, 1, 52, 49, 1, 6, 49, 38, 49, 2, 152, 210, 49, 1, 196, 49, 1, 166, 49, 182, 49, 2, 98, 49, 1, 52, 49, 68, 49, 84, 49, 3, 38, 49, 1, 244, 49, 1, 49, 184, 255, 192, 64, 55, 130, 133, 72, 137, 49, 1, 38, 49, 70, 49, 86, 49, 118, 49, 4, 9, 49, 1, 182, 49, 230, 49, 246, 49, 3, 116, 49, 132, 49, 2, 102, 49, 1, 41, 49, 57, 49, 2, 22, 49, 1, 4, 49, 1, 103, 246, 49, 1, 201, 49, 1, 187, 49, 1, 49, 184, 255, 192, 64, 174, 93, 96, 72, 73, 49, 1, 38, 49, 54, 49, 2, 230, 49, 246, 49, 2, 201, 49, 1, 180, 49, 1, 166, 49, 1, 89, 49, 105, 49, 121, 49, 3, 68, 49, 1, 54, 49, 1, 9, 49, 1, 251, 49, 1, 237, 49, 1, 1, 192, 49, 208, 49, 2, 164, 49, 180, 49, 2, 139, 49, 1, 127, 49, 1, 36, 49, 52, 49, 68, 49, 100, 49, 4, 11, 49, 1, 55, 240, 49, 1, 228, 49, 1, 139, 49, 155, 49, 203, 49, 3, 116, 49, 1, 75, 49, 91, 49, 2, 47, 49, 63, 49, 2, 2, 0, 49, 16, 49, 2, 208, 49, 224, 49, 2, 175, 49, 191, 49, 2, 96, 49, 112, 49, 144, 49, 3, 63, 49, 79, 49, 2, 32, 49, 1, 15, 49, 1, 240, 49, 1, 79, 49, 111, 49, 143, 49, 159, 49, 207, 49, 223, 49, 6, 48, 49, 1, 15, 49, 1, 7, 19, 41, 82, 18, 33, 16, 45, 29, 81, 5, 8, 22, 6, 27, 0, 63, 63, 51, 237, 50, 63, 51, 237, 50, 1, 94, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 114, 95, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 95, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 43, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 113, 113, 113, 43, 113, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 16, 222, 237, 47, 237, 18, 57, 47, 51, 237, 50, 18, 57, 49, 48, 1, 20, 14, 2, 7, 17, 35, 17, 46, 3, 53, 52, 62, 2, 55, 23, 14, 3, 21, 20, 30, 2, 23, 17, 52, 54, 51, 50, 30, 2, 5, 52, 38, 35, 34, 6, 21, 17, 62, 1, 5, 106, 81, 145, 198, 117, 238, 121, 195, 137, 74, 60, 114, 167, 108, 21, 51, 74, 48, 22, 35, 65, 94, 58, 174, 186, 95, 155, 110, 59, 254, 237, 75, 68, 57, 66, 128, 138, 2, 53, 151, 215, 140, 71, 6, 254, 105, 1, 149, 5, 72, 138, 208, 141, 133, 196, 135, 80, 18, 179, 13, 70, 103, 127, 70, 93, 138, 93, 49, 4, 2, 23, 198, 204, 76, 141, 199, 121, 191, 172, 109, 122, 253, 235, 6, 200, 0, 0, 0, 1, 0, 13, 254, 88, 4, 145, 4, 80, 0, 44, 0, 150, 181, 20, 40, 10, 0, 77, 30, 184, 255, 216, 179, 10, 0, 77, 2, 184, 255, 216, 179, 10, 0, 77, 2, 184, 255, 232, 64, 44, 9, 0, 77, 23, 9, 1, 9, 17, 33, 3, 25, 7, 25, 1, 25, 18, 32, 15, 16, 16, 16, 16, 19, 18, 16, 16, 18, 32, 18, 48, 18, 3, 18, 18, 46, 79, 46, 159, 46, 2, 42, 42, 31, 32, 184, 255, 240, 64, 25, 32, 23, 9, 1, 9, 25, 25, 25, 2, 9, 17, 25, 3, 33, 33, 15, 32, 18, 27, 15, 15, 39, 80, 0, 16, 0, 63, 237, 63, 63, 51, 18, 57, 25, 47, 23, 51, 93, 93, 1, 24, 47, 56, 51, 51, 47, 93, 17, 51, 47, 93, 56, 51, 51, 56, 17, 51, 17, 18, 57, 93, 17, 23, 51, 93, 49, 48, 0, 43, 43, 1, 43, 43, 19, 50, 30, 2, 31, 1, 30, 1, 23, 62, 3, 55, 19, 33, 9, 1, 33, 3, 46, 3, 39, 14, 3, 7, 3, 33, 1, 39, 46, 3, 35, 34, 7, 39, 62, 1, 233, 60, 90, 79, 77, 47, 20, 2, 9, 3, 5, 16, 17, 16, 5, 155, 1, 41, 254, 137, 1, 157, 254, 212, 195, 7, 21, 21, 18, 5, 5, 20, 22, 21, 7, 214, 254, 212, 1, 196, 119, 37, 55, 46, 43, 27, 41, 40, 40, 31, 109, 4, 80, 42, 94, 150, 108, 46, 5, 29, 12, 14, 39, 40, 36, 10, 1, 69, 253, 78, 252, 208, 1, 176, 15, 50, 55, 52, 18, 17, 52, 53, 49, 14, 254, 75, 3, 61, 243, 76, 98, 56, 21, 16, 191, 11, 19, 0, 0, 0, 0, 1, 0, 129, 254, 87, 5, 135, 5, 60, 0, 31, 2, 134, 64, 21, 11, 24, 9, 0, 77, 0, 13, 70, 29, 22, 16, 1, 16, 16, 7, 23, 70, 9, 22, 1, 22, 184, 255, 192, 64, 255, 9, 12, 72, 22, 6, 70, 6, 7, 1, 23, 7, 33, 166, 33, 1, 146, 33, 1, 132, 33, 1, 102, 33, 118, 33, 2, 73, 33, 1, 59, 33, 1, 34, 33, 1, 20, 33, 1, 6, 33, 1, 244, 33, 1, 214, 33, 230, 33, 2, 180, 33, 1, 166, 33, 1, 146, 33, 1, 132, 33, 1, 118, 33, 1, 73, 33, 1, 6, 33, 54, 33, 2, 203, 230, 33, 246, 33, 2, 210, 33, 1, 196, 33, 1, 134, 33, 166, 33, 182, 33, 3, 98, 33, 1, 84, 33, 1, 70, 33, 1, 25, 33, 1, 11, 33, 1, 228, 33, 244, 33, 2, 210, 33, 1, 196, 33, 1, 166, 33, 182, 33, 2, 137, 33, 1, 118, 33, 1, 98, 33, 1, 84, 33, 1, 70, 33, 1, 25, 33, 1, 6, 33, 1, 214, 33, 1, 196, 33, 1, 166, 33, 182, 33, 2, 146, 33, 1, 132, 33, 1, 70, 33, 102, 33, 118, 33, 3, 34, 33, 1, 20, 33, 1, 6, 33, 1, 154, 233, 33, 1, 219, 33, 1, 201, 33, 1, 176, 33, 1, 162, 33, 1, 148, 33, 1, 118, 33, 134, 33, 2, 89, 33, 1, 70, 33, 1, 36, 33, 52, 33, 2, 22, 33, 1, 233, 33, 249, 33, 2, 214, 33, 1, 185, 33, 1, 162, 33, 1, 148, 33, 1, 134, 33, 1, 84, 33, 1, 22, 33, 70, 33, 2, 233, 33, 249, 33, 2, 214, 33, 1, 169, 33, 185, 33, 2, 64, 203, 155, 33, 1, 134, 33, 1, 98, 33, 1, 84, 33, 1, 70, 33, 1, 25, 33, 1, 11, 33, 1, 105, 228, 33, 244, 33, 2, 214, 33, 1, 169, 33, 185, 33, 2, 155, 33, 1, 118, 33, 1, 98, 33, 1, 84, 33, 1, 70, 33, 1, 20, 33, 1, 6, 33, 1, 214, 33, 1, 169, 33, 185, 33, 2, 150, 33, 1, 73, 33, 105, 33, 121, 33, 3, 34, 33, 1, 1, 16, 33, 1, 4, 33, 1, 219, 33, 1, 207, 33, 1, 148, 33, 164, 33, 2, 123, 33, 1, 95, 33, 111, 33, 2, 64, 33, 1, 52, 33, 1, 16, 33, 1, 4, 33, 1, 57, 251, 33, 1, 224, 33, 1, 212, 33, 1, 139, 33, 171, 33, 187, 33, 3, 127, 33, 1, 100, 33, 1, 27, 33, 75, 33, 2, 212, 33, 1, 171, 33, 187, 33, 2, 100, 33, 116, 33, 2, 75, 33, 1, 63, 33, 1, 2, 0, 33, 1, 208, 33, 1, 175, 33, 191, 33, 2, 144, 33, 1, 63, 33, 111, 33, 127, 33, 3, 0, 33, 16, 33, 2, 8, 0, 29, 79, 13, 16, 22, 30, 30, 6, 22, 15, 14, 27, 0, 63, 63, 51, 51, 47, 63, 51, 237, 50, 1, 94, 93, 93, 93, 93, 93, 113, 95, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 95, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 16, 222, 94, 93, 237, 47, 43, 93, 237, 18, 57, 47, 113, 51, 237, 50, 49, 48, 0, 43, 37, 62, 3, 53, 17, 33, 17, 20, 14, 2, 7, 17, 33, 17, 46, 3, 53, 17, 33, 17, 20, 30, 2, 23, 17, 33, 3, 133, 66, 91, 57, 25, 1, 19, 55, 123, 194, 140, 254, 253, 136, 195, 125, 59, 1, 19, 29, 59, 91, 61, 1, 1, 176, 1, 29, 69, 114, 85, 2, 96, 253, 144, 122, 179, 117, 59, 1, 254, 107, 1, 149, 1, 59, 117, 179, 122, 2, 112, 253, 161, 85, 113, 69, 29, 2, 4, 139, 0, 0, 1, 0, 81, 255, 236, 6, 113, 4, 79, 0, 61, 2, 129, 64, 255, 13, 13, 19, 61, 46, 46, 40, 30, 61, 70, 60, 60, 19, 51, 70, 6, 40, 1, 40, 8, 70, 9, 19, 1, 38, 19, 63, 185, 63, 1, 148, 63, 164, 63, 2, 134, 63, 1, 116, 63, 1, 102, 63, 1, 52, 63, 1, 38, 63, 1, 4, 63, 20, 63, 2, 246, 63, 1, 196, 63, 1, 178, 63, 1, 164, 63, 1, 102, 63, 150, 63, 2, 68, 63, 1, 54, 63, 1, 25, 63, 1, 6, 63, 1, 202, 233, 63, 1, 212, 63, 1, 198, 63, 1, 164, 63, 1, 150, 63, 1, 121, 63, 1, 102, 63, 1, 84, 63, 1, 66, 63, 1, 52, 63, 1, 38, 63, 1, 9, 63, 1, 242, 63, 1, 212, 63, 228, 63, 2, 198, 63, 1, 137, 63, 169, 63, 2, 116, 63, 1, 102, 63, 1, 41, 63, 73, 63, 2, 2, 63, 1, 244, 63, 1, 226, 63, 1, 212, 63, 1, 198, 63, 1, 148, 63, 1, 130, 63, 1, 116, 63, 1, 102, 63, 1, 57, 63, 73, 63, 2, 34, 63, 1, 20, 63, 1, 6, 63, 1, 154, 244, 63, 1, 230, 63, 1, 196, 63, 1, 118, 63, 134, 63, 150, 63, 182, 63, 4, 84, 63, 1, 70, 63, 1, 36, 63, 52, 63, 2, 22, 63, 1, 249, 63, 1, 226, 63, 1, 196, 63, 212, 63, 2, 182, 63, 1, 121, 63, 153, 63, 2, 38, 63, 70, 63, 86, 63, 102, 63, 4, 9, 63, 1, 249, 63, 64, 222, 1, 182, 63, 198, 63, 230, 63, 3, 137, 63, 153, 63, 2, 114, 63, 1, 100, 63, 1, 86, 63, 1, 41, 63, 57, 63, 2, 4, 63, 1, 104, 246, 63, 1, 217, 63, 1, 203, 63, 1, 169, 63, 1, 86, 63, 102, 63, 134, 63, 150, 63, 4, 57, 63, 1, 6, 63, 38, 63, 2, 230, 63, 246, 63, 2, 201, 63, 1, 187, 63, 1, 164, 63, 1, 134, 63, 150, 63, 2, 105, 63, 1, 91, 63, 1, 73, 63, 1, 38, 63, 54, 63, 2, 9, 63, 1, 233, 63, 1, 219, 63, 1, 150, 63, 182, 63, 198, 63, 3, 121, 63, 1, 107, 63, 1, 86, 63, 1, 52, 63, 1, 38, 63, 1, 9, 63, 1, 56, 251, 63, 1, 226, 63, 1, 1, 208, 63, 1, 196, 63, 1, 171, 63, 1, 159, 63, 1, 123, 63, 1, 100, 63, 1, 75, 63, 1, 63, 63, 1, 27, 63, 43, 63, 2, 240, 63, 1, 2, 176, 63, 192, 63, 224, 63, 3, 159, 63, 1, 80, 63, 96, 63, 128, 63, 3, 63, 63, 1, 0, 63, 1, 79, 63, 95, 63, 127, 63, 191, 63, 223, 63, 5, 0, 63, 1, 8, 60, 60, 14, 3, 56, 79, 30, 24, 35, 22, 46, 13, 81, 45, 14, 16, 0, 63, 51, 237, 50, 63, 51, 51, 237, 50, 17, 57, 47, 1, 94, 93, 93, 113, 113, 113, 113, 113, 95, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 95, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 16, 222, 94, 93, 237, 47, 93, 237, 18, 57, 47, 237, 57, 18, 57, 47, 17, 18, 57, 47, 49, 48, 1, 20, 22, 51, 50, 62, 2, 53, 52, 46, 2, 39, 55, 30, 3, 21, 20, 14, 2, 35, 34, 46, 2, 39, 35, 14, 3, 35, 34, 46, 2, 53, 52, 62, 2, 55, 23, 14, 3, 21, 20, 30, 2, 51, 50, 54, 61, 1, 33, 3, 227, 94, 85, 54, 73, 44, 18, 29, 61, 96, 68, 23, 121, 192, 133, 71, 58, 111, 162, 104, 74, 114, 84, 58, 17, 4, 17, 58, 84, 114, 74, 104, 162, 111, 58, 71, 133, 192, 120, 23, 68, 96, 62, 28, 18, 44, 72, 54, 86, 97, 1, 2, 1, 218, 142, 156, 48, 90, 127, 78, 72, 131, 106, 73, 13, 189, 18, 93, 147, 201, 127, 128, 200, 137, 72, 32, 60, 89, 57, 57, 89, 60, 32, 72, 137, 200, 128, 127, 201, 147, 93, 18, 187, 13, 74, 105, 131, 72, 78, 127, 90, 49, 156, 141, 187, 0, 0, 255, 255, 255, 217, 0, 0, 2, 100, 5, 138, 18, 38, 1, 134, 0, 0, 17, 6, 0, 105, 201, 0, 0, 25, 182, 2, 1, 14, 17, 38, 2, 1, 184, 255, 225, 180, 18, 16, 5, 13, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 0, 255, 255, 0, 127, 255, 236, 4, 84, 5, 138, 18, 38, 1, 146, 0, 0, 17, 7, 0, 105, 0, 242, 0, 0, 0, 25, 182, 2, 1, 30, 17, 38, 2, 1, 184, 255, 222, 180, 34, 32, 8, 0, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 255, 255, 0, 80, 255, 236, 4, 147, 5, 228, 18, 38, 0, 82, 0, 0, 17, 7, 1, 84, 1, 86, 0, 0, 0, 19, 64, 11, 2, 36, 17, 38, 2, 64, 36, 39, 10, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 127, 255, 236, 4, 84, 5, 228, 18, 38, 1, 146, 0, 0, 17, 7, 1, 84, 1, 24, 0, 0, 0, 19, 64, 11, 1, 30, 17, 38, 1, 10, 30, 33, 8, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 81, 255, 236, 6, 113, 5, 228, 18, 38, 1, 150, 0, 0, 17, 7, 1, 84, 2, 91, 0, 0, 0, 19, 64, 11, 1, 62, 17, 38, 1, 86, 62, 65, 40, 19, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 137, 0, 0, 5, 6, 6, 213, 16, 38, 0, 40, 0, 0, 17, 7, 2, 158, 1, 121, 0, 0, 2, 60, 64, 14, 2, 1, 12, 5, 38, 2, 1, 6, 16, 14, 0, 10, 37, 21, 184, 255, 192, 179, 228, 228, 72, 21, 184, 255, 192, 179, 227, 227, 72, 21, 184, 255, 192, 179, 225, 225, 72, 21, 184, 255, 192, 179, 224, 224, 72, 21, 184, 255, 192, 179, 222, 222, 72, 21, 184, 255, 192, 179, 221, 221, 72, 21, 184, 255, 192, 179, 219, 219, 72, 21, 184, 255, 192, 179, 218, 218, 72, 21, 184, 255, 192, 179, 216, 216, 72, 21, 184, 255, 192, 179, 215, 215, 72, 21, 184, 255, 192, 179, 212, 212, 72, 21, 184, 255, 192, 179, 209, 209, 72, 21, 184, 255, 192, 179, 206, 206, 72, 21, 184, 255, 192, 179, 203, 203, 72, 21, 184, 255, 192, 179, 200, 200, 72, 21, 184, 255, 192, 179, 197, 197, 72, 21, 184, 255, 192, 179, 194, 194, 72, 21, 184, 255, 192, 179, 191, 191, 72, 21, 184, 255, 192, 179, 188, 188, 72, 21, 184, 255, 192, 179, 185, 185, 72, 21, 184, 255, 192, 179, 182, 182, 72, 21, 184, 255, 192, 179, 179, 179, 72, 21, 184, 255, 192, 179, 176, 176, 72, 21, 184, 255, 192, 179, 173, 173, 72, 21, 184, 255, 192, 179, 170, 170, 72, 21, 184, 255, 192, 179, 167, 167, 72, 21, 184, 255, 192, 179, 164, 164, 72, 21, 184, 255, 192, 179, 161, 161, 72, 21, 184, 255, 192, 179, 158, 158, 72, 21, 184, 255, 192, 179, 155, 155, 72, 21, 184, 255, 192, 179, 152, 152, 72, 21, 184, 255, 192, 179, 149, 149, 72, 21, 184, 255, 192, 179, 146, 146, 72, 21, 184, 255, 192, 179, 143, 143, 72, 21, 184, 255, 192, 179, 140, 140, 72, 21, 184, 255, 192, 179, 137, 137, 72, 21, 184, 255, 192, 179, 134, 134, 72, 21, 184, 255, 192, 179, 131, 131, 72, 21, 184, 255, 192, 179, 128, 128, 72, 21, 184, 255, 192, 179, 125, 125, 72, 21, 184, 255, 192, 179, 122, 122, 72, 21, 184, 255, 192, 179, 119, 119, 72, 21, 184, 255, 192, 179, 116, 116, 72, 21, 184, 255, 192, 179, 113, 113, 72, 21, 184, 255, 192, 179, 110, 110, 72, 21, 184, 255, 192, 179, 107, 107, 72, 21, 184, 255, 192, 179, 104, 104, 72, 21, 184, 255, 192, 179, 101, 101, 72, 21, 184, 255, 192, 179, 98, 98, 72, 21, 184, 255, 192, 179, 95, 95, 72, 21, 184, 255, 192, 179, 92, 92, 72, 21, 184, 255, 192, 179, 89, 89, 72, 21, 184, 255, 192, 179, 86, 86, 72, 21, 184, 255, 192, 179, 83, 83, 72, 21, 184, 255, 192, 179, 80, 80, 72, 21, 184, 255, 192, 179, 77, 77, 72, 21, 184, 255, 192, 179, 74, 74, 72, 21, 184, 255, 192, 179, 71, 71, 72, 21, 184, 255, 192, 179, 13, 13, 72, 21, 184, 255, 192, 179, 12, 12, 72, 21, 184, 255, 192, 178, 11, 11, 72, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 0, 1, 0, 23, 255, 236, 6, 172, 5, 129, 0, 51, 0, 116, 64, 72, 15, 16, 9, 10, 0, 76, 22, 16, 9, 0, 77, 22, 45, 33, 90, 11, 53, 64, 51, 14, 45, 46, 48, 14, 1, 45, 90, 63, 48, 1, 48, 32, 46, 48, 46, 2, 46, 1, 39, 95, 16, 6, 1, 144, 6, 208, 6, 2, 112, 6, 1, 6, 6, 28, 0, 48, 95, 49, 3, 46, 18, 0, 23, 16, 23, 2, 23, 23, 28, 95, 17, 19, 0, 63, 237, 51, 47, 93, 63, 63, 237, 50, 18, 57, 47, 93, 113, 114, 237, 51, 1, 47, 93, 198, 93, 237, 50, 43, 1, 24, 16, 77, 228, 26, 16, 222, 237, 17, 57, 49, 48, 43, 0, 43, 1, 17, 62, 3, 51, 50, 30, 2, 29, 1, 20, 14, 2, 35, 34, 46, 2, 39, 55, 30, 3, 51, 50, 62, 2, 61, 1, 52, 46, 2, 35, 34, 14, 2, 7, 17, 33, 17, 33, 53, 33, 21, 3, 5, 36, 103, 126, 143, 75, 117, 171, 111, 53, 42, 102, 169, 128, 74, 118, 95, 76, 32, 202, 17, 37, 44, 52, 31, 54, 67, 36, 12, 24, 60, 101, 78, 54, 110, 102, 89, 33, 254, 217, 254, 57, 4, 182, 4, 157, 254, 176, 15, 36, 31, 21, 54, 110, 169, 115, 54, 108, 172, 121, 65, 23, 45, 67, 43, 171, 22, 42, 33, 20, 33, 63, 93, 60, 9, 67, 97, 63, 30, 12, 20, 23, 11, 253, 107, 4, 157, 228, 228, 0, 0, 255, 255, 0, 137, 0, 1, 4, 97, 7, 23, 16, 39, 2, 155, 1, 113, 0, 0, 17, 6, 1, 173, 0, 0, 6, 161, 180, 1, 6, 20, 39, 1, 184, 255, 174, 181, 10, 6, 0, 3, 37, 13, 184, 2, 0, 179, 229, 229, 72, 13, 184, 2, 0, 179, 228, 228, 72, 13, 184, 1, 192, 179, 227, 227, 72, 13, 184, 2, 0, 179, 226, 226, 72, 13, 184, 1, 192, 179, 225, 225, 72, 13, 184, 2, 0, 179, 224, 224, 72, 13, 184, 2, 0, 179, 223, 223, 72, 13, 184, 1, 192, 179, 222, 222, 72, 13, 184, 2, 0, 179, 221, 221, 72, 13, 184, 1, 192, 179, 220, 220, 72, 13, 184, 2, 0, 179, 219, 219, 72, 13, 184, 1, 192, 179, 218, 218, 72, 13, 184, 1, 192, 179, 217, 217, 72, 13, 184, 2, 0, 179, 216, 216, 72, 13, 184, 1, 192, 179, 215, 215, 72, 13, 184, 2, 0, 179, 214, 214, 72, 13, 184, 1, 192, 179, 213, 213, 72, 13, 184, 1, 192, 179, 212, 212, 72, 13, 184, 1, 192, 179, 211, 211, 72, 13, 184, 1, 192, 179, 210, 210, 72, 13, 184, 2, 0, 179, 209, 209, 72, 13, 184, 1, 192, 179, 208, 208, 72, 13, 184, 1, 192, 179, 207, 207, 72, 13, 184, 1, 192, 179, 206, 206, 72, 13, 184, 1, 192, 179, 205, 205, 72, 13, 184, 1, 192, 179, 204, 204, 72, 13, 184, 1, 192, 179, 203, 203, 72, 13, 184, 1, 128, 179, 202, 202, 72, 13, 184, 1, 192, 179, 201, 201, 72, 13, 184, 1, 192, 179, 200, 200, 72, 13, 184, 1, 192, 179, 199, 199, 72, 13, 184, 1, 192, 179, 198, 198, 72, 13, 184, 1, 128, 179, 197, 197, 72, 13, 184, 1, 192, 179, 196, 196, 72, 13, 184, 1, 128, 179, 195, 195, 72, 13, 184, 1, 192, 179, 194, 194, 72, 13, 184, 1, 192, 179, 193, 193, 72, 13, 184, 1, 128, 179, 192, 192, 72, 13, 184, 1, 192, 179, 191, 191, 72, 13, 184, 1, 128, 179, 190, 190, 72, 13, 184, 1, 192, 179, 189, 189, 72, 13, 184, 1, 128, 179, 188, 188, 72, 13, 184, 1, 128, 179, 187, 187, 72, 13, 184, 1, 192, 179, 186, 186, 72, 13, 184, 1, 128, 179, 185, 185, 72, 13, 184, 1, 192, 179, 184, 184, 72, 13, 184, 1, 128, 179, 183, 183, 72, 13, 184, 1, 128, 179, 182, 182, 72, 13, 184, 1, 128, 179, 181, 181, 72, 13, 184, 1, 128, 179, 180, 180, 72, 13, 184, 1, 192, 179, 179, 179, 72, 13, 184, 1, 128, 179, 178, 178, 72, 13, 184, 1, 128, 179, 177, 177, 72, 13, 184, 1, 128, 179, 176, 176, 72, 13, 184, 1, 128, 179, 175, 175, 72, 13, 184, 1, 128, 179, 174, 174, 72, 13, 184, 1, 128, 179, 173, 173, 72, 13, 184, 1, 64, 179, 172, 172, 72, 13, 184, 1, 128, 179, 171, 171, 72, 13, 184, 1, 128, 179, 170, 170, 72, 13, 184, 1, 128, 179, 169, 169, 72, 13, 184, 1, 128, 179, 168, 168, 72, 13, 184, 1, 64, 179, 167, 167, 72, 13, 184, 1, 128, 179, 166, 166, 72, 13, 184, 1, 64, 179, 165, 165, 72, 13, 184, 1, 128, 179, 164, 164, 72, 13, 184, 1, 128, 179, 163, 163, 72, 13, 184, 1, 64, 179, 162, 162, 72, 13, 184, 1, 128, 179, 161, 161, 72, 13, 184, 1, 64, 179, 160, 160, 72, 13, 184, 1, 128, 179, 159, 159, 72, 13, 184, 1, 64, 179, 158, 158, 72, 13, 184, 1, 64, 179, 157, 157, 72, 13, 184, 1, 128, 179, 156, 156, 72, 13, 184, 1, 64, 179, 155, 155, 72, 13, 184, 1, 128, 179, 154, 154, 72, 13, 184, 1, 64, 179, 153, 153, 72, 13, 184, 1, 64, 179, 152, 152, 72, 13, 184, 1, 64, 179, 151, 151, 72, 13, 184, 1, 64, 179, 150, 150, 72, 13, 184, 1, 128, 179, 149, 149, 72, 13, 184, 1, 64, 179, 148, 148, 72, 13, 184, 1, 64, 179, 147, 147, 72, 13, 184, 1, 64, 179, 146, 146, 72, 13, 184, 1, 64, 179, 145, 145, 72, 13, 184, 1, 64, 179, 144, 144, 72, 13, 184, 1, 64, 179, 143, 143, 72, 13, 184, 1, 0, 179, 142, 142, 72, 13, 184, 1, 64, 179, 141, 141, 72, 13, 184, 1, 64, 179, 140, 140, 72, 13, 184, 1, 64, 179, 139, 139, 72, 13, 184, 1, 64, 179, 138, 138, 72, 13, 184, 1, 0, 179, 137, 137, 72, 13, 184, 1, 64, 179, 136, 136, 72, 13, 184, 1, 0, 179, 135, 135, 72, 13, 184, 1, 64, 179, 134, 134, 72, 13, 184, 1, 64, 179, 133, 133, 72, 13, 184, 1, 0, 179, 132, 132, 72, 13, 184, 1, 64, 179, 131, 131, 72, 13, 184, 1, 0, 179, 130, 130, 72, 13, 184, 1, 64, 179, 129, 129, 72, 13, 184, 1, 0, 179, 128, 128, 72, 13, 184, 1, 0, 179, 127, 127, 72, 13, 184, 1, 64, 179, 126, 126, 72, 13, 184, 1, 0, 179, 125, 125, 72, 13, 184, 1, 64, 179, 124, 124, 72, 13, 184, 1, 0, 179, 123, 123, 72, 13, 184, 1, 0, 179, 122, 122, 72, 13, 184, 1, 0, 179, 121, 121, 72, 13, 184, 1, 0, 179, 120, 120, 72, 13, 184, 1, 64, 179, 119, 119, 72, 13, 184, 1, 0, 179, 118, 118, 72, 13, 184, 1, 0, 179, 117, 117, 72, 13, 184, 1, 0, 179, 116, 116, 72, 13, 184, 1, 0, 179, 115, 115, 72, 13, 184, 1, 0, 179, 114, 114, 72, 13, 184, 1, 0, 64, 9, 113, 113, 72, 13, 192, 112, 112, 72, 13, 184, 1, 0, 179, 111, 111, 72, 13, 184, 1, 0, 179, 110, 110, 72, 13, 184, 1, 0, 179, 109, 109, 72, 13, 184, 1, 0, 64, 9, 108, 108, 72, 13, 192, 107, 107, 72, 13, 184, 1, 0, 64, 9, 106, 106, 72, 13, 192, 105, 105, 72, 13, 184, 1, 0, 179, 104, 104, 72, 13, 184, 1, 0, 64, 9, 103, 103, 72, 13, 192, 102, 102, 72, 13, 184, 1, 0, 64, 9, 101, 101, 72, 13, 192, 100, 100, 72, 13, 184, 1, 0, 64, 14, 99, 99, 72, 13, 192, 98, 98, 72, 13, 192, 97, 97, 72, 13, 184, 1, 0, 64, 9, 96, 96, 72, 13, 192, 95, 95, 72, 13, 184, 1, 0, 64, 24, 94, 94, 72, 13, 192, 93, 93, 72, 13, 192, 92, 92, 72, 13, 192, 91, 91, 72, 13, 192, 90, 90, 72, 13, 184, 1, 0, 64, 255, 89, 89, 72, 13, 192, 88, 88, 72, 13, 192, 87, 87, 72, 13, 192, 86, 86, 72, 13, 192, 85, 85, 72, 13, 128, 84, 84, 72, 13, 192, 83, 83, 72, 13, 192, 82, 82, 72, 13, 192, 81, 81, 72, 13, 192, 80, 80, 72, 13, 128, 79, 79, 72, 13, 192, 78, 78, 72, 13, 128, 77, 77, 72, 13, 192, 76, 76, 72, 13, 128, 75, 75, 72, 13, 128, 74, 74, 72, 13, 192, 73, 73, 72, 13, 128, 72, 72, 72, 13, 192, 71, 71, 72, 13, 128, 70, 70, 72, 13, 128, 69, 69, 72, 13, 128, 68, 68, 72, 13, 128, 67, 67, 72, 13, 192, 66, 66, 72, 13, 128, 65, 65, 72, 13, 128, 64, 64, 72, 13, 128, 63, 63, 72, 13, 128, 62, 62, 72, 13, 128, 61, 61, 72, 13, 128, 60, 60, 72, 13, 128, 59, 59, 72, 13, 128, 58, 58, 72, 13, 128, 57, 57, 72, 13, 128, 56, 56, 72, 13, 128, 55, 55, 72, 13, 64, 54, 54, 72, 13, 128, 53, 53, 72, 13, 128, 52, 52, 72, 13, 128, 51, 51, 72, 13, 128, 50, 50, 72, 13, 64, 49, 49, 72, 13, 128, 48, 48, 72, 13, 64, 47, 47, 72, 13, 128, 46, 46, 72, 13, 64, 45, 45, 72, 13, 64, 44, 44, 72, 13, 128, 43, 43, 72, 13, 64, 42, 42, 72, 13, 128, 41, 41, 72, 13, 64, 40, 40, 72, 13, 64, 39, 39, 72, 13, 64, 64, 108, 38, 38, 72, 13, 64, 37, 37, 72, 13, 128, 36, 36, 72, 13, 64, 35, 35, 72, 13, 64, 34, 34, 72, 13, 64, 33, 33, 72, 13, 64, 32, 32, 72, 13, 64, 31, 31, 72, 13, 64, 30, 30, 72, 13, 64, 29, 29, 72, 13, 64, 28, 28, 72, 13, 64, 27, 27, 72, 13, 64, 26, 26, 72, 13, 64, 25, 25, 72, 13, 64, 23, 23, 72, 13, 64, 22, 22, 72, 13, 64, 21, 21, 72, 13, 64, 20, 20, 72, 13, 64, 18, 18, 72, 13, 64, 16, 16, 72, 13, 64, 13, 13, 72, 13, 64, 11, 11, 72, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 1, 43, 53, 0, 43, 53, 0, 0, 1, 0, 84, 255, 236, 5, 123, 5, 150, 0, 44, 0, 120, 64, 80, 27, 92, 26, 38, 26, 38, 6, 37, 40, 91, 48, 16, 1, 15, 16, 31, 16, 2, 16, 5, 92, 15, 6, 1, 6, 46, 40, 95, 95, 37, 111, 37, 143, 37, 223, 37, 255, 37, 5, 239, 37, 1, 37, 37, 0, 32, 95, 21, 127, 27, 1, 27, 27, 21, 4, 0, 95, 11, 32, 5, 48, 5, 2, 32, 5, 96, 5, 112, 5, 160, 5, 224, 5, 240, 5, 6, 5, 5, 11, 19, 0, 63, 51, 47, 93, 113, 16, 237, 63, 51, 47, 93, 16, 237, 18, 57, 47, 93, 113, 237, 1, 16, 222, 93, 237, 47, 93, 93, 237, 50, 17, 57, 57, 47, 47, 237, 49, 48, 37, 50, 62, 2, 55, 23, 14, 3, 35, 34, 36, 38, 2, 53, 52, 18, 54, 36, 51, 50, 30, 2, 23, 7, 46, 3, 35, 34, 14, 2, 7, 33, 21, 33, 30, 3, 3, 19, 81, 120, 86, 58, 19, 252, 31, 98, 148, 204, 138, 180, 254, 248, 172, 84, 83, 170, 1, 3, 175, 136, 204, 149, 97, 28, 255, 14, 57, 87, 117, 75, 91, 142, 99, 56, 5, 2, 34, 253, 221, 6, 56, 100, 145, 212, 47, 76, 96, 49, 97, 76, 146, 112, 69, 109, 195, 1, 12, 159, 165, 1, 10, 187, 101, 58, 105, 143, 86, 71, 45, 83, 64, 39, 50, 95, 137, 87, 228, 89, 144, 101, 55, 0, 255, 255, 0, 59, 255, 236, 5, 6, 5, 150, 18, 6, 0, 54, 0, 0, 255, 255, 0, 137, 0, 0, 1, 176, 5, 129, 18, 6, 0, 44, 0, 0, 255, 255, 255, 213, 0, 0, 2, 96, 6, 213, 16, 38, 0, 44, 0, 0, 17, 6, 2, 158, 198, 0, 2, 22, 182, 2, 1, 4, 5, 38, 2, 1, 184, 255, 254, 64, 255, 8, 6, 0, 2, 37, 13, 64, 229, 229, 72, 13, 64, 226, 226, 72, 13, 64, 225, 225, 72, 13, 64, 222, 222, 72, 13, 64, 219, 219, 72, 13, 64, 218, 218, 72, 13, 64, 215, 215, 72, 13, 64, 212, 212, 72, 13, 64, 211, 211, 72, 13, 64, 208, 208, 72, 13, 64, 207, 207, 72, 13, 64, 204, 204, 72, 13, 64, 201, 201, 72, 13, 64, 200, 200, 72, 13, 64, 197, 197, 72, 13, 64, 193, 193, 72, 13, 64, 190, 190, 72, 13, 64, 189, 189, 72, 13, 64, 186, 186, 72, 13, 64, 183, 183, 72, 13, 64, 182, 182, 72, 13, 64, 179, 179, 72, 13, 64, 175, 175, 72, 13, 64, 172, 172, 72, 13, 64, 171, 171, 72, 13, 64, 168, 168, 72, 13, 64, 164, 164, 72, 13, 64, 161, 161, 72, 13, 64, 157, 157, 72, 13, 64, 154, 154, 72, 13, 64, 153, 153, 72, 13, 64, 150, 150, 72, 13, 64, 146, 146, 72, 13, 64, 143, 143, 72, 13, 64, 139, 139, 72, 13, 64, 135, 135, 72, 13, 64, 132, 132, 72, 13, 64, 128, 128, 72, 13, 64, 125, 125, 72, 13, 64, 121, 121, 72, 13, 64, 117, 117, 72, 13, 64, 114, 114, 72, 13, 64, 110, 110, 72, 13, 64, 103, 103, 72, 13, 64, 99, 99, 72, 13, 64, 96, 96, 72, 13, 64, 92, 92, 72, 13, 64, 85, 85, 72, 13, 64, 81, 81, 72, 13, 64, 74, 74, 72, 64, 16, 13, 64, 67, 67, 72, 13, 64, 63, 63, 72, 13, 64, 56, 56, 72, 13, 184, 255, 192, 179, 55, 55, 72, 13, 184, 255, 192, 179, 52, 52, 72, 13, 184, 255, 192, 179, 51, 51, 72, 13, 184, 255, 192, 179, 50, 50, 72, 13, 184, 255, 192, 179, 49, 49, 72, 13, 184, 255, 192, 179, 46, 46, 72, 13, 184, 255, 192, 179, 41, 41, 72, 13, 184, 255, 192, 64, 9, 40, 40, 72, 13, 64, 38, 38, 72, 13, 184, 255, 192, 179, 37, 37, 72, 13, 184, 255, 192, 179, 36, 36, 72, 13, 184, 255, 192, 179, 35, 35, 72, 13, 184, 255, 192, 179, 32, 32, 72, 13, 184, 255, 192, 64, 14, 31, 31, 72, 13, 64, 27, 27, 72, 13, 64, 26, 26, 72, 13, 184, 255, 192, 179, 23, 23, 72, 13, 184, 255, 192, 179, 22, 22, 72, 13, 184, 255, 192, 179, 21, 21, 72, 13, 184, 255, 192, 179, 20, 20, 72, 13, 184, 255, 192, 183, 17, 17, 72, 13, 64, 9, 9, 72, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 255, 255, 0, 31, 255, 236, 3, 231, 5, 129, 18, 6, 0, 45, 0, 0, 0, 2, 0, 8, 255, 240, 8, 120, 5, 129, 0, 38, 0, 47, 0, 120, 185, 0, 8, 255, 232, 179, 26, 39, 72, 8, 184, 255, 224, 64, 11, 22, 25, 72, 165, 8, 181, 8, 197, 8, 3, 8, 184, 255, 240, 64, 53, 11, 18, 72, 8, 92, 31, 33, 44, 90, 6, 31, 6, 31, 6, 19, 39, 91, 0, 49, 31, 19, 1, 19, 43, 95, 16, 33, 1, 95, 33, 111, 33, 143, 33, 3, 239, 33, 1, 33, 33, 44, 8, 96, 31, 3, 23, 96, 16, 19, 44, 95, 6, 18, 0, 63, 237, 63, 237, 63, 237, 18, 57, 47, 93, 113, 114, 237, 1, 47, 93, 16, 222, 237, 17, 57, 57, 47, 47, 16, 237, 50, 16, 237, 43, 93, 43, 43, 49, 48, 1, 20, 14, 2, 35, 33, 17, 33, 3, 14, 5, 35, 34, 38, 39, 53, 30, 1, 51, 50, 62, 4, 55, 19, 33, 17, 33, 50, 30, 2, 5, 52, 38, 35, 33, 17, 33, 50, 54, 8, 120, 65, 131, 195, 130, 253, 77, 254, 165, 49, 23, 45, 53, 65, 85, 110, 72, 27, 58, 14, 8, 27, 8, 23, 40, 37, 36, 35, 38, 21, 67, 3, 135, 1, 172, 123, 184, 121, 61, 254, 214, 139, 138, 254, 170, 1, 92, 140, 131, 1, 175, 90, 158, 116, 67, 4, 141, 254, 164, 161, 249, 185, 126, 78, 34, 9, 8, 247, 4, 3, 21, 56, 98, 155, 218, 147, 1, 217, 253, 207, 60, 109, 154, 98, 93, 101, 254, 121, 101, 0, 0, 0, 0, 2, 0, 137, 0, 0, 8, 54, 5, 129, 0, 22, 0, 31, 0, 75, 64, 43, 17, 28, 90, 14, 6, 6, 10, 23, 91, 0, 33, 13, 9, 90, 10, 27, 27, 8, 96, 17, 16, 13, 1, 95, 13, 111, 13, 143, 13, 3, 239, 13, 1, 13, 13, 15, 11, 3, 28, 95, 10, 6, 18, 0, 63, 51, 237, 63, 51, 57, 47, 93, 113, 114, 51, 237, 50, 47, 1, 47, 237, 50, 16, 222, 237, 17, 57, 47, 51, 237, 50, 49, 48, 1, 20, 14, 2, 35, 33, 17, 33, 17, 33, 17, 33, 17, 33, 17, 33, 17, 33, 50, 30, 2, 5, 52, 38, 43, 1, 17, 33, 50, 54, 8, 54, 65, 131, 195, 130, 253, 166, 253, 221, 254, 217, 1, 39, 2, 35, 1, 39, 1, 83, 123, 184, 121, 61, 254, 214, 139, 138, 253, 1, 3, 140, 131, 1, 175, 90, 158, 116, 67, 2, 92, 253, 164, 5, 129, 253, 207, 2, 49, 253, 207, 60, 109, 154, 98, 93, 101, 254, 121, 101, 0, 0, 0, 0, 1, 0, 23, 0, 0, 6, 123, 5, 129, 0, 27, 0, 72, 64, 39, 11, 90, 10, 29, 64, 27, 14, 21, 22, 24, 14, 1, 21, 90, 63, 24, 1, 24, 32, 22, 48, 22, 2, 22, 0, 24, 95, 25, 17, 95, 1, 6, 6, 10, 25, 3, 22, 10, 18, 0, 63, 51, 63, 18, 57, 47, 51, 237, 16, 237, 50, 1, 47, 93, 198, 93, 237, 50, 43, 1, 24, 16, 77, 228, 26, 16, 222, 237, 49, 48, 1, 17, 62, 3, 51, 50, 22, 21, 17, 33, 17, 52, 46, 2, 35, 34, 6, 7, 17, 33, 17, 33, 53, 33, 21, 3, 5, 37, 91, 104, 118, 64, 235, 237, 254, 228, 30, 68, 107, 78, 88, 165, 66, 254, 217, 254, 57, 4, 182, 4, 157, 254, 193, 14, 30, 24, 15, 226, 239, 254, 32, 1, 193, 72, 105, 67, 33, 32, 21, 253, 95, 4, 157, 228, 228, 0, 0, 0, 255, 255, 0, 137, 0, 0, 4, 229, 7, 23, 18, 38, 1, 180, 0, 0, 17, 7, 2, 155, 1, 172, 0, 0, 0, 19, 64, 11, 1, 26, 5, 38, 1, 75, 26, 29, 0, 16, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 255, 249, 255, 236, 5, 5, 7, 62, 18, 38, 1, 189, 248, 0, 17, 7, 2, 151, 1, 31, 1, 74, 0, 21, 180, 1, 26, 5, 38, 1, 184, 255, 244, 180, 33, 41, 21, 25, 37, 1, 43, 53, 0, 43, 53, 0, 0, 1, 0, 137, 254, 104, 5, 54, 5, 129, 0, 11, 1, 236, 64, 255, 11, 92, 0, 0, 2, 6, 90, 9, 13, 5, 90, 4, 2, 20, 2, 2, 11, 2, 180, 13, 1, 139, 13, 1, 116, 13, 1, 96, 13, 1, 4, 13, 36, 13, 68, 13, 84, 13, 4, 235, 13, 1, 212, 13, 1, 187, 13, 1, 175, 13, 1, 128, 13, 144, 13, 2, 100, 13, 116, 13, 2, 80, 13, 1, 68, 13, 1, 27, 13, 1, 4, 13, 1, 202, 235, 13, 1, 192, 13, 1, 180, 13, 1, 155, 13, 1, 128, 13, 1, 68, 13, 116, 13, 2, 11, 13, 27, 13, 43, 13, 3, 224, 13, 240, 13, 2, 100, 13, 164, 13, 180, 13, 212, 13, 4, 59, 13, 75, 13, 2, 4, 13, 20, 13, 2, 196, 13, 212, 13, 244, 13, 3, 91, 13, 107, 13, 171, 13, 3, 4, 13, 52, 13, 2, 153, 196, 13, 228, 13, 244, 13, 3, 155, 13, 1, 143, 13, 1, 116, 13, 1, 96, 13, 1, 84, 13, 1, 48, 13, 1, 36, 13, 1, 11, 13, 1, 228, 13, 1, 155, 13, 187, 13, 2, 132, 13, 1, 80, 13, 1, 68, 13, 1, 43, 13, 1, 20, 13, 1, 187, 13, 219, 13, 251, 13, 3, 52, 13, 68, 13, 100, 13, 116, 13, 132, 13, 164, 13, 6, 27, 13, 1, 15, 13, 1, 105, 228, 13, 244, 13, 2, 208, 13, 1, 196, 13, 1, 155, 13, 1, 116, 13, 1, 43, 13, 91, 13, 2, 240, 13, 1, 180, 13, 228, 13, 64, 117, 2, 75, 13, 123, 13, 139, 13, 3, 20, 13, 36, 13, 2, 212, 13, 1, 123, 13, 139, 13, 171, 13, 187, 13, 4, 100, 13, 1, 80, 13, 1, 52, 13, 68, 13, 2, 27, 13, 1, 4, 13, 1, 55, 219, 13, 1, 196, 13, 1, 155, 13, 171, 13, 2, 112, 13, 1, 52, 13, 84, 13, 100, 13, 3, 251, 13, 1, 228, 13, 1, 203, 13, 1, 191, 13, 1, 148, 13, 1, 43, 13, 59, 13, 75, 13, 107, 13, 4, 251, 13, 1, 84, 13, 132, 13, 196, 13, 212, 13, 4, 27, 13, 43, 13, 2, 15, 13, 1, 7, 2, 5, 96, 1, 10, 2, 18, 0, 184, 1, 17, 178, 7, 3, 3, 0, 63, 51, 63, 63, 196, 16, 237, 1, 95, 94, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 47, 94, 93, 237, 16, 222, 237, 17, 57, 47, 237, 49, 48, 1, 17, 33, 17, 33, 17, 33, 17, 33, 17, 33, 17, 2, 99, 254, 38, 1, 39, 2, 105, 1, 29, 254, 39, 254, 104, 1, 152, 5, 129, 251, 115, 4, 141, 250, 127, 254, 104, 255, 255, 0, 51, 0, 0, 5, 145, 5, 129, 18, 6, 0, 36, 0, 0, 0, 2, 0, 137, 0, 0, 5, 119, 5, 129, 0, 16, 0, 25, 0, 85, 181, 3, 24, 9, 0, 77, 14, 184, 255, 232, 64, 44, 9, 0, 77, 9, 9, 16, 22, 17, 91, 0, 27, 48, 27, 1, 11, 22, 90, 6, 21, 95, 16, 11, 1, 95, 11, 111, 11, 143, 11, 3, 239, 11, 1, 11, 11, 22, 10, 95, 7, 3, 22, 95, 6, 18, 0, 63, 237, 63, 237, 18, 57, 47, 93, 113, 114, 237, 1, 47, 237, 50, 93, 16, 222, 237, 17, 18, 57, 47, 49, 48, 0, 43, 43, 1, 20, 14, 2, 35, 33, 17, 33, 21, 33, 17, 33, 50, 30, 2, 5, 52, 38, 35, 33, 17, 33, 50, 54, 5, 119, 65, 131, 195, 130, 253, 27, 4, 37, 253, 2, 1, 222, 123, 184, 121, 61, 254, 214, 139, 138, 254, 120, 1, 142, 140, 131, 1, 175, 90, 158, 116, 67, 5, 129, 227, 254, 178, 60, 109, 154, 98, 93, 101, 254, 121, 101, 0, 0, 0, 255, 255, 0, 137, 0, 0, 5, 106, 5, 129, 18, 6, 0, 37, 0, 0, 0, 1, 0, 137, 0, 1, 4, 97, 5, 129, 0, 5, 0, 34, 64, 19, 15, 1, 1, 1, 7, 3, 90, 32, 4, 48, 4, 2, 4, 2, 95, 5, 3, 3, 18, 0, 63, 63, 237, 1, 47, 93, 237, 16, 206, 93, 49, 48, 1, 21, 33, 17, 33, 17, 4, 97, 253, 79, 254, 217, 5, 129, 228, 251, 100, 5, 128, 0, 0, 2, 0, 18, 254, 104, 5, 142, 5, 129, 0, 16, 0, 25, 0, 78, 64, 43, 41, 15, 57, 15, 2, 15, 16, 18, 24, 72, 25, 91, 9, 19, 92, 15, 9, 15, 9, 7, 3, 92, 2, 2, 17, 90, 0, 27, 6, 92, 7, 19, 96, 15, 3, 25, 0, 8, 96, 5, 18, 7, 2, 184, 1, 17, 0, 63, 51, 63, 237, 50, 50, 63, 237, 1, 47, 237, 16, 220, 237, 51, 47, 237, 17, 57, 57, 47, 47, 237, 16, 237, 43, 93, 49, 48, 37, 51, 17, 35, 17, 33, 17, 35, 17, 51, 62, 3, 55, 19, 33, 1, 17, 33, 7, 14, 3, 7, 4, 213, 185, 250, 252, 120, 250, 156, 34, 64, 55, 45, 15, 61, 3, 21, 254, 227, 254, 250, 31, 12, 36, 45, 54, 29, 244, 253, 116, 1, 152, 254, 104, 2, 140, 62, 160, 186, 205, 107, 1, 189, 251, 115, 3, 153, 234, 85, 191, 184, 166, 61, 255, 255, 0, 137, 0, 0, 5, 6, 5, 129, 18, 6, 0, 40, 0, 0, 0, 1, 255, 250, 0, 0, 7, 69, 5, 129, 0, 45, 2, 251, 64, 35, 38, 41, 39, 45, 6, 9, 8, 25, 45, 90, 22, 0, 0, 8, 39, 31, 32, 16, 32, 32, 40, 39, 16, 6, 39, 22, 39, 38, 39, 3, 39, 39, 47, 16, 15, 184, 255, 240, 179, 15, 15, 7, 8, 184, 255, 240, 64, 255, 9, 8, 1, 10, 8, 235, 47, 1, 217, 47, 1, 203, 47, 1, 189, 47, 1, 171, 47, 1, 157, 47, 1, 139, 47, 1, 86, 47, 1, 9, 47, 57, 47, 2, 214, 47, 1, 185, 47, 1, 166, 47, 1, 105, 47, 137, 47, 2, 91, 47, 1, 73, 47, 1, 38, 47, 1, 9, 47, 1, 199, 233, 47, 1, 219, 47, 1, 9, 47, 25, 47, 57, 47, 89, 47, 105, 47, 137, 47, 185, 47, 7, 198, 47, 230, 47, 246, 47, 3, 169, 47, 1, 118, 47, 1, 89, 47, 1, 70, 47, 1, 41, 47, 1, 22, 47, 1, 246, 47, 1, 185, 47, 217, 47, 2, 118, 47, 150, 47, 2, 9, 47, 41, 47, 89, 47, 3, 151, 246, 47, 1, 228, 47, 1, 214, 47, 1, 194, 47, 1, 180, 47, 1, 166, 47, 1, 148, 47, 1, 102, 47, 134, 47, 2, 84, 47, 1, 66, 47, 1, 52, 47, 1, 38, 47, 1, 20, 47, 1, 6, 47, 1, 228, 47, 1, 214, 47, 1, 180, 47, 196, 47, 2, 166, 47, 1, 146, 47, 1, 132, 47, 1, 114, 47, 1, 96, 47, 1, 82, 47, 1, 68, 47, 1, 50, 47, 1, 36, 47, 1, 2, 47, 18, 47, 2, 242, 47, 1, 224, 47, 1, 210, 47, 1, 196, 47, 1, 178, 47, 1, 164, 47, 1, 130, 47, 146, 47, 2, 116, 47, 1, 96, 47, 1, 82, 47, 1, 68, 47, 1, 50, 47, 1, 36, 47, 64, 232, 1, 16, 47, 1, 2, 47, 1, 103, 244, 47, 1, 226, 47, 1, 212, 47, 1, 198, 47, 1, 162, 47, 178, 47, 2, 148, 47, 1, 130, 47, 1, 116, 47, 1, 98, 47, 1, 84, 47, 1, 70, 47, 1, 50, 47, 1, 20, 47, 36, 47, 2, 2, 47, 1, 244, 47, 1, 226, 47, 1, 212, 47, 1, 198, 47, 1, 178, 47, 1, 164, 47, 1, 150, 47, 1, 116, 47, 132, 47, 2, 102, 47, 1, 68, 47, 84, 47, 2, 50, 47, 1, 36, 47, 1, 22, 47, 1, 4, 47, 1, 246, 47, 1, 196, 47, 212, 47, 2, 178, 47, 1, 1, 160, 47, 1, 148, 47, 1, 128, 47, 1, 100, 47, 116, 47, 2, 80, 47, 1, 68, 47, 1, 32, 47, 48, 47, 2, 20, 47, 1, 0, 47, 1, 55, 240, 47, 1, 228, 47, 1, 208, 47, 1, 132, 47, 164, 47, 196, 47, 3, 112, 47, 1, 100, 47, 1, 80, 47, 1, 36, 47, 68, 47, 2, 0, 47, 1, 244, 47, 1, 208, 47, 1, 148, 47, 164, 47, 196, 47, 3, 128, 47, 1, 84, 47, 116, 47, 2, 32, 47, 1, 2, 16, 47, 1, 208, 47, 240, 47, 2, 191, 47, 1, 112, 47, 160, 47, 2, 79, 47, 1, 32, 47, 1, 15, 47, 1, 7, 41, 38, 9, 9, 184, 255, 240, 64, 21, 9, 10, 0, 76, 9, 6, 22, 44, 1, 25, 1, 22, 22, 31, 23, 15, 3, 40, 8, 0, 18, 0, 63, 50, 50, 63, 51, 51, 57, 47, 51, 51, 17, 51, 17, 18, 57, 43, 17, 51, 50, 1, 94, 93, 93, 93, 93, 93, 93, 113, 95, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 95, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 47, 94, 93, 56, 51, 51, 47, 56, 51, 17, 51, 47, 93, 56, 51, 51, 47, 56, 51, 17, 18, 57, 47, 51, 237, 50, 18, 57, 57, 17, 18, 57, 57, 49, 48, 33, 17, 34, 46, 2, 39, 1, 33, 1, 46, 3, 39, 3, 33, 19, 30, 3, 51, 17, 33, 17, 50, 62, 2, 55, 19, 33, 3, 14, 3, 7, 1, 33, 1, 14, 1, 35, 17, 3, 18, 15, 35, 34, 32, 11, 254, 163, 254, 196, 1, 199, 12, 37, 43, 46, 22, 251, 1, 44, 198, 48, 70, 56, 48, 27, 1, 28, 27, 48, 57, 70, 48, 198, 1, 44, 251, 22, 46, 43, 37, 12, 1, 199, 254, 196, 254, 163, 26, 71, 30, 2, 100, 4, 7, 10, 7, 253, 128, 3, 12, 9, 45, 61, 71, 36, 1, 151, 254, 188, 78, 106, 64, 27, 2, 87, 253, 169, 27, 64, 106, 78, 1, 68, 254, 105, 36, 71, 61, 45, 9, 252, 244, 2, 128, 13, 15, 253, 156, 0, 0, 1, 0, 46, 255, 236, 4, 165, 5, 149, 0, 56, 0, 141, 185, 0, 40, 255, 248, 64, 88, 9, 10, 0, 76, 31, 92, 32, 47, 42, 19, 19, 32, 23, 90, 42, 32, 42, 32, 42, 5, 14, 90, 52, 58, 6, 92, 15, 5, 31, 5, 2, 5, 64, 13, 21, 72, 5, 47, 18, 95, 95, 19, 111, 19, 143, 19, 223, 19, 255, 19, 5, 239, 19, 1, 19, 19, 11, 37, 127, 31, 1, 31, 31, 26, 95, 37, 4, 11, 95, 0, 48, 6, 1, 32, 6, 96, 6, 112, 6, 160, 6, 240, 6, 5, 6, 6, 0, 19, 0, 63, 50, 47, 93, 113, 16, 237, 63, 237, 51, 47, 93, 17, 18, 57, 47, 93, 113, 237, 57, 1, 47, 43, 93, 237, 16, 222, 237, 18, 57, 57, 47, 47, 16, 237, 17, 57, 47, 18, 57, 16, 237, 49, 48, 43, 5, 34, 46, 2, 39, 37, 30, 3, 51, 50, 54, 53, 52, 38, 43, 1, 53, 51, 50, 54, 53, 52, 38, 35, 34, 14, 2, 7, 37, 62, 3, 51, 50, 30, 2, 21, 20, 14, 2, 7, 30, 3, 21, 20, 14, 2, 2, 126, 126, 193, 142, 99, 32, 1, 8, 20, 58, 79, 104, 67, 129, 134, 159, 169, 59, 59, 151, 144, 123, 108, 63, 94, 69, 47, 15, 254, 244, 31, 94, 136, 182, 118, 116, 188, 134, 73, 40, 73, 104, 63, 67, 115, 85, 49, 74, 141, 205, 20, 52, 99, 144, 93, 93, 55, 92, 68, 38, 107, 97, 101, 89, 227, 96, 100, 91, 96, 40, 68, 90, 49, 61, 92, 148, 106, 57, 52, 95, 136, 84, 69, 111, 83, 57, 16, 10, 49, 81, 113, 73, 93, 154, 111, 62, 0, 0, 0, 1, 0, 136, 0, 0, 5, 55, 5, 129, 0, 19, 0, 109, 64, 41, 9, 32, 10, 0, 77, 9, 24, 9, 0, 77, 18, 9, 12, 92, 11, 21, 64, 21, 80, 21, 96, 21, 3, 112, 21, 128, 21, 2, 32, 21, 48, 21, 160, 21, 192, 21, 4, 15, 21, 1, 19, 184, 255, 224, 179, 10, 0, 77, 19, 184, 255, 232, 64, 23, 9, 0, 77, 19, 8, 2, 92, 32, 1, 48, 1, 2, 1, 18, 8, 18, 8, 9, 1, 3, 12, 0, 18, 0, 63, 50, 63, 51, 57, 57, 47, 47, 1, 47, 93, 237, 50, 50, 43, 43, 93, 93, 113, 114, 16, 222, 237, 50, 50, 43, 43, 49, 48, 51, 17, 33, 17, 20, 6, 7, 6, 7, 1, 33, 17, 33, 17, 52, 54, 55, 54, 55, 1, 136, 1, 6, 2, 2, 2, 2, 2, 101, 1, 76, 254, 250, 2, 2, 2, 2, 253, 159, 5, 129, 252, 205, 50, 98, 39, 46, 42, 4, 70, 250, 127, 3, 63, 40, 88, 38, 44, 44, 251, 195, 255, 255, 0, 136, 0, 0, 5, 55, 7, 62, 18, 38, 1, 178, 0, 0, 17, 7, 2, 151, 1, 146, 1, 74, 0, 19, 64, 11, 1, 20, 5, 38, 1, 6, 27, 35, 0, 10, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 0, 1, 0, 137, 0, 0, 4, 229, 5, 129, 0, 25, 0, 90, 181, 17, 8, 10, 0, 77, 15, 184, 255, 240, 64, 44, 9, 10, 0, 76, 18, 15, 16, 8, 9, 16, 9, 9, 17, 16, 16, 0, 16, 16, 16, 2, 16, 16, 27, 2, 24, 90, 32, 25, 48, 25, 2, 25, 15, 18, 23, 97, 2, 2, 25, 16, 18, 8, 0, 3, 0, 63, 50, 63, 51, 57, 47, 237, 57, 57, 1, 47, 93, 237, 50, 17, 51, 47, 93, 56, 51, 51, 47, 56, 51, 17, 57, 57, 49, 48, 0, 43, 1, 43, 19, 33, 17, 50, 62, 2, 55, 19, 33, 1, 14, 3, 7, 1, 33, 1, 14, 3, 35, 17, 33, 137, 1, 39, 27, 52, 62, 76, 49, 206, 1, 44, 254, 247, 23, 50, 46, 40, 12, 1, 229, 254, 191, 254, 138, 11, 31, 35, 35, 15, 254, 218, 5, 129, 253, 169, 28, 64, 105, 78, 1, 68, 254, 107, 35, 72, 62, 46, 9, 252, 244, 2, 128, 7, 12, 10, 6, 253, 163, 0, 0, 1, 0, 8, 255, 240, 5, 20, 5, 129, 0, 27, 0, 79, 185, 0, 1, 255, 232, 179, 26, 39, 72, 1, 184, 255, 224, 64, 11, 22, 25, 72, 165, 1, 181, 1, 197, 1, 3, 1, 184, 255, 240, 64, 26, 11, 18, 72, 1, 92, 24, 24, 12, 27, 90, 26, 29, 31, 12, 1, 12, 27, 18, 1, 96, 24, 3, 15, 96, 9, 19, 0, 63, 237, 63, 237, 63, 1, 47, 93, 16, 222, 237, 17, 57, 47, 237, 43, 93, 43, 43, 49, 48, 1, 33, 3, 14, 5, 35, 34, 38, 39, 53, 30, 1, 51, 50, 62, 4, 55, 19, 33, 17, 33, 3, 248, 254, 105, 49, 23, 45, 53, 65, 85, 110, 72, 27, 58, 14, 8, 27, 8, 23, 40, 37, 36, 35, 38, 21, 67, 3, 184, 254, 228, 4, 141, 254, 164, 161, 249, 185, 126, 78, 34, 9, 8, 247, 4, 3, 21, 56, 98, 155, 218, 147, 1, 217, 250, 127, 0, 0, 0, 255, 255, 0, 137, 0, 0, 6, 33, 5, 129, 18, 6, 0, 48, 0, 0, 255, 255, 0, 137, 0, 0, 5, 61, 5, 129, 18, 6, 0, 43, 0, 0, 255, 255, 0, 84, 255, 236, 5, 227, 5, 150, 18, 6, 0, 50, 0, 0, 0, 1, 0, 137, 0, 0, 5, 55, 5, 129, 0, 7, 0, 35, 64, 19, 0, 90, 7, 9, 3, 90, 32, 4, 48, 4, 2, 4, 2, 96, 5, 3, 4, 0, 18, 0, 63, 50, 63, 237, 1, 47, 93, 237, 16, 222, 237, 49, 48, 33, 17, 33, 17, 33, 17, 33, 17, 4, 26, 253, 149, 254, 218, 4, 174, 4, 141, 251, 115, 5, 129, 250, 127, 0, 0, 0, 255, 255, 0, 137, 0, 0, 5, 16, 5, 129, 18, 6, 0, 51, 0, 0, 255, 255, 0, 84, 255, 236, 5, 143, 5, 150, 18, 6, 0, 38, 0, 0, 255, 255, 0, 23, 0, 0, 4, 205, 5, 129, 18, 6, 0, 55, 0, 0, 0, 1, 0, 1, 255, 236, 5, 13, 5, 129, 0, 25, 0, 140, 182, 24, 32, 9, 10, 0, 76, 22, 184, 255, 224, 64, 67, 9, 10, 0, 76, 10, 10, 25, 0, 20, 23, 7, 23, 23, 23, 2, 9, 3, 23, 21, 24, 25, 16, 4, 25, 20, 25, 2, 57, 20, 25, 52, 25, 100, 25, 132, 25, 148, 25, 180, 25, 228, 25, 7, 52, 25, 100, 25, 180, 25, 228, 25, 4, 180, 25, 228, 25, 2, 48, 25, 1, 2, 32, 25, 1, 25, 22, 21, 184, 255, 240, 64, 16, 15, 21, 31, 21, 2, 21, 23, 20, 20, 24, 21, 3, 14, 96, 5, 19, 0, 63, 237, 63, 51, 57, 47, 51, 1, 47, 93, 56, 51, 47, 93, 95, 93, 93, 113, 114, 94, 93, 56, 51, 18, 57, 95, 94, 93, 17, 51, 51, 17, 57, 47, 49, 48, 43, 43, 1, 14, 3, 35, 34, 46, 2, 39, 55, 30, 1, 51, 50, 62, 2, 63, 1, 1, 33, 9, 1, 33, 3, 0, 40, 79, 97, 125, 86, 31, 71, 67, 61, 23, 82, 38, 78, 44, 35, 55, 49, 46, 25, 17, 253, 212, 1, 51, 1, 132, 1, 42, 1, 43, 1, 62, 83, 126, 86, 43, 8, 16, 22, 14, 246, 18, 24, 20, 46, 75, 55, 37, 3, 164, 253, 88, 2, 168, 0, 3, 0, 71, 255, 245, 6, 141, 5, 139, 0, 10, 0, 40, 0, 51, 2, 93, 64, 30, 27, 5, 40, 92, 47, 24, 11, 11, 0, 41, 91, 9, 18, 25, 18, 73, 18, 89, 18, 4, 9, 18, 64, 38, 43, 72, 18, 0, 91, 33, 184, 255, 192, 64, 255, 38, 43, 72, 33, 53, 235, 53, 1, 201, 53, 1, 187, 53, 1, 169, 53, 1, 139, 53, 155, 53, 2, 105, 53, 121, 53, 2, 91, 53, 1, 25, 53, 41, 53, 73, 53, 3, 6, 53, 1, 201, 53, 233, 53, 2, 187, 53, 1, 105, 53, 137, 53, 2, 91, 53, 1, 41, 53, 57, 53, 73, 53, 3, 27, 53, 1, 9, 53, 1, 199, 251, 53, 1, 237, 53, 1, 219, 53, 1, 166, 53, 1, 89, 53, 105, 53, 137, 53, 3, 70, 53, 1, 41, 53, 1, 27, 53, 1, 9, 53, 1, 249, 53, 1, 235, 53, 1, 201, 53, 1, 187, 53, 1, 169, 53, 1, 139, 53, 155, 53, 2, 105, 53, 1, 70, 53, 1, 25, 53, 41, 53, 2, 6, 53, 1, 201, 53, 233, 53, 2, 187, 53, 1, 105, 53, 137, 53, 2, 91, 53, 1, 41, 53, 57, 53, 73, 53, 3, 27, 53, 1, 9, 53, 1, 151, 251, 53, 1, 233, 53, 1, 166, 53, 1, 105, 53, 137, 53, 2, 70, 53, 1, 41, 53, 1, 27, 53, 1, 9, 53, 1, 251, 53, 1, 201, 53, 233, 53, 2, 187, 53, 1, 153, 53, 169, 53, 2, 139, 53, 1, 114, 53, 1, 1, 96, 53, 1, 84, 53, 1, 64, 53, 1, 52, 53, 1, 27, 53, 1, 4, 53, 1, 212, 53, 244, 53, 2, 187, 53, 1, 116, 53, 1, 27, 53, 43, 53, 59, 53, 91, 53, 4, 0, 53, 1, 64, 169, 103, 196, 53, 212, 53, 244, 53, 3, 160, 53, 1, 52, 53, 68, 53, 116, 53, 148, 53, 4, 27, 53, 1, 187, 53, 203, 53, 235, 53, 251, 53, 4, 148, 53, 1, 112, 53, 1, 100, 53, 1, 64, 53, 1, 52, 53, 1, 27, 53, 1, 4, 53, 1, 235, 53, 1, 212, 53, 1, 91, 53, 139, 53, 187, 53, 3, 4, 53, 36, 53, 2, 55, 164, 53, 196, 53, 212, 53, 244, 53, 4, 139, 53, 1, 68, 53, 116, 53, 2, 43, 53, 1, 31, 53, 1, 203, 53, 235, 53, 251, 53, 3, 148, 53, 164, 53, 2, 112, 53, 1, 2, 64, 53, 96, 53, 2, 31, 53, 1, 0, 53, 1, 207, 53, 239, 53, 2, 160, 53, 1, 95, 53, 111, 53, 143, 53, 3, 0, 53, 32, 53, 2, 7, 4, 48, 95, 24, 27, 24, 5, 47, 95, 39, 128, 24, 144, 24, 160, 24, 3, 12, 24, 12, 24, 11, 25, 4, 11, 19, 0, 63, 63, 18, 57, 57, 47, 47, 93, 51, 237, 50, 17, 51, 16, 237, 50, 1, 94, 93, 93, 93, 93, 113, 113, 113, 95, 113, 113, 113, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 95, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 16, 222, 43, 237, 47, 43, 94, 93, 237, 18, 57, 47, 51, 51, 237, 50, 50, 49, 48, 1, 52, 38, 43, 1, 17, 51, 50, 62, 2, 1, 53, 35, 34, 46, 2, 53, 52, 62, 2, 59, 1, 53, 33, 21, 51, 50, 30, 2, 21, 20, 14, 2, 43, 1, 21, 1, 20, 30, 2, 59, 1, 17, 35, 34, 6, 5, 100, 158, 165, 44, 51, 84, 119, 77, 36, 253, 123, 79, 148, 220, 146, 71, 74, 149, 224, 150, 67, 1, 22, 67, 150, 224, 149, 74, 71, 146, 219, 149, 79, 253, 123, 36, 77, 119, 84, 51, 44, 165, 158, 2, 218, 152, 170, 253, 113, 50, 89, 122, 253, 99, 199, 88, 150, 198, 110, 119, 195, 138, 75, 158, 158, 75, 138, 195, 119, 110, 198, 150, 88, 199, 2, 229, 72, 122, 89, 50, 2, 143, 170, 0, 0, 0, 255, 255, 0, 18, 0, 0, 5, 68, 5, 129, 18, 6, 0, 59, 0, 0, 0, 1, 0, 137, 254, 104, 5, 201, 5, 129, 0, 11, 0, 83, 181, 0, 92, 192, 11, 1, 11, 184, 255, 192, 179, 27, 34, 72, 11, 184, 255, 192, 64, 36, 16, 22, 72, 11, 11, 6, 90, 9, 64, 25, 37, 72, 9, 64, 15, 22, 72, 9, 13, 5, 90, 32, 2, 48, 2, 2, 2, 7, 3, 3, 9, 5, 96, 2, 18, 0, 184, 1, 17, 0, 63, 63, 237, 50, 63, 51, 1, 47, 93, 237, 16, 220, 43, 43, 237, 51, 47, 43, 43, 113, 237, 49, 48, 1, 17, 33, 17, 33, 17, 33, 17, 33, 17, 51, 17, 4, 207, 251, 186, 1, 39, 2, 57, 1, 29, 195, 254, 104, 1, 152, 5, 129, 251, 115, 4, 141, 251, 115, 253, 116, 0, 0, 0, 1, 0, 110, 0, 0, 5, 21, 5, 129, 0, 23, 0, 60, 64, 36, 7, 8, 9, 0, 77, 20, 0, 90, 23, 25, 11, 90, 10, 64, 23, 27, 72, 32, 10, 48, 10, 2, 15, 10, 1, 10, 17, 95, 1, 6, 6, 21, 10, 3, 0, 18, 0, 63, 63, 51, 57, 47, 51, 237, 1, 47, 93, 93, 43, 237, 16, 222, 237, 50, 49, 48, 0, 43, 33, 17, 14, 3, 35, 34, 38, 53, 17, 33, 17, 20, 30, 2, 51, 50, 54, 55, 17, 33, 17, 3, 238, 39, 95, 110, 124, 67, 240, 221, 1, 28, 25, 63, 107, 82, 92, 173, 70, 1, 39, 2, 35, 14, 30, 24, 15, 226, 239, 1, 224, 254, 63, 72, 105, 67, 33, 32, 21, 2, 161, 250, 127, 0, 0, 0, 0, 1, 0, 137, 0, 0, 7, 129, 5, 129, 0, 11, 2, 115, 64, 48, 7, 90, 4, 4, 0, 8, 90, 11, 13, 54, 13, 1, 39, 13, 1, 22, 13, 1, 7, 13, 1, 244, 13, 1, 213, 13, 229, 13, 2, 198, 13, 1, 181, 13, 1, 166, 13, 1, 149, 13, 1, 134, 13, 1, 117, 13, 1, 13, 184, 255, 192, 64, 10, 212, 216, 72, 5, 13, 21, 13, 2, 210, 13, 184, 255, 128, 179, 203, 209, 72, 13, 184, 255, 192, 64, 9, 198, 202, 72, 149, 13, 165, 13, 2, 13, 184, 255, 128, 179, 189, 195, 72, 13, 184, 255, 192, 64, 9, 185, 188, 72, 197, 13, 213, 13, 2, 13, 184, 255, 128, 179, 176, 182, 72, 13, 184, 255, 192, 64, 28, 171, 175, 72, 213, 13, 229, 13, 245, 13, 3, 198, 13, 1, 181, 13, 1, 166, 13, 1, 149, 13, 1, 118, 13, 134, 13, 2, 13, 184, 255, 192, 64, 10, 157, 161, 72, 5, 13, 21, 13, 2, 155, 13, 184, 255, 128, 64, 255, 151, 154, 72, 229, 13, 1, 212, 13, 1, 181, 13, 197, 13, 2, 166, 13, 1, 149, 13, 1, 134, 13, 1, 115, 13, 1, 100, 13, 1, 83, 13, 1, 69, 13, 1, 52, 13, 1, 37, 13, 1, 20, 13, 1, 5, 13, 1, 244, 13, 1, 213, 13, 229, 13, 2, 198, 13, 1, 181, 13, 1, 166, 13, 1, 147, 13, 1, 0, 130, 13, 1, 112, 13, 1, 100, 13, 1, 82, 13, 1, 68, 13, 1, 50, 13, 1, 36, 13, 1, 18, 13, 1, 4, 13, 1, 242, 13, 1, 230, 13, 1, 212, 13, 1, 198, 13, 1, 176, 13, 1, 162, 13, 1, 144, 13, 1, 114, 13, 130, 13, 2, 100, 13, 1, 82, 13, 1, 68, 13, 1, 54, 13, 1, 36, 13, 1, 6, 13, 22, 13, 2, 104, 226, 13, 1, 1, 192, 13, 208, 13, 2, 180, 13, 1, 160, 13, 1, 68, 13, 100, 13, 132, 13, 3, 27, 13, 1, 0, 13, 1, 244, 13, 1, 224, 13, 1, 212, 13, 1, 192, 13, 1, 68, 13, 100, 13, 132, 13, 164, 13, 180, 13, 5, 59, 13, 1, 32, 13, 1, 20, 13, 1, 0, 13, 1, 244, 13, 1, 224, 13, 1, 84, 13, 100, 13, 132, 13, 164, 13, 196, 13, 212, 13, 6, 64, 13, 1, 52, 13, 1, 32, 13, 1, 20, 13, 1, 0, 13, 1, 56, 244, 13, 1, 139, 13, 171, 13, 203, 13, 235, 13, 4, 112, 13, 1, 64, 64, 2, 16, 13, 48, 13, 80, 13, 3, 175, 13, 207, 13, 239, 13, 3, 48, 13, 80, 13, 112, 13, 3, 15, 13, 1, 239, 13, 1, 64, 13, 80, 13, 112, 13, 144, 13, 160, 13, 192, 13, 6, 15, 13, 47, 13, 2, 8, 3, 90, 32, 0, 48, 0, 2, 0, 9, 5, 1, 3, 7, 3, 96, 0, 18, 0, 63, 237, 50, 63, 51, 51, 1, 47, 93, 237, 94, 93, 93, 93, 113, 113, 113, 114, 95, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 95, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 95, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 43, 94, 93, 43, 93, 93, 93, 93, 93, 93, 43, 43, 113, 43, 43, 114, 43, 43, 94, 93, 43, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 16, 222, 237, 17, 57, 47, 237, 49, 48, 51, 17, 33, 17, 33, 17, 33, 17, 33, 17, 33, 17, 137, 1, 29, 1, 208, 1, 29, 1, 209, 1, 29, 5, 129, 251, 115, 4, 141, 251, 115, 4, 141, 250, 127, 0, 1, 0, 137, 254, 104, 8, 24, 5, 129, 0, 15, 2, 237, 183, 14, 92, 150, 13, 214, 13, 2, 13, 184, 255, 192, 64, 29, 16, 22, 72, 13, 13, 11, 7, 90, 4, 4, 0, 8, 90, 9, 11, 153, 11, 217, 11, 3, 25, 11, 64, 15, 22, 72, 11, 17, 17, 184, 255, 192, 64, 10, 226, 229, 72, 100, 17, 1, 82, 17, 1, 17, 184, 255, 128, 64, 169, 219, 223, 72, 226, 17, 242, 17, 2, 212, 17, 1, 198, 17, 1, 180, 17, 1, 166, 17, 1, 132, 17, 148, 17, 2, 114, 17, 1, 100, 17, 1, 82, 17, 1, 68, 17, 1, 50, 17, 1, 36, 17, 1, 18, 17, 1, 4, 17, 1, 203, 244, 17, 1, 230, 17, 1, 212, 17, 1, 198, 17, 1, 164, 17, 180, 17, 2, 146, 17, 1, 134, 17, 1, 100, 17, 116, 17, 2, 82, 17, 1, 68, 17, 1, 50, 17, 1, 20, 17, 36, 17, 2, 6, 17, 1, 244, 17, 1, 230, 17, 1, 210, 17, 1, 180, 17, 196, 17, 2, 166, 17, 1, 148, 17, 1, 134, 17, 1, 114, 17, 1, 100, 17, 1, 82, 17, 1, 70, 17, 1, 52, 17, 1, 38, 17, 1, 20, 17, 1, 6, 17, 1, 242, 17, 1, 212, 17, 228, 17, 2, 198, 17, 1, 180, 17, 1, 166, 17, 1, 148, 17, 1, 134, 17, 1, 116, 17, 1, 17, 184, 255, 192, 64, 10, 157, 161, 72, 4, 17, 20, 17, 2, 155, 17, 184, 255, 192, 64, 255, 151, 154, 72, 244, 17, 1, 226, 17, 1, 212, 17, 1, 194, 17, 1, 180, 17, 1, 162, 17, 1, 148, 17, 1, 128, 17, 1, 114, 17, 1, 96, 17, 1, 84, 17, 1, 66, 17, 1, 52, 17, 1, 34, 17, 1, 20, 17, 1, 2, 17, 1, 228, 17, 244, 17, 2, 214, 17, 1, 194, 17, 1, 180, 17, 1, 160, 17, 1, 148, 17, 1, 130, 17, 1, 118, 17, 1, 100, 17, 1, 86, 17, 1, 68, 17, 1, 54, 17, 1, 36, 17, 1, 22, 17, 1, 4, 17, 1, 214, 17, 230, 17, 2, 194, 17, 1, 180, 17, 1, 162, 17, 1, 1, 128, 17, 144, 17, 2, 116, 17, 1, 96, 17, 1, 52, 17, 84, 17, 2, 11, 17, 1, 103, 244, 17, 1, 208, 17, 1, 196, 17, 1, 176, 17, 1, 84, 17, 116, 17, 148, 17, 3, 43, 17, 1, 20, 17, 1, 228, 17, 244, 17, 2, 208, 17, 1, 84, 17, 116, 17, 148, 17, 180, 17, 196, 17, 5, 75, 17, 1, 52, 17, 1, 16, 17, 1, 4, 17, 1, 208, 17, 224, 17, 240, 17, 3, 196, 17, 1, 176, 17, 1, 164, 17, 1, 144, 17, 1, 132, 17, 1, 112, 17, 1, 100, 17, 1, 80, 17, 1, 68, 17, 1, 48, 17, 1, 36, 17, 1, 16, 17, 1, 4, 17, 1, 55, 164, 17, 196, 17, 228, 17, 3, 128, 17, 1, 2, 32, 17, 64, 17, 96, 17, 3, 64, 64, 52, 17, 96, 17, 128, 17, 192, 17, 224, 17, 5, 31, 17, 1, 255, 17, 1, 80, 17, 96, 17, 128, 17, 160, 17, 176, 17, 208, 17, 6, 31, 17, 63, 17, 2, 0, 17, 1, 7, 3, 90, 79, 0, 95, 0, 2, 32, 0, 48, 0, 2, 0, 14, 184, 1, 17, 64, 10, 9, 5, 1, 3, 11, 7, 3, 96, 0, 18, 0, 63, 237, 50, 50, 63, 51, 51, 63, 1, 47, 93, 114, 237, 94, 93, 93, 93, 93, 113, 113, 114, 95, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 95, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 43, 94, 93, 43, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 43, 113, 113, 43, 16, 220, 43, 94, 93, 237, 17, 57, 47, 237, 17, 51, 47, 43, 93, 237, 49, 48, 51, 17, 33, 17, 33, 17, 33, 17, 33, 17, 33, 17, 51, 17, 35, 17, 137, 1, 29, 1, 187, 1, 29, 1, 186, 1, 29, 195, 250, 5, 129, 251, 115, 4, 141, 251, 115, 4, 141, 251, 115, 253, 116, 1, 152, 0, 2, 0, 22, 0, 0, 6, 172, 5, 129, 0, 16, 0, 25, 0, 59, 64, 35, 17, 91, 5, 27, 16, 22, 90, 13, 11, 21, 95, 16, 16, 1, 95, 16, 111, 16, 143, 16, 3, 239, 16, 1, 16, 16, 22, 13, 95, 14, 3, 22, 95, 11, 18, 0, 63, 237, 63, 237, 18, 57, 47, 93, 113, 114, 237, 1, 47, 198, 237, 50, 16, 222, 237, 49, 48, 1, 50, 30, 2, 21, 20, 14, 2, 35, 33, 17, 33, 53, 33, 17, 1, 52, 38, 35, 33, 17, 33, 50, 54, 4, 195, 123, 184, 121, 61, 65, 131, 195, 130, 253, 59, 254, 56, 2, 239, 2, 125, 139, 138, 254, 152, 1, 110, 140, 131, 3, 80, 60, 109, 154, 94, 90, 158, 116, 67, 4, 157, 228, 253, 207, 254, 91, 93, 101, 254, 121, 101, 0, 0, 3, 0, 137, 0, 0, 7, 76, 5, 129, 0, 14, 0, 23, 0, 27, 0, 73, 64, 45, 15, 91, 0, 0, 20, 24, 90, 27, 29, 112, 29, 224, 29, 240, 29, 3, 9, 20, 90, 6, 19, 95, 16, 9, 1, 95, 9, 111, 9, 143, 9, 3, 239, 9, 1, 9, 9, 25, 7, 3, 20, 95, 24, 6, 18, 0, 63, 51, 237, 63, 51, 57, 47, 93, 113, 114, 237, 1, 47, 237, 50, 93, 16, 222, 237, 17, 57, 47, 237, 49, 48, 1, 20, 14, 2, 35, 33, 17, 33, 17, 33, 50, 30, 2, 5, 52, 38, 35, 33, 17, 33, 50, 54, 1, 17, 33, 17, 5, 79, 65, 131, 195, 130, 253, 67, 1, 39, 1, 182, 123, 184, 121, 61, 254, 214, 139, 138, 254, 160, 1, 102, 140, 131, 2, 0, 1, 39, 1, 175, 90, 158, 116, 67, 5, 129, 253, 207, 60, 109, 154, 98, 93, 101, 254, 121, 101, 254, 181, 5, 129, 250, 127, 0, 2, 0, 137, 0, 0, 5, 119, 5, 129, 0, 14, 0, 23, 0, 80, 181, 3, 24, 9, 0, 77, 12, 184, 255, 232, 64, 44, 9, 0, 77, 15, 91, 0, 25, 64, 25, 1, 48, 25, 112, 25, 224, 25, 3, 9, 20, 90, 6, 19, 95, 16, 9, 1, 95, 9, 111, 9, 143, 9, 3, 239, 9, 1, 9, 9, 7, 3, 20, 95, 6, 18, 0, 63, 237, 63, 57, 47, 93, 113, 114, 237, 1, 47, 237, 50, 93, 113, 16, 222, 237, 49, 48, 0, 43, 43, 1, 20, 14, 2, 35, 33, 17, 33, 17, 33, 50, 30, 2, 5, 52, 38, 35, 33, 17, 33, 50, 54, 5, 119, 65, 131, 195, 130, 253, 27, 1, 39, 1, 222, 123, 184, 121, 61, 254, 214, 139, 138, 254, 120, 1, 142, 140, 131, 1, 175, 90, 158, 116, 67, 5, 129, 253, 207, 60, 109, 154, 98, 93, 101, 254, 121, 101, 0, 0, 1, 0, 54, 255, 236, 5, 93, 5, 150, 0, 44, 0, 114, 64, 76, 18, 92, 19, 6, 19, 6, 39, 8, 5, 91, 29, 46, 40, 92, 31, 39, 1, 39, 64, 13, 18, 72, 39, 6, 95, 95, 7, 111, 7, 143, 7, 223, 7, 255, 7, 5, 239, 7, 1, 7, 7, 24, 0, 95, 34, 32, 40, 48, 40, 2, 32, 40, 96, 40, 112, 40, 160, 40, 224, 40, 240, 40, 6, 40, 40, 34, 19, 127, 18, 1, 18, 18, 13, 95, 24, 4, 0, 63, 237, 51, 47, 93, 63, 51, 47, 93, 113, 16, 237, 17, 57, 47, 93, 113, 237, 1, 47, 43, 93, 237, 16, 222, 237, 50, 17, 57, 57, 47, 47, 237, 49, 48, 37, 50, 62, 2, 55, 33, 53, 33, 46, 3, 35, 34, 14, 2, 7, 39, 62, 3, 51, 50, 4, 22, 18, 21, 20, 2, 6, 4, 35, 34, 46, 2, 39, 55, 30, 3, 2, 158, 95, 144, 100, 56, 6, 253, 221, 2, 34, 5, 56, 99, 142, 91, 75, 117, 87, 57, 14, 255, 28, 97, 149, 204, 136, 175, 1, 3, 170, 83, 84, 172, 254, 248, 180, 138, 204, 148, 98, 31, 252, 19, 58, 86, 120, 212, 55, 101, 144, 89, 228, 87, 137, 95, 50, 39, 64, 83, 45, 71, 86, 143, 105, 58, 101, 187, 254, 246, 165, 159, 254, 244, 195, 109, 69, 112, 146, 76, 97, 49, 96, 76, 47, 0, 0, 0, 0, 2, 0, 137, 255, 236, 7, 234, 5, 150, 0, 26, 0, 46, 0, 110, 64, 11, 44, 24, 10, 0, 77, 30, 24, 10, 0, 77, 40, 184, 255, 232, 179, 10, 0, 77, 40, 184, 255, 248, 179, 9, 0, 77, 34, 184, 255, 232, 64, 44, 10, 0, 77, 37, 90, 10, 17, 17, 12, 27, 91, 191, 0, 207, 0, 2, 0, 48, 16, 12, 90, 32, 13, 48, 13, 2, 13, 32, 95, 22, 4, 11, 96, 16, 16, 13, 14, 3, 13, 18, 42, 95, 5, 19, 0, 63, 237, 63, 63, 18, 57, 47, 237, 63, 237, 1, 47, 93, 237, 50, 16, 222, 113, 237, 17, 57, 47, 51, 237, 49, 48, 43, 43, 43, 43, 43, 1, 20, 2, 14, 1, 35, 34, 46, 2, 39, 33, 17, 33, 17, 33, 17, 33, 62, 3, 51, 50, 30, 1, 18, 5, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 7, 234, 90, 171, 246, 155, 150, 231, 163, 95, 13, 254, 232, 254, 217, 1, 39, 1, 27, 17, 101, 165, 226, 142, 159, 246, 168, 87, 254, 211, 44, 90, 135, 90, 92, 136, 89, 44, 44, 90, 135, 91, 97, 136, 87, 40, 2, 199, 165, 254, 242, 192, 104, 92, 165, 229, 138, 253, 164, 5, 129, 253, 207, 135, 216, 150, 81, 102, 188, 254, 247, 164, 111, 179, 128, 69, 69, 128, 179, 111, 110, 183, 132, 74, 75, 133, 183, 0, 0, 0, 0, 2, 0, 35, 0, 0, 5, 55, 5, 129, 0, 17, 0, 28, 0, 111, 185, 0, 17, 255, 232, 179, 10, 0, 77, 17, 184, 255, 248, 64, 26, 9, 0, 77, 1, 16, 6, 24, 14, 90, 13, 30, 112, 30, 1, 32, 30, 48, 30, 160, 30, 3, 15, 30, 1, 17, 0, 184, 255, 240, 64, 31, 0, 0, 16, 0, 2, 0, 0, 18, 91, 32, 6, 48, 6, 2, 15, 6, 1, 6, 1, 16, 95, 23, 23, 0, 26, 95, 11, 3, 14, 0, 18, 0, 63, 50, 63, 237, 18, 57, 47, 237, 57, 1, 47, 93, 93, 237, 51, 47, 93, 56, 51, 93, 93, 113, 16, 222, 237, 50, 17, 57, 57, 49, 48, 43, 43, 51, 1, 46, 3, 53, 52, 62, 2, 51, 33, 17, 33, 17, 33, 1, 19, 20, 30, 2, 51, 33, 17, 33, 34, 6, 35, 1, 125, 67, 114, 83, 47, 65, 132, 197, 132, 2, 192, 254, 217, 254, 166, 254, 185, 35, 30, 61, 95, 66, 1, 130, 254, 134, 125, 135, 2, 80, 16, 69, 102, 131, 79, 97, 155, 109, 59, 250, 127, 2, 23, 253, 233, 3, 209, 47, 78, 57, 31, 1, 160, 100, 255, 255, 0, 60, 255, 236, 4, 128, 4, 78, 18, 6, 0, 68, 0, 0, 0, 2, 0, 94, 255, 236, 4, 160, 5, 222, 0, 19, 0, 56, 0, 64, 64, 38, 42, 42, 23, 52, 10, 71, 208, 31, 1, 32, 31, 48, 31, 2, 31, 0, 71, 223, 23, 1, 23, 58, 96, 58, 112, 58, 2, 52, 5, 79, 20, 20, 41, 0, 15, 79, 26, 22, 0, 63, 237, 63, 57, 47, 237, 51, 1, 113, 16, 222, 113, 237, 47, 93, 113, 237, 57, 18, 57, 47, 49, 48, 1, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 3, 50, 18, 17, 16, 0, 33, 34, 46, 2, 53, 52, 18, 62, 1, 55, 62, 3, 55, 21, 14, 1, 7, 14, 5, 7, 62, 3, 3, 122, 33, 62, 89, 55, 59, 96, 69, 37, 37, 66, 89, 52, 59, 95, 66, 36, 193, 251, 236, 254, 230, 254, 244, 127, 201, 139, 73, 65, 145, 232, 166, 65, 112, 103, 96, 49, 97, 182, 102, 88, 140, 106, 76, 49, 25, 3, 22, 72, 106, 144, 1, 245, 97, 128, 77, 31, 33, 77, 128, 95, 96, 127, 75, 31, 30, 75, 127, 2, 111, 254, 251, 254, 250, 254, 247, 254, 253, 70, 156, 250, 180, 192, 1, 22, 193, 115, 28, 11, 17, 14, 12, 6, 235, 10, 23, 16, 13, 32, 48, 69, 104, 142, 97, 67, 115, 84, 48, 0, 0, 0, 0, 3, 0, 143, 0, 0, 4, 155, 4, 58, 0, 21, 0, 34, 0, 45, 0, 97, 185, 0, 17, 255, 232, 180, 9, 10, 0, 76, 3, 184, 255, 232, 64, 21, 9, 10, 0, 76, 42, 71, 10, 5, 5, 22, 28, 70, 16, 47, 36, 22, 70, 208, 20, 1, 20, 184, 255, 192, 179, 36, 40, 72, 20, 184, 255, 192, 64, 18, 9, 12, 72, 20, 10, 34, 82, 36, 36, 22, 35, 82, 21, 15, 22, 82, 20, 21, 0, 63, 237, 63, 237, 18, 57, 47, 237, 57, 1, 47, 43, 43, 93, 237, 50, 16, 222, 237, 18, 57, 47, 57, 237, 49, 48, 43, 43, 1, 50, 30, 2, 21, 20, 14, 2, 7, 21, 30, 3, 21, 20, 6, 35, 33, 17, 1, 51, 50, 62, 2, 53, 52, 46, 2, 43, 1, 25, 1, 51, 50, 62, 2, 53, 52, 38, 35, 2, 167, 93, 171, 129, 77, 39, 67, 88, 49, 59, 99, 74, 41, 239, 219, 253, 190, 1, 26, 227, 66, 92, 57, 25, 27, 60, 96, 68, 216, 208, 64, 86, 51, 22, 96, 114, 4, 58, 24, 62, 104, 81, 52, 82, 58, 37, 9, 7, 7, 35, 62, 89, 61, 157, 155, 4, 58, 252, 117, 16, 36, 56, 39, 42, 59, 36, 16, 1, 176, 254, 252, 15, 31, 50, 35, 67, 62, 0, 1, 0, 143, 0, 0, 3, 30, 4, 58, 0, 5, 0, 58, 185, 0, 1, 255, 192, 64, 12, 9, 12, 72, 1, 1, 7, 3, 70, 208, 4, 1, 4, 184, 255, 192, 179, 36, 40, 72, 4, 184, 255, 192, 64, 10, 9, 12, 72, 4, 2, 79, 5, 15, 3, 21, 0, 63, 63, 237, 1, 47, 43, 43, 93, 237, 17, 51, 47, 43, 49, 48, 1, 21, 33, 17, 33, 17, 3, 30, 254, 139, 254, 230, 4, 58, 190, 252, 132, 4, 58, 0, 0, 2, 0, 14, 254, 104, 4, 238, 4, 58, 0, 7, 0, 23, 0, 127, 64, 75, 22, 72, 21, 21, 19, 6, 6, 1, 6, 6, 22, 6, 134, 6, 230, 6, 246, 6, 5, 6, 12, 6, 1, 1, 247, 1, 1, 153, 1, 1, 118, 1, 134, 1, 2, 57, 1, 73, 1, 2, 1, 17, 144, 17, 1, 12, 17, 12, 17, 11, 7, 70, 159, 19, 1, 0, 19, 16, 19, 96, 19, 112, 19, 4, 19, 25, 8, 72, 11, 1, 79, 17, 15, 22, 9, 184, 1, 17, 181, 19, 6, 11, 79, 8, 21, 0, 63, 237, 50, 50, 63, 51, 63, 237, 1, 47, 237, 16, 220, 93, 93, 237, 17, 57, 57, 47, 47, 93, 17, 51, 93, 93, 93, 93, 113, 17, 51, 93, 113, 17, 51, 47, 237, 49, 48, 1, 35, 14, 3, 7, 33, 5, 17, 35, 17, 51, 62, 2, 18, 55, 33, 17, 51, 17, 35, 17, 3, 66, 236, 18, 40, 43, 44, 23, 1, 148, 253, 193, 245, 125, 30, 56, 55, 54, 28, 2, 242, 146, 245, 3, 124, 138, 222, 173, 126, 43, 190, 254, 104, 2, 86, 47, 134, 207, 1, 39, 209, 252, 132, 253, 170, 1, 152, 0, 255, 255, 0, 80, 255, 236, 4, 45, 4, 78, 18, 6, 0, 72, 0, 0, 0, 1, 255, 239, 0, 0, 5, 189, 4, 58, 0, 41, 1, 251, 181, 34, 16, 10, 0, 77, 3, 184, 255, 240, 64, 10, 10, 0, 77, 24, 24, 9, 10, 0, 76, 13, 184, 255, 232, 64, 28, 9, 10, 0, 76, 31, 34, 32, 40, 3, 6, 5, 20, 40, 72, 17, 4, 41, 1, 33, 41, 41, 5, 32, 11, 10, 10, 4, 5, 184, 255, 240, 183, 5, 26, 27, 27, 33, 32, 16, 32, 184, 255, 192, 64, 255, 9, 12, 72, 32, 32, 43, 159, 43, 1, 132, 43, 1, 59, 43, 91, 43, 107, 43, 3, 47, 43, 1, 20, 43, 1, 203, 43, 235, 43, 251, 43, 3, 191, 43, 1, 164, 43, 1, 91, 43, 123, 43, 139, 43, 3, 79, 43, 1, 2, 15, 43, 31, 43, 2, 204, 15, 43, 31, 43, 63, 43, 79, 43, 127, 43, 143, 43, 175, 43, 191, 43, 239, 43, 255, 43, 10, 15, 43, 47, 43, 63, 43, 95, 43, 111, 43, 127, 43, 159, 43, 175, 43, 207, 43, 223, 43, 10, 15, 43, 47, 43, 79, 43, 95, 43, 127, 43, 159, 43, 191, 43, 207, 43, 239, 43, 9, 155, 63, 43, 79, 43, 111, 43, 159, 43, 175, 43, 191, 43, 223, 43, 239, 43, 8, 32, 43, 1, 207, 43, 223, 43, 255, 43, 3, 176, 43, 1, 31, 43, 95, 43, 111, 43, 143, 43, 4, 15, 43, 63, 43, 95, 43, 127, 43, 175, 43, 207, 43, 239, 43, 7, 107, 63, 43, 111, 43, 143, 43, 175, 43, 223, 43, 255, 43, 6, 31, 43, 47, 43, 95, 43, 143, 43, 159, 43, 207, 43, 255, 43, 7, 175, 43, 191, 43, 239, 43, 3, 144, 43, 1, 63, 43, 79, 43, 127, 43, 3, 32, 43, 1, 15, 43, 1, 58, 239, 43, 255, 43, 2, 208, 43, 1, 127, 43, 143, 43, 191, 43, 3, 96, 43, 1, 31, 43, 79, 43, 2, 240, 43, 1, 223, 43, 1, 192, 43, 64, 66, 1, 175, 43, 1, 128, 43, 1, 111, 43, 1, 80, 43, 1, 63, 43, 1, 16, 43, 1, 255, 43, 1, 224, 43, 1, 143, 43, 207, 43, 2, 112, 43, 1, 63, 43, 95, 43, 2, 0, 43, 32, 43, 2, 8, 34, 3, 31, 6, 3, 6, 17, 3, 0, 0, 20, 17, 17, 4, 26, 18, 11, 15, 41, 33, 4, 21, 0, 63, 51, 51, 63, 51, 51, 18, 57, 17, 51, 51, 17, 51, 18, 57, 57, 17, 51, 17, 51, 1, 94, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 113, 114, 94, 93, 113, 113, 113, 114, 114, 94, 93, 113, 114, 94, 93, 95, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 17, 51, 47, 43, 56, 51, 51, 17, 51, 47, 56, 51, 51, 17, 51, 17, 18, 57, 47, 94, 93, 51, 237, 50, 18, 57, 57, 17, 18, 57, 57, 49, 48, 43, 43, 43, 43, 1, 34, 38, 39, 3, 33, 1, 46, 1, 39, 3, 33, 19, 30, 3, 23, 17, 51, 17, 62, 3, 55, 19, 33, 3, 14, 1, 7, 1, 33, 3, 14, 3, 35, 17, 35, 2, 88, 25, 58, 14, 223, 254, 215, 1, 62, 17, 44, 31, 216, 1, 18, 136, 39, 56, 43, 38, 21, 252, 21, 38, 43, 56, 39, 136, 1, 18, 216, 30, 45, 17, 1, 62, 254, 215, 223, 7, 23, 26, 28, 13, 252, 1, 201, 6, 5, 254, 44, 2, 59, 14, 61, 55, 1, 125, 254, 255, 75, 86, 43, 12, 1, 1, 218, 254, 38, 1, 12, 43, 86, 75, 1, 1, 254, 131, 56, 60, 14, 253, 197, 1, 212, 3, 4, 3, 1, 254, 55, 0, 0, 0, 0, 1, 0, 53, 255, 236, 3, 181, 4, 78, 0, 57, 0, 121, 185, 0, 55, 255, 232, 180, 9, 10, 0, 76, 40, 184, 255, 232, 64, 61, 9, 10, 0, 76, 31, 72, 32, 47, 42, 18, 18, 3, 23, 70, 42, 32, 42, 32, 42, 3, 12, 71, 53, 59, 79, 59, 1, 4, 72, 3, 47, 17, 82, 18, 18, 37, 9, 43, 31, 1, 31, 31, 1, 31, 31, 26, 82, 37, 16, 9, 81, 0, 0, 4, 16, 4, 2, 4, 4, 0, 22, 0, 63, 50, 47, 93, 16, 237, 63, 237, 51, 47, 93, 93, 17, 18, 57, 47, 237, 57, 1, 47, 237, 93, 16, 222, 237, 18, 57, 57, 47, 47, 16, 237, 17, 57, 47, 18, 57, 16, 237, 49, 48, 43, 43, 5, 34, 38, 39, 55, 30, 3, 51, 50, 54, 53, 52, 46, 2, 35, 53, 50, 62, 2, 53, 52, 38, 35, 34, 14, 2, 7, 39, 62, 3, 51, 50, 30, 2, 21, 20, 14, 2, 7, 21, 30, 3, 21, 20, 14, 2, 1, 237, 179, 220, 41, 241, 9, 38, 52, 64, 34, 80, 89, 43, 78, 109, 65, 63, 104, 75, 41, 78, 72, 30, 61, 51, 37, 5, 237, 13, 73, 114, 150, 88, 91, 148, 105, 57, 38, 67, 91, 52, 56, 102, 77, 46, 56, 113, 171, 20, 160, 148, 44, 39, 61, 42, 22, 79, 64, 50, 62, 35, 13, 177, 13, 33, 57, 45, 60, 67, 13, 33, 56, 42, 22, 75, 113, 75, 38, 41, 74, 103, 63, 56, 85, 62, 40, 11, 2, 6, 39, 66, 92, 58, 69, 119, 87, 49, 0, 0, 1, 0, 142, 0, 0, 4, 93, 4, 58, 0, 19, 0, 97, 185, 0, 17, 255, 240, 64, 12, 9, 10, 0, 76, 7, 16, 9, 10, 0, 76, 7, 10, 184, 1, 18, 64, 15, 223, 9, 1, 9, 64, 36, 40, 72, 9, 21, 208, 21, 1, 17, 0, 184, 1, 18, 179, 208, 19, 1, 19, 184, 255, 192, 179, 36, 40, 72, 19, 184, 255, 192, 64, 12, 9, 12, 72, 19, 16, 6, 18, 9, 21, 7, 0, 15, 0, 63, 50, 63, 51, 57, 57, 1, 47, 43, 43, 93, 237, 50, 93, 16, 222, 43, 93, 237, 50, 49, 48, 43, 43, 1, 17, 20, 14, 2, 7, 1, 33, 17, 33, 17, 52, 62, 2, 55, 1, 33, 17, 1, 148, 4, 6, 7, 3, 1, 192, 1, 29, 254, 252, 3, 6, 7, 4, 254, 77, 254, 212, 4, 58, 254, 26, 23, 80, 86, 77, 21, 3, 5, 251, 198, 2, 38, 19, 60, 64, 60, 20, 252, 251, 4, 58, 0, 0, 0, 255, 255, 0, 142, 0, 0, 4, 93, 5, 244, 18, 38, 1, 210, 0, 0, 17, 7, 2, 151, 1, 42, 0, 0, 0, 19, 64, 11, 1, 20, 17, 38, 1, 8, 27, 35, 18, 8, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 0, 1, 0, 142, 0, 0, 4, 2, 4, 58, 0, 21, 0, 101, 185, 0, 13, 255, 232, 64, 14, 9, 10, 0, 76, 13, 16, 14, 2, 20, 70, 208, 21, 1, 21, 184, 255, 192, 179, 36, 40, 72, 21, 184, 255, 192, 64, 11, 9, 12, 72, 21, 8, 9, 9, 15, 14, 16, 14, 184, 255, 208, 64, 18, 9, 12, 72, 14, 14, 23, 16, 13, 19, 19, 2, 2, 21, 14, 21, 8, 0, 15, 0, 63, 50, 63, 51, 57, 17, 51, 18, 57, 57, 17, 1, 51, 47, 43, 56, 51, 51, 17, 51, 47, 43, 43, 93, 237, 50, 17, 57, 57, 49, 48, 43, 19, 33, 17, 62, 3, 55, 19, 33, 3, 14, 1, 7, 1, 33, 3, 14, 1, 35, 17, 33, 142, 1, 26, 23, 36, 41, 53, 39, 126, 1, 18, 206, 32, 53, 17, 1, 62, 254, 225, 233, 14, 50, 18, 254, 230, 4, 58, 254, 48, 1, 9, 40, 82, 75, 1, 1, 254, 131, 60, 56, 14, 253, 197, 1, 202, 5, 6, 254, 65, 0, 1, 0, 21, 255, 236, 4, 134, 4, 58, 0, 27, 0, 90, 64, 61, 25, 2, 41, 2, 2, 7, 2, 1, 247, 2, 1, 184, 2, 1, 153, 2, 169, 2, 2, 132, 2, 1, 118, 2, 1, 103, 2, 1, 43, 2, 59, 2, 75, 2, 3, 2, 191, 25, 207, 25, 223, 25, 3, 25, 25, 15, 0, 70, 27, 29, 15, 2, 79, 25, 15, 18, 79, 9, 22, 0, 21, 0, 63, 63, 237, 63, 237, 1, 47, 16, 222, 237, 17, 57, 47, 93, 51, 93, 93, 93, 93, 93, 93, 93, 113, 113, 49, 48, 33, 17, 33, 6, 2, 14, 3, 35, 34, 46, 2, 39, 53, 30, 1, 51, 50, 62, 3, 18, 55, 33, 17, 3, 108, 254, 202, 25, 42, 44, 51, 70, 94, 65, 14, 45, 47, 39, 9, 11, 38, 19, 29, 43, 36, 31, 35, 41, 27, 3, 59, 3, 124, 184, 254, 234, 203, 134, 80, 33, 2, 4, 5, 2, 191, 4, 5, 25, 70, 126, 201, 1, 32, 197, 251, 198, 0, 1, 0, 143, 0, 0, 5, 92, 4, 58, 0, 28, 1, 218, 182, 19, 24, 9, 10, 0, 76, 11, 184, 255, 232, 64, 16, 9, 10, 0, 76, 0, 1, 15, 15, 21, 11, 8, 72, 4, 9, 1, 9, 184, 255, 192, 179, 36, 40, 72, 9, 184, 255, 192, 64, 255, 9, 12, 72, 9, 19, 22, 72, 11, 21, 1, 22, 21, 64, 36, 40, 72, 21, 30, 96, 30, 1, 36, 30, 52, 30, 84, 30, 3, 11, 30, 1, 244, 30, 1, 223, 30, 1, 132, 30, 196, 30, 2, 11, 30, 27, 30, 59, 30, 107, 30, 4, 205, 212, 30, 228, 30, 2, 176, 30, 1, 116, 30, 132, 30, 164, 30, 3, 91, 30, 1, 4, 30, 20, 30, 52, 30, 68, 30, 4, 155, 30, 187, 30, 2, 4, 30, 52, 30, 100, 30, 116, 30, 4, 235, 30, 1, 212, 30, 1, 187, 30, 1, 175, 30, 1, 84, 30, 100, 30, 132, 30, 3, 11, 30, 1, 154, 212, 30, 1, 123, 30, 139, 30, 187, 30, 3, 100, 30, 1, 75, 30, 1, 52, 30, 1, 11, 30, 27, 30, 2, 235, 30, 1, 148, 30, 180, 30, 196, 30, 3, 75, 30, 1, 36, 30, 1, 244, 30, 1, 155, 30, 219, 30, 2, 132, 30, 1, 43, 30, 59, 30, 107, 30, 3, 4, 30, 20, 30, 2, 105, 68, 30, 116, 30, 180, 30, 228, 30, 4, 43, 30, 1, 20, 30, 1, 235, 30, 251, 30, 2, 212, 30, 1, 107, 30, 139, 30, 187, 30, 3, 4, 30, 52, 30, 84, 30, 3, 148, 30, 212, 30, 2, 123, 30, 1, 100, 30, 1, 75, 30, 1, 36, 30, 1, 11, 30, 1, 57, 203, 30, 219, 30, 251, 30, 3, 176, 30, 1, 68, 30, 116, 30, 148, 30, 164, 64, 71, 30, 4, 43, 30, 1, 20, 30, 1, 251, 30, 1, 239, 30, 1, 203, 30, 1, 191, 30, 1, 2, 175, 30, 1, 112, 30, 144, 30, 2, 31, 30, 79, 30, 2, 144, 30, 192, 30, 224, 30, 240, 30, 4, 127, 30, 1, 32, 30, 48, 30, 80, 30, 96, 30, 4, 15, 30, 1, 7, 28, 2, 15, 2, 9, 19, 10, 15, 22, 1, 9, 21, 0, 63, 51, 51, 63, 51, 18, 57, 57, 17, 51, 1, 94, 93, 93, 93, 93, 113, 113, 113, 95, 113, 113, 113, 113, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 114, 114, 114, 94, 93, 93, 93, 93, 93, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 113, 113, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 113, 113, 113, 16, 222, 43, 94, 93, 237, 50, 47, 43, 43, 93, 237, 50, 18, 57, 17, 51, 51, 49, 48, 43, 43, 33, 35, 1, 30, 3, 21, 17, 35, 17, 33, 19, 30, 1, 23, 62, 1, 55, 19, 33, 17, 35, 17, 52, 62, 2, 55, 3, 102, 213, 254, 228, 3, 6, 5, 2, 246, 1, 116, 180, 20, 40, 8, 10, 38, 20, 175, 1, 110, 246, 3, 6, 6, 3, 3, 117, 29, 71, 70, 64, 23, 253, 140, 4, 58, 253, 207, 65, 149, 72, 72, 149, 65, 2, 49, 251, 198, 2, 116, 22, 67, 73, 71, 26, 0, 0, 1, 0, 143, 0, 0, 4, 70, 4, 58, 0, 11, 0, 82, 64, 20, 2, 6, 70, 223, 5, 1, 5, 64, 36, 40, 72, 5, 13, 1, 9, 70, 208, 10, 1, 10, 184, 255, 192, 179, 36, 40, 72, 10, 184, 255, 192, 64, 22, 9, 12, 72, 10, 8, 79, 31, 1, 1, 127, 1, 143, 1, 2, 1, 1, 10, 5, 21, 3, 0, 15, 0, 63, 50, 63, 51, 57, 47, 93, 113, 237, 1, 47, 43, 43, 93, 237, 50, 16, 222, 43, 93, 237, 50, 49, 48, 1, 17, 33, 17, 33, 17, 33, 17, 33, 17, 33, 17, 1, 169, 1, 131, 1, 26, 254, 230, 254, 125, 254, 230, 4, 58, 254, 84, 1, 172, 251, 198, 1, 207, 254, 49, 4, 58, 0, 0, 255, 255, 0, 80, 255, 236, 4, 147, 4, 78, 18, 6, 0, 82, 0, 0, 0, 1, 0, 143, 0, 0, 4, 70, 4, 58, 0, 7, 0, 62, 64, 18, 2, 70, 223, 1, 1, 1, 64, 36, 40, 72, 1, 9, 5, 70, 208, 6, 1, 6, 184, 255, 192, 179, 36, 40, 72, 6, 184, 255, 192, 64, 11, 9, 12, 72, 6, 4, 79, 7, 15, 6, 1, 21, 0, 63, 51, 63, 237, 1, 47, 43, 43, 93, 237, 16, 222, 43, 93, 237, 49, 48, 1, 17, 33, 17, 33, 17, 33, 17, 4, 70, 254, 230, 254, 125, 254, 230, 4, 58, 251, 198, 3, 124, 252, 132, 4, 58, 0, 0, 255, 255, 0, 135, 254, 87, 4, 143, 4, 81, 18, 6, 0, 83, 0, 0, 255, 255, 0, 80, 255, 236, 4, 55, 4, 78, 18, 6, 0, 70, 0, 0, 0, 1, 0, 58, 0, 0, 3, 178, 4, 58, 0, 7, 2, 252, 64, 79, 2, 14, 4, 5, 7, 14, 24, 7, 40, 7, 56, 7, 136, 7, 152, 7, 5, 72, 7, 88, 7, 104, 7, 184, 7, 200, 7, 5, 8, 7, 24, 7, 2, 11, 7, 64, 24, 27, 72, 7, 64, 17, 21, 72, 7, 4, 70, 7, 5, 23, 5, 39, 5, 3, 66, 23, 5, 39, 5, 103, 5, 119, 5, 135, 5, 5, 7, 5, 87, 5, 103, 5, 183, 5, 199, 5, 5, 15, 5, 184, 255, 192, 179, 70, 82, 72, 5, 184, 255, 192, 179, 54, 57, 72, 5, 184, 255, 192, 179, 49, 52, 72, 5, 184, 255, 192, 179, 43, 46, 72, 5, 184, 255, 192, 64, 22, 9, 12, 72, 5, 180, 9, 1, 163, 9, 1, 132, 9, 148, 9, 2, 117, 9, 1, 99, 9, 1, 9, 184, 255, 0, 64, 190, 220, 223, 72, 21, 9, 1, 3, 9, 1, 228, 9, 244, 9, 2, 213, 9, 1, 196, 9, 1, 181, 9, 1, 163, 9, 1, 0, 128, 9, 144, 9, 2, 98, 9, 114, 9, 2, 84, 9, 1, 66, 9, 1, 32, 9, 48, 9, 2, 2, 9, 18, 9, 2, 202, 228, 9, 244, 9, 2, 192, 9, 208, 9, 2, 146, 9, 162, 9, 178, 9, 3, 132, 9, 1, 80, 9, 96, 9, 112, 9, 3, 50, 9, 66, 9, 2, 36, 9, 1, 16, 9, 1, 2, 9, 1, 240, 9, 1, 210, 9, 226, 9, 2, 196, 9, 1, 176, 9, 1, 146, 9, 162, 9, 2, 132, 9, 1, 114, 9, 1, 100, 9, 1, 80, 9, 1, 50, 9, 66, 9, 2, 4, 9, 20, 9, 36, 9, 3, 240, 9, 1, 210, 9, 226, 9, 2, 180, 9, 196, 9, 2, 166, 9, 1, 148, 9, 1, 114, 9, 130, 9, 2, 84, 9, 100, 9, 2, 54, 9, 70, 9, 2, 18, 9, 34, 9, 2, 4, 9, 1, 154, 244, 9, 1, 214, 9, 230, 9, 2, 9, 184, 255, 128, 64, 10, 146, 150, 72, 118, 9, 1, 98, 9, 1, 9, 184, 255, 128, 64, 75, 140, 143, 72, 22, 9, 1, 2, 9, 1, 228, 9, 244, 9, 2, 214, 9, 1, 196, 9, 1, 182, 9, 1, 162, 9, 1, 132, 9, 148, 9, 2, 102, 9, 118, 9, 2, 66, 9, 1, 36, 9, 52, 9, 2, 6, 9, 22, 9, 2, 214, 9, 1, 196, 9, 1, 6, 9, 22, 9, 166, 9, 182, 9, 4, 106, 134, 9, 182, 9, 198, 9, 246, 9, 4, 9, 184, 255, 192, 64, 62, 110, 113, 72, 100, 9, 1, 22, 9, 38, 9, 70, 9, 86, 9, 4, 2, 9, 1, 228, 9, 244, 9, 2, 166, 9, 198, 9, 214, 9, 3, 130, 9, 146, 9, 2, 100, 9, 116, 9, 2, 70, 9, 86, 9, 2, 52, 9, 1, 34, 9, 1, 4, 9, 20, 9, 2, 230, 9, 246, 9, 2, 9, 184, 255, 128, 64, 31, 67, 70, 72, 134, 9, 150, 9, 2, 100, 9, 116, 9, 2, 86, 9, 1, 68, 9, 1, 38, 9, 54, 9, 2, 4, 9, 20, 9, 2, 57, 9, 184, 255, 192, 64, 67, 53, 56, 72, 180, 9, 196, 9, 2, 134, 9, 150, 9, 166, 9, 3, 98, 9, 1, 1, 64, 9, 80, 9, 2, 36, 9, 52, 9, 2, 224, 9, 240, 9, 2, 148, 9, 196, 9, 212, 9, 3, 128, 9, 1, 2, 96, 9, 112, 9, 2, 0, 9, 32, 9, 64, 9, 96, 9, 112, 9, 192, 9, 208, 9, 7, 8, 9, 184, 255, 192, 64, 10, 24, 27, 72, 4, 21, 3, 7, 79, 0, 15, 0, 63, 237, 50, 63, 1, 43, 94, 93, 113, 95, 113, 113, 113, 114, 114, 95, 114, 114, 114, 43, 94, 93, 93, 93, 93, 93, 93, 43, 93, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 43, 114, 94, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 43, 114, 114, 43, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 95, 93, 93, 93, 93, 93, 113, 113, 43, 113, 113, 113, 113, 113, 47, 43, 43, 43, 43, 43, 94, 93, 113, 94, 93, 237, 198, 43, 43, 94, 93, 113, 114, 43, 1, 24, 16, 77, 230, 49, 48, 19, 33, 21, 33, 17, 33, 17, 33, 58, 3, 120, 254, 209, 254, 230, 254, 209, 4, 58, 190, 252, 132, 3, 124, 0, 0, 255, 255, 0, 16, 254, 87, 4, 104, 4, 58, 18, 6, 0, 92, 0, 0, 0, 3, 0, 82, 254, 87, 6, 173, 5, 204, 0, 54, 0, 71, 0, 87, 2, 242, 178, 46, 80, 17, 184, 1, 18, 64, 255, 45, 55, 182, 18, 198, 18, 214, 18, 3, 6, 18, 246, 18, 2, 33, 18, 18, 0, 65, 71, 22, 28, 1, 28, 72, 71, 9, 0, 25, 0, 2, 37, 0, 89, 212, 89, 1, 198, 89, 1, 178, 89, 1, 164, 89, 1, 146, 89, 1, 132, 89, 1, 114, 89, 1, 68, 89, 84, 89, 100, 89, 3, 34, 89, 50, 89, 2, 16, 89, 1, 2, 89, 1, 228, 89, 244, 89, 2, 214, 89, 1, 194, 89, 1, 180, 89, 1, 162, 89, 1, 148, 89, 1, 130, 89, 1, 100, 89, 116, 89, 2, 86, 89, 1, 66, 89, 1, 52, 89, 1, 38, 89, 1, 20, 89, 1, 6, 89, 1, 200, 244, 89, 1, 230, 89, 1, 196, 89, 212, 89, 2, 178, 89, 1, 164, 89, 1, 146, 89, 1, 134, 89, 1, 100, 89, 116, 89, 2, 66, 89, 82, 89, 2, 52, 89, 1, 34, 89, 1, 22, 89, 1, 4, 89, 1, 246, 89, 1, 228, 89, 1, 214, 89, 1, 194, 89, 1, 180, 89, 1, 162, 89, 1, 150, 89, 1, 132, 89, 1, 70, 89, 86, 89, 118, 89, 3, 48, 89, 1, 36, 89, 1, 18, 89, 1, 4, 89, 1, 242, 89, 1, 228, 89, 1, 178, 89, 194, 89, 210, 89, 3, 164, 89, 1, 150, 89, 1, 132, 89, 1, 118, 89, 1, 100, 89, 1, 86, 89, 1, 68, 89, 1, 54, 89, 1, 36, 89, 1, 22, 89, 1, 2, 89, 1, 152, 64, 255, 244, 89, 1, 226, 89, 1, 212, 89, 1, 198, 89, 1, 180, 89, 1, 166, 89, 1, 148, 89, 1, 134, 89, 1, 114, 89, 1, 68, 89, 84, 89, 100, 89, 3, 50, 89, 1, 36, 89, 1, 18, 89, 1, 4, 89, 1, 242, 89, 1, 230, 89, 1, 196, 89, 1, 182, 89, 1, 164, 89, 1, 150, 89, 1, 132, 89, 1, 102, 89, 118, 89, 2, 66, 89, 1, 52, 89, 1, 34, 89, 1, 20, 89, 1, 6, 89, 1, 244, 89, 1, 198, 89, 214, 89, 2, 178, 89, 1, 164, 89, 1, 146, 89, 1, 116, 89, 132, 89, 2, 102, 89, 1, 68, 89, 84, 89, 2, 54, 89, 1, 36, 89, 1, 6, 89, 22, 89, 2, 104, 230, 89, 1, 196, 89, 1, 182, 89, 1, 132, 89, 164, 89, 2, 70, 89, 86, 89, 118, 89, 3, 52, 89, 1, 22, 89, 1, 244, 89, 1, 230, 89, 1, 196, 89, 212, 89, 2, 178, 89, 1, 1, 100, 89, 132, 89, 164, 89, 3, 64, 89, 1, 4, 89, 36, 89, 2, 228, 89, 1, 192, 89, 1, 116, 89, 148, 89, 180, 89, 3, 48, 89, 1, 36, 89, 1, 16, 89, 1, 4, 89, 1, 56, 240, 89, 1, 219, 89, 1, 132, 89, 164, 89, 196, 89, 3, 91, 89, 1, 4, 89, 36, 89, 68, 89, 3, 196, 89, 212, 89, 244, 89, 3, 176, 89, 1, 164, 89, 1, 144, 89, 1, 2, 32, 89, 64, 64, 51, 89, 80, 89, 112, 89, 4, 31, 89, 1, 223, 89, 255, 89, 2, 160, 89, 192, 89, 2, 95, 89, 127, 89, 159, 89, 3, 32, 89, 48, 89, 2, 15, 89, 1, 8, 67, 85, 79, 23, 5, 22, 75, 60, 79, 50, 33, 16, 45, 0, 17, 27, 0, 63, 63, 63, 51, 237, 50, 63, 51, 237, 50, 1, 94, 93, 93, 93, 93, 93, 113, 113, 95, 113, 113, 113, 113, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 95, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 16, 222, 94, 93, 237, 47, 93, 237, 18, 57, 47, 94, 93, 113, 51, 51, 237, 50, 50, 49, 48, 1, 20, 14, 2, 35, 34, 46, 2, 39, 35, 30, 3, 21, 17, 33, 17, 35, 14, 1, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 30, 2, 23, 51, 52, 38, 52, 38, 53, 17, 33, 17, 62, 1, 51, 50, 30, 2, 5, 52, 46, 2, 35, 34, 14, 2, 21, 16, 51, 50, 62, 2, 37, 52, 38, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 54, 6, 173, 45, 94, 144, 98, 44, 87, 80, 67, 24, 6, 1, 2, 2, 1, 254, 251, 2, 45, 161, 112, 94, 137, 89, 43, 45, 94, 144, 99, 49, 90, 77, 63, 22, 2, 1, 1, 1, 5, 47, 164, 107, 95, 137, 90, 43, 252, 84, 35, 56, 72, 37, 47, 72, 50, 25, 192, 37, 72, 57, 36, 2, 135, 97, 97, 36, 72, 57, 35, 35, 56, 72, 36, 94, 101, 2, 34, 123, 208, 150, 85, 20, 45, 73, 54, 5, 40, 53, 59, 25, 254, 97, 2, 89, 105, 91, 84, 150, 205, 121, 123, 206, 149, 84, 22, 46, 72, 51, 10, 39, 50, 54, 25, 1, 139, 253, 190, 107, 92, 84, 148, 205, 121, 107, 141, 83, 33, 42, 90, 140, 99, 254, 144, 36, 86, 145, 107, 185, 179, 35, 85, 143, 109, 106, 141, 84, 35, 178, 255, 255, 0, 14, 0, 0, 4, 100, 4, 58, 18, 6, 0, 91, 0, 0, 0, 1, 0, 143, 254, 104, 4, 216, 4, 58, 0, 11, 0, 66, 64, 14, 10, 72, 9, 9, 4, 70, 7, 13, 3, 70, 208, 0, 1, 0, 184, 255, 192, 179, 36, 40, 72, 0, 184, 255, 192, 180, 9, 12, 72, 0, 10, 184, 1, 17, 183, 5, 1, 15, 7, 3, 79, 0, 21, 0, 63, 237, 50, 63, 51, 63, 1, 47, 43, 43, 93, 237, 16, 220, 237, 51, 47, 237, 49, 48, 51, 17, 33, 17, 33, 17, 33, 17, 51, 17, 35, 17, 143, 1, 26, 1, 131, 1, 26, 146, 245, 4, 58, 252, 132, 3, 124, 252, 132, 253, 170, 1, 152, 0, 0, 0, 0, 1, 0, 83, 0, 0, 4, 23, 4, 58, 0, 27, 0, 58, 64, 35, 24, 40, 9, 10, 0, 76, 11, 15, 70, 223, 14, 1, 14, 64, 36, 40, 72, 14, 29, 1, 70, 191, 26, 1, 26, 11, 6, 80, 21, 21, 14, 21, 12, 0, 15, 0, 63, 50, 63, 57, 47, 237, 51, 1, 47, 113, 237, 16, 222, 43, 93, 237, 50, 49, 48, 43, 1, 17, 20, 30, 2, 51, 50, 62, 2, 55, 17, 33, 17, 33, 17, 14, 3, 35, 34, 46, 2, 53, 17, 1, 107, 16, 36, 61, 45, 33, 59, 58, 60, 35, 1, 25, 254, 231, 43, 85, 92, 100, 57, 74, 114, 78, 40, 4, 58, 254, 126, 33, 57, 42, 24, 6, 12, 17, 10, 1, 241, 251, 198, 1, 159, 15, 31, 24, 16, 43, 82, 117, 73, 1, 182, 0, 0, 1, 0, 143, 0, 0, 6, 24, 4, 58, 0, 11, 2, 190, 185, 0, 8, 1, 18, 179, 5, 5, 1, 9, 184, 1, 18, 181, 198, 0, 214, 0, 2, 0, 184, 255, 192, 64, 255, 40, 43, 72, 9, 0, 25, 0, 2, 21, 0, 13, 196, 13, 1, 166, 13, 182, 13, 2, 148, 13, 1, 134, 13, 1, 116, 13, 1, 70, 13, 102, 13, 2, 4, 13, 20, 13, 36, 13, 3, 198, 13, 214, 13, 246, 13, 3, 180, 13, 1, 118, 13, 166, 13, 2, 98, 13, 1, 84, 13, 1, 70, 13, 1, 52, 13, 1, 38, 13, 1, 20, 13, 1, 6, 13, 1, 201, 244, 13, 1, 230, 13, 1, 212, 13, 1, 182, 13, 198, 13, 2, 164, 13, 1, 134, 13, 1, 84, 13, 100, 13, 2, 70, 13, 1, 52, 13, 1, 22, 13, 38, 13, 2, 230, 13, 1, 194, 13, 1, 180, 13, 1, 166, 13, 1, 148, 13, 1, 134, 13, 1, 116, 13, 1, 54, 13, 70, 13, 102, 13, 3, 36, 13, 1, 9, 13, 1, 233, 13, 1, 118, 13, 134, 13, 166, 13, 182, 13, 214, 13, 5, 100, 13, 1, 54, 13, 86, 13, 2, 41, 13, 1, 6, 13, 22, 13, 2, 152, 226, 13, 1, 180, 13, 196, 13, 212, 13, 3, 166, 13, 1, 148, 13, 1, 134, 13, 1, 114, 13, 1, 100, 13, 1, 82, 13, 1, 68, 13, 1, 54, 13, 1, 36, 13, 1, 22, 13, 1, 4, 13, 1, 228, 13, 244, 13, 2, 210, 13, 1, 196, 13, 1, 178, 13, 1, 148, 13, 164, 13, 2, 130, 13, 1, 100, 13, 116, 13, 2, 70, 13, 86, 13, 2, 50, 13, 64, 237, 1, 36, 13, 1, 18, 13, 1, 4, 13, 1, 214, 13, 230, 13, 246, 13, 3, 180, 13, 196, 13, 2, 162, 13, 1, 148, 13, 1, 134, 13, 1, 116, 13, 1, 102, 13, 1, 84, 13, 1, 70, 13, 1, 2, 13, 18, 13, 34, 13, 3, 104, 244, 13, 1, 230, 13, 1, 212, 13, 1, 198, 13, 1, 178, 13, 1, 132, 13, 164, 13, 2, 118, 13, 1, 84, 13, 100, 13, 2, 70, 13, 1, 52, 13, 1, 22, 13, 1, 242, 13, 1, 228, 13, 1, 214, 13, 1, 196, 13, 1, 118, 13, 150, 13, 166, 13, 182, 13, 4, 100, 13, 1, 82, 13, 1, 68, 13, 1, 54, 13, 1, 36, 13, 1, 22, 13, 1, 4, 13, 1, 246, 13, 1, 212, 13, 1, 198, 13, 1, 180, 13, 1, 118, 13, 134, 13, 166, 13, 3, 100, 13, 1, 54, 13, 70, 13, 2, 20, 13, 1, 6, 13, 1, 56, 244, 13, 1, 217, 13, 1, 162, 13, 1, 1, 144, 13, 1, 132, 13, 1, 80, 13, 112, 13, 2, 2, 0, 13, 32, 13, 64, 13, 3, 175, 13, 207, 13, 239, 13, 3, 144, 13, 1, 143, 13, 1, 48, 13, 64, 13, 96, 13, 3, 15, 13, 1, 176, 13, 208, 13, 224, 13, 3, 143, 13, 1, 0, 13, 64, 13, 80, 13, 112, 13, 4, 8, 4, 184, 1, 18, 179, 208, 1, 1, 1, 184, 255, 192, 64, 13, 9, 12, 72, 1, 10, 6, 2, 15, 8, 4, 79, 1, 21, 0, 63, 237, 50, 63, 51, 51, 1, 47, 43, 93, 237, 94, 93, 93, 93, 113, 113, 113, 113, 113, 114, 95, 114, 114, 114, 95, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 16, 222, 94, 93, 43, 93, 237, 17, 57, 47, 237, 49, 48, 41, 1, 17, 33, 17, 33, 17, 33, 17, 33, 17, 33, 6, 24, 250, 119, 1, 6, 1, 60, 1, 6, 1, 59, 1, 6, 4, 58, 252, 132, 3, 124, 252, 132, 3, 124, 0, 1, 0, 143, 254, 104, 6, 172, 4, 58, 0, 15, 2, 188, 185, 0, 7, 1, 18, 64, 9, 4, 4, 8, 0, 14, 72, 13, 13, 8, 184, 1, 18, 181, 150, 11, 166, 11, 2, 11, 184, 255, 192, 64, 15, 40, 43, 72, 121, 11, 137, 11, 2, 6, 11, 22, 11, 2, 9, 11, 184, 255, 192, 64, 255, 27, 30, 72, 11, 17, 180, 17, 1, 150, 17, 166, 17, 2, 132, 17, 1, 38, 17, 54, 17, 102, 17, 3, 4, 17, 20, 17, 2, 244, 17, 1, 230, 17, 1, 196, 17, 1, 182, 17, 1, 164, 17, 1, 102, 17, 150, 17, 2, 84, 17, 1, 70, 17, 1, 36, 17, 1, 22, 17, 1, 4, 17, 1, 202, 150, 17, 182, 17, 214, 17, 246, 17, 4, 132, 17, 1, 102, 17, 1, 68, 17, 1, 38, 17, 54, 17, 2, 4, 17, 20, 17, 2, 244, 17, 1, 230, 17, 1, 196, 17, 1, 182, 17, 1, 162, 17, 1, 148, 17, 1, 102, 17, 118, 17, 134, 17, 3, 84, 17, 1, 6, 17, 38, 17, 70, 17, 3, 182, 17, 214, 17, 246, 17, 3, 148, 17, 1, 22, 17, 70, 17, 102, 17, 134, 17, 4, 9, 17, 1, 154, 240, 17, 1, 210, 17, 226, 17, 2, 196, 17, 1, 182, 17, 1, 148, 17, 164, 17, 2, 128, 17, 1, 98, 17, 114, 17, 2, 84, 17, 1, 70, 17, 1, 36, 17, 52, 17, 2, 18, 17, 1, 4, 17, 1, 246, 17, 1, 226, 17, 1, 212, 17, 1, 192, 17, 1, 178, 17, 1, 164, 17, 1, 146, 17, 1, 116, 17, 132, 17, 2, 86, 17, 102, 17, 2, 68, 17, 1, 54, 17, 1, 36, 17, 1, 22, 17, 1, 214, 17, 246, 17, 2, 196, 17, 1, 178, 17, 1, 132, 17, 148, 17, 164, 17, 3, 64, 205, 118, 17, 1, 84, 17, 100, 17, 2, 70, 17, 1, 18, 17, 34, 17, 50, 17, 3, 4, 17, 1, 103, 246, 17, 1, 228, 17, 1, 214, 17, 1, 194, 17, 1, 180, 17, 1, 166, 17, 1, 148, 17, 1, 134, 17, 1, 116, 17, 1, 86, 17, 102, 17, 2, 68, 17, 1, 38, 17, 1, 4, 17, 1, 244, 17, 1, 230, 17, 1, 212, 17, 1, 182, 17, 198, 17, 2, 116, 17, 132, 17, 2, 98, 17, 1, 1, 80, 17, 1, 36, 17, 52, 17, 2, 16, 17, 1, 4, 17, 1, 228, 17, 1, 219, 17, 1, 148, 17, 196, 17, 2, 64, 17, 80, 17, 112, 17, 3, 52, 17, 1, 32, 17, 1, 20, 17, 1, 0, 17, 1, 55, 212, 17, 244, 17, 2, 176, 17, 1, 148, 17, 164, 17, 2, 128, 17, 1, 36, 17, 52, 17, 84, 17, 100, 17, 4, 16, 17, 1, 107, 17, 139, 17, 155, 17, 187, 17, 219, 17, 251, 17, 6, 84, 17, 1, 27, 17, 1, 244, 17, 1, 219, 17, 1, 84, 17, 100, 17, 132, 17, 3, 43, 17, 59, 17, 2, 16, 17, 1, 2, 0, 17, 1, 7, 3, 184, 1, 18, 179, 208, 0, 1, 0, 184, 255, 192, 180, 9, 12, 72, 0, 14, 184, 1, 17, 64, 10, 11, 7, 3, 79, 0, 21, 9, 5, 1, 15, 0, 63, 51, 51, 63, 237, 50, 50, 63, 1, 47, 43, 93, 237, 94, 93, 95, 93, 93, 93, 93, 93, 113, 113, 113, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 95, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 16, 220, 43, 94, 93, 113, 43, 113, 237, 51, 47, 237, 17, 18, 57, 47, 237, 49, 48, 51, 17, 33, 17, 33, 17, 33, 17, 33, 17, 33, 17, 51, 17, 35, 17, 143, 1, 6, 1, 61, 1, 6, 1, 60, 1, 6, 146, 245, 4, 58, 252, 132, 3, 124, 252, 132, 3, 124, 252, 132, 253, 170, 1, 152, 0, 0, 2, 0, 38, 0, 0, 5, 128, 4, 58, 0, 14, 0, 27, 0, 75, 185, 0, 5, 255, 232, 180, 9, 10, 0, 76, 2, 184, 255, 232, 64, 35, 9, 10, 0, 76, 14, 15, 70, 9, 9, 11, 21, 70, 191, 3, 207, 3, 223, 3, 3, 3, 29, 11, 27, 82, 14, 14, 15, 11, 79, 12, 15, 15, 82, 9, 21, 0, 63, 237, 63, 237, 18, 57, 47, 237, 1, 47, 16, 222, 113, 237, 18, 57, 47, 237, 50, 49, 48, 43, 43, 1, 50, 22, 21, 20, 14, 2, 35, 33, 17, 33, 53, 33, 25, 1, 51, 50, 62, 2, 53, 52, 46, 2, 43, 1, 3, 173, 235, 232, 57, 116, 175, 118, 253, 237, 254, 139, 2, 143, 188, 69, 93, 55, 23, 25, 56, 92, 66, 189, 2, 135, 154, 164, 77, 122, 85, 45, 3, 124, 190, 254, 77, 254, 40, 20, 39, 58, 37, 38, 55, 36, 17, 0, 0, 3, 0, 143, 0, 0, 6, 70, 4, 58, 0, 12, 0, 23, 0, 27, 0, 120, 185, 0, 5, 255, 232, 180, 9, 10, 0, 76, 2, 184, 255, 232, 64, 42, 9, 10, 0, 76, 19, 70, 96, 3, 1, 36, 3, 1, 3, 3, 9, 24, 70, 223, 27, 1, 27, 64, 36, 40, 72, 16, 27, 1, 27, 29, 128, 29, 208, 29, 2, 12, 13, 70, 208, 9, 1, 9, 184, 255, 192, 179, 36, 40, 72, 9, 184, 255, 192, 64, 16, 9, 12, 72, 9, 23, 82, 12, 12, 25, 10, 15, 13, 82, 24, 9, 21, 0, 63, 51, 237, 63, 51, 57, 47, 237, 1, 47, 43, 43, 93, 237, 50, 93, 16, 222, 93, 43, 93, 237, 18, 57, 47, 93, 93, 237, 49, 48, 43, 43, 1, 50, 22, 21, 20, 14, 2, 35, 33, 17, 33, 25, 1, 51, 50, 62, 2, 53, 52, 38, 43, 1, 1, 17, 33, 17, 2, 185, 235, 242, 60, 120, 178, 118, 253, 213, 1, 26, 212, 69, 96, 59, 26, 116, 133, 213, 3, 132, 1, 25, 2, 135, 154, 164, 77, 122, 85, 45, 4, 58, 254, 77, 254, 40, 20, 39, 58, 37, 76, 70, 254, 37, 4, 58, 251, 198, 0, 0, 0, 2, 0, 143, 0, 0, 4, 150, 4, 58, 0, 12, 0, 23, 0, 93, 185, 0, 5, 255, 232, 180, 9, 10, 0, 76, 2, 184, 255, 232, 64, 27, 9, 10, 0, 76, 19, 70, 191, 3, 207, 3, 223, 3, 3, 3, 25, 32, 25, 208, 25, 2, 12, 13, 70, 208, 9, 1, 9, 184, 255, 192, 179, 36, 40, 72, 9, 184, 255, 192, 64, 14, 9, 12, 72, 9, 23, 82, 12, 12, 10, 15, 13, 82, 9, 21, 0, 63, 237, 63, 57, 47, 237, 1, 47, 43, 43, 93, 237, 50, 93, 16, 222, 113, 237, 49, 48, 43, 43, 1, 50, 22, 21, 20, 14, 2, 35, 33, 17, 33, 25, 1, 51, 50, 62, 2, 53, 52, 38, 43, 1, 2, 185, 235, 242, 60, 120, 178, 118, 253, 213, 1, 26, 212, 69, 96, 59, 26, 116, 133, 213, 2, 135, 154, 164, 77, 122, 85, 45, 4, 58, 254, 77, 254, 40, 20, 39, 58, 37, 76, 70, 0, 0, 1, 0, 52, 255, 236, 4, 27, 4, 78, 0, 40, 0, 84, 64, 49, 144, 10, 1, 10, 10, 0, 12, 9, 71, 31, 42, 20, 70, 21, 21, 1, 70, 0, 10, 79, 11, 11, 26, 4, 79, 36, 64, 1, 160, 1, 2, 1, 1, 36, 22, 121, 20, 137, 20, 2, 45, 20, 1, 20, 20, 17, 79, 26, 16, 0, 63, 237, 51, 47, 93, 93, 63, 51, 47, 93, 16, 237, 17, 57, 47, 237, 1, 47, 237, 51, 47, 237, 16, 222, 237, 50, 18, 57, 47, 93, 49, 48, 19, 37, 30, 1, 51, 50, 62, 2, 55, 33, 53, 33, 46, 3, 35, 34, 6, 7, 37, 62, 3, 51, 50, 30, 2, 21, 20, 14, 2, 35, 34, 46, 2, 52, 1, 26, 13, 108, 80, 58, 80, 51, 25, 3, 254, 203, 1, 53, 3, 24, 50, 79, 57, 88, 96, 12, 254, 229, 14, 73, 118, 163, 105, 123, 193, 132, 70, 64, 128, 193, 129, 111, 172, 121, 71, 1, 104, 13, 100, 101, 37, 71, 105, 68, 190, 61, 99, 69, 37, 99, 83, 14, 76, 132, 97, 56, 76, 145, 211, 135, 124, 205, 146, 80, 63, 105, 137, 0, 0, 0, 0, 2, 0, 143, 255, 236, 6, 133, 4, 78, 0, 26, 0, 40, 0, 97, 64, 26, 33, 71, 17, 47, 10, 111, 10, 143, 10, 223, 10, 4, 10, 10, 13, 27, 71, 0, 42, 16, 12, 70, 208, 13, 1, 13, 184, 255, 192, 179, 36, 40, 72, 13, 184, 255, 192, 64, 26, 9, 12, 72, 13, 11, 79, 63, 16, 79, 16, 2, 16, 16, 38, 30, 79, 22, 16, 14, 15, 13, 21, 38, 79, 5, 22, 0, 63, 237, 63, 63, 63, 237, 18, 57, 47, 114, 237, 1, 47, 43, 43, 93, 237, 50, 16, 222, 237, 17, 57, 47, 93, 51, 237, 49, 48, 1, 20, 14, 2, 35, 34, 46, 2, 39, 35, 17, 33, 17, 33, 17, 51, 62, 3, 51, 50, 30, 2, 5, 52, 38, 35, 34, 6, 21, 20, 30, 2, 51, 50, 54, 6, 133, 66, 133, 199, 132, 117, 183, 131, 77, 10, 196, 254, 230, 1, 26, 200, 14, 77, 129, 182, 118, 141, 199, 126, 58, 254, 218, 116, 110, 115, 121, 32, 59, 83, 50, 114, 124, 2, 30, 124, 206, 149, 83, 69, 127, 178, 109, 254, 49, 4, 58, 254, 84, 99, 165, 118, 66, 84, 149, 205, 122, 193, 174, 176, 191, 97, 140, 90, 43, 175, 0, 0, 2, 255, 255, 0, 0, 4, 28, 4, 58, 0, 17, 0, 26, 0, 101, 185, 0, 1, 255, 232, 64, 24, 10, 0, 77, 5, 16, 9, 0, 77, 10, 16, 9, 10, 0, 76, 0, 3, 8, 26, 16, 70, 15, 28, 1, 2, 184, 255, 240, 64, 32, 63, 2, 1, 2, 2, 22, 70, 48, 8, 1, 8, 139, 3, 1, 3, 0, 82, 25, 64, 14, 17, 72, 25, 25, 1, 19, 82, 13, 15, 16, 1, 21, 0, 63, 51, 63, 237, 18, 57, 47, 43, 237, 57, 1, 93, 47, 93, 237, 51, 47, 93, 56, 51, 16, 222, 237, 50, 17, 57, 57, 49, 48, 43, 43, 43, 9, 1, 33, 1, 46, 3, 53, 52, 62, 2, 51, 33, 17, 33, 17, 19, 35, 34, 6, 21, 20, 22, 59, 1, 2, 66, 254, 240, 254, 205, 1, 66, 50, 85, 63, 35, 64, 122, 178, 113, 1, 231, 254, 230, 2, 192, 102, 103, 92, 97, 208, 1, 179, 254, 77, 1, 215, 12, 47, 75, 101, 66, 79, 117, 76, 38, 251, 198, 1, 179, 1, 216, 73, 78, 72, 77, 0, 0, 0, 255, 255, 0, 80, 255, 236, 4, 45, 5, 138, 18, 38, 0, 72, 0, 0, 17, 7, 0, 105, 0, 244, 0, 0, 0, 23, 64, 13, 3, 2, 40, 17, 38, 3, 2, 11, 44, 42, 5, 15, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 0, 0, 1, 0, 10, 254, 87, 4, 100, 5, 204, 0, 55, 0, 172, 185, 0, 53, 255, 232, 180, 9, 10, 0, 76, 48, 184, 255, 232, 64, 46, 9, 0, 77, 3, 33, 3, 33, 24, 12, 70, 224, 51, 240, 51, 2, 51, 57, 144, 57, 160, 57, 2, 112, 57, 240, 57, 2, 239, 57, 1, 35, 32, 24, 70, 25, 29, 25, 224, 28, 1, 28, 28, 208, 25, 1, 25, 184, 255, 192, 179, 36, 40, 72, 25, 184, 255, 192, 64, 25, 9, 12, 72, 25, 35, 27, 82, 28, 32, 28, 40, 18, 80, 45, 16, 45, 1, 0, 45, 16, 45, 32, 45, 3, 45, 184, 255, 192, 64, 16, 14, 17, 72, 28, 45, 28, 45, 25, 30, 0, 25, 21, 7, 80, 0, 27, 0, 63, 237, 63, 63, 18, 57, 57, 47, 47, 43, 93, 113, 16, 237, 51, 17, 51, 16, 237, 50, 1, 47, 43, 43, 93, 51, 47, 93, 17, 51, 16, 237, 50, 50, 93, 113, 114, 16, 222, 93, 237, 18, 57, 57, 47, 47, 49, 48, 43, 43, 1, 34, 38, 39, 53, 30, 1, 51, 50, 62, 2, 53, 17, 52, 46, 2, 35, 34, 14, 2, 21, 17, 33, 17, 35, 53, 51, 53, 33, 21, 33, 21, 33, 21, 20, 14, 2, 7, 51, 62, 1, 51, 50, 30, 2, 21, 17, 20, 14, 2, 3, 69, 56, 83, 31, 13, 26, 12, 39, 49, 28, 10, 20, 46, 74, 53, 51, 83, 60, 33, 254, 231, 133, 133, 1, 25, 1, 54, 254, 202, 2, 3, 2, 1, 4, 57, 172, 119, 98, 135, 85, 38, 32, 69, 109, 254, 87, 5, 4, 198, 2, 2, 16, 38, 62, 46, 2, 114, 63, 105, 75, 42, 45, 83, 115, 69, 253, 229, 4, 151, 170, 139, 139, 170, 136, 32, 65, 57, 46, 13, 124, 112, 64, 112, 152, 88, 252, 250, 65, 108, 80, 44, 255, 255, 0, 143, 0, 0, 3, 45, 5, 222, 18, 38, 1, 205, 0, 0, 17, 7, 0, 116, 0, 216, 0, 0, 0, 19, 64, 11, 1, 6, 17, 38, 1, 87, 6, 9, 4, 0, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 0, 1, 0, 80, 255, 236, 4, 55, 4, 78, 0, 36, 0, 90, 64, 53, 24, 24, 5, 32, 16, 70, 15, 15, 31, 70, 32, 64, 13, 19, 72, 32, 38, 22, 25, 71, 5, 25, 79, 22, 22, 28, 19, 79, 10, 121, 16, 137, 16, 2, 45, 16, 1, 16, 16, 10, 16, 28, 79, 0, 64, 31, 160, 31, 2, 31, 31, 0, 22, 0, 63, 50, 47, 93, 16, 237, 63, 51, 47, 93, 93, 16, 237, 18, 57, 47, 237, 1, 47, 237, 50, 16, 222, 43, 237, 51, 47, 237, 17, 18, 57, 47, 49, 48, 5, 34, 46, 2, 53, 52, 62, 2, 51, 50, 30, 2, 23, 5, 46, 1, 35, 34, 6, 7, 33, 21, 33, 30, 1, 51, 50, 54, 55, 5, 14, 3, 2, 82, 129, 193, 128, 64, 70, 132, 193, 123, 105, 163, 118, 73, 14, 254, 229, 12, 96, 88, 101, 107, 5, 1, 53, 254, 203, 5, 110, 102, 80, 108, 13, 1, 26, 10, 71, 121, 172, 20, 80, 146, 205, 124, 135, 211, 145, 76, 56, 97, 132, 76, 14, 83, 99, 135, 131, 190, 141, 140, 101, 100, 13, 75, 137, 105, 63, 0, 255, 255, 0, 72, 255, 236, 4, 31, 4, 79, 18, 6, 0, 86, 0, 0, 255, 255, 0, 143, 0, 0, 1, 170, 5, 204, 16, 38, 0, 241, 254, 0, 17, 6, 1, 79, 201, 0, 0, 102, 185, 0, 9, 255, 192, 179, 45, 46, 72, 9, 184, 255, 192, 64, 9, 35, 36, 72, 9, 64, 32, 32, 72, 9, 184, 255, 192, 64, 14, 31, 31, 72, 9, 64, 26, 26, 72, 9, 64, 23, 23, 72, 9, 184, 255, 192, 179, 20, 22, 72, 9, 184, 255, 192, 181, 17, 17, 72, 1, 0, 0, 184, 255, 192, 179, 50, 50, 72, 0, 184, 255, 192, 64, 11, 45, 46, 72, 0, 1, 0, 4, 7, 1, 3, 37, 1, 43, 53, 17, 43, 43, 53, 53, 1, 43, 43, 43, 43, 43, 43, 43, 43, 0, 0, 255, 255, 255, 218, 0, 0, 2, 101, 5, 138, 16, 38, 0, 241, 0, 0, 17, 6, 0, 105, 202, 0, 3, 130, 64, 14, 2, 1, 4, 17, 38, 2, 1, 2, 8, 6, 0, 2, 37, 13, 184, 255, 192, 179, 228, 228, 72, 13, 184, 255, 192, 179, 227, 227, 72, 13, 184, 255, 192, 179, 226, 226, 72, 13, 184, 255, 192, 179, 224, 224, 72, 13, 184, 255, 192, 179, 223, 223, 72, 13, 184, 255, 192, 179, 221, 221, 72, 13, 184, 255, 192, 179, 220, 220, 72, 13, 184, 255, 192, 179, 219, 219, 72, 13, 184, 255, 192, 179, 217, 217, 72, 13, 184, 255, 192, 179, 216, 216, 72, 13, 184, 255, 192, 179, 214, 214, 72, 13, 184, 255, 192, 179, 213, 213, 72, 13, 184, 255, 192, 179, 212, 212, 72, 13, 184, 255, 192, 179, 210, 210, 72, 13, 184, 255, 192, 179, 209, 209, 72, 13, 184, 255, 192, 179, 208, 208, 72, 13, 184, 255, 192, 179, 206, 206, 72, 13, 184, 255, 192, 179, 205, 205, 72, 13, 184, 255, 192, 179, 203, 203, 72, 13, 184, 255, 192, 179, 202, 202, 72, 13, 184, 255, 192, 179, 201, 201, 72, 13, 184, 255, 192, 179, 199, 199, 72, 13, 184, 255, 192, 179, 198, 198, 72, 13, 184, 255, 192, 179, 196, 196, 72, 13, 184, 255, 192, 179, 195, 195, 72, 13, 184, 255, 192, 179, 194, 194, 72, 13, 184, 255, 192, 179, 192, 192, 72, 13, 184, 255, 192, 179, 191, 191, 72, 13, 184, 255, 192, 179, 188, 188, 72, 13, 184, 255, 192, 179, 187, 187, 72, 13, 184, 255, 192, 179, 185, 185, 72, 13, 184, 255, 192, 179, 184, 184, 72, 13, 184, 255, 192, 179, 181, 181, 72, 13, 184, 255, 192, 179, 180, 180, 72, 13, 184, 255, 192, 179, 178, 178, 72, 13, 184, 255, 192, 179, 177, 177, 72, 13, 184, 255, 192, 179, 176, 176, 72, 13, 184, 255, 192, 179, 174, 174, 72, 13, 184, 255, 192, 179, 173, 173, 72, 13, 184, 255, 192, 179, 170, 170, 72, 13, 184, 255, 192, 179, 169, 169, 72, 13, 184, 255, 192, 179, 167, 167, 72, 13, 184, 255, 192, 179, 166, 166, 72, 13, 184, 255, 192, 179, 163, 163, 72, 13, 184, 255, 192, 179, 162, 162, 72, 13, 184, 255, 192, 179, 160, 160, 72, 13, 184, 255, 192, 179, 159, 159, 72, 13, 184, 255, 192, 179, 156, 156, 72, 13, 184, 255, 192, 179, 155, 155, 72, 13, 184, 255, 192, 179, 152, 152, 72, 13, 184, 255, 192, 179, 149, 149, 72, 13, 184, 255, 192, 179, 148, 148, 72, 13, 184, 255, 192, 179, 145, 145, 72, 13, 184, 255, 192, 179, 144, 144, 72, 13, 184, 255, 192, 179, 142, 142, 72, 13, 184, 255, 192, 179, 141, 141, 72, 13, 184, 255, 192, 179, 138, 138, 72, 13, 184, 255, 192, 179, 137, 137, 72, 13, 184, 255, 192, 179, 134, 134, 72, 13, 184, 255, 192, 179, 131, 131, 72, 13, 184, 255, 192, 179, 130, 130, 72, 13, 184, 255, 192, 179, 127, 127, 72, 13, 184, 255, 192, 179, 124, 124, 72, 13, 184, 255, 192, 179, 123, 123, 72, 13, 184, 255, 192, 179, 120, 120, 72, 13, 184, 255, 192, 179, 116, 116, 72, 13, 184, 255, 192, 179, 113, 113, 72, 13, 184, 255, 192, 179, 112, 112, 72, 13, 184, 255, 192, 179, 109, 109, 72, 13, 184, 255, 192, 179, 106, 106, 72, 13, 184, 255, 192, 179, 105, 105, 72, 13, 184, 255, 192, 179, 102, 102, 72, 13, 184, 255, 192, 179, 98, 98, 72, 13, 184, 255, 192, 179, 95, 95, 72, 13, 184, 255, 192, 179, 91, 91, 72, 13, 184, 255, 192, 179, 88, 88, 72, 13, 184, 255, 192, 179, 84, 84, 72, 13, 184, 255, 192, 179, 80, 80, 72, 13, 184, 255, 192, 179, 77, 77, 72, 13, 184, 255, 192, 179, 73, 73, 72, 13, 184, 255, 192, 179, 70, 70, 72, 13, 184, 255, 192, 179, 66, 66, 72, 13, 184, 255, 192, 179, 59, 59, 72, 13, 184, 255, 192, 179, 52, 52, 72, 13, 184, 255, 192, 179, 48, 48, 72, 13, 184, 255, 192, 179, 41, 41, 72, 13, 184, 255, 192, 179, 36, 36, 72, 13, 184, 255, 192, 179, 35, 35, 72, 13, 184, 255, 192, 64, 9, 34, 34, 72, 13, 64, 32, 32, 72, 13, 184, 255, 192, 64, 14, 31, 31, 72, 13, 64, 26, 26, 72, 13, 64, 23, 23, 72, 13, 184, 255, 192, 179, 22, 22, 72, 13, 184, 255, 192, 179, 21, 21, 72, 13, 184, 255, 192, 179, 20, 20, 72, 13, 184, 255, 192, 179, 17, 17, 72, 13, 184, 255, 192, 178, 16, 16, 72, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 255, 255, 255, 224, 254, 87, 1, 169, 5, 204, 18, 6, 0, 77, 0, 0, 0, 2, 0, 21, 255, 236, 7, 107, 4, 58, 0, 36, 0, 47, 0, 159, 185, 0, 33, 255, 232, 180, 9, 10, 0, 76, 30, 184, 255, 232, 64, 99, 9, 10, 0, 76, 25, 2, 41, 2, 2, 7, 2, 1, 247, 2, 1, 184, 2, 1, 153, 2, 169, 2, 2, 132, 2, 1, 118, 2, 1, 103, 2, 1, 43, 2, 59, 2, 75, 2, 3, 2, 25, 27, 37, 70, 0, 111, 0, 1, 111, 25, 191, 25, 207, 25, 223, 25, 4, 16, 25, 32, 25, 2, 25, 0, 25, 0, 14, 43, 70, 191, 31, 207, 31, 223, 31, 3, 31, 49, 64, 49, 1, 14, 47, 82, 27, 27, 37, 1, 79, 26, 15, 18, 79, 9, 22, 37, 82, 0, 21, 0, 63, 237, 63, 237, 63, 237, 18, 57, 47, 237, 1, 47, 93, 16, 222, 113, 237, 17, 57, 57, 47, 47, 93, 93, 93, 16, 237, 50, 17, 51, 93, 93, 93, 93, 93, 93, 93, 113, 113, 49, 48, 43, 43, 33, 17, 33, 6, 2, 14, 3, 35, 34, 46, 2, 39, 53, 30, 1, 51, 50, 62, 3, 18, 55, 33, 17, 33, 50, 22, 21, 20, 14, 2, 35, 37, 51, 50, 62, 2, 53, 52, 38, 43, 1, 3, 100, 254, 210, 25, 42, 44, 51, 70, 94, 65, 14, 45, 47, 39, 9, 11, 38, 19, 29, 43, 36, 31, 35, 41, 27, 3, 51, 1, 16, 235, 242, 60, 120, 178, 118, 254, 239, 212, 69, 96, 59, 26, 116, 133, 213, 3, 124, 184, 254, 234, 203, 134, 80, 33, 2, 4, 5, 2, 191, 4, 5, 25, 70, 126, 201, 1, 32, 197, 254, 77, 154, 164, 77, 122, 85, 45, 175, 20, 39, 58, 37, 76, 70, 0, 2, 0, 143, 0, 0, 6, 235, 4, 58, 0, 20, 0, 31, 0, 108, 185, 0, 5, 255, 240, 180, 9, 10, 0, 76, 2, 184, 255, 232, 64, 29, 9, 10, 0, 76, 20, 21, 70, 17, 9, 9, 13, 27, 70, 191, 3, 207, 3, 223, 3, 3, 3, 33, 16, 12, 70, 208, 13, 1, 13, 184, 255, 192, 179, 36, 40, 72, 13, 184, 255, 192, 64, 18, 9, 12, 72, 13, 10, 31, 82, 17, 20, 20, 14, 19, 15, 21, 82, 13, 9, 21, 0, 63, 51, 237, 63, 51, 57, 47, 197, 253, 197, 1, 47, 43, 43, 93, 237, 50, 16, 222, 113, 237, 17, 57, 47, 51, 237, 50, 49, 48, 43, 43, 1, 50, 22, 21, 20, 14, 2, 35, 33, 17, 33, 17, 33, 17, 33, 17, 33, 17, 33, 25, 1, 51, 50, 62, 2, 53, 52, 38, 43, 1, 5, 14, 235, 242, 60, 120, 178, 118, 253, 249, 254, 161, 254, 230, 1, 26, 1, 95, 1, 26, 176, 69, 96, 59, 26, 116, 133, 177, 2, 135, 154, 164, 77, 122, 85, 45, 1, 207, 254, 49, 4, 58, 254, 84, 1, 172, 254, 77, 254, 40, 20, 39, 58, 37, 76, 70, 0, 0, 0, 1, 0, 10, 0, 0, 4, 100, 5, 204, 0, 39, 0, 153, 185, 0, 36, 255, 232, 64, 45, 9, 10, 0, 76, 21, 21, 12, 0, 70, 224, 39, 240, 39, 2, 39, 41, 144, 41, 160, 41, 2, 112, 41, 240, 41, 2, 239, 41, 1, 23, 20, 12, 70, 13, 17, 13, 224, 16, 1, 16, 16, 208, 13, 1, 13, 184, 255, 192, 179, 36, 40, 72, 13, 184, 255, 192, 64, 25, 9, 12, 72, 13, 23, 15, 82, 16, 20, 16, 29, 6, 80, 33, 16, 33, 1, 0, 33, 16, 33, 32, 33, 3, 33, 184, 255, 192, 64, 12, 14, 17, 72, 16, 33, 16, 33, 18, 0, 13, 0, 21, 0, 63, 50, 63, 57, 57, 47, 47, 43, 93, 113, 16, 237, 51, 17, 51, 16, 237, 50, 1, 47, 43, 43, 93, 51, 47, 93, 17, 51, 16, 237, 50, 50, 93, 113, 114, 16, 222, 93, 237, 18, 57, 47, 49, 48, 43, 33, 17, 52, 46, 2, 35, 34, 14, 2, 21, 17, 33, 17, 35, 53, 51, 53, 33, 21, 33, 21, 33, 21, 20, 14, 2, 7, 51, 62, 1, 51, 50, 30, 2, 21, 17, 3, 76, 20, 46, 74, 53, 51, 83, 60, 33, 254, 231, 133, 133, 1, 25, 1, 54, 254, 202, 2, 3, 2, 1, 4, 57, 172, 119, 98, 135, 85, 38, 2, 54, 63, 105, 75, 42, 45, 83, 115, 69, 253, 229, 4, 151, 170, 139, 139, 170, 136, 32, 65, 57, 46, 13, 124, 112, 64, 112, 152, 88, 253, 122, 0, 255, 255, 0, 142, 0, 0, 4, 2, 5, 222, 18, 38, 1, 212, 0, 0, 17, 7, 0, 116, 1, 63, 0, 0, 0, 19, 64, 11, 1, 22, 17, 38, 1, 77, 22, 25, 0, 14, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 0, 16, 254, 87, 4, 104, 5, 244, 18, 38, 0, 92, 0, 0, 16, 7, 2, 151, 0, 228, 0, 0, 0, 1, 0, 143, 254, 104, 4, 70, 4, 58, 0, 11, 2, 187, 64, 24, 10, 72, 11, 11, 1, 5, 70, 9, 8, 1, 8, 64, 36, 40, 72, 8, 13, 4, 70, 6, 1, 1, 22, 1, 184, 255, 192, 179, 36, 40, 72, 1, 184, 255, 192, 64, 255, 9, 12, 72, 1, 191, 13, 1, 139, 13, 155, 13, 171, 13, 3, 121, 13, 1, 107, 13, 1, 93, 13, 1, 79, 13, 1, 61, 13, 1, 43, 13, 1, 29, 13, 1, 9, 13, 1, 251, 13, 1, 237, 13, 1, 217, 13, 1, 189, 13, 205, 13, 2, 175, 13, 1, 141, 13, 157, 13, 2, 127, 13, 1, 89, 13, 1, 13, 128, 203, 206, 72, 13, 13, 1, 202, 13, 128, 198, 201, 72, 201, 13, 1, 187, 13, 1, 173, 13, 1, 139, 13, 155, 13, 2, 125, 13, 1, 107, 13, 1, 89, 13, 1, 59, 13, 75, 13, 2, 41, 13, 1, 27, 13, 1, 13, 13, 1, 235, 13, 251, 13, 2, 221, 13, 1, 207, 13, 1, 153, 13, 169, 13, 2, 107, 13, 123, 13, 2, 93, 13, 1, 73, 13, 1, 59, 13, 1, 45, 13, 1, 25, 13, 1, 11, 13, 1, 13, 192, 165, 168, 72, 191, 13, 1, 173, 13, 1, 153, 13, 1, 139, 13, 1, 105, 13, 1, 91, 13, 1, 77, 13, 1, 43, 13, 59, 13, 2, 29, 13, 1, 11, 13, 1, 153, 249, 13, 1, 219, 13, 235, 13, 2, 201, 13, 1, 187, 13, 1, 173, 13, 1, 139, 13, 155, 13, 2, 109, 13, 125, 13, 2, 89, 13, 1, 59, 13, 75, 13, 2, 41, 13, 1, 13, 13, 29, 13, 2, 255, 13, 1, 235, 13, 1, 217, 13, 1, 203, 13, 1, 153, 13, 169, 13, 2, 107, 64, 234, 13, 123, 13, 2, 93, 13, 1, 57, 13, 73, 13, 2, 43, 13, 1, 9, 13, 1, 13, 128, 117, 120, 72, 189, 13, 1, 153, 13, 169, 13, 2, 123, 13, 139, 13, 2, 105, 13, 1, 91, 13, 1, 77, 13, 1, 43, 13, 59, 13, 2, 25, 13, 1, 11, 13, 1, 105, 185, 13, 217, 13, 233, 13, 3, 171, 13, 1, 121, 13, 137, 13, 153, 13, 3, 107, 13, 1, 57, 13, 73, 13, 2, 11, 13, 27, 13, 2, 253, 13, 1, 1, 219, 13, 1, 207, 13, 1, 155, 13, 171, 13, 2, 111, 13, 127, 13, 143, 13, 3, 91, 13, 1, 68, 13, 1, 27, 13, 43, 13, 2, 251, 13, 1, 239, 13, 1, 91, 13, 123, 13, 139, 13, 187, 13, 203, 13, 219, 13, 6, 79, 13, 1, 27, 13, 59, 13, 2, 15, 13, 1, 57, 219, 13, 235, 13, 251, 13, 3, 207, 13, 1, 171, 13, 1, 148, 13, 1, 123, 13, 1, 100, 13, 1, 27, 13, 43, 13, 59, 13, 3, 235, 13, 1, 223, 13, 1, 2, 160, 13, 176, 13, 2, 111, 13, 159, 13, 2, 80, 13, 1, 47, 13, 63, 13, 2, 208, 13, 224, 13, 2, 191, 13, 1, 112, 13, 160, 13, 2, 79, 13, 95, 13, 2, 48, 13, 1, 31, 13, 1, 0, 13, 1, 8, 11, 184, 1, 17, 183, 9, 4, 79, 1, 21, 6, 2, 15, 0, 63, 51, 63, 237, 51, 63, 1, 94, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 95, 113, 113, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 95, 113, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 43, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 43, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 43, 94, 93, 43, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 47, 43, 43, 94, 93, 237, 16, 222, 43, 93, 237, 17, 57, 47, 237, 49, 48, 41, 1, 17, 33, 17, 33, 17, 33, 17, 33, 17, 35, 1, 240, 254, 159, 1, 26, 1, 131, 1, 26, 254, 159, 245, 4, 58, 252, 133, 3, 123, 251, 198, 254, 104, 0, 1, 0, 137, 0, 1, 3, 185, 7, 28, 0, 7, 0, 51, 64, 30, 0, 92, 3, 64, 24, 36, 72, 48, 3, 1, 3, 3, 9, 5, 90, 32, 6, 48, 6, 2, 6, 4, 95, 7, 1, 1, 7, 3, 5, 18, 0, 63, 63, 51, 47, 16, 237, 1, 47, 93, 237, 17, 51, 47, 93, 43, 237, 49, 48, 1, 17, 51, 17, 33, 17, 33, 17, 2, 191, 250, 253, 247, 254, 217, 5, 129, 1, 155, 253, 129, 251, 100, 5, 128, 0, 0, 0, 1, 0, 143, 0, 0, 3, 61, 5, 210, 0, 7, 0, 70, 183, 0, 72, 3, 64, 13, 66, 72, 3, 184, 255, 192, 64, 12, 9, 12, 72, 3, 3, 9, 5, 70, 208, 6, 1, 6, 184, 255, 192, 179, 36, 40, 72, 6, 184, 255, 192, 64, 12, 9, 12, 72, 6, 4, 79, 7, 15, 5, 21, 1, 0, 0, 63, 63, 63, 237, 1, 47, 43, 43, 93, 237, 17, 51, 47, 43, 43, 237, 49, 48, 1, 17, 51, 17, 33, 17, 33, 17, 2, 72, 245, 254, 108, 254, 230, 4, 58, 1, 152, 253, 170, 252, 132, 4, 58, 0, 0, 0, 255, 255, 0, 2, 0, 0, 7, 139, 7, 23, 18, 38, 0, 58, 0, 0, 17, 7, 2, 154, 2, 65, 0, 0, 0, 21, 180, 1, 49, 5, 38, 1, 184, 255, 208, 180, 50, 53, 17, 48, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 255, 250, 0, 0, 6, 61, 5, 222, 18, 38, 0, 90, 0, 0, 16, 7, 0, 67, 1, 123, 0, 0, 255, 255, 0, 2, 0, 0, 7, 139, 7, 23, 18, 38, 0, 58, 0, 0, 17, 7, 2, 155, 2, 224, 0, 0, 0, 19, 64, 11, 1, 49, 5, 38, 1, 111, 49, 52, 17, 48, 37, 1, 43, 53, 0, 43, 53, 0, 0, 0, 255, 255, 255, 250, 0, 0, 6, 61, 5, 222, 18, 38, 0, 90, 0, 0, 16, 7, 0, 116, 2, 38, 0, 0, 255, 255, 0, 2, 0, 0, 7, 139, 6, 213, 18, 38, 0, 58, 0, 0, 17, 7, 2, 158, 2, 117, 0, 0, 0, 23, 64, 13, 2, 1, 49, 5, 38, 2, 1, 3, 53, 51, 17, 48, 37, 1, 43, 53, 53, 0, 43, 53, 53, 0, 0, 0, 255, 255, 255, 250, 0, 0, 6, 61, 5, 138, 18, 38, 0, 90, 0, 0, 16, 7, 0, 105, 1, 200, 0, 0, 255, 255, 0, 35, 0, 0, 5, 53, 7, 23, 18, 38, 0, 60, 0, 0, 17, 7, 2, 154, 1, 34, 0, 0, 0, 21, 180, 1, 9, 5, 38, 1, 184, 255, 204, 180, 10, 13, 4, 8, 37, 1, 43, 53, 0, 43, 53, 0, 255, 255, 0, 16, 254, 87, 4, 104, 5, 222, 18, 38, 0, 92, 0, 0, 16, 7, 0, 67, 0, 139, 0, 0, 0, 1, 0, 80, 1, 153, 2, 88, 2, 141, 0, 3, 0, 29, 0, 176, 0, 47, 176, 1, 205, 176, 1, 205, 1, 176, 4, 47, 176, 0, 220, 176, 3, 205, 176, 3, 16, 176, 5, 214, 0, 48, 49, 19, 53, 33, 21, 80, 2, 8, 1, 153, 244, 244, 0, 0, 0, 1, 0, 80, 1, 153, 2, 88, 2, 141, 0, 3, 0, 29, 0, 176, 0, 47, 176, 1, 205, 176, 1, 205, 1, 176, 4, 47, 176, 0, 220, 176, 3, 205, 176, 3, 16, 176, 5, 214, 0, 48, 49, 19, 53, 33, 21, 80, 2, 8, 1, 153, 244, 244, 0, 0, 0, 1, 0, 62, 1, 192, 4, 52, 2, 139, 0, 3, 0, 15, 181, 2, 0, 0, 185, 1, 188, 0, 63, 237, 1, 47, 47, 49, 48, 19, 53, 33, 21, 62, 3, 246, 1, 192, 203, 203, 0, 1, 0, 0, 1, 192, 8, 0, 2, 139, 0, 3, 0, 15, 181, 2, 0, 0, 185, 1, 188, 0, 63, 237, 1, 47, 47, 49, 48, 17, 53, 33, 21, 8, 0, 1, 192, 203, 203, 0, 0, 1, 0, 0, 1, 192, 8, 0, 2, 139, 0, 3, 0, 15, 181, 2, 0, 0, 185, 1, 188, 0, 63, 237, 1, 47, 47, 49, 48, 17, 53, 33, 21, 8, 0, 1, 192, 203, 203, 0, 255, 255, 255, 236, 254, 0, 4, 133, 255, 84, 16, 39, 0, 66, 0, 0, 254, 250, 16, 6, 0, 66, 0, 0, 0, 1, 0, 139, 3, 63, 1, 174, 5, 129, 0, 14, 0, 65, 64, 45, 6, 7, 14, 12, 151, 15, 14, 31, 14, 2, 14, 150, 79, 0, 95, 0, 2, 111, 0, 127, 0, 175, 0, 191, 0, 4, 143, 0, 191, 0, 207, 0, 3, 32, 0, 48, 0, 2, 0, 14, 158, 12, 168, 6, 3, 0, 63, 253, 237, 1, 47, 93, 93, 113, 114, 237, 93, 237, 16, 198, 50, 49, 48, 19, 53, 52, 62, 2, 55, 51, 14, 3, 21, 51, 17, 139, 15, 28, 40, 25, 183, 28, 48, 35, 20, 127, 3, 63, 195, 67, 110, 92, 79, 35, 35, 78, 82, 82, 40, 254, 251, 0, 0, 0, 0, 1, 0, 139, 3, 63, 1, 174, 5, 129, 0, 14, 0, 43, 64, 26, 5, 6, 12, 11, 151, 0, 12, 16, 12, 2, 0, 150, 32, 12, 48, 12, 208, 12, 3, 12, 6, 168, 12, 158, 13, 3, 0, 63, 253, 230, 1, 47, 93, 253, 93, 237, 16, 198, 50, 49, 48, 1, 20, 14, 2, 7, 35, 62, 3, 53, 35, 17, 33, 1, 174, 14, 28, 41, 26, 182, 28, 48, 35, 20, 127, 1, 31, 4, 190, 67, 109, 93, 78, 36, 36, 78, 81, 83, 40, 1, 4, 0, 0, 0, 0, 1, 0, 138, 254, 195, 1, 175, 1, 4, 0, 14, 0, 66, 64, 45, 5, 6, 12, 11, 151, 0, 12, 16, 12, 2, 0, 150, 79, 12, 1, 111, 12, 127, 12, 175, 12, 3, 143, 12, 191, 12, 207, 12, 3, 32, 12, 48, 12, 2, 15, 12, 31, 12, 2, 12, 13, 158, 6, 168, 12, 0, 47, 230, 237, 1, 47, 93, 93, 93, 113, 114, 253, 93, 237, 16, 198, 50, 49, 48, 37, 20, 14, 2, 7, 35, 62, 3, 53, 35, 17, 33, 1, 175, 15, 28, 40, 25, 185, 29, 49, 36, 20, 129, 1, 32, 66, 67, 110, 93, 78, 35, 35, 78, 82, 82, 40, 1, 4, 0, 0, 1, 0, 139, 3, 63, 1, 174, 5, 129, 0, 14, 0, 41, 64, 24, 8, 7, 1, 2, 151, 15, 1, 31, 1, 2, 1, 150, 32, 13, 48, 13, 2, 13, 8, 168, 2, 158, 14, 3, 0, 63, 253, 237, 1, 47, 93, 237, 93, 237, 16, 198, 50, 49, 48, 1, 17, 35, 20, 30, 2, 23, 35, 46, 3, 61, 1, 1, 170, 127, 20, 35, 48, 28, 182, 26, 41, 28, 14, 5, 129, 254, 252, 40, 83, 81, 78, 36, 36, 78, 93, 109, 67, 195, 0, 0, 0, 2, 0, 151, 3, 63, 3, 104, 5, 129, 0, 14, 0, 29, 0, 93, 64, 43, 6, 7, 14, 12, 151, 15, 14, 31, 14, 2, 14, 150, 175, 0, 1, 95, 0, 207, 0, 2, 112, 0, 1, 0, 21, 22, 29, 27, 151, 15, 29, 31, 29, 2, 29, 150, 95, 15, 1, 191, 15, 1, 15, 184, 255, 192, 64, 13, 9, 12, 72, 15, 29, 14, 158, 27, 12, 168, 21, 6, 3, 0, 63, 196, 253, 196, 253, 196, 1, 47, 43, 93, 113, 237, 93, 237, 16, 198, 50, 47, 93, 113, 114, 237, 93, 237, 16, 198, 50, 49, 48, 1, 53, 52, 62, 2, 55, 51, 14, 3, 21, 51, 17, 33, 53, 52, 62, 2, 55, 51, 14, 3, 21, 51, 17, 2, 67, 15, 29, 41, 26, 182, 28, 48, 35, 20, 127, 253, 51, 15, 28, 40, 25, 183, 28, 48, 35, 20, 127, 3, 63, 195, 67, 110, 92, 79, 35, 35, 78, 82, 82, 40, 254, 251, 195, 67, 110, 92, 79, 35, 35, 78, 82, 82, 40, 254, 251, 0, 0, 0, 0, 2, 0, 151, 3, 63, 3, 104, 5, 129, 0, 12, 0, 27, 0, 85, 64, 54, 5, 6, 11, 9, 151, 0, 11, 16, 11, 2, 12, 150, 80, 11, 1, 15, 11, 31, 11, 2, 11, 18, 19, 26, 24, 151, 0, 26, 16, 26, 2, 27, 150, 63, 26, 1, 127, 26, 1, 32, 26, 48, 26, 2, 26, 19, 6, 168, 25, 10, 158, 26, 11, 3, 0, 63, 196, 253, 196, 246, 196, 1, 47, 93, 93, 114, 253, 93, 237, 16, 198, 50, 47, 93, 113, 253, 93, 237, 16, 198, 50, 49, 48, 1, 20, 14, 2, 7, 35, 62, 1, 53, 35, 17, 33, 5, 20, 14, 2, 7, 35, 62, 3, 53, 35, 17, 33, 3, 104, 15, 28, 40, 26, 184, 57, 76, 127, 1, 31, 254, 82, 14, 28, 41, 26, 182, 28, 48, 35, 20, 127, 1, 31, 4, 193, 68, 111, 93, 78, 36, 72, 165, 81, 1, 4, 192, 68, 111, 93, 78, 36, 36, 78, 81, 83, 40, 1, 4, 0, 2, 0, 151, 254, 195, 3, 104, 1, 4, 0, 14, 0, 29, 0, 124, 64, 89, 5, 6, 12, 11, 151, 0, 12, 16, 12, 2, 0, 150, 47, 12, 79, 12, 2, 15, 12, 79, 12, 111, 12, 127, 12, 143, 12, 5, 15, 12, 31, 12, 111, 12, 143, 12, 175, 12, 5, 12, 20, 21, 27, 26, 151, 0, 27, 16, 27, 2, 15, 150, 15, 27, 1, 111, 27, 127, 27, 143, 27, 175, 27, 4, 27, 64, 43, 46, 72, 27, 64, 29, 32, 72, 32, 27, 48, 27, 2, 27, 28, 13, 158, 12, 21, 6, 168, 27, 12, 0, 47, 196, 246, 196, 16, 253, 196, 1, 47, 93, 43, 43, 93, 113, 253, 93, 237, 16, 198, 50, 47, 93, 113, 114, 253, 93, 237, 16, 198, 50, 49, 48, 37, 20, 14, 2, 7, 35, 62, 3, 53, 35, 17, 33, 5, 20, 14, 2, 7, 35, 62, 3, 53, 35, 17, 33, 3, 104, 15, 28, 40, 26, 184, 29, 48, 36, 20, 127, 1, 31, 254, 82, 14, 28, 41, 26, 182, 28, 48, 35, 20, 127, 1, 31, 66, 67, 110, 93, 78, 35, 35, 78, 82, 82, 40, 1, 4, 194, 67, 110, 93, 78, 35, 35, 78, 82, 82, 40, 1, 4, 0, 0, 0, 1, 0, 138, 255, 118, 3, 234, 5, 204, 0, 11, 0, 56, 64, 26, 6, 3, 9, 0, 4, 7, 10, 193, 8, 190, 5, 193, 48, 7, 64, 7, 2, 7, 7, 13, 12, 11, 4, 192, 10, 5, 184, 1, 22, 178, 7, 0, 1, 0, 47, 63, 246, 50, 237, 50, 17, 18, 1, 57, 47, 93, 230, 253, 230, 18, 23, 57, 49, 48, 1, 3, 35, 3, 5, 53, 5, 3, 33, 3, 37, 21, 2, 157, 22, 155, 22, 254, 180, 1, 76, 28, 0, 255, 28, 1, 77, 3, 192, 251, 182, 4, 74, 27, 204, 29, 1, 120, 254, 136, 29, 204, 0, 1, 0, 136, 255, 115, 3, 234, 5, 204, 0, 21, 0, 85, 64, 36, 3, 0, 20, 17, 6, 9, 11, 14, 8, 5, 4, 12, 7, 193, 15, 5, 191, 4, 19, 2, 193, 16, 48, 4, 64, 4, 2, 4, 4, 23, 22, 12, 19, 192, 13, 18, 184, 1, 22, 181, 16, 8, 1, 192, 7, 2, 184, 1, 22, 177, 4, 0, 0, 63, 246, 50, 237, 50, 47, 246, 50, 237, 50, 17, 18, 1, 57, 47, 93, 51, 246, 198, 16, 253, 50, 246, 196, 17, 18, 23, 57, 49, 48, 1, 5, 53, 5, 3, 51, 3, 37, 21, 37, 3, 19, 37, 21, 37, 19, 35, 19, 5, 53, 5, 19, 1, 222, 254, 171, 1, 85, 16, 215, 16, 1, 85, 254, 171, 26, 26, 1, 84, 254, 172, 16, 215, 16, 254, 170, 1, 86, 26, 3, 212, 27, 204, 29, 1, 100, 254, 156, 29, 204, 27, 254, 202, 254, 205, 27, 204, 29, 254, 156, 1, 100, 29, 204, 27, 1, 51, 0, 1, 0, 65, 1, 125, 2, 139, 3, 201, 0, 19, 0, 58, 185, 0, 18, 255, 232, 180, 9, 10, 0, 76, 2, 184, 255, 232, 64, 26, 9, 10, 0, 76, 12, 24, 9, 10, 0, 76, 8, 24, 9, 10, 0, 76, 10, 10, 15, 0, 1, 0, 21, 15, 15, 5, 0, 47, 51, 47, 1, 16, 206, 93, 50, 47, 49, 48, 43, 43, 43, 43, 1, 20, 14, 2, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 30, 2, 2, 139, 47, 80, 107, 61, 60, 106, 79, 46, 46, 79, 106, 60, 61, 107, 80, 47, 2, 164, 61, 107, 80, 47, 47, 80, 107, 61, 61, 107, 79, 46, 46, 79, 107, 0, 0, 3, 0, 225, 0, 0, 7, 24, 1, 49, 0, 3, 0, 7, 0, 11, 0, 72, 64, 42, 3, 150, 64, 0, 14, 4, 8, 4, 14, 11, 150, 8, 7, 150, 0, 4, 1, 32, 4, 1, 32, 4, 48, 4, 64, 4, 144, 4, 176, 4, 5, 4, 4, 12, 13, 9, 1, 5, 155, 8, 0, 4, 0, 47, 51, 51, 237, 50, 50, 17, 18, 1, 57, 47, 93, 113, 114, 237, 212, 237, 43, 1, 24, 16, 77, 244, 26, 237, 49, 48, 33, 17, 33, 17, 33, 17, 33, 17, 33, 17, 33, 17, 5, 248, 1, 32, 252, 88, 1, 30, 252, 83, 1, 32, 1, 49, 254, 207, 1, 49, 254, 207, 1, 49, 254, 207, 0, 0, 0, 7, 0, 41, 255, 253, 7, 215, 5, 139, 0, 3, 0, 23, 0, 43, 0, 63, 0, 83, 0, 103, 0, 123, 3, 205, 185, 0, 87, 255, 232, 64, 17, 9, 10, 0, 76, 101, 24, 9, 10, 0, 76, 97, 24, 9, 10, 0, 76, 91, 184, 255, 232, 180, 9, 10, 0, 76, 47, 184, 255, 232, 64, 17, 9, 10, 0, 76, 61, 24, 9, 10, 0, 76, 57, 24, 9, 10, 0, 76, 51, 184, 255, 232, 180, 9, 10, 0, 76, 11, 184, 255, 232, 64, 17, 9, 10, 0, 76, 21, 24, 9, 10, 0, 76, 17, 24, 9, 10, 0, 76, 7, 184, 255, 232, 64, 27, 9, 10, 0, 76, 74, 180, 80, 59, 96, 59, 2, 59, 64, 180, 9, 2, 1, 2, 3, 6, 0, 1, 10, 3, 0, 1, 1, 184, 255, 240, 64, 255, 3, 16, 49, 3, 1, 1, 3, 49, 3, 89, 19, 114, 180, 6, 99, 22, 99, 2, 99, 104, 180, 89, 64, 14, 25, 72, 89, 125, 24, 180, 9, 9, 1, 15, 9, 34, 180, 19, 217, 125, 1, 187, 125, 203, 125, 2, 153, 125, 1, 139, 125, 1, 114, 125, 1, 100, 125, 1, 86, 125, 1, 41, 125, 57, 125, 2, 27, 125, 1, 13, 125, 1, 249, 125, 1, 235, 125, 1, 210, 125, 1, 196, 125, 1, 150, 125, 182, 125, 2, 121, 125, 1, 107, 125, 1, 93, 125, 1, 73, 125, 1, 59, 125, 1, 34, 125, 1, 4, 125, 20, 125, 2, 200, 246, 125, 1, 217, 125, 1, 203, 125, 1, 189, 125, 1, 175, 125, 1, 155, 125, 1, 130, 125, 1, 100, 125, 116, 125, 2, 86, 125, 1, 41, 125, 1, 27, 125, 1, 13, 125, 1, 255, 125, 1, 235, 125, 1, 208, 125, 1, 194, 125, 1, 180, 125, 1, 166, 125, 1, 137, 125, 1, 123, 125, 1, 109, 125, 1, 79, 125, 95, 125, 2, 48, 125, 1, 34, 125, 1, 20, 125, 1, 6, 125, 1, 233, 125, 1, 203, 125, 219, 125, 2, 173, 125, 189, 125, 2, 148, 125, 1, 128, 125, 1, 114, 125, 1, 100, 125, 1, 86, 125, 1, 57, 125, 1, 27, 125, 43, 125, 2, 13, 125, 1, 152, 255, 125, 1, 230, 125, 1, 210, 125, 1, 196, 125, 1, 182, 125, 1, 137, 125, 153, 125, 2, 64, 255, 107, 125, 123, 125, 2, 93, 125, 1, 68, 125, 1, 54, 125, 1, 34, 125, 1, 20, 125, 1, 6, 125, 1, 217, 125, 1, 203, 125, 1, 189, 125, 1, 175, 125, 1, 150, 125, 1, 116, 125, 1, 86, 125, 102, 125, 2, 57, 125, 1, 43, 125, 1, 13, 125, 29, 125, 2, 244, 125, 1, 230, 125, 1, 194, 125, 1, 180, 125, 1, 166, 125, 1, 137, 125, 1, 123, 125, 1, 109, 125, 1, 84, 125, 1, 70, 125, 1, 20, 125, 1, 6, 125, 1, 104, 249, 125, 1, 235, 125, 1, 221, 125, 1, 207, 125, 1, 164, 125, 180, 125, 2, 150, 125, 1, 116, 125, 1, 102, 125, 1, 73, 125, 1, 59, 125, 1, 45, 125, 1, 18, 125, 1, 4, 125, 1, 246, 125, 1, 217, 125, 1, 203, 125, 1, 169, 125, 1, 139, 125, 155, 125, 2, 125, 125, 1, 84, 125, 100, 125, 2, 70, 125, 1, 41, 125, 1, 27, 125, 1, 233, 125, 249, 125, 2, 219, 125, 1, 194, 125, 1, 180, 125, 1, 166, 125, 1, 137, 125, 1, 123, 125, 1, 109, 125, 1, 73, 125, 1, 59, 125, 1, 34, 125, 1, 20, 125, 1, 6, 125, 1, 55, 246, 125, 1, 201, 125, 217, 125, 2, 187, 125, 1, 153, 125, 1, 139, 125, 1, 114, 125, 1, 100, 125, 1, 86, 125, 1, 41, 125, 57, 125, 2, 27, 125, 1, 13, 125, 1, 249, 125, 1, 235, 125, 1, 210, 64, 98, 125, 1, 196, 125, 1, 150, 125, 182, 125, 2, 121, 125, 1, 107, 125, 1, 93, 125, 1, 73, 125, 1, 59, 125, 1, 36, 125, 1, 6, 125, 22, 125, 2, 246, 125, 1, 217, 125, 1, 203, 125, 1, 169, 125, 1, 155, 125, 1, 141, 125, 1, 116, 125, 1, 86, 125, 102, 125, 2, 41, 125, 1, 27, 125, 1, 13, 125, 1, 7, 1, 69, 109, 44, 84, 79, 119, 54, 94, 39, 182, 14, 184, 29, 182, 4, 7, 2, 6, 109, 182, 84, 184, 119, 182, 94, 25, 1, 24, 0, 63, 63, 237, 244, 237, 63, 63, 237, 244, 237, 17, 51, 17, 51, 17, 51, 17, 51, 1, 95, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 47, 237, 212, 94, 93, 237, 16, 222, 43, 237, 212, 93, 237, 17, 18, 23, 57, 47, 47, 47, 56, 56, 17, 51, 95, 94, 93, 17, 51, 93, 237, 212, 93, 237, 49, 48, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 33, 35, 1, 51, 37, 50, 30, 2, 21, 20, 14, 2, 35, 34, 46, 2, 53, 52, 62, 2, 19, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 1, 50, 30, 2, 21, 20, 14, 2, 35, 34, 46, 2, 53, 52, 62, 2, 19, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 1, 50, 30, 2, 21, 20, 14, 2, 35, 34, 46, 2, 53, 52, 62, 2, 19, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 1, 126, 197, 3, 44, 199, 252, 159, 58, 104, 78, 45, 46, 78, 105, 60, 60, 104, 77, 45, 44, 78, 106, 171, 14, 27, 41, 27, 30, 43, 29, 13, 14, 28, 42, 29, 27, 42, 28, 14, 2, 105, 58, 104, 78, 45, 46, 78, 105, 60, 60, 104, 77, 45, 44, 78, 106, 171, 14, 27, 41, 27, 30, 44, 28, 14, 14, 28, 43, 29, 27, 42, 28, 14, 2, 44, 59, 103, 78, 45, 45, 79, 105, 60, 60, 104, 77, 45, 44, 78, 106, 171, 14, 27, 41, 27, 30, 43, 29, 13, 14, 28, 42, 29, 27, 42, 28, 14, 5, 129, 10, 33, 81, 138, 106, 100, 137, 85, 37, 37, 84, 137, 101, 106, 138, 81, 33, 254, 154, 69, 90, 53, 22, 22, 54, 90, 68, 67, 90, 54, 23, 23, 54, 90, 254, 232, 33, 81, 138, 106, 100, 137, 85, 37, 37, 84, 137, 101, 106, 138, 81, 33, 254, 154, 69, 90, 53, 22, 22, 54, 90, 68, 67, 90, 54, 23, 23, 54, 90, 1, 169, 33, 81, 138, 106, 100, 137, 85, 37, 37, 84, 137, 101, 106, 138, 81, 33, 254, 154, 69, 90, 53, 22, 22, 54, 90, 68, 67, 90, 54, 23, 23, 54, 90, 0, 0, 0, 0, 1, 0, 85, 3, 122, 1, 199, 5, 129, 0, 3, 0, 35, 64, 18, 3, 0, 3, 2, 150, 0, 1, 16, 1, 2, 1, 1, 4, 5, 0, 169, 1, 3, 0, 63, 237, 17, 18, 1, 57, 47, 93, 237, 51, 17, 51, 49, 48, 27, 1, 33, 3, 85, 64, 1, 50, 158, 3, 122, 2, 7, 253, 249, 255, 255, 0, 85, 3, 122, 3, 176, 5, 129, 16, 38, 2, 20, 0, 0, 17, 7, 2, 20, 1, 233, 0, 0, 0, 14, 185, 0, 1, 1, 233, 180, 4, 6, 0, 2, 37, 1, 43, 53, 0, 1, 0, 92, 0, 141, 2, 76, 3, 172, 0, 8, 0, 59, 64, 35, 3, 235, 4, 0, 235, 8, 236, 6, 235, 64, 31, 2, 1, 2, 64, 29, 32, 72, 32, 2, 48, 2, 160, 2, 3, 2, 3, 237, 2, 1, 0, 237, 32, 6, 239, 0, 25, 63, 26, 237, 51, 51, 237, 1, 24, 47, 93, 43, 113, 26, 237, 253, 237, 212, 237, 49, 48, 37, 1, 53, 1, 51, 21, 3, 1, 21, 1, 94, 254, 254, 1, 2, 236, 254, 1, 0, 141, 1, 105, 71, 1, 111, 37, 254, 146, 254, 151, 35, 0, 1, 0, 93, 0, 141, 2, 77, 3, 172, 0, 8, 0, 59, 64, 35, 2, 235, 6, 236, 0, 5, 235, 4, 8, 235, 64, 176, 0, 1, 32, 0, 48, 0, 64, 0, 96, 0, 112, 0, 5, 0, 8, 237, 7, 6, 5, 237, 32, 2, 239, 0, 25, 63, 26, 237, 51, 51, 237, 1, 24, 47, 93, 113, 26, 237, 212, 237, 16, 253, 237, 49, 48, 55, 53, 1, 3, 53, 51, 1, 21, 1, 93, 1, 0, 254, 238, 1, 0, 255, 0, 141, 35, 1, 105, 1, 110, 37, 254, 145, 71, 254, 151, 0, 255, 255, 0, 193, 0, 0, 4, 20, 5, 129, 16, 38, 0, 4, 0, 0, 17, 7, 0, 4, 2, 45, 0, 0, 0, 16, 177, 3, 2, 184, 2, 45, 180, 10, 11, 2, 3, 37, 1, 43, 53, 53, 0, 0, 0, 1, 255, 126, 5, 174, 3, 44, 6, 84, 0, 3, 0, 14, 180, 1, 0, 1, 185, 2, 0, 47, 237, 1, 47, 47, 49, 48, 1, 33, 53, 33, 3, 44, 252, 82, 3, 174, 5, 174, 166, 0, 0, 0, 0, 1, 254, 135, 0, 0, 2, 207, 5, 129, 0, 3, 0, 40, 64, 9, 2, 3, 16, 16, 3, 1, 3, 0, 1, 184, 255, 240, 64, 10, 15, 1, 31, 1, 2, 1, 2, 6, 0, 24, 0, 63, 63, 1, 47, 93, 56, 51, 47, 93, 56, 51, 49, 48, 43, 1, 1, 51, 176, 201, 3, 127, 201, 5, 129, 0, 0, 0, 0, 1, 0, 108, 2, 7, 2, 198, 4, 157, 0, 33, 0, 55, 185, 0, 31, 255, 208, 64, 12, 9, 10, 0, 76, 0, 224, 33, 35, 23, 10, 224, 11, 184, 255, 192, 64, 12, 9, 13, 72, 11, 17, 23, 17, 6, 228, 29, 11, 0, 0, 47, 50, 47, 237, 51, 51, 47, 1, 47, 43, 237, 50, 16, 222, 237, 49, 48, 43, 1, 17, 52, 46, 2, 35, 34, 6, 21, 17, 35, 17, 52, 46, 2, 53, 51, 30, 3, 21, 51, 62, 3, 51, 50, 22, 21, 17, 2, 19, 11, 25, 40, 30, 62, 73, 178, 1, 1, 2, 166, 1, 2, 3, 2, 3, 15, 38, 49, 64, 42, 110, 107, 2, 7, 1, 128, 44, 59, 36, 15, 96, 91, 254, 161, 1, 255, 20, 46, 40, 29, 4, 3, 27, 34, 35, 12, 28, 46, 32, 17, 108, 121, 254, 79, 0, 0, 0, 1, 0, 7, 0, 0, 4, 68, 5, 129, 0, 17, 0, 112, 64, 71, 3, 7, 3, 7, 9, 16, 19, 5, 1, 9, 90, 10, 12, 14, 12, 10, 8, 12, 95, 13, 5, 13, 4, 95, 1, 16, 1, 64, 1, 96, 1, 112, 1, 144, 1, 5, 31, 1, 79, 1, 2, 127, 1, 175, 1, 2, 31, 13, 47, 13, 63, 13, 127, 13, 4, 47, 13, 127, 13, 2, 13, 1, 13, 1, 9, 0, 95, 15, 3, 9, 18, 0, 63, 63, 237, 18, 57, 57, 47, 47, 93, 113, 93, 113, 114, 16, 237, 17, 51, 16, 237, 50, 1, 47, 51, 51, 47, 16, 237, 50, 50, 16, 206, 17, 57, 57, 47, 47, 49, 48, 1, 17, 33, 21, 33, 21, 33, 21, 33, 17, 33, 17, 35, 53, 51, 17, 33, 21, 1, 166, 2, 125, 253, 131, 1, 58, 254, 198, 254, 227, 130, 130, 3, 187, 4, 177, 254, 116, 208, 190, 149, 254, 254, 1, 2, 149, 3, 234, 208, 0, 0, 1, 0, 21, 0, 0, 4, 94, 5, 150, 0, 56, 0, 195, 64, 39, 3, 16, 9, 0, 77, 41, 23, 1, 23, 40, 9, 10, 0, 76, 45, 40, 40, 31, 46, 39, 43, 110, 20, 13, 16, 32, 110, 31, 41, 31, 1, 16, 31, 16, 31, 6, 56, 110, 0, 184, 255, 192, 64, 23, 38, 53, 72, 41, 0, 1, 0, 58, 19, 14, 6, 64, 38, 60, 72, 6, 64, 14, 31, 72, 6, 46, 14, 184, 1, 19, 180, 15, 43, 15, 42, 18, 184, 1, 19, 64, 35, 19, 39, 19, 143, 15, 175, 15, 2, 15, 19, 31, 19, 47, 19, 3, 15, 19, 15, 19, 52, 35, 117, 26, 32, 32, 26, 7, 7, 52, 116, 6, 64, 56, 1, 56, 184, 255, 192, 182, 18, 21, 72, 56, 56, 6, 24, 0, 63, 51, 47, 43, 93, 16, 237, 50, 63, 51, 47, 16, 237, 18, 57, 57, 47, 47, 93, 113, 17, 51, 16, 237, 50, 17, 51, 16, 237, 50, 1, 47, 43, 43, 214, 196, 16, 222, 93, 43, 237, 18, 57, 57, 47, 47, 93, 16, 237, 16, 197, 196, 253, 196, 196, 18, 57, 17, 51, 49, 48, 43, 93, 0, 43, 1, 14, 3, 35, 33, 53, 62, 3, 61, 1, 35, 53, 51, 53, 35, 53, 51, 53, 52, 62, 2, 51, 50, 30, 2, 23, 7, 46, 1, 35, 34, 6, 29, 1, 33, 21, 33, 21, 33, 21, 33, 21, 20, 14, 2, 7, 33, 50, 54, 55, 4, 94, 13, 60, 98, 134, 87, 253, 74, 39, 66, 46, 26, 188, 178, 178, 178, 48, 103, 161, 114, 96, 136, 95, 61, 19, 233, 21, 82, 66, 91, 80, 1, 30, 254, 226, 1, 30, 254, 226, 25, 46, 68, 43, 1, 124, 104, 107, 17, 1, 107, 73, 132, 99, 59, 205, 22, 49, 67, 93, 66, 6, 149, 112, 149, 104, 92, 151, 107, 58, 41, 76, 107, 67, 47, 77, 70, 115, 125, 81, 149, 112, 149, 4, 59, 90, 69, 53, 24, 99, 94, 0, 0, 0, 3, 0, 158, 255, 236, 8, 123, 5, 129, 0, 43, 0, 95, 0, 108, 3, 113, 182, 72, 40, 9, 10, 0, 76, 45, 184, 255, 216, 64, 82, 9, 10, 0, 76, 5, 40, 9, 10, 0, 76, 96, 72, 24, 33, 0, 0, 31, 35, 73, 6, 28, 6, 86, 73, 52, 71, 23, 24, 1, 40, 71, 1, 71, 64, 40, 45, 72, 71, 64, 18, 35, 72, 152, 6, 1, 6, 64, 21, 31, 72, 87, 6, 1, 40, 6, 56, 6, 2, 6, 24, 71, 77, 77, 71, 24, 6, 4, 17, 61, 73, 8, 44, 24, 44, 2, 9, 44, 110, 103, 16, 72, 17, 184, 255, 192, 64, 31, 9, 13, 72, 17, 182, 110, 198, 110, 2, 167, 110, 1, 150, 110, 1, 103, 110, 119, 110, 135, 110, 3, 84, 110, 1, 53, 110, 69, 110, 2, 110, 184, 255, 128, 64, 127, 212, 218, 72, 183, 110, 1, 166, 110, 1, 149, 110, 1, 134, 110, 1, 119, 110, 1, 70, 110, 86, 110, 102, 110, 3, 55, 110, 1, 37, 110, 1, 22, 110, 1, 5, 110, 1, 200, 244, 110, 1, 229, 110, 1, 214, 110, 1, 183, 110, 199, 110, 2, 166, 110, 1, 151, 110, 1, 133, 110, 1, 102, 110, 118, 110, 2, 55, 110, 71, 110, 87, 110, 3, 22, 110, 1, 7, 110, 1, 197, 110, 213, 110, 229, 110, 3, 180, 110, 1, 165, 110, 1, 147, 110, 1, 100, 110, 116, 110, 132, 110, 3, 85, 110, 1, 54, 110, 70, 110, 2, 21, 110, 37, 110, 2, 4, 110, 1, 229, 110, 245, 110, 2, 103, 110, 1, 110, 184, 255, 192, 64, 255, 162, 165, 72, 70, 110, 1, 23, 110, 39, 110, 55, 110, 3, 6, 110, 1, 152, 252, 110, 1, 237, 110, 1, 219, 110, 1, 202, 110, 1, 187, 110, 1, 170, 110, 1, 155, 110, 1, 141, 110, 1, 126, 110, 1, 108, 110, 1, 91, 110, 1, 76, 110, 1, 43, 110, 59, 110, 2, 28, 110, 1, 13, 110, 1, 235, 110, 251, 110, 2, 218, 110, 1, 201, 110, 1, 186, 110, 1, 171, 110, 1, 154, 110, 1, 139, 110, 1, 87, 110, 1, 57, 110, 1, 42, 110, 1, 27, 110, 1, 12, 110, 1, 200, 110, 216, 110, 248, 110, 3, 185, 110, 1, 170, 110, 1, 155, 110, 1, 88, 110, 104, 110, 136, 110, 3, 73, 110, 1, 58, 110, 1, 43, 110, 1, 7, 110, 1, 103, 233, 110, 1, 218, 110, 1, 203, 110, 1, 188, 110, 1, 104, 110, 152, 110, 2, 89, 110, 1, 74, 110, 1, 8, 110, 40, 110, 2, 249, 110, 1, 218, 110, 234, 110, 2, 203, 110, 1, 167, 110, 1, 137, 110, 1, 122, 110, 1, 107, 110, 1, 92, 110, 1, 0, 25, 110, 73, 110, 2, 11, 110, 1, 253, 110, 1, 239, 110, 1, 198, 110, 1, 169, 110, 1, 155, 110, 1, 141, 110, 1, 127, 110, 1, 84, 110, 1, 70, 110, 1, 57, 110, 1, 43, 110, 1, 29, 110, 1, 15, 110, 1, 55, 212, 110, 228, 110, 2, 198, 110, 1, 169, 110, 1, 155, 110, 1, 64, 103, 143, 110, 1, 116, 110, 1, 102, 110, 1, 41, 110, 57, 110, 2, 27, 110, 1, 0, 110, 1, 242, 110, 1, 230, 110, 1, 185, 110, 1, 171, 110, 1, 150, 110, 1, 130, 110, 1, 116, 110, 1, 102, 110, 1, 73, 110, 1, 61, 110, 1, 38, 110, 1, 20, 110, 1, 6, 110, 1, 185, 110, 201, 110, 233, 110, 3, 150, 110, 166, 110, 2, 137, 110, 1, 48, 110, 1, 34, 110, 1, 1, 16, 110, 1, 2, 0, 110, 1, 7, 15, 79, 103, 34, 7, 82, 28, 29, 29, 31, 28, 78, 78, 83, 184, 1, 15, 64, 15, 74, 103, 74, 28, 28, 74, 103, 3, 56, 102, 79, 18, 3, 40, 56, 184, 1, 15, 183, 47, 53, 53, 3, 47, 19, 17, 18, 0, 63, 63, 51, 51, 47, 16, 237, 50, 63, 237, 18, 23, 57, 47, 47, 47, 16, 237, 51, 47, 17, 51, 51, 47, 16, 237, 50, 16, 237, 1, 94, 93, 95, 93, 95, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 95, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 43, 93, 93, 113, 113, 113, 113, 113, 113, 113, 113, 113, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 114, 94, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 43, 113, 113, 113, 113, 113, 113, 47, 43, 237, 50, 16, 222, 94, 93, 237, 18, 23, 57, 47, 47, 47, 47, 93, 93, 43, 93, 43, 43, 93, 113, 16, 198, 237, 17, 51, 16, 237, 50, 50, 47, 51, 16, 237, 49, 48, 43, 43, 43, 37, 14, 1, 35, 34, 38, 53, 17, 35, 53, 14, 3, 43, 1, 17, 35, 17, 33, 50, 30, 2, 21, 20, 6, 7, 51, 55, 51, 21, 51, 21, 35, 17, 20, 30, 2, 51, 50, 54, 55, 37, 20, 6, 35, 34, 46, 2, 39, 55, 30, 1, 51, 50, 62, 2, 53, 52, 46, 2, 39, 46, 3, 53, 52, 54, 51, 50, 22, 23, 7, 46, 3, 35, 34, 6, 21, 20, 30, 2, 23, 30, 3, 1, 52, 46, 2, 43, 1, 17, 51, 50, 62, 2, 5, 147, 34, 65, 48, 125, 113, 104, 27, 81, 108, 133, 80, 110, 241, 1, 58, 131, 196, 130, 65, 16, 15, 86, 88, 125, 147, 147, 11, 22, 34, 24, 23, 32, 19, 2, 232, 194, 179, 83, 129, 94, 62, 16, 199, 15, 89, 79, 36, 61, 44, 24, 35, 62, 86, 52, 49, 97, 76, 47, 178, 171, 149, 176, 23, 201, 5, 27, 39, 48, 26, 69, 67, 32, 58, 79, 48, 48, 101, 81, 52, 250, 117, 37, 71, 104, 66, 75, 83, 67, 101, 68, 34, 8, 11, 13, 122, 123, 1, 162, 113, 48, 77, 56, 30, 253, 219, 5, 129, 61, 111, 157, 95, 47, 86, 39, 242, 242, 166, 254, 143, 37, 49, 28, 12, 7, 7, 75, 127, 134, 27, 60, 95, 68, 26, 61, 48, 6, 18, 32, 25, 27, 33, 22, 17, 11, 11, 33, 57, 86, 63, 115, 121, 127, 124, 17, 28, 38, 24, 10, 27, 36, 21, 27, 19, 16, 11, 10, 34, 59, 89, 2, 164, 67, 89, 54, 23, 254, 36, 25, 57, 93, 0, 0, 0, 1, 0, 10, 255, 236, 4, 79, 5, 150, 0, 61, 0, 179, 185, 0, 15, 255, 224, 64, 32, 10, 0, 77, 55, 46, 46, 51, 37, 110, 36, 36, 3, 110, 4, 63, 57, 45, 51, 111, 24, 14, 26, 15, 3, 0, 20, 32, 20, 2, 20, 57, 15, 184, 1, 19, 180, 16, 54, 16, 48, 24, 184, 1, 19, 64, 71, 25, 45, 25, 47, 25, 1, 15, 25, 31, 25, 47, 25, 207, 25, 239, 25, 5, 79, 16, 143, 16, 2, 207, 16, 239, 16, 2, 16, 25, 16, 25, 0, 40, 115, 31, 15, 37, 31, 37, 47, 37, 3, 37, 37, 31, 7, 0, 115, 9, 64, 3, 80, 3, 2, 0, 3, 16, 3, 32, 3, 64, 3, 160, 3, 240, 3, 6, 3, 3, 9, 25, 0, 63, 51, 47, 93, 113, 16, 237, 63, 51, 47, 93, 16, 237, 18, 57, 57, 47, 47, 93, 113, 93, 113, 17, 51, 16, 237, 50, 17, 51, 16, 237, 50, 1, 47, 93, 23, 51, 50, 237, 50, 50, 16, 222, 237, 51, 47, 237, 18, 57, 17, 51, 49, 48, 43, 37, 50, 54, 55, 5, 14, 3, 35, 34, 46, 2, 39, 35, 55, 51, 46, 1, 53, 52, 54, 55, 35, 55, 51, 62, 3, 51, 50, 30, 2, 23, 5, 46, 1, 35, 34, 14, 2, 7, 33, 7, 33, 14, 1, 21, 20, 22, 23, 33, 7, 33, 30, 3, 2, 146, 72, 86, 10, 1, 21, 13, 62, 108, 158, 108, 125, 183, 124, 70, 13, 129, 40, 77, 1, 1, 1, 1, 117, 40, 87, 15, 76, 127, 180, 119, 101, 152, 108, 65, 13, 254, 232, 10, 84, 74, 47, 74, 55, 35, 8, 1, 71, 29, 254, 209, 1, 1, 2, 1, 1, 84, 30, 254, 208, 6, 30, 55, 82, 199, 92, 82, 16, 80, 138, 101, 58, 78, 141, 195, 116, 149, 5, 30, 16, 17, 35, 4, 149, 123, 192, 132, 68, 55, 97, 131, 76, 16, 74, 82, 32, 71, 112, 81, 149, 11, 31, 14, 14, 25, 12, 149, 67, 114, 83, 47, 0, 0, 0, 4, 0, 54, 255, 240, 6, 223, 5, 145, 0, 33, 0, 53, 0, 57, 0, 77, 0, 230, 64, 13, 3, 24, 9, 10, 0, 76, 7, 24, 9, 10, 0, 76, 52, 184, 255, 232, 64, 17, 9, 10, 0, 76, 46, 24, 9, 10, 0, 76, 42, 24, 9, 10, 0, 76, 36, 184, 255, 232, 64, 14, 9, 10, 0, 76, 25, 56, 1, 56, 57, 22, 54, 1, 54, 55, 184, 255, 240, 64, 53, 57, 16, 0, 57, 1, 240, 57, 1, 16, 57, 1, 31, 55, 1, 55, 57, 55, 57, 5, 34, 68, 180, 44, 181, 58, 180, 95, 34, 111, 34, 127, 34, 3, 34, 79, 16, 28, 180, 15, 29, 181, 22, 180, 143, 5, 159, 5, 2, 5, 144, 28, 1, 28, 184, 255, 192, 64, 48, 36, 39, 72, 143, 28, 1, 96, 28, 1, 112, 28, 192, 28, 2, 79, 28, 1, 28, 28, 8, 25, 182, 0, 183, 10, 47, 16, 63, 16, 2, 16, 16, 19, 182, 10, 7, 56, 6, 63, 182, 49, 183, 73, 182, 39, 25, 54, 24, 0, 63, 63, 237, 244, 237, 63, 63, 237, 51, 47, 93, 16, 244, 237, 17, 51, 47, 93, 93, 113, 113, 43, 113, 1, 47, 93, 237, 244, 50, 237, 50, 16, 222, 93, 237, 244, 237, 17, 18, 57, 57, 47, 47, 93, 93, 113, 114, 56, 56, 51, 93, 17, 51, 93, 49, 48, 43, 43, 43, 43, 43, 43, 1, 34, 46, 2, 53, 52, 62, 2, 51, 50, 30, 2, 23, 7, 46, 1, 35, 34, 6, 21, 20, 22, 51, 50, 54, 55, 23, 14, 3, 5, 20, 14, 2, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 30, 2, 1, 35, 1, 51, 19, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 1, 163, 99, 139, 87, 40, 63, 102, 130, 67, 75, 113, 80, 47, 10, 188, 8, 66, 59, 85, 69, 70, 84, 60, 68, 8, 188, 7, 46, 81, 116, 4, 241, 56, 96, 129, 73, 75, 129, 95, 55, 55, 96, 131, 76, 72, 128, 95, 55, 251, 69, 206, 3, 152, 209, 73, 17, 34, 50, 34, 37, 53, 34, 17, 16, 35, 52, 36, 33, 51, 35, 18, 2, 13, 69, 121, 165, 96, 131, 173, 103, 42, 43, 74, 101, 58, 12, 63, 75, 143, 146, 151, 145, 77, 67, 10, 58, 109, 82, 50, 93, 125, 172, 105, 46, 46, 105, 172, 125, 132, 173, 103, 41, 41, 103, 173, 253, 204, 5, 129, 252, 47, 87, 114, 67, 27, 27, 68, 114, 86, 84, 111, 68, 28, 28, 67, 112, 0, 2, 0, 41, 255, 236, 3, 160, 5, 149, 0, 40, 0, 54, 0, 120, 64, 12, 17, 40, 9, 0, 77, 12, 40, 9, 10, 0, 76, 29, 184, 255, 232, 180, 9, 10, 0, 76, 25, 184, 255, 232, 64, 54, 9, 10, 0, 76, 3, 73, 4, 4, 38, 41, 73, 47, 32, 1, 32, 56, 50, 38, 70, 21, 17, 0, 14, 32, 14, 48, 14, 64, 14, 144, 14, 160, 14, 6, 14, 15, 37, 79, 50, 21, 50, 3, 50, 3, 50, 11, 44, 82, 27, 4, 0, 80, 11, 22, 0, 63, 237, 63, 237, 18, 57, 57, 47, 47, 17, 51, 16, 237, 50, 1, 47, 93, 51, 51, 237, 50, 16, 222, 93, 237, 18, 57, 47, 237, 49, 48, 0, 43, 43, 43, 1, 43, 37, 50, 54, 55, 51, 14, 5, 35, 34, 38, 61, 1, 6, 7, 53, 62, 1, 55, 3, 52, 62, 2, 51, 50, 30, 2, 21, 20, 14, 2, 7, 21, 20, 22, 19, 52, 38, 35, 34, 14, 2, 21, 17, 62, 3, 2, 70, 80, 85, 23, 146, 10, 31, 46, 63, 85, 110, 70, 169, 159, 64, 68, 33, 69, 31, 1, 37, 92, 155, 117, 83, 131, 92, 48, 65, 123, 176, 111, 68, 168, 54, 57, 34, 46, 26, 11, 54, 85, 58, 31, 195, 106, 107, 51, 103, 95, 83, 61, 35, 167, 163, 166, 25, 23, 195, 11, 25, 12, 1, 134, 68, 132, 104, 64, 39, 76, 110, 72, 98, 169, 139, 110, 38, 201, 96, 86, 3, 144, 69, 84, 24, 40, 54, 30, 254, 176, 22, 69, 86, 100, 0, 4, 0, 137, 0, 0, 8, 127, 5, 129, 0, 3, 0, 23, 0, 43, 0, 63, 0, 178, 185, 0, 42, 255, 232, 64, 17, 9, 10, 0, 76, 36, 24, 9, 10, 0, 76, 32, 24, 9, 10, 0, 76, 26, 184, 255, 232, 64, 11, 9, 10, 0, 76, 4, 24, 9, 17, 72, 4, 21, 184, 1, 32, 64, 20, 22, 54, 180, 34, 1, 34, 22, 34, 22, 34, 12, 44, 180, 2, 24, 65, 47, 65, 1, 14, 184, 255, 232, 180, 9, 17, 72, 14, 11, 184, 1, 32, 64, 37, 0, 12, 32, 12, 48, 12, 64, 12, 4, 12, 59, 182, 29, 49, 182, 39, 29, 39, 29, 39, 1, 13, 20, 15, 1, 27, 5, 1, 5, 15, 5, 15, 12, 21, 13, 3, 1, 184, 1, 33, 179, 4, 0, 12, 18, 0, 63, 51, 51, 228, 63, 51, 18, 57, 57, 47, 47, 93, 93, 17, 18, 57, 57, 47, 47, 16, 237, 16, 237, 1, 47, 93, 237, 50, 43, 93, 16, 222, 50, 237, 17, 57, 57, 47, 47, 17, 51, 16, 237, 16, 237, 50, 43, 49, 48, 43, 43, 43, 43, 33, 53, 33, 21, 33, 1, 22, 23, 30, 1, 21, 17, 35, 17, 33, 1, 38, 39, 46, 1, 53, 17, 51, 17, 1, 20, 14, 2, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 30, 2, 7, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 62, 2, 5, 244, 2, 123, 251, 160, 253, 90, 5, 4, 4, 5, 242, 1, 41, 2, 171, 5, 4, 4, 5, 242, 3, 66, 43, 85, 126, 84, 80, 123, 84, 43, 41, 83, 126, 84, 88, 127, 81, 38, 214, 15, 30, 44, 29, 29, 46, 32, 17, 17, 31, 43, 26, 30, 46, 32, 17, 166, 166, 4, 71, 46, 47, 40, 91, 40, 252, 193, 5, 129, 251, 176, 49, 50, 43, 99, 44, 3, 51, 250, 127, 2, 111, 77, 128, 92, 51, 51, 91, 128, 78, 75, 127, 92, 52, 52, 92, 127, 75, 56, 74, 45, 18, 19, 45, 74, 55, 57, 76, 46, 19, 19, 46, 76, 0, 2, 0, 125, 3, 0, 7, 4, 5, 129, 0, 42, 0, 50, 0, 118, 182, 15, 24, 9, 10, 0, 76, 3, 184, 255, 232, 64, 65, 9, 10, 0, 76, 9, 17, 3, 0, 197, 64, 1, 1, 18, 45, 50, 14, 44, 47, 45, 14, 47, 44, 196, 0, 45, 16, 45, 2, 45, 15, 18, 197, 111, 17, 1, 15, 17, 79, 17, 95, 17, 223, 17, 4, 17, 52, 1, 18, 31, 9, 4, 45, 209, 24, 37, 43, 3, 47, 202, 2, 15, 45, 3, 48, 3, 0, 63, 23, 51, 237, 23, 50, 63, 23, 51, 1, 16, 222, 93, 113, 237, 50, 47, 93, 237, 198, 43, 1, 24, 16, 77, 230, 17, 18, 57, 47, 26, 237, 50, 18, 57, 49, 48, 43, 43, 1, 35, 17, 51, 19, 30, 1, 23, 22, 23, 54, 55, 62, 1, 55, 19, 51, 17, 35, 17, 52, 54, 55, 54, 55, 6, 7, 14, 1, 7, 3, 35, 3, 46, 1, 39, 38, 39, 22, 23, 30, 1, 21, 37, 17, 35, 17, 35, 53, 33, 21, 4, 35, 166, 248, 139, 9, 23, 10, 11, 12, 12, 11, 10, 22, 9, 144, 243, 165, 2, 2, 2, 2, 16, 14, 12, 26, 8, 154, 131, 149, 8, 26, 13, 15, 15, 2, 2, 2, 1, 254, 1, 180, 243, 2, 162, 3, 0, 2, 129, 254, 211, 20, 55, 25, 29, 31, 31, 29, 25, 55, 20, 1, 45, 253, 127, 1, 84, 14, 56, 29, 34, 39, 39, 36, 31, 61, 17, 254, 184, 1, 72, 19, 61, 30, 35, 39, 41, 35, 30, 55, 11, 162, 254, 10, 1, 246, 139, 139, 0, 0, 1, 0, 85, 0, 0, 5, 208, 5, 150, 0, 57, 0, 113, 185, 0, 31, 255, 240, 64, 67, 10, 0, 77, 27, 16, 10, 0, 77, 48, 40, 10, 18, 32, 40, 1, 48, 40, 64, 40, 96, 40, 112, 40, 4, 63, 18, 79, 18, 2, 40, 18, 40, 18, 53, 24, 90, 5, 5, 16, 59, 34, 90, 53, 53, 48, 42, 1, 15, 42, 31, 42, 2, 42, 19, 19, 39, 39, 15, 42, 95, 18, 41, 18, 29, 95, 0, 4, 0, 63, 237, 63, 51, 237, 50, 50, 47, 51, 47, 1, 47, 93, 93, 50, 47, 237, 16, 206, 50, 47, 237, 18, 57, 57, 47, 47, 93, 93, 113, 17, 51, 17, 51, 49, 48, 43, 43, 1, 50, 30, 2, 21, 20, 14, 2, 7, 54, 55, 62, 1, 51, 33, 21, 33, 17, 62, 3, 53, 52, 46, 2, 35, 34, 14, 2, 21, 20, 30, 2, 23, 17, 33, 53, 33, 50, 22, 23, 22, 23, 46, 3, 53, 52, 62, 2, 3, 19, 156, 250, 174, 93, 47, 100, 155, 109, 30, 31, 26, 59, 25, 1, 12, 253, 139, 87, 118, 72, 32, 51, 97, 141, 91, 91, 141, 97, 51, 32, 74, 119, 88, 253, 132, 1, 14, 26, 61, 26, 31, 30, 111, 157, 101, 47, 93, 174, 250, 5, 150, 82, 156, 223, 141, 102, 177, 153, 128, 51, 3, 3, 2, 3, 228, 1, 53, 43, 101, 115, 132, 74, 101, 158, 108, 57, 57, 108, 158, 101, 74, 132, 115, 101, 43, 254, 203, 228, 3, 2, 3, 3, 51, 128, 153, 178, 102, 141, 223, 155, 82, 0, 0, 0, 2, 0, 88, 255, 222, 4, 124, 4, 72, 0, 34, 0, 47, 0, 66, 64, 18, 30, 30, 5, 35, 73, 17, 49, 47, 19, 73, 48, 5, 1, 5, 29, 29, 24, 18, 184, 1, 31, 179, 47, 47, 24, 41, 184, 1, 31, 178, 12, 16, 24, 184, 1, 31, 177, 0, 22, 0, 63, 237, 63, 237, 18, 57, 47, 237, 17, 57, 47, 1, 47, 93, 237, 50, 16, 222, 237, 18, 57, 47, 49, 48, 5, 34, 46, 2, 53, 52, 62, 4, 51, 50, 30, 2, 21, 33, 17, 30, 3, 51, 50, 62, 2, 55, 23, 14, 3, 19, 17, 46, 3, 35, 34, 14, 2, 7, 17, 2, 107, 130, 198, 134, 69, 44, 76, 102, 118, 128, 63, 113, 193, 142, 81, 252, 197, 22, 64, 78, 88, 46, 75, 116, 93, 77, 34, 72, 36, 83, 110, 143, 203, 19, 59, 76, 93, 53, 51, 87, 74, 60, 24, 34, 93, 157, 204, 111, 98, 160, 125, 93, 60, 29, 79, 146, 209, 131, 254, 156, 24, 45, 35, 20, 32, 60, 87, 55, 42, 57, 100, 76, 44, 2, 138, 1, 21, 20, 42, 34, 22, 19, 32, 42, 24, 254, 234, 0, 0, 0, 255, 255, 0, 114, 255, 248, 6, 72, 5, 134, 16, 38, 0, 121, 32, 0, 16, 39, 2, 26, 2, 188, 0, 0, 17, 7, 2, 150, 3, 207, 253, 76, 0, 32, 64, 18, 4, 3, 2, 20, 25, 1, 128, 12, 1, 32, 12, 1, 12, 0, 32, 0, 1, 0, 17, 93, 53, 17, 93, 93, 53, 0, 63, 53, 53, 53, 0, 0, 255, 255, 0, 84, 255, 248, 6, 72, 5, 146, 16, 39, 2, 26, 2, 168, 0, 0, 16, 39, 2, 150, 3, 207, 253, 76, 17, 6, 0, 115, 40, 0, 0, 28, 64, 16, 1, 3, 2, 9, 25, 0, 128, 0, 1, 64, 0, 1, 32, 0, 1, 0, 17, 93, 93, 93, 53, 0, 63, 53, 53, 53, 0, 0, 255, 255, 0, 103, 255, 248, 6, 72, 5, 129, 16, 39, 2, 26, 2, 168, 0, 0, 16, 39, 2, 150, 3, 207, 253, 76, 17, 6, 2, 148, 50, 0, 0, 28, 64, 16, 1, 3, 2, 9, 25, 0, 128, 0, 1, 64, 0, 1, 32, 0, 1, 0, 17, 93, 93, 93, 53, 0, 63, 53, 53, 53, 0, 0, 255, 255, 0, 163, 255, 248, 6, 72, 5, 129, 16, 39, 2, 26, 2, 148, 0, 0, 16, 39, 2, 150, 3, 207, 253, 76, 17, 6, 2, 149, 120, 0, 0, 44, 64, 27, 3, 2, 1, 9, 25, 0, 64, 0, 1, 32, 0, 1, 0, 4, 64, 82, 1, 32, 82, 1, 16, 82, 1, 0, 82, 1, 82, 17, 93, 93, 93, 93, 53, 17, 93, 93, 53, 0, 63, 53, 53, 53, 0, 0, 0, 1, 1, 162, 0, 100, 6, 94, 2, 68, 0, 17, 0, 24, 64, 9, 0, 15, 12, 3, 128, 16, 7, 17, 16, 0, 47, 205, 1, 47, 205, 26, 204, 50, 57, 57, 49, 48, 1, 30, 1, 23, 35, 46, 1, 39, 53, 62, 1, 55, 51, 14, 1, 7, 33, 21, 2, 129, 29, 59, 31, 72, 58, 130, 82, 82, 130, 58, 72, 31, 59, 29, 3, 221, 1, 41, 34, 98, 65, 68, 112, 42, 36, 42, 112, 68, 65, 98, 34, 86, 0, 0, 0, 1, 1, 16, 255, 195, 2, 240, 4, 127, 0, 17, 0, 26, 64, 10, 15, 64, 0, 0, 15, 12, 3, 17, 128, 7, 0, 47, 26, 205, 204, 50, 57, 57, 1, 47, 26, 205, 49, 48, 1, 14, 1, 7, 53, 62, 1, 55, 51, 30, 1, 23, 21, 46, 1, 39, 17, 35, 1, 213, 34, 98, 65, 68, 112, 42, 36, 42, 112, 68, 65, 98, 34, 86, 3, 160, 29, 59, 31, 72, 58, 130, 82, 82, 130, 58, 72, 31, 59, 29, 252, 35, 0, 1, 1, 162, 0, 100, 6, 94, 2, 68, 0, 17, 0, 24, 64, 9, 0, 15, 12, 3, 128, 7, 17, 16, 17, 0, 47, 205, 1, 47, 221, 26, 204, 50, 57, 57, 49, 48, 1, 46, 1, 39, 51, 30, 1, 23, 21, 14, 1, 7, 35, 62, 1, 55, 33, 53, 5, 127, 29, 59, 31, 72, 58, 130, 82, 82, 130, 58, 72, 31, 59, 29, 252, 35, 1, 127, 34, 98, 65, 68, 112, 42, 36, 42, 112, 68, 65, 98, 34, 86, 0, 0, 0, 1, 1, 16, 255, 195, 2, 240, 4, 127, 0, 17, 0, 26, 64, 10, 17, 64, 16, 15, 0, 3, 12, 128, 8, 16, 0, 47, 221, 26, 204, 50, 57, 57, 1, 47, 26, 205, 49, 48, 37, 62, 1, 55, 21, 14, 1, 7, 35, 46, 1, 39, 53, 30, 1, 23, 17, 51, 2, 43, 34, 98, 65, 68, 112, 42, 36, 42, 112, 68, 65, 98, 34, 86, 162, 29, 59, 31, 72, 58, 130, 82, 82, 130, 58, 72, 31, 59, 29, 3, 221, 0, 0, 1, 1, 162, 0, 100, 6, 94, 2, 68, 0, 31, 0, 36, 64, 15, 16, 31, 28, 19, 128, 23, 64, 15, 0, 3, 12, 128, 8, 0, 15, 0, 47, 205, 1, 47, 26, 204, 50, 57, 57, 26, 221, 26, 204, 50, 57, 57, 49, 48, 1, 30, 1, 23, 35, 46, 1, 39, 53, 62, 1, 55, 51, 14, 1, 7, 33, 46, 1, 39, 51, 30, 1, 23, 21, 14, 1, 7, 35, 62, 1, 55, 2, 129, 29, 59, 31, 72, 58, 130, 82, 82, 130, 58, 72, 31, 59, 29, 2, 254, 29, 59, 31, 72, 58, 130, 82, 82, 130, 58, 72, 31, 59, 29, 1, 41, 34, 98, 65, 68, 112, 42, 36, 42, 112, 68, 65, 98, 34, 34, 98, 65, 68, 112, 42, 36, 42, 112, 68, 65, 98, 34, 0, 0, 0, 1, 1, 16, 255, 195, 2, 240, 4, 127, 0, 31, 0, 38, 64, 16, 15, 64, 0, 31, 16, 19, 28, 128, 24, 64, 0, 15, 12, 3, 128, 7, 0, 47, 26, 204, 50, 57, 57, 26, 221, 26, 204, 50, 57, 57, 1, 47, 26, 205, 49, 48, 1, 14, 1, 7, 53, 62, 1, 55, 51, 30, 1, 23, 21, 46, 1, 39, 17, 62, 1, 55, 21, 14, 1, 7, 35, 46, 1, 39, 53, 30, 1, 23, 1, 213, 34, 98, 65, 68, 112, 42, 36, 42, 112, 68, 65, 98, 34, 34, 98, 65, 68, 112, 42, 36, 42, 112, 68, 65, 98, 34, 3, 160, 29, 59, 31, 72, 58, 130, 82, 82, 130, 58, 72, 31, 59, 29, 253, 2, 29, 59, 31, 72, 58, 130, 82, 82, 130, 58, 72, 31, 59, 29, 0, 2, 1, 16, 255, 72, 2, 240, 4, 127, 0, 3, 0, 35, 0, 40, 64, 17, 1, 19, 0, 4, 35, 20, 23, 32, 28, 3, 0, 28, 4, 19, 16, 7, 11, 0, 47, 204, 50, 57, 57, 221, 222, 205, 16, 204, 50, 57, 57, 1, 47, 51, 205, 50, 49, 48, 5, 33, 21, 33, 19, 14, 1, 7, 53, 62, 1, 55, 51, 30, 1, 23, 21, 46, 1, 39, 17, 62, 1, 55, 21, 14, 1, 7, 35, 46, 1, 39, 53, 30, 1, 23, 1, 16, 1, 224, 254, 32, 197, 34, 98, 65, 68, 112, 42, 36, 42, 112, 68, 65, 98, 34, 34, 98, 65, 68, 112, 42, 36, 42, 112, 68, 65, 98, 34, 104, 80, 4, 88, 29, 59, 31, 72, 58, 130, 82, 82, 130, 58, 72, 31, 59, 29, 253, 2, 29, 59, 31, 72, 58, 130, 82, 82, 130, 58, 72, 31, 59, 29, 0, 0, 2, 0, 53, 255, 231, 3, 177, 5, 188, 0, 45, 0, 67, 0, 97, 64, 14, 7, 43, 1, 12, 16, 10, 0, 77, 12, 24, 9, 0, 77, 8, 184, 255, 224, 64, 19, 10, 0, 77, 37, 37, 15, 46, 29, 70, 0, 64, 9, 25, 72, 0, 69, 58, 70, 15, 184, 255, 192, 64, 21, 20, 25, 72, 15, 51, 82, 25, 22, 22, 63, 41, 37, 37, 32, 79, 41, 0, 63, 79, 10, 22, 0, 63, 237, 63, 237, 51, 47, 17, 18, 57, 47, 51, 237, 1, 47, 43, 237, 16, 222, 43, 237, 50, 17, 57, 47, 49, 48, 43, 43, 43, 93, 1, 20, 14, 2, 7, 14, 3, 35, 34, 46, 2, 53, 52, 62, 4, 51, 50, 22, 23, 51, 54, 52, 53, 52, 38, 35, 34, 14, 2, 7, 55, 62, 1, 51, 50, 30, 2, 1, 46, 3, 35, 34, 14, 4, 21, 20, 30, 2, 51, 50, 62, 2, 3, 177, 6, 12, 17, 12, 28, 90, 125, 161, 101, 94, 130, 81, 35, 20, 44, 68, 96, 125, 78, 76, 122, 31, 4, 1, 106, 111, 25, 57, 55, 52, 20, 45, 39, 107, 66, 110, 151, 94, 41, 254, 252, 7, 29, 41, 50, 29, 41, 67, 53, 40, 25, 13, 17, 34, 50, 32, 51, 87, 67, 47, 3, 139, 49, 105, 106, 105, 48, 117, 191, 137, 74, 64, 109, 144, 79, 59, 136, 136, 126, 97, 58, 86, 76, 20, 44, 26, 173, 190, 10, 18, 25, 15, 205, 23, 34, 92, 154, 204, 254, 139, 36, 62, 45, 25, 43, 70, 92, 97, 96, 40, 46, 76, 54, 29, 81, 134, 170, 0, 2, 0, 43, 0, 0, 4, 185, 5, 129, 0, 5, 0, 18, 0, 173, 64, 11, 18, 16, 10, 0, 77, 18, 24, 9, 0, 77, 17, 184, 255, 240, 179, 10, 0, 77, 17, 184, 255, 232, 179, 9, 0, 77, 16, 184, 255, 240, 64, 43, 10, 0, 77, 6, 16, 10, 0, 77, 3, 2, 11, 11, 1, 18, 0, 4, 16, 4, 2, 11, 4, 20, 16, 20, 32, 20, 144, 20, 3, 48, 20, 80, 20, 128, 20, 160, 20, 208, 20, 240, 20, 6, 20, 184, 255, 192, 64, 55, 93, 96, 72, 79, 20, 1, 0, 20, 1, 57, 16, 20, 64, 20, 96, 20, 144, 20, 176, 20, 208, 20, 224, 20, 7, 15, 20, 1, 191, 20, 223, 20, 2, 0, 20, 32, 20, 80, 20, 112, 20, 144, 20, 160, 20, 6, 17, 1, 11, 2, 3, 17, 95, 0, 18, 0, 63, 237, 63, 57, 1, 47, 51, 93, 93, 113, 114, 94, 93, 93, 43, 113, 114, 16, 198, 94, 93, 50, 17, 57, 17, 51, 51, 49, 48, 43, 43, 43, 43, 43, 43, 51, 53, 1, 33, 1, 21, 1, 46, 3, 39, 14, 3, 7, 3, 33, 43, 1, 141, 1, 112, 1, 145, 254, 12, 14, 29, 24, 17, 1, 1, 16, 23, 27, 14, 207, 2, 68, 215, 4, 170, 251, 86, 215, 3, 152, 47, 97, 82, 57, 5, 5, 58, 83, 97, 45, 253, 79, 0, 0, 0, 1, 0, 204, 254, 57, 5, 202, 5, 129, 0, 7, 0, 36, 64, 19, 0, 90, 7, 9, 3, 90, 32, 4, 48, 4, 2, 4, 2, 96, 5, 3, 4, 4, 0, 0, 47, 50, 47, 63, 237, 1, 47, 93, 237, 16, 222, 237, 49, 48, 1, 17, 33, 17, 33, 17, 33, 17, 4, 176, 253, 67, 254, 217, 4, 254, 254, 57, 6, 84, 249, 172, 7, 72, 248, 184, 0, 1, 0, 134, 254, 57, 5, 68, 5, 129, 0, 11, 0, 138, 64, 41, 80, 2, 96, 2, 2, 2, 64, 26, 45, 72, 2, 91, 79, 8, 1, 8, 6, 8, 6, 0, 10, 13, 143, 7, 1, 7, 91, 3, 143, 9, 1, 9, 91, 3, 32, 0, 48, 0, 2, 0, 3, 184, 255, 232, 64, 50, 10, 17, 72, 3, 7, 95, 4, 8, 79, 2, 95, 2, 111, 2, 239, 2, 4, 47, 2, 63, 2, 79, 2, 191, 2, 223, 2, 255, 2, 6, 2, 2, 4, 3, 26, 1, 42, 1, 58, 1, 3, 1, 24, 14, 17, 72, 1, 9, 95, 0, 0, 47, 237, 57, 43, 93, 63, 57, 25, 47, 93, 113, 51, 24, 16, 237, 57, 43, 1, 47, 93, 196, 237, 114, 16, 237, 114, 16, 206, 17, 57, 57, 47, 47, 93, 237, 43, 114, 49, 48, 19, 53, 9, 1, 53, 33, 21, 33, 9, 1, 33, 21, 134, 2, 94, 253, 182, 4, 113, 253, 2, 2, 16, 253, 220, 3, 75, 254, 57, 160, 3, 8, 3, 8, 152, 227, 253, 71, 253, 56, 228, 0, 0, 0, 0, 1, 0, 85, 2, 57, 4, 88, 3, 25, 0, 3, 0, 22, 64, 10, 2, 5, 64, 1, 1, 1, 0, 173, 1, 178, 0, 63, 237, 1, 47, 93, 16, 206, 49, 48, 19, 53, 33, 21, 85, 4, 3, 2, 57, 224, 224, 0, 0, 1, 0, 2, 255, 231, 4, 106, 6, 84, 0, 8, 0, 169, 182, 1, 2, 5, 6, 1, 6, 5, 184, 1, 29, 64, 10, 2, 1, 20, 2, 2, 1, 0, 7, 6, 7, 184, 1, 29, 64, 20, 8, 0, 20, 8, 8, 0, 5, 2, 1, 0, 6, 6, 8, 2, 2, 3, 7, 8, 16, 8, 184, 255, 192, 64, 67, 10, 0, 77, 8, 3, 111, 10, 127, 10, 159, 10, 191, 10, 223, 10, 255, 10, 6, 15, 10, 47, 10, 95, 10, 127, 10, 159, 10, 191, 10, 6, 59, 176, 10, 208, 10, 240, 10, 3, 175, 10, 207, 10, 239, 10, 3, 112, 10, 144, 10, 2, 79, 10, 111, 10, 143, 10, 175, 10, 4, 2, 173, 5, 5, 7, 0, 25, 0, 63, 47, 57, 47, 237, 1, 93, 113, 113, 114, 94, 93, 113, 47, 47, 43, 56, 51, 18, 57, 47, 18, 57, 17, 51, 51, 17, 51, 135, 16, 43, 135, 125, 196, 135, 24, 16, 43, 16, 0, 193, 135, 5, 125, 16, 196, 49, 48, 5, 35, 1, 35, 53, 33, 19, 1, 51, 2, 112, 168, 254, 242, 184, 1, 55, 219, 1, 156, 186, 25, 2, 242, 166, 253, 133, 5, 80, 0, 3, 0, 72, 0, 216, 5, 109, 3, 196, 0, 35, 0, 51, 0, 69, 0, 117, 185, 0, 34, 255, 232, 64, 17, 9, 10, 0, 76, 20, 24, 9, 10, 0, 76, 16, 24, 9, 10, 0, 76, 2, 184, 255, 232, 183, 9, 10, 0, 76, 52, 39, 18, 47, 184, 1, 24, 178, 0, 71, 62, 184, 1, 24, 181, 31, 18, 1, 18, 36, 57, 184, 1, 25, 180, 31, 26, 23, 42, 67, 184, 1, 25, 64, 21, 8, 5, 47, 13, 63, 13, 79, 13, 3, 63, 13, 79, 13, 127, 13, 207, 13, 223, 13, 5, 13, 0, 47, 93, 113, 51, 51, 237, 50, 47, 51, 51, 237, 50, 1, 47, 93, 237, 16, 222, 237, 18, 57, 57, 49, 48, 43, 43, 43, 43, 1, 20, 14, 2, 35, 34, 38, 39, 14, 3, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 22, 23, 62, 3, 51, 50, 30, 2, 37, 34, 6, 7, 30, 1, 51, 50, 62, 2, 53, 52, 46, 2, 5, 46, 3, 35, 34, 14, 2, 21, 20, 30, 2, 51, 50, 54, 5, 109, 47, 86, 118, 72, 103, 168, 65, 28, 69, 83, 97, 56, 70, 120, 86, 49, 47, 86, 120, 72, 103, 165, 65, 27, 67, 80, 95, 55, 75, 124, 88, 48, 254, 165, 60, 106, 48, 44, 99, 70, 36, 59, 41, 22, 21, 40, 58, 254, 63, 22, 43, 48, 55, 35, 37, 61, 44, 24, 22, 42, 62, 41, 59, 96, 2, 71, 74, 133, 101, 59, 112, 127, 49, 84, 62, 34, 52, 96, 138, 85, 77, 134, 99, 57, 111, 128, 49, 84, 62, 35, 52, 97, 137, 113, 96, 101, 94, 102, 31, 53, 71, 41, 41, 72, 53, 31, 187, 47, 74, 51, 26, 31, 53, 72, 42, 39, 71, 54, 31, 95, 0, 0, 0, 0, 1, 1, 152, 0, 0, 6, 96, 4, 199, 0, 5, 0, 13, 179, 2, 5, 2, 5, 0, 47, 205, 1, 47, 205, 49, 48, 1, 51, 17, 33, 21, 33, 1, 152, 94, 4, 106, 251, 56, 4, 199, 251, 151, 94, 0, 0, 0, 0, 1, 1, 25, 255, 254, 4, 173, 4, 8, 0, 25, 0, 25, 64, 11, 25, 172, 0, 12, 172, 13, 13, 0, 19, 174, 6, 0, 47, 237, 47, 51, 1, 47, 237, 47, 237, 49, 48, 5, 17, 52, 62, 2, 51, 50, 30, 2, 21, 17, 35, 17, 52, 46, 2, 35, 34, 14, 2, 21, 17, 1, 25, 68, 122, 167, 98, 99, 169, 123, 70, 103, 53, 95, 130, 78, 78, 130, 94, 52, 2, 2, 0, 116, 192, 138, 76, 76, 138, 192, 116, 254, 0, 2, 2, 98, 155, 108, 57, 56, 108, 156, 100, 254, 0, 0, 0, 0, 0, 1, 255, 127, 254, 57, 2, 190, 5, 207, 0, 37, 0, 81, 185, 0, 35, 255, 232, 64, 33, 9, 10, 0, 76, 17, 24, 9, 10, 0, 76, 24, 24, 6, 6, 33, 70, 16, 14, 32, 14, 2, 0, 14, 32, 14, 48, 14, 192, 14, 208, 14, 5, 14, 184, 255, 192, 64, 14, 35, 38, 72, 14, 14, 39, 38, 27, 80, 20, 0, 9, 80, 0, 0, 47, 237, 63, 237, 17, 18, 1, 57, 47, 43, 93, 113, 237, 51, 47, 50, 47, 49, 48, 43, 43, 19, 34, 46, 2, 39, 53, 30, 1, 51, 50, 62, 2, 53, 17, 52, 62, 2, 51, 50, 22, 23, 21, 46, 1, 35, 34, 14, 2, 21, 17, 20, 14, 2, 26, 19, 43, 42, 37, 14, 21, 62, 36, 44, 60, 36, 15, 52, 101, 150, 99, 40, 87, 28, 20, 63, 36, 44, 60, 37, 16, 51, 101, 149, 254, 57, 3, 6, 7, 5, 217, 8, 17, 30, 53, 72, 42, 4, 127, 87, 141, 99, 54, 11, 8, 219, 10, 15, 31, 54, 71, 39, 251, 127, 87, 141, 99, 54, 0, 2, 0, 43, 1, 18, 4, 57, 4, 55, 0, 30, 0, 62, 0, 136, 64, 18, 33, 16, 10, 0, 77, 61, 48, 9, 10, 0, 76, 60, 48, 9, 10, 0, 76, 43, 184, 255, 192, 64, 34, 9, 10, 0, 76, 44, 48, 9, 10, 0, 76, 2, 16, 10, 0, 77, 27, 48, 9, 10, 0, 76, 28, 48, 9, 10, 0, 76, 29, 48, 9, 10, 0, 76, 11, 184, 255, 192, 64, 36, 9, 10, 0, 76, 12, 48, 9, 10, 0, 76, 58, 26, 64, 43, 11, 57, 37, 173, 46, 175, 54, 173, 42, 31, 25, 6, 173, 14, 175, 23, 173, 11, 63, 0, 1, 0, 0, 47, 93, 50, 237, 253, 237, 51, 47, 51, 237, 253, 237, 51, 1, 47, 196, 16, 222, 196, 49, 48, 43, 0, 43, 43, 43, 43, 43, 1, 43, 0, 43, 43, 43, 43, 1, 34, 38, 39, 38, 35, 34, 14, 2, 7, 53, 62, 1, 51, 50, 30, 2, 23, 30, 1, 51, 50, 54, 55, 21, 14, 3, 3, 34, 38, 39, 46, 1, 35, 34, 14, 2, 7, 53, 62, 1, 51, 50, 22, 23, 30, 3, 51, 50, 54, 55, 21, 14, 3, 3, 46, 75, 145, 75, 132, 89, 39, 67, 61, 58, 30, 51, 136, 84, 41, 82, 80, 78, 38, 45, 107, 48, 68, 128, 52, 32, 61, 63, 70, 41, 75, 145, 75, 66, 109, 46, 39, 67, 61, 58, 30, 51, 136, 84, 83, 160, 76, 22, 50, 52, 52, 24, 68, 128, 52, 32, 61, 63, 70, 2, 244, 41, 26, 47, 12, 22, 33, 21, 213, 39, 45, 13, 21, 26, 13, 16, 27, 50, 42, 219, 23, 31, 18, 8, 254, 30, 44, 26, 23, 22, 12, 23, 32, 21, 213, 38, 46, 46, 26, 7, 16, 14, 8, 50, 42, 219, 22, 31, 19, 8, 0, 0, 0, 0, 1, 0, 29, 0, 37, 4, 72, 5, 43, 0, 19, 0, 185, 185, 0, 16, 255, 248, 64, 46, 10, 0, 77, 13, 16, 17, 0, 4, 1, 12, 37, 1, 53, 1, 69, 1, 3, 1, 10, 7, 6, 3, 4, 2, 11, 42, 11, 58, 11, 74, 11, 3, 11, 12, 47, 2, 63, 2, 2, 2, 12, 2, 12, 4, 19, 14, 184, 255, 192, 64, 77, 37, 40, 72, 14, 21, 8, 63, 4, 1, 4, 64, 36, 40, 72, 4, 64, 14, 34, 72, 4, 16, 8, 173, 13, 48, 11, 1, 48, 11, 176, 11, 2, 11, 48, 9, 112, 9, 2, 32, 9, 64, 9, 96, 9, 112, 9, 160, 9, 192, 9, 6, 9, 17, 5, 173, 2, 0, 223, 4, 1, 15, 4, 31, 4, 63, 4, 79, 4, 143, 4, 5, 4, 64, 20, 25, 72, 4, 0, 47, 43, 93, 113, 51, 198, 237, 50, 47, 93, 113, 198, 93, 113, 51, 237, 50, 1, 47, 43, 43, 93, 51, 16, 206, 43, 50, 17, 57, 57, 47, 47, 93, 17, 51, 93, 17, 18, 23, 57, 50, 93, 17, 18, 23, 57, 49, 48, 43, 1, 7, 35, 55, 35, 53, 33, 19, 33, 53, 33, 19, 51, 3, 51, 21, 33, 3, 33, 21, 1, 205, 129, 213, 129, 219, 1, 71, 166, 254, 19, 2, 90, 133, 211, 131, 252, 254, 151, 166, 2, 15, 1, 35, 254, 254, 221, 1, 74, 223, 1, 2, 254, 254, 223, 254, 182, 221, 0, 0, 0, 0, 3, 0, 100, 0, 244, 4, 71, 4, 80, 0, 3, 0, 7, 0, 11, 0, 66, 64, 13, 11, 7, 2, 13, 8, 4, 32, 0, 64, 0, 2, 0, 8, 184, 1, 0, 179, 9, 9, 1, 5, 184, 1, 0, 180, 63, 4, 1, 4, 0, 184, 1, 0, 183, 15, 1, 31, 1, 63, 1, 3, 1, 0, 47, 93, 237, 47, 93, 237, 17, 57, 47, 237, 1, 47, 93, 51, 51, 16, 206, 50, 50, 49, 48, 19, 53, 33, 21, 1, 53, 33, 21, 1, 53, 33, 21, 100, 3, 227, 252, 29, 3, 227, 252, 29, 3, 227, 3, 188, 148, 148, 253, 56, 148, 148, 1, 100, 148, 148, 0, 0, 2, 0, 49, 0, 0, 4, 51, 5, 18, 0, 6, 0, 10, 0, 131, 64, 35, 0, 1, 82, 5, 4, 5, 176, 6, 0, 20, 6, 0, 5, 6, 1, 2, 1, 82, 3, 4, 1, 4, 3, 176, 2, 1, 20, 2, 1, 3, 2, 10, 10, 2, 6, 184, 255, 192, 64, 36, 37, 40, 72, 6, 12, 7, 7, 4, 0, 64, 36, 40, 72, 0, 64, 12, 20, 72, 0, 8, 173, 7, 1, 0, 4, 4, 2, 5, 6, 3, 48, 2, 64, 2, 2, 2, 0, 47, 93, 51, 47, 51, 18, 57, 61, 47, 51, 51, 24, 47, 237, 1, 47, 43, 43, 51, 51, 47, 16, 222, 43, 196, 51, 47, 16, 193, 135, 4, 43, 16, 1, 193, 135, 4, 43, 16, 196, 16, 1, 193, 135, 4, 24, 43, 135, 43, 196, 49, 48, 19, 17, 1, 21, 9, 1, 21, 1, 53, 33, 21, 49, 4, 2, 252, 192, 3, 64, 251, 254, 4, 0, 2, 119, 1, 65, 1, 90, 227, 254, 232, 254, 233, 227, 254, 227, 223, 223, 0, 0, 0, 0, 2, 0, 49, 0, 0, 4, 51, 5, 18, 0, 6, 0, 10, 0, 129, 64, 35, 6, 1, 82, 1, 2, 1, 176, 0, 6, 20, 0, 6, 1, 0, 5, 4, 1, 82, 3, 2, 5, 2, 3, 176, 4, 5, 20, 4, 5, 3, 4, 10, 10, 2, 6, 184, 255, 192, 64, 35, 37, 40, 72, 6, 12, 7, 7, 4, 0, 64, 36, 40, 72, 0, 64, 12, 20, 72, 0, 8, 173, 7, 6, 5, 2, 2, 3, 48, 4, 64, 4, 2, 4, 1, 0, 0, 47, 50, 47, 93, 51, 57, 61, 47, 51, 51, 24, 47, 237, 1, 47, 43, 43, 196, 51, 47, 16, 206, 43, 50, 50, 47, 16, 193, 135, 4, 43, 16, 1, 193, 135, 4, 43, 16, 196, 16, 1, 193, 135, 4, 24, 43, 135, 43, 196, 49, 48, 19, 53, 9, 1, 53, 1, 17, 1, 53, 33, 21, 49, 3, 63, 252, 193, 4, 2, 251, 254, 4, 2, 1, 29, 227, 1, 23, 1, 24, 227, 254, 166, 254, 191, 253, 137, 223, 223, 0, 0, 2, 0, 157, 0, 0, 4, 55, 4, 129, 0, 4, 0, 9, 0, 35, 64, 18, 105, 9, 121, 9, 2, 105, 7, 121, 7, 2, 6, 4, 5, 0, 2, 8, 5, 0, 0, 47, 205, 47, 205, 1, 47, 205, 221, 205, 49, 48, 0, 93, 93, 51, 17, 9, 1, 17, 37, 33, 17, 9, 1, 157, 1, 205, 1, 205, 252, 182, 2, 250, 254, 131, 254, 131, 2, 123, 2, 6, 253, 250, 253, 133, 82, 2, 6, 1, 170, 254, 86, 0, 0, 0, 0, 1, 0, 100, 0, 180, 4, 71, 2, 242, 0, 5, 0, 44, 64, 28, 32, 2, 1, 2, 5, 170, 32, 0, 80, 0, 2, 0, 4, 173, 15, 1, 63, 1, 95, 1, 143, 1, 4, 1, 63, 0, 1, 0, 0, 47, 93, 47, 93, 237, 1, 47, 93, 237, 47, 93, 49, 48, 55, 17, 33, 21, 33, 17, 100, 3, 227, 252, 174, 180, 2, 62, 146, 254, 84, 0, 0, 1, 2, 34, 253, 154, 3, 210, 6, 170, 0, 23, 0, 29, 182, 4, 32, 8, 11, 72, 9, 0, 184, 1, 0, 180, 1, 19, 12, 6, 1, 0, 47, 47, 205, 205, 1, 47, 237, 204, 49, 48, 43, 1, 35, 17, 52, 55, 54, 51, 50, 22, 21, 20, 6, 35, 34, 39, 46, 1, 39, 38, 35, 34, 7, 6, 21, 2, 181, 147, 84, 82, 128, 63, 75, 51, 37, 30, 13, 8, 26, 20, 33, 16, 36, 9, 6, 253, 154, 7, 86, 196, 123, 123, 63, 48, 40, 52, 10, 4, 24, 22, 39, 39, 35, 105, 0, 0, 0, 1, 1, 5, 253, 154, 2, 181, 6, 170, 0, 28, 0, 32, 185, 0, 4, 255, 224, 180, 8, 11, 72, 12, 2, 184, 1, 0, 180, 28, 24, 17, 7, 0, 0, 47, 47, 205, 205, 1, 47, 253, 204, 49, 48, 43, 1, 51, 17, 20, 7, 14, 1, 35, 34, 46, 2, 53, 52, 62, 2, 51, 50, 23, 30, 1, 23, 22, 51, 50, 55, 54, 53, 2, 34, 147, 90, 40, 103, 62, 30, 50, 37, 20, 14, 23, 31, 18, 33, 26, 5, 21, 15, 31, 16, 37, 8, 7, 6, 170, 248, 168, 205, 125, 56, 54, 16, 29, 39, 24, 20, 34, 24, 14, 16, 2, 23, 20, 37, 41, 31, 106, 0, 0, 0, 1, 255, 246, 2, 37, 5, 181, 2, 182, 0, 3, 0, 22, 180, 3, 5, 0, 4, 0, 184, 1, 2, 177, 1, 252, 0, 63, 237, 17, 1, 51, 17, 51, 49, 48, 3, 53, 33, 21, 10, 5, 191, 2, 37, 145, 145, 0, 0, 1, 1, 216, 253, 147, 2, 105, 7, 72, 0, 3, 0, 24, 187, 0, 2, 1, 0, 0, 3, 1, 6, 180, 4, 3, 254, 0, 250, 0, 63, 63, 1, 16, 246, 237, 49, 48, 1, 51, 17, 35, 1, 216, 145, 145, 7, 72, 246, 75, 0, 0, 0, 1, 2, 141, 253, 147, 5, 181, 2, 182, 0, 5, 0, 34, 178, 2, 7, 3, 186, 1, 0, 0, 0, 1, 6, 179, 6, 5, 254, 3, 184, 1, 2, 177, 0, 252, 0, 63, 237, 63, 1, 16, 246, 237, 17, 51, 49, 48, 1, 33, 21, 33, 17, 35, 2, 141, 3, 40, 253, 105, 145, 2, 182, 145, 251, 110, 0, 0, 0, 1, 255, 246, 253, 147, 3, 30, 2, 182, 0, 5, 0, 34, 187, 0, 2, 1, 0, 0, 5, 1, 6, 181, 6, 0, 6, 4, 254, 5, 184, 1, 2, 177, 2, 252, 0, 63, 237, 63, 17, 1, 51, 16, 246, 237, 49, 48, 3, 53, 33, 17, 35, 17, 10, 3, 40, 145, 2, 37, 145, 250, 221, 4, 146, 0, 0, 0, 0, 1, 2, 141, 2, 37, 5, 181, 7, 72, 0, 5, 0, 34, 178, 4, 7, 2, 189, 1, 0, 0, 5, 1, 6, 0, 6, 0, 5, 1, 2, 179, 2, 252, 0, 250, 0, 63, 63, 237, 1, 16, 246, 237, 17, 51, 49, 48, 1, 51, 17, 33, 21, 33, 2, 141, 145, 2, 151, 252, 216, 7, 72, 251, 110, 145, 0, 0, 0, 1, 255, 246, 2, 37, 3, 30, 7, 72, 0, 5, 0, 34, 187, 0, 5, 1, 0, 0, 2, 1, 6, 181, 6, 0, 6, 3, 250, 5, 184, 1, 2, 177, 2, 252, 0, 63, 237, 63, 17, 1, 51, 16, 244, 237, 49, 48, 3, 53, 33, 17, 51, 17, 10, 2, 151, 145, 2, 37, 145, 4, 146, 250, 221, 0, 0, 0, 0, 1, 2, 141, 253, 147, 5, 181, 7, 72, 0, 7, 0, 39, 179, 4, 9, 5, 1, 186, 1, 0, 0, 0, 1, 6, 179, 8, 7, 254, 5, 184, 1, 2, 179, 2, 252, 0, 250, 0, 63, 63, 237, 63, 1, 16, 246, 237, 50, 17, 51, 49, 48, 1, 51, 17, 33, 21, 33, 17, 35, 2, 141, 145, 2, 151, 253, 105, 145, 7, 72, 251, 110, 145, 251, 110, 0, 1, 255, 246, 253, 147, 3, 30, 7, 72, 0, 7, 0, 39, 177, 7, 4, 186, 1, 0, 0, 2, 1, 6, 183, 8, 0, 8, 6, 254, 3, 250, 7, 184, 1, 2, 177, 2, 252, 0, 63, 237, 63, 63, 17, 1, 51, 16, 244, 237, 51, 49, 48, 3, 53, 33, 17, 51, 17, 35, 17, 10, 2, 151, 145, 145, 2, 37, 145, 4, 146, 246, 75, 4, 146, 0, 0, 1, 255, 246, 253, 147, 5, 181, 2, 182, 0, 7, 0, 40, 178, 3, 9, 4, 186, 1, 0, 0, 7, 1, 6, 182, 8, 0, 8, 6, 254, 4, 0, 184, 1, 2, 177, 1, 252, 0, 63, 237, 50, 63, 17, 1, 51, 16, 246, 237, 17, 51, 49, 48, 3, 53, 33, 21, 33, 17, 35, 17, 10, 5, 191, 253, 105, 145, 2, 37, 145, 145, 251, 110, 4, 146, 0, 1, 255, 246, 2, 37, 5, 181, 7, 72, 0, 7, 0, 40, 178, 7, 9, 5, 186, 1, 0, 0, 2, 1, 6, 182, 8, 0, 8, 3, 250, 5, 0, 184, 1, 2, 177, 1, 252, 0, 63, 237, 51, 63, 17, 1, 51, 16, 244, 237, 17, 51, 49, 48, 3, 53, 33, 17, 51, 17, 33, 21, 10, 2, 151, 145, 2, 151, 2, 37, 145, 4, 146, 251, 110, 145, 0, 1, 255, 246, 253, 147, 5, 181, 7, 72, 0, 11, 0, 51, 179, 7, 13, 5, 8, 187, 1, 0, 0, 2, 0, 11, 1, 6, 64, 9, 12, 0, 12, 10, 254, 3, 250, 8, 11, 184, 1, 2, 178, 5, 2, 252, 0, 63, 51, 237, 50, 63, 63, 17, 1, 51, 16, 246, 50, 237, 50, 17, 51, 49, 48, 3, 53, 33, 17, 51, 17, 33, 21, 33, 17, 35, 17, 10, 2, 151, 145, 2, 151, 253, 105, 145, 2, 37, 145, 4, 146, 251, 110, 145, 251, 110, 4, 146, 0, 0, 0, 2, 255, 246, 1, 113, 5, 181, 3, 106, 0, 3, 0, 7, 0, 37, 183, 3, 7, 7, 9, 0, 4, 8, 4, 184, 1, 2, 178, 5, 253, 0, 184, 1, 2, 177, 1, 251, 0, 63, 237, 63, 237, 17, 1, 51, 50, 17, 51, 17, 51, 49, 48, 3, 53, 33, 21, 1, 53, 33, 21, 10, 5, 191, 250, 65, 5, 191, 2, 217, 145, 145, 254, 152, 145, 145, 0, 2, 1, 217, 253, 147, 3, 210, 7, 72, 0, 3, 0, 7, 0, 42, 65, 9, 0, 5, 1, 0, 0, 4, 1, 7, 0, 8, 0, 1, 1, 0, 0, 0, 1, 4, 182, 8, 7, 3, 254, 4, 0, 250, 0, 63, 50, 63, 51, 1, 16, 246, 237, 16, 244, 237, 49, 48, 1, 51, 17, 35, 1, 51, 17, 35, 1, 217, 145, 145, 1, 104, 145, 145, 7, 72, 246, 75, 9, 181, 246, 75, 0, 0, 0, 1, 2, 141, 253, 147, 5, 181, 3, 106, 0, 9, 0, 49, 181, 2, 6, 6, 11, 7, 3, 186, 1, 0, 0, 0, 1, 6, 179, 10, 9, 254, 7, 184, 1, 2, 178, 4, 253, 3, 184, 1, 2, 177, 0, 251, 0, 63, 237, 63, 237, 63, 1, 16, 246, 237, 50, 17, 51, 17, 51, 49, 48, 1, 33, 21, 33, 21, 33, 21, 33, 17, 35, 2, 141, 3, 40, 253, 105, 2, 151, 253, 105, 145, 3, 106, 145, 215, 145, 252, 34, 0, 0, 1, 1, 217, 253, 147, 5, 181, 2, 182, 0, 9, 0, 51, 178, 1, 11, 6, 191, 1, 0, 0, 9, 1, 4, 0, 10, 0, 2, 1, 0, 0, 5, 1, 7, 178, 10, 2, 6, 184, 1, 2, 180, 9, 252, 4, 8, 254, 0, 63, 51, 63, 237, 50, 1, 16, 244, 237, 16, 246, 237, 17, 51, 49, 48, 1, 21, 33, 17, 35, 17, 35, 17, 35, 17, 5, 181, 254, 29, 145, 215, 145, 2, 182, 145, 251, 110, 4, 146, 251, 110, 5, 35, 0, 0, 0, 0, 2, 1, 217, 253, 147, 5, 181, 3, 106, 0, 5, 0, 11, 0, 63, 180, 2, 8, 8, 13, 9, 65, 11, 1, 0, 0, 6, 1, 7, 0, 12, 0, 3, 1, 0, 0, 0, 1, 4, 0, 12, 0, 9, 1, 2, 181, 6, 253, 11, 5, 254, 3, 184, 1, 2, 177, 0, 251, 0, 63, 237, 63, 51, 63, 237, 1, 16, 246, 237, 16, 244, 237, 17, 51, 17, 51, 49, 48, 1, 33, 21, 33, 17, 35, 1, 33, 21, 33, 17, 35, 1, 217, 3, 220, 252, 181, 145, 1, 104, 2, 116, 254, 29, 145, 3, 106, 145, 250, 186, 4, 111, 145, 252, 34, 0, 0, 1, 255, 246, 253, 147, 3, 30, 3, 106, 0, 9, 0, 49, 177, 9, 6, 186, 1, 0, 0, 3, 1, 6, 183, 10, 4, 0, 0, 10, 8, 254, 3, 184, 1, 2, 178, 6, 251, 9, 184, 1, 2, 177, 2, 253, 0, 63, 237, 63, 237, 63, 17, 1, 51, 17, 51, 16, 244, 237, 51, 49, 48, 3, 53, 33, 53, 33, 53, 33, 17, 35, 17, 10, 2, 151, 253, 105, 3, 40, 145, 1, 113, 145, 215, 145, 250, 41, 3, 222, 0, 0, 0, 1, 255, 246, 253, 147, 3, 210, 2, 182, 0, 9, 0, 52, 65, 9, 0, 6, 1, 0, 0, 9, 1, 4, 0, 10, 0, 2, 1, 0, 0, 5, 1, 7, 183, 10, 0, 10, 4, 8, 254, 6, 0, 184, 1, 2, 177, 1, 252, 0, 63, 237, 50, 63, 51, 17, 1, 51, 16, 244, 237, 16, 246, 237, 49, 48, 3, 53, 33, 17, 35, 17, 35, 17, 35, 17, 10, 3, 220, 145, 215, 145, 2, 37, 145, 250, 221, 4, 146, 251, 110, 4, 146, 0, 0, 0, 0, 2, 255, 246, 253, 147, 3, 210, 3, 106, 0, 5, 0, 11, 0, 63, 180, 4, 9, 9, 12, 11, 65, 11, 1, 0, 0, 8, 1, 4, 0, 12, 0, 0, 1, 0, 0, 3, 1, 7, 0, 12, 0, 9, 1, 2, 181, 10, 253, 2, 7, 254, 4, 184, 1, 2, 177, 5, 251, 0, 63, 237, 63, 51, 63, 237, 1, 16, 244, 237, 16, 246, 237, 17, 51, 17, 51, 49, 48, 1, 17, 35, 17, 33, 53, 1, 35, 17, 33, 53, 33, 3, 210, 145, 252, 181, 2, 116, 145, 254, 29, 2, 116, 3, 106, 250, 41, 5, 70, 145, 250, 41, 3, 222, 145, 0, 0, 1, 2, 141, 1, 113, 5, 181, 7, 72, 0, 9, 0, 49, 181, 4, 8, 8, 11, 2, 6, 189, 1, 0, 0, 9, 1, 6, 0, 10, 0, 9, 1, 2, 178, 6, 253, 5, 184, 1, 2, 179, 2, 251, 0, 250, 0, 63, 63, 237, 63, 237, 1, 16, 246, 237, 50, 17, 51, 17, 51, 49, 48, 1, 51, 17, 33, 21, 33, 21, 33, 21, 33, 2, 141, 145, 2, 151, 253, 105, 2, 151, 252, 216, 7, 72, 252, 34, 145, 215, 145, 0, 0, 1, 1, 217, 2, 37, 5, 181, 7, 72, 0, 9, 0, 52, 178, 4, 11, 2, 65, 11, 1, 0, 0, 9, 1, 7, 0, 10, 0, 8, 1, 0, 0, 5, 1, 4, 0, 10, 0, 5, 1, 2, 181, 2, 8, 252, 0, 6, 250, 0, 63, 51, 63, 51, 237, 1, 16, 246, 237, 16, 244, 237, 17, 51, 49, 48, 1, 51, 17, 33, 21, 33, 17, 51, 17, 51, 3, 65, 145, 1, 227, 252, 36, 145, 215, 7, 72, 251, 110, 145, 5, 35, 251, 110, 0, 0, 0, 2, 1, 217, 1, 113, 5, 181, 7, 72, 0, 5, 0, 11, 0, 63, 180, 10, 4, 4, 13, 8, 65, 11, 1, 0, 0, 11, 1, 7, 0, 12, 0, 2, 1, 0, 0, 5, 1, 4, 0, 12, 0, 11, 1, 2, 178, 8, 251, 5, 184, 1, 2, 180, 2, 253, 6, 0, 250, 0, 63, 50, 63, 237, 63, 237, 1, 16, 246, 237, 16, 244, 237, 17, 51, 17, 51, 49, 48, 1, 51, 17, 33, 21, 33, 1, 51, 17, 33, 21, 33, 1, 217, 145, 3, 75, 252, 36, 1, 104, 145, 1, 227, 253, 140, 7, 72, 250, 186, 145, 5, 215, 252, 34, 145, 0, 0, 1, 255, 246, 1, 113, 3, 30, 7, 72, 0, 9, 0, 50, 188, 0, 9, 1, 0, 0, 6, 0, 2, 1, 6, 183, 10, 4, 0, 0, 10, 7, 250, 3, 184, 1, 2, 178, 6, 251, 9, 184, 1, 2, 177, 2, 253, 0, 63, 237, 63, 237, 63, 17, 1, 51, 17, 51, 16, 244, 50, 237, 49, 48, 3, 53, 33, 53, 33, 53, 33, 17, 51, 17, 10, 2, 151, 253, 105, 2, 151, 145, 1, 113, 145, 215, 145, 3, 222, 250, 41, 0, 0, 1, 255, 246, 2, 37, 3, 210, 7, 72, 0, 9, 0, 52, 65, 9, 0, 0, 1, 0, 0, 7, 1, 7, 0, 10, 0, 6, 1, 0, 0, 3, 1, 4, 183, 10, 1, 10, 8, 4, 250, 6, 1, 184, 1, 2, 177, 2, 252, 0, 63, 237, 51, 63, 51, 17, 1, 51, 16, 244, 237, 16, 244, 237, 49, 48, 1, 33, 53, 33, 17, 51, 17, 51, 17, 51, 3, 210, 252, 36, 1, 227, 145, 215, 145, 2, 37, 145, 4, 146, 251, 110, 4, 146, 0, 0, 0, 2, 255, 246, 1, 113, 3, 210, 7, 72, 0, 5, 0, 11, 0, 63, 65, 9, 0, 8, 1, 0, 0, 11, 1, 4, 0, 12, 0, 0, 1, 0, 0, 3, 1, 7, 181, 12, 9, 1, 1, 12, 9, 184, 1, 2, 181, 10, 251, 4, 6, 250, 1, 184, 1, 2, 177, 2, 253, 0, 63, 237, 63, 51, 63, 237, 17, 1, 51, 17, 51, 16, 244, 237, 16, 244, 237, 49, 48, 1, 33, 53, 33, 17, 51, 33, 51, 17, 33, 53, 33, 3, 210, 252, 36, 3, 75, 145, 254, 7, 145, 253, 140, 1, 227, 1, 113, 145, 5, 70, 251, 145, 145, 0, 0, 0, 0, 1, 2, 141, 253, 147, 5, 181, 7, 72, 0, 11, 0, 54, 182, 4, 8, 8, 13, 6, 2, 10, 186, 1, 0, 0, 11, 1, 6, 179, 12, 11, 254, 9, 184, 1, 2, 178, 6, 253, 5, 184, 1, 2, 179, 2, 251, 0, 250, 0, 63, 63, 237, 63, 237, 63, 1, 16, 246, 237, 50, 50, 17, 51, 17, 51, 49, 48, 1, 51, 17, 33, 21, 33, 21, 33, 21, 33, 17, 35, 2, 141, 145, 2, 151, 253, 105, 2, 151, 253, 105, 145, 7, 72, 252, 34, 145, 215, 145, 252, 34, 0, 0, 0, 0, 2, 1, 217, 253, 147, 5, 181, 7, 72, 0, 7, 0, 11, 0, 56, 178, 4, 13, 10, 186, 1, 0, 0, 11, 1, 4, 178, 12, 2, 6, 186, 1, 0, 0, 7, 1, 7, 183, 12, 7, 11, 254, 0, 8, 250, 5, 184, 1, 2, 177, 2, 252, 0, 63, 237, 63, 51, 63, 51, 1, 16, 244, 237, 50, 16, 246, 237, 17, 51, 49, 48, 1, 51, 17, 33, 21, 33, 17, 35, 1, 51, 17, 35, 3, 65, 145, 1, 227, 254, 29, 145, 254, 152, 145, 145, 7, 72, 251, 110, 145, 251, 110, 9, 181, 246, 75, 0, 0, 3, 1, 217, 253, 147, 5, 181, 7, 72, 0, 3, 0, 9, 0, 15, 0, 73, 181, 14, 6, 6, 17, 12, 8, 65, 12, 1, 0, 0, 15, 0, 9, 1, 7, 0, 16, 0, 0, 1, 0, 0, 1, 1, 4, 0, 16, 0, 15, 1, 2, 178, 12, 251, 7, 184, 1, 2, 183, 4, 253, 10, 2, 250, 9, 1, 254, 0, 63, 51, 63, 51, 63, 237, 63, 237, 1, 16, 246, 237, 16, 244, 50, 237, 50, 17, 51, 17, 51, 49, 48, 1, 35, 17, 51, 19, 33, 21, 33, 17, 35, 17, 51, 17, 33, 21, 33, 2, 106, 145, 145, 215, 2, 116, 254, 29, 145, 145, 1, 227, 253, 140, 253, 147, 9, 181, 250, 186, 145, 252, 34, 9, 181, 252, 34, 145, 0, 1, 255, 246, 253, 147, 3, 30, 7, 72, 0, 11, 0, 56, 185, 0, 9, 1, 0, 178, 6, 2, 10, 184, 1, 6, 64, 10, 12, 4, 0, 0, 12, 10, 254, 7, 250, 3, 184, 1, 2, 178, 6, 251, 11, 184, 1, 2, 177, 2, 253, 0, 63, 237, 63, 237, 63, 63, 17, 1, 51, 17, 51, 16, 246, 50, 50, 237, 49, 48, 3, 53, 33, 53, 33, 53, 33, 17, 51, 17, 35, 17, 10, 2, 151, 253, 105, 2, 151, 145, 145, 1, 113, 145, 215, 145, 3, 222, 246, 75, 3, 222, 0, 0, 0, 2, 255, 246, 253, 147, 3, 210, 7, 72, 0, 7, 0, 11, 0, 59, 65, 10, 0, 10, 1, 0, 0, 11, 1, 7, 0, 12, 0, 5, 1, 0, 0, 2, 0, 6, 1, 4, 64, 10, 12, 0, 12, 11, 6, 254, 8, 3, 250, 7, 184, 1, 2, 177, 2, 252, 0, 63, 237, 63, 51, 63, 51, 17, 1, 51, 16, 246, 50, 237, 16, 244, 237, 49, 48, 3, 53, 33, 17, 51, 17, 35, 17, 1, 51, 17, 35, 10, 1, 227, 145, 145, 1, 104, 145, 145, 2, 37, 145, 4, 146, 246, 75, 4, 146, 5, 35, 246, 75, 0, 0, 0, 0, 3, 255, 246, 253, 147, 3, 210, 7, 72, 0, 3, 0, 9, 0, 15, 0, 73, 181, 7, 13, 13, 16, 6, 10, 65, 12, 1, 0, 0, 9, 0, 11, 1, 4, 0, 16, 0, 2, 1, 0, 0, 3, 1, 7, 0, 16, 0, 12, 1, 2, 181, 15, 253, 3, 11, 254, 6, 184, 1, 2, 180, 9, 251, 0, 4, 250, 0, 63, 51, 63, 237, 63, 51, 63, 237, 1, 16, 244, 237, 16, 246, 50, 237, 50, 17, 51, 17, 51, 49, 48, 1, 51, 17, 35, 1, 51, 17, 33, 53, 33, 19, 35, 17, 33, 53, 33, 3, 65, 145, 145, 254, 152, 145, 253, 140, 1, 227, 145, 145, 254, 29, 2, 116, 7, 72, 246, 75, 9, 181, 251, 145, 145, 250, 41, 3, 222, 145, 0, 0, 0, 2, 255, 246, 253, 147, 5, 181, 3, 106, 0, 7, 0, 11, 0, 57, 180, 11, 3, 3, 13, 4, 186, 1, 0, 0, 7, 1, 6, 181, 12, 8, 0, 0, 12, 8, 184, 1, 2, 181, 9, 251, 6, 254, 4, 0, 184, 1, 2, 177, 1, 253, 0, 63, 237, 50, 63, 63, 237, 17, 1, 51, 17, 51, 16, 246, 237, 17, 51, 17, 51, 49, 48, 3, 53, 33, 21, 33, 17, 35, 17, 1, 53, 33, 21, 10, 5, 191, 253, 105, 145, 253, 105, 5, 191, 1, 113, 145, 145, 252, 34, 3, 222, 1, 104, 145, 145, 0, 0, 1, 255, 246, 253, 147, 5, 181, 2, 182, 0, 11, 0, 58, 178, 3, 13, 8, 191, 1, 0, 0, 11, 1, 4, 0, 12, 0, 4, 1, 0, 0, 7, 1, 7, 64, 9, 12, 0, 12, 6, 10, 254, 8, 4, 0, 184, 1, 2, 177, 1, 252, 0, 63, 237, 50, 50, 63, 51, 17, 1, 51, 16, 244, 237, 16, 246, 237, 17, 51, 49, 48, 3, 53, 33, 21, 33, 17, 35, 17, 35, 17, 35, 17, 10, 5, 191, 254, 29, 145, 215, 145, 2, 37, 145, 145, 251, 110, 4, 146, 251, 110, 4, 146, 0, 3, 255, 246, 253, 147, 5, 181, 3, 106, 0, 5, 0, 11, 0, 15, 0, 74, 180, 13, 8, 8, 17, 9, 186, 1, 0, 0, 6, 1, 7, 181, 16, 14, 3, 3, 16, 5, 189, 1, 0, 0, 2, 1, 4, 0, 16, 0, 14, 1, 2, 179, 15, 251, 9, 3, 184, 1, 2, 181, 6, 4, 253, 11, 1, 254, 0, 63, 51, 63, 51, 237, 50, 63, 237, 1, 16, 246, 237, 17, 51, 17, 51, 16, 244, 237, 17, 51, 17, 51, 49, 48, 1, 35, 17, 33, 53, 33, 51, 33, 21, 33, 17, 35, 1, 21, 33, 53, 2, 106, 145, 254, 29, 2, 116, 215, 2, 116, 254, 29, 145, 2, 116, 250, 65, 253, 147, 3, 222, 145, 145, 252, 34, 5, 215, 145, 145, 0, 0, 0, 0, 2, 255, 246, 1, 113, 5, 181, 7, 72, 0, 7, 0, 11, 0, 58, 64, 9, 7, 11, 11, 13, 0, 8, 8, 12, 5, 189, 1, 0, 0, 2, 1, 6, 0, 12, 0, 8, 1, 2, 181, 9, 253, 3, 250, 5, 0, 184, 1, 2, 177, 1, 251, 0, 63, 237, 51, 63, 63, 237, 1, 16, 244, 237, 17, 51, 17, 51, 17, 51, 17, 51, 49, 48, 3, 53, 33, 17, 51, 17, 33, 21, 1, 53, 33, 21, 10, 2, 151, 145, 2, 151, 250, 65, 5, 191, 2, 217, 145, 3, 222, 252, 34, 145, 254, 152, 145, 145, 0, 1, 255, 246, 2, 37, 5, 181, 7, 72, 0, 11, 0, 58, 178, 11, 13, 9, 191, 1, 0, 0, 6, 1, 7, 0, 12, 0, 5, 1, 0, 0, 2, 1, 4, 64, 9, 12, 0, 12, 7, 3, 250, 9, 5, 0, 184, 1, 2, 177, 1, 252, 0, 63, 237, 51, 51, 63, 51, 17, 1, 51, 16, 244, 237, 16, 244, 237, 17, 51, 49, 48, 3, 53, 33, 17, 51, 17, 51, 17, 51, 17, 33, 21, 10, 1, 227, 145, 215, 145, 1, 227, 2, 37, 145, 4, 146, 251, 110, 4, 146, 251, 110, 145, 0, 3, 255, 246, 1, 113, 5, 181, 7, 72, 0, 5, 0, 11, 0, 15, 0, 76, 64, 9, 4, 15, 15, 17, 9, 12, 12, 16, 8, 65, 11, 1, 0, 0, 11, 1, 4, 0, 16, 0, 2, 1, 0, 0, 5, 1, 7, 0, 16, 0, 12, 1, 2, 179, 13, 253, 5, 9, 184, 1, 2, 181, 2, 10, 251, 0, 6, 250, 0, 63, 51, 63, 51, 237, 50, 63, 237, 1, 16, 244, 237, 16, 244, 237, 17, 51, 17, 51, 17, 51, 17, 51, 49, 48, 1, 51, 17, 33, 21, 33, 1, 51, 17, 33, 53, 33, 1, 53, 33, 21, 3, 65, 145, 1, 227, 253, 140, 254, 152, 145, 253, 140, 1, 227, 254, 29, 5, 191, 7, 72, 252, 34, 145, 4, 111, 251, 145, 145, 254, 7, 145, 145, 0, 0, 0, 1, 255, 246, 253, 147, 5, 181, 7, 72, 0, 19, 0, 76, 182, 11, 15, 15, 21, 13, 9, 16, 184, 1, 0, 178, 6, 2, 19, 184, 1, 6, 64, 11, 20, 4, 0, 0, 20, 18, 254, 7, 250, 12, 4, 184, 1, 2, 180, 9, 5, 251, 16, 0, 184, 1, 2, 178, 13, 1, 253, 0, 63, 51, 237, 50, 63, 51, 237, 50, 63, 63, 17, 1, 51, 17, 51, 16, 246, 50, 50, 237, 50, 50, 17, 51, 17, 51, 49, 48, 3, 53, 33, 53, 33, 53, 33, 17, 51, 17, 33, 21, 33, 21, 33, 21, 33, 17, 35, 17, 10, 2, 151, 253, 105, 2, 151, 145, 2, 151, 253, 105, 2, 151, 253, 105, 145, 1, 113, 145, 215, 145, 3, 222, 252, 34, 145, 215, 145, 252, 34, 3, 222, 0, 0, 1, 255, 246, 253, 147, 5, 181, 7, 72, 0, 19, 0, 77, 179, 4, 21, 18, 9, 187, 1, 0, 0, 15, 0, 12, 1, 4, 178, 20, 2, 5, 187, 1, 0, 0, 19, 0, 8, 1, 7, 64, 9, 20, 13, 20, 0, 16, 250, 9, 5, 13, 184, 1, 2, 182, 18, 2, 14, 252, 7, 11, 254, 0, 63, 51, 63, 51, 51, 237, 50, 50, 63, 51, 17, 1, 51, 16, 244, 50, 237, 50, 16, 246, 50, 237, 50, 17, 51, 49, 48, 1, 51, 17, 33, 21, 33, 17, 35, 17, 35, 17, 35, 17, 33, 53, 33, 17, 51, 17, 51, 3, 65, 145, 1, 227, 254, 29, 145, 215, 145, 254, 29, 1, 227, 145, 215, 7, 72, 251, 110, 145, 251, 110, 4, 146, 251, 110, 4, 146, 145, 4, 146, 251, 110, 0, 0, 0, 0, 4, 255, 246, 253, 147, 5, 181, 7, 72, 0, 5, 0, 11, 0, 17, 0, 23, 0, 93, 181, 4, 14, 14, 25, 2, 15, 187, 1, 0, 0, 5, 0, 12, 1, 7, 182, 24, 21, 9, 9, 24, 20, 11, 187, 1, 0, 0, 23, 0, 8, 1, 4, 178, 24, 5, 21, 184, 1, 2, 183, 2, 22, 251, 0, 18, 250, 15, 9, 184, 1, 2, 181, 12, 10, 253, 17, 7, 254, 0, 63, 51, 63, 51, 237, 50, 63, 51, 63, 51, 237, 50, 1, 16, 246, 50, 237, 50, 17, 51, 17, 51, 16, 244, 50, 237, 50, 17, 51, 17, 51, 49, 48, 1, 51, 17, 33, 21, 33, 3, 35, 17, 33, 53, 33, 51, 33, 21, 33, 17, 35, 1, 51, 17, 33, 53, 33, 3, 65, 145, 1, 227, 253, 140, 215, 145, 254, 29, 2, 116, 215, 2, 116, 254, 29, 145, 254, 152, 145, 253, 140, 1, 227, 7, 72, 252, 34, 145, 250, 186, 3, 222, 145, 145, 252, 34, 9, 181, 251, 145, 145, 0, 0, 0, 0, 1, 0, 0, 2, 109, 5, 171, 7, 72, 0, 3, 0, 18, 182, 0, 5, 1, 4, 2, 250, 1, 0, 47, 63, 17, 1, 51, 17, 51, 49, 48, 1, 33, 17, 33, 5, 171, 250, 85, 5, 171, 2, 109, 4, 219, 0, 0, 0, 1, 0, 0, 253, 147, 5, 171, 2, 109, 0, 3, 0, 18, 182, 0, 5, 1, 4, 2, 1, 254, 0, 63, 47, 17, 1, 51, 17, 51, 49, 48, 1, 33, 17, 33, 5, 171, 250, 85, 5, 171, 253, 147, 4, 218, 0, 0, 0, 1, 0, 0, 253, 147, 5, 171, 7, 72, 0, 3, 0, 19, 183, 0, 5, 1, 4, 2, 250, 1, 254, 0, 63, 63, 17, 1, 51, 17, 51, 49, 48, 1, 33, 17, 33, 5, 171, 250, 85, 5, 171, 253, 147, 9, 181, 0, 0, 1, 0, 0, 253, 147, 2, 214, 7, 72, 0, 3, 0, 17, 182, 1, 4, 0, 2, 250, 1, 254, 0, 63, 63, 1, 47, 17, 51, 49, 48, 1, 33, 17, 33, 2, 214, 253, 42, 2, 214, 253, 147, 9, 181, 0, 0, 0, 0, 1, 2, 213, 253, 147, 5, 171, 7, 72, 0, 3, 0, 17, 182, 0, 5, 1, 2, 250, 1, 254, 0, 63, 63, 1, 47, 17, 51, 49, 48, 1, 33, 17, 33, 5, 171, 253, 42, 2, 214, 253, 147, 9, 181, 0, 0, 0, 0, 42, 0, 103, 253, 245, 5, 171, 6, 163, 0, 3, 0, 7, 0, 11, 0, 15, 0, 19, 0, 23, 0, 27, 0, 31, 0, 35, 0, 39, 0, 43, 0, 47, 0, 51, 0, 55, 0, 59, 0, 63, 0, 67, 0, 71, 0, 75, 0, 79, 0, 83, 0, 87, 0, 91, 0, 95, 0, 99, 0, 103, 0, 107, 0, 111, 0, 115, 0, 119, 0, 123, 0, 127, 0, 131, 0, 135, 0, 139, 0, 143, 0, 147, 0, 151, 0, 155, 0, 159, 0, 163, 0, 167, 2, 49, 181, 161, 157, 153, 149, 145, 165, 184, 1, 1, 182, 164, 109, 85, 69, 45, 13, 121, 184, 1, 1, 64, 13, 120, 108, 84, 68, 44, 12, 120, 101, 77, 53, 29, 5, 137, 184, 1, 1, 64, 13, 136, 100, 76, 52, 28, 4, 136, 113, 89, 65, 41, 17, 125, 184, 1, 1, 64, 13, 124, 112, 88, 64, 40, 16, 124, 97, 81, 57, 25, 9, 141, 184, 1, 1, 64, 13, 140, 96, 80, 56, 24, 8, 140, 117, 93, 61, 37, 21, 129, 184, 1, 1, 64, 33, 128, 116, 92, 60, 36, 20, 128, 120, 136, 124, 140, 128, 128, 140, 124, 136, 120, 5, 132, 160, 156, 152, 148, 144, 164, 164, 169, 105, 73, 49, 33, 1, 133, 184, 1, 1, 64, 15, 104, 72, 48, 32, 0, 10, 132, 1, 8, 3, 132, 167, 143, 139, 135, 184, 1, 3, 180, 132, 163, 103, 99, 107, 184, 1, 3, 183, 104, 160, 100, 96, 104, 95, 91, 87, 184, 1, 3, 183, 84, 92, 88, 84, 159, 83, 79, 75, 184, 1, 3, 183, 72, 156, 80, 76, 72, 67, 63, 71, 184, 1, 3, 183, 68, 64, 60, 68, 155, 59, 55, 51, 184, 1, 3, 183, 48, 152, 56, 52, 48, 43, 39, 47, 184, 1, 3, 183, 44, 40, 36, 44, 151, 31, 27, 35, 184, 1, 3, 183, 32, 148, 28, 24, 32, 23, 19, 15, 184, 1, 3, 183, 12, 20, 16, 12, 147, 11, 7, 3, 184, 1, 3, 183, 0, 144, 8, 4, 0, 131, 127, 123, 184, 1, 3, 64, 60, 120, 128, 124, 120, 22, 84, 1, 27, 72, 1, 25, 68, 1, 27, 48, 1, 27, 44, 1, 20, 32, 1, 104, 84, 72, 68, 48, 44, 32, 12, 0, 120, 120, 0, 12, 32, 44, 48, 68, 72, 84, 104, 10, 108, 164, 140, 136, 27, 132, 59, 132, 2, 15, 132, 1, 2, 132, 119, 115, 111, 184, 1, 3, 178, 116, 112, 108, 0, 47, 51, 51, 237, 50, 50, 47, 95, 93, 93, 51, 51, 51, 18, 23, 57, 47, 47, 47, 47, 47, 47, 47, 47, 47, 47, 93, 93, 93, 93, 93, 93, 17, 51, 51, 16, 237, 50, 50, 17, 51, 51, 51, 16, 237, 50, 50, 50, 17, 51, 51, 16, 237, 50, 50, 17, 51, 51, 51, 16, 237, 50, 50, 50, 17, 51, 51, 16, 237, 50, 50, 17, 51, 51, 51, 16, 237, 50, 50, 50, 17, 51, 51, 16, 237, 50, 50, 17, 51, 51, 51, 16, 237, 50, 50, 50, 17, 51, 51, 16, 237, 50, 50, 17, 51, 51, 51, 16, 237, 50, 50, 50, 16, 237, 50, 50, 50, 1, 47, 95, 94, 93, 51, 51, 51, 51, 51, 237, 50, 50, 50, 50, 50, 17, 51, 47, 51, 51, 51, 51, 51, 18, 23, 57, 47, 47, 47, 47, 47, 17, 51, 51, 51, 51, 51, 16, 237, 50, 50, 50, 50, 50, 17, 51, 51, 51, 51, 51, 16, 237, 50, 50, 50, 50, 50, 17, 51, 51, 51, 51, 51, 16, 237, 50, 50, 50, 50, 50, 17, 51, 51, 51, 51, 51, 16, 237, 50, 50, 50, 50, 50, 17, 51, 51, 51, 51, 51, 16, 237, 50, 50, 50, 50, 50, 16, 237, 50, 50, 50, 50, 50, 49, 48, 19, 51, 21, 35, 37, 51, 21, 35, 37, 51, 21, 35, 5, 51, 21, 35, 37, 51, 21, 35, 37, 51, 21, 35, 7, 51, 21, 35, 37, 51, 21, 35, 37, 51, 21, 35, 5, 51, 21, 35, 37, 51, 21, 35, 37, 51, 21, 35, 7, 51, 21, 35, 37, 51, 21, 35, 37, 51, 21, 35, 23, 51, 21, 35, 37, 51, 21, 35, 37, 51, 21, 35, 7, 51, 21, 35, 37, 51, 21, 35, 37, 51, 21, 35, 5, 51, 21, 35, 37, 51, 21, 35, 37, 51, 21, 35, 7, 51, 21, 35, 37, 51, 21, 35, 37, 51, 21, 35, 23, 51, 21, 35, 37, 51, 21, 35, 37, 51, 21, 35, 1, 51, 21, 35, 37, 51, 21, 35, 37, 51, 21, 35, 1, 51, 21, 35, 37, 51, 21, 35, 37, 51, 21, 35, 1, 51, 21, 35, 17, 51, 21, 35, 17, 51, 21, 35, 17, 51, 21, 35, 17, 51, 21, 35, 17, 51, 21, 35, 103, 104, 104, 1, 158, 104, 104, 1, 160, 103, 103, 253, 145, 104, 104, 1, 159, 104, 104, 1, 159, 104, 104, 207, 103, 103, 254, 96, 104, 104, 254, 98, 104, 104, 4, 13, 104, 104, 254, 97, 104, 104, 254, 97, 104, 104, 207, 104, 104, 1, 158, 104, 104, 1, 160, 103, 103, 207, 104, 104, 254, 97, 104, 104, 254, 97, 104, 104, 207, 104, 104, 1, 158, 104, 104, 1, 160, 103, 103, 253, 145, 104, 104, 1, 159, 104, 104, 1, 159, 104, 104, 207, 103, 103, 254, 96, 104, 104, 254, 98, 104, 104, 207, 104, 104, 1, 159, 104, 104, 1, 159, 104, 104, 252, 194, 104, 104, 1, 159, 104, 104, 1, 159, 104, 104, 251, 243, 104, 104, 1, 158, 104, 104, 1, 160, 103, 103, 1, 158, 104, 104, 104, 104, 104, 104, 104, 104, 104, 104, 104, 104, 5, 34, 98, 98, 98, 98, 98, 97, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 99, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 99, 96, 96, 96, 96, 96, 96, 97, 97, 97, 97, 97, 98, 94, 94, 94, 94, 94, 98, 97, 97, 97, 97, 97, 96, 96, 96, 96, 96, 96, 7, 237, 98, 98, 98, 98, 98, 1, 35, 96, 96, 96, 96, 96, 254, 223, 98, 254, 223, 96, 254, 221, 96, 254, 221, 97, 254, 222, 97, 7, 238, 96, 0, 0, 0, 0, 84, 0, 0, 253, 245, 5, 171, 6, 163, 0, 3, 0, 7, 0, 11, 0, 15, 0, 19, 0, 23, 0, 27, 0, 31, 0, 35, 0, 39, 0, 43, 0, 47, 0, 51, 0, 55, 0, 59, 0, 63, 0, 67, 0, 71, 0, 75, 0, 79, 0, 83, 0, 87, 0, 91, 0, 95, 0, 99, 0, 103, 0, 107, 0, 111, 0, 115, 0, 119, 0, 123, 0, 127, 0, 131, 0, 135, 0, 139, 0, 143, 0, 147, 0, 151, 0, 155, 0, 159, 0, 163, 0, 167, 0, 171, 0, 175, 0, 179, 0, 183, 0, 187, 0, 191, 0, 195, 0, 199, 0, 203, 0, 207, 0, 211, 0, 215, 0, 219, 0, 223, 0, 227, 0, 231, 0, 235, 0, 239, 0, 243, 0, 247, 0, 251, 0, 255, 1, 3, 1, 7, 1, 11, 1, 15, 1, 19, 1, 23, 1, 27, 1, 31, 1, 35, 1, 39, 1, 43, 1, 47, 1, 51, 1, 55, 1, 59, 1, 63, 1, 67, 1, 71, 1, 75, 1, 79, 0, 0, 19, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 5, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 5, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 5, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 5, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 5, 51, 21, 35, 37, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 37, 51, 21, 35, 5, 51, 21, 35, 39, 51, 21, 35, 39, 51, 21, 35, 39, 51, 21, 35, 39, 51, 21, 35, 39, 51, 21, 35, 7, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 23, 51, 21, 35, 39, 51, 21, 35, 39, 51, 21, 35, 39, 51, 21, 35, 39, 51, 21, 35, 39, 51, 21, 35, 7, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 1, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 1, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 55, 51, 21, 35, 19, 51, 21, 35, 7, 51, 21, 35, 23, 51, 21, 35, 7, 51, 21, 35, 23, 51, 21, 35, 7, 51, 21, 35, 23, 51, 21, 35, 7, 51, 21, 35, 23, 51, 21, 35, 7, 51, 21, 35, 17, 51, 21, 35, 19, 51, 21, 35, 103, 104, 104, 207, 104, 104, 207, 104, 104, 208, 104, 104, 208, 104, 104, 207, 104, 104, 251, 140, 103, 103, 207, 103, 103, 207, 103, 103, 207, 104, 104, 208, 104, 104, 208, 103, 103, 252, 90, 104, 104, 207, 104, 104, 207, 104, 104, 208, 104, 104, 208, 104, 104, 207, 104, 104, 251, 140, 103, 103, 207, 103, 103, 207, 103, 103, 207, 104, 104, 208, 104, 104, 208, 103, 103, 252, 90, 104, 104, 207, 104, 104, 207, 104, 104, 208, 104, 104, 208, 104, 104, 207, 104, 104, 251, 140, 103, 103, 1, 158, 103, 103, 207, 104, 104, 208, 104, 104, 208, 103, 103, 252, 194, 103, 103, 3, 165, 104, 104, 207, 104, 104, 208, 104, 104, 208, 104, 104, 207, 104, 104, 207, 104, 104, 103, 103, 103, 207, 103, 103, 207, 103, 103, 207, 104, 104, 208, 104, 104, 208, 103, 103, 103, 104, 104, 207, 104, 104, 208, 104, 104, 208, 104, 104, 207, 104, 104, 207, 104, 104, 103, 103, 103, 207, 103, 103, 207, 103, 103, 207, 104, 104, 208, 104, 104, 208, 103, 103, 251, 243, 103, 103, 207, 103, 103, 207, 103, 103, 207, 104, 104, 208, 104, 104, 208, 103, 103, 252, 90, 104, 104, 207, 104, 104, 207, 104, 104, 208, 104, 104, 208, 104, 104, 207, 104, 104, 207, 104, 104, 103, 103, 103, 103, 104, 104, 103, 103, 103, 103, 104, 104, 103, 103, 103, 103, 104, 104, 103, 103, 103, 103, 104, 104, 103, 103, 103, 103, 103, 103, 104, 104, 5, 34, 98, 98, 98, 98, 98, 98, 98, 98, 98, 98, 98, 97, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 99, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 99, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 97, 97, 97, 97, 97, 97, 97, 97, 97, 97, 97, 98, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 98, 97, 97, 97, 97, 97, 97, 97, 97, 97, 97, 97, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 7, 237, 98, 98, 98, 98, 98, 98, 98, 98, 98, 98, 98, 1, 35, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 254, 223, 98, 97, 96, 96, 96, 99, 96, 96, 96, 99, 96, 96, 97, 98, 94, 98, 97, 96, 96, 7, 237, 98, 1, 35, 96, 0, 0, 67, 0, 0, 253, 147, 5, 213, 6, 163, 0, 73, 0, 77, 0, 81, 0, 85, 0, 89, 0, 93, 0, 97, 0, 101, 0, 105, 0, 109, 0, 113, 0, 117, 0, 121, 0, 125, 0, 129, 0, 133, 0, 137, 0, 141, 0, 145, 0, 149, 0, 153, 0, 157, 0, 161, 0, 165, 0, 169, 0, 173, 0, 177, 0, 181, 0, 185, 0, 189, 0, 193, 0, 197, 0, 201, 0, 205, 0, 209, 0, 213, 0, 217, 0, 221, 0, 225, 0, 229, 0, 233, 0, 237, 0, 241, 0, 245, 0, 249, 0, 253, 1, 1, 1, 5, 1, 9, 1, 13, 1, 17, 1, 21, 1, 25, 1, 29, 1, 33, 1, 37, 1, 41, 1, 45, 1, 49, 1, 53, 1, 57, 1, 61, 1, 65, 1, 69, 1, 73, 1, 77, 1, 81, 0, 0, 1, 33, 17, 51, 53, 35, 17, 51, 53, 35, 17, 51, 53, 35, 17, 51, 53, 35, 17, 51, 53, 35, 17, 51, 53, 51, 21, 51, 53, 51, 21, 51, 53, 51, 21, 51, 53, 51, 21, 51, 53, 51, 21, 51, 53, 51, 21, 51, 53, 51, 21, 35, 21, 51, 17, 35, 21, 51, 17, 35, 21, 51, 17, 35, 21, 51, 17, 35, 21, 51, 17, 35, 21, 51, 1, 21, 51, 53, 51, 21, 51, 53, 51, 21, 51, 53, 51, 21, 51, 53, 23, 35, 21, 51, 39, 35, 21, 51, 39, 35, 21, 51, 39, 35, 21, 51, 7, 21, 51, 53, 51, 21, 51, 53, 51, 21, 51, 53, 51, 21, 51, 53, 5, 35, 21, 51, 55, 21, 51, 53, 51, 21, 51, 53, 51, 21, 51, 53, 5, 21, 51, 53, 33, 21, 51, 53, 7, 53, 35, 21, 37, 21, 51, 53, 19, 53, 35, 21, 35, 53, 35, 21, 35, 53, 35, 21, 35, 53, 35, 21, 7, 21, 51, 53, 51, 21, 51, 53, 51, 21, 51, 53, 51, 21, 51, 53, 19, 53, 35, 21, 35, 53, 35, 21, 35, 53, 35, 21, 35, 53, 35, 21, 7, 21, 51, 53, 51, 21, 51, 53, 51, 21, 51, 53, 51, 21, 51, 53, 19, 35, 21, 51, 39, 35, 21, 51, 39, 35, 21, 51, 39, 35, 21, 51, 1, 35, 21, 51, 39, 35, 21, 51, 39, 35, 21, 51, 39, 35, 21, 51, 1, 21, 51, 53, 51, 21, 51, 53, 23, 35, 21, 51, 39, 35, 21, 51, 7, 21, 51, 53, 51, 21, 51, 53, 7, 35, 21, 51, 55, 21, 51, 53, 5, 21, 51, 53, 23, 53, 35, 21, 23, 53, 35, 21, 35, 53, 35, 21, 7, 21, 51, 53, 51, 21, 51, 53, 19, 53, 35, 21, 35, 53, 35, 21, 7, 21, 51, 53, 51, 21, 51, 53, 19, 35, 21, 51, 39, 35, 21, 51, 19, 35, 21, 51, 39, 35, 21, 51, 5, 213, 250, 43, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 107, 106, 107, 106, 107, 107, 107, 107, 107, 106, 107, 106, 107, 107, 107, 107, 107, 107, 107, 107, 107, 107, 107, 107, 107, 250, 149, 107, 106, 107, 106, 107, 107, 107, 107, 107, 107, 214, 107, 107, 214, 106, 106, 213, 106, 106, 213, 107, 106, 107, 106, 107, 107, 107, 253, 234, 106, 106, 107, 106, 107, 107, 107, 107, 252, 170, 107, 1, 63, 107, 213, 107, 1, 171, 107, 107, 107, 107, 107, 107, 106, 107, 106, 107, 107, 106, 107, 106, 107, 107, 107, 107, 107, 107, 107, 107, 106, 107, 106, 107, 107, 106, 107, 106, 107, 107, 107, 107, 107, 107, 214, 107, 107, 214, 106, 106, 213, 106, 106, 2, 22, 107, 107, 214, 107, 107, 213, 107, 107, 213, 107, 107, 2, 235, 107, 106, 107, 106, 106, 106, 213, 106, 106, 213, 107, 106, 107, 107, 106, 106, 107, 106, 254, 86, 107, 213, 107, 213, 106, 107, 106, 107, 107, 106, 107, 106, 106, 107, 106, 107, 107, 106, 107, 106, 106, 106, 213, 106, 106, 107, 107, 107, 213, 107, 107, 253, 147, 1, 34, 97, 1, 34, 97, 1, 35, 96, 1, 33, 98, 1, 33, 98, 1, 33, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 193, 98, 254, 223, 96, 254, 221, 96, 254, 221, 96, 254, 221, 94, 254, 221, 96, 6, 106, 96, 96, 96, 96, 96, 96, 96, 96, 192, 98, 98, 98, 98, 98, 98, 98, 97, 96, 96, 96, 96, 96, 96, 96, 96, 192, 96, 96, 96, 96, 96, 96, 96, 96, 195, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 254, 223, 97, 97, 97, 97, 97, 97, 97, 97, 98, 94, 94, 94, 94, 94, 94, 94, 94, 254, 223, 97, 97, 97, 97, 97, 97, 97, 97, 96, 96, 96, 96, 96, 96, 96, 96, 96, 6, 205, 98, 98, 98, 98, 98, 98, 98, 1, 34, 98, 98, 98, 98, 98, 98, 98, 254, 223, 96, 96, 96, 96, 192, 98, 98, 98, 97, 96, 96, 96, 96, 192, 96, 96, 96, 96, 195, 96, 96, 96, 96, 96, 193, 97, 97, 97, 97, 98, 94, 94, 94, 94, 254, 223, 97, 97, 97, 97, 96, 96, 96, 96, 96, 6, 205, 98, 98, 98, 1, 34, 98, 98, 98, 0, 0, 0, 0, 1, 0, 123, 0, 117, 4, 90, 4, 84, 0, 3, 0, 0, 19, 33, 17, 33, 123, 3, 223, 252, 33, 4, 84, 252, 33, 0, 0, 2, 0, 6, 0, 0, 4, 207, 4, 201, 0, 3, 0, 7, 0, 21, 183, 7, 1, 4, 0, 4, 0, 5, 3, 0, 47, 205, 221, 205, 1, 47, 205, 221, 205, 49, 48, 19, 33, 17, 33, 19, 17, 33, 17, 6, 4, 201, 251, 55, 76, 4, 49, 4, 201, 251, 55, 4, 125, 251, 207, 4, 49, 0, 0, 1, 0, 109, 1, 127, 2, 105, 3, 123, 0, 3, 0, 26, 64, 13, 3, 48, 2, 1, 15, 2, 31, 2, 2, 8, 2, 1, 2, 0, 47, 205, 1, 47, 94, 93, 93, 205, 49, 48, 1, 33, 17, 33, 2, 105, 254, 4, 1, 252, 1, 127, 1, 252, 0, 0, 0, 2, 0, 109, 1, 127, 2, 105, 3, 123, 0, 3, 0, 7, 0, 34, 64, 17, 5, 3, 6, 48, 2, 1, 15, 2, 31, 2, 2, 8, 2, 7, 1, 6, 2, 0, 47, 205, 221, 205, 1, 47, 94, 93, 93, 205, 221, 205, 49, 48, 1, 33, 17, 33, 3, 17, 33, 17, 2, 105, 254, 4, 1, 252, 76, 254, 156, 1, 127, 1, 252, 254, 80, 1, 98, 254, 158, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 2, 104, 0, 3, 0, 0, 17, 33, 17, 33, 8, 0, 248, 0, 2, 104, 253, 152, 0, 0, 0, 1, 1, 158, 0, 0, 6, 76, 4, 174, 0, 2, 0, 0, 33, 9, 1, 1, 158, 2, 88, 2, 86, 4, 174, 251, 82, 0, 0, 1, 1, 145, 255, 229, 6, 90, 4, 172, 0, 2, 0, 0, 9, 2, 1, 145, 4, 201, 251, 55, 4, 172, 253, 158, 253, 155, 0, 1, 1, 158, 255, 229, 6, 76, 4, 147, 0, 2, 0, 0, 9, 2, 6, 76, 253, 170, 253, 168, 4, 147, 251, 82, 4, 174, 0, 1, 1, 145, 255, 229, 6, 90, 4, 172, 0, 2, 0, 0, 1, 17, 1, 6, 90, 251, 55, 4, 172, 251, 57, 2, 101, 0, 0, 2, 0, 3, 0, 0, 3, 244, 5, 166, 0, 5, 0, 9, 0, 92, 181, 8, 32, 9, 0, 77, 6, 184, 255, 224, 64, 16, 9, 0, 77, 1, 0, 8, 4, 3, 6, 8, 6, 8, 6, 2, 9, 5, 184, 255, 192, 64, 22, 9, 13, 72, 5, 11, 7, 31, 2, 1, 2, 2, 5, 9, 3, 7, 7, 1, 6, 3, 7, 8, 1, 0, 47, 51, 63, 51, 18, 57, 61, 47, 23, 51, 1, 24, 47, 93, 51, 16, 196, 43, 50, 17, 57, 57, 61, 47, 47, 17, 51, 51, 17, 51, 51, 49, 48, 0, 43, 43, 33, 35, 9, 1, 51, 9, 4, 2, 46, 104, 254, 61, 1, 195, 104, 1, 198, 254, 7, 254, 223, 1, 33, 1, 33, 2, 209, 2, 213, 253, 45, 1, 225, 254, 31, 254, 18, 1, 238, 0, 0, 2, 0, 167, 0, 162, 4, 46, 4, 41, 0, 19, 0, 39, 0, 46, 64, 28, 68, 37, 84, 37, 2, 75, 33, 91, 33, 2, 75, 27, 91, 27, 2, 68, 23, 84, 23, 2, 30, 10, 20, 0, 25, 15, 35, 5, 0, 47, 205, 220, 205, 1, 47, 205, 220, 205, 49, 48, 93, 93, 93, 93, 19, 52, 62, 2, 51, 50, 30, 2, 21, 20, 14, 2, 35, 34, 46, 2, 55, 20, 30, 2, 51, 50, 62, 2, 53, 52, 46, 2, 35, 34, 14, 2, 167, 70, 122, 164, 94, 94, 165, 123, 71, 71, 123, 165, 94, 94, 164, 122, 70, 86, 57, 98, 133, 76, 76, 134, 99, 58, 58, 99, 134, 76, 76, 133, 98, 57, 2, 100, 94, 165, 123, 71, 71, 123, 165, 94, 94, 164, 122, 70, 70, 122, 164, 94, 76, 132, 99, 57, 57, 99, 132, 76, 76, 134, 99, 58, 58, 99, 134, 0, 0, 0, 0, 1, 0, 178, 0, 137, 4, 35, 3, 250, 0, 23, 0, 17, 182, 8, 16, 12, 15, 0, 1, 0, 0, 47, 93, 205, 1, 47, 205, 49, 48, 1, 50, 23, 30, 1, 23, 30, 1, 21, 20, 7, 6, 35, 34, 39, 38, 53, 52, 54, 55, 62, 1, 55, 54, 2, 106, 110, 107, 53, 82, 29, 29, 31, 129, 129, 183, 182, 129, 129, 30, 29, 29, 83, 52, 108, 3, 250, 57, 28, 82, 52, 54, 110, 57, 183, 129, 129, 129, 129, 183, 58, 109, 54, 52, 82, 28, 57, 0, 0, 0, 2, 0, 41, 0, 0, 4, 172, 4, 131, 0, 3, 0, 23, 0, 21, 183, 14, 2, 4, 1, 19, 1, 9, 0, 0, 47, 205, 221, 205, 1, 47, 205, 221, 205, 49, 48, 51, 17, 33, 17, 1, 20, 30, 2, 51, 50, 62, 2, 53, 52, 46, 2, 35, 34, 14, 2, 41, 4, 131, 252, 4, 69, 120, 160, 91, 91, 161, 120, 69, 69, 120, 161, 91, 91, 160, 120, 69, 4, 131, 251, 125, 2, 65, 91, 160, 120, 69, 69, 120, 160, 91, 91, 161, 120, 69, 69, 120, 161, 0, 0, 3, 0, 41, 0, 0, 4, 172, 4, 131, 0, 3, 0, 23, 0, 43, 0, 34, 64, 14, 4, 24, 1, 14, 34, 2, 1, 19, 29, 0, 9, 39, 1, 0, 0, 47, 221, 221, 206, 16, 221, 206, 1, 47, 221, 221, 206, 16, 221, 206, 49, 48, 51, 17, 33, 17, 1, 52, 62, 2, 51, 50, 30, 2, 21, 20, 14, 2, 35, 34, 46, 2, 39, 20, 30, 2, 51, 50, 62, 2, 53, 52, 46, 2, 35, 34, 14, 2, 41, 4, 131, 252, 81, 58, 99, 133, 75, 75, 133, 99, 58, 58, 99, 133, 75, 75, 133, 99, 58, 77, 69, 120, 160, 91, 91, 161, 120, 69, 69, 120, 161, 91, 91, 160, 120, 69, 4, 131, 251, 125, 2, 65, 75, 133, 99, 58, 58, 99, 133, 75, 75, 133, 99, 58, 58, 99, 133, 75, 91, 160, 120, 69, 69, 120, 160, 91, 91, 161, 120, 69, 69, 120, 161, 0, 0, 2, 0, 115, 1, 133, 2, 99, 3, 117, 0, 18, 0, 34, 0, 21, 183, 19, 0, 27, 11, 31, 6, 23, 15, 0, 47, 205, 220, 205, 1, 47, 205, 220, 205, 49, 48, 1, 20, 6, 7, 14, 1, 35, 34, 39, 46, 1, 53, 52, 55, 54, 51, 50, 23, 22, 7, 52, 39, 38, 35, 34, 7, 6, 21, 20, 23, 22, 51, 50, 55, 54, 2, 99, 37, 37, 37, 86, 51, 101, 75, 35, 37, 72, 74, 102, 103, 71, 74, 76, 51, 51, 70, 70, 51, 51, 51, 49, 72, 72, 49, 51, 2, 125, 53, 86, 37, 35, 37, 72, 37, 86, 53, 102, 72, 74, 74, 71, 103, 70, 51, 51, 51, 51, 70, 69, 54, 49, 49, 54, 0, 0, 0, 5, 1, 177, 255, 229, 6, 121, 4, 172, 0, 17, 0, 33, 0, 45, 0, 57, 0, 68, 0, 147, 64, 93, 20, 32, 36, 32, 116, 32, 3, 20, 28, 36, 28, 116, 28, 3, 27, 24, 43, 24, 123, 24, 3, 27, 20, 43, 20, 123, 20, 3, 68, 34, 40, 63, 52, 46, 40, 46, 40, 46, 8, 18, 31, 0, 1, 0, 26, 8, 49, 37, 43, 55, 43, 62, 58, 104, 58, 1, 89, 58, 1, 71, 58, 1, 25, 58, 1, 58, 60, 65, 15, 43, 95, 43, 111, 43, 3, 8, 65, 64, 9, 14, 72, 43, 65, 43, 65, 4, 22, 15, 13, 1, 13, 30, 4, 0, 47, 205, 220, 93, 205, 18, 57, 57, 47, 47, 43, 94, 93, 16, 205, 51, 93, 93, 93, 93, 17, 51, 17, 51, 16, 205, 50, 1, 47, 205, 220, 93, 205, 18, 57, 57, 47, 47, 16, 205, 51, 16, 205, 51, 49, 48, 0, 93, 93, 93, 93, 1, 20, 7, 6, 35, 34, 39, 38, 53, 52, 54, 55, 54, 51, 50, 23, 30, 1, 7, 52, 39, 38, 35, 34, 7, 6, 21, 20, 23, 22, 51, 50, 55, 54, 1, 20, 6, 35, 34, 38, 53, 52, 54, 51, 50, 22, 5, 20, 6, 35, 34, 38, 53, 52, 54, 51, 50, 22, 1, 22, 51, 50, 55, 23, 6, 35, 34, 38, 39, 6, 121, 180, 179, 253, 253, 179, 180, 90, 90, 178, 254, 254, 178, 90, 90, 90, 153, 151, 218, 218, 151, 153, 153, 152, 217, 217, 152, 153, 253, 90, 46, 32, 32, 45, 45, 32, 32, 46, 1, 211, 44, 32, 32, 47, 47, 32, 32, 44, 253, 234, 76, 147, 145, 76, 62, 98, 185, 94, 141, 48, 2, 72, 254, 178, 179, 179, 178, 254, 128, 215, 91, 178, 178, 91, 215, 128, 217, 153, 154, 154, 153, 217, 216, 153, 154, 154, 153, 1, 87, 32, 46, 46, 32, 32, 45, 45, 32, 32, 46, 46, 32, 32, 45, 45, 254, 191, 137, 137, 35, 186, 95, 91, 0, 0, 4, 1, 209, 255, 229, 6, 153, 4, 172, 0, 17, 0, 29, 0, 41, 0, 52, 0, 96, 64, 55, 42, 18, 24, 47, 36, 30, 24, 30, 24, 30, 0, 8, 39, 27, 21, 33, 21, 48, 52, 104, 52, 1, 89, 52, 1, 75, 52, 1, 61, 52, 1, 52, 50, 45, 15, 21, 31, 21, 95, 21, 111, 21, 4, 8, 79, 45, 95, 45, 2, 21, 45, 21, 45, 13, 4, 0, 47, 204, 57, 57, 47, 47, 93, 94, 93, 16, 206, 51, 93, 93, 93, 93, 17, 51, 17, 51, 16, 206, 50, 1, 47, 205, 57, 57, 47, 47, 16, 206, 51, 16, 206, 51, 49, 48, 1, 20, 7, 6, 35, 34, 39, 38, 53, 52, 54, 55, 54, 51, 50, 23, 30, 1, 5, 52, 38, 35, 34, 6, 21, 20, 22, 51, 50, 54, 37, 52, 38, 35, 34, 6, 21, 20, 22, 51, 50, 54, 1, 30, 1, 51, 50, 55, 39, 6, 35, 34, 39, 6, 153, 180, 179, 253, 253, 179, 180, 90, 90, 178, 254, 254, 178, 90, 90, 253, 0, 46, 32, 32, 45, 45, 32, 32, 46, 1, 211, 44, 32, 32, 47, 47, 32, 32, 44, 253, 174, 48, 141, 94, 185, 98, 62, 76, 145, 147, 76, 2, 72, 254, 178, 179, 179, 178, 254, 128, 215, 91, 178, 178, 91, 215, 1, 32, 45, 45, 32, 32, 46, 46, 32, 32, 45, 45, 32, 32, 46, 46, 254, 220, 91, 95, 186, 35, 137, 137, 0, 2, 1, 70, 255, 115, 6, 14, 4, 59, 0, 51, 0, 70, 0, 139, 185, 0, 47, 255, 240, 64, 13, 11, 14, 72, 52, 46, 1, 52, 36, 1, 119, 35, 1, 35, 184, 255, 240, 64, 77, 11, 14, 72, 21, 16, 11, 14, 72, 59, 20, 1, 59, 9, 1, 8, 16, 11, 14, 72, 59, 47, 1, 52, 35, 1, 52, 21, 1, 59, 8, 1, 66, 143, 13, 223, 13, 2, 112, 13, 1, 63, 13, 1, 32, 13, 1, 13, 57, 43, 62, 128, 31, 208, 31, 224, 31, 3, 127, 31, 1, 48, 31, 1, 47, 31, 1, 31, 52, 15, 51, 63, 51, 79, 51, 3, 8, 51, 0, 47, 94, 93, 205, 220, 93, 93, 93, 93, 205, 1, 47, 205, 220, 93, 93, 93, 93, 205, 49, 48, 0, 93, 93, 93, 93, 1, 43, 93, 93, 43, 43, 93, 93, 93, 43, 1, 51, 21, 30, 3, 23, 55, 23, 7, 30, 1, 23, 51, 21, 35, 14, 1, 7, 23, 7, 39, 14, 1, 7, 14, 1, 7, 21, 35, 53, 46, 1, 39, 7, 39, 55, 46, 1, 39, 35, 53, 51, 54, 55, 39, 55, 23, 62, 1, 55, 23, 34, 6, 7, 6, 21, 20, 23, 30, 1, 51, 50, 55, 54, 53, 52, 39, 46, 1, 3, 137, 66, 32, 57, 54, 53, 29, 186, 45, 184, 45, 44, 3, 215, 215, 8, 44, 40, 184, 49, 182, 31, 55, 23, 24, 58, 34, 66, 63, 110, 48, 188, 43, 182, 40, 46, 8, 215, 215, 12, 80, 180, 40, 189, 57, 112, 54, 31, 69, 117, 48, 98, 98, 48, 117, 69, 139, 96, 99, 99, 49, 117, 4, 59, 217, 3, 12, 21, 32, 22, 182, 45, 184, 59, 113, 57, 62, 60, 110, 51, 188, 43, 182, 23, 32, 11, 9, 12, 5, 217, 217, 9, 46, 35, 180, 45, 184, 51, 111, 63, 62, 128, 95, 184, 49, 182, 40, 44, 6, 61, 50, 48, 100, 136, 137, 98, 50, 47, 97, 97, 138, 137, 99, 48, 50, 0, 0, 0, 2, 1, 218, 0, 80, 4, 38, 4, 129, 0, 28, 0, 47, 0, 98, 64, 62, 22, 18, 25, 0, 0, 5, 15, 43, 1, 239, 43, 255, 43, 2, 43, 15, 14, 1, 14, 0, 34, 1, 224, 34, 240, 34, 2, 34, 5, 22, 25, 19, 0, 28, 16, 28, 80, 28, 3, 28, 0, 39, 1, 240, 39, 1, 39, 18, 0, 0, 128, 0, 2, 8, 0, 29, 64, 37, 40, 72, 29, 10, 0, 47, 205, 43, 220, 94, 93, 50, 205, 113, 114, 47, 93, 51, 205, 50, 1, 47, 205, 113, 114, 220, 93, 205, 113, 114, 17, 57, 47, 51, 205, 50, 49, 48, 1, 46, 1, 39, 38, 53, 52, 55, 62, 1, 51, 50, 23, 22, 21, 20, 7, 6, 7, 21, 33, 21, 33, 17, 35, 17, 33, 53, 33, 19, 34, 7, 14, 1, 21, 20, 22, 23, 22, 51, 50, 55, 54, 53, 52, 38, 39, 38, 2, 220, 55, 90, 35, 71, 83, 44, 101, 60, 118, 83, 86, 72, 72, 106, 1, 0, 255, 0, 74, 254, 254, 1, 2, 35, 83, 62, 29, 31, 31, 29, 62, 83, 87, 59, 61, 30, 29, 62, 2, 66, 8, 46, 42, 80, 108, 122, 83, 43, 43, 86, 83, 122, 109, 81, 82, 12, 166, 70, 254, 250, 1, 6, 70, 2, 145, 59, 31, 71, 44, 43, 71, 31, 62, 62, 61, 84, 44, 71, 31, 59, 0, 2, 1, 81, 0, 250, 4, 175, 4, 129, 0, 65, 0, 81, 0, 70, 64, 40, 49, 65, 59, 15, 78, 1, 78, 63, 32, 1, 32, 15, 51, 1, 51, 0, 70, 1, 70, 59, 65, 49, 63, 74, 0, 55, 128, 55, 2, 55, 66, 144, 20, 1, 20, 15, 63, 1, 8, 63, 0, 47, 94, 93, 204, 93, 205, 220, 93, 205, 18, 57, 57, 1, 47, 205, 114, 220, 93, 204, 93, 205, 114, 18, 57, 57, 49, 48, 1, 46, 1, 39, 46, 1, 39, 46, 1, 53, 52, 55, 62, 1, 51, 50, 22, 23, 30, 1, 51, 50, 54, 55, 54, 51, 50, 21, 20, 7, 14, 1, 21, 20, 22, 23, 30, 1, 21, 20, 6, 7, 6, 35, 34, 39, 46, 1, 39, 7, 22, 21, 20, 7, 6, 35, 34, 39, 38, 53, 52, 55, 54, 51, 50, 23, 7, 34, 7, 6, 21, 20, 23, 22, 51, 50, 55, 54, 53, 52, 39, 38, 3, 255, 17, 54, 37, 28, 40, 14, 5, 3, 6, 3, 6, 5, 5, 15, 13, 32, 63, 32, 46, 64, 19, 36, 13, 16, 6, 9, 7, 4, 8, 2, 2, 2, 2, 9, 5, 21, 20, 22, 31, 11, 237, 84, 86, 87, 118, 118, 87, 84, 84, 85, 122, 71, 83, 154, 90, 62, 61, 61, 64, 88, 89, 60, 62, 62, 60, 4, 0, 5, 18, 14, 11, 24, 14, 3, 10, 5, 8, 9, 2, 2, 2, 2, 8, 9, 7, 6, 12, 14, 9, 18, 34, 79, 45, 31, 64, 34, 11, 16, 5, 5, 7, 3, 6, 39, 42, 82, 42, 238, 81, 109, 125, 86, 88, 84, 84, 117, 117, 87, 86, 43, 32, 62, 61, 88, 91, 61, 61, 61, 62, 90, 87, 62, 62, 0, 0, 1, 0, 59, 0, 0, 4, 5, 4, 207, 0, 47, 0, 40, 64, 25, 38, 32, 10, 48, 10, 96, 10, 112, 10, 4, 10, 14, 34, 64, 8, 11, 72, 34, 23, 79, 0, 95, 0, 2, 0, 0, 47, 93, 47, 47, 43, 51, 1, 47, 93, 47, 49, 48, 1, 30, 1, 23, 30, 1, 23, 22, 23, 22, 21, 20, 7, 6, 35, 34, 39, 22, 23, 30, 1, 31, 1, 33, 55, 50, 55, 62, 3, 39, 14, 1, 35, 34, 39, 38, 53, 52, 55, 62, 1, 55, 62, 1, 55, 54, 2, 32, 14, 40, 26, 28, 95, 69, 141, 35, 37, 63, 66, 88, 157, 99, 3, 36, 38, 163, 137, 8, 252, 232, 6, 125, 86, 43, 66, 44, 20, 1, 45, 132, 83, 90, 66, 63, 30, 23, 78, 57, 69, 110, 38, 56, 4, 207, 54, 95, 44, 43, 105, 63, 126, 66, 67, 70, 95, 63, 66, 191, 147, 87, 86, 99, 9, 37, 37, 49, 25, 69, 91, 119, 75, 96, 95, 66, 63, 91, 74, 59, 42, 85, 47, 59, 113, 57, 83, 0, 0, 0, 0, 1, 0, 60, 0, 0, 5, 4, 4, 199, 0, 75, 0, 47, 64, 24, 57, 77, 63, 23, 1, 23, 52, 61, 67, 13, 47, 30, 4, 18, 31, 18, 1, 27, 18, 27, 18, 1, 41, 1, 0, 47, 47, 18, 57, 57, 47, 47, 93, 18, 23, 57, 50, 51, 1, 47, 93, 16, 206, 49, 48, 41, 1, 55, 62, 1, 55, 62, 1, 55, 54, 53, 52, 38, 53, 6, 7, 14, 1, 35, 34, 38, 39, 38, 53, 52, 55, 54, 51, 50, 22, 23, 46, 1, 39, 46, 1, 53, 52, 55, 62, 1, 51, 50, 23, 22, 21, 20, 7, 54, 55, 62, 1, 51, 50, 22, 23, 22, 21, 20, 7, 6, 35, 34, 38, 39, 46, 1, 39, 30, 1, 23, 30, 1, 23, 22, 23, 4, 70, 252, 182, 8, 84, 108, 27, 41, 64, 26, 52, 2, 58, 90, 43, 88, 45, 59, 97, 41, 79, 73, 73, 93, 31, 80, 51, 20, 27, 8, 5, 6, 78, 40, 97, 60, 116, 80, 80, 69, 84, 16, 14, 30, 17, 51, 86, 36, 73, 80, 80, 112, 62, 132, 50, 17, 43, 26, 3, 23, 23, 22, 67, 46, 61, 159, 35, 17, 33, 17, 25, 75, 50, 100, 109, 8, 22, 17, 121, 59, 28, 30, 42, 38, 83, 116, 115, 79, 80, 25, 26, 34, 52, 19, 17, 38, 20, 115, 78, 38, 40, 80, 78, 109, 86, 98, 40, 3, 5, 3, 37, 41, 76, 116, 118, 83, 80, 60, 51, 19, 61, 45, 81, 125, 46, 45, 76, 31, 39, 30, 0, 1, 0, 102, 255, 233, 4, 90, 4, 121, 0, 39, 0, 38, 64, 23, 18, 2, 1, 4, 2, 1, 8, 29, 41, 16, 12, 64, 12, 80, 12, 112, 12, 128, 12, 5, 12, 16, 0, 0, 47, 47, 1, 47, 93, 16, 206, 49, 48, 94, 93, 93, 5, 46, 1, 39, 46, 1, 39, 46, 1, 39, 46, 1, 53, 52, 55, 54, 51, 50, 23, 30, 1, 23, 62, 1, 51, 50, 22, 23, 22, 21, 20, 7, 14, 1, 7, 14, 1, 7, 14, 1, 2, 98, 14, 42, 26, 28, 103, 76, 56, 69, 14, 43, 37, 68, 70, 102, 98, 78, 28, 47, 17, 34, 142, 88, 50, 85, 35, 70, 41, 20, 78, 60, 75, 108, 32, 31, 44, 23, 56, 101, 48, 50, 147, 102, 76, 93, 22, 65, 106, 56, 103, 71, 70, 72, 28, 80, 54, 119, 117, 36, 34, 70, 94, 86, 88, 45, 119, 75, 96, 152, 55, 54, 110, 0, 0, 0, 0, 1, 0, 66, 255, 231, 3, 210, 4, 199, 0, 26, 0, 18, 183, 48, 12, 1, 12, 75, 21, 1, 21, 0, 25, 47, 93, 1, 47, 93, 49, 48, 1, 30, 1, 23, 30, 1, 23, 14, 1, 7, 14, 1, 7, 46, 1, 39, 46, 1, 39, 46, 1, 39, 62, 1, 55, 62, 1, 2, 7, 45, 113, 69, 69, 116, 47, 39, 120, 83, 69, 106, 40, 13, 35, 22, 38, 98, 60, 14, 94, 81, 50, 128, 80, 59, 96, 4, 199, 78, 165, 93, 93, 141, 53, 40, 150, 111, 93, 159, 72, 25, 58, 32, 57, 135, 80, 20, 119, 99, 59, 160, 107, 77, 148, 0, 0, 1, 0, 196, 0, 29, 3, 59, 4, 129, 0, 33, 0, 48, 64, 25, 2, 19, 33, 13, 64, 79, 6, 95, 6, 111, 6, 3, 6, 128, 27, 33, 18, 10, 10, 47, 0, 1, 0, 31, 24, 0, 47, 205, 204, 93, 57, 47, 57, 1, 47, 205, 26, 220, 93, 26, 205, 16, 205, 50, 49, 48, 1, 51, 21, 23, 30, 1, 21, 20, 6, 7, 35, 62, 1, 53, 52, 38, 39, 38, 39, 17, 20, 6, 7, 6, 35, 34, 38, 53, 52, 55, 54, 51, 50, 23, 1, 233, 76, 153, 51, 58, 48, 46, 47, 29, 28, 28, 29, 57, 64, 37, 37, 72, 108, 57, 58, 60, 63, 80, 44, 46, 4, 129, 100, 193, 69, 163, 85, 78, 134, 59, 65, 124, 59, 60, 99, 40, 81, 9, 254, 6, 63, 98, 38, 75, 54, 46, 73, 60, 60, 19, 0, 2, 1, 16, 255, 213, 4, 239, 4, 135, 0, 34, 0, 38, 0, 108, 64, 61, 35, 32, 64, 18, 26, 128, 36, 15, 64, 111, 0, 1, 0, 128, 15, 9, 1, 9, 9, 0, 26, 1, 26, 17, 35, 86, 35, 1, 67, 35, 1, 35, 16, 36, 54, 36, 1, 37, 36, 1, 20, 36, 1, 3, 36, 1, 8, 36, 34, 38, 33, 88, 33, 1, 33, 37, 34, 30, 23, 13, 6, 0, 47, 205, 47, 205, 47, 51, 51, 93, 17, 51, 17, 51, 94, 93, 93, 93, 93, 17, 51, 51, 93, 93, 17, 51, 1, 47, 93, 51, 47, 93, 26, 221, 93, 26, 205, 50, 26, 16, 221, 26, 205, 51, 49, 48, 1, 20, 6, 7, 14, 1, 35, 34, 38, 53, 52, 55, 54, 51, 50, 23, 17, 5, 17, 20, 6, 7, 6, 35, 34, 38, 53, 52, 55, 54, 51, 50, 23, 17, 37, 1, 37, 53, 5, 4, 239, 36, 38, 37, 88, 51, 57, 57, 57, 62, 81, 48, 42, 253, 218, 37, 35, 74, 106, 57, 58, 59, 60, 84, 45, 45, 2, 186, 253, 144, 2, 38, 253, 218, 1, 68, 63, 101, 35, 37, 39, 54, 47, 76, 57, 59, 18, 1, 192, 149, 254, 118, 62, 98, 38, 74, 53, 45, 76, 57, 60, 19, 2, 240, 178, 254, 103, 149, 117, 152, 0, 0, 0, 3, 0, 35, 0, 0, 4, 82, 5, 204, 0, 3, 0, 7, 0, 35, 0, 112, 185, 0, 18, 255, 224, 64, 39, 9, 10, 0, 76, 0, 4, 70, 3, 223, 7, 1, 7, 37, 240, 37, 1, 47, 37, 63, 37, 2, 35, 35, 95, 23, 1, 23, 23, 33, 9, 70, 10, 12, 14, 12, 48, 10, 1, 10, 184, 255, 192, 64, 22, 16, 19, 72, 10, 27, 81, 20, 0, 8, 12, 79, 33, 5, 13, 15, 10, 4, 21, 0, 83, 1, 0, 0, 63, 237, 63, 51, 63, 51, 51, 237, 50, 63, 237, 1, 47, 43, 113, 51, 51, 47, 16, 237, 50, 50, 47, 93, 51, 47, 93, 93, 16, 222, 93, 50, 237, 50, 49, 48, 0, 43, 1, 53, 33, 21, 1, 17, 33, 17, 1, 17, 33, 17, 35, 53, 51, 53, 52, 62, 2, 51, 50, 22, 23, 21, 46, 1, 35, 34, 14, 2, 29, 1, 51, 21, 3, 57, 1, 25, 254, 231, 1, 25, 253, 135, 254, 232, 158, 158, 30, 72, 122, 91, 48, 93, 37, 18, 45, 19, 39, 51, 29, 12, 213, 4, 253, 207, 207, 251, 3, 4, 58, 251, 198, 3, 124, 252, 132, 3, 124, 190, 113, 62, 105, 78, 44, 10, 6, 181, 4, 5, 16, 32, 49, 32, 85, 190, 0, 0, 0, 2, 0, 35, 0, 0, 4, 82, 5, 204, 0, 3, 0, 31, 0, 103, 185, 0, 14, 255, 224, 64, 37, 9, 10, 0, 76, 0, 70, 223, 3, 1, 3, 33, 240, 33, 1, 47, 33, 63, 33, 2, 31, 31, 95, 19, 1, 19, 19, 29, 5, 70, 6, 8, 10, 8, 48, 6, 1, 6, 184, 255, 192, 64, 19, 16, 19, 72, 6, 23, 81, 16, 0, 4, 8, 79, 29, 9, 15, 1, 0, 6, 0, 21, 0, 63, 50, 63, 63, 51, 237, 50, 63, 237, 1, 47, 43, 113, 51, 51, 47, 16, 237, 50, 50, 47, 93, 51, 47, 93, 93, 16, 222, 93, 237, 49, 48, 0, 43, 33, 17, 33, 17, 1, 17, 33, 17, 35, 53, 51, 53, 52, 62, 2, 51, 50, 22, 23, 21, 46, 1, 35, 34, 14, 2, 29, 1, 51, 21, 3, 58, 1, 24, 253, 135, 254, 232, 158, 158, 30, 72, 122, 91, 48, 93, 37, 18, 45, 19, 39, 51, 29, 12, 213, 5, 204, 250, 52, 3, 124, 252, 132, 3, 124, 190, 113, 62, 105, 78, 44, 10, 6, 181, 4, 5, 16, 32, 49, 32, 85, 190, 0, 0, 0, 0, 1, 0, 140, 254, 87, 2, 32, 255, 198, 0, 25, 0, 68, 185, 0, 25, 255, 216, 179, 10, 0, 77, 2, 184, 255, 232, 64, 34, 10, 0, 77, 14, 136, 16, 0, 1, 0, 19, 64, 9, 0, 77, 19, 0, 7, 16, 7, 2, 7, 16, 146, 15, 23, 1, 255, 23, 1, 23, 11, 146, 5, 27, 0, 63, 237, 47, 93, 113, 237, 1, 47, 93, 196, 43, 47, 93, 237, 49, 48, 43, 43, 5, 20, 14, 2, 35, 34, 39, 53, 30, 1, 51, 50, 54, 53, 52, 35, 42, 1, 7, 55, 62, 1, 51, 50, 22, 2, 32, 31, 71, 116, 85, 45, 56, 25, 42, 17, 75, 62, 113, 13, 24, 14, 38, 20, 57, 35, 91, 106, 231, 44, 71, 51, 28, 6, 118, 5, 2, 37, 32, 69, 2, 109, 2, 3, 92, 0, 0, 1, 0, 141, 2, 19, 1, 173, 3, 68, 0, 3, 0, 34, 64, 21, 3, 150, 95, 0, 127, 0, 2, 143, 0, 191, 0, 207, 0, 3, 0, 1, 155, 15, 0, 1, 0, 0, 47, 93, 237, 1, 47, 93, 113, 237, 49, 48, 19, 17, 33, 17, 141, 1, 32, 2, 19, 1, 49, 254, 207, 0, 0, 0, 0, 1, 0, 103, 254, 57, 1, 92, 255, 178, 0, 12, 0, 39, 64, 14, 9, 9, 47, 12, 63, 12, 2, 12, 6, 11, 10, 10, 6, 11, 184, 255, 192, 179, 9, 12, 72, 11, 0, 47, 43, 196, 57, 47, 1, 47, 196, 205, 93, 57, 47, 49, 48, 5, 20, 14, 2, 7, 35, 62, 1, 53, 35, 53, 51, 1, 92, 14, 26, 34, 20, 137, 45, 49, 108, 245, 204, 44, 71, 61, 51, 24, 48, 84, 38, 207, 0, 0, 0, 2, 0, 35, 2, 182, 2, 153, 5, 134, 0, 10, 0, 23, 0, 84, 64, 51, 17, 47, 5, 63, 5, 2, 111, 5, 127, 5, 2, 5, 64, 21, 24, 72, 5, 5, 19, 10, 1, 10, 8, 1, 224, 18, 6, 64, 2, 80, 2, 96, 2, 3, 2, 2, 24, 25, 0, 4, 229, 8, 5, 17, 17, 1, 11, 6, 220, 1, 221, 0, 63, 63, 51, 18, 57, 47, 51, 51, 237, 50, 17, 18, 1, 57, 47, 113, 51, 51, 237, 50, 50, 93, 51, 47, 43, 93, 113, 51, 49, 48, 1, 21, 35, 53, 33, 53, 1, 51, 17, 51, 21, 1, 14, 3, 15, 1, 51, 53, 52, 62, 2, 2, 50, 183, 254, 168, 1, 60, 211, 103, 254, 230, 3, 17, 21, 20, 4, 141, 202, 1, 1, 2, 3, 66, 140, 140, 148, 1, 176, 254, 72, 140, 1, 186, 4, 31, 36, 31, 6, 194, 194, 8, 28, 32, 30, 0, 0, 0, 0, 1, 0, 53, 2, 172, 2, 128, 5, 129, 0, 38, 0, 113, 185, 0, 2, 255, 216, 180, 9, 10, 0, 76, 37, 184, 255, 216, 64, 60, 9, 10, 0, 76, 30, 31, 27, 25, 31, 3, 26, 29, 26, 29, 10, 19, 225, 15, 0, 31, 0, 2, 0, 40, 11, 225, 10, 159, 26, 175, 26, 2, 26, 26, 22, 228, 239, 34, 255, 34, 2, 34, 34, 16, 30, 229, 27, 220, 16, 228, 5, 96, 11, 112, 11, 2, 11, 11, 5, 223, 0, 63, 51, 47, 93, 16, 237, 63, 237, 18, 57, 47, 93, 237, 51, 47, 93, 1, 47, 237, 16, 222, 93, 237, 18, 57, 57, 47, 47, 23, 51, 17, 51, 49, 48, 43, 43, 1, 20, 14, 2, 35, 34, 46, 2, 39, 55, 30, 3, 51, 50, 54, 53, 52, 38, 35, 34, 6, 7, 35, 19, 33, 21, 33, 7, 62, 1, 51, 50, 30, 2, 2, 128, 39, 76, 112, 74, 68, 101, 70, 40, 7, 190, 3, 14, 24, 36, 25, 49, 58, 52, 52, 34, 51, 14, 178, 29, 1, 239, 254, 175, 10, 23, 79, 46, 57, 91, 63, 33, 3, 171, 55, 94, 68, 38, 32, 56, 73, 42, 12, 17, 32, 24, 15, 64, 60, 53, 62, 27, 19, 1, 149, 138, 136, 19, 27, 35, 64, 89, 0, 0, 0, 0, 1, 0, 43, 2, 182, 2, 112, 5, 129, 0, 14, 0, 44, 64, 24, 5, 225, 6, 6, 12, 11, 15, 0, 31, 0, 2, 0, 16, 239, 12, 1, 12, 0, 12, 229, 13, 220, 5, 221, 0, 63, 63, 237, 50, 1, 47, 93, 16, 206, 93, 50, 17, 57, 47, 237, 49, 48, 1, 14, 3, 21, 35, 52, 62, 2, 55, 33, 53, 33, 2, 112, 64, 95, 62, 31, 193, 40, 73, 101, 60, 254, 102, 2, 67, 5, 1, 79, 137, 136, 146, 89, 83, 147, 139, 136, 72, 138, 0, 0, 0, 3, 0, 45, 2, 172, 2, 121, 5, 144, 0, 37, 0, 53, 0, 71, 0, 94, 182, 8, 24, 9, 10, 0, 76, 2, 184, 255, 232, 64, 46, 9, 10, 0, 76, 16, 19, 54, 32, 64, 38, 225, 27, 44, 225, 19, 27, 19, 27, 10, 54, 225, 15, 0, 31, 0, 2, 0, 73, 64, 224, 10, 32, 16, 59, 228, 49, 49, 67, 41, 228, 22, 222, 67, 228, 5, 223, 0, 63, 237, 63, 237, 18, 57, 47, 237, 57, 57, 1, 47, 237, 16, 222, 93, 237, 18, 57, 57, 47, 47, 237, 16, 237, 18, 57, 17, 18, 57, 49, 48, 43, 43, 1, 20, 14, 2, 35, 34, 46, 2, 53, 52, 62, 2, 55, 53, 46, 1, 53, 52, 54, 51, 50, 30, 2, 21, 20, 14, 2, 7, 21, 30, 3, 3, 52, 38, 35, 34, 6, 21, 20, 30, 2, 51, 50, 62, 2, 19, 52, 46, 2, 35, 34, 14, 2, 21, 20, 22, 51, 50, 62, 2, 2, 121, 35, 72, 111, 76, 76, 111, 72, 35, 25, 42, 53, 28, 60, 69, 139, 134, 72, 104, 68, 33, 18, 34, 48, 31, 32, 55, 40, 23, 206, 37, 51, 50, 38, 7, 19, 35, 27, 29, 35, 18, 6, 17, 9, 25, 42, 33, 30, 40, 25, 10, 47, 62, 31, 41, 24, 9, 3, 129, 46, 79, 56, 32, 32, 57, 77, 46, 39, 61, 43, 27, 4, 2, 14, 90, 58, 86, 104, 28, 50, 71, 42, 28, 53, 43, 30, 6, 2, 5, 27, 43, 61, 1, 25, 36, 47, 47, 36, 16, 31, 25, 15, 16, 25, 31, 254, 223, 18, 33, 26, 15, 15, 26, 34, 18, 45, 55, 15, 26, 38, 0, 0, 0, 0, 1, 255, 189, 4, 160, 2, 235, 5, 244, 0, 21, 0, 98, 185, 0, 19, 255, 232, 64, 32, 9, 10, 0, 76, 3, 24, 9, 10, 0, 76, 14, 0, 15, 1, 16, 15, 64, 15, 112, 15, 144, 15, 160, 15, 192, 15, 208, 15, 240, 15, 8, 15, 184, 255, 192, 64, 34, 27, 60, 72, 15, 8, 7, 64, 16, 60, 72, 7, 14, 7, 11, 147, 15, 0, 1, 15, 0, 47, 0, 63, 0, 95, 0, 127, 0, 159, 0, 239, 0, 7, 0, 0, 47, 93, 113, 237, 205, 50, 1, 47, 43, 205, 47, 43, 93, 113, 205, 49, 48, 43, 43, 1, 34, 46, 4, 39, 51, 30, 1, 51, 50, 54, 55, 51, 14, 5, 1, 84, 82, 124, 89, 59, 35, 16, 2, 224, 5, 94, 84, 84, 94, 5, 224, 2, 16, 35, 59, 89, 124, 4, 160, 26, 47, 65, 75, 84, 43, 103, 96, 96, 103, 43, 84, 75, 65, 47, 26, 0, 1, 0, 113, 3, 244, 1, 102, 5, 129, 0, 12, 0, 35, 64, 19, 9, 9, 12, 6, 11, 111, 10, 127, 10, 143, 10, 3, 10, 144, 6, 1, 6, 11, 3, 0, 63, 196, 93, 205, 93, 1, 47, 196, 205, 57, 47, 49, 48, 1, 20, 14, 2, 7, 35, 62, 1, 53, 35, 53, 51, 1, 102, 14, 26, 34, 20, 137, 45, 49, 108, 245, 4, 239, 43, 72, 61, 51, 24, 48, 96, 46, 207, 0, 0, 1, 0, 103, 4, 188, 1, 92, 6, 73, 0, 10, 0, 30, 64, 14, 7, 4, 64, 9, 1, 9, 10, 8, 8, 64, 4, 1, 4, 9, 0, 47, 204, 93, 57, 47, 1, 47, 205, 93, 50, 57, 49, 48, 19, 52, 54, 55, 51, 14, 1, 21, 51, 21, 35, 103, 44, 40, 147, 45, 49, 108, 245, 5, 78, 87, 117, 47, 48, 96, 46, 207, 0, 1, 0, 87, 5, 250, 2, 84, 7, 23, 0, 5, 0, 32, 64, 18, 0, 131, 5, 132, 3, 130, 2, 3, 143, 95, 0, 1, 0, 64, 9, 12, 72, 0, 0, 47, 43, 93, 237, 1, 47, 237, 253, 237, 49, 48, 1, 37, 53, 33, 23, 21, 1, 171, 254, 172, 1, 2, 251, 5, 250, 242, 43, 254, 31, 0, 0, 0, 0, 1, 0, 87, 5, 250, 2, 85, 7, 23, 0, 5, 0, 32, 64, 18, 2, 130, 3, 132, 5, 131, 0, 2, 143, 95, 5, 1, 5, 64, 9, 12, 72, 5, 0, 47, 43, 93, 237, 1, 47, 237, 253, 237, 49, 48, 19, 53, 55, 33, 21, 5, 87, 252, 1, 2, 254, 172, 5, 250, 31, 254, 43, 242, 0, 1, 255, 229, 5, 250, 2, 198, 7, 43, 0, 9, 0, 95, 64, 68, 38, 9, 54, 9, 70, 9, 3, 41, 8, 57, 8, 73, 8, 3, 9, 8, 3, 3, 1, 38, 5, 54, 5, 70, 5, 3, 5, 131, 6, 41, 2, 57, 2, 73, 2, 3, 2, 131, 0, 1, 48, 1, 96, 1, 3, 64, 1, 112, 1, 160, 1, 208, 1, 4, 1, 3, 8, 143, 6, 95, 2, 1, 2, 64, 9, 12, 72, 2, 0, 47, 43, 93, 51, 237, 50, 1, 47, 93, 113, 237, 93, 47, 237, 93, 18, 57, 17, 51, 51, 93, 93, 49, 48, 1, 21, 35, 39, 35, 7, 35, 53, 1, 51, 2, 198, 159, 203, 4, 211, 160, 1, 2, 229, 6, 23, 29, 151, 151, 29, 1, 20, 0, 0, 0, 0, 1, 255, 229, 5, 250, 2, 198, 7, 43, 0, 9, 0, 63, 64, 40, 1, 0, 5, 5, 3, 7, 131, 0, 8, 48, 8, 96, 8, 3, 64, 8, 112, 8, 160, 8, 208, 8, 4, 8, 4, 131, 3, 7, 4, 143, 5, 95, 0, 1, 0, 64, 9, 12, 72, 0, 0, 47, 43, 93, 50, 237, 50, 1, 47, 237, 47, 93, 113, 237, 18, 57, 17, 51, 51, 49, 48, 1, 35, 1, 53, 51, 23, 51, 55, 51, 21, 1, 204, 229, 254, 254, 160, 211, 4, 203, 159, 5, 250, 1, 20, 29, 152, 152, 29, 0, 0, 0, 0, 2, 0, 15, 5, 250, 2, 154, 6, 213, 0, 3, 0, 7, 0, 41, 64, 23, 0, 133, 95, 3, 1, 3, 3, 7, 133, 4, 5, 1, 141, 4, 95, 0, 1, 0, 64, 9, 12, 72, 0, 0, 47, 43, 93, 50, 237, 50, 1, 47, 237, 51, 47, 93, 237, 49, 48, 1, 53, 51, 21, 33, 53, 51, 21, 1, 213, 197, 253, 117, 194, 5, 250, 219, 219, 219, 219, 0, 0, 0, 0, 1, 255, 207, 5, 250, 2, 219, 7, 31, 0, 31, 0, 88, 185, 0, 30, 255, 216, 64, 61, 9, 10, 0, 76, 14, 24, 9, 10, 0, 76, 0, 27, 32, 27, 48, 27, 80, 27, 96, 27, 5, 64, 27, 112, 27, 160, 27, 192, 27, 208, 27, 240, 27, 6, 15, 27, 1, 27, 11, 64, 21, 31, 72, 11, 26, 5, 144, 16, 143, 21, 144, 10, 95, 0, 1, 0, 64, 9, 12, 72, 0, 0, 47, 43, 93, 50, 237, 253, 237, 51, 1, 47, 43, 47, 93, 93, 113, 49, 48, 43, 43, 1, 34, 46, 2, 35, 34, 14, 2, 7, 35, 62, 3, 51, 50, 30, 2, 51, 50, 62, 2, 55, 51, 14, 3, 1, 252, 44, 89, 84, 75, 30, 26, 34, 21, 12, 5, 137, 3, 16, 47, 86, 73, 45, 90, 84, 73, 29, 25, 33, 23, 13, 5, 135, 2, 16, 46, 86, 5, 250, 38, 47, 38, 17, 32, 45, 29, 45, 102, 88, 58, 38, 47, 38, 17, 32, 46, 28, 45, 102, 88, 58, 0, 0, 2, 255, 174, 5, 250, 3, 6, 7, 24, 0, 5, 0, 11, 0, 49, 64, 30, 112, 10, 128, 10, 2, 10, 63, 7, 1, 7, 112, 4, 128, 4, 2, 4, 1, 9, 3, 143, 6, 95, 0, 1, 0, 64, 9, 12, 72, 0, 0, 47, 43, 93, 50, 237, 50, 1, 47, 205, 93, 212, 93, 205, 93, 49, 48, 19, 35, 53, 55, 51, 21, 23, 35, 53, 55, 51, 21, 50, 132, 215, 235, 88, 132, 215, 235, 5, 250, 34, 252, 43, 243, 34, 252, 43, 0, 0, 0, 1, 255, 251, 5, 240, 2, 191, 7, 16, 0, 21, 0, 76, 64, 56, 16, 131, 32, 17, 80, 17, 128, 17, 160, 17, 176, 17, 5, 0, 17, 48, 17, 96, 17, 144, 17, 192, 17, 240, 17, 6, 112, 17, 160, 17, 208, 17, 3, 15, 17, 31, 17, 2, 17, 6, 131, 5, 16, 5, 143, 11, 144, 95, 0, 1, 0, 64, 9, 12, 72, 0, 0, 47, 43, 93, 237, 237, 50, 1, 47, 237, 47, 93, 93, 113, 114, 237, 49, 48, 1, 34, 46, 2, 39, 51, 30, 3, 51, 50, 62, 2, 55, 51, 14, 3, 1, 91, 80, 126, 89, 52, 5, 163, 8, 36, 50, 63, 34, 36, 63, 50, 34, 7, 164, 8, 51, 87, 126, 5, 240, 48, 79, 104, 57, 32, 50, 35, 19, 19, 35, 50, 32, 57, 104, 79, 48, 0, 0, 0, 0, 1, 0, 0, 21, 86, 0, 1, 3, 140, 12, 0, 0, 9, 9, 72, 0, 3, 0, 36, 255, 180, 0, 3, 0, 60, 255, 219, 0, 3, 1, 86, 255, 180, 0, 3, 1, 95, 255, 180, 0, 3, 1, 98, 255, 180, 0, 3, 1, 105, 255, 180, 0, 3, 1, 114, 255, 219, 0, 3, 1, 120, 255, 219, 0, 20, 0, 20, 255, 143, 0, 36, 0, 3, 255, 180, 0, 36, 0, 55, 255, 104, 0, 36, 0, 57, 255, 104, 0, 36, 0, 58, 255, 143, 0, 36, 0, 60, 255, 68, 0, 36, 0, 89, 255, 180, 0, 36, 0, 90, 255, 219, 0, 36, 0, 92, 255, 180, 0, 36, 2, 9, 255, 143, 0, 41, 0, 15, 255, 29, 0, 41, 0, 17, 255, 29, 0, 41, 0, 36, 255, 143, 0, 47, 0, 3, 255, 219, 0, 47, 0, 55, 255, 104, 0, 47, 0, 57, 255, 104, 0, 47, 0, 58, 255, 143, 0, 47, 0, 60, 255, 68, 0, 47, 0, 92, 255, 180, 0, 47, 2, 9, 255, 143, 0, 51, 0, 3, 255, 219, 0, 51, 0, 15, 254, 248, 0, 51, 0, 17, 254, 248, 0, 51, 0, 36, 255, 104, 0, 53, 0, 57, 255, 219, 0, 53, 0, 58, 255, 219, 0, 53, 0, 60, 255, 180, 0, 55, 0, 15, 255, 29, 0, 55, 0, 16, 255, 143, 0, 55, 0, 17, 255, 29, 0, 55, 0, 29, 255, 29, 0, 55, 0, 30, 255, 29, 0, 55, 0, 36, 255, 104, 0, 55, 0, 50, 255, 219, 0, 55, 0, 68, 255, 104, 0, 55, 0, 70, 255, 104, 0, 55, 0, 72, 255, 104, 0, 55, 0, 76, 255, 219, 0, 55, 0, 82, 255, 104, 0, 55, 0, 85, 255, 143, 0, 55, 0, 86, 255, 104, 0, 55, 0, 88, 255, 104, 0, 55, 0, 90, 255, 104, 0, 55, 0, 92, 255, 104, 0, 57, 0, 15, 255, 68, 0, 57, 0, 16, 255, 143, 0, 57, 0, 17, 255, 68, 0, 57, 0, 29, 255, 143, 0, 57, 0, 30, 255, 143, 0, 57, 0, 36, 255, 104, 0, 57, 0, 68, 255, 143, 0, 57, 0, 72, 255, 143, 0, 57, 0, 76, 255, 219, 0, 57, 0, 82, 255, 104, 0, 57, 0, 85, 255, 143, 0, 57, 0, 88, 255, 180, 0, 57, 0, 92, 255, 180, 0, 58, 0, 15, 255, 143, 0, 58, 0, 16, 255, 215, 0, 58, 0, 17, 255, 143, 0, 58, 0, 29, 255, 219, 0, 58, 0, 30, 255, 219, 0, 58, 0, 36, 255, 143, 0, 58, 0, 68, 255, 180, 0, 58, 0, 72, 255, 219, 0, 58, 0, 76, 255, 238, 0, 58, 0, 82, 255, 219, 0, 58, 0, 85, 255, 219, 0, 58, 0, 88, 255, 219, 0, 58, 0, 92, 255, 219, 0, 60, 0, 3, 255, 219, 0, 60, 0, 15, 255, 29, 0, 60, 0, 16, 255, 143, 0, 60, 0, 17, 255, 29, 0, 60, 0, 29, 255, 104, 0, 60, 0, 30, 255, 104, 0, 60, 0, 36, 255, 68, 0, 60, 0, 68, 255, 143, 0, 60, 0, 72, 255, 143, 0, 60, 0, 76, 255, 180, 0, 60, 0, 82, 255, 104, 0, 60, 0, 83, 255, 143, 0, 60, 0, 84, 255, 104, 0, 60, 0, 88, 255, 143, 0, 60, 0, 89, 255, 143, 0, 73, 2, 9, 0, 37, 0, 85, 0, 15, 255, 143, 0, 85, 0, 17, 255, 143, 0, 85, 2, 9, 0, 76, 0, 89, 0, 15, 255, 104, 0, 89, 0, 17, 255, 104, 0, 90, 0, 15, 255, 180, 0, 90, 0, 17, 255, 180, 0, 92, 0, 15, 255, 104, 0, 92, 0, 17, 255, 104, 1, 86, 1, 102, 255, 201, 1, 86, 1, 109, 255, 201, 1, 86, 1, 113, 255, 86, 1, 86, 1, 114, 255, 70, 1, 86, 1, 115, 255, 201, 1, 86, 1, 120, 255, 70, 1, 86, 1, 128, 255, 180, 1, 86, 1, 138, 255, 180, 1, 86, 1, 148, 255, 180, 1, 91, 1, 114, 255, 199, 1, 91, 1, 120, 255, 199, 1, 92, 1, 94, 1, 0, 1, 92, 1, 95, 255, 70, 1, 92, 1, 98, 255, 70, 1, 92, 1, 102, 255, 178, 1, 92, 1, 105, 255, 70, 1, 92, 1, 109, 255, 178, 1, 92, 1, 115, 255, 178, 1, 92, 1, 118, 255, 178, 1, 92, 1, 121, 255, 104, 1, 92, 1, 123, 255, 180, 1, 92, 1, 124, 255, 180, 1, 92, 1, 126, 255, 104, 1, 92, 1, 129, 255, 180, 1, 92, 1, 132, 255, 180, 1, 92, 1, 134, 255, 180, 1, 92, 1, 135, 255, 180, 1, 92, 1, 137, 255, 180, 1, 92, 1, 140, 255, 104, 1, 92, 1, 144, 255, 104, 1, 92, 1, 147, 255, 104, 1, 92, 1, 151, 0, 92, 1, 92, 1, 153, 255, 104, 1, 93, 1, 114, 255, 199, 1, 93, 1, 120, 255, 199, 1, 95, 1, 102, 255, 201, 1, 95, 1, 109, 255, 201, 1, 95, 1, 113, 255, 86, 1, 95, 1, 114, 255, 70, 1, 95, 1, 115, 255, 201, 1, 95, 1, 120, 255, 70, 1, 95, 1, 128, 255, 180, 1, 95, 1, 138, 255, 180, 1, 95, 1, 148, 255, 180, 1, 95, 2, 9, 255, 143, 1, 97, 0, 15, 255, 31, 1, 97, 0, 17, 255, 31, 1, 97, 1, 95, 255, 33, 1, 97, 1, 98, 255, 33, 1, 97, 1, 105, 255, 33, 1, 97, 1, 124, 255, 190, 1, 97, 1, 134, 255, 190, 1, 97, 1, 151, 0, 94, 1, 98, 1, 102, 255, 201, 1, 98, 1, 109, 255, 201, 1, 98, 1, 113, 255, 86, 1, 98, 1, 114, 255, 70, 1, 98, 1, 120, 255, 70, 1, 102, 1, 95, 255, 201, 1, 102, 1, 98, 255, 201, 1, 102, 1, 105, 255, 201, 1, 102, 1, 114, 255, 199, 1, 102, 1, 120, 255, 199, 1, 104, 1, 102, 255, 162, 1, 104, 1, 109, 255, 162, 1, 104, 1, 115, 255, 162, 1, 104, 1, 121, 255, 209, 1, 104, 1, 126, 255, 209, 1, 104, 1, 129, 255, 209, 1, 104, 1, 131, 255, 209, 1, 104, 1, 133, 255, 209, 1, 104, 1, 139, 255, 209, 1, 104, 1, 140, 255, 209, 1, 104, 1, 144, 255, 209, 1, 104, 1, 147, 255, 209, 1, 104, 1, 150, 255, 209, 1, 104, 1, 153, 255, 209, 1, 104, 1, 155, 255, 209, 1, 105, 1, 102, 255, 201, 1, 105, 1, 109, 255, 201, 1, 105, 1, 113, 255, 86, 1, 105, 1, 114, 255, 70, 1, 105, 1, 120, 255, 70, 1, 109, 1, 95, 255, 201, 1, 109, 1, 98, 255, 201, 1, 109, 1, 105, 255, 201, 1, 109, 1, 114, 255, 199, 1, 109, 1, 120, 255, 199, 1, 111, 0, 15, 254, 250, 1, 111, 0, 17, 254, 250, 1, 111, 1, 95, 255, 104, 1, 111, 1, 98, 255, 104, 1, 111, 1, 105, 255, 104, 1, 112, 1, 141, 255, 221, 1, 112, 1, 145, 255, 221, 1, 113, 0, 15, 255, 31, 1, 113, 0, 16, 255, 143, 1, 113, 0, 17, 255, 31, 1, 113, 0, 29, 255, 31, 1, 113, 0, 30, 255, 31, 1, 113, 1, 94, 0, 242, 1, 113, 1, 95, 255, 104, 1, 113, 1, 98, 255, 92, 1, 113, 1, 102, 255, 219, 1, 113, 1, 105, 255, 104, 1, 113, 1, 109, 255, 219, 1, 113, 1, 115, 255, 201, 1, 113, 1, 118, 255, 219, 1, 113, 1, 121, 255, 104, 1, 113, 1, 122, 255, 104, 1, 113, 1, 126, 255, 104, 1, 113, 1, 128, 255, 104, 1, 113, 1, 129, 255, 172, 1, 113, 1, 130, 255, 104, 1, 113, 1, 132, 255, 104, 1, 113, 1, 134, 255, 219, 1, 113, 1, 137, 255, 104, 1, 113, 1, 138, 255, 104, 1, 113, 1, 140, 255, 104, 1, 113, 1, 144, 255, 104, 1, 113, 1, 146, 255, 104, 1, 113, 1, 147, 255, 104, 1, 113, 1, 148, 255, 133, 1, 113, 1, 149, 255, 104, 1, 113, 1, 151, 0, 92, 1, 113, 1, 152, 255, 104, 1, 113, 1, 153, 255, 104, 1, 113, 1, 154, 255, 104, 1, 114, 0, 15, 255, 31, 1, 114, 0, 16, 255, 143, 1, 114, 0, 17, 255, 31, 1, 114, 0, 29, 255, 104, 1, 114, 0, 30, 255, 104, 1, 114, 1, 94, 1, 0, 1, 114, 1, 95, 255, 70, 1, 114, 1, 98, 255, 70, 1, 114, 1, 102, 255, 178, 1, 114, 1, 105, 255, 70, 1, 114, 1, 109, 255, 178, 1, 114, 1, 115, 255, 178, 1, 114, 1, 118, 255, 178, 1, 114, 1, 121, 255, 104, 1, 114, 1, 123, 255, 180, 1, 114, 1, 124, 255, 180, 1, 114, 1, 126, 255, 104, 1, 114, 1, 128, 255, 172, 1, 114, 1, 129, 255, 180, 1, 114, 1, 132, 255, 180, 1, 114, 1, 134, 255, 180, 1, 114, 1, 135, 255, 180, 1, 114, 1, 137, 255, 180, 1, 114, 1, 140, 255, 104, 1, 114, 1, 144, 255, 104, 1, 114, 1, 147, 255, 104, 1, 114, 1, 151, 0, 92, 1, 114, 1, 153, 255, 104, 1, 115, 1, 95, 255, 201, 1, 115, 1, 113, 255, 201, 1, 115, 1, 114, 255, 199, 1, 115, 1, 120, 255, 199, 1, 116, 1, 150, 255, 229, 1, 116, 1, 155, 255, 229, 1, 117, 1, 121, 255, 219, 1, 117, 1, 126, 255, 219, 1, 117, 1, 129, 255, 219, 1, 117, 1, 140, 255, 219, 1, 117, 1, 144, 255, 219, 1, 117, 1, 147, 255, 219, 1, 117, 1, 150, 255, 219, 1, 117, 1, 153, 255, 219, 1, 117, 1, 155, 255, 219, 1, 118, 1, 114, 255, 199, 1, 118, 1, 120, 255, 199, 1, 120, 1, 94, 1, 0, 1, 120, 1, 95, 255, 70, 1, 120, 1, 98, 255, 70, 1, 120, 1, 102, 255, 178, 1, 120, 1, 105, 255, 70, 1, 120, 1, 109, 255, 178, 1, 120, 1, 115, 255, 178, 1, 120, 1, 118, 255, 178, 1, 120, 1, 121, 255, 104, 1, 120, 1, 123, 255, 180, 1, 120, 1, 124, 255, 180, 1, 120, 1, 126, 255, 104, 1, 120, 1, 129, 255, 180, 1, 120, 1, 132, 255, 180, 1, 120, 1, 134, 255, 180, 1, 120, 1, 135, 255, 180, 1, 120, 1, 137, 255, 180, 1, 120, 1, 140, 255, 104, 1, 120, 1, 144, 255, 104, 1, 120, 1, 147, 255, 104, 1, 120, 1, 151, 0, 92, 1, 120, 1, 153, 255, 104, 1, 129, 1, 141, 255, 199, 1, 129, 1, 145, 255, 199, 1, 129, 1, 148, 255, 182, 1, 131, 1, 121, 255, 141, 1, 131, 1, 123, 255, 207, 1, 131, 1, 126, 255, 141, 1, 131, 1, 128, 255, 190, 1, 131, 1, 129, 255, 180, 1, 131, 1, 132, 255, 207, 1, 131, 1, 133, 255, 180, 1, 131, 1, 134, 255, 207, 1, 131, 1, 135, 255, 207, 1, 131, 1, 138, 255, 190, 1, 131, 1, 140, 255, 141, 1, 131, 1, 141, 255, 180, 1, 131, 1, 144, 255, 141, 1, 131, 1, 145, 255, 180, 1, 131, 1, 147, 255, 141, 1, 131, 1, 150, 255, 141, 1, 131, 1, 153, 255, 141, 1, 131, 1, 155, 255, 141, 1, 135, 1, 121, 255, 188, 1, 135, 1, 126, 255, 188, 1, 135, 1, 129, 255, 188, 1, 135, 1, 131, 255, 188, 1, 135, 1, 133, 255, 227, 1, 135, 1, 139, 255, 188, 1, 135, 1, 140, 255, 188, 1, 135, 1, 143, 255, 188, 1, 135, 1, 144, 255, 188, 1, 135, 1, 147, 255, 188, 1, 135, 1, 150, 255, 188, 1, 135, 1, 153, 255, 188, 1, 135, 1, 155, 255, 188, 1, 136, 1, 121, 255, 231, 1, 136, 1, 125, 255, 225, 1, 136, 1, 126, 255, 231, 1, 136, 1, 129, 255, 231, 1, 136, 1, 131, 255, 231, 1, 136, 1, 139, 255, 231, 1, 136, 1, 140, 255, 231, 1, 136, 1, 143, 255, 231, 1, 136, 1, 144, 255, 231, 1, 136, 1, 146, 255, 225, 1, 136, 1, 147, 255, 231, 1, 136, 1, 150, 255, 231, 1, 136, 1, 152, 255, 225, 1, 136, 1, 153, 255, 231, 1, 136, 1, 154, 255, 225, 1, 136, 1, 155, 255, 231, 1, 139, 1, 121, 255, 231, 1, 139, 1, 126, 255, 231, 1, 139, 1, 129, 255, 231, 1, 139, 1, 131, 255, 231, 1, 139, 1, 139, 255, 231, 1, 139, 1, 140, 255, 231, 1, 139, 1, 143, 255, 231, 1, 139, 1, 144, 255, 231, 1, 139, 1, 147, 255, 231, 1, 139, 1, 153, 255, 231, 1, 140, 1, 141, 255, 199, 1, 140, 1, 145, 255, 199, 1, 140, 1, 148, 255, 182, 1, 141, 1, 121, 255, 199, 1, 141, 1, 126, 255, 199, 1, 141, 1, 129, 255, 199, 1, 141, 1, 131, 255, 199, 1, 141, 1, 136, 255, 180, 1, 141, 1, 140, 255, 199, 1, 141, 1, 143, 255, 199, 1, 141, 1, 144, 255, 199, 1, 141, 1, 147, 255, 199, 1, 141, 1, 150, 255, 199, 1, 141, 1, 155, 255, 199, 1, 142, 1, 141, 255, 199, 1, 142, 1, 145, 255, 199, 1, 145, 1, 121, 255, 199, 1, 145, 1, 126, 255, 199, 1, 145, 1, 129, 255, 199, 1, 145, 1, 131, 255, 199, 1, 145, 1, 140, 255, 199, 1, 145, 1, 143, 255, 199, 1, 145, 1, 144, 255, 199, 1, 145, 1, 147, 255, 199, 1, 145, 1, 150, 255, 199, 1, 145, 1, 155, 255, 199, 1, 147, 1, 136, 255, 231, 1, 147, 1, 141, 255, 199, 1, 147, 1, 145, 255, 199, 1, 147, 1, 148, 255, 182, 1, 148, 1, 121, 255, 182, 1, 148, 1, 126, 255, 182, 1, 148, 1, 129, 255, 182, 1, 148, 1, 131, 255, 182, 1, 148, 1, 140, 255, 182, 1, 148, 1, 143, 255, 182, 1, 148, 1, 144, 255, 182, 1, 148, 1, 147, 255, 182, 1, 148, 1, 150, 255, 213, 1, 148, 1, 153, 255, 182, 1, 148, 1, 155, 255, 213, 1, 150, 1, 141, 255, 199, 1, 150, 1, 145, 255, 199, 1, 150, 1, 148, 255, 213, 1, 153, 1, 141, 255, 199, 1, 153, 1, 145, 255, 199, 1, 153, 1, 148, 255, 182, 1, 155, 1, 141, 255, 199, 1, 155, 1, 145, 255, 199, 1, 155, 1, 148, 255, 213, 1, 158, 0, 15, 255, 25, 1, 158, 0, 17, 255, 0, 1, 158, 0, 29, 255, 229, 1, 158, 0, 30, 255, 229, 1, 158, 0, 108, 255, 178, 1, 158, 0, 123, 255, 178, 1, 164, 2, 9, 255, 51, 1, 165, 2, 9, 255, 51, 1, 170, 1, 174, 0, 76, 1, 170, 1, 181, 0, 25, 1, 170, 1, 184, 255, 229, 1, 170, 1, 185, 255, 229, 1, 170, 1, 187, 255, 205, 1, 170, 1, 188, 255, 154, 1, 170, 1, 189, 255, 178, 1, 170, 1, 190, 255, 205, 1, 170, 1, 193, 255, 100, 1, 170, 1, 199, 255, 205, 1, 170, 1, 202, 0, 25, 1, 170, 1, 203, 255, 229, 1, 170, 1, 219, 255, 229, 1, 170, 1, 220, 255, 229, 1, 170, 1, 231, 0, 25, 1, 170, 2, 9, 255, 152, 1, 171, 1, 170, 255, 178, 1, 171, 1, 176, 255, 205, 1, 171, 1, 177, 255, 229, 1, 171, 1, 181, 255, 205, 1, 171, 1, 187, 255, 229, 1, 171, 1, 188, 255, 205, 1, 171, 1, 189, 255, 205, 1, 171, 1, 190, 255, 229, 1, 171, 1, 191, 255, 205, 1, 171, 1, 193, 255, 178, 1, 171, 1, 196, 255, 178, 1, 171, 1, 199, 255, 205, 1, 171, 1, 201, 255, 205, 1, 171, 1, 221, 255, 229, 1, 172, 1, 170, 255, 154, 1, 172, 1, 174, 255, 229, 1, 172, 1, 176, 255, 178, 1, 172, 1, 177, 255, 229, 1, 172, 1, 181, 255, 205, 1, 172, 1, 184, 255, 205, 1, 172, 1, 187, 255, 178, 1, 172, 1, 188, 255, 178, 1, 172, 1, 189, 255, 178, 1, 172, 1, 190, 255, 205, 1, 172, 1, 191, 255, 178, 1, 172, 1, 193, 255, 178, 1, 172, 1, 196, 255, 154, 1, 172, 1, 201, 255, 205, 1, 172, 1, 220, 255, 229, 1, 172, 1, 223, 255, 229, 1, 172, 1, 225, 255, 178, 1, 173, 0, 15, 255, 25, 1, 173, 0, 17, 255, 0, 1, 173, 0, 29, 255, 229, 1, 173, 0, 30, 255, 229, 1, 173, 0, 108, 255, 178, 1, 173, 0, 123, 255, 178, 1, 173, 1, 170, 255, 127, 1, 173, 1, 174, 255, 205, 1, 173, 1, 181, 255, 205, 1, 173, 1, 184, 255, 229, 1, 173, 1, 187, 255, 229, 1, 173, 1, 202, 255, 229, 1, 173, 1, 204, 255, 205, 1, 173, 1, 206, 255, 178, 1, 173, 1, 207, 255, 152, 1, 173, 1, 210, 255, 205, 1, 173, 1, 213, 255, 154, 1, 173, 1, 214, 255, 178, 1, 173, 1, 215, 255, 205, 1, 173, 1, 216, 255, 154, 1, 173, 1, 218, 255, 178, 1, 173, 1, 221, 255, 178, 1, 173, 1, 229, 255, 178, 1, 173, 1, 230, 255, 178, 1, 173, 1, 232, 255, 178, 1, 173, 1, 233, 255, 178, 1, 174, 1, 177, 0, 25, 1, 174, 1, 189, 0, 25, 1, 174, 1, 190, 255, 229, 1, 174, 1, 193, 255, 229, 1, 174, 1, 207, 0, 25, 1, 174, 1, 209, 0, 51, 1, 174, 1, 216, 0, 25, 1, 174, 1, 221, 0, 25, 1, 176, 1, 177, 0, 25, 1, 176, 1, 184, 255, 229, 1, 176, 1, 187, 255, 205, 1, 176, 1, 188, 0, 51, 1, 176, 1, 189, 0, 51, 1, 176, 1, 193, 0, 25, 1, 176, 1, 196, 0, 76, 1, 176, 1, 202, 0, 25, 1, 176, 1, 216, 255, 229, 1, 177, 1, 176, 255, 205, 1, 177, 1, 181, 255, 205, 1, 177, 1, 184, 255, 229, 1, 177, 1, 187, 255, 205, 1, 177, 1, 188, 255, 178, 1, 177, 1, 189, 255, 178, 1, 177, 1, 190, 255, 205, 1, 177, 1, 193, 255, 178, 1, 177, 1, 201, 255, 205, 1, 180, 1, 177, 0, 76, 1, 180, 1, 187, 255, 229, 1, 180, 1, 188, 0, 51, 1, 180, 1, 189, 0, 51, 1, 180, 1, 190, 255, 229, 1, 180, 1, 193, 0, 51, 1, 180, 1, 199, 0, 25, 1, 180, 1, 202, 0, 25, 1, 180, 1, 209, 0, 25, 1, 180, 1, 219, 255, 229, 1, 181, 1, 202, 0, 51, 1, 182, 1, 202, 0, 25, 1, 182, 1, 219, 255, 229, 1, 182, 1, 225, 255, 229, 1, 184, 1, 170, 255, 205, 1, 184, 1, 174, 255, 229, 1, 184, 1, 176, 255, 229, 1, 184, 1, 181, 255, 205, 1, 184, 1, 189, 255, 205, 1, 184, 1, 191, 255, 178, 1, 184, 1, 201, 255, 229, 1, 184, 1, 206, 255, 205, 1, 184, 1, 213, 255, 229, 1, 186, 0, 15, 254, 229, 1, 186, 0, 17, 254, 205, 1, 186, 0, 29, 255, 229, 1, 186, 0, 30, 255, 229, 1, 186, 1, 170, 255, 76, 1, 186, 1, 174, 255, 127, 1, 186, 1, 176, 255, 229, 1, 186, 1, 177, 255, 229, 1, 186, 1, 181, 255, 127, 1, 186, 1, 182, 255, 229, 1, 186, 1, 184, 255, 229, 1, 186, 1, 187, 255, 205, 1, 186, 1, 188, 255, 229, 1, 186, 1, 189, 255, 229, 1, 186, 1, 190, 255, 229, 1, 186, 1, 191, 255, 178, 1, 186, 1, 201, 255, 205, 1, 186, 1, 202, 255, 229, 1, 186, 1, 206, 255, 127, 1, 186, 1, 207, 255, 205, 1, 186, 1, 216, 255, 205, 1, 186, 1, 233, 255, 229, 1, 187, 1, 170, 255, 205, 1, 187, 1, 174, 255, 229, 1, 187, 1, 177, 255, 229, 1, 187, 1, 181, 255, 205, 1, 187, 1, 182, 255, 229, 1, 187, 1, 184, 255, 205, 1, 187, 1, 188, 255, 205, 1, 187, 1, 189, 255, 229, 1, 187, 1, 191, 255, 178, 1, 187, 1, 193, 255, 205, 1, 187, 1, 196, 255, 229, 1, 187, 1, 199, 255, 229, 1, 187, 1, 202, 0, 25, 1, 187, 1, 203, 255, 229, 1, 187, 1, 208, 0, 25, 1, 187, 1, 219, 255, 229, 1, 187, 1, 222, 255, 229, 1, 187, 1, 225, 255, 229, 1, 188, 0, 15, 255, 51, 1, 188, 0, 17, 255, 25, 1, 188, 0, 29, 255, 229, 1, 188, 0, 30, 255, 229, 1, 188, 0, 108, 255, 205, 1, 188, 1, 170, 255, 127, 1, 188, 1, 174, 255, 205, 1, 188, 1, 176, 0, 51, 1, 188, 1, 181, 255, 205, 1, 188, 1, 184, 255, 205, 1, 188, 1, 190, 255, 178, 1, 188, 1, 201, 255, 229, 1, 188, 1, 202, 255, 205, 1, 188, 1, 204, 255, 178, 1, 188, 1, 207, 255, 154, 1, 188, 1, 210, 255, 178, 1, 188, 1, 212, 255, 178, 1, 188, 1, 213, 255, 127, 1, 188, 1, 214, 255, 152, 1, 188, 1, 216, 255, 127, 1, 188, 1, 217, 255, 229, 1, 188, 1, 218, 255, 178, 1, 188, 1, 219, 255, 127, 1, 188, 1, 221, 255, 178, 1, 188, 1, 223, 255, 178, 1, 188, 1, 227, 255, 229, 1, 188, 1, 229, 255, 229, 1, 188, 1, 230, 255, 229, 1, 188, 1, 232, 255, 229, 1, 188, 1, 233, 255, 205, 1, 189, 0, 15, 255, 25, 1, 189, 0, 17, 255, 0, 1, 189, 0, 29, 255, 205, 1, 189, 0, 30, 255, 205, 1, 189, 0, 108, 255, 178, 1, 189, 0, 123, 255, 178, 1, 189, 1, 170, 255, 102, 1, 189, 1, 174, 255, 152, 1, 189, 1, 181, 255, 178, 1, 189, 1, 184, 255, 205, 1, 189, 1, 190, 255, 178, 1, 189, 1, 199, 255, 229, 1, 189, 1, 201, 255, 205, 1, 189, 1, 203, 255, 205, 1, 189, 1, 204, 255, 178, 1, 189, 1, 205, 255, 178, 1, 189, 1, 206, 255, 127, 1, 189, 1, 207, 255, 127, 1, 189, 1, 208, 255, 229, 1, 189, 1, 209, 255, 154, 1, 189, 1, 210, 255, 178, 1, 189, 1, 211, 255, 178, 1, 189, 1, 212, 255, 178, 1, 189, 1, 213, 255, 127, 1, 189, 1, 214, 255, 154, 1, 189, 1, 215, 255, 178, 1, 189, 1, 216, 255, 127, 1, 189, 1, 217, 255, 178, 1, 189, 1, 218, 255, 178, 1, 189, 1, 219, 255, 127, 1, 189, 1, 223, 255, 205, 1, 189, 1, 224, 255, 178, 1, 189, 1, 226, 255, 178, 1, 189, 1, 227, 255, 178, 1, 189, 1, 232, 255, 178, 1, 189, 1, 233, 255, 154, 1, 190, 1, 170, 255, 205, 1, 190, 1, 174, 255, 152, 1, 190, 1, 181, 255, 178, 1, 190, 1, 188, 255, 178, 1, 190, 1, 189, 255, 178, 1, 190, 1, 190, 255, 229, 1, 190, 1, 193, 255, 229, 1, 190, 1, 201, 255, 203, 1, 190, 1, 213, 255, 205, 1, 191, 1, 177, 255, 229, 1, 191, 1, 184, 255, 203, 1, 191, 1, 187, 255, 178, 1, 191, 1, 190, 255, 178, 1, 191, 1, 199, 255, 205, 1, 191, 1, 216, 255, 229, 1, 191, 1, 221, 255, 229, 1, 192, 1, 202, 0, 76, 1, 192, 1, 207, 0, 25, 1, 192, 1, 216, 0, 25, 1, 195, 1, 202, 0, 25, 1, 196, 1, 201, 255, 178, 1, 196, 2, 9, 255, 51, 1, 198, 1, 170, 255, 205, 1, 198, 1, 174, 255, 229, 1, 198, 1, 176, 255, 178, 1, 198, 1, 177, 255, 205, 1, 198, 1, 181, 255, 178, 1, 198, 1, 182, 255, 205, 1, 198, 1, 184, 255, 229, 1, 198, 1, 187, 255, 205, 1, 198, 1, 188, 255, 49, 1, 198, 1, 191, 255, 152, 1, 198, 1, 193, 255, 102, 1, 198, 1, 199, 255, 178, 1, 198, 1, 201, 255, 178, 1, 198, 2, 9, 255, 102, 1, 199, 1, 174, 255, 205, 1, 199, 1, 176, 255, 205, 1, 199, 1, 177, 255, 229, 1, 199, 1, 181, 255, 178, 1, 199, 1, 190, 255, 229, 1, 199, 1, 191, 255, 205, 1, 199, 1, 201, 255, 205, 1, 199, 1, 206, 255, 229, 1, 199, 1, 208, 0, 25, 1, 199, 1, 213, 255, 205, 1, 200, 1, 170, 255, 205, 1, 200, 1, 174, 255, 205, 1, 200, 1, 176, 255, 205, 1, 200, 1, 181, 255, 178, 1, 200, 1, 187, 255, 229, 1, 200, 1, 188, 255, 205, 1, 200, 1, 191, 255, 178, 1, 200, 1, 193, 255, 229, 1, 200, 1, 206, 255, 205, 1, 200, 1, 208, 0, 25, 1, 200, 1, 213, 255, 205, 1, 202, 1, 209, 0, 25, 1, 202, 1, 225, 255, 205, 1, 203, 1, 206, 255, 205, 1, 203, 1, 208, 255, 229, 1, 203, 1, 209, 255, 229, 1, 203, 1, 213, 255, 205, 1, 203, 1, 214, 255, 229, 1, 203, 1, 219, 255, 229, 1, 203, 1, 221, 255, 229, 1, 203, 1, 223, 255, 205, 1, 203, 1, 225, 255, 205, 1, 203, 1, 228, 255, 229, 1, 203, 1, 231, 255, 229, 1, 203, 1, 233, 255, 229, 1, 204, 1, 202, 255, 229, 1, 204, 1, 203, 255, 229, 1, 204, 1, 207, 255, 229, 1, 204, 1, 208, 255, 229, 1, 204, 1, 213, 255, 229, 1, 204, 1, 214, 255, 229, 1, 204, 1, 216, 255, 229, 1, 204, 1, 219, 255, 205, 1, 204, 1, 220, 255, 229, 1, 204, 1, 221, 255, 205, 1, 204, 1, 222, 255, 229, 1, 204, 1, 225, 255, 178, 1, 204, 1, 228, 255, 205, 1, 204, 1, 233, 255, 229, 1, 205, 0, 15, 255, 76, 1, 205, 0, 17, 255, 51, 1, 205, 1, 206, 255, 178, 1, 205, 1, 213, 255, 205, 1, 205, 1, 216, 255, 229, 1, 205, 1, 219, 255, 229, 1, 206, 1, 209, 0, 25, 1, 206, 1, 219, 255, 229, 1, 206, 1, 221, 0, 25, 1, 206, 1, 228, 255, 229, 1, 207, 1, 203, 255, 229, 1, 207, 1, 208, 255, 229, 1, 207, 1, 214, 255, 229, 1, 207, 1, 219, 255, 229, 1, 207, 1, 220, 255, 229, 1, 207, 1, 221, 255, 229, 1, 207, 1, 223, 255, 229, 1, 207, 1, 225, 255, 205, 1, 208, 1, 202, 0, 25, 1, 208, 1, 207, 255, 229, 1, 208, 1, 209, 0, 25, 1, 208, 1, 216, 255, 205, 1, 208, 1, 219, 255, 229, 1, 208, 1, 225, 255, 205, 1, 209, 1, 202, 255, 229, 1, 209, 1, 203, 255, 205, 1, 209, 1, 207, 255, 229, 1, 209, 1, 208, 255, 229, 1, 209, 1, 209, 255, 229, 1, 209, 1, 213, 255, 229, 1, 209, 1, 214, 255, 205, 1, 209, 1, 216, 255, 205, 1, 209, 1, 219, 255, 205, 1, 209, 1, 221, 255, 205, 1, 209, 1, 222, 255, 229, 1, 209, 1, 225, 255, 178, 1, 209, 1, 228, 255, 205, 1, 212, 1, 213, 0, 25, 1, 212, 1, 216, 255, 229, 1, 212, 1, 219, 255, 229, 1, 212, 1, 222, 255, 229, 1, 212, 1, 225, 255, 229, 1, 212, 1, 231, 255, 229, 1, 213, 1, 203, 255, 229, 1, 213, 1, 207, 255, 229, 1, 213, 1, 216, 255, 229, 1, 213, 1, 219, 255, 229, 1, 213, 1, 221, 255, 229, 1, 213, 1, 225, 255, 205, 1, 214, 1, 202, 255, 229, 1, 214, 1, 203, 255, 229, 1, 214, 1, 209, 255, 229, 1, 214, 1, 216, 255, 229, 1, 214, 1, 219, 255, 229, 1, 214, 1, 221, 255, 229, 1, 214, 1, 222, 255, 229, 1, 214, 1, 231, 255, 229, 1, 216, 1, 206, 255, 229, 1, 216, 1, 208, 255, 229, 1, 216, 1, 209, 255, 229, 1, 216, 1, 213, 255, 205, 1, 216, 1, 214, 255, 229, 1, 216, 1, 219, 255, 229, 1, 216, 1, 220, 255, 205, 1, 216, 1, 221, 255, 229, 1, 216, 1, 223, 255, 205, 1, 216, 1, 225, 255, 205, 1, 216, 1, 231, 255, 229, 1, 216, 1, 233, 255, 229, 1, 218, 1, 206, 255, 205, 1, 218, 1, 208, 255, 229, 1, 218, 1, 209, 255, 229, 1, 218, 1, 213, 255, 205, 1, 218, 1, 214, 255, 229, 1, 218, 1, 220, 255, 229, 1, 218, 1, 221, 255, 229, 1, 218, 1, 223, 255, 229, 1, 218, 1, 225, 255, 205, 1, 218, 1, 231, 255, 229, 1, 218, 1, 233, 255, 229, 1, 219, 1, 202, 0, 25, 1, 219, 1, 203, 255, 229, 1, 219, 1, 223, 255, 229, 1, 219, 1, 225, 255, 203, 1, 219, 1, 228, 255, 229, 1, 220, 0, 15, 255, 102, 1, 220, 0, 17, 255, 76, 1, 220, 1, 206, 255, 229, 1, 220, 1, 208, 0, 25, 1, 220, 1, 213, 255, 229, 1, 220, 1, 216, 255, 229, 1, 220, 1, 219, 255, 229, 1, 220, 1, 221, 0, 51, 1, 221, 0, 15, 255, 102, 1, 221, 0, 17, 255, 76, 1, 221, 0, 29, 255, 229, 1, 221, 0, 30, 255, 229, 1, 221, 0, 123, 0, 51, 1, 221, 1, 202, 255, 229, 1, 221, 1, 206, 255, 205, 1, 221, 1, 207, 255, 229, 1, 221, 1, 208, 0, 25, 1, 221, 1, 209, 255, 229, 1, 221, 1, 213, 255, 229, 1, 221, 1, 214, 255, 229, 1, 221, 1, 216, 255, 205, 1, 221, 1, 218, 255, 229, 1, 221, 1, 219, 255, 205, 1, 221, 1, 220, 0, 25, 1, 221, 1, 222, 255, 229, 1, 221, 1, 223, 0, 25, 1, 221, 1, 231, 255, 229, 1, 221, 1, 233, 255, 229, 1, 222, 1, 203, 255, 229, 1, 222, 1, 206, 255, 229, 1, 222, 1, 207, 255, 229, 1, 222, 1, 213, 255, 205, 1, 222, 1, 214, 255, 229, 1, 222, 1, 216, 255, 229, 1, 222, 1, 220, 255, 229, 1, 222, 1, 221, 255, 229, 1, 222, 1, 225, 255, 205, 1, 222, 1, 233, 255, 229, 1, 223, 1, 203, 255, 229, 1, 223, 1, 207, 255, 205, 1, 223, 1, 209, 255, 229, 1, 223, 1, 216, 255, 205, 1, 223, 1, 219, 255, 205, 1, 223, 1, 221, 0, 25, 1, 223, 1, 222, 255, 229, 1, 223, 1, 225, 255, 205, 1, 223, 1, 231, 255, 229, 1, 224, 1, 202, 0, 25, 1, 224, 1, 209, 0, 25, 1, 224, 1, 219, 255, 229, 1, 227, 1, 202, 0, 25, 1, 227, 1, 216, 255, 229, 1, 230, 1, 220, 255, 76, 1, 230, 1, 225, 255, 76, 1, 231, 1, 203, 255, 229, 1, 231, 1, 206, 255, 229, 1, 231, 1, 208, 255, 229, 1, 231, 1, 209, 255, 229, 1, 231, 1, 213, 255, 205, 1, 231, 1, 214, 255, 229, 1, 231, 1, 219, 255, 229, 1, 231, 1, 220, 255, 229, 1, 231, 1, 223, 255, 229, 1, 231, 1, 233, 255, 229, 1, 232, 1, 203, 255, 229, 1, 232, 1, 206, 255, 229, 1, 232, 1, 208, 255, 229, 1, 232, 1, 213, 255, 205, 1, 232, 1, 214, 255, 229, 1, 232, 1, 219, 255, 229, 1, 232, 1, 220, 255, 205, 1, 232, 1, 223, 255, 205, 1, 232, 1, 225, 255, 178, 1, 232, 1, 231, 255, 229, 1, 246, 0, 15, 255, 102, 1, 246, 0, 17, 255, 76, 1, 246, 0, 29, 255, 229, 1, 246, 0, 30, 255, 229, 1, 246, 0, 108, 255, 205, 1, 248, 0, 15, 255, 127, 1, 248, 0, 17, 255, 102, 1, 248, 0, 29, 255, 229, 1, 248, 0, 30, 255, 229, 1, 248, 0, 108, 255, 205, 1, 248, 0, 123, 255, 205, 2, 8, 2, 8, 255, 180, 2, 9, 0, 3, 255, 143, 2, 9, 0, 86, 255, 180, 2, 9, 2, 9, 255, 180, 2, 14, 1, 157, 255, 51, 2, 14, 1, 166, 255, 51, 2, 14, 1, 188, 255, 76, 2, 14, 1, 193, 255, 49, 2, 14, 1, 196, 255, 76, 0, 0, 0, 0, 0, 28, 1, 86, 0, 1, 0, 0, 0, 0, 0, 0, 0, 94, 0, 190, 0, 1, 0, 0, 0, 0, 0, 1, 0, 15, 1, 61, 0, 1, 0, 0, 0, 0, 0, 2, 0, 4, 1, 87, 0, 1, 0, 0, 0, 0, 0, 3, 0, 31, 1, 156, 0, 1, 0, 0, 0, 0, 0, 4, 0, 20, 1, 230, 0, 1, 0, 0, 0, 0, 0, 5, 0, 12, 2, 21, 0, 1, 0, 0, 0, 0, 0, 6, 0, 19, 2, 74, 0, 1, 0, 0, 0, 0, 0, 7, 0, 122, 3, 84, 0, 1, 0, 0, 0, 0, 0, 8, 0, 20, 3, 249, 0, 1, 0, 0, 0, 0, 0, 9, 0, 14, 4, 44, 0, 1, 0, 0, 0, 0, 0, 11, 0, 28, 4, 117, 0, 1, 0, 0, 0, 0, 0, 12, 0, 46, 4, 240, 0, 1, 0, 0, 0, 0, 0, 13, 0, 127, 6, 31, 0, 1, 0, 0, 0, 0, 0, 14, 0, 43, 6, 247, 0, 3, 0, 1, 4, 9, 0, 0, 0, 188, 0, 0, 0, 3, 0, 1, 4, 9, 0, 1, 0, 30, 1, 29, 0, 3, 0, 1, 4, 9, 0, 2, 0, 8, 1, 77, 0, 3, 0, 1, 4, 9, 0, 3, 0, 62, 1, 92, 0, 3, 0, 1, 4, 9, 0, 4, 0, 40, 1, 188, 0, 3, 0, 1, 4, 9, 0, 5, 0, 24, 1, 251, 0, 3, 0, 1, 4, 9, 0, 6, 0, 38, 2, 34, 0, 3, 0, 1, 4, 9, 0, 7, 0, 244, 2, 94, 0, 3, 0, 1, 4, 9, 0, 8, 0, 40, 3, 207, 0, 3, 0, 1, 4, 9, 0, 9, 0, 28, 4, 14, 0, 3, 0, 1, 4, 9, 0, 11, 0, 56, 4, 59, 0, 3, 0, 1, 4, 9, 0, 12, 0, 92, 4, 146, 0, 3, 0, 1, 4, 9, 0, 13, 0, 254, 5, 31, 0, 3, 0, 1, 4, 9, 0, 14, 0, 86, 6, 159, 0, 67, 0, 111, 0, 112, 0, 121, 0, 114, 0, 105, 0, 103, 0, 104, 0, 116, 0, 32, 0, 169, 0, 32, 0, 50, 0, 48, 0, 48, 0, 55, 0, 32, 0, 82, 0, 101, 0, 100, 0, 32, 0, 72, 0, 97, 0, 116, 0, 44, 0, 32, 0, 73, 0, 110, 0, 99, 0, 46, 0, 32, 0, 65, 0, 108, 0, 108, 0, 32, 0, 114, 0, 105, 0, 103, 0, 104, 0, 116, 0, 115, 0, 32, 0, 114, 0, 101, 0, 115, 0, 101, 0, 114, 0, 118, 0, 101, 0, 100, 0, 46, 0, 32, 0, 76, 0, 73, 0, 66, 0, 69, 0, 82, 0, 65, 0, 84, 0, 73, 0, 79, 0, 78, 0, 32, 0, 105, 0, 115, 0, 32, 0, 97, 0, 32, 0, 116, 0, 114, 0, 97, 0, 100, 0, 101, 0, 109, 0, 97, 0, 114, 0, 107, 0, 32, 0, 111, 0, 102, 0, 32, 0, 82, 0, 101, 0, 100, 0, 32, 0, 72, 0, 97, 0, 116, 0, 44, 0, 32, 0, 73, 0, 110, 0, 99, 0, 46, 0, 0, 67, 111, 112, 121, 114, 105, 103, 104, 116, 32, 169, 32, 50, 48, 48, 55, 32, 82, 101, 100, 32, 72, 97, 116, 44, 32, 73, 110, 99, 46, 32, 65, 108, 108, 32, 114, 105, 103, 104, 116, 115, 32, 114, 101, 115, 101, 114, 118, 101, 100, 46, 32, 76, 73, 66, 69, 82, 65, 84, 73, 79, 78, 32, 105, 115, 32, 97, 32, 116, 114, 97, 100, 101, 109, 97, 114, 107, 32, 111, 102, 32, 82, 101, 100, 32, 72, 97, 116, 44, 32, 73, 110, 99, 46, 0, 0, 76, 0, 105, 0, 98, 0, 101, 0, 114, 0, 97, 0, 116, 0, 105, 0, 111, 0, 110, 0, 32, 0, 83, 0, 97, 0, 110, 0, 115, 0, 0, 76, 105, 98, 101, 114, 97, 116, 105, 111, 110, 32, 83, 97, 110, 115, 0, 0, 66, 0, 111, 0, 108, 0, 100, 0, 0, 66, 111, 108, 100, 0, 0, 65, 0, 115, 0, 99, 0, 101, 0, 110, 0, 100, 0, 101, 0, 114, 0, 32, 0, 45, 0, 32, 0, 76, 0, 105, 0, 98, 0, 101, 0, 114, 0, 97, 0, 116, 0, 105, 0, 111, 0, 110, 0, 32, 0, 83, 0, 97, 0, 110, 0, 115, 0, 32, 0, 66, 0, 111, 0, 108, 0, 100, 0, 0, 65, 115, 99, 101, 110, 100, 101, 114, 32, 45, 32, 76, 105, 98, 101, 114, 97, 116, 105, 111, 110, 32, 83, 97, 110, 115, 32, 66, 111, 108, 100, 0, 0, 76, 0, 105, 0, 98, 0, 101, 0, 114, 0, 97, 0, 116, 0, 105, 0, 111, 0, 110, 0, 32, 0, 83, 0, 97, 0, 110, 0, 115, 0, 32, 0, 66, 0, 111, 0, 108, 0, 100, 0, 0, 76, 105, 98, 101, 114, 97, 116, 105, 111, 110, 32, 83, 97, 110, 115, 32, 66, 111, 108, 100, 0, 0, 86, 0, 101, 0, 114, 0, 115, 0, 105, 0, 111, 0, 110, 0, 32, 0, 49, 0, 46, 0, 48, 0, 54, 0, 0, 86, 101, 114, 115, 105, 111, 110, 32, 49, 46, 48, 54, 0, 0, 76, 0, 105, 0, 98, 0, 101, 0, 114, 0, 97, 0, 116, 0, 105, 0, 111, 0, 110, 0, 83, 0, 97, 0, 110, 0, 115, 0, 45, 0, 66, 0, 111, 0, 108, 0, 100, 0, 0, 76, 105, 98, 101, 114, 97, 116, 105, 111, 110, 83, 97, 110, 115, 45, 66, 111, 108, 100, 0, 0, 76, 0, 105, 0, 98, 0, 101, 0, 114, 0, 97, 0, 116, 0, 105, 0, 111, 0, 110, 0, 32, 0, 105, 0, 115, 0, 32, 0, 97, 0, 32, 0, 116, 0, 114, 0, 97, 0, 100, 0, 101, 0, 109, 0, 97, 0, 114, 0, 107, 0, 32, 0, 111, 0, 102, 0, 32, 0, 82, 0, 101, 0, 100, 0, 32, 0, 72, 0, 97, 0, 116, 0, 44, 0, 32, 0, 73, 0, 110, 0, 99, 0, 46, 0, 32, 0, 114, 0, 101, 0, 103, 0, 105, 0, 115, 0, 116, 0, 101, 0, 114, 0, 101, 0, 100, 0, 32, 0, 105, 0, 110, 0, 32, 0, 85, 0, 46, 0, 83, 0, 46, 0, 32, 0, 80, 0, 97, 0, 116, 0, 101, 0, 110, 0, 116, 0, 32, 0, 97, 0, 110, 0, 100, 0, 32, 0, 84, 0, 114, 0, 97, 0, 100, 0, 101, 0, 109, 0, 97, 0, 114, 0, 107, 0, 32, 0, 79, 0, 102, 0, 102, 0, 105, 0, 99, 0, 101, 0, 32, 0, 97, 0, 110, 0, 100, 0, 32, 0, 99, 0, 101, 0, 114, 0, 116, 0, 97, 0, 105, 0, 110, 0, 32, 0, 111, 0, 116, 0, 104, 0, 101, 0, 114, 0, 32, 0, 106, 0, 117, 0, 114, 0, 105, 0, 115, 0, 100, 0, 105, 0, 99, 0, 116, 0, 105, 0, 111, 0, 110, 0, 115, 0, 46, 0, 0, 76, 105, 98, 101, 114, 97, 116, 105, 111, 110, 32, 105, 115, 32, 97, 32, 116, 114, 97, 100, 101, 109, 97, 114, 107, 32, 111, 102, 32, 82, 101, 100, 32, 72, 97, 116, 44, 32, 73, 110, 99, 46, 32, 114, 101, 103, 105, 115, 116, 101, 114, 101, 100, 32, 105, 110, 32, 85, 46, 83, 46, 32, 80, 97, 116, 101, 110, 116, 32, 97, 110, 100, 32, 84, 114, 97, 100, 101, 109, 97, 114, 107, 32, 79, 102, 102, 105, 99, 101, 32, 97, 110, 100, 32, 99, 101, 114, 116, 97, 105, 110, 32, 111, 116, 104, 101, 114, 32, 106, 117, 114, 105, 115, 100, 105, 99, 116, 105, 111, 110, 115, 46, 0, 0, 65, 0, 115, 0, 99, 0, 101, 0, 110, 0, 100, 0, 101, 0, 114, 0, 32, 0, 67, 0, 111, 0, 114, 0, 112, 0, 111, 0, 114, 0, 97, 0, 116, 0, 105, 0, 111, 0, 110, 0, 0, 65, 115, 99, 101, 110, 100, 101, 114, 32, 67, 111, 114, 112, 111, 114, 97, 116, 105, 111, 110, 0, 0, 83, 0, 116, 0, 101, 0, 118, 0, 101, 0, 32, 0, 77, 0, 97, 0, 116, 0, 116, 0, 101, 0, 115, 0, 111, 0, 110, 0, 0, 83, 116, 101, 118, 101, 32, 77, 97, 116, 116, 101, 115, 111, 110, 0, 0, 104, 0, 116, 0, 116, 0, 112, 0, 58, 0, 47, 0, 47, 0, 119, 0, 119, 0, 119, 0, 46, 0, 97, 0, 115, 0, 99, 0, 101, 0, 110, 0, 100, 0, 101, 0, 114, 0, 99, 0, 111, 0, 114, 0, 112, 0, 46, 0, 99, 0, 111, 0, 109, 0, 47, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 97, 115, 99, 101, 110, 100, 101, 114, 99, 111, 114, 112, 46, 99, 111, 109, 47, 0, 0, 104, 0, 116, 0, 116, 0, 112, 0, 58, 0, 47, 0, 47, 0, 119, 0, 119, 0, 119, 0, 46, 0, 97, 0, 115, 0, 99, 0, 101, 0, 110, 0, 100, 0, 101, 0, 114, 0, 99, 0, 111, 0, 114, 0, 112, 0, 46, 0, 99, 0, 111, 0, 109, 0, 47, 0, 116, 0, 121, 0, 112, 0, 101, 0, 100, 0, 101, 0, 115, 0, 105, 0, 103, 0, 110, 0, 101, 0, 114, 0, 115, 0, 46, 0, 104, 0, 116, 0, 109, 0, 108, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 97, 115, 99, 101, 110, 100, 101, 114, 99, 111, 114, 112, 46, 99, 111, 109, 47, 116, 121, 112, 101, 100, 101, 115, 105, 103, 110, 101, 114, 115, 46, 104, 116, 109, 108, 0, 0, 85, 0, 115, 0, 101, 0, 32, 0, 111, 0, 102, 0, 32, 0, 116, 0, 104, 0, 105, 0, 115, 0, 32, 0, 76, 0, 105, 0, 98, 0, 101, 0, 114, 0, 97, 0, 116, 0, 105, 0, 111, 0, 110, 0, 32, 0, 102, 0, 111, 0, 110, 0, 116, 0, 32, 0, 115, 0, 111, 0, 102, 0, 116, 0, 119, 0, 97, 0, 114, 0, 101, 0, 32, 0, 105, 0, 115, 0, 32, 0, 115, 0, 117, 0, 98, 0, 106, 0, 101, 0, 99, 0, 116, 0, 32, 0, 116, 0, 111, 0, 32, 0, 116, 0, 104, 0, 101, 0, 32, 0, 108, 0, 105, 0, 99, 0, 101, 0, 110, 0, 115, 0, 101, 0, 32, 0, 97, 0, 103, 0, 114, 0, 101, 0, 101, 0, 109, 0, 101, 0, 110, 0, 116, 0, 32, 0, 117, 0, 110, 0, 100, 0, 101, 0, 114, 0, 32, 0, 119, 0, 104, 0, 105, 0, 99, 0, 104, 0, 32, 0, 121, 0, 111, 0, 117, 0, 32, 0, 97, 0, 99, 0, 99, 0, 101, 0, 112, 0, 116, 0, 101, 0, 100, 0, 32, 0, 116, 0, 104, 0, 101, 0, 32, 0, 76, 0, 105, 0, 98, 0, 101, 0, 114, 0, 97, 0, 116, 0, 105, 0, 111, 0, 110, 0, 32, 0, 102, 0, 111, 0, 110, 0, 116, 0, 32, 0, 115, 0, 111, 0, 102, 0, 116, 0, 119, 0, 97, 0, 114, 0, 101, 0, 46, 0, 0, 85, 115, 101, 32, 111, 102, 32, 116, 104, 105, 115, 32, 76, 105, 98, 101, 114, 97, 116, 105, 111, 110, 32, 102, 111, 110, 116, 32, 115, 111, 102, 116, 119, 97, 114, 101, 32, 105, 115, 32, 115, 117, 98, 106, 101, 99, 116, 32, 116, 111, 32, 116, 104, 101, 32, 108, 105, 99, 101, 110, 115, 101, 32, 97, 103, 114, 101, 101, 109, 101, 110, 116, 32, 117, 110, 100, 101, 114, 32, 119, 104, 105, 99, 104, 32, 121, 111, 117, 32, 97, 99, 99, 101, 112, 116, 101, 100, 32, 116, 104, 101, 32, 76, 105, 98, 101, 114, 97, 116, 105, 111, 110, 32, 102, 111, 110, 116, 32, 115, 111, 102, 116, 119, 97, 114, 101, 46, 0, 0, 104, 0, 116, 0, 116, 0, 112, 0, 58, 0, 47, 0, 47, 0, 119, 0, 119, 0, 119, 0, 46, 0, 97, 0, 115, 0, 99, 0, 101, 0, 110, 0, 100, 0, 101, 0, 114, 0, 99, 0, 111, 0, 114, 0, 112, 0, 46, 0, 99, 0, 111, 0, 109, 0, 47, 0, 108, 0, 105, 0, 98, 0, 101, 0, 114, 0, 97, 0, 116, 0, 105, 0, 111, 0, 110, 0, 46, 0, 104, 0, 116, 0, 109, 0, 108, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 97, 115, 99, 101, 110, 100, 101, 114, 99, 111, 114, 112, 46, 99, 111, 109, 47, 108, 105, 98, 101, 114, 97, 116, 105, 111, 110, 46, 104, 116, 109, 108, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 255, 39, 0, 215, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 162, 0, 0, 0, 1, 0, 2, 1, 2, 0, 4, 0, 5, 0, 6, 0, 7, 0, 8, 0, 9, 0, 10, 0, 11, 0, 12, 0, 13, 0, 14, 0, 15, 1, 3, 0, 17, 0, 18, 0, 19, 0, 20, 0, 21, 0, 22, 0, 23, 0, 24, 0, 25, 0, 26, 0, 27, 0, 28, 0, 29, 1, 4, 0, 31, 0, 32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 163, 0, 132, 0, 133, 0, 189, 0, 150, 0, 232, 0, 134, 0, 142, 0, 139, 0, 157, 0, 169, 0, 164, 0, 138, 0, 218, 0, 131, 0, 147, 1, 5, 1, 6, 0, 141, 1, 7, 0, 136, 1, 8, 0, 222, 1, 9, 0, 158, 0, 170, 0, 245, 0, 244, 0, 246, 0, 162, 0, 173, 0, 201, 0, 199, 0, 174, 0, 98, 0, 99, 0, 144, 0, 100, 0, 203, 0, 101, 0, 200, 0, 202, 0, 207, 0, 204, 0, 205, 0, 206, 0, 233, 0, 102, 0, 211, 0, 208, 0, 209, 0, 175, 0, 103, 0, 240, 0, 145, 0, 214, 0, 212, 0, 213, 0, 104, 0, 235, 0, 237, 0, 137, 0, 106, 0, 105, 0, 107, 0, 109, 0, 108, 0, 110, 0, 160, 0, 111, 0, 113, 0, 112, 0, 114, 0, 115, 0, 117, 0, 116, 0, 118, 0, 119, 0, 234, 0, 120, 0, 122, 0, 121, 0, 123, 0, 125, 0, 124, 0, 184, 0, 161, 0, 127, 0, 126, 0, 128, 0, 129, 0, 236, 0, 238, 0, 186, 1, 10, 1, 11, 1, 12, 1, 13, 1, 14, 1, 15, 0, 253, 0, 254, 1, 16, 1, 17, 1, 18, 1, 19, 0, 255, 1, 0, 1, 20, 1, 21, 1, 22, 1, 1, 1, 23, 1, 24, 1, 25, 1, 26, 1, 27, 1, 28, 1, 29, 1, 30, 1, 31, 1, 32, 1, 33, 1, 34, 0, 248, 0, 249, 1, 35, 1, 36, 1, 37, 1, 38, 1, 39, 1, 40, 1, 41, 1, 42, 1, 43, 1, 44, 1, 45, 1, 46, 1, 47, 1, 48, 1, 49, 1, 50, 0, 250, 0, 215, 1, 51, 1, 52, 1, 53, 1, 54, 1, 55, 1, 56, 1, 57, 1, 58, 1, 59, 1, 60, 1, 61, 1, 62, 1, 63, 1, 64, 1, 65, 0, 226, 0, 227, 1, 66, 1, 67, 1, 68, 1, 69, 1, 70, 1, 71, 1, 72, 1, 73, 1, 74, 1, 75, 1, 76, 1, 77, 1, 78, 1, 79, 1, 80, 0, 176, 0, 177, 1, 81, 1, 82, 1, 83, 1, 84, 1, 85, 1, 86, 1, 87, 1, 88, 1, 89, 1, 90, 0, 251, 0, 252, 0, 228, 0, 229, 1, 91, 1, 92, 1, 93, 1, 94, 1, 95, 1, 96, 1, 97, 1, 98, 1, 99, 1, 100, 1, 101, 1, 102, 1, 103, 1, 104, 1, 105, 1, 106, 1, 107, 1, 108, 1, 109, 1, 110, 1, 111, 1, 112, 0, 187, 1, 113, 1, 114, 1, 115, 1, 116, 0, 230, 0, 231, 1, 117, 0, 166, 1, 118, 1, 119, 1, 120, 1, 121, 1, 122, 1, 123, 1, 124, 1, 125, 1, 126, 1, 127, 0, 216, 0, 225, 1, 128, 0, 219, 0, 220, 0, 221, 0, 224, 0, 217, 0, 223, 1, 129, 1, 130, 1, 131, 1, 132, 1, 133, 1, 134, 1, 135, 1, 136, 1, 137, 1, 138, 1, 139, 1, 140, 1, 141, 1, 142, 0, 168, 1, 143, 1, 144, 1, 145, 1, 146, 1, 147, 1, 148, 1, 149, 1, 150, 1, 151, 1, 152, 1, 153, 1, 154, 1, 155, 1, 156, 1, 157, 1, 158, 1, 159, 1, 160, 1, 161, 0, 159, 1, 162, 1, 163, 1, 164, 1, 165, 1, 166, 1, 167, 1, 168, 1, 169, 1, 170, 1, 171, 1, 172, 1, 173, 1, 174, 1, 175, 1, 176, 1, 177, 1, 178, 1, 179, 0, 151, 1, 180, 1, 181, 1, 182, 0, 155, 1, 183, 1, 184, 1, 185, 1, 186, 1, 187, 1, 188, 1, 189, 1, 190, 1, 191, 1, 192, 1, 193, 1, 194, 1, 195, 1, 196, 1, 197, 1, 198, 1, 199, 1, 200, 1, 201, 1, 202, 1, 203, 1, 204, 1, 205, 1, 206, 1, 207, 1, 208, 1, 209, 1, 210, 1, 211, 1, 212, 1, 213, 1, 214, 1, 215, 1, 216, 1, 217, 1, 218, 1, 219, 1, 220, 1, 221, 1, 222, 1, 223, 1, 224, 1, 225, 1, 226, 1, 227, 1, 228, 1, 229, 1, 230, 1, 231, 1, 232, 1, 233, 1, 234, 1, 235, 1, 236, 1, 237, 1, 238, 1, 239, 1, 240, 1, 241, 1, 242, 1, 243, 1, 244, 1, 245, 1, 246, 1, 247, 1, 248, 1, 249, 1, 250, 1, 251, 1, 252, 1, 253, 1, 254, 1, 255, 2, 0, 2, 1, 2, 2, 2, 3, 2, 4, 2, 5, 2, 6, 2, 7, 2, 8, 2, 9, 2, 10, 2, 11, 2, 12, 2, 13, 2, 14, 2, 15, 2, 16, 2, 17, 2, 18, 2, 19, 2, 20, 2, 21, 2, 22, 2, 23, 2, 24, 2, 25, 2, 26, 2, 27, 2, 28, 2, 29, 2, 30, 2, 31, 2, 32, 2, 33, 2, 34, 2, 35, 2, 36, 2, 37, 2, 38, 2, 39, 2, 40, 2, 41, 2, 42, 2, 43, 2, 44, 0, 178, 0, 179, 2, 45, 2, 46, 0, 182, 0, 183, 0, 196, 2, 47, 0, 180, 0, 181, 0, 197, 0, 130, 0, 194, 0, 135, 0, 171, 0, 198, 2, 48, 2, 49, 0, 190, 0, 191, 2, 50, 2, 51, 2, 52, 2, 53, 0, 247, 2, 54, 2, 55, 2, 56, 2, 57, 2, 58, 2, 59, 0, 140, 2, 60, 2, 61, 2, 62, 2, 63, 2, 64, 2, 65, 2, 66, 2, 67, 2, 68, 2, 69, 2, 70, 2, 71, 2, 72, 0, 152, 2, 73, 0, 154, 0, 153, 0, 239, 0, 165, 0, 146, 2, 74, 2, 75, 0, 156, 0, 167, 0, 143, 2, 76, 0, 148, 0, 149, 2, 77, 2, 78, 2, 79, 2, 80, 2, 81, 2, 82, 2, 83, 2, 84, 2, 85, 2, 86, 2, 87, 2, 88, 2, 89, 2, 90, 2, 91, 2, 92, 2, 93, 2, 94, 2, 95, 2, 96, 2, 97, 2, 98, 2, 99, 2, 100, 2, 101, 2, 102, 2, 103, 2, 104, 2, 105, 2, 106, 2, 107, 2, 108, 2, 109, 2, 110, 2, 111, 2, 112, 2, 113, 2, 114, 2, 115, 2, 116, 2, 117, 2, 118, 2, 119, 2, 120, 2, 121, 2, 122, 2, 123, 2, 124, 2, 125, 2, 126, 2, 127, 2, 128, 2, 129, 2, 130, 2, 131, 2, 132, 2, 133, 2, 134, 2, 135, 2, 136, 2, 137, 0, 185, 2, 138, 2, 139, 2, 140, 2, 141, 2, 142, 2, 143, 2, 144, 2, 145, 2, 146, 2, 147, 2, 148, 2, 149, 2, 150, 2, 151, 2, 152, 2, 153, 2, 154, 2, 155, 2, 156, 2, 157, 2, 158, 2, 159, 2, 160, 2, 161, 2, 162, 2, 163, 2, 164, 2, 165, 2, 166, 2, 167, 2, 168, 2, 169, 2, 170, 2, 171, 2, 172, 2, 173, 7, 117, 110, 105, 48, 48, 65, 48, 7, 117, 110, 105, 48, 48, 65, 68, 7, 117, 110, 105, 48, 51, 55, 69, 7, 117, 110, 105, 48, 48, 66, 50, 7, 117, 110, 105, 48, 48, 66, 51, 7, 117, 110, 105, 48, 48, 66, 53, 7, 117, 110, 105, 50, 50, 49, 57, 7, 117, 110, 105, 48, 48, 66, 57, 7, 65, 109, 97, 99, 114, 111, 110, 7, 97, 109, 97, 99, 114, 111, 110, 6, 65, 98, 114, 101, 118, 101, 6, 97, 98, 114, 101, 118, 101, 7, 65, 111, 103, 111, 110, 101, 107, 7, 97, 111, 103, 111, 110, 101, 107, 11, 67, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 11, 99, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 10, 67, 100, 111, 116, 97, 99, 99, 101, 110, 116, 10, 99, 100, 111, 116, 97, 99, 99, 101, 110, 116, 6, 68, 99, 97, 114, 111, 110, 6, 100, 99, 97, 114, 111, 110, 6, 68, 99, 114, 111, 97, 116, 7, 69, 109, 97, 99, 114, 111, 110, 7, 101, 109, 97, 99, 114, 111, 110, 6, 69, 98, 114, 101, 118, 101, 6, 101, 98, 114, 101, 118, 101, 10, 69, 100, 111, 116, 97, 99, 99, 101, 110, 116, 10, 101, 100, 111, 116, 97, 99, 99, 101, 110, 116, 7, 69, 111, 103, 111, 110, 101, 107, 7, 101, 111, 103, 111, 110, 101, 107, 6, 69, 99, 97, 114, 111, 110, 6, 101, 99, 97, 114, 111, 110, 11, 71, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 11, 103, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 10, 71, 100, 111, 116, 97, 99, 99, 101, 110, 116, 10, 103, 100, 111, 116, 97, 99, 99, 101, 110, 116, 12, 71, 99, 111, 109, 109, 97, 97, 99, 99, 101, 110, 116, 12, 103, 99, 111, 109, 109, 97, 97, 99, 99, 101, 110, 116, 11, 72, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 11, 104, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 4, 72, 98, 97, 114, 4, 104, 98, 97, 114, 6, 73, 116, 105, 108, 100, 101, 6, 105, 116, 105, 108, 100, 101, 7, 73, 109, 97, 99, 114, 111, 110, 7, 105, 109, 97, 99, 114, 111, 110, 6, 73, 98, 114, 101, 118, 101, 6, 105, 98, 114, 101, 118, 101, 7, 73, 111, 103, 111, 110, 101, 107, 7, 105, 111, 103, 111, 110, 101, 107, 2, 73, 74, 2, 105, 106, 11, 74, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 11, 106, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 12, 75, 99, 111, 109, 109, 97, 97, 99, 99, 101, 110, 116, 12, 107, 99, 111, 109, 109, 97, 97, 99, 99, 101, 110, 116, 12, 107, 103, 114, 101, 101, 110, 108, 97, 110, 100, 105, 99, 6, 76, 97, 99, 117, 116, 101, 6, 108, 97, 99, 117, 116, 101, 12, 76, 99, 111, 109, 109, 97, 97, 99, 99, 101, 110, 116, 12, 108, 99, 111, 109, 109, 97, 97, 99, 99, 101, 110, 116, 6, 76, 99, 97, 114, 111, 110, 6, 108, 99, 97, 114, 111, 110, 4, 76, 100, 111, 116, 4, 108, 100, 111, 116, 6, 78, 97, 99, 117, 116, 101, 6, 110, 97, 99, 117, 116, 101, 12, 78, 99, 111, 109, 109, 97, 97, 99, 99, 101, 110, 116, 12, 110, 99, 111, 109, 109, 97, 97, 99, 99, 101, 110, 116, 6, 78, 99, 97, 114, 111, 110, 6, 110, 99, 97, 114, 111, 110, 11, 110, 97, 112, 111, 115, 116, 114, 111, 112, 104, 101, 3, 69, 110, 103, 3, 101, 110, 103, 7, 79, 109, 97, 99, 114, 111, 110, 7, 111, 109, 97, 99, 114, 111, 110, 6, 79, 98, 114, 101, 118, 101, 6, 111, 98, 114, 101, 118, 101, 13, 79, 104, 117, 110, 103, 97, 114, 117, 109, 108, 97, 117, 116, 13, 111, 104, 117, 110, 103, 97, 114, 117, 109, 108, 97, 117, 116, 6, 82, 97, 99, 117, 116, 101, 6, 114, 97, 99, 117, 116, 101, 12, 82, 99, 111, 109, 109, 97, 97, 99, 99, 101, 110, 116, 12, 114, 99, 111, 109, 109, 97, 97, 99, 99, 101, 110, 116, 6, 82, 99, 97, 114, 111, 110, 6, 114, 99, 97, 114, 111, 110, 6, 83, 97, 99, 117, 116, 101, 6, 115, 97, 99, 117, 116, 101, 11, 83, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 11, 115, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 12, 84, 99, 111, 109, 109, 97, 97, 99, 99, 101, 110, 116, 12, 116, 99, 111, 109, 109, 97, 97, 99, 99, 101, 110, 116, 6, 84, 99, 97, 114, 111, 110, 6, 116, 99, 97, 114, 111, 110, 4, 84, 98, 97, 114, 4, 116, 98, 97, 114, 6, 85, 116, 105, 108, 100, 101, 6, 117, 116, 105, 108, 100, 101, 7, 85, 109, 97, 99, 114, 111, 110, 7, 117, 109, 97, 99, 114, 111, 110, 6, 85, 98, 114, 101, 118, 101, 6, 117, 98, 114, 101, 118, 101, 5, 85, 114, 105, 110, 103, 5, 117, 114, 105, 110, 103, 13, 85, 104, 117, 110, 103, 97, 114, 117, 109, 108, 97, 117, 116, 13, 117, 104, 117, 110, 103, 97, 114, 117, 109, 108, 97, 117, 116, 7, 85, 111, 103, 111, 110, 101, 107, 7, 117, 111, 103, 111, 110, 101, 107, 11, 87, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 11, 119, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 11, 89, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 11, 121, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 6, 90, 97, 99, 117, 116, 101, 6, 122, 97, 99, 117, 116, 101, 10, 90, 100, 111, 116, 97, 99, 99, 101, 110, 116, 10, 122, 100, 111, 116, 97, 99, 99, 101, 110, 116, 5, 108, 111, 110, 103, 115, 10, 65, 114, 105, 110, 103, 97, 99, 117, 116, 101, 10, 97, 114, 105, 110, 103, 97, 99, 117, 116, 101, 7, 65, 69, 97, 99, 117, 116, 101, 7, 97, 101, 97, 99, 117, 116, 101, 11, 79, 115, 108, 97, 115, 104, 97, 99, 117, 116, 101, 11, 111, 115, 108, 97, 115, 104, 97, 99, 117, 116, 101, 12, 83, 99, 111, 109, 109, 97, 97, 99, 99, 101, 110, 116, 12, 115, 99, 111, 109, 109, 97, 97, 99, 99, 101, 110, 116, 7, 117, 110, 105, 48, 50, 49, 65, 7, 117, 110, 105, 48, 50, 49, 66, 7, 117, 110, 105, 48, 50, 67, 57, 5, 116, 111, 110, 111, 115, 13, 100, 105, 101, 114, 101, 115, 105, 115, 116, 111, 110, 111, 115, 10, 65, 108, 112, 104, 97, 116, 111, 110, 111, 115, 9, 97, 110, 111, 116, 101, 108, 101, 105, 97, 12, 69, 112, 115, 105, 108, 111, 110, 116, 111, 110, 111, 115, 8, 69, 116, 97, 116, 111, 110, 111, 115, 9, 73, 111, 116, 97, 116, 111, 110, 111, 115, 12, 79, 109, 105, 99, 114, 111, 110, 116, 111, 110, 111, 115, 12, 85, 112, 115, 105, 108, 111, 110, 116, 111, 110, 111, 115, 10, 79, 109, 101, 103, 97, 116, 111, 110, 111, 115, 17, 105, 111, 116, 97, 100, 105, 101, 114, 101, 115, 105, 115, 116, 111, 110, 111, 115, 5, 65, 108, 112, 104, 97, 4, 66, 101, 116, 97, 5, 71, 97, 109, 109, 97, 7, 69, 112, 115, 105, 108, 111, 110, 4, 90, 101, 116, 97, 3, 69, 116, 97, 5, 84, 104, 101, 116, 97, 4, 73, 111, 116, 97, 5, 75, 97, 112, 112, 97, 6, 76, 97, 109, 98, 100, 97, 2, 77, 117, 2, 78, 117, 2, 88, 105, 7, 79, 109, 105, 99, 114, 111, 110, 2, 80, 105, 3, 82, 104, 111, 5, 83, 105, 103, 109, 97, 3, 84, 97, 117, 7, 85, 112, 115, 105, 108, 111, 110, 3, 80, 104, 105, 3, 67, 104, 105, 3, 80, 115, 105, 12, 73, 111, 116, 97, 100, 105, 101, 114, 101, 115, 105, 115, 15, 85, 112, 115, 105, 108, 111, 110, 100, 105, 101, 114, 101, 115, 105, 115, 10, 97, 108, 112, 104, 97, 116, 111, 110, 111, 115, 12, 101, 112, 115, 105, 108, 111, 110, 116, 111, 110, 111, 115, 8, 101, 116, 97, 116, 111, 110, 111, 115, 9, 105, 111, 116, 97, 116, 111, 110, 111, 115, 20, 117, 112, 115, 105, 108, 111, 110, 100, 105, 101, 114, 101, 115, 105, 115, 116, 111, 110, 111, 115, 5, 97, 108, 112, 104, 97, 4, 98, 101, 116, 97, 5, 103, 97, 109, 109, 97, 5, 100, 101, 108, 116, 97, 7, 101, 112, 115, 105, 108, 111, 110, 4, 122, 101, 116, 97, 3, 101, 116, 97, 5, 116, 104, 101, 116, 97, 4, 105, 111, 116, 97, 5, 107, 97, 112, 112, 97, 6, 108, 97, 109, 98, 100, 97, 2, 110, 117, 2, 120, 105, 7, 111, 109, 105, 99, 114, 111, 110, 3, 114, 104, 111, 6, 115, 105, 103, 109, 97, 49, 5, 115, 105, 103, 109, 97, 3, 116, 97, 117, 7, 117, 112, 115, 105, 108, 111, 110, 3, 112, 104, 105, 3, 99, 104, 105, 3, 112, 115, 105, 5, 111, 109, 101, 103, 97, 12, 105, 111, 116, 97, 100, 105, 101, 114, 101, 115, 105, 115, 15, 117, 112, 115, 105, 108, 111, 110, 100, 105, 101, 114, 101, 115, 105, 115, 12, 111, 109, 105, 99, 114, 111, 110, 116, 111, 110, 111, 115, 12, 117, 112, 115, 105, 108, 111, 110, 116, 111, 110, 111, 115, 10, 111, 109, 101, 103, 97, 116, 111, 110, 111, 115, 9, 97, 102, 105, 105, 49, 48, 48, 50, 51, 9, 97, 102, 105, 105, 49, 48, 48, 53, 49, 9, 97, 102, 105, 105, 49, 48, 48, 53, 50, 9, 97, 102, 105, 105, 49, 48, 48, 53, 51, 9, 97, 102, 105, 105, 49, 48, 48, 53, 52, 9, 97, 102, 105, 105, 49, 48, 48, 53, 53, 9, 97, 102, 105, 105, 49, 48, 48, 53, 54, 9, 97, 102, 105, 105, 49, 48, 48, 53, 55, 9, 97, 102, 105, 105, 49, 48, 48, 53, 56, 9, 97, 102, 105, 105, 49, 48, 48, 53, 57, 9, 97, 102, 105, 105, 49, 48, 48, 54, 48, 9, 97, 102, 105, 105, 49, 48, 48, 54, 49, 9, 97, 102, 105, 105, 49, 48, 48, 54, 50, 9, 97, 102, 105, 105, 49, 48, 49, 52, 53, 9, 97, 102, 105, 105, 49, 48, 48, 49, 55, 9, 97, 102, 105, 105, 49, 48, 48, 49, 56, 9, 97, 102, 105, 105, 49, 48, 48, 49, 57, 9, 97, 102, 105, 105, 49, 48, 48, 50, 48, 9, 97, 102, 105, 105, 49, 48, 48, 50, 49, 9, 97, 102, 105, 105, 49, 48, 48, 50, 50, 9, 97, 102, 105, 105, 49, 48, 48, 50, 52, 9, 97, 102, 105, 105, 49, 48, 48, 50, 53, 9, 97, 102, 105, 105, 49, 48, 48, 50, 54, 9, 97, 102, 105, 105, 49, 48, 48, 50, 55, 9, 97, 102, 105, 105, 49, 48, 48, 50, 56, 9, 97, 102, 105, 105, 49, 48, 48, 50, 57, 9, 97, 102, 105, 105, 49, 48, 48, 51, 48, 9, 97, 102, 105, 105, 49, 48, 48, 51, 49, 9, 97, 102, 105, 105, 49, 48, 48, 51, 50, 9, 97, 102, 105, 105, 49, 48, 48, 51, 51, 9, 97, 102, 105, 105, 49, 48, 48, 51, 52, 9, 97, 102, 105, 105, 49, 48, 48, 51, 53, 9, 97, 102, 105, 105, 49, 48, 48, 51, 54, 9, 97, 102, 105, 105, 49, 48, 48, 51, 55, 9, 97, 102, 105, 105, 49, 48, 48, 51, 56, 9, 97, 102, 105, 105, 49, 48, 48, 51, 57, 9, 97, 102, 105, 105, 49, 48, 48, 52, 48, 9, 97, 102, 105, 105, 49, 48, 48, 52, 49, 9, 97, 102, 105, 105, 49, 48, 48, 52, 50, 9, 97, 102, 105, 105, 49, 48, 48, 52, 51, 9, 97, 102, 105, 105, 49, 48, 48, 52, 52, 9, 97, 102, 105, 105, 49, 48, 48, 52, 53, 9, 97, 102, 105, 105, 49, 48, 48, 52, 54, 9, 97, 102, 105, 105, 49, 48, 48, 52, 55, 9, 97, 102, 105, 105, 49, 48, 48, 52, 56, 9, 97, 102, 105, 105, 49, 48, 48, 52, 57, 9, 97, 102, 105, 105, 49, 48, 48, 54, 53, 9, 97, 102, 105, 105, 49, 48, 48, 54, 54, 9, 97, 102, 105, 105, 49, 48, 48, 54, 55, 9, 97, 102, 105, 105, 49, 48, 48, 54, 56, 9, 97, 102, 105, 105, 49, 48, 48, 54, 57, 9, 97, 102, 105, 105, 49, 48, 48, 55, 48, 9, 97, 102, 105, 105, 49, 48, 48, 55, 50, 9, 97, 102, 105, 105, 49, 48, 48, 55, 51, 9, 97, 102, 105, 105, 49, 48, 48, 55, 52, 9, 97, 102, 105, 105, 49, 48, 48, 55, 53, 9, 97, 102, 105, 105, 49, 48, 48, 55, 54, 9, 97, 102, 105, 105, 49, 48, 48, 55, 55, 9, 97, 102, 105, 105, 49, 48, 48, 55, 56, 9, 97, 102, 105, 105, 49, 48, 48, 55, 57, 9, 97, 102, 105, 105, 49, 48, 48, 56, 48, 9, 97, 102, 105, 105, 49, 48, 48, 56, 49, 9, 97, 102, 105, 105, 49, 48, 48, 56, 50, 9, 97, 102, 105, 105, 49, 48, 48, 56, 51, 9, 97, 102, 105, 105, 49, 48, 48, 56, 52, 9, 97, 102, 105, 105, 49, 48, 48, 56, 53, 9, 97, 102, 105, 105, 49, 48, 48, 56, 54, 9, 97, 102, 105, 105, 49, 48, 48, 56, 55, 9, 97, 102, 105, 105, 49, 48, 48, 56, 56, 9, 97, 102, 105, 105, 49, 48, 48, 56, 57, 9, 97, 102, 105, 105, 49, 48, 48, 57, 48, 9, 97, 102, 105, 105, 49, 48, 48, 57, 49, 9, 97, 102, 105, 105, 49, 48, 48, 57, 50, 9, 97, 102, 105, 105, 49, 48, 48, 57, 51, 9, 97, 102, 105, 105, 49, 48, 48, 57, 52, 9, 97, 102, 105, 105, 49, 48, 48, 57, 53, 9, 97, 102, 105, 105, 49, 48, 48, 57, 54, 9, 97, 102, 105, 105, 49, 48, 48, 57, 55, 9, 97, 102, 105, 105, 49, 48, 48, 55, 49, 9, 97, 102, 105, 105, 49, 48, 48, 57, 57, 9, 97, 102, 105, 105, 49, 48, 49, 48, 48, 9, 97, 102, 105, 105, 49, 48, 49, 48, 49, 9, 97, 102, 105, 105, 49, 48, 49, 48, 50, 9, 97, 102, 105, 105, 49, 48, 49, 48, 51, 9, 97, 102, 105, 105, 49, 48, 49, 48, 52, 9, 97, 102, 105, 105, 49, 48, 49, 48, 53, 9, 97, 102, 105, 105, 49, 48, 49, 48, 54, 9, 97, 102, 105, 105, 49, 48, 49, 48, 55, 9, 97, 102, 105, 105, 49, 48, 49, 48, 56, 9, 97, 102, 105, 105, 49, 48, 49, 48, 57, 9, 97, 102, 105, 105, 49, 48, 49, 49, 48, 9, 97, 102, 105, 105, 49, 48, 49, 57, 51, 9, 97, 102, 105, 105, 49, 48, 48, 53, 48, 9, 97, 102, 105, 105, 49, 48, 48, 57, 56, 6, 87, 103, 114, 97, 118, 101, 6, 119, 103, 114, 97, 118, 101, 6, 87, 97, 99, 117, 116, 101, 6, 119, 97, 99, 117, 116, 101, 9, 87, 100, 105, 101, 114, 101, 115, 105, 115, 9, 119, 100, 105, 101, 114, 101, 115, 105, 115, 6, 89, 103, 114, 97, 118, 101, 6, 121, 103, 114, 97, 118, 101, 7, 117, 110, 105, 50, 48, 49, 48, 7, 117, 110, 105, 50, 48, 49, 49, 9, 97, 102, 105, 105, 48, 48, 50, 48, 56, 13, 117, 110, 100, 101, 114, 115, 99, 111, 114, 101, 100, 98, 108, 13, 113, 117, 111, 116, 101, 114, 101, 118, 101, 114, 115, 101, 100, 6, 109, 105, 110, 117, 116, 101, 6, 115, 101, 99, 111, 110, 100, 9, 101, 120, 99, 108, 97, 109, 100, 98, 108, 7, 117, 110, 105, 50, 48, 51, 69, 7, 117, 110, 105, 50, 50, 49, 53, 7, 117, 110, 105, 50, 48, 55, 70, 4, 108, 105, 114, 97, 6, 112, 101, 115, 101, 116, 97, 4, 69, 117, 114, 111, 9, 97, 102, 105, 105, 54, 49, 50, 52, 56, 9, 97, 102, 105, 105, 54, 49, 50, 56, 57, 9, 97, 102, 105, 105, 54, 49, 51, 53, 50, 7, 117, 110, 105, 50, 49, 50, 54, 9, 101, 115, 116, 105, 109, 97, 116, 101, 100, 9, 111, 110, 101, 101, 105, 103, 104, 116, 104, 12, 116, 104, 114, 101, 101, 101, 105, 103, 104, 116, 104, 115, 11, 102, 105, 118, 101, 101, 105, 103, 104, 116, 104, 115, 12, 115, 101, 118, 101, 110, 101, 105, 103, 104, 116, 104, 115, 9, 97, 114, 114, 111, 119, 108, 101, 102, 116, 7, 97, 114, 114, 111, 119, 117, 112, 10, 97, 114, 114, 111, 119, 114, 105, 103, 104, 116, 9, 97, 114, 114, 111, 119, 100, 111, 119, 110, 9, 97, 114, 114, 111, 119, 98, 111, 116, 104, 9, 97, 114, 114, 111, 119, 117, 112, 100, 110, 12, 97, 114, 114, 111, 119, 117, 112, 100, 110, 98, 115, 101, 7, 117, 110, 105, 50, 50, 48, 54, 10, 111, 114, 116, 104, 111, 103, 111, 110, 97, 108, 12, 105, 110, 116, 101, 114, 115, 101, 99, 116, 105, 111, 110, 11, 101, 113, 117, 105, 118, 97, 108, 101, 110, 99, 101, 5, 104, 111, 117, 115, 101, 13, 114, 101, 118, 108, 111, 103, 105, 99, 97, 108, 110, 111, 116, 10, 105, 110, 116, 101, 103, 114, 97, 108, 116, 112, 10, 105, 110, 116, 101, 103, 114, 97, 108, 98, 116, 8, 83, 70, 49, 48, 48, 48, 48, 48, 8, 83, 70, 49, 49, 48, 48, 48, 48, 8, 83, 70, 48, 49, 48, 48, 48, 48, 8, 83, 70, 48, 51, 48, 48, 48, 48, 8, 83, 70, 48, 50, 48, 48, 48, 48, 8, 83, 70, 48, 52, 48, 48, 48, 48, 8, 83, 70, 48, 56, 48, 48, 48, 48, 8, 83, 70, 48, 57, 48, 48, 48, 48, 8, 83, 70, 48, 54, 48, 48, 48, 48, 8, 83, 70, 48, 55, 48, 48, 48, 48, 8, 83, 70, 48, 53, 48, 48, 48, 48, 8, 83, 70, 52, 51, 48, 48, 48, 48, 8, 83, 70, 50, 52, 48, 48, 48, 48, 8, 83, 70, 53, 49, 48, 48, 48, 48, 8, 83, 70, 53, 50, 48, 48, 48, 48, 8, 83, 70, 51, 57, 48, 48, 48, 48, 8, 83, 70, 50, 50, 48, 48, 48, 48, 8, 83, 70, 50, 49, 48, 48, 48, 48, 8, 83, 70, 50, 53, 48, 48, 48, 48, 8, 83, 70, 53, 48, 48, 48, 48, 48, 8, 83, 70, 52, 57, 48, 48, 48, 48, 8, 83, 70, 51, 56, 48, 48, 48, 48, 8, 83, 70, 50, 56, 48, 48, 48, 48, 8, 83, 70, 50, 55, 48, 48, 48, 48, 8, 83, 70, 50, 54, 48, 48, 48, 48, 8, 83, 70, 51, 54, 48, 48, 48, 48, 8, 83, 70, 51, 55, 48, 48, 48, 48, 8, 83, 70, 52, 50, 48, 48, 48, 48, 8, 83, 70, 49, 57, 48, 48, 48, 48, 8, 83, 70, 50, 48, 48, 48, 48, 48, 8, 83, 70, 50, 51, 48, 48, 48, 48, 8, 83, 70, 52, 55, 48, 48, 48, 48, 8, 83, 70, 52, 56, 48, 48, 48, 48, 8, 83, 70, 52, 49, 48, 48, 48, 48, 8, 83, 70, 52, 53, 48, 48, 48, 48, 8, 83, 70, 52, 54, 48, 48, 48, 48, 8, 83, 70, 52, 48, 48, 48, 48, 48, 8, 83, 70, 53, 52, 48, 48, 48, 48, 8, 83, 70, 53, 51, 48, 48, 48, 48, 8, 83, 70, 52, 52, 48, 48, 48, 48, 7, 117, 112, 98, 108, 111, 99, 107, 7, 100, 110, 98, 108, 111, 99, 107, 5, 98, 108, 111, 99, 107, 7, 108, 102, 98, 108, 111, 99, 107, 7, 114, 116, 98, 108, 111, 99, 107, 7, 108, 116, 115, 104, 97, 100, 101, 5, 115, 104, 97, 100, 101, 7, 100, 107, 115, 104, 97, 100, 101, 9, 102, 105, 108, 108, 101, 100, 98, 111, 120, 6, 72, 50, 50, 48, 55, 51, 6, 72, 49, 56, 53, 52, 51, 6, 72, 49, 56, 53, 53, 49, 10, 102, 105, 108, 108, 101, 100, 114, 101, 99, 116, 7, 116, 114, 105, 97, 103, 117, 112, 7, 116, 114, 105, 97, 103, 114, 116, 7, 116, 114, 105, 97, 103, 100, 110, 7, 116, 114, 105, 97, 103, 108, 102, 6, 99, 105, 114, 99, 108, 101, 6, 72, 49, 56, 53, 51, 51, 9, 105, 110, 118, 98, 117, 108, 108, 101, 116, 9, 105, 110, 118, 99, 105, 114, 99, 108, 101, 10, 111, 112, 101, 110, 98, 117, 108, 108, 101, 116, 9, 115, 109, 105, 108, 101, 102, 97, 99, 101, 12, 105, 110, 118, 115, 109, 105, 108, 101, 102, 97, 99, 101, 3, 115, 117, 110, 6, 102, 101, 109, 97, 108, 101, 4, 109, 97, 108, 101, 5, 115, 112, 97, 100, 101, 4, 99, 108, 117, 98, 5, 104, 101, 97, 114, 116, 7, 100, 105, 97, 109, 111, 110, 100, 11, 109, 117, 115, 105, 99, 97, 108, 110, 111, 116, 101, 14, 109, 117, 115, 105, 99, 97, 108, 110, 111, 116, 101, 100, 98, 108, 7, 117, 110, 105, 70, 66, 48, 49, 7, 117, 110, 105, 70, 66, 48, 50, 7, 117, 110, 105, 70, 48, 48, 53, 6, 109, 105, 100, 100, 111, 116, 11, 99, 111, 109, 109, 97, 97, 99, 99, 101, 110, 116, 12, 102, 111, 117, 114, 115, 117, 112, 101, 114, 105, 111, 114, 12, 102, 105, 118, 101, 115, 117, 112, 101, 114, 105, 111, 114, 13, 115, 101, 118, 101, 110, 115, 117, 112, 101, 114, 105, 111, 114, 13, 101, 105, 103, 104, 116, 115, 117, 112, 101, 114, 105, 111, 114, 13, 99, 121, 114, 105, 108, 108, 105, 99, 98, 114, 101, 118, 101, 16, 99, 97, 114, 111, 110, 99, 111, 109, 109, 97, 97, 99, 99, 101, 110, 116, 17, 99, 111, 109, 109, 97, 97, 99, 99, 101, 110, 116, 114, 111, 116, 97, 116, 101, 8, 103, 114, 97, 118, 101, 46, 117, 99, 8, 97, 99, 117, 116, 101, 46, 117, 99, 13, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 46, 117, 99, 8, 99, 97, 114, 111, 110, 46, 117, 99, 11, 100, 105, 101, 114, 101, 115, 105, 115, 46, 117, 99, 8, 116, 105, 108, 100, 101, 46, 117, 99, 15, 104, 117, 110, 103, 97, 114, 117, 109, 108, 97, 117, 116, 46, 117, 99, 8, 98, 114, 101, 118, 101, 46, 117, 99, 0, 0, 0, 0, 0, 3, 0, 8, 0, 2, 0, 10, 0, 1, 255, 255, 0, 3, 0, 1, 0, 0, 0, 14, 0, 0, 0, 24, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 2, 161, 0, 1, 0, 4, 0, 0, 0, 2, 0, 0, 0, 1, 0, 0, 0, 10, 0, 76, 0, 78, 0, 4, 68, 70, 76, 84, 0, 26, 99, 121, 114, 108, 0, 36, 103, 114, 101, 107, 0, 46, 108, 97, 116, 110, 0, 56, 0, 4, 0, 0, 0, 0, 255, 255, 0, 0, 0, 4, 0, 0, 0, 0, 255, 255, 0, 0, 0, 4, 0, 0, 0, 0, 255, 255, 0, 0, 0, 4, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 10, 0, 84, 0, 98, 0, 4, 68, 70, 76, 84, 0, 26, 99, 121, 114, 108, 0, 38, 103, 114, 101, 107, 0, 50, 108, 97, 116, 110, 0, 62, 0, 4, 0, 0, 0, 0, 255, 255, 0, 1, 0, 0, 0, 4, 0, 0, 0, 0, 255, 255, 0, 1, 0, 0, 0, 4, 0, 0, 0, 0, 255, 255, 0, 1, 0, 0, 0, 4, 0, 0, 0, 0, 255, 255, 0, 1, 0, 0, 0, 1, 107, 101, 114, 110, 0, 8, 0, 0, 0, 1, 0, 0, 0, 1, 0, 4, 0, 2, 0, 0, 0, 1, 0, 8, 0, 1, 15, 6, 0, 4, 0, 0, 0, 104, 0, 218, 0, 252, 1, 2, 1, 40, 1, 54, 1, 84, 1, 102, 1, 116, 1, 186, 1, 240, 2, 38, 2, 100, 2, 106, 2, 120, 2, 130, 2, 120, 2, 140, 2, 178, 2, 188, 2, 178, 3, 22, 3, 64, 3, 98, 3, 120, 3, 142, 3, 98, 3, 120, 3, 204, 3, 226, 3, 236, 4, 114, 4, 228, 4, 246, 5, 0, 2, 178, 2, 188, 5, 38, 5, 52, 5, 126, 5, 180, 5, 246, 5, 38, 6, 32, 6, 78, 6, 88, 6, 130, 6, 148, 6, 194, 5, 38, 6, 194, 6, 208, 6, 234, 6, 234, 6, 240, 7, 50, 7, 108, 7, 178, 8, 28, 8, 62, 8, 100, 8, 138, 8, 180, 8, 186, 8, 200, 8, 238, 9, 72, 9, 146, 10, 12, 10, 158, 10, 196, 10, 226, 10, 240, 10, 246, 11, 0, 11, 58, 11, 100, 11, 146, 11, 156, 11, 206, 12, 8, 12, 34, 12, 52, 12, 86, 12, 112, 12, 166, 12, 192, 12, 218, 12, 252, 13, 46, 13, 92, 13, 114, 13, 148, 13, 230, 14, 16, 14, 54, 14, 68, 14, 78, 14, 88, 14, 130, 14, 172, 14, 194, 14, 220, 14, 226, 14, 240, 0, 8, 0, 36, 255, 180, 0, 60, 255, 219, 1, 86, 255, 180, 1, 95, 255, 180, 1, 98, 255, 180, 1, 105, 255, 180, 1, 114, 255, 219, 1, 120, 255, 219, 0, 1, 0, 20, 255, 143, 0, 9, 0, 3, 255, 180, 0, 55, 255, 104, 0, 57, 255, 104, 0, 58, 255, 143, 0, 60, 255, 68, 0, 89, 255, 180, 0, 90, 255, 219, 0, 92, 255, 180, 2, 9, 255, 143, 0, 3, 0, 15, 255, 29, 0, 17, 255, 29, 0, 36, 255, 143, 0, 7, 0, 3, 255, 219, 0, 55, 255, 104, 0, 57, 255, 104, 0, 58, 255, 143, 0, 60, 255, 68, 0, 92, 255, 180, 2, 9, 255, 143, 0, 4, 0, 3, 255, 219, 0, 15, 254, 248, 0, 17, 254, 248, 0, 36, 255, 104, 0, 3, 0, 57, 255, 219, 0, 58, 255, 219, 0, 60, 255, 180, 0, 17, 0, 15, 255, 29, 0, 16, 255, 143, 0, 17, 255, 29, 0, 29, 255, 29, 0, 30, 255, 29, 0, 36, 255, 104, 0, 50, 255, 219, 0, 68, 255, 104, 0, 70, 255, 104, 0, 72, 255, 104, 0, 76, 255, 219, 0, 82, 255, 104, 0, 85, 255, 143, 0, 86, 255, 104, 0, 88, 255, 104, 0, 90, 255, 104, 0, 92, 255, 104, 0, 13, 0, 15, 255, 68, 0, 16, 255, 143, 0, 17, 255, 68, 0, 29, 255, 143, 0, 30, 255, 143, 0, 36, 255, 104, 0, 68, 255, 143, 0, 72, 255, 143, 0, 76, 255, 219, 0, 82, 255, 104, 0, 85, 255, 143, 0, 88, 255, 180, 0, 92, 255, 180, 0, 13, 0, 15, 255, 143, 0, 16, 255, 215, 0, 17, 255, 143, 0, 29, 255, 219, 0, 30, 255, 219, 0, 36, 255, 143, 0, 68, 255, 180, 0, 72, 255, 219, 0, 76, 255, 238, 0, 82, 255, 219, 0, 85, 255, 219, 0, 88, 255, 219, 0, 92, 255, 219, 0, 15, 0, 3, 255, 219, 0, 15, 255, 29, 0, 16, 255, 143, 0, 17, 255, 29, 0, 29, 255, 104, 0, 30, 255, 104, 0, 36, 255, 68, 0, 68, 255, 143, 0, 72, 255, 143, 0, 76, 255, 180, 0, 82, 255, 104, 0, 83, 255, 143, 0, 84, 255, 104, 0, 88, 255, 143, 0, 89, 255, 143, 0, 1, 2, 9, 0, 37, 0, 3, 0, 15, 255, 143, 0, 17, 255, 143, 2, 9, 0, 76, 0, 2, 0, 15, 255, 104, 0, 17, 255, 104, 0, 2, 0, 15, 255, 180, 0, 17, 255, 180, 0, 9, 1, 102, 255, 201, 1, 109, 255, 201, 1, 113, 255, 86, 1, 114, 255, 70, 1, 115, 255, 201, 1, 120, 255, 70, 1, 128, 255, 180, 1, 138, 255, 180, 1, 148, 255, 180, 0, 2, 1, 114, 255, 199, 1, 120, 255, 199, 0, 22, 1, 94, 1, 0, 1, 95, 255, 70, 1, 98, 255, 70, 1, 102, 255, 178, 1, 105, 255, 70, 1, 109, 255, 178, 1, 115, 255, 178, 1, 118, 255, 178, 1, 121, 255, 104, 1, 123, 255, 180, 1, 124, 255, 180, 1, 126, 255, 104, 1, 129, 255, 180, 1, 132, 255, 180, 1, 134, 255, 180, 1, 135, 255, 180, 1, 137, 255, 180, 1, 140, 255, 104, 1, 144, 255, 104, 1, 147, 255, 104, 1, 151, 0, 92, 1, 153, 255, 104, 0, 10, 1, 102, 255, 201, 1, 109, 255, 201, 1, 113, 255, 86, 1, 114, 255, 70, 1, 115, 255, 201, 1, 120, 255, 70, 1, 128, 255, 180, 1, 138, 255, 180, 1, 148, 255, 180, 2, 9, 255, 143, 0, 8, 0, 15, 255, 31, 0, 17, 255, 31, 1, 95, 255, 33, 1, 98, 255, 33, 1, 105, 255, 33, 1, 124, 255, 190, 1, 134, 255, 190, 1, 151, 0, 94, 0, 5, 1, 102, 255, 201, 1, 109, 255, 201, 1, 113, 255, 86, 1, 114, 255, 70, 1, 120, 255, 70, 0, 5, 1, 95, 255, 201, 1, 98, 255, 201, 1, 105, 255, 201, 1, 114, 255, 199, 1, 120, 255, 199, 0, 15, 1, 102, 255, 162, 1, 109, 255, 162, 1, 115, 255, 162, 1, 121, 255, 209, 1, 126, 255, 209, 1, 129, 255, 209, 1, 131, 255, 209, 1, 133, 255, 209, 1, 139, 255, 209, 1, 140, 255, 209, 1, 144, 255, 209, 1, 147, 255, 209, 1, 150, 255, 209, 1, 153, 255, 209, 1, 155, 255, 209, 0, 5, 0, 15, 254, 250, 0, 17, 254, 250, 1, 95, 255, 104, 1, 98, 255, 104, 1, 105, 255, 104, 0, 2, 1, 141, 255, 221, 1, 145, 255, 221, 0, 33, 0, 15, 255, 31, 0, 16, 255, 143, 0, 17, 255, 31, 0, 29, 255, 31, 0, 30, 255, 31, 1, 94, 0, 242, 1, 95, 255, 104, 1, 98, 255, 92, 1, 102, 255, 219, 1, 105, 255, 104, 1, 109, 255, 219, 1, 115, 255, 201, 1, 118, 255, 219, 1, 121, 255, 104, 1, 122, 255, 104, 1, 126, 255, 104, 1, 128, 255, 104, 1, 129, 255, 172, 1, 130, 255, 104, 1, 132, 255, 104, 1, 134, 255, 219, 1, 137, 255, 104, 1, 138, 255, 104, 1, 140, 255, 104, 1, 144, 255, 104, 1, 146, 255, 104, 1, 147, 255, 104, 1, 148, 255, 133, 1, 149, 255, 104, 1, 151, 0, 92, 1, 152, 255, 104, 1, 153, 255, 104, 1, 154, 255, 104, 0, 28, 0, 15, 255, 31, 0, 16, 255, 143, 0, 17, 255, 31, 0, 29, 255, 104, 0, 30, 255, 104, 1, 94, 1, 0, 1, 95, 255, 70, 1, 98, 255, 70, 1, 102, 255, 178, 1, 105, 255, 70, 1, 109, 255, 178, 1, 115, 255, 178, 1, 118, 255, 178, 1, 121, 255, 104, 1, 123, 255, 180, 1, 124, 255, 180, 1, 126, 255, 104, 1, 128, 255, 172, 1, 129, 255, 180, 1, 132, 255, 180, 1, 134, 255, 180, 1, 135, 255, 180, 1, 137, 255, 180, 1, 140, 255, 104, 1, 144, 255, 104, 1, 147, 255, 104, 1, 151, 0, 92, 1, 153, 255, 104, 0, 4, 1, 95, 255, 201, 1, 113, 255, 201, 1, 114, 255, 199, 1, 120, 255, 199, 0, 2, 1, 150, 255, 229, 1, 155, 255, 229, 0, 9, 1, 121, 255, 219, 1, 126, 255, 219, 1, 129, 255, 219, 1, 140, 255, 219, 1, 144, 255, 219, 1, 147, 255, 219, 1, 150, 255, 219, 1, 153, 255, 219, 1, 155, 255, 219, 0, 3, 1, 141, 255, 199, 1, 145, 255, 199, 1, 148, 255, 182, 0, 18, 1, 121, 255, 141, 1, 123, 255, 207, 1, 126, 255, 141, 1, 128, 255, 190, 1, 129, 255, 180, 1, 132, 255, 207, 1, 133, 255, 180, 1, 134, 255, 207, 1, 135, 255, 207, 1, 138, 255, 190, 1, 140, 255, 141, 1, 141, 255, 180, 1, 144, 255, 141, 1, 145, 255, 180, 1, 147, 255, 141, 1, 150, 255, 141, 1, 153, 255, 141, 1, 155, 255, 141, 0, 13, 1, 121, 255, 188, 1, 126, 255, 188, 1, 129, 255, 188, 1, 131, 255, 188, 1, 133, 255, 227, 1, 139, 255, 188, 1, 140, 255, 188, 1, 143, 255, 188, 1, 144, 255, 188, 1, 147, 255, 188, 1, 150, 255, 188, 1, 153, 255, 188, 1, 155, 255, 188, 0, 16, 1, 121, 255, 231, 1, 125, 255, 225, 1, 126, 255, 231, 1, 129, 255, 231, 1, 131, 255, 231, 1, 139, 255, 231, 1, 140, 255, 231, 1, 143, 255, 231, 1, 144, 255, 231, 1, 146, 255, 225, 1, 147, 255, 231, 1, 150, 255, 231, 1, 152, 255, 225, 1, 153, 255, 231, 1, 154, 255, 225, 1, 155, 255, 231, 0, 10, 1, 121, 255, 231, 1, 126, 255, 231, 1, 129, 255, 231, 1, 131, 255, 231, 1, 139, 255, 231, 1, 140, 255, 231, 1, 143, 255, 231, 1, 144, 255, 231, 1, 147, 255, 231, 1, 153, 255, 231, 0, 11, 1, 121, 255, 199, 1, 126, 255, 199, 1, 129, 255, 199, 1, 131, 255, 199, 1, 136, 255, 180, 1, 140, 255, 199, 1, 143, 255, 199, 1, 144, 255, 199, 1, 147, 255, 199, 1, 150, 255, 199, 1, 155, 255, 199, 0, 2, 1, 141, 255, 199, 1, 145, 255, 199, 0, 10, 1, 121, 255, 199, 1, 126, 255, 199, 1, 129, 255, 199, 1, 131, 255, 199, 1, 140, 255, 199, 1, 143, 255, 199, 1, 144, 255, 199, 1, 147, 255, 199, 1, 150, 255, 199, 1, 155, 255, 199, 0, 4, 1, 136, 255, 231, 1, 141, 255, 199, 1, 145, 255, 199, 1, 148, 255, 182, 0, 11, 1, 121, 255, 182, 1, 126, 255, 182, 1, 129, 255, 182, 1, 131, 255, 182, 1, 140, 255, 182, 1, 143, 255, 182, 1, 144, 255, 182, 1, 147, 255, 182, 1, 150, 255, 213, 1, 153, 255, 182, 1, 155, 255, 213, 0, 3, 1, 141, 255, 199, 1, 145, 255, 199, 1, 148, 255, 213, 0, 6, 0, 15, 255, 25, 0, 17, 255, 0, 0, 29, 255, 229, 0, 30, 255, 229, 0, 108, 255, 178, 0, 123, 255, 178, 0, 1, 2, 9, 255, 51, 0, 16, 1, 174, 0, 76, 1, 181, 0, 25, 1, 184, 255, 229, 1, 185, 255, 229, 1, 187, 255, 205, 1, 188, 255, 154, 1, 189, 255, 178, 1, 190, 255, 205, 1, 193, 255, 100, 1, 199, 255, 205, 1, 202, 0, 25, 1, 203, 255, 229, 1, 219, 255, 229, 1, 220, 255, 229, 1, 231, 0, 25, 2, 9, 255, 152, 0, 14, 1, 170, 255, 178, 1, 176, 255, 205, 1, 177, 255, 229, 1, 181, 255, 205, 1, 187, 255, 229, 1, 188, 255, 205, 1, 189, 255, 205, 1, 190, 255, 229, 1, 191, 255, 205, 1, 193, 255, 178, 1, 196, 255, 178, 1, 199, 255, 205, 1, 201, 255, 205, 1, 221, 255, 229, 0, 17, 1, 170, 255, 154, 1, 174, 255, 229, 1, 176, 255, 178, 1, 177, 255, 229, 1, 181, 255, 205, 1, 184, 255, 205, 1, 187, 255, 178, 1, 188, 255, 178, 1, 189, 255, 178, 1, 190, 255, 205, 1, 191, 255, 178, 1, 193, 255, 178, 1, 196, 255, 154, 1, 201, 255, 205, 1, 220, 255, 229, 1, 223, 255, 229, 1, 225, 255, 178, 0, 26, 0, 15, 255, 25, 0, 17, 255, 0, 0, 29, 255, 229, 0, 30, 255, 229, 0, 108, 255, 178, 0, 123, 255, 178, 1, 170, 255, 127, 1, 174, 255, 205, 1, 181, 255, 205, 1, 184, 255, 229, 1, 187, 255, 229, 1, 202, 255, 229, 1, 204, 255, 205, 1, 206, 255, 178, 1, 207, 255, 152, 1, 210, 255, 205, 1, 213, 255, 154, 1, 214, 255, 178, 1, 215, 255, 205, 1, 216, 255, 154, 1, 218, 255, 178, 1, 221, 255, 178, 1, 229, 255, 178, 1, 230, 255, 178, 1, 232, 255, 178, 1, 233, 255, 178, 0, 8, 1, 177, 0, 25, 1, 189, 0, 25, 1, 190, 255, 229, 1, 193, 255, 229, 1, 207, 0, 25, 1, 209, 0, 51, 1, 216, 0, 25, 1, 221, 0, 25, 0, 9, 1, 177, 0, 25, 1, 184, 255, 229, 1, 187, 255, 205, 1, 188, 0, 51, 1, 189, 0, 51, 1, 193, 0, 25, 1, 196, 0, 76, 1, 202, 0, 25, 1, 216, 255, 229, 0, 9, 1, 176, 255, 205, 1, 181, 255, 205, 1, 184, 255, 229, 1, 187, 255, 205, 1, 188, 255, 178, 1, 189, 255, 178, 1, 190, 255, 205, 1, 193, 255, 178, 1, 201, 255, 205, 0, 10, 1, 177, 0, 76, 1, 187, 255, 229, 1, 188, 0, 51, 1, 189, 0, 51, 1, 190, 255, 229, 1, 193, 0, 51, 1, 199, 0, 25, 1, 202, 0, 25, 1, 209, 0, 25, 1, 219, 255, 229, 0, 1, 1, 202, 0, 51, 0, 3, 1, 202, 0, 25, 1, 219, 255, 229, 1, 225, 255, 229, 0, 9, 1, 170, 255, 205, 1, 174, 255, 229, 1, 176, 255, 229, 1, 181, 255, 205, 1, 189, 255, 205, 1, 191, 255, 178, 1, 201, 255, 229, 1, 206, 255, 205, 1, 213, 255, 229, 0, 22, 0, 15, 254, 229, 0, 17, 254, 205, 0, 29, 255, 229, 0, 30, 255, 229, 1, 170, 255, 76, 1, 174, 255, 127, 1, 176, 255, 229, 1, 177, 255, 229, 1, 181, 255, 127, 1, 182, 255, 229, 1, 184, 255, 229, 1, 187, 255, 205, 1, 188, 255, 229, 1, 189, 255, 229, 1, 190, 255, 229, 1, 191, 255, 178, 1, 201, 255, 205, 1, 202, 255, 229, 1, 206, 255, 127, 1, 207, 255, 205, 1, 216, 255, 205, 1, 233, 255, 229, 0, 18, 1, 170, 255, 205, 1, 174, 255, 229, 1, 177, 255, 229, 1, 181, 255, 205, 1, 182, 255, 229, 1, 184, 255, 205, 1, 188, 255, 205, 1, 189, 255, 229, 1, 191, 255, 178, 1, 193, 255, 205, 1, 196, 255, 229, 1, 199, 255, 229, 1, 202, 0, 25, 1, 203, 255, 229, 1, 208, 0, 25, 1, 219, 255, 229, 1, 222, 255, 229, 1, 225, 255, 229, 0, 30, 0, 15, 255, 51, 0, 17, 255, 25, 0, 29, 255, 229, 0, 30, 255, 229, 0, 108, 255, 205, 1, 170, 255, 127, 1, 174, 255, 205, 1, 176, 0, 51, 1, 181, 255, 205, 1, 184, 255, 205, 1, 190, 255, 178, 1, 201, 255, 229, 1, 202, 255, 205, 1, 204, 255, 178, 1, 207, 255, 154, 1, 210, 255, 178, 1, 212, 255, 178, 1, 213, 255, 127, 1, 214, 255, 152, 1, 216, 255, 127, 1, 217, 255, 229, 1, 218, 255, 178, 1, 219, 255, 127, 1, 221, 255, 178, 1, 223, 255, 178, 1, 227, 255, 229, 1, 229, 255, 229, 1, 230, 255, 229, 1, 232, 255, 229, 1, 233, 255, 205, 0, 36, 0, 15, 255, 25, 0, 17, 255, 0, 0, 29, 255, 205, 0, 30, 255, 205, 0, 108, 255, 178, 0, 123, 255, 178, 1, 170, 255, 102, 1, 174, 255, 152, 1, 181, 255, 178, 1, 184, 255, 205, 1, 190, 255, 178, 1, 199, 255, 229, 1, 201, 255, 205, 1, 203, 255, 205, 1, 204, 255, 178, 1, 205, 255, 178, 1, 206, 255, 127, 1, 207, 255, 127, 1, 208, 255, 229, 1, 209, 255, 154, 1, 210, 255, 178, 1, 211, 255, 178, 1, 212, 255, 178, 1, 213, 255, 127, 1, 214, 255, 154, 1, 215, 255, 178, 1, 216, 255, 127, 1, 217, 255, 178, 1, 218, 255, 178, 1, 219, 255, 127, 1, 223, 255, 205, 1, 224, 255, 178, 1, 226, 255, 178, 1, 227, 255, 178, 1, 232, 255, 178, 1, 233, 255, 154, 0, 9, 1, 170, 255, 205, 1, 174, 255, 152, 1, 181, 255, 178, 1, 188, 255, 178, 1, 189, 255, 178, 1, 190, 255, 229, 1, 193, 255, 229, 1, 201, 255, 203, 1, 213, 255, 205, 0, 7, 1, 177, 255, 229, 1, 184, 255, 203, 1, 187, 255, 178, 1, 190, 255, 178, 1, 199, 255, 205, 1, 216, 255, 229, 1, 221, 255, 229, 0, 3, 1, 202, 0, 76, 1, 207, 0, 25, 1, 216, 0, 25, 0, 1, 1, 202, 0, 25, 0, 2, 1, 201, 255, 178, 2, 9, 255, 51, 0, 14, 1, 170, 255, 205, 1, 174, 255, 229, 1, 176, 255, 178, 1, 177, 255, 205, 1, 181, 255, 178, 1, 182, 255, 205, 1, 184, 255, 229, 1, 187, 255, 205, 1, 188, 255, 49, 1, 191, 255, 152, 1, 193, 255, 102, 1, 199, 255, 178, 1, 201, 255, 178, 2, 9, 255, 102, 0, 10, 1, 174, 255, 205, 1, 176, 255, 205, 1, 177, 255, 229, 1, 181, 255, 178, 1, 190, 255, 229, 1, 191, 255, 205, 1, 201, 255, 205, 1, 206, 255, 229, 1, 208, 0, 25, 1, 213, 255, 205, 0, 11, 1, 170, 255, 205, 1, 174, 255, 205, 1, 176, 255, 205, 1, 181, 255, 178, 1, 187, 255, 229, 1, 188, 255, 205, 1, 191, 255, 178, 1, 193, 255, 229, 1, 206, 255, 205, 1, 208, 0, 25, 1, 213, 255, 205, 0, 2, 1, 209, 0, 25, 1, 225, 255, 205, 0, 12, 1, 206, 255, 205, 1, 208, 255, 229, 1, 209, 255, 229, 1, 213, 255, 205, 1, 214, 255, 229, 1, 219, 255, 229, 1, 221, 255, 229, 1, 223, 255, 205, 1, 225, 255, 205, 1, 228, 255, 229, 1, 231, 255, 229, 1, 233, 255, 229, 0, 14, 1, 202, 255, 229, 1, 203, 255, 229, 1, 207, 255, 229, 1, 208, 255, 229, 1, 213, 255, 229, 1, 214, 255, 229, 1, 216, 255, 229, 1, 219, 255, 205, 1, 220, 255, 229, 1, 221, 255, 205, 1, 222, 255, 229, 1, 225, 255, 178, 1, 228, 255, 205, 1, 233, 255, 229, 0, 6, 0, 15, 255, 76, 0, 17, 255, 51, 1, 206, 255, 178, 1, 213, 255, 205, 1, 216, 255, 229, 1, 219, 255, 229, 0, 4, 1, 209, 0, 25, 1, 219, 255, 229, 1, 221, 0, 25, 1, 228, 255, 229, 0, 8, 1, 203, 255, 229, 1, 208, 255, 229, 1, 214, 255, 229, 1, 219, 255, 229, 1, 220, 255, 229, 1, 221, 255, 229, 1, 223, 255, 229, 1, 225, 255, 205, 0, 6, 1, 202, 0, 25, 1, 207, 255, 229, 1, 209, 0, 25, 1, 216, 255, 205, 1, 219, 255, 229, 1, 225, 255, 205, 0, 13, 1, 202, 255, 229, 1, 203, 255, 205, 1, 207, 255, 229, 1, 208, 255, 229, 1, 209, 255, 229, 1, 213, 255, 229, 1, 214, 255, 205, 1, 216, 255, 205, 1, 219, 255, 205, 1, 221, 255, 205, 1, 222, 255, 229, 1, 225, 255, 178, 1, 228, 255, 205, 0, 6, 1, 213, 0, 25, 1, 216, 255, 229, 1, 219, 255, 229, 1, 222, 255, 229, 1, 225, 255, 229, 1, 231, 255, 229, 0, 6, 1, 203, 255, 229, 1, 207, 255, 229, 1, 216, 255, 229, 1, 219, 255, 229, 1, 221, 255, 229, 1, 225, 255, 205, 0, 8, 1, 202, 255, 229, 1, 203, 255, 229, 1, 209, 255, 229, 1, 216, 255, 229, 1, 219, 255, 229, 1, 221, 255, 229, 1, 222, 255, 229, 1, 231, 255, 229, 0, 12, 1, 206, 255, 229, 1, 208, 255, 229, 1, 209, 255, 229, 1, 213, 255, 205, 1, 214, 255, 229, 1, 219, 255, 229, 1, 220, 255, 205, 1, 221, 255, 229, 1, 223, 255, 205, 1, 225, 255, 205, 1, 231, 255, 229, 1, 233, 255, 229, 0, 11, 1, 206, 255, 205, 1, 208, 255, 229, 1, 209, 255, 229, 1, 213, 255, 205, 1, 214, 255, 229, 1, 220, 255, 229, 1, 221, 255, 229, 1, 223, 255, 229, 1, 225, 255, 205, 1, 231, 255, 229, 1, 233, 255, 229, 0, 5, 1, 202, 0, 25, 1, 203, 255, 229, 1, 223, 255, 229, 1, 225, 255, 203, 1, 228, 255, 229, 0, 8, 0, 15, 255, 102, 0, 17, 255, 76, 1, 206, 255, 229, 1, 208, 0, 25, 1, 213, 255, 229, 1, 216, 255, 229, 1, 219, 255, 229, 1, 221, 0, 51, 0, 20, 0, 15, 255, 102, 0, 17, 255, 76, 0, 29, 255, 229, 0, 30, 255, 229, 0, 123, 0, 51, 1, 202, 255, 229, 1, 206, 255, 205, 1, 207, 255, 229, 1, 208, 0, 25, 1, 209, 255, 229, 1, 213, 255, 229, 1, 214, 255, 229, 1, 216, 255, 205, 1, 218, 255, 229, 1, 219, 255, 205, 1, 220, 0, 25, 1, 222, 255, 229, 1, 223, 0, 25, 1, 231, 255, 229, 1, 233, 255, 229, 0, 10, 1, 203, 255, 229, 1, 206, 255, 229, 1, 207, 255, 229, 1, 213, 255, 205, 1, 214, 255, 229, 1, 216, 255, 229, 1, 220, 255, 229, 1, 221, 255, 229, 1, 225, 255, 205, 1, 233, 255, 229, 0, 9, 1, 203, 255, 229, 1, 207, 255, 205, 1, 209, 255, 229, 1, 216, 255, 205, 1, 219, 255, 205, 1, 221, 0, 25, 1, 222, 255, 229, 1, 225, 255, 205, 1, 231, 255, 229, 0, 3, 1, 202, 0, 25, 1, 209, 0, 25, 1, 219, 255, 229, 0, 2, 1, 202, 0, 25, 1, 216, 255, 229, 0, 2, 1, 220, 255, 76, 1, 225, 255, 76, 0, 10, 1, 203, 255, 229, 1, 206, 255, 229, 1, 208, 255, 229, 1, 209, 255, 229, 1, 213, 255, 205, 1, 214, 255, 229, 1, 219, 255, 229, 1, 220, 255, 229, 1, 223, 255, 229, 1, 233, 255, 229, 0, 10, 1, 203, 255, 229, 1, 206, 255, 229, 1, 208, 255, 229, 1, 213, 255, 205, 1, 214, 255, 229, 1, 219, 255, 229, 1, 220, 255, 205, 1, 223, 255, 205, 1, 225, 255, 178, 1, 231, 255, 229, 0, 5, 0, 15, 255, 102, 0, 17, 255, 76, 0, 29, 255, 229, 0, 30, 255, 229, 0, 108, 255, 205, 0, 6, 0, 15, 255, 127, 0, 17, 255, 102, 0, 29, 255, 229, 0, 30, 255, 229, 0, 108, 255, 205, 0, 123, 255, 205, 0, 1, 2, 8, 255, 180, 0, 3, 0, 3, 255, 143, 0, 86, 255, 180, 2, 9, 255, 180, 0, 5, 1, 157, 255, 51, 1, 166, 255, 51, 1, 188, 255, 76, 1, 193, 255, 49, 1, 196, 255, 76, 0, 1, 0, 104, 0, 3, 0, 20, 0, 36, 0, 41, 0, 47, 0, 51, 0, 53, 0, 55, 0, 57, 0, 58, 0, 60, 0, 73, 0, 85, 0, 89, 0, 90, 0, 92, 1, 86, 1, 91, 1, 92, 1, 93, 1, 95, 1, 97, 1, 98, 1, 102, 1, 104, 1, 105, 1, 109, 1, 111, 1, 112, 1, 113, 1, 114, 1, 115, 1, 116, 1, 117, 1, 118, 1, 120, 1, 129, 1, 131, 1, 135, 1, 136, 1, 139, 1, 140, 1, 141, 1, 142, 1, 145, 1, 147, 1, 148, 1, 150, 1, 153, 1, 155, 1, 158, 1, 164, 1, 165, 1, 170, 1, 171, 1, 172, 1, 173, 1, 174, 1, 176, 1, 177, 1, 180, 1, 181, 1, 182, 1, 184, 1, 186, 1, 187, 1, 188, 1, 189, 1, 190, 1, 191, 1, 192, 1, 195, 1, 196, 1, 198, 1, 199, 1, 200, 1, 202, 1, 203, 1, 204, 1, 205, 1, 206, 1, 207, 1, 208, 1, 209, 1, 212, 1, 213, 1, 214, 1, 216, 1, 218, 1, 219, 1, 220, 1, 221, 1, 222, 1, 223, 1, 224, 1, 227, 1, 230, 1, 231, 1, 232, 1, 246, 1, 248, 2, 8, 2, 9, 2, 14, 0, 0, 0, 1, 0, 0, 0, 0, 198, 212, 46, 153, 0, 0, 0, 0, 191, 26, 255, 128, 0, 0, 0, 0, 200, 13, 85, 156], true, false);
if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}
// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}
run('font.ttf waka 150 120 25'.split(' '));
// {{POST_RUN_ADDITIONS}}
  // {{MODULE_ADDITIONS}}
